{"cells": [{"cell_type": "code", "execution_count": 1, "id": "bc8f4f90", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:46.827386Z", "iopub.status.busy": "2024-12-04T12:14:46.825996Z", "iopub.status.idle": "2024-12-04T12:14:47.235902Z", "shell.execute_reply": "2024-12-04T12:14:47.234788Z"}, "papermill": {"duration": 0.421271, "end_time": "2024-12-04T12:14:47.238606", "exception": false, "start_time": "2024-12-04T12:14:46.817335", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [], "source": ["import pandas as pd\n", "import numpy as np\n", "import plotly.express as px\n", "\n", "def natural_sort( l ): \n", "    import re \n", "    \"\"\" Sort the given iterable in the way that humans expect.\"\"\" \n", "    convert = lambda text: int(text) if text.isdigit() else text \n", "    alphanum_key = lambda key: [ convert(c) for c in re.split('([0-9]+)', key) ] \n", "    return sorted(l, key = alphanum_key)"]}, {"cell_type": "code", "execution_count": 2, "id": "882cd1c8", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:47.252023Z", "iopub.status.busy": "2024-12-04T12:14:47.251670Z", "iopub.status.idle": "2024-12-04T12:14:47.256599Z", "shell.execute_reply": "2024-12-04T12:14:47.255709Z"}, "papermill": {"duration": 0.013231, "end_time": "2024-12-04T12:14:47.258463", "exception": false, "start_time": "2024-12-04T12:14:47.245232", "status": "completed"}, "tags": ["parameters", "remove-input"]}, "outputs": [], "source": ["metadata_path = '../../results/config/metadata.qcpass.tsv'\n", "bed_targets_path = \"../../config/ag-vampir.bed\"\n", "wkdir = \"../..\""]}, {"cell_type": "code", "execution_count": 3, "id": "2f7702a3", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:47.270482Z", "iopub.status.busy": "2024-12-04T12:14:47.270258Z", "iopub.status.idle": "2024-12-04T12:14:47.274581Z", "shell.execute_reply": "2024-12-04T12:14:47.273703Z"}, "papermill": {"duration": 0.012511, "end_time": "2024-12-04T12:14:47.276457", "exception": false, "start_time": "2024-12-04T12:14:47.263946", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [], "source": ["# Parameters\n", "metadata_path = \"config/metadata_ms.tsv\"\n", "bed_targets_path = \"config/ag-vampir.bed\"\n", "wkdir = \"/home/snagi/lstm_projects/ampseq-agvampir002\"\n"]}, {"cell_type": "markdown", "id": "45cc4120", "metadata": {"papermill": {"duration": 0.005357, "end_time": "2024-12-04T12:14:47.287251", "exception": false, "start_time": "2024-12-04T12:14:47.281894", "status": "completed"}, "tags": []}, "source": ["### Coverage\n", "\n", "In this notebook, we calculate coverage across the whole-genome and specifically at the SNP targets of the amplicon panel. "]}, {"cell_type": "code", "execution_count": 4, "id": "41d97bf4", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:47.299197Z", "iopub.status.busy": "2024-12-04T12:14:47.298980Z", "iopub.status.idle": "2024-12-04T12:14:47.317241Z", "shell.execute_reply": "2024-12-04T12:14:47.316072Z"}, "papermill": {"duration": 0.026536, "end_time": "2024-12-04T12:14:47.319139", "exception": false, "start_time": "2024-12-04T12:14:47.292603", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [], "source": ["# load panel metadata\n", "if metadata_path.endswith('.xlsx'):\n", "\tmetadata = pd.read_excel(metadata_path, engine='openpyxl')\n", "elif metadata_path.endswith('.tsv'):\n", "\tmetadata = pd.read_csv(metadata_path, sep=\"\\t\")\n", "elif metadata_path.endswith('.csv'):\n", "\tmetadata = pd.read_csv(metadata_path, sep=\",\")\n", "else:\n", "\traise ValueError(\"Metadata file must be .xlsx or .csv\")\n", "\n", "panel_metadata = pd.read_csv(bed_targets_path, sep=\"\\t\")\n", "panel_metadata.columns = ['contig', 'start', 'end', 'amplicon', 'mutation', 'ref', 'alt']\n", "contigs = panel_metadata.contig.unique()"]}, {"cell_type": "markdown", "id": "c5c1227b", "metadata": {"papermill": {"duration": 0.004581, "end_time": "2024-12-04T12:14:47.328446", "exception": false, "start_time": "2024-12-04T12:14:47.323865", "status": "completed"}, "tags": []}, "source": ["#### Whole-genome\n", "\n", "Lets plot coverage across the whole genome to see if we have off-target effects!"]}, {"cell_type": "code", "execution_count": 5, "id": "e177b62a", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:47.339895Z", "iopub.status.busy": "2024-12-04T12:14:47.339316Z", "iopub.status.idle": "2024-12-04T12:14:49.520964Z", "shell.execute_reply": "2024-12-04T12:14:49.519866Z"}, "papermill": {"duration": 2.19071, "end_time": "2024-12-04T12:14:49.523853", "exception": false, "start_time": "2024-12-04T12:14:47.333143", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [], "source": ["cov_list = []\n", "for sample_id in metadata['sample_id']:\n", "    cov_df = pd.read_csv(f\"{wkdir}/results/coverage/{sample_id}.per-base.bed.gz\", sep=\"\\t\", header=None)\n", "    cov_df.columns = [\"contig\", \"start\", \"end\", \"depth\"]\n", "    cov_df = cov_df.assign(sample_id=sample_id).query(\"contig in @contigs\")\n", "    cov_list.append(cov_df)\n", "\n", "cov_df = pd.concat(cov_list, axis=0)\n", "\n", "total_cov_df = cov_df.groupby(['contig', 'start', 'end']).agg({'depth':'sum'}).reset_index()\n", "total_cov_df = total_cov_df.assign(midpoint=lambda x: ((x.start + x.end)/2).astype(int))"]}, {"cell_type": "code", "execution_count": 6, "id": "e8a46ded", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:49.537554Z", "iopub.status.busy": "2024-12-04T12:14:49.537242Z", "iopub.status.idle": "2024-12-04T12:14:50.886679Z", "shell.execute_reply": "2024-12-04T12:14:50.885849Z"}, "papermill": {"duration": 1.383552, "end_time": "2024-12-04T12:14:50.913837", "exception": false, "start_time": "2024-12-04T12:14:49.530285", "status": "completed"}, "scrolled": false, "tags": ["remove-input"]}, "outputs": [{"data": {"text/html": ["        <script type=\"text/javascript\">\n", "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n", "        if (window.MathJax && window.MathJax.Hub && window.MathJax.Hub.Config) {window.MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n", "        if (typeof require !== 'undefined') {\n", "        require.undef(\"plotly\");\n", "        define('plotly', function(require, exports, module) {\n", "            /**\n", "* plotly.js v2.35.2\n", "* Copyright 2012-2024, Plotly, Inc.\n", "* All rights reserved.\n", "* Licensed under the MIT license\n", "*/\n", "/*! For license information please see plotly.min.js.LICENSE.txt */\n", "!function(t,e){\"object\"==typeof exports&&\"object\"==typeof module?module.exports=e():\"function\"==typeof define&&define.amd?define([],e):\"object\"==typeof exports?exports.Plotly=e():t.Plotly=e()}(self,(function(){return function(){var t={6713:function(t,e,r){\"use strict\";var n=r(34809),i={\"X,X div\":'direction:ltr;font-family:\"Open Sans\",verdana,arial,sans-serif;margin:0;padding:0;',\"X input,X button\":'font-family:\"Open Sans\",verdana,arial,sans-serif;',\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color .3s ease 0s;-moz-transition:background-color .3s ease 0s;-ms-transition:background-color .3s ease 0s;-o-transition:background-color .3s ease 0s;transition:background-color .3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity .3s ease 0s;-moz-transition:opacity .3s ease 0s;-ms-transition:opacity .3s ease 0s;-o-transition:opacity .3s ease 0s;transition:opacity .3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":'content:\"\";position:absolute;background:rgba(0,0,0,0);border:6px solid rgba(0,0,0,0);z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;',\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:#fff;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid rgba(0,0,0,0);border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",Y:'font-family:\"Open Sans\",verdana,arial,sans-serif;position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;',\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},14187:function(t,e,r){\"use strict\";t.exports=r(47908)},20273:function(t,e,r){\"use strict\";t.exports=r(58218)},6457:function(t,e,r){\"use strict\";t.exports=r(89362)},15849:function(t,e,r){\"use strict\";t.exports=r(53794)},38847:function(t,e,r){\"use strict\";t.exports=r(29698)},7659:function(t,e,r){\"use strict\";t.exports=r(51252)},60089:function(t,e,r){\"use strict\";t.exports=r(48050)},22084:function(t,e,r){\"use strict\";t.exports=r(58075)},35892:function(t,e,r){\"use strict\";t.exports=r(9419)},81204:function(t,e,r){\"use strict\";t.exports=r(28128)},55857:function(t,e,r){\"use strict\";t.exports=r(47050)},12862:function(t,e,r){\"use strict\";t.exports=r(91405)},97629:function(t,e,r){\"use strict\";t.exports=r(34406)},67549:function(t,e,r){\"use strict\";t.exports=r(17430)},2660:function(t,e,r){\"use strict\";t.exports=r(91995)},86071:function(t,e,r){\"use strict\";t.exports=r(81264)},66200:function(t,e,r){\"use strict\";t.exports=r(42849)},53446:function(t,e,r){\"use strict\";t.exports=r(52213)},86899:function(t,e,r){\"use strict\";t.exports=r(91132)},13430:function(t,e,r){\"use strict\";t.exports=r(50453)},21548:function(t,e,r){\"use strict\";t.exports=r(29251)},53939:function(t,e,r){\"use strict\";t.exports=r(72892)},1902:function(t,e,r){\"use strict\";t.exports=r(74461)},29096:function(t,e,r){\"use strict\";t.exports=r(66143)},23820:function(t,e,r){\"use strict\";t.exports=r(81955)},82017:function(t,e,r){\"use strict\";t.exports=r(36858)},113:function(t,e,r){\"use strict\";t.exports=r(92106)},20260:function(t,e,r){\"use strict\";var n=r(67549);n.register([r(20273),r(15849),r(21548),r(1902),r(29096),r(23820),r(12862),r(1639),r(10067),r(53446),r(31014),r(113),r(78170),r(8202),r(92382),r(82017),r(86899),r(54357),r(66903),r(90594),r(71680),r(7412),r(55857),r(784),r(74221),r(22084),r(44001),r(97281),r(12345),r(53939),r(29117),r(5410),r(5057),r(81204),r(86071),r(14226),r(35892),r(2660),r(96599),r(28573),r(76832),r(60089),r(51469),r(97629),r(27700),r(7659),r(11780),r(27195),r(6457),r(84639),r(14187),r(66200),r(13430),r(90590),r(38847)]),t.exports=n},28573:function(t,e,r){\"use strict\";t.exports=r(25638)},90594:function(t,e,r){\"use strict\";t.exports=r(75297)},7412:function(t,e,r){\"use strict\";t.exports=r(58859)},27700:function(t,e,r){\"use strict\";t.exports=r(12683)},5410:function(t,e,r){\"use strict\";t.exports=r(6305)},29117:function(t,e,r){\"use strict\";t.exports=r(83910)},78170:function(t,e,r){\"use strict\";t.exports=r(49913)},12345:function(t,e,r){\"use strict\";t.exports=r(15186)},96599:function(t,e,r){\"use strict\";t.exports=r(71760)},54357:function(t,e,r){\"use strict\";t.exports=r(17822)},51469:function(t,e,r){\"use strict\";t.exports=r(56534)},74221:function(t,e,r){\"use strict\";t.exports=r(18070)},44001:function(t,e,r){\"use strict\";t.exports=r(52378)},14226:function(t,e,r){\"use strict\";t.exports=r(30929)},5057:function(t,e,r){\"use strict\";t.exports=r(83866)},11780:function(t,e,r){\"use strict\";t.exports=r(66939)},27195:function(t,e,r){\"use strict\";t.exports=r(23748)},84639:function(t,e,r){\"use strict\";t.exports=r(73304)},1639:function(t,e,r){\"use strict\";t.exports=r(12864)},90590:function(t,e,r){\"use strict\";t.exports=r(99855)},97281:function(t,e,r){\"use strict\";t.exports=r(91450)},784:function(t,e,r){\"use strict\";t.exports=r(51943)},8202:function(t,e,r){\"use strict\";t.exports=r(80809)},66903:function(t,e,r){\"use strict\";t.exports=r(95984)},76832:function(t,e,r){\"use strict\";t.exports=r(51671)},92382:function(t,e,r){\"use strict\";t.exports=r(47181)},10067:function(t,e,r){\"use strict\";t.exports=r(37276)},71680:function(t,e,r){\"use strict\";t.exports=r(75703)},31014:function(t,e,r){\"use strict\";t.exports=r(38261)},11645:function(t){\"use strict\";t.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},50222:function(t,e,r){\"use strict\";var n=r(11645),i=r(80337),a=r(54826),o=r(78032).templatedArray;r(35081),t.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},60317:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(3377).draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach((function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref),a=i.getRefType(e.xref),o=i.getRefType(e.yref);e._extremes={},\"range\"===a&&s(e,r),\"range\"===o&&s(e,n)}))}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,m=p-f,g=3*t.startarrowsize*t.arrowwidth||0,y=g+f,v=g-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:m}),_=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,y),ppadminus:Math.max(h,v)});r={min:[x.min[0],_.min[0]],max:[x.max[0],_.max[0]]}}else y=s?y+s:y,v=s?v-s:v,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,y),ppadminus:Math.max(h,m,v)});t._extremes[n]=r}t.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},6035:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626),a=r(78032).arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}t.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(c.length||u.length){for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}}},53271:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766);t.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),m=r.hoverlabel||{};if(d){var g=a(\"hoverlabel.bgcolor\",m.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),y=a(\"hoverlabel.bordercolor\",m.bordercolor||i.contrast(g)),v=n.extendFlat({},m.font);v.color||(v.color=y),n.coerceFont(a,\"hoverlabel.font\",v)}a(\"captureevents\",!!d)}},59741:function(t,e,r){\"use strict\";var n=r(10721),i=r(8083);t.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},63737:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(59008),o=r(53271),s=r(50222);function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var m=h[d],g=i.coerceRef(t,e,p,m,\"\",\"paper\");if(\"paper\"!==g&&i.getFromId(p,g)._annIndices.push(e._index),i.coercePosition(e,p,a,g,m,.5),u){var y=\"a\"+m,v=i.coerceRef(t,e,p,y,\"pixel\",[\"pixel\",\"paper\"]);\"pixel\"!==v&&v!==g&&(v=e[y]=\"pixel\");var x=\"pixel\"===v?f[d]:.4;i.coercePosition(e,p,a,v,y,x)}a(m+\"anchor\"),a(m+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var _=a(\"xclick\"),b=a(\"yclick\");e._xclick=void 0===_?e.x:i.cleanPosition(_,p,e.xref),e._yclick=void 0===b?e.y:i.cleanPosition(b,p,e.yref)}}}t.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},3377:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(44122),o=r(34809),s=o.strTranslate,l=r(29714),c=r(78766),u=r(62203),h=r(32141),f=r(30635),p=r(27983),d=r(14751),m=r(78032).arrayEditor,g=r(23768);function y(t,e){var r=t._fullLayout.annotations[e]||{},n=l.getFromId(t,r.xref),i=l.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),x(t,r,e,!1,n,i)}function v(t,e,r,n,i){var a=i[r],o=i[r+\"ref\"],s=-1!==r.indexOf(\"y\"),c=\"domain\"===l.getRefType(o),u=s?n.h:n.w;return t?c?a+(s?-e:e)/t._length:t.p2r(t.r2p(a)+e):a+(s?-e:e)/u}function x(t,e,r,a,y,x){var _,b,w=t._fullLayout,T=t._fullLayout._size,k=t._context.edits;a?(_=\"annotation-\"+a,b=a+\".annotations\"):(_=\"annotation\",b=\"annotations\");var A=m(t.layout,b,e),M=A.modifyBase,S=A.modifyItem,E=A.getUpdateObj;w._infolayer.selectAll(\".\"+_+'[data-index=\"'+r+'\"]').remove();var C=\"clip\"+w._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var L={x:{},y:{}},I=+e.textangle||0,P=w._infolayer.append(\"g\").classed(_,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),z=P.append(\"g\").classed(\"annotation-text-g\",!0),O=k[e.showarrow?\"annotationTail\":\"annotationPosition\"],D=e.captureevents||k.annotationText||O,R=z.append(\"g\").style(\"pointer-events\",D?\"all\":null).call(p,\"pointer\").on(\"click\",(function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",Z(n.event))}));e.hovertext&&R.on(\"mouseover\",(function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();h.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color,fontWeight:n.weight,fontStyle:n.style,fontVariant:n.variant,fontShadow:n.fontShadow,fontLineposition:n.fontLineposition,fontTextcase:n.fontTextcase},{container:w._hoverlayer.node(),outerContainer:w._paper.node(),gd:t})})).on(\"mouseout\",(function(){h.loneUnhover(w._hoverlayer.node())}));var F=e.borderwidth,B=e.borderpad,N=F+B,j=R.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",F+\"px\").call(c.stroke,e.bordercolor).call(c.fill,e.bgcolor),U=e.width||e.height,V=w._topclips.selectAll(\"#\"+C).data(U?[0]:[]);V.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",C).append(\"rect\"),V.exit().remove();var q=e.font,H=w._meta?o.templateString(e.text,w._meta):e.text,G=R.append(\"text\").classed(\"annotation-text\",!0).text(H);k.annotationText?G.call(f.makeEditable,{delegate:R,gd:t}).call(W).on(\"edit\",(function(r){e.text=r,this.call(W),S(\"text\",r),y&&y.autorange&&M(y._name+\".autorange\",!0),x&&x.autorange&&M(x._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,E())})):G.call(W)}else n.selectAll(\"#\"+C).remove();function Z(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function W(r){return r.call(u.font,q).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),f.convertToTspans(r,t,Y),r}function Y(){var r=G.selectAll(\"a\");1===r.size()&&r.text()===G.text()&&R.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(j.node());var n=R.select(\".annotation-text-math-group\"),h=!n.empty(),m=u.bBox((h?n:G).node()),_=m.width,b=m.height,A=e.width||_,D=e.height||b,B=Math.round(A+2*N),q=Math.round(D+2*N);function H(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var W=!1,Y=[\"x\",\"y\"],X=0;X<Y.length;X++){var $,J,K,Q,tt,et=Y[X],rt=e[et+\"ref\"]||et,nt=e[\"a\"+et+\"ref\"],it={x:y,y:x}[et],at=(I+(\"x\"===et?0:-90))*Math.PI/180,ot=B*Math.cos(at),st=q*Math.sin(at),lt=Math.abs(ot)+Math.abs(st),ct=e[et+\"anchor\"],ut=e[et+\"shift\"]*(\"x\"===et?1:-1),ht=L[et],ft=l.getRefType(rt);if(it&&\"domain\"!==ft){var pt=it.r2fraction(e[et]);(pt<0||pt>1)&&(nt===rt?((pt=it.r2fraction(e[\"a\"+et]))<0||pt>1)&&(W=!0):W=!0),$=it._offset+it.r2p(e[et]),Q=.5}else{var dt=\"domain\"===ft;\"x\"===et?(K=e[et],$=dt?it._offset+it._length*K:$=T.l+T.w*K):(K=1-e[et],$=dt?it._offset+it._length*K:$=T.t+T.h*K),Q=e.showarrow?.5:K}if(e.showarrow){ht.head=$;var mt=e[\"a\"+et];if(tt=ot*H(.5,e.xanchor)-st*H(.5,e.yanchor),nt===rt){var gt=l.getRefType(nt);\"domain\"===gt?(\"y\"===et&&(mt=1-mt),ht.tail=it._offset+it._length*mt):\"paper\"===gt?\"y\"===et?(mt=1-mt,ht.tail=T.t+T.h*mt):ht.tail=T.l+T.w*mt:ht.tail=it._offset+it.r2p(mt),J=tt}else ht.tail=$+mt,J=tt+mt;ht.text=ht.tail+tt;var yt=w[\"x\"===et?\"width\":\"height\"];if(\"paper\"===rt&&(ht.head=o.constrain(ht.head,1,yt-1)),\"pixel\"===nt){var vt=-Math.max(ht.tail-3,ht.text),xt=Math.min(ht.tail+3,ht.text)-yt;vt>0?(ht.tail+=vt,ht.text+=vt):xt>0&&(ht.tail-=xt,ht.text-=xt)}ht.tail+=ut,ht.head+=ut}else J=tt=lt*H(Q,ct),ht.text=$+tt;ht.text+=ut,tt+=ut,J+=ut,e[\"_\"+et+\"padplus\"]=lt/2+J,e[\"_\"+et+\"padminus\"]=lt/2-J,e[\"_\"+et+\"size\"]=lt,e[\"_\"+et+\"shift\"]=tt}if(W)R.remove();else{var _t=0,bt=0;if(\"left\"!==e.align&&(_t=(A-_)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(bt=(D-b)*(\"middle\"===e.valign?.5:1)),h)n.select(\"svg\").attr({x:N+_t-1,y:N+bt}).call(u.setClipUrl,U?C:null,t);else{var wt=N+bt-m.top,Tt=N+_t-m.left;G.call(f.positionText,Tt,wt).call(u.setClipUrl,U?C:null,t)}V.select(\"rect\").call(u.setRect,N,N,A,D),j.call(u.setRect,F/2,F/2,B-F,q-F),R.call(u.setTranslate,Math.round(L.x.text-B/2),Math.round(L.y.text-q/2)),z.attr({transform:\"rotate(\"+I+\",\"+L.x.text+\",\"+L.y.text+\")\"});var kt,At=function(r,n){P.selectAll(\".annotation-arrow-g\").remove();var l=L.x.head,h=L.y.head,f=L.x.tail+r,p=L.y.tail+n,m=L.x.text+r,_=L.y.text+n,b=o.rotationXYMatrix(I,m,_),w=o.apply2DTransform(b),A=o.apply2DTransform2(b),C=+j.attr(\"width\"),O=+j.attr(\"height\"),D=m-.5*C,F=D+C,B=_-.5*O,N=B+O,U=[[D,B,D,N],[D,N,F,N],[F,N,F,B],[F,B,D,B]].map(A);if(!U.reduce((function(t,e){return t^!!o.segmentsIntersect(l,h,l+1e6,h+1e6,e[0],e[1],e[2],e[3])}),!1)){U.forEach((function(t){var e=o.segmentsIntersect(f,p,l,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,p=e.y)}));var V=e.arrowwidth,q=e.arrowcolor,H=e.arrowside,G=P.append(\"g\").style({opacity:c.opacity(q)}).classed(\"annotation-arrow-g\",!0),Z=G.append(\"path\").attr(\"d\",\"M\"+f+\",\"+p+\"L\"+l+\",\"+h).style(\"stroke-width\",V+\"px\").call(c.stroke,c.rgb(q));if(g(Z,H,e),k.annotationPosition&&Z.node().parentNode&&!a){var W=l,Y=h;if(e.standoff){var X=Math.sqrt(Math.pow(l-f,2)+Math.pow(h-p,2));W+=e.standoff*(f-l)/X,Y+=e.standoff*(p-h)/X}var $,J,K=G.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-W)+\",\"+(p-Y),transform:s(W,Y)}).style(\"stroke-width\",V+6+\"px\").call(c.stroke,\"rgba(0,0,0,0)\").call(c.fill,\"rgba(0,0,0,0)\");d.init({element:K.node(),gd:t,prepFn:function(){var t=u.getTranslate(R);$=t.x,J=t.y,y&&y.autorange&&M(y._name+\".autorange\",!0),x&&x.autorange&&M(x._name+\".autorange\",!0)},moveFn:function(t,r){var n=w($,J),i=n[0]+t,a=n[1]+r;R.call(u.setTranslate,i,a),S(\"x\",v(y,t,\"x\",T,e)),S(\"y\",v(x,r,\"y\",T,e)),e.axref===e.xref&&S(\"ax\",v(y,t,\"ax\",T,e)),e.ayref===e.yref&&S(\"ay\",v(x,r,\"ay\",T,e)),G.attr(\"transform\",s(t,r)),z.attr({transform:\"rotate(\"+I+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};e.showarrow&&At(0,0),O&&d.init({element:R.node(),gd:t,prepFn:function(){kt=z.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?S(\"ax\",v(y,t,\"ax\",T,e)):S(\"ax\",e.ax+t),e.ayref===e.yref?S(\"ay\",v(x,r,\"ay\",T.w,e)):S(\"ay\",e.ay+r),At(t,r);else{if(a)return;var i,o;if(y)i=v(y,t,\"x\",T,e);else{var l=e._xsize/T.w,c=e.x+(e._xshift-e.xshift)/T.w-l/2;i=d.align(c+t/T.w,l,0,1,e.xanchor)}if(x)o=v(x,r,\"y\",T,e);else{var u=e._ysize/T.h,h=e.y-(e._yshift+e.yshift)/T.h-u/2;o=d.align(h-r/T.h,u,0,1,e.yanchor)}S(\"x\",i),S(\"y\",o),y&&x||(n=d.getCursor(y?.5:i,x?.5:o,e.xanchor,e.yanchor))}z.attr({transform:s(t,r)+kt}),p(R,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",Z(n))},doneFn:function(){p(R),i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}}t.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&y(t,r);return a.previousPromises(t)},drawOne:y,drawRaw:x}},23768:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(11645),o=r(34809),s=o.strScale,l=o.strRotate,c=o.strTranslate;t.exports=function(t,e,r){var o,u,h,f,p=t.node(),d=a[r.arrowhead||0],m=a[r.startarrowhead||0],g=(r.arrowwidth||1)*(r.arrowsize||1),y=(r.arrowwidth||1)*(r.startarrowsize||1),v=e.indexOf(\"start\")>=0,x=e.indexOf(\"end\")>=0,_=d.backoff*g+r.standoff,b=m.backoff*y+r.startstandoff;if(\"line\"===p.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},u={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var w=o.x-u.x,T=o.y-u.y;if(f=(h=Math.atan2(T,w))+Math.PI,_&&b&&_+b>Math.sqrt(w*w+T*T))return void O();if(_){if(_*_>w*w+T*T)return void O();var k=_*Math.cos(h),A=_*Math.sin(h);u.x+=k,u.y+=A,t.attr({x2:u.x,y2:u.y})}if(b){if(b*b>w*w+T*T)return void O();var M=b*Math.cos(h),S=b*Math.sin(h);o.x-=M,o.y-=S,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===p.nodeName){var E=p.getTotalLength(),C=\"\";if(E<_+b)return void O();var L=p.getPointAtLength(0),I=p.getPointAtLength(.1);h=Math.atan2(L.y-I.y,L.x-I.x),o=p.getPointAtLength(Math.min(b,E)),C=\"0px,\"+b+\"px,\";var P=p.getPointAtLength(E),z=p.getPointAtLength(E-.1);f=Math.atan2(P.y-z.y,P.x-z.x),u=p.getPointAtLength(Math.max(0,E-_)),C+=E-(C?b+_:_)+\"px,\"+E+\"px\",t.style(\"stroke-dasharray\",C)}function O(){t.style(\"stroke-dasharray\",\"0px,100px\")}function D(e,a,o,u){e.path&&(e.noRotate&&(o=0),n.select(p.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:c(a.x,a.y)+l(180*o/Math.PI)+s(u)}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}v&&D(m,o,h,y),x&&D(d,u,f,g)}},3599:function(t,e,r){\"use strict\";var n=r(3377),i=r(6035);t.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:r(50222),supplyLayoutDefaults:r(63737),includeBasePlot:r(20706)(\"annotations\"),calcAutorange:r(60317),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:r(59741)}},38239:function(t,e,r){\"use strict\";var n=r(50222),i=r(13582).overrideAll,a=r(78032).templatedArray;t.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},47979:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714);function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}t.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},34232:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(59008),o=r(53271),s=r(38239);function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}t.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},9756:function(t,e,r){\"use strict\";var n=r(3377).drawRaw,i=r(25802),a=[\"x\",\"y\",\"z\"];t.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},83348:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809);t.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:r(38239)}}},layoutAttributes:r(38239),handleDefaults:r(34232),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(r)for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:r(47979),draw:r(9756)}},37177:function(t,e,r){\"use strict\";t.exports=r(24453),r(23428),r(1401),r(72210),r(28569),r(81133),r(78295),r(25512),r(42645),r(62324),r(91662),r(66445),r(50506),r(84756),r(41858),r(57985)},29698:function(t,e,r){\"use strict\";var n=r(37177),i=r(34809),a=r(63821),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:i.sortObjectKeys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}},f={};function p(t){var e=f[t];return e||(f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function m(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var g={xcalendar:d(m(\"x\"))},y=i.extendFlat({},g,{ycalendar:d(m(\"y\"))}),v=i.extendFlat({},y,{zcalendar:d(m(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));t.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:y,bar:y,box:y,heatmap:y,contour:y,histogram:y,histogram2d:y,histogram2dcontour:y,scatter3d:v,surface:v,mesh3d:v,scattergl:y,ohlc:g,candlestick:g},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"WARNING: All transforms are deprecated and may be removed from the API in next major version.\",\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"WARNING: All transforms are deprecated and may be removed from the API in next major version.\",\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),m=0;-1!==(m=t.indexOf(\"%\",m));)\"0\"===(n=t.charAt(m+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(m+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,m)+c+t.substr(m+a),m+=c.length):m+=a;return t}}},10229:function(t,e){\"use strict\";e.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],e.defaultLine=\"#444\",e.lightLine=\"#eee\",e.background=\"#fff\",e.borderLine=\"#BEC8D9\",e.lightFraction=1e3/11},78766:function(t,e,r){\"use strict\";var n=r(65657),i=r(10721),a=r(87800).isTypedArray,o=t.exports={},s=r(10229);o.defaults=s.defaults;var l=o.defaultLine=s.defaultLine;o.lightLine=s.lightLine;var c=o.background=s.background;function u(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}o.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},o.rgb=function(t){return o.tinyRGB(n(t))},o.opacity=function(t){return t?n(t).getAlpha():0},o.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},o.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||c).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},o.interpolate=function(t,e,r){var i=n(t).toRgb(),a=n(e).toRgb(),o={r:r*i.r+(1-r)*a.r,g:r*i.g+(1-r)*a.g,b:r*i.b+(1-r)*a.b};return n(o).toRgbString()},o.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(o.combine(t,c))),(i.isDark()?e?i.lighten(e):c:r?i.darken(r):l).toString()},o.stroke=function(t,e){var r=n(e);t.style({stroke:o.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},o.fill=function(t,e){var r=n(e);t.style({fill:o.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},o.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,s=Object.keys(t);for(e=0;e<s.length;e++)if(i=t[n=s[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=u(i[r]);else t[n]=u(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=u(i[r][1]));else if(Array.isArray(i)){var l=i[0];if(!Array.isArray(l)&&l&&\"object\"==typeof l)for(r=0;r<i.length;r++)o.clean(i[r])}else i&&\"object\"==typeof i&&!a(i)&&o.clean(i)}}},25158:function(t,e,r){\"use strict\";var n=r(25829),i=r(80337),a=r(93049).extendFlat,o=r(13582).overrideAll;t.exports=o({orientation:{valType:\"enumerated\",values:[\"h\",\"v\"],dflt:\"v\"},thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\"},xref:{valType:\"enumerated\",dflt:\"paper\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"]},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\"},yref:{valType:\"enumerated\",dflt:\"paper\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"]},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.minor.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklabeloverflow:a({},n.ticklabeloverflow,{}),ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside left\",\"inside left\",\"outside right\",\"inside right\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\"},ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,ticklabelstep:n.ticklabelstep,showticklabels:n.showticklabels,labelalias:n.labelalias,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,minexponent:n.minexponent,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"]}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},34554:function(t){\"use strict\";t.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},42097:function(t,e,r){\"use strict\";var n=r(34809),i=r(78032),a=r(22777),o=r(87433),s=r(12036),l=r(54616),c=r(25158);t.exports=function(t,e,r){var u=i.newContainer(e,\"colorbar\"),h=t.colorbar||{};function f(t,e){return n.coerce(h,u,c,t,e)}var p=r.margin||{t:0,b:0,l:0,r:0},d=r.width-p.l-p.r,m=r.height-p.t-p.b,g=\"v\"===f(\"orientation\"),y=f(\"thicknessmode\");f(\"thickness\",\"fraction\"===y?30/(g?d:m):30);var v=f(\"lenmode\");f(\"len\",\"fraction\"===v?1:g?m:d);var x,_,b,w=\"paper\"===f(\"yref\"),T=\"paper\"===f(\"xref\"),k=\"left\";g?(b=\"middle\",k=T?\"left\":\"right\",x=T?1.02:1,_=.5):(b=w?\"bottom\":\"top\",k=\"center\",x=.5,_=w?1.02:1),n.coerce(h,u,{x:{valType:\"number\",min:T?-2:0,max:T?3:1,dflt:x}},\"x\"),n.coerce(h,u,{y:{valType:\"number\",min:w?-2:0,max:w?3:1,dflt:_}},\"y\"),f(\"xanchor\",k),f(\"xpad\"),f(\"yanchor\",b),f(\"ypad\"),n.noneOrAll(h,u,[\"x\",\"y\"]),f(\"outlinecolor\"),f(\"outlinewidth\"),f(\"bordercolor\"),f(\"borderwidth\"),f(\"bgcolor\");var A=n.coerce(h,u,{ticklabelposition:{valType:\"enumerated\",dflt:\"outside\",values:g?[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"]:[\"outside\",\"inside\",\"outside left\",\"inside left\",\"outside right\",\"inside right\"]}},\"ticklabelposition\");f(\"ticklabeloverflow\",-1!==A.indexOf(\"inside\")?\"hide past domain\":\"hide past div\"),a(h,u,f,\"linear\");var M=r.font,S={noAutotickangles:!0,noTicklabelshift:!0,noTicklabelstandoff:!0,outerTicks:!1,font:M};-1!==A.indexOf(\"inside\")&&(S.bgColor=\"black\"),l(h,u,f,\"linear\",S),s(h,u,f,\"linear\",S),o(h,u,f,\"linear\",S),f(\"title.text\",r._dfltTitle.colorbar);var E=u.showticklabels?u.tickfont:M,C=n.extendFlat({},M,{family:E.family,size:n.bigFont(E.size)});n.coerceFont(f,\"title.font\",C),f(\"title.side\",g?\"top\":\"right\")}},5881:function(t,e,r){\"use strict\";var n=r(45568),i=r(65657),a=r(44122),o=r(33626),s=r(29714),l=r(14751),c=r(34809),u=c.strTranslate,h=r(93049).extendFlat,f=r(27983),p=r(62203),d=r(78766),m=r(17240),g=r(30635),y=r(65477).flipScale,v=r(97655),x=r(40957),_=r(25829),b=r(4530),w=b.LINE_SPACING,T=b.FROM_TL,k=b.FROM_BR,A=r(34554).cn;t.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+A.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return h(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?y(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var u=0;u<o.length;u++){var f=o[u];if((n=f[0].trace)._module){var p=n._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),m=d?p:[p],g=0;g<m.length;g++){var v=(i=m[g]).container;(r=v?n[v]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&v?\"-\"+v:\"\"),e._traceIndex=n.index,e._propPrefix=(v?v+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}}for(var x in a._colorAxes)if((r=a[x]).showscale){var _=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==_[0]&&(n=_[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),(function(t){return t._id}));e.enter().append(\"g\").attr(\"class\",(function(t){return t._id})).classed(A.colorbar,!0),e.each((function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",A.cbbg),c.ensureSingle(r,\"g\",A.cbfills),c.ensureSingle(r,\"g\",A.cblines),c.ensureSingle(r,\"g\",A.cbaxis,(function(t){t.classed(A.crisp,!0)})),c.ensureSingle(r,\"g\",A.cbtitleunshift,(function(t){t.append(\"g\").classed(A.cbtitle,!0)})),c.ensureSingle(r,\"rect\",A.cboutline);var y=function(t,e,r){var o=\"v\"===e.orientation,l=e.len,f=e.lenmode,y=e.thickness,b=e.thicknessmode,M=e.outlinewidth,S=e.borderwidth,E=e.bgcolor,C=e.xanchor,L=e.yanchor,I=e.xpad,P=e.ypad,z=e.x,O=o?e.y:1-e.y,D=\"paper\"===e.yref,R=\"paper\"===e.xref,F=r._fullLayout,B=F._size,N=e._fillcolor,j=e._line,U=e.title,V=U.side,q=e._zrange||n.extent((\"function\"==typeof N?N:j.color).domain()),H=\"function\"==typeof j.color?j.color:function(){return j.color},G=\"function\"==typeof N?N:function(){return N},Z=e._levels,W=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map((function(t){return t-a.size/2}))).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,q),Y=W.fill,X=W.line,$=Math.round(y*(\"fraction\"===b?o?B.w:B.h:1)),J=$/(o?B.w:B.h),K=Math.round(l*(\"fraction\"===f?o?B.h:B.w:1)),Q=K/(o?B.h:B.w),tt=R?B.w:r._fullLayout.width,et=D?B.h:r._fullLayout.height,rt=Math.round(o?z*tt+I:O*et+P),nt={center:.5,right:1}[C]||0,it={top:1,middle:.5}[L]||0,at=o?z-nt*J:O-it*J,ot=o?O-it*Q:z-nt*Q,st=Math.round(o?et*(1-ot):tt*ot);e._lenFrac=Q,e._thickFrac=J,e._uFrac=at,e._vFrac=ot;var lt=e._axis=function(t,e,r){var n=t._fullLayout,i=\"v\"===e.orientation,a={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,labelalias:e.labelalias,ticklabelposition:e.ticklabelposition,ticklabeloverflow:e.ticklabeloverflow,ticklabelstep:e.ticklabelstep,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,minexponent:e.minexponent,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:i?\"right\":\"bottom\",position:1},o=i?\"y\":\"x\",s={type:\"linear\",_id:o+e._id},l={letter:o,font:n.font,noAutotickangles:\"y\"===o,noHover:!0,noTickson:!0,noTicklabelmode:!0,noInsideRange:!0,calendar:n.calendar};function u(t,e){return c.coerce(a,s,_,t,e)}return v(a,s,u,l,n),x(a,s,u,l),s}(r,e,q);lt.position=J+(o?z+I/B.w:O+P/B.h);var ct=-1!==[\"top\",\"bottom\"].indexOf(V);if(o&&ct&&(lt.title.side=V,lt.titlex=z+I/B.w,lt.titley=ot+(\"top\"===U.side?Q-P/B.h:P/B.h)),o||ct||(lt.title.side=V,lt.titley=O+P/B.h,lt.titlex=ot+I/B.w),j.color&&\"auto\"===e.tickmode){lt.tickmode=\"linear\",lt.tick0=Z.start;var ut=Z.size,ht=c.constrain(K/50,4,15)+1,ft=(q[1]-q[0])/((e.nticks||ht)*ut);if(ft>1){var pt=Math.pow(10,Math.floor(Math.log(ft)/Math.LN10));ut*=pt*c.roundUp(ft/pt,[2,5,10]),(Math.abs(Z.start)/Z.size+1e-6)%1<2e-6&&(lt.tick0=0)}lt.dtick=ut}lt.domain=o?[ot+P/B.h,ot+Q-P/B.h]:[ot+I/B.w,ot+Q-I/B.w],lt.setScale(),t.attr(\"transform\",u(Math.round(B.l),Math.round(B.t)));var dt,mt=t.select(\".\"+A.cbtitleunshift).attr(\"transform\",u(-Math.round(B.l),-Math.round(B.t))),gt=lt.ticklabelposition,yt=lt.title.font.size,vt=t.select(\".\"+A.cbaxis),xt=0,_t=0;function bt(n,i){var a={propContainer:lt,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:F._dfltTitle.colorbar,containerGroup:t.select(\".\"+A.cbtitle)},o=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+o+\",.\"+o+\"-math-group\").remove(),m.draw(r,n,h(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){var t,e;(o&&ct||!o&&!ct)&&(\"top\"===V&&(t=I+B.l+tt*z,e=P+B.t+et*(1-ot-Q)+3+.75*yt),\"bottom\"===V&&(t=I+B.l+tt*z,e=P+B.t+et*(1-ot)-3-.25*yt),\"right\"===V&&(e=P+B.t+et*O+3+.75*yt,t=I+B.l+tt*ot),bt(lt._id+\"title\",{attributes:{x:t,y:e,\"text-anchor\":o?\"start\":\"middle\"}}))},function(){if(!o&&!ct||o&&ct){var a,l=t.select(\".\"+A.cbtitle),h=l.select(\"text\"),f=[-M/2,M/2],d=l.select(\".h\"+lt._id+\"title-math-group\").node(),m=15.6;if(h.node()&&(m=parseInt(h.node().style.fontSize,10)*w),d?(a=p.bBox(d),_t=a.width,(xt=a.height)>m&&(f[1]-=(xt-m)/2)):h.node()&&!h.classed(A.jsPlaceholder)&&(a=p.bBox(h.node()),_t=a.width,xt=a.height),o){if(xt){if(xt+=5,\"top\"===V)lt.domain[1]-=xt/B.h,f[1]*=-1;else{lt.domain[0]+=xt/B.h;var y=g.lineCount(h);f[1]+=(1-y)*m}l.attr(\"transform\",u(f[0],f[1])),lt.setScale()}}else _t&&(\"right\"===V&&(lt.domain[0]+=(_t+yt/2)/B.w),l.attr(\"transform\",u(f[0],f[1])),lt.setScale())}t.selectAll(\".\"+A.cbfills+\",.\"+A.cblines).attr(\"transform\",o?u(0,Math.round(B.h*(1-lt.domain[1]))):u(Math.round(B.w*lt.domain[0]),0)),vt.attr(\"transform\",o?u(0,Math.round(-B.t)):u(Math.round(-B.l),0));var v=t.select(\".\"+A.cbfills).selectAll(\"rect.\"+A.cbfill).attr(\"style\",\"\").data(Y);v.enter().append(\"rect\").classed(A.cbfill,!0).attr(\"style\",\"\"),v.exit().remove();var x=q.map(lt.c2p).map(Math.round).sort((function(t,e){return t-e}));v.each((function(t,a){var s=[0===a?q[0]:(Y[a]+Y[a-1])/2,a===Y.length-1?q[1]:(Y[a]+Y[a+1])/2].map(lt.c2p).map(Math.round);o&&(s[1]=c.constrain(s[1]+(s[1]>s[0])?1:-1,x[0],x[1]));var l=n.select(this).attr(o?\"x\":\"y\",rt).attr(o?\"y\":\"x\",n.min(s)).attr(o?\"width\":\"height\",Math.max($,2)).attr(o?\"height\":\"width\",Math.max(n.max(s)-n.min(s),2));if(e._fillgradient)p.gradient(l,r,e._id,o?\"vertical\":\"horizontalreversed\",e._fillgradient,\"fill\");else{var u=G(t).replace(\"e-\",\"\");l.attr(\"fill\",i(u).toHexString())}}));var _=t.select(\".\"+A.cblines).selectAll(\"path.\"+A.cbline).data(j.color&&j.width?X:[]);_.enter().append(\"path\").classed(A.cbline,!0),_.exit().remove(),_.each((function(t){var e=rt,r=Math.round(lt.c2p(t))+j.width/2%1;n.select(this).attr(\"d\",\"M\"+(o?e+\",\"+r:r+\",\"+e)+(o?\"h\":\"v\")+$).call(p.lineGroupStyle,j.width,H(t),j.dash)})),vt.selectAll(\"g.\"+lt._id+\"tick,path\").remove();var b=rt+$+(M||0)/2-(\"outside\"===e.ticks?1:0),T=s.calcTicks(lt),k=s.getTickSigns(lt)[2];return s.drawTicks(r,lt,{vals:\"inside\"===lt.ticks?s.clipEnds(lt,T):T,layer:vt,path:s.makeTickPath(lt,b,k),transFn:s.makeTransTickFn(lt)}),s.drawLabels(r,lt,{vals:T,layer:vt,transFn:s.makeTransTickLabelFn(lt),labelFns:s.makeLabelFns(lt,b)})},function(){if(o&&!ct||!o&&ct){var t,i,a=lt.position||0,s=lt._offset+lt._length/2;if(\"right\"===V)i=s,t=B.l+tt*a+10+yt*(lt.showticklabels?1:.5);else if(t=s,\"bottom\"===V&&(i=B.t+et*a+10+(-1===gt.indexOf(\"inside\")?lt.tickfont.size:0)+(\"intside\"!==lt.ticks&&e.ticklen||0)),\"top\"===V){var l=U.text.split(\"<br>\").length;i=B.t+et*a+10-$-w*yt*l}bt((o?\"h\":\"v\")+lt._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+lt._id+\"tick\"),side:V,offsetTop:o?0:B.t,offsetLeft:o?B.l:0,maxShift:o?F.width:F.height},attributes:{x:t,y:i,\"text-anchor\":\"middle\"},transform:{rotate:o?-90:0,offset:0}})}},a.previousPromises,function(){var n,s=$+M/2;-1===gt.indexOf(\"inside\")&&(n=p.bBox(vt.node()),s+=o?n.width:n.height),dt=mt.select(\"text\");var c=0,h=o&&\"top\"===V,m=!o&&\"right\"===V,g=0;if(dt.node()&&!dt.classed(A.jsPlaceholder)){var v,x=mt.select(\".h\"+lt._id+\"title-math-group\").node();x&&(o&&ct||!o&&!ct)?(c=(n=p.bBox(x)).width,v=n.height):(c=(n=p.bBox(mt.node())).right-B.l-(o?rt:st),v=n.bottom-B.t-(o?st:rt),o||\"top\"!==V||(s+=n.height,g=n.height)),m&&(dt.attr(\"transform\",u(c/2+yt/2,0)),c*=2),s=Math.max(s,o?c:v)}var _=2*(o?I:P)+s+S+M/2,w=0;!o&&U.text&&\"bottom\"===L&&O<=0&&(_+=w=_/2,g+=w),F._hColorbarMoveTitle=w,F._hColorbarMoveCBTitle=g;var N=S+M,j=(o?rt:st)-N/2-(o?I:0),q=(o?st:rt)-(o?K:P+g-w);t.select(\".\"+A.cbbg).attr(\"x\",j).attr(\"y\",q).attr(o?\"width\":\"height\",Math.max(_-w,2)).attr(o?\"height\":\"width\",Math.max(K+N,2)).call(d.fill,E).call(d.stroke,e.bordercolor).style(\"stroke-width\",S);var H=m?Math.max(c-10,0):0;t.selectAll(\".\"+A.cboutline).attr(\"x\",(o?rt:st+I)+H).attr(\"y\",(o?st+P-K:rt)+(h?xt:0)).attr(o?\"width\":\"height\",Math.max($,2)).attr(o?\"height\":\"width\",Math.max(K-(o?2*P+xt:2*I+H),2)).call(d.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":M});var G=o?nt*_:0,Z=o?0:(1-it)*_-g;if(G=R?B.l-G:-G,Z=D?B.t-Z:-Z,t.attr(\"transform\",u(G,Z)),!o&&(S||i(E).getAlpha()&&!i.equals(F.paper_bgcolor,E))){var W=vt.selectAll(\"text\"),Y=W[0].length,X=t.select(\".\"+A.cbbg).node(),J=p.bBox(X),Q=p.getTranslate(t);W.each((function(t,e){var r=Y-1;if(0===e||e===r){var n,i=p.bBox(this),a=p.getTranslate(this);if(e===r){var o=i.right+a.x;(n=J.right+Q.x+st-S-2+z-o)>0&&(n=0)}else if(0===e){var s=i.left+a.x;(n=J.left+Q.x+st+S+2-s)<0&&(n=0)}n&&(Y<3?this.setAttribute(\"transform\",\"translate(\"+n+\",0) \"+this.getAttribute(\"transform\")):this.setAttribute(\"visibility\",\"hidden\"))}}))}var tt={},et=T[C],at=k[C],ot=T[L],ut=k[L],ht=_-$;o?(\"pixels\"===f?(tt.y=O,tt.t=K*ot,tt.b=K*ut):(tt.t=tt.b=0,tt.yt=O+l*ot,tt.yb=O-l*ut),\"pixels\"===b?(tt.x=z,tt.l=_*et,tt.r=_*at):(tt.l=ht*et,tt.r=ht*at,tt.xl=z-y*et,tt.xr=z+y*at)):(\"pixels\"===f?(tt.x=z,tt.l=K*et,tt.r=K*at):(tt.l=tt.r=0,tt.xl=z+l*et,tt.xr=z-l*at),\"pixels\"===b?(tt.y=1-O,tt.t=_*ot,tt.b=_*ut):(tt.t=ht*ot,tt.b=ht*ut,tt.yt=O-y*ot,tt.yb=O+y*ut));var ft=e.y<.5?\"b\":\"t\",pt=e.x<.5?\"l\":\"r\";r._fullLayout._reservedMargin[e._id]={};var _t={r:F.width-j-G,l:j+tt.r,b:F.height-q-Z,t:q+tt.b};R&&D?a.autoMargin(r,e._id,tt):R?r._fullLayout._reservedMargin[e._id][ft]=_t[ft]:D||o?r._fullLayout._reservedMargin[e._id][pt]=_t[pt]:r._fullLayout._reservedMargin[e._id][ft]=_t[ft]}],r)}(r,e,t);y&&y.then&&(t._promises||[]).push(y),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=\"v\"===e.orientation,c=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),f(t)},moveFn:function(r,o){t.attr(\"transform\",n+u(r,o)),i=l.align((s?e._uFrac:e._vFrac)+r/c.w,s?e._thickFrac:e._lenFrac,0,1,e.xanchor),a=l.align((s?e._vFrac:1-e._uFrac)-o/c.h,s?e._lenFrac:e._thickFrac,0,1,e.yanchor);var h=l.getCursor(i,a,e.xanchor,e.yanchor);f(t,h)},doneFn:function(){if(f(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)})),e.exit().each((function(e){a.autoMargin(t,e._id)})).remove(),e.order()}}},91362:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t){return n.isPlainObject(t.colorbar)}},96919:function(t,e,r){\"use strict\";t.exports={moduleType:\"component\",name:\"colorbar\",attributes:r(25158),supplyDefaults:r(42097),draw:r(5881).draw,hasColorbar:r(91362)}},87163:function(t,e,r){\"use strict\";var n=r(25158),i=r(90694).counter,a=r(62994),o=r(19017).scales;function s(t){return\"`\"+t+\"`\"}a(o),t.exports=function(t,e){t=t||\"\";var r,a=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===a,u=\"string\"==typeof e.colorscaleDflt?o[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):s(f+(r={z:\"z\",c:\"color\"}[a]));var p=a+\"auto\",d=a+\"min\",m=a+\"max\",g=a+\"mid\",y=(s(f+p),s(f+d),s(f+m),{});y[d]=y[m]=void 0;var v={};v[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:y},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:v},x[m]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:v},x[g]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:y},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},28379:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(65477).extractOpts;t.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,m=h.mid,g=function(){return i.aggNums(Math.min,null,l)},y=function(){return i.aggNums(Math.max,null,l)};void 0===p?p=g():f&&(p=u._colorAx&&n(p)?Math.min(p,g()):g()),void 0===d?d=y():f&&(d=u._colorAx&&n(d)?Math.max(d,y()):y()),f&&void 0!==m&&(d-m>m-p?p=m-(d-m):d-m<m-p&&(d=m+(m-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},67623:function(t,e,r){\"use strict\";var n=r(34809),i=r(65477).hasColorscale,a=r(65477).extractOpts;t.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},39356:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(91362),o=r(42097),s=r(19017).isValid,l=r(33626).traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}t.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,m=\"_module\"in r,g=c(e,p),y=c(r,p),v=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(m){var _=u._colorAxes||{},b=h(p+\"coloraxis\");if(b){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",T=_[b];return void(T?(T[2].push(x),T[0]!==w&&(T[0]=!1,i.warn([\"Ignoring coloraxis:\",b,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):_[b]=[w,r,[x]])}}var k=g[d+\"min\"],A=g[d+\"max\"],M=n(k)&&n(A)&&k<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=g.colorscale,L=v.colorscale;void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p&&(p&&m&&(E=a(g)),h(p+\"showscale\",E)&&(p&&v&&(y._template=v),o(g,y,u)))}},65477:function(t,e,r){\"use strict\";var n=r(45568),i=r(65657),a=r(10721),o=r(34809),s=r(78766),l=r(19017).isValid,c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)((s=\"c\"+(n=u[r]))in a||(s=\"z\"+n)in a)&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,g=e.returnArray;return(f=d&&g?p:d?function(t){return m(p(t))}:g?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?m(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function m(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}t.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,i=n[r||\"color\"];i&&i._inputArray&&(i=i._inputArray);var s=!1;if(o.isArrayOrTypedArray(i))for(var c=0;c<i.length;c++)if(a(i[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||a(n.cmin)&&a(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},88856:function(t,e,r){\"use strict\";var n=r(19017),i=r(65477);t.exports={moduleType:\"component\",name:\"colorscale\",attributes:r(87163),layoutAttributes:r(56978),supplyLayoutDefaults:r(64613),handleDefaults:r(39356),crossTraceDefaults:r(67623),calc:r(28379),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},56978:function(t,e,r){\"use strict\";var n=r(93049).extendFlat,i=r(87163),a=r(19017).scales;t.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},64613:function(t,e,r){\"use strict\";var n=r(34809),i=r(78032),a=r(56978),o=r(39356);t.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},19017:function(t,e,r){\"use strict\";var n=r(65657),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}t.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},53770:function(t){\"use strict\";t.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},4001:function(t,e,r){\"use strict\";var n=r(34809),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];t.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},70414:function(t,e){\"use strict\";e.selectMode=function(t){return\"lasso\"===t||\"select\"===t},e.drawMode=function(t){return\"drawclosedpath\"===t||\"drawopenpath\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},e.openMode=function(t){return\"drawline\"===t||\"drawopenpath\"===t},e.rectMode=function(t){return\"select\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},e.freeMode=function(t){return\"lasso\"===t||\"drawclosedpath\"===t||\"drawopenpath\"===t},e.selectingOrDrawing=function(t){return e.freeMode(t)||e.rectMode(t)}},14751:function(t,e,r){\"use strict\";var n=r(44039),i=r(39784),a=r(74043),o=r(34809).removeElement,s=r(54826),l=t.exports={};l.align=r(53770),l.getCursor=r(4001);var c=r(60148);function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,m,g=t.gd,y=1,v=g._context.doubleClickDelay,x=t.element;g._mouseDownTime||(g._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=b,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=b,x.addEventListener(\"touchstart\",b,{passive:!1})):x.ontouchstart=b;var _=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function b(a){g._dragged=!1,g._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,m=2===a.buttons||a.ctrlKey,void 0===a.clientX&&void 0===a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-g._mouseDownTime<v?y+=1:(y=1,g._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!m?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",T),document.addEventListener(\"touchend\",T),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w,{passive:!1}))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=_(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(g._dragged=!0,l.unhover(g,n)),g._dragged&&t.moveFn&&!m&&(g._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function T(e){if(delete g._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",T),document.removeEventListener(\"touchend\",T),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),g._dragging){if(g._dragging=!1,(new Date).getTime()-g._mouseDownTime>v&&(y=Math.max(y-1,1)),g._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(y,p),!m){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}g._dragging=!1,g._dragged=!1}else g._dragged=!1}},l.coverSlip=u},60148:function(t,e,r){\"use strict\";var n=r(68596),i=r(64025),a=r(95425).getGraphDiv,o=r(85988),s=t.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!t._dragged&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},94850:function(t,e){\"use strict\";e.T={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"},e.k={shape:{valType:\"enumerated\",values:[\"\",\"/\",\"\\\\\",\"x\",\"-\",\"|\",\"+\",\".\"],dflt:\"\",arrayOk:!0,editType:\"style\"},fillmode:{valType:\"enumerated\",values:[\"replace\",\"overlay\"],dflt:\"replace\",editType:\"style\"},bgcolor:{valType:\"color\",arrayOk:!0,editType:\"style\"},fgcolor:{valType:\"color\",arrayOk:!0,editType:\"style\"},fgopacity:{valType:\"number\",editType:\"style\",min:0,max:1},size:{valType:\"number\",min:0,dflt:8,arrayOk:!0,editType:\"style\"},solidity:{valType:\"number\",min:0,max:1,dflt:.3,arrayOk:!0,editType:\"style\"},editType:\"style\"}},62203:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=i.numberFormat,o=r(10721),s=r(65657),l=r(33626),c=r(78766),u=r(88856),h=i.strTranslate,f=r(30635),p=r(62972),d=r(4530).LINE_SPACING,m=r(20438).DESELECTDIM,g=r(64726),y=r(92527),v=r(36040).appendArrayPointValue,x=t.exports={};function _(t){return\"none\"===t?void 0:t}x.font=function(t,e){var r=e.variant,n=e.style,i=e.weight,a=e.color,o=e.size,s=e.family,l=e.shadow,u=e.lineposition,h=e.textcase;s&&t.style(\"font-family\",s),o+1&&t.style(\"font-size\",o+\"px\"),a&&t.call(c.fill,a),i&&t.style(\"font-weight\",i),n&&t.style(\"font-style\",n),r&&t.style(\"font-variant\",r),h&&t.style(\"text-transform\",_(function(t){return b[t]}(h))),l&&t.style(\"text-shadow\",\"auto\"===l?f.makeTextShadow(c.contrast(a)):_(l)),u&&t.style(\"text-decoration-line\",_(function(t){return t.replace(\"under\",\"underline\").replace(\"over\",\"overline\").replace(\"through\",\"line-through\").split(\"+\").join(\" \")}(u)))};var b={normal:\"none\",lower:\"lowercase\",upper:\"uppercase\",\"word caps\":\"capitalize\"};function w(t,e,r,n){var i=e.fillpattern,a=e.fillgradient,o=i&&x.getPatternAttr(i.shape,0,\"\");if(o){var s=x.getPatternAttr(i.bgcolor,0,null),l=x.getPatternAttr(i.fgcolor,0,null),u=i.fgopacity,h=x.getPatternAttr(i.size,0,8),f=x.getPatternAttr(i.solidity,0,.3),p=e.uid;x.pattern(t,\"point\",r,p,o,h,f,void 0,i.fillmode,s,l,u)}else if(a&&\"none\"!==a.type){var d,m,g=a.type,y=\"scatterfill-\"+e.uid;n&&(y=\"legendfill-\"+e.uid),n||void 0===a.start&&void 0===a.stop?(\"horizontal\"===g&&(g+=\"reversed\"),t.call(x.gradient,r,y,g,a.colorscale,\"fill\")):(\"horizontal\"===g?(d={x:a.start,y:0},m={x:a.stop,y:0}):\"vertical\"===g&&(d={x:0,y:a.start},m={x:0,y:a.stop}),d.x=e._xA.c2p(void 0===d.x?e._extremes.x.min[0].val:d.x,!0),d.y=e._yA.c2p(void 0===d.y?e._extremes.y.min[0].val:d.y,!0),m.x=e._xA.c2p(void 0===m.x?e._extremes.x.max[0].val:m.x,!0),m.y=e._yA.c2p(void 0===m.y?e._extremes.y.max[0].val:m.y,!0),t.call(E,r,y,\"linear\",a.colorscale,\"fill\",d,m,!0,!1))}else e.fillcolor&&t.call(c.fill,e.fillcolor)}x.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},x.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},x.setRect=function(t,e,r,n,i){t.call(x.setPosition,e,r).call(x.setSize,n,i)},x.translatePoint=function(t,e,r,n){var i=r.c2p(t.x),a=n.c2p(t.y);return!!(o(i)&&o(a)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",i).attr(\"y\",a):e.attr(\"transform\",h(i,a)),!0)},x.translatePoints=function(t,e,r){t.each((function(t){var i=n.select(this);x.translatePoint(t,i,e,r)}))},x.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},x.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each((function(e){var a=e[0].trace,o=a.xcalendar,s=a.ycalendar,c=l.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each((function(t){x.hideOutsideRangePoint(t,n.select(this),r,i,o,s)}))}))}},x.crispRound=function(t,e,r){return e&&o(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},x.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,s=i||a.dash||\"\";c.stroke(e,n||a.color),x.dashLine(e,s,o)},x.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each((function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,s=i||a.dash||\"\";n.select(this).call(c.stroke,r||a.color).call(x.dashLine,s,o)}))},x.dashLine=function(t,e,r){r=+r||0,e=x.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},x.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},x.singleFillStyle=function(t,e){var r=n.select(t.node());w(t,((r.data()[0]||[])[0]||{}).trace||{},e,!1)},x.fillGroupStyle=function(t,e,r){t.style(\"stroke-width\",0).each((function(t){var i=n.select(this);t[0].trace&&w(i,t[0].trace,e,r)}))};var T=r(38882);x.symbolNames=[],x.symbolFuncs=[],x.symbolBackOffs=[],x.symbolNeedLines={},x.symbolNoDot={},x.symbolNoFill={},x.symbolList=[],Object.keys(T).forEach((function(t){var e=T[t],r=e.n;x.symbolList.push(r,String(r),t,r+100,String(r+100),t+\"-open\"),x.symbolNames[r]=t,x.symbolFuncs[r]=e.f,x.symbolBackOffs[r]=e.backoff||0,e.needLine&&(x.symbolNeedLines[r]=!0),e.noDot?x.symbolNoDot[r]=!0:x.symbolList.push(r+200,String(r+200),t+\"-dot\",r+300,String(r+300),t+\"-open-dot\"),e.noFill&&(x.symbolNoFill[r]=!0)}));var k=x.symbolNames.length;function A(t,e,r,n){var i=t%100;return x.symbolFuncs[i](e,r,n)+(t>=200?\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\":\"\")}x.symbolNumber=function(t){if(o(t))t=+t;else if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=x.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=k||t>=400?0:Math.floor(Math.max(t,0))};var M=a(\"~f\"),S={radial:{type:\"radial\"},radialreversed:{type:\"radial\",reversed:!0},horizontal:{type:\"linear\",start:{x:1,y:0},stop:{x:0,y:0}},horizontalreversed:{type:\"linear\",start:{x:1,y:0},stop:{x:0,y:0},reversed:!0},vertical:{type:\"linear\",start:{x:0,y:1},stop:{x:0,y:0}},verticalreversed:{type:\"linear\",start:{x:0,y:1},stop:{x:0,y:0},reversed:!0}};function E(t,e,r,a,o,l,u,h,f,p){var d,m=o.length;\"linear\"===a?d={node:\"linearGradient\",attrs:{x1:u.x,y1:u.y,x2:h.x,y2:h.y,gradientUnits:f?\"userSpaceOnUse\":\"objectBoundingBox\"},reversed:p}:\"radial\"===a&&(d={node:\"radialGradient\",reversed:p});for(var g=new Array(m),y=0;y<m;y++)d.reversed?g[m-1-y]=[M(100*(1-o[y][0])),o[y][1]]:g[y]=[M(100*o[y][0]),o[y][1]];var v=e._fullLayout,x=\"g\"+v._uid+\"-\"+r,_=v._defs.select(\".gradients\").selectAll(\"#\"+x).data([a+g.join(\";\")],i.identity);_.exit().remove(),_.enter().append(d.node).each((function(){var t=n.select(this);d.attrs&&t.attr(d.attrs),t.attr(\"id\",x);var e=t.selectAll(\"stop\").data(g);e.exit().remove(),e.enter().append(\"stop\"),e.each((function(t){var e=s(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":c.tinyRGB(e),\"stop-opacity\":e.getAlpha()})}))})),t.style(l,q(x,e)).style(l+\"-opacity\",null),t.classed(\"gradient_filled\",!0)}x.gradient=function(t,e,r,n,i,a){var o=S[n];return E(t,e,r,o.type,i,a,o.start,o.stop,!1,o.reversed)},x.pattern=function(t,e,r,a,o,l,u,h,f,p,d,m){var g=\"legend\"===e;h&&(\"overlay\"===f?(p=h,d=c.contrast(p)):(p=void 0,d=h));var y,v,x,_,b,w,T,k,A,M=r._fullLayout,S=\"p\"+M._uid+\"-\"+a,E={},C=s(d),L=c.tinyRGB(C),I=m*C.getAlpha();switch(o){case\"/\":y=l*Math.sqrt(2),v=l*Math.sqrt(2),w=\"path\",E={d:x=\"M-\"+y/4+\",\"+v/4+\"l\"+y/2+\",-\"+v/2+\"M0,\"+v+\"L\"+y+\",0M\"+y/4*3+\",\"+v/4*5+\"l\"+y/2+\",-\"+v/2,opacity:I,stroke:L,\"stroke-width\":(_=u*l)+\"px\"};break;case\"\\\\\":y=l*Math.sqrt(2),v=l*Math.sqrt(2),w=\"path\",E={d:x=\"M\"+y/4*3+\",-\"+v/4+\"l\"+y/2+\",\"+v/2+\"M0,0L\"+y+\",\"+v+\"M-\"+y/4+\",\"+v/4*3+\"l\"+y/2+\",\"+v/2,opacity:I,stroke:L,\"stroke-width\":(_=u*l)+\"px\"};break;case\"x\":y=l*Math.sqrt(2),v=l*Math.sqrt(2),x=\"M-\"+y/4+\",\"+v/4+\"l\"+y/2+\",-\"+v/2+\"M0,\"+v+\"L\"+y+\",0M\"+y/4*3+\",\"+v/4*5+\"l\"+y/2+\",-\"+v/2+\"M\"+y/4*3+\",-\"+v/4+\"l\"+y/2+\",\"+v/2+\"M0,0L\"+y+\",\"+v+\"M-\"+y/4+\",\"+v/4*3+\"l\"+y/2+\",\"+v/2,_=l-l*Math.sqrt(1-u),w=\"path\",E={d:x,opacity:I,stroke:L,\"stroke-width\":_+\"px\"};break;case\"|\":w=\"path\",w=\"path\",E={d:x=\"M\"+(y=l)/2+\",0L\"+y/2+\",\"+(v=l),opacity:I,stroke:L,\"stroke-width\":(_=u*l)+\"px\"};break;case\"-\":w=\"path\",w=\"path\",E={d:x=\"M0,\"+(v=l)/2+\"L\"+(y=l)+\",\"+v/2,opacity:I,stroke:L,\"stroke-width\":(_=u*l)+\"px\"};break;case\"+\":w=\"path\",x=\"M\"+(y=l)/2+\",0L\"+y/2+\",\"+(v=l)+\"M0,\"+v/2+\"L\"+y+\",\"+v/2,_=l-l*Math.sqrt(1-u),w=\"path\",E={d:x,opacity:I,stroke:L,\"stroke-width\":_+\"px\"};break;case\".\":y=l,v=l,u<Math.PI/4?b=Math.sqrt(u*l*l/Math.PI):(T=u,k=Math.PI/4,1,b=(A=l/2)+(l/Math.sqrt(2)-A)*(T-k)/(1-k)),w=\"circle\",E={cx:y/2,cy:v/2,r:b,opacity:I,fill:L}}var P=[o||\"noSh\",p||\"noBg\",d||\"noFg\",l,u].join(\";\"),z=M._defs.select(\".patterns\").selectAll(\"#\"+S).data([P],i.identity);z.exit().remove(),z.enter().append(\"pattern\").each((function(){var t=n.select(this);if(t.attr({id:S,width:y+\"px\",height:v+\"px\",patternUnits:\"userSpaceOnUse\",patternTransform:g?\"scale(0.8)\":\"\"}),p){var e=s(p),r=c.tinyRGB(e),i=e.getAlpha(),a=t.selectAll(\"rect\").data([0]);a.exit().remove(),a.enter().append(\"rect\").attr({width:y+\"px\",height:v+\"px\",fill:r,\"fill-opacity\":i})}var o=t.selectAll(w).data([0]);o.exit().remove(),o.enter().append(w).attr(E)})),t.style(\"fill\",q(S,r)).style(\"fill-opacity\",null),t.classed(\"pattern_filled\",!0)},x.initGradients=function(t){var e=t._fullLayout;i.ensureSingle(e._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove(),n.select(t).selectAll(\".gradient_filled\").classed(\"gradient_filled\",!1)},x.initPatterns=function(t){var e=t._fullLayout;i.ensureSingle(e._defs,\"g\",\"patterns\").selectAll(\"pattern\").remove(),n.select(t).selectAll(\".pattern_filled\").classed(\"pattern_filled\",!1)},x.getPatternAttr=function(t,e,r){return t&&i.isArrayOrTypedArray(t)?e<t.length?t[e]:r:t},x.pointStyle=function(t,e,r,i){if(t.size()){var a=x.makePointStyleFns(e);t.each((function(t){x.singlePointStyle(t,n.select(this),e,a,r,i)}))}},x.singlePointStyle=function(t,e,r,n,a,o){var s=r.marker,l=s.line;if(o&&o.i>=0&&void 0===t.i&&(t.i=o.i),e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?s.opacity:t.mo),n.ms2mrc){var u;u=\"various\"===t.ms||\"various\"===s.size?3:n.ms2mrc(t.ms),t.mrc=u,n.selectedSizeFn&&(u=t.mrc=n.selectedSizeFn(t));var h=x.symbolNumber(t.mx||s.symbol)||0;t.om=h%200>=100;var f=nt(t,r),p=Z(t,r);e.attr(\"d\",A(h,u,f,p))}var d,m,g,y=!1;if(t.so)g=l.outlierwidth,m=l.outliercolor,d=s.outliercolor;else{var v=(l||{}).width;g=(t.mlw+1||v+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,m=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):i.isArrayOrTypedArray(l.color)?c.defaultLine:l.color,i.isArrayOrTypedArray(s.color)&&(d=c.defaultLine,y=!0),d=\"mc\"in t?t.mcc=n.markerScale(t.mc):s.color||s.colors||\"rgba(0,0,0,0)\",n.selectedColorFn&&(d=n.selectedColorFn(t))}if(t.om)e.call(c.stroke,d).style({\"stroke-width\":(g||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",(t.isBlank?0:g)+\"px\");var _=s.gradient,b=t.mgt;b?y=!0:b=_&&_.type,i.isArrayOrTypedArray(b)&&(b=b[0],S[b]||(b=0));var w=s.pattern,T=w&&x.getPatternAttr(w.shape,t.i,\"\");if(b&&\"none\"!==b){var k=t.mgc;k?y=!0:k=_.color;var M=r.uid;y&&(M+=\"-\"+t.i),x.gradient(e,a,M,b,[[0,k],[1,d]],\"fill\")}else if(T){var E=!1,C=w.fgcolor;!C&&o&&o.color&&(C=o.color,E=!0);var L=x.getPatternAttr(C,t.i,o&&o.color||null),I=x.getPatternAttr(w.bgcolor,t.i,null),P=w.fgopacity,z=x.getPatternAttr(w.size,t.i,8),O=x.getPatternAttr(w.solidity,t.i,.3);E=E||t.mcc||i.isArrayOrTypedArray(w.shape)||i.isArrayOrTypedArray(w.bgcolor)||i.isArrayOrTypedArray(w.fgcolor)||i.isArrayOrTypedArray(w.size)||i.isArrayOrTypedArray(w.solidity);var D=r.uid;E&&(D+=\"-\"+t.i),x.pattern(e,\"point\",a,D,T,z,O,t.mcc,w.fillmode,I,L,P)}else i.isArrayOrTypedArray(d)?c.fill(e,d[t.i]):c.fill(e,d);g&&c.stroke(e,m)}},x.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=x.tryColorscale(r,\"\"),e.lineScale=x.tryColorscale(r,\"line\"),l.traceIs(t,\"symbols\")&&(e.ms2mrc=g.isBubble(t)?y(t):function(){return(r.size||6)/2}),t.selectedpoints&&i.extendFlat(e,x.makeSelectedPointStyleFns(t)),e},x.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},a=t.marker||{},o=r.marker||{},s=n.marker||{},c=a.opacity,u=o.opacity,h=s.opacity,f=void 0!==u,p=void 0!==h;(i.isArrayOrTypedArray(c)||f||p)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?a.opacity:t.mo;return t.selected?f?u:e:p?h:m*e});var d=a.color,g=o.color,y=s.color;(g||y)&&(e.selectedColorFn=function(t){var e=t.mcc||d;return t.selected?g||e:y||e});var v=a.size,x=o.size,_=s.size,b=void 0!==x,w=void 0!==_;return l.traceIs(t,\"symbols\")&&(b||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||v/2;return t.selected?b?x/2:e:w?_/2:e}),e},x.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},s=i.color,l=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||s;return t.selected?l||e:u||(l?e:c.addOpacity(e,m))},e},x.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=x.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push((function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))})),r.selectedColorFn&&a.push((function(t,e){c.fill(t,r.selectedColorFn(e))})),r.selectedSizeFn&&a.push((function(t,n){var a=n.mx||i.symbol||0,o=r.selectedSizeFn(n);t.attr(\"d\",A(x.symbolNumber(a),o,nt(n,e),Z(n,e))),n.mrc2=o})),a.length&&t.each((function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)}))}},x.tryColorscale=function(t,e){var r=e?i.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&i.isArrayOrTypedArray(n))return u.makeColorScaleFuncFromTrace(r)}return i.identity};var C,L,I={start:1,end:-1,middle:0,bottom:1,top:-1};function P(t,e,r,i,a){var o=n.select(t.node().parentNode),s=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",l=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",c=i?i/.8+1:0,u=(f.lineCount(t)-1)*d+1,p=I[l]*c,m=.75*r+I[s]*c+(I[s]-1)*u*r/2;t.attr(\"text-anchor\",l),a||o.attr(\"transform\",h(p,m))}function z(t,e){var r=t.ts||e.textfont.size;return o(r)&&r>0?r:0}function O(t,e,r){return r&&(t=j(t)),e?R(t[1]):D(t[0])}function D(t){var e=n.round(t,2);return C=e,e}function R(t){var e=n.round(t,2);return L=e,e}function F(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=3*c*(l+c),p=3*l*(l+c);return[[D(e[0]+(f&&u/f)),R(e[1]+(f&&h/f))],[D(e[0]-(p&&u/p)),R(e[1]-(p&&h/p))]]}x.textPointStyle=function(t,e,r){if(t.size()){var a;if(e.selectedpoints){var o=x.makeSelectedTextStyleFns(e);a=o.selectedTextColorFn}var s=e.texttemplate,l=r._fullLayout;t.each((function(t){var o=n.select(this),c=s?i.extractOption(t,e,\"txt\",\"texttemplate\"):i.extractOption(t,e,\"tx\",\"text\");if(c||0===c){if(s){var u=e._module.formatLabels,h=u?u(t,e,l):{},p={};v(p,e,t.i);var d=e._meta||{};c=i.texttemplateString(c,h,l._d3locale,p,t,d)}var m=t.tp||e.textposition,g=z(t,e),y=a?a(t):t.tc||e.textfont.color;o.call(x.font,{family:t.tf||e.textfont.family,weight:t.tw||e.textfont.weight,style:t.ty||e.textfont.style,variant:t.tv||e.textfont.variant,textcase:t.tC||e.textfont.textcase,lineposition:t.tE||e.textfont.lineposition,shadow:t.tS||e.textfont.shadow,size:g,color:y}).text(c).call(f.convertToTspans,r).call(P,m,g,t.mrc)}else o.remove()}))}},x.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=x.makeSelectedTextStyleFns(e);t.each((function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,s=z(t,e);c.fill(i,a);var u=l.traceIs(e,\"bar-like\");P(i,o,s,t.mrc2||t.mrc,u)}))}},x.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(F(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},x.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[F(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(F(t[r-1],t[r],t[r+1],e));for(a.push(F(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var B={hv:function(t,e,r){return\"H\"+D(e[0])+\"V\"+O(e,1,r)},vh:function(t,e,r){return\"V\"+R(e[1])+\"H\"+O(e,0,r)},hvh:function(t,e,r){return\"H\"+D((t[0]+e[0])/2)+\"V\"+R(e[1])+\"H\"+O(e,0,r)},vhv:function(t,e,r){return\"V\"+R((t[1]+e[1])/2)+\"H\"+D(e[0])+\"V\"+O(e,1,r)}},N=function(t,e,r){return\"L\"+O(e,0,r)+\",\"+O(e,1,r)};function j(t,e){var r=t.backoff,n=t.trace,a=t.d,o=t.i;if(r&&n&&n.marker&&n.marker.angle%360==0&&n.line&&\"spline\"!==n.line.shape){var s=i.isArrayOrTypedArray(r),l=t,c=e?e[0]:C||0,u=e?e[1]:L||0,h=l[0],f=l[1],p=h-c,d=f-u,m=Math.atan2(d,p),g=s?r[o]:r;if(\"auto\"===g){var y=l.i;\"scatter\"===n.type&&y--;var v=l.marker,_=v.symbol;i.isArrayOrTypedArray(_)&&(_=_[y]);var b=v.size;i.isArrayOrTypedArray(b)&&(b=b[y]),g=v?x.symbolBackOffs[x.symbolNumber(_)]*b:0,g+=x.getMarkerStandoff(a[y],n)||0}var w=h-g*Math.cos(m),T=f-g*Math.sin(m);(w<=h&&w>=c||w>=h&&w<=c)&&(T<=f&&T>=u||T>=f&&T<=u)&&(t=[w,T])}return t}x.steps=function(t){var e=B[t]||N;return function(t){for(var r=\"M\"+D(t[0][0])+\",\"+R(t[0][1]),n=t.length,i=1;i<n;i++)r+=e(t[i-1],t[i],i===n-1);return r}},x.applyBackoff=j,x.makeTester=function(){var t=i.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",(function(t){t.attr(p.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})})),e=i.ensureSingle(t,\"path\",\"js-reference-point\",(function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})}));x.tester=t,x.testref=e},x.savedBBoxes={};var U=0;function V(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function q(t,e){if(!t)return null;var r=e._context,n=r._exportedPlot?\"\":r._baseUrl||\"\";return n?\"url('\"+n+\"#\"+t+\"')\":\"url(#\"+t+\")\"}x.bBox=function(t,e,r){var a,o,s;if(r||(r=V(t)),r){if(a=x.savedBBoxes[r])return i.extendFlat({},a)}else if(1===t.childNodes.length){var l=t.childNodes[0];if(r=V(l)){var c=+l.getAttribute(\"x\")||0,u=+l.getAttribute(\"y\")||0,h=l.getAttribute(\"transform\");if(!h){var p=x.bBox(l,!1,r);return c&&(p.left+=c,p.right+=c),u&&(p.top+=u,p.bottom+=u),p}if(r+=\"~\"+c+\"~\"+u+\"~\"+h,a=x.savedBBoxes[r])return i.extendFlat({},a)}}e?o=t:(s=x.tester.node(),o=t.cloneNode(!0),s.appendChild(o)),n.select(o).attr(\"transform\",null).call(f.positionText,0,0);var d=o.getBoundingClientRect(),m=x.testref.node().getBoundingClientRect();e||s.removeChild(o);var g={height:d.height,width:d.width,left:d.left-m.left,top:d.top-m.top,right:d.right-m.left,bottom:d.bottom-m.top};return U>=1e4&&(x.savedBBoxes={},U=0),r&&(x.savedBBoxes[r]=g),U++,i.extendFlat({},g)},x.setClipUrl=function(t,e,r){t.attr(\"clip-path\",q(e,r))},x.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},x.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=h(e,r)).trim(),t[i](\"transform\",a),a},x.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},x.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\"scale(\"+e+\",\"+r+\")\").trim(),t[i](\"transform\",a),a};var H=/\\s*sc.*/;x.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\"scale(\"+e+\",\"+r+\")\";t.each((function(){var t=(this.getAttribute(\"transform\")||\"\").replace(H,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)}))}};var G=/translate\\([^)]*\\)\\s*$/;function Z(t,e){var r;return t&&(r=t.mf),void 0===r&&(r=e.marker&&e.marker.standoff||0),e._geo||e._xA?r:-r}x.setTextPointsScale=function(t,e,r){t&&t.each((function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(G);t=1===e&&1===r?[]:[h(o,s),\"scale(\"+e+\",\"+r+\")\",h(-o,-s)],l&&t.push(l),i.attr(\"transform\",t.join(\"\"))}}))},x.getMarkerStandoff=Z;var W,Y,X,$,J,K,Q=Math.atan2,tt=Math.cos,et=Math.sin;function rt(t,e){var r=e[0],n=e[1];return[r*tt(t)-n*et(t),r*et(t)+n*tt(t)]}function nt(t,e){var r,n,a=t.ma;void 0===a&&((a=e.marker.angle)&&!i.isArrayOrTypedArray(a)||(a=0));var s=e.marker.angleref;if(\"previous\"===s||\"north\"===s){if(e._geo){var l=e._geo.project(t.lonlat);r=l[0],n=l[1]}else{var c=e._xA,u=e._yA;if(!c||!u)return 90;r=c.c2p(t.x),n=u.c2p(t.y)}if(e._geo){var h,f=t.lonlat[0],p=t.lonlat[1],d=e._geo.project([f,p+1e-5]),m=e._geo.project([f+1e-5,p]),g=Q(m[1]-n,m[0]-r),y=Q(d[1]-n,d[0]-r);if(\"north\"===s)h=a/180*Math.PI;else if(\"previous\"===s){var v=f/180*Math.PI,x=p/180*Math.PI,_=W/180*Math.PI,b=Y/180*Math.PI,w=_-v,T=tt(b)*et(w),k=et(b)*tt(x)-tt(b)*et(x)*tt(w);h=-Q(T,k)-Math.PI,W=f,Y=p}var A=rt(g,[tt(h),0]),M=rt(y,[et(h),0]);a=Q(A[1]+M[1],A[0]+M[0])/Math.PI*180,\"previous\"!==s||K===e.uid&&t.i===J+1||(a=null)}if(\"previous\"===s&&!e._geo)if(K===e.uid&&t.i===J+1&&o(r)&&o(n)){var S=r-X,E=n-$,C=e.line&&e.line.shape||\"\",L=C.slice(C.length-1);\"h\"===L&&(E=0),\"v\"===L&&(S=0),a+=Q(E,S)/Math.PI*180+90}else a=null}return X=r,$=n,J=t.i,K=e.uid,a}x.getMarkerAngle=nt},38882:function(t,e,r){\"use strict\";var n,i,a,o,s=r(26953),l=r(45568).round,c=\"M0,0Z\",u=Math.sqrt(2),h=Math.sqrt(3),f=Math.PI,p=Math.cos,d=Math.sin;function m(t){return null===t}function g(t,e,r){if(!(t&&t%360!=0||e))return r;if(a===t&&o===e&&n===r)return i;function l(t,r){var n=p(t),i=d(t),a=r[0],o=r[1]+(e||0);return[a*n-o*i,a*i+o*n]}a=t,o=e,n=r;for(var c=t/180*f,u=0,h=0,m=s(r),g=\"\",y=0;y<m.length;y++){var v=m[y],x=v[0],_=u,b=h;if(\"M\"===x||\"L\"===x)u=+v[1],h=+v[2];else if(\"m\"===x||\"l\"===x)u+=+v[1],h+=+v[2];else if(\"H\"===x)u=+v[1];else if(\"h\"===x)u+=+v[1];else if(\"V\"===x)h=+v[1];else if(\"v\"===x)h+=+v[1];else if(\"A\"===x){u=+v[1],h=+v[2];var w=l(c,[+v[6],+v[7]]);v[6]=w[0],v[7]=w[1],v[3]=+v[3]+t}\"H\"!==x&&\"V\"!==x||(x=\"L\"),\"h\"!==x&&\"v\"!==x||(x=\"l\"),\"m\"!==x&&\"l\"!==x||(u-=_,h-=b);var T=l(c,[u,h]);\"H\"!==x&&\"V\"!==x||(x=\"L\"),\"M\"!==x&&\"L\"!==x&&\"m\"!==x&&\"l\"!==x||(v[1]=T[0],v[2]=T[1]),v[0]=x,g+=v[0]+v.slice(1).join(\",\")}return i=g,g}t.exports={circle:{n:0,f:function(t,e,r){if(m(e))return c;var n=l(t,2),i=\"M\"+n+\",0A\"+n+\",\"+n+\" 0 1,1 0,-\"+n+\"A\"+n+\",\"+n+\" 0 0,1 \"+n+\",0Z\";return r?g(e,r,i):i}},square:{n:1,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M\"+n+\",\"+n+\"H-\"+n+\"V-\"+n+\"H\"+n+\"Z\")}},diamond:{n:2,f:function(t,e,r){if(m(e))return c;var n=l(1.3*t,2);return g(e,r,\"M\"+n+\",0L0,\"+n+\"L-\"+n+\",0L0,-\"+n+\"Z\")}},cross:{n:3,f:function(t,e,r){if(m(e))return c;var n=l(.4*t,2),i=l(1.2*t,2);return g(e,r,\"M\"+i+\",\"+n+\"H\"+n+\"V\"+i+\"H-\"+n+\"V\"+n+\"H-\"+i+\"V-\"+n+\"H-\"+n+\"V-\"+i+\"H\"+n+\"V-\"+n+\"H\"+i+\"Z\")}},x:{n:4,f:function(t,e,r){if(m(e))return c;var n=l(.8*t/u,2),i=\"l\"+n+\",\"+n,a=\"l\"+n+\",-\"+n,o=\"l-\"+n+\",-\"+n,s=\"l-\"+n+\",\"+n;return g(e,r,\"M0,\"+n+i+a+o+a+o+s+o+s+i+s+i+\"Z\")}},\"triangle-up\":{n:5,f:function(t,e,r){if(m(e))return c;var n=l(2*t/h,2);return g(e,r,\"M-\"+n+\",\"+l(t/2,2)+\"H\"+n+\"L0,-\"+l(t,2)+\"Z\")}},\"triangle-down\":{n:6,f:function(t,e,r){if(m(e))return c;var n=l(2*t/h,2);return g(e,r,\"M-\"+n+\",-\"+l(t/2,2)+\"H\"+n+\"L0,\"+l(t,2)+\"Z\")}},\"triangle-left\":{n:7,f:function(t,e,r){if(m(e))return c;var n=l(2*t/h,2);return g(e,r,\"M\"+l(t/2,2)+\",-\"+n+\"V\"+n+\"L-\"+l(t,2)+\",0Z\")}},\"triangle-right\":{n:8,f:function(t,e,r){if(m(e))return c;var n=l(2*t/h,2);return g(e,r,\"M-\"+l(t/2,2)+\",-\"+n+\"V\"+n+\"L\"+l(t,2)+\",0Z\")}},\"triangle-ne\":{n:9,f:function(t,e,r){if(m(e))return c;var n=l(.6*t,2),i=l(1.2*t,2);return g(e,r,\"M-\"+i+\",-\"+n+\"H\"+n+\"V\"+i+\"Z\")}},\"triangle-se\":{n:10,f:function(t,e,r){if(m(e))return c;var n=l(.6*t,2),i=l(1.2*t,2);return g(e,r,\"M\"+n+\",-\"+i+\"V\"+n+\"H-\"+i+\"Z\")}},\"triangle-sw\":{n:11,f:function(t,e,r){if(m(e))return c;var n=l(.6*t,2),i=l(1.2*t,2);return g(e,r,\"M\"+i+\",\"+n+\"H-\"+n+\"V-\"+i+\"Z\")}},\"triangle-nw\":{n:12,f:function(t,e,r){if(m(e))return c;var n=l(.6*t,2),i=l(1.2*t,2);return g(e,r,\"M-\"+n+\",\"+i+\"V-\"+n+\"H\"+i+\"Z\")}},pentagon:{n:13,f:function(t,e,r){if(m(e))return c;var n=l(.951*t,2),i=l(.588*t,2),a=l(-t,2),o=l(-.309*t,2);return g(e,r,\"M\"+n+\",\"+o+\"L\"+i+\",\"+l(.809*t,2)+\"H-\"+i+\"L-\"+n+\",\"+o+\"L0,\"+a+\"Z\")}},hexagon:{n:14,f:function(t,e,r){if(m(e))return c;var n=l(t,2),i=l(t/2,2),a=l(t*h/2,2);return g(e,r,\"M\"+a+\",-\"+i+\"V\"+i+\"L0,\"+n+\"L-\"+a+\",\"+i+\"V-\"+i+\"L0,-\"+n+\"Z\")}},hexagon2:{n:15,f:function(t,e,r){if(m(e))return c;var n=l(t,2),i=l(t/2,2),a=l(t*h/2,2);return g(e,r,\"M-\"+i+\",\"+a+\"H\"+i+\"L\"+n+\",0L\"+i+\",-\"+a+\"H-\"+i+\"L-\"+n+\",0Z\")}},octagon:{n:16,f:function(t,e,r){if(m(e))return c;var n=l(.924*t,2),i=l(.383*t,2);return g(e,r,\"M-\"+i+\",-\"+n+\"H\"+i+\"L\"+n+\",-\"+i+\"V\"+i+\"L\"+i+\",\"+n+\"H-\"+i+\"L-\"+n+\",\"+i+\"V-\"+i+\"Z\")}},star:{n:17,f:function(t,e,r){if(m(e))return c;var n=1.4*t,i=l(.225*n,2),a=l(.951*n,2),o=l(.363*n,2),s=l(.588*n,2),u=l(-n,2),h=l(-.309*n,2),f=l(.118*n,2),p=l(.809*n,2);return g(e,r,\"M\"+i+\",\"+h+\"H\"+a+\"L\"+o+\",\"+f+\"L\"+s+\",\"+p+\"L0,\"+l(.382*n,2)+\"L-\"+s+\",\"+p+\"L-\"+o+\",\"+f+\"L-\"+a+\",\"+h+\"H-\"+i+\"L0,\"+u+\"Z\")}},hexagram:{n:18,f:function(t,e,r){if(m(e))return c;var n=l(.66*t,2),i=l(.38*t,2),a=l(.76*t,2);return g(e,r,\"M-\"+a+\",0l-\"+i+\",-\"+n+\"h\"+a+\"l\"+i+\",-\"+n+\"l\"+i+\",\"+n+\"h\"+a+\"l-\"+i+\",\"+n+\"l\"+i+\",\"+n+\"h-\"+a+\"l-\"+i+\",\"+n+\"l-\"+i+\",-\"+n+\"h-\"+a+\"Z\")}},\"star-triangle-up\":{n:19,f:function(t,e,r){if(m(e))return c;var n=l(t*h*.8,2),i=l(.8*t,2),a=l(1.6*t,2),o=l(4*t,2),s=\"A \"+o+\",\"+o+\" 0 0 1 \";return g(e,r,\"M-\"+n+\",\"+i+s+n+\",\"+i+s+\"0,-\"+a+s+\"-\"+n+\",\"+i+\"Z\")}},\"star-triangle-down\":{n:20,f:function(t,e,r){if(m(e))return c;var n=l(t*h*.8,2),i=l(.8*t,2),a=l(1.6*t,2),o=l(4*t,2),s=\"A \"+o+\",\"+o+\" 0 0 1 \";return g(e,r,\"M\"+n+\",-\"+i+s+\"-\"+n+\",-\"+i+s+\"0,\"+a+s+n+\",-\"+i+\"Z\")}},\"star-square\":{n:21,f:function(t,e,r){if(m(e))return c;var n=l(1.1*t,2),i=l(2*t,2),a=\"A \"+i+\",\"+i+\" 0 0 1 \";return g(e,r,\"M-\"+n+\",-\"+n+a+\"-\"+n+\",\"+n+a+n+\",\"+n+a+n+\",-\"+n+a+\"-\"+n+\",-\"+n+\"Z\")}},\"star-diamond\":{n:22,f:function(t,e,r){if(m(e))return c;var n=l(1.4*t,2),i=l(1.9*t,2),a=\"A \"+i+\",\"+i+\" 0 0 1 \";return g(e,r,\"M-\"+n+\",0\"+a+\"0,\"+n+a+n+\",0\"+a+\"0,-\"+n+a+\"-\"+n+\",0Z\")}},\"diamond-tall\":{n:23,f:function(t,e,r){if(m(e))return c;var n=l(.7*t,2),i=l(1.4*t,2);return g(e,r,\"M0,\"+i+\"L\"+n+\",0L0,-\"+i+\"L-\"+n+\",0Z\")}},\"diamond-wide\":{n:24,f:function(t,e,r){if(m(e))return c;var n=l(1.4*t,2),i=l(.7*t,2);return g(e,r,\"M0,\"+i+\"L\"+n+\",0L0,-\"+i+\"L-\"+n+\",0Z\")}},hourglass:{n:25,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M\"+n+\",\"+n+\"H-\"+n+\"L\"+n+\",-\"+n+\"H-\"+n+\"Z\")},noDot:!0},bowtie:{n:26,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M\"+n+\",\"+n+\"V-\"+n+\"L-\"+n+\",\"+n+\"V-\"+n+\"Z\")},noDot:!0},\"circle-cross\":{n:27,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M0,\"+n+\"V-\"+n+\"M\"+n+\",0H-\"+n+\"M\"+n+\",0A\"+n+\",\"+n+\" 0 1,1 0,-\"+n+\"A\"+n+\",\"+n+\" 0 0,1 \"+n+\",0Z\")},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t,e,r){if(m(e))return c;var n=l(t,2),i=l(t/u,2);return g(e,r,\"M\"+i+\",\"+i+\"L-\"+i+\",-\"+i+\"M\"+i+\",-\"+i+\"L-\"+i+\",\"+i+\"M\"+n+\",0A\"+n+\",\"+n+\" 0 1,1 0,-\"+n+\"A\"+n+\",\"+n+\" 0 0,1 \"+n+\",0Z\")},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M0,\"+n+\"V-\"+n+\"M\"+n+\",0H-\"+n+\"M\"+n+\",\"+n+\"H-\"+n+\"V-\"+n+\"H\"+n+\"Z\")},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M\"+n+\",\"+n+\"L-\"+n+\",-\"+n+\"M\"+n+\",-\"+n+\"L-\"+n+\",\"+n+\"M\"+n+\",\"+n+\"H-\"+n+\"V-\"+n+\"H\"+n+\"Z\")},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t,e,r){if(m(e))return c;var n=l(1.3*t,2);return g(e,r,\"M\"+n+\",0L0,\"+n+\"L-\"+n+\",0L0,-\"+n+\"ZM0,-\"+n+\"V\"+n+\"M-\"+n+\",0H\"+n)},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t,e,r){if(m(e))return c;var n=l(1.3*t,2),i=l(.65*t,2);return g(e,r,\"M\"+n+\",0L0,\"+n+\"L-\"+n+\",0L0,-\"+n+\"ZM-\"+i+\",-\"+i+\"L\"+i+\",\"+i+\"M-\"+i+\",\"+i+\"L\"+i+\",-\"+i)},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t,e,r){if(m(e))return c;var n=l(1.4*t,2);return g(e,r,\"M0,\"+n+\"V-\"+n+\"M\"+n+\",0H-\"+n)},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M\"+n+\",\"+n+\"L-\"+n+\",-\"+n+\"M\"+n+\",-\"+n+\"L-\"+n+\",\"+n)},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t,e,r){if(m(e))return c;var n=l(1.2*t,2),i=l(.85*t,2);return g(e,r,\"M0,\"+n+\"V-\"+n+\"M\"+n+\",0H-\"+n+\"M\"+i+\",\"+i+\"L-\"+i+\",-\"+i+\"M\"+i+\",-\"+i+\"L-\"+i+\",\"+i)},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t,e,r){if(m(e))return c;var n=l(t/2,2),i=l(t,2);return g(e,r,\"M\"+n+\",\"+i+\"V-\"+i+\"M\"+(n-i)+\",-\"+i+\"V\"+i+\"M\"+i+\",\"+n+\"H-\"+i+\"M-\"+i+\",\"+(n-i)+\"H\"+i)},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t,e,r){if(m(e))return c;var n=l(1.2*t,2),i=l(1.6*t,2),a=l(.8*t,2);return g(e,r,\"M-\"+n+\",\"+a+\"L0,0M\"+n+\",\"+a+\"L0,0M0,-\"+i+\"L0,0\")},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t,e,r){if(m(e))return c;var n=l(1.2*t,2),i=l(1.6*t,2),a=l(.8*t,2);return g(e,r,\"M-\"+n+\",-\"+a+\"L0,0M\"+n+\",-\"+a+\"L0,0M0,\"+i+\"L0,0\")},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t,e,r){if(m(e))return c;var n=l(1.2*t,2),i=l(1.6*t,2),a=l(.8*t,2);return g(e,r,\"M\"+a+\",\"+n+\"L0,0M\"+a+\",-\"+n+\"L0,0M-\"+i+\",0L0,0\")},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t,e,r){if(m(e))return c;var n=l(1.2*t,2),i=l(1.6*t,2),a=l(.8*t,2);return g(e,r,\"M-\"+a+\",\"+n+\"L0,0M-\"+a+\",-\"+n+\"L0,0M\"+i+\",0L0,0\")},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t,e,r){if(m(e))return c;var n=l(1.4*t,2);return g(e,r,\"M\"+n+\",0H-\"+n)},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t,e,r){if(m(e))return c;var n=l(1.4*t,2);return g(e,r,\"M0,\"+n+\"V-\"+n)},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M\"+n+\",-\"+n+\"L-\"+n+\",\"+n)},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M\"+n+\",\"+n+\"L-\"+n+\",-\"+n)},needLine:!0,noDot:!0,noFill:!0},\"arrow-up\":{n:45,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M0,0L-\"+n+\",\"+l(2*t,2)+\"H\"+n+\"Z\")},backoff:1,noDot:!0},\"arrow-down\":{n:46,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M0,0L-\"+n+\",-\"+l(2*t,2)+\"H\"+n+\"Z\")},noDot:!0},\"arrow-left\":{n:47,f:function(t,e,r){if(m(e))return c;var n=l(2*t,2),i=l(t,2);return g(e,r,\"M0,0L\"+n+\",-\"+i+\"V\"+i+\"Z\")},noDot:!0},\"arrow-right\":{n:48,f:function(t,e,r){if(m(e))return c;var n=l(2*t,2),i=l(t,2);return g(e,r,\"M0,0L-\"+n+\",-\"+i+\"V\"+i+\"Z\")},noDot:!0},\"arrow-bar-up\":{n:49,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M-\"+n+\",0H\"+n+\"M0,0L-\"+n+\",\"+l(2*t,2)+\"H\"+n+\"Z\")},backoff:1,needLine:!0,noDot:!0},\"arrow-bar-down\":{n:50,f:function(t,e,r){if(m(e))return c;var n=l(t,2);return g(e,r,\"M-\"+n+\",0H\"+n+\"M0,0L-\"+n+\",-\"+l(2*t,2)+\"H\"+n+\"Z\")},needLine:!0,noDot:!0},\"arrow-bar-left\":{n:51,f:function(t,e,r){if(m(e))return c;var n=l(2*t,2),i=l(t,2);return g(e,r,\"M0,-\"+i+\"V\"+i+\"M0,0L\"+n+\",-\"+i+\"V\"+i+\"Z\")},needLine:!0,noDot:!0},\"arrow-bar-right\":{n:52,f:function(t,e,r){if(m(e))return c;var n=l(2*t,2),i=l(t,2);return g(e,r,\"M0,-\"+i+\"V\"+i+\"M0,0L-\"+n+\",-\"+i+\"V\"+i+\"Z\")},needLine:!0,noDot:!0},arrow:{n:53,f:function(t,e,r){if(m(e))return c;var n=f/2.5,i=2*t*p(n),a=2*t*d(n);return g(e,r,\"M0,0L\"+-i+\",\"+a+\"L\"+i+\",\"+a+\"Z\")},backoff:.9,noDot:!0},\"arrow-wide\":{n:54,f:function(t,e,r){if(m(e))return c;var n=f/4,i=2*t*p(n),a=2*t*d(n);return g(e,r,\"M0,0L\"+-i+\",\"+a+\"A \"+2*t+\",\"+2*t+\" 0 0 1 \"+i+\",\"+a+\"Z\")},backoff:.4,noDot:!0}}},75568:function(t){\"use strict\";t.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},352:function(t,e,r){\"use strict\";var n=r(10721),i=r(33626),a=r(29714),o=r(34809),s=r(25589);function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var m=u(d,p);if(n(m[0])&&n(m[1])){var g=f[i+\"s\"]=d-m[0],y=f[i+\"h\"]=d+m[1];c.push(g,y)}}}var v=r._id,x=e._extremes[v],_=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(_.min),x.max=x.max.concat(_.max)}}t.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},25589:function(t){\"use strict\";function e(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}t.exports=function(t){var r=t.type,n=t.symmetric;if(\"data\"===r){var i=t.array||[];if(n)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=e(r,t.value),s=e(r,t.valueminus);return n||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},5543:function(t,e,r){\"use strict\";var n=r(10721),i=r(33626),a=r(34809),o=r(78032),s=r(75568);t.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var m=\"copy_\"+l.inherit+\"style\";l.inherit&&(e[\"error_\"+l.inherit]||{}).visible&&f(m,!(h.color||n(h.thickness)||n(h.width))),l.inherit&&u[m]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},77901:function(t,e,r){\"use strict\";var n=r(34809),i=r(13582).overrideAll,a=r(75568),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,t.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:r(5543),calc:r(352),makeComputeError:r(25589),plot:r(42130),style:r(22800),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys)),(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},42130:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(62203),o=r(64726);t.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0,h=t._context.staticPlot;e.each((function(e){var f,p=e[0].trace,d=p.error_x||{},m=p.error_y||{};p.ids&&(f=function(t){return t.id});var g=o.hasMarkers(p)&&p.marker.maxdisplayed>0;m.visible||d.visible||(e=[]);var y=n.select(this).selectAll(\"g.errorbar\").data(e,f);if(y.exit().remove(),e.length){d.visible||y.selectAll(\"path.xerror\").remove(),m.visible||y.selectAll(\"path.yerror\").remove(),y.style(\"opacity\",1);var v=y.enter().append(\"g\").classed(\"errorbar\",!0);u&&v.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(y,r.layerClipId,t),y.each((function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};return void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0))),void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0))),n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(m.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var f=m.width;a=\"M\"+(r.x-f)+\",\"+r.yh+\"h\"+2*f+\"m-\"+f+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+f+\",0h\"+2*f),o.size()?u&&(o=o.transition().duration(s.duration).ease(s.easing)):o=e.append(\"path\").style(\"vector-effect\",h?\"none\":\"non-scaling-stroke\").classed(\"yerror\",!0),o.attr(\"d\",a)}else o.remove();var p=e.select(\"path.xerror\");if(d.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var y=(d.copy_ystyle?m:d).width;a=\"M\"+r.xh+\",\"+(r.y-y)+\"v\"+2*y+\"m0,-\"+y+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+y+\"v\"+2*y),p.size()?u&&(p=p.transition().duration(s.duration).ease(s.easing)):p=e.append(\"path\").style(\"vector-effect\",h?\"none\":\"non-scaling-stroke\").classed(\"xerror\",!0),p.attr(\"d\",a)}else p.remove()}}))}}))}},22800:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766);t.exports=function(t){t.each((function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)}))}},70192:function(t,e,r){\"use strict\";var n=r(80337),i=r(6811).hoverlabel,a=r(93049).extendFlat;t.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},83552:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626);function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}t.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.font.weight,l,\"htw\"),u(c.hoverlabel.font.style,l,\"hty\"),u(c.hoverlabel.font.variant,l,\"htv\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},94225:function(t,e,r){\"use strict\";var n=r(33626),i=r(38103).hover;t.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},85988:function(t){\"use strict\";t.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},3239:function(t,e,r){\"use strict\";var n=r(34809),i=r(70192),a=r(26430);t.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,(function(r,a){return n.coerce(t,e,i,r,a)}),s)}},36040:function(t,e,r){\"use strict\";var n=r(34809);e.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},e.isTraceInSubplots=function(t,r){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==r.indexOf(n[a]+i[o]))return!0;return!1}return-1!==r.indexOf(e.getSubplot(t))},e.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},e.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},e.getDistanceFunction=function(t,r,n,i){return\"closest\"===t?i||e.quadrature(r,n):\"x\"===t.charAt(0)?r:n},e.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},e.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},e.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},e.makeEventData=function(t,r,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:r._input,fullData:r,curveNumber:r.index,pointNumber:i};if(r._indexToPoints){var o=r._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return r._module.eventData?a=r._module.eventData(a,t,r,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),e.appendArrayPointValue(a,r,i),a},e.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},e.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={\"x unified\":!0,\"y unified\":!0};e.isUnifiedHover=function(t){return\"string\"==typeof t&&!!l[t]},e.isXYhover=function(t){return\"string\"==typeof t&&!!s[t]}},38103:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(65657),o=r(34809),s=o.pushUnique,l=o.strTranslate,c=o.strRotate,u=r(68596),h=r(30635),f=r(93134),p=r(62203),d=r(78766),m=r(14751),g=r(29714),y=r(54826).zindexSeparator,v=r(33626),x=r(36040),_=r(85988),b=r(73970),w=r(6134),T=_.YANGLE,k=Math.PI*T/180,A=1/Math.sin(k),M=Math.cos(k),S=Math.sin(k),E=_.HOVERARROWSIZE,C=_.HOVERTEXTPAD,L={box:!0,ohlc:!0,violin:!0,candlestick:!0},I={scatter:!0,scattergl:!0,splom:!0};function P(t,e){return t.distance-e.distance}function z(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa?t.xa._id:\"\",t.ya?t.ya._id:\"\"].join(\",\")}e.hover=function(t,e,r,a){t=o.getGraphDiv(t);var l=e.target;o.throttle(t._fullLayout._uid+_.HOVERID,_.HOVERMINTIME,(function(){!function(t,e,r,a,l){r||(r=\"xy\"),\"string\"==typeof r&&(r=r.split(y)[0]);var c,h,p,_=Array.isArray(r)?r:[r],b=t._fullLayout,w=b.hoversubplots,T=b._plots||[],k=T[r],M=b._has(\"cartesian\"),S=e.hovermode||b.hovermode,C=\"x\"===(S||\"\").charAt(0),O=\"y\"===(S||\"\").charAt(0);if(M&&(C||O)&&\"axis\"===w)for(var R=_.length,V=0;V<R;V++)if(T[c=_[V]]){h=g.getFromId(t,c,\"x\"),p=g.getFromId(t,c,\"y\");var Z=(C?h:p)._subplotsWith;if(Z&&Z.length)for(var W=0;W<Z.length;W++)s(_,Z[W])}if(k&&\"single\"!==w){var Y=k.overlays.map((function(t){return t.id}));_=_.concat(Y)}for(var X=_.length,$=new Array(X),J=new Array(X),K=!1,Q=0;Q<X;Q++)if(T[c=_[Q]])K=!0,$[Q]=T[c].xaxis,J[Q]=T[c].yaxis;else{if(!b[c]||!b[c]._subplot)return void o.warn(\"Unrecognized subplot: \"+c);var tt=b[c]._subplot;$[Q]=tt.xaxis,J[Q]=tt.yaxis}if(S&&!K&&(S=\"closest\"),-1===[\"x\",\"y\",\"closest\",\"x unified\",\"y unified\"].indexOf(S)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return m.unhoverRaw(t,e);var et=b.hoverdistance;-1===et&&(et=1/0);var rt=b.spikedistance;-1===rt&&(rt=1/0);var nt,it,at,ot,st,lt,ct,ut,ht,ft,pt,dt,mt,gt=[],yt=[],vt={hLinePoint:null,vLinePoint:null},xt=!1;if(Array.isArray(e))for(S=\"array\",at=0;at<e.length;at++)(st=t.calcdata[e[at].curveNumber||0])&&(lt=st[0].trace,\"skip\"!==st[0].trace.hoverinfo&&(yt.push(st),\"h\"===lt.orientation&&(xt=!0)));else{var _t,bt,wt=t.calcdata.slice();for(wt.sort((function(t,e){return(t[0].trace.zorder||0)-(e[0].trace.zorder||0)})),ot=0;ot<wt.length;ot++)st=wt[ot],\"skip\"!==(lt=st[0].trace).hoverinfo&&x.isTraceInSubplots(lt,_)&&(yt.push(st),\"h\"===lt.orientation&&(xt=!0));if(l){if(!1===u.triggerHandler(t,\"plotly_beforehover\",e))return;var Tt=l.getBoundingClientRect();_t=e.clientX-Tt.left,bt=e.clientY-Tt.top,b._calcInverseTransform(t);var kt=o.apply3DTransform(b._invTransform)(_t,bt);if(_t=kt[0],bt=kt[1],_t<0||_t>$[0]._length||bt<0||bt>J[0]._length)return m.unhoverRaw(t,e)}else _t=\"xpx\"in e?e.xpx:$[0]._length/2,bt=\"ypx\"in e?e.ypx:J[0]._length/2;if(e.pointerX=_t+$[0]._offset,e.pointerY=bt+J[0]._offset,nt=\"xval\"in e?x.flat(_,e.xval):x.p2c($,_t),it=\"yval\"in e?x.flat(_,e.yval):x.p2c(J,bt),!i(nt[0])||!i(it[0]))return o.warn(\"Fx.hover failed\",e,t),m.unhoverRaw(t,e)}var At=1/0;function Mt(r,n){for(ot=0;ot<yt.length;ot++)if((st=yt[ot])&&st[0]&&st[0].trace&&!0===(lt=st[0].trace).visible&&0!==lt._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(lt._module.name)){if(ht=S,x.isUnifiedHover(ht)&&(ht=ht.charAt(0)),\"splom\"===lt.type?ct=_[ut=0]:(ct=x.getSubplot(lt),ut=_.indexOf(ct)),dt={cd:st,trace:lt,xa:$[ut],ya:J[ut],maxHoverDistance:et,maxSpikeDistance:rt,index:!1,distance:Math.min(At,et),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:d.defaultLine,name:lt.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},b[ct]&&(dt.subplot=b[ct]._subplot),b._splomScenes&&b._splomScenes[lt.uid]&&(dt.scene=b._splomScenes[lt.uid]),\"array\"===ht){var a=e[ot];\"pointNumber\"in a?(dt.index=a.pointNumber,ht=\"closest\"):(ht=\"\",\"xval\"in a&&(ft=a.xval,ht=\"x\"),\"yval\"in a&&(pt=a.yval,ht=ht?\"closest\":\"y\"))}else void 0!==r&&void 0!==n?(ft=r,pt=n):(ft=nt[ut],pt=it[ut]);if(mt=gt.length,0!==et)if(lt._module&&lt._module.hoverPoints){var s=lt._module.hoverPoints(dt,ft,pt,ht,{finiteRange:!0,hoverLayer:b._hoverlayer,hoversubplots:w,gd:t});if(s)for(var l,c=0;c<s.length;c++)l=s[c],i(l.x0)&&i(l.y0)&&gt.push(N(l,S))}else o.log(\"Unrecognized trace type in hover:\",lt);if(\"closest\"===S&&gt.length>mt&&(gt.splice(0,mt),At=gt[0].distance),M&&0!==rt&&0===gt.length){dt.distance=rt,dt.index=!1;var u=lt._module.hoverPoints(dt,ft,pt,\"closest\",{hoverLayer:b._hoverlayer});if(u&&(u=u.filter((function(t){return t.spikeDistance<=rt}))),u&&u.length){var h,f=u.filter((function(t){return t.xa.showspikes&&\"hovered data\"!==t.xa.spikesnap}));if(f.length){var p=f[0];i(p.x0)&&i(p.y0)&&(h=Et(p),(!vt.vLinePoint||vt.vLinePoint.spikeDistance>h.spikeDistance)&&(vt.vLinePoint=h))}var m=u.filter((function(t){return t.ya.showspikes&&\"hovered data\"!==t.ya.spikesnap}));if(m.length){var g=m[0];i(g.x0)&&i(g.y0)&&(h=Et(g),(!vt.hLinePoint||vt.hLinePoint.spikeDistance>h.spikeDistance)&&(vt.hLinePoint=h))}}}}}function St(t,e,r){for(var n,i=null,a=1/0,o=0;o<t.length;o++)h&&h._id!==t[o].xa._id||p&&p._id!==t[o].ya._id||(n=t[o].spikeDistance,r&&0===o&&(n=-1/0),n<=a&&n<=e&&(i=t[o],a=n));return i}function Et(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}Mt();var Ct={fullLayout:b,container:b._hoverlayer,event:e},Lt=t._spikepoints,It={vLinePoint:vt.vLinePoint,hLinePoint:vt.hLinePoint};t._spikepoints=It;var Pt=function(){var t=gt.filter((function(t){return h&&h._id===t.xa._id&&p&&p._id===t.ya._id})),e=gt.filter((function(t){return!(h&&h._id===t.xa._id&&p&&p._id===t.ya._id)}));t.sort(P),e.sort(P),gt=function(t,e){for(var r=e.charAt(0),n=[],i=[],a=[],o=0;o<t.length;o++){var s=t[o];v.traceIs(s.trace,\"bar-like\")||v.traceIs(s.trace,\"box-violin\")?a.push(s):s.trace[r+\"period\"]?i.push(s):n.push(s)}return n.concat(i).concat(a)}(gt=t.concat(e),S)};Pt();var zt=S.charAt(0),Ot=(\"x\"===zt||\"y\"===zt)&&gt[0]&&I[gt[0].trace.type];if(M&&0!==rt&&0!==gt.length){var Dt=St(gt.filter((function(t){return t.ya.showspikes})),rt,Ot);vt.hLinePoint=Et(Dt);var Rt=St(gt.filter((function(t){return t.xa.showspikes})),rt,Ot);vt.vLinePoint=Et(Rt)}if(0===gt.length){var Ft=m.unhoverRaw(t,e);return!M||null===vt.hLinePoint&&null===vt.vLinePoint||U(Lt)&&j(t,vt,Ct),Ft}if(M&&U(Lt)&&j(t,vt,Ct),x.isXYhover(ht)&&0!==gt[0].length&&\"splom\"!==gt[0].trace.type){var Bt=gt[0],Nt=(gt=L[Bt.trace.type]?gt.filter((function(t){return t.trace.index===Bt.trace.index})):[Bt]).length;Mt(q(\"x\",Bt,b),q(\"y\",Bt,b));var jt,Ut=[],Vt={},qt=0,Ht=function(t){var e=L[t.trace.type]?z(t):t.trace.index;if(Vt[e]){var r=Vt[e]-1,n=Ut[r];r>0&&Math.abs(t.distance)<Math.abs(n.distance)&&(Ut[r]=t)}else qt++,Vt[e]=qt,Ut.push(t)};for(jt=0;jt<Nt;jt++)Ht(gt[jt]);for(jt=gt.length-1;jt>Nt-1;jt--)Ht(gt[jt]);gt=Ut,Pt()}var Gt=t._hoverdata,Zt=[],Wt=H(t),Yt=G(t);for(at=0;at<gt.length;at++){var Xt=gt[at],$t=x.makeEventData(Xt,Xt.trace,Xt.cd);if(!1!==Xt.hovertemplate){var Jt=!1;Xt.cd[Xt.index]&&Xt.cd[Xt.index].ht&&(Jt=Xt.cd[Xt.index].ht),Xt.hovertemplate=Jt||Xt.trace.hovertemplate||!1}if(Xt.xa&&Xt.ya){var Kt=Xt.x0+Xt.xa._offset,Qt=Xt.x1+Xt.xa._offset,te=Xt.y0+Xt.ya._offset,ee=Xt.y1+Xt.ya._offset,re=Math.min(Kt,Qt),ne=Math.max(Kt,Qt),ie=Math.min(te,ee),ae=Math.max(te,ee);$t.bbox={x0:re+Yt,x1:ne+Yt,y0:ie+Wt,y1:ae+Wt}}Xt.eventData=[$t],Zt.push($t)}t._hoverdata=Zt;var oe=\"y\"===S&&(yt.length>1||gt.length>1)||\"closest\"===S&&xt&&gt.length>1,se=d.combine(b.plot_bgcolor||d.background,b.paper_bgcolor),le=D(gt,{gd:t,hovermode:S,rotateLabels:oe,bgColor:se,container:b._hoverlayer,outerContainer:b._paper.node(),commonLabelOpts:b.hoverlabel,hoverdistance:b.hoverdistance}),ce=le.hoverLabels;if(x.isUnifiedHover(S)||(function(t,e,r,n){var i,a,o,s,l,c,u,h=e?\"xa\":\"ya\",f=e?\"ya\":\"xa\",p=0,d=1,m=t.size(),g=new Array(m),y=0,v=n.minX,x=n.maxX,_=n.minY,b=n.maxY,w=function(t){return t*r._invScaleX},T=function(t){return t*r._invScaleY};function k(t){var e=t[0],r=t[t.length-1];if(a=e.pmin-e.pos-e.dp+e.size,o=r.pos+r.dp+r.size-e.pmax,a>.01){for(l=t.length-1;l>=0;l--)t[l].dp+=a;i=!1}if(!(o<.01)){if(a<-.01){for(l=t.length-1;l>=0;l--)t[l].dp-=o;i=!1}if(i){var n=0;for(s=0;s<t.length;s++)(c=t[s]).pos+c.dp+c.size>e.pmax&&n++;for(s=t.length-1;s>=0&&!(n<=0);s--)(c=t[s]).pos>e.pmax-1&&(c.del=!0,n--);for(s=0;s<t.length&&!(n<=0);s++)if((c=t[s]).pos<e.pmin+1)for(c.del=!0,n--,o=2*c.size,l=t.length-1;l>=0;l--)t[l].dp-=o;for(s=t.length-1;s>=0&&!(n<=0);s--)(c=t[s]).pos+c.dp+c.size>e.pmax&&(c.del=!0,n--)}}}for(t.each((function(t){var n=t[h],i=t[f],a=\"x\"===n._id.charAt(0),o=n.range;0===y&&o&&o[0]>o[1]!==a&&(d=-1);var s=0,l=a?r.width:r.height;if(\"x\"===r.hovermode||\"y\"===r.hovermode){var c,u,p=F(t,e),m=t.anchor,k=\"end\"===m?-1:1;if(\"middle\"===m)u=(c=t.crossPos+(a?T(p.y-t.by/2):w(t.bx/2+t.tx2width/2)))+(a?T(t.by):w(t.bx));else if(a)u=(c=t.crossPos+T(E+p.y)-T(t.by/2-E))+T(t.by);else{var M=w(k*E+p.x),S=M+w(k*t.bx);c=t.crossPos+Math.min(M,S),u=t.crossPos+Math.max(M,S)}a?void 0!==_&&void 0!==b&&Math.min(u,b)-Math.max(c,_)>1&&(\"left\"===i.side?(s=i._mainLinePosition,l=r.width):l=i._mainLinePosition):void 0!==v&&void 0!==x&&Math.min(u,x)-Math.max(c,v)>1&&(\"top\"===i.side?(s=i._mainLinePosition,l=r.height):l=i._mainLinePosition)}g[y++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(a?A:1)/2,pmin:s,pmax:l}]})),g.sort((function(t,e){return t[0].posref-e[0].posref||d*(e[0].traceIndex-t[0].traceIndex)}));!i&&p<=m;){for(p++,i=!0,s=0;s<g.length-1;){var M=g[s],S=g[s+1],C=M[M.length-1],L=S[0];if((a=C.pos+C.dp+C.size-L.pos-L.dp+L.size)>.01){for(l=S.length-1;l>=0;l--)S[l].dp+=a;for(M.push.apply(M,S),g.splice(s+1,1),u=0,l=M.length-1;l>=0;l--)u+=M[l].dp;for(o=u/M.length,l=M.length-1;l>=0;l--)M[l].dp-=o;i=!1}else s++}g.forEach(k)}for(s=g.length-1;s>=0;s--){var I=g[s];for(l=I.length-1;l>=0;l--){var P=I[l],z=P.datum;z.offset=P.dp,z.del=P.del}}}(ce,oe,b,le.commonLabelBoundingBox),B(ce,oe,b._invScaleX,b._invScaleY)),l&&l.tagName){var ue=v.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Zt);f(n.select(l),ue?\"pointer\":\"\")}l&&!a&&function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,Gt)&&(Gt&&t.emit(\"plotly_unhover\",{event:e,points:Gt}),t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:$,yaxes:J,xvals:nt,yvals:it}))}(t,e,r,a,l)}))},e.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=e.gd,a=H(i),o=G(i),s=D(t.map((function(t){var r=t._x0||t.x0||t.x||0,n=t._x1||t.x1||t.x||0,s=t._y0||t.y0||t.y||0,l=t._y1||t.y1||t.y||0,c=t.eventData;if(c){var u=Math.min(r,n),h=Math.max(r,n),f=Math.min(s,l),p=Math.max(s,l),m=t.trace;if(v.traceIs(m,\"gl3d\")){var g=i._fullLayout[m.scene]._scene.container,y=g.offsetLeft,x=g.offsetTop;u+=y,h+=y,f+=x,p+=x}c.bbox={x0:u+o,x1:h+o,y0:f+a,y1:p+a},e.inOut_bbox&&e.inOut_bbox.push(c.bbox)}else c=!1;return{color:t.color||d.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,fontWeight:t.fontWeight,fontStyle:t.fontStyle,fontVariant:t.fontVariant,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,hovertemplateLabels:t.hovertemplateLabels||!1,eventData:c}})),{gd:i,hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||d.background,container:n.select(e.container),outerContainer:e.outerContainer||e.container}).hoverLabels,l=0,c=0;return s.sort((function(t,e){return t.y0-e.y0})).each((function(t,r){var n=t.y0-t.by/2;t.offset=n-5<l?l-n+5:0,l=n+t.by+t.offset,r===e.anchorIndex&&(c=t.offset)})).each((function(t){t.offset-=c})),B(s,!1,i._fullLayout._invScaleX,i._fullLayout._invScaleY),r?s:s.node()};var O=/<extra>([\\s\\S]*)<\\/extra>/;function D(t,e){var r=e.gd,i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,u=e.bgColor,f=e.container,m=e.outerContainer,g=e.commonLabelOpts||{};if(0===t.length)return[[]];var y=e.fontFamily||_.HOVERFONT,k=e.fontSize||_.HOVERFONTSIZE,A=e.fontWeight||i.font.weight,M=e.fontStyle||i.font.style,S=e.fontVariant||i.font.variant,L=e.fontTextcase||i.font.textcase,I=e.fontLineposition||i.font.lineposition,P=e.fontShadow||i.font.shadow,O=t[0],D=O.xa,F=O.ya,B=a.charAt(0),N=B+\"Label\",j=O[N];if(void 0===j&&\"multicategory\"===D.type)for(var U=0;U<t.length&&void 0===(j=t[U][N]);U++);var V=Z(r,m),q=V.top,H=V.width,G=V.height,W=void 0!==j&&O.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(W){var Y,X,$=!0;for(Y=0;Y<t.length;Y++)if($&&void 0===t[Y].zLabel&&($=!1),X=t[Y].hoverinfo||t[Y].trace.hoverinfo){var J=Array.isArray(X)?X:X.split(\"+\");if(-1===J.indexOf(\"all\")&&-1===J.indexOf(a)){W=!1;break}}$&&(W=!1)}var K=f.selectAll(\"g.axistext\").data(W?[0]:[]);K.enter().append(\"g\").classed(\"axistext\",!0),K.exit().remove();var Q={minX:0,maxX:0,minY:0,maxY:0};if(K.each((function(){var t=n.select(this),e=o.ensureSingle(t,\"path\",\"\",(function(t){t.style({\"stroke-width\":\"1px\"})})),s=o.ensureSingle(t,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),c=g.bgcolor||d.defaultLine,u=g.bordercolor||d.contrast(c),f=d.contrast(c),m=g.font,v={weight:m.weight||A,style:m.style||M,variant:m.variant||S,textcase:m.textcase||L,lineposition:m.lineposition||I,shadow:m.shadow||P,family:m.family||y,size:m.size||k,color:m.color||f};e.style({fill:c,stroke:u}),s.text(j).call(p.font,v).call(h.positionText,0,0).call(h.convertToTspans,r),t.attr(\"transform\",\"\");var x,_,b=Z(r,s.node());if(\"x\"===a){var w=\"top\"===D.side?\"-\":\"\";s.attr(\"text-anchor\",\"middle\").call(h.positionText,0,\"top\"===D.side?q-b.bottom-E-C:q-b.top+E+C),x=D._offset+(O.x0+O.x1)/2,_=F._offset+(\"top\"===D.side?0:F._length);var T=b.width/2+C,z=x;x<T?z=T:x>i.width-T&&(z=i.width-T),e.attr(\"d\",\"M\"+(x-z)+\",0L\"+(x-z+E)+\",\"+w+E+\"H\"+T+\"v\"+w+(2*C+b.height)+\"H\"+-T+\"V\"+w+E+\"H\"+(x-z-E)+\"Z\"),x=z,Q.minX=x-T,Q.maxX=x+T,\"top\"===D.side?(Q.minY=_-(2*C+b.height),Q.maxY=_-C):(Q.minY=_+C,Q.maxY=_+(2*C+b.height))}else{var R,B,N;\"right\"===F.side?(R=\"start\",B=1,N=\"\",x=D._offset+D._length):(R=\"end\",B=-1,N=\"-\",x=D._offset),_=F._offset+(O.y0+O.y1)/2,s.attr(\"text-anchor\",R),e.attr(\"d\",\"M0,0L\"+N+E+\",\"+E+\"V\"+(C+b.height/2)+\"h\"+N+(2*C+b.width)+\"V-\"+(C+b.height/2)+\"H\"+N+E+\"V-\"+E+\"Z\"),Q.minY=_-(C+b.height/2),Q.maxY=_+(C+b.height/2),\"right\"===F.side?(Q.minX=x+E,Q.maxX=x+E+(2*C+b.width)):(Q.minX=x-E-(2*C+b.width),Q.maxX=x-E);var U,V=b.height/2,H=q-b.top-V,G=\"clip\"+i._uid+\"commonlabel\"+F._id;if(x<b.width+2*C+E){U=\"M-\"+(E+C)+\"-\"+V+\"h-\"+(b.width-C)+\"V\"+V+\"h\"+(b.width-C)+\"Z\";var W=b.width-x+C;h.positionText(s,W,H),\"end\"===R&&s.selectAll(\"tspan\").each((function(){var t=n.select(this),e=p.tester.append(\"text\").text(t.text()).call(p.font,v),i=Z(r,e.node());Math.round(i.width)<Math.round(b.width)&&t.attr(\"x\",W-i.width),e.remove()}))}else h.positionText(s,B*(C+E),H),U=null;var Y=i._topclips.selectAll(\"#\"+G).data(U?[0]:[]);Y.enter().append(\"clipPath\").attr(\"id\",G).append(\"path\"),Y.exit().remove(),Y.select(\"path\").attr(\"d\",U),p.setClipUrl(s,U?G:null,r)}t.attr(\"transform\",l(x,_))})),x.isUnifiedHover(a)){f.selectAll(\"g.hovertext\").remove();var tt=t.filter((function(t){return\"none\"!==t.hoverinfo}));if(0===tt.length)return[];var et=i.hoverlabel,rt=et.font,nt={showlegend:!0,legend:{title:{text:j,font:rt},font:rt,bgcolor:et.bgcolor,bordercolor:et.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:i.legend?i.legend.traceorder:void 0,orientation:\"v\"}},it={font:rt};b(nt,it,r._fullData);var at=it.legend;at.entries=[];for(var ot=0;ot<tt.length;ot++){var st=tt[ot];if(\"none\"!==st.hoverinfo){var lt=R(st,!0,a,i,j),ct=lt[0],ut=lt[1];st.name=ut,st.text=\"\"!==ut?ut+\" : \"+ct:ct;var ht=st.cd[st.index];ht&&(ht.mc&&(st.mc=ht.mc),ht.mcc&&(st.mc=ht.mcc),ht.mlc&&(st.mlc=ht.mlc),ht.mlcc&&(st.mlc=ht.mlcc),ht.mlw&&(st.mlw=ht.mlw),ht.mrc&&(st.mrc=ht.mrc),ht.dir&&(st.dir=ht.dir)),st._distinct=!0,at.entries.push([st])}}at.entries.sort((function(t,e){return t[0].trace.index-e[0].trace.index})),at.layer=f,at._inHover=!0,at._groupTitleFont=et.grouptitlefont,w(r,at);var ft,pt,dt,mt,gt=f.select(\"g.legend\"),yt=Z(r,gt.node()),vt=yt.width+2*C,xt=yt.height+2*C,_t=tt[0],bt=(_t.x0+_t.x1)/2,wt=(_t.y0+_t.y1)/2,Tt=!(v.traceIs(_t.trace,\"bar-like\")||v.traceIs(_t.trace,\"box-violin\"));\"y\"===B?Tt?(pt=wt-C,ft=wt+C):(pt=Math.min.apply(null,tt.map((function(t){return Math.min(t.y0,t.y1)}))),ft=Math.max.apply(null,tt.map((function(t){return Math.max(t.y0,t.y1)})))):pt=ft=o.mean(tt.map((function(t){return(t.y0+t.y1)/2})))-xt/2,\"x\"===B?Tt?(dt=bt+C,mt=bt-C):(dt=Math.max.apply(null,tt.map((function(t){return Math.max(t.x0,t.x1)}))),mt=Math.min.apply(null,tt.map((function(t){return Math.min(t.x0,t.x1)})))):dt=mt=o.mean(tt.map((function(t){return(t.x0+t.x1)/2})))-vt/2;var kt,At,Mt=D._offset,St=F._offset;return mt+=Mt-vt,pt+=St-xt,kt=(dt+=Mt)+vt<H&&dt>=0?dt:mt+vt<H&&mt>=0?mt:Mt+vt<H?Mt:dt-bt<bt-mt+vt?H-vt:0,kt+=C,At=(ft+=St)+xt<G&&ft>=0?ft:pt+xt<G&&pt>=0?pt:St+xt<G?St:ft-wt<wt-pt+xt?G-xt:0,At+=C,gt.attr(\"transform\",l(kt-1,At-1)),gt}var Et=f.selectAll(\"g.hovertext\").data(t,(function(t){return z(t)}));return Et.enter().append(\"g\").classed(\"hovertext\",!0).each((function(){var t=n.select(this);t.append(\"rect\").call(d.fill,d.addOpacity(u,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(p.font,{weight:A,style:M,variant:S,textcase:L,lineposition:I,shadow:P,family:y,size:k})})),Et.exit().remove(),Et.each((function(t){var e=n.select(this).attr(\"transform\",\"\"),o=t.color;Array.isArray(o)&&(o=o[t.eventData[0].pointNumber]);var f=t.bgcolor||o,m=d.combine(d.opacity(f)?f:d.defaultLine,u),g=d.combine(d.opacity(o)?o:d.defaultLine,u),v=t.borderColor||d.contrast(m),x=R(t,W,a,i,j,e),_=x[0],b=x[1],w=e.select(\"text.nums\").call(p.font,{family:t.fontFamily||y,size:t.fontSize||k,color:t.fontColor||v,weight:t.fontWeight||A,style:t.fontStyle||M,variant:t.fontVariant||S,textcase:t.fontTextcase||L,lineposition:t.fontLineposition||I,shadow:t.fontShadow||P}).text(_).attr(\"data-notex\",1).call(h.positionText,0,0).call(h.convertToTspans,r),z=e.select(\"text.name\"),O=0,D=0;if(b&&b!==_){z.call(p.font,{family:t.fontFamily||y,size:t.fontSize||k,color:g,weight:t.fontWeight||A,style:t.fontStyle||M,variant:t.fontVariant||S,textcase:t.fontTextcase||L,lineposition:t.fontLineposition||I,shadow:t.fontShadow||P}).text(b).attr(\"data-notex\",1).call(h.positionText,0,0).call(h.convertToTspans,r);var F=Z(r,z.node());O=F.width+2*C,D=F.height+2*C}else z.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:m,stroke:v});var B=t.xa._offset+(t.x0+t.x1)/2,N=t.ya._offset+(t.y0+t.y1)/2,U=Math.abs(t.x1-t.x0),V=Math.abs(t.y1-t.y0),Y=Z(r,w.node()),X=Y.width/i._invScaleX,$=Y.height/i._invScaleY;t.ty0=(q-Y.top)/i._invScaleY,t.bx=X+2*C,t.by=Math.max($+2*C,D),t.anchor=\"start\",t.txwidth=X,t.tx2width=O,t.offset=0;var J,K,Q=(X+E+C+O)*i._invScaleX;if(s)t.pos=B,J=N+V/2+Q<=G,K=N-V/2-Q>=0,\"top\"!==t.idealAlign&&J||!K?J?(N+=V/2,t.anchor=\"start\"):t.anchor=\"middle\":(N-=V/2,t.anchor=\"end\"),t.crossPos=N;else{if(t.pos=N,J=B+U/2+Q<=H,K=B-U/2-Q>=0,\"left\"!==t.idealAlign&&J||!K)if(J)B+=U/2,t.anchor=\"start\";else{t.anchor=\"middle\";var tt=Q/2,et=B+tt-H,rt=B-tt;et>0&&(B-=et),rt<0&&(B+=-rt)}else B-=U/2,t.anchor=\"end\";t.crossPos=B}w.attr(\"text-anchor\",t.anchor),O&&z.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",l(B,N)+(s?c(T):\"\"))})),{hoverLabels:Et,commonLabelBoundingBox:Q}}function R(t,e,r,n,i,a){var s=\"\",l=\"\";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=V(t.name,t.nameLength));var c=r.charAt(0),u=\"x\"===c?\"y\":\"x\";void 0!==t.zLabel?(void 0!==t.xLabel&&(l+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(l+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&\"choroplethmap\"!==t.trace.type&&(l+=(l?\"z: \":\"\")+t.zLabel)):e&&t[c+\"Label\"]===i?l=t[u+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(l+=(l?\"<br>\":\"\")+t.extraText),a&&\"\"===l&&!t.hovertemplate&&(\"\"===s&&a.remove(),l=s);var h=t.hovertemplate||!1;if(h){var f=t.hovertemplateLabels||t;t[c+\"Label\"]!==i&&(f[c+\"other\"]=f[c+\"Val\"],f[c+\"otherLabel\"]=f[c+\"Label\"]),l=(l=o.hovertemplateString(h,f,n._d3locale,t.eventData[0]||{},t.trace._meta)).replace(O,(function(e,r){return s=V(r,t.nameLength),\"\"}))}return[l,s]}function F(t,e){var r=0,n=t.offset;return e&&(n*=-S,r=t.offset*M),{x:r,y:n}}function B(t,e,r,i){var a=function(t){return t*r},o=function(t){return t*i};t.each((function(t){var r=n.select(this);if(t.del)return r.remove();var i,s,l,c,u=r.select(\"text.nums\"),f=t.anchor,d=\"end\"===f?-1:1,m=(c=(l=(s={start:1,end:-1,middle:0}[(i=t).anchor])*(E+C))+s*(i.txwidth+C),\"middle\"===i.anchor&&(l-=i.tx2width/2,c+=i.txwidth/2+C),{alignShift:s,textShiftX:l,text2ShiftX:c}),g=F(t,e),y=g.x,v=g.y,x=\"middle\"===f;r.select(\"path\").attr(\"d\",x?\"M-\"+a(t.bx/2+t.tx2width/2)+\",\"+o(v-t.by/2)+\"h\"+a(t.bx)+\"v\"+o(t.by)+\"h-\"+a(t.bx)+\"Z\":\"M0,0L\"+a(d*E+y)+\",\"+o(E+v)+\"v\"+o(t.by/2-E)+\"h\"+a(d*t.bx)+\"v-\"+o(t.by)+\"H\"+a(d*E+y)+\"V\"+o(v-E)+\"Z\");var _=y+m.textShiftX,b=v+t.ty0-t.by/2+C,w=t.textAlign||\"auto\";\"auto\"!==w&&(\"left\"===w&&\"start\"!==f?(u.attr(\"text-anchor\",\"start\"),_=x?-t.bx/2-t.tx2width/2+C:-t.bx-C):\"right\"===w&&\"end\"!==f&&(u.attr(\"text-anchor\",\"end\"),_=x?t.bx/2-t.tx2width/2-C:t.bx+C)),u.call(h.positionText,a(_),o(b)),t.tx2width&&(r.select(\"text.name\").call(h.positionText,a(m.text2ShiftX+m.alignShift*C+y),o(v+t.ty0-t.by/2+C)),r.select(\"rect\").call(p.setRect,a(m.text2ShiftX+(m.alignShift-1)*t.tx2width/2+y),o(v-t.by/2-1),a(t.tx2width),o(t.by+2)))}))}function N(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"fontWeight\",\"htw\",\"hoverlabel.font.weight\"),u(\"fontStyle\",\"hty\",\"hoverlabel.font.style\"),u(\"fontVariant\",\"htv\",\"hoverlabel.font.variant\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:g.hoverLabelText(t.xa,t.xLabelVal,n.xhoverformat),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:g.hoverLabelText(t.ya,t.yLabelVal,n.yhoverformat),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=g.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+g.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \u00b1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=g.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+g.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \u00b1 \"+f,\"y\"===e&&(t.distance+=1)}var p=t.hoverinfo||t.trace.hoverinfo;return p&&\"all\"!==p&&(-1===(p=Array.isArray(p)?p:p.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===p.indexOf(\"y\")&&(t.yLabel=void 0),-1===p.indexOf(\"z\")&&(t.zLabel=void 0),-1===p.indexOf(\"text\")&&(t.text=void 0),-1===p.indexOf(\"name\")&&(t.name=void 0)),t}function j(t,e,r){var n,i,o=r.container,s=r.fullLayout,l=s._size,c=r.event,u=!!e.hLinePoint,h=!!e.vLinePoint;if(o.selectAll(\".spikeline\").remove(),h||u){var f=d.combine(s.plot_bgcolor,s.paper_bgcolor);if(u){var m,y,v=e.hLinePoint;n=v&&v.xa,\"cursor\"===(i=v&&v.ya).spikesnap?(m=c.pointerX,y=c.pointerY):(m=n._offset+v.x,y=i._offset+v.y);var x,_,b=a.readability(v.color,f)<1.5?d.contrast(f):v.color,w=i.spikemode,T=i.spikethickness,k=i.spikecolor||b,A=g.getPxPosition(t,i);if(-1!==w.indexOf(\"toaxis\")||-1!==w.indexOf(\"across\")){if(-1!==w.indexOf(\"toaxis\")&&(x=A,_=m),-1!==w.indexOf(\"across\")){var M=i._counterDomainMin,S=i._counterDomainMax;\"free\"===i.anchor&&(M=Math.min(M,i.position),S=Math.max(S,i.position)),x=l.l+M*l.w,_=l.l+S*l.w}o.insert(\"line\",\":first-child\").attr({x1:x,x2:_,y1:y,y2:y,\"stroke-width\":T,stroke:k,\"stroke-dasharray\":p.dashStyle(i.spikedash,T)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:x,x2:_,y1:y,y2:y,\"stroke-width\":T+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==w.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:A+(\"right\"!==i.side?T:-T),cy:y,r:T,fill:k}).classed(\"spikeline\",!0)}if(h){var E,C,L=e.vLinePoint;n=L&&L.xa,i=L&&L.ya,\"cursor\"===n.spikesnap?(E=c.pointerX,C=c.pointerY):(E=n._offset+L.x,C=i._offset+L.y);var I,P,z=a.readability(L.color,f)<1.5?d.contrast(f):L.color,O=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=g.getPxPosition(t,n);if(-1!==O.indexOf(\"toaxis\")||-1!==O.indexOf(\"across\")){if(-1!==O.indexOf(\"toaxis\")&&(I=F,P=C),-1!==O.indexOf(\"across\")){var B=n._counterDomainMin,N=n._counterDomainMax;\"free\"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),I=l.t+(1-N)*l.h,P=l.t+(1-B)*l.h}o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D,stroke:R,\"stroke-dasharray\":p.dashStyle(n.spikedash,D)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==O.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:E,cy:F-(\"top\"!==n.side?D:-D),r:D,fill:R}).classed(\"spikeline\",!0)}}}function U(t,e){return!e||e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint}function V(t,e){return h.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\",\"s\",\"u\"]})}function q(t,e,r){var n=e[t+\"a\"],i=e[t+\"Val\"],a=e.cd[0];if(\"category\"===n.type||\"multicategory\"===n.type)i=n._categoriesMap[i];else if(\"date\"===n.type){var o=e.trace[t+\"periodalignment\"];if(o){var s=e.cd[e.index],l=s[t+\"Start\"];void 0===l&&(l=s[t]);var c=s[t+\"End\"];void 0===c&&(c=s[t]);var u=c-l;\"end\"===o?i+=u:\"middle\"===o&&(i+=u/2)}i=n.d2c(i)}return a&&a.t&&a.t.posLetter===n._id&&(\"group\"!==r.boxmode&&\"group\"!==r.violinmode||(i+=a.t.dPos)),i}function H(t){return t.offsetTop+t.clientTop}function G(t){return t.offsetLeft+t.clientLeft}function Z(t,e){var r=t._fullLayout,n=e.getBoundingClientRect(),i=n.left,a=n.top,s=i+n.width,l=a+n.height,c=o.apply3DTransform(r._invTransform)(i,a),u=o.apply3DTransform(r._invTransform)(s,l),h=c[0],f=c[1],p=u[0],d=u[1];return{x:h,y:f,width:p-h,height:d-f,top:Math.min(f,d),left:Math.min(h,p),right:Math.max(h,p),bottom:Math.max(f,d)}}},26430:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(36040).isUnifiedHover;t.exports=function(t,e,r,o){o=o||{};var s=e.legend;function l(t){o.font[t]||(o.font[t]=s?e.legend.font[t]:e.font[t])}e&&a(e.hovermode)&&(o.font||(o.font={}),l(\"size\"),l(\"family\"),l(\"color\"),l(\"weight\"),l(\"style\"),l(\"variant\"),s?(o.bgcolor||(o.bgcolor=i.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r(\"hoverlabel.bgcolor\",o.bgcolor),r(\"hoverlabel.bordercolor\",o.bordercolor),r(\"hoverlabel.namelength\",o.namelength),n.coerceFont(r,\"hoverlabel.font\",o.font),r(\"hoverlabel.align\",o.align)}},45265:function(t,e,r){\"use strict\";var n=r(34809),i=r(6811);t.exports=function(t,e){function r(r,a){return void 0!==e[r]?e[r]:n.coerce(t,e,i,r,a)}return r(\"clickmode\"),r(\"hoversubplots\"),r(\"hovermode\")}},32141:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(14751),o=r(36040),s=r(6811),l=r(38103);t.exports={moduleType:\"component\",name:\"fx\",constants:r(85988),schema:{layout:s},attributes:r(70192),layoutAttributes:s,supplyLayoutGlobalDefaults:r(5358),supplyDefaults:r(3239),supplyLayoutDefaults:r(8412),calc:r(83552),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",(function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)}))},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:r(94225)}},6811:function(t,e,r){\"use strict\";var n=r(85988),i=r(80337),a=i({editType:\"none\"});a.family.dflt=n.HOVERFONT,a.size.dflt=n.HOVERFONTSIZE,t.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"drawclosedpath\",\"drawopenpath\",\"drawline\",\"drawrect\",\"drawcircle\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1,\"x unified\",\"y unified\"],dflt:\"closest\",editType:\"modebar\"},hoversubplots:{valType:\"enumerated\",values:[\"single\",\"overlaying\",\"axis\"],dflt:\"overlaying\",editType:\"none\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:-1,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:a,grouptitlefont:i({editType:\"none\"}),align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},8412:function(t,e,r){\"use strict\";var n=r(34809),i=r(6811),a=r(45265),o=r(26430);t.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}a(t,e)&&(r(\"hoverdistance\"),r(\"spikedistance\")),\"select\"===r(\"dragmode\")&&r(\"selectdirection\");var s=e._has(\"mapbox\"),l=e._has(\"map\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((s||l||c)&&1===u||(s||l)&&c&&2===u)&&(e.dragmode=\"pan\"),o(t,e,r),n.coerceFont(r,\"hoverlabel.grouptitlefont\",e.hoverlabel.font)}},5358:function(t,e,r){\"use strict\";var n=r(34809),i=r(26430),a=r(6811);t.exports=function(t,e){i(t,e,(function(r,i){return n.coerce(t,e,a,r,i)}))}},83595:function(t,e,r){\"use strict\";var n=r(34809),i=r(90694).counter,a=r(13792).u,o=r(54826).idRegex,s=r(78032),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}t.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),m=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var g=s.newContainer(e,\"grid\"),y=k(\"rows\",o),v=k(\"columns\",h);if(y*v>1){f||p||d||\"independent\"===k(\"pattern\")&&(f=!0),g._hasSubplotGrid=f;var x,_,b=\"top to bottom\"===k(\"roworder\"),w=f?.2:.1,T=f?.3:.1;m&&e._splomGridDflt&&(x=e._splomGridDflt.xside,_=e._splomGridDflt.yside),g._domains={x:u(\"x\",k,w,x,v),y:u(\"y\",k,T,_,y,b)}}else delete e.grid}function k(t,e){return n.coerce(r,g,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,m=r.rows,g=r.columns,y=\"independent\"===r.pattern,v=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(m);var _=1;for(n=0;n<m;n++){var b=l[n]=new Array(g),w=x[n]||[];for(i=0;i<g;i++)if(y?(s=1===_?\"xy\":\"x\"+_+\"y\"+_,_++):s=w[i],b[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==v[a]&&v[a]!==i||void 0!==v[o]&&v[o]!==n)continue;b[i]=s,v[a]=i,v[o]=n}}}else{var T=c(e,f,\"x\"),k=c(e,f,\"y\");r.xaxes=h(T,p.xaxis,g,v,\"x\"),r.yaxes=h(k,p.yaxis,m,v,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in v){var E,C,L,I=S.charAt(0),P=r[I+\"side\"];if(P.length<8)A[S]=\"free\";else if(\"x\"===I){if(\"t\"===P.charAt(0)===M?(E=0,C=1,L=m):(E=m-1,C=-1,L=-1),d){var z=v[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===P.charAt(0)?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var O=v[S];for(n=E;n!==L;n+=C)if((s=l[O][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},37260:function(t,e,r){\"use strict\";var n=r(54826),i=r(78032).templatedArray;r(35081),t.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},89443:function(t,e,r){\"use strict\";var n=r(10721),i=r(8083);t.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],m=null,g=null;if(o){m=i(p,e.range);var y=d/Math.pow(10,m)/2;g=2*Math.log(y+Math.sqrt(1+y*y))/Math.LN10}else g=(m=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(m)?n(g)||(g=null):(m=null,g=null),a(c+h,m),a(c+\"size\"+h,g)}}},507:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(59008),o=r(37260);function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\",void 0);\"paper\"!==f&&i.getFromId(l,f)._imgIndices.push(e._index),i.coercePosition(e,l,a,f,h,0)}return e}t.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},32211:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(29714),o=r(5975),s=r(62972);t.exports=function(t){var e,r,l=t._fullLayout,c=[],u={},h=[];for(r=0;r<l.images.length;r++){var f=l.images[r];if(f.visible)if(\"below\"===f.layer&&\"paper\"!==f.xref&&\"paper\"!==f.yref){e=o.ref2id(f.xref)+o.ref2id(f.yref);var p=l._plots[e];if(!p){h.push(f);continue}p.mainplot&&(e=p.mainplot.id),u[e]||(u[e]=[]),u[e].push(f)}else\"above\"===f.layer?c.push(f):h.push(f)}var d={left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},m={top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}};function g(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr(\"xmlns\",s.svg),e.source&&\"data:\"===e.source.slice(0,5))r.attr(\"xlink:href\",e.source),this._imgSrc=e.source;else{var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\",{willReadFrequently:!0}).drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(i)}}function y(e){var r,o,s=n.select(this),c=a.getFromId(t,e.xref),u=a.getFromId(t,e.yref),h=\"domain\"===a.getRefType(e.xref),f=\"domain\"===a.getRefType(e.yref),p=l._size;r=void 0!==c?\"string\"==typeof e.xref&&h?c._length*e.sizex:Math.abs(c.l2p(e.sizex)-c.l2p(0)):e.sizex*p.w,o=void 0!==u?\"string\"==typeof e.yref&&f?u._length*e.sizey:Math.abs(u.l2p(e.sizey)-u.l2p(0)):e.sizey*p.h;var g,y,v=r*d[e.xanchor].offset,x=o*m[e.yanchor].offset,_=d[e.xanchor].sizing+m[e.yanchor].sizing;switch(g=void 0!==c?\"string\"==typeof e.xref&&h?c._length*e.x+c._offset:c.r2p(e.x)+c._offset:e.x*p.w+p.l,g+=v,y=void 0!==u?\"string\"==typeof e.yref&&f?u._length*(1-e.y)+u._offset:u.r2p(e.y)+u._offset:p.h-e.y*p.h+p.t,y+=x,e.sizing){case\"fill\":_+=\" slice\";break;case\"stretch\":_=\"none\"}s.attr({x:g,y:y,width:r,height:o,preserveAspectRatio:_,opacity:e.opacity});var b=(c&&\"domain\"!==a.getRefType(e.xref)?c._id:\"\")+(u&&\"domain\"!==a.getRefType(e.yref)?u._id:\"\");i.setClipUrl(s,b?\"clip\"+l._uid+b:null,t)}var v=l._imageLowerLayer.selectAll(\"image\").data(h),x=l._imageUpperLayer.selectAll(\"image\").data(c);v.enter().append(\"image\"),x.enter().append(\"image\"),v.exit().remove(),x.exit().remove(),v.each((function(t){g.bind(this)(t),y.bind(this)(t)})),x.each((function(t){g.bind(this)(t),y.bind(this)(t)}));var _=Object.keys(l._plots);for(r=0;r<_.length;r++){e=_[r];var b=l._plots[e];if(b.imagelayer){var w=b.imagelayer.selectAll(\"image\").data(u[e]||[]);w.enter().append(\"image\"),w.exit().remove(),w.each((function(t){g.bind(this)(t),y.bind(this)(t)}))}}}},15553:function(t,e,r){\"use strict\";t.exports={moduleType:\"component\",name:\"images\",layoutAttributes:r(37260),supplyLayoutDefaults:r(507),includeBasePlot:r(20706)(\"images\"),draw:r(32211),convertCoords:r(89443)}},86405:function(t,e,r){\"use strict\";var n=r(80337),i=r(10229);t.exports={_isSubplotObj:!0,visible:{valType:\"boolean\",dflt:!0,editType:\"legend\"},bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),grouptitlefont:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},entrywidth:{valType:\"number\",min:0,editType:\"legend\"},entrywidthmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\",editType:\"legend\"},indentation:{valType:\"number\",min:-15,dflt:0,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemwidth:{valType:\"number\",min:30,dflt:30,editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},groupclick:{valType:\"enumerated\",values:[\"toggleitem\",\"togglegroup\"],dflt:\"togglegroup\",editType:\"legend\"},x:{valType:\"number\",editType:\"legend\"},xref:{valType:\"enumerated\",dflt:\"paper\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",editType:\"legend\"},yref:{valType:\"enumerated\",dflt:\"paper\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"legend\"},font:n({editType:\"legend\"}),side:{valType:\"enumerated\",values:[\"top\",\"left\",\"top left\",\"top center\",\"top right\"],editType:\"legend\"},editType:\"legend\"},editType:\"legend\"}},72783:function(t){\"use strict\";t.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,itemGap:5}},73970:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(78032),o=r(9829),s=r(86405),l=r(6704),c=r(57599);function u(t,e,r,u){var h=e[t]||{},f=a.newContainer(r,t);function p(t,e){return i.coerce(h,f,s,t,e)}var d=i.coerceFont(p,\"font\",r.font);if(p(\"bgcolor\",r.paper_bgcolor),p(\"bordercolor\"),p(\"visible\")){for(var m,g=function(t,e){var r=m._input,n=m;return i.coerce(r,n,o,t,e)},y=r.font||{},v=i.coerceFont(p,\"grouptitlefont\",y,{overrideDflt:{size:Math.round(1.1*y.size)}}),x=0,_=!1,b=\"normal\",w=(r.shapes||[]).filter((function(t){return t.showlegend})),T=u.concat(w).filter((function(e){return t===(e.legend||\"legend\")})),k=0;k<T.length;k++)if((m=T[k]).visible){var A=m._isShape;(m.showlegend||m._dfltShowLegend&&!(m._module&&m._module.attributes&&m._module.attributes.showlegend&&!1===m._module.attributes.showlegend.dflt))&&(x++,m.showlegend&&(_=!0,(!A&&n.traceIs(m,\"pie-like\")||!0===m._input.showlegend)&&x++),i.coerceFont(g,\"legendgrouptitle.font\",v)),(!A&&n.traceIs(m,\"bar\")&&\"stack\"===r.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(m.fill))&&(b=c.isGrouped({traceorder:b})?\"grouped+reversed\":\"reversed\"),void 0!==m.legendgroup&&\"\"!==m.legendgroup&&(b=c.isReversed({traceorder:b})?\"reversed+grouped\":\"grouped\")}var M=i.coerce(e,r,l,\"showlegend\",_&&x>(\"legend\"===t?1:0));if(!1===M&&(r[t]=void 0),(!1!==M||h.uirevision)&&(p(\"uirevision\",r.uirevision),!1!==M)){p(\"borderwidth\");var S,E,C,L=\"h\"===p(\"orientation\"),I=\"paper\"===p(\"yref\"),P=\"paper\"===p(\"xref\"),z=\"left\";if(L?(S=0,n.getComponentMethod(\"rangeslider\",\"isVisible\")(e.xaxis)?I?(E=1.1,C=\"bottom\"):(E=1,C=\"top\"):I?(E=-.1,C=\"top\"):(E=0,C=\"bottom\")):(E=1,C=\"auto\",P?S=1.02:(S=1,z=\"right\")),i.coerce(h,f,{x:{valType:\"number\",editType:\"legend\",min:P?-2:0,max:P?3:1,dflt:S}},\"x\"),i.coerce(h,f,{y:{valType:\"number\",editType:\"legend\",min:I?-2:0,max:I?3:1,dflt:E}},\"y\"),p(\"traceorder\",b),c.isGrouped(r[t])&&p(\"tracegroupgap\"),p(\"entrywidth\"),p(\"entrywidthmode\"),p(\"indentation\"),p(\"itemsizing\"),p(\"itemwidth\"),p(\"itemclick\"),p(\"itemdoubleclick\"),p(\"groupclick\"),p(\"xanchor\",z),p(\"yanchor\",C),p(\"valign\"),i.noneOrAll(h,f,[\"x\",\"y\"]),p(\"title.text\")){p(\"title.side\",L?\"left\":\"top\");var O=i.extendFlat({},d,{size:i.bigFont(d.size)});i.coerceFont(p,\"title.font\",O)}}}}t.exports=function(t,e,r){var n,a=r.slice(),o=e.shapes;if(o)for(n=0;n<o.length;n++){var s=o[n];if(s.showlegend){var l={_input:s._input,visible:s.visible,showlegend:s.showlegend,legend:s.legend};a.push(l)}}var c=[\"legend\"];for(n=0;n<a.length;n++)i.pushUnique(c,a[n].legend);for(e._legends=[],n=0;n<c.length;n++){var h=c[n];u(h,t,e,a),e[h]&&e[h].visible&&(e[h]._id=h),e._legends.push(h)}}},6134:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(44122),o=r(33626),s=r(68596),l=r(14751),c=r(62203),u=r(78766),h=r(30635),f=r(22165),p=r(72783),d=r(4530),m=d.LINE_SPACING,g=d.FROM_TL,y=d.FROM_BR,v=r(851),x=r(14375),_=r(57599),b=1,w=/^legend[0-9]*$/;function T(t,e){var r,s,f=e||{},d=t._fullLayout,w=P(f),T=f._inHover;if(T?(s=f.layer,r=\"hover\"):(s=d._infolayer,r=w),s){var S;if(r+=d._uid,t._legendMouseDownTime||(t._legendMouseDownTime=0),T){if(!f.entries)return;S=v(f.entries,f)}else{for(var z=(t.calcdata||[]).slice(),O=d.shapes,D=0;D<O.length;D++){var R=O[D];if(R.showlegend){var F={_isShape:!0,_fullInput:R,index:R._index,name:R.name||R.label.text||\"shape \"+R._index,legend:R.legend,legendgroup:R.legendgroup,legendgrouptitle:R.legendgrouptitle,legendrank:R.legendrank,legendwidth:R.legendwidth,showlegend:R.showlegend,visible:R.visible,opacity:R.opacity,mode:\"line\"===R.type?\"lines\":\"markers\",line:R.line,marker:{line:R.line,color:R.fillcolor,size:12,symbol:\"rect\"===R.type?\"square\":\"circle\"===R.type?\"circle\":\"hexagon2\"}};z.push([{trace:F}])}}S=d.showlegend&&v(z,f,d._legends.length>1)}var B=d.hiddenlabels||[];if(!(T||d.showlegend&&S.length))return s.selectAll(\".\"+w).remove(),d._topdefs.select(\"#\"+r).remove(),a.autoMargin(t,w);var N=i.ensureSingle(s,\"g\",w,(function(t){T||t.attr(\"pointer-events\",\"all\")})),j=i.ensureSingleById(d._topdefs,\"clipPath\",r,(function(t){t.append(\"rect\")})),U=i.ensureSingle(N,\"rect\",\"bg\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));U.call(u.stroke,f.bordercolor).call(u.fill,f.bgcolor).style(\"stroke-width\",f.borderwidth+\"px\");var V,q=i.ensureSingle(N,\"g\",\"scrollbox\"),H=f.title;f._titleWidth=0,f._titleHeight=0,H.text?((V=i.ensureSingle(q,\"text\",w+\"titletext\")).attr(\"text-anchor\",\"start\").call(c.font,H.font).text(H.text),C(V,q,t,f,b)):q.selectAll(\".\"+w+\"titletext\").remove();var G=i.ensureSingle(N,\"rect\",\"scrollbar\",(function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)})),Z=q.selectAll(\"g.groups\").data(S);Z.enter().append(\"g\").attr(\"class\",\"groups\"),Z.exit().remove();var W=Z.selectAll(\"g.traces\").data(i.identity);W.enter().append(\"g\").attr(\"class\",\"traces\"),W.exit().remove(),W.style(\"opacity\",(function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==B.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1})).each((function(){n.select(this).call(M,t,f)})).call(x,t,f).each((function(){T||n.select(this).call(E,t,w)})),i.syncOrAsync([a.previousPromises,function(){return function(t,e,r,i){var a=t._fullLayout,o=P(i);i||(i=a[o]);var s=a._size,l=_.isVertical(i),u=_.isGrouped(i),h=\"fraction\"===i.entrywidthmode,f=i.borderwidth,d=2*f,m=p.itemGap,g=i.indentation+i.itemwidth+2*m,y=2*(f+m),v=I(i),x=i.y<0||0===i.y&&\"top\"===v,b=i.y>1||1===i.y&&\"bottom\"===v,w=i.tracegroupgap,T={};i._maxHeight=Math.max(x||b?a.height/2:s.h,30);var A=0;i._width=0,i._height=0;var M=function(t){var e=0,r=0,n=t.title.side;return n&&(-1!==n.indexOf(\"left\")&&(e=t._titleWidth),-1!==n.indexOf(\"top\")&&(r=t._titleHeight)),[e,r]}(i);if(l)r.each((function(t){var e=t[0].height;c.setTranslate(this,f+M[0],f+M[1]+i._height+e/2+m),i._height+=e,i._width=Math.max(i._width,t[0].width)})),A=g+i._width,i._width+=m+g+d,i._height+=y,u&&(e.each((function(t,e){c.setTranslate(this,0,e*i.tracegroupgap)})),i._height+=(i._lgroupsLength-1)*i.tracegroupgap);else{var S=L(i),E=i.x<0||0===i.x&&\"right\"===S,C=i.x>1||1===i.x&&\"left\"===S,z=b||x,O=a.width/2;i._maxWidth=Math.max(E?z&&\"left\"===S?s.l+s.w:O:C?z&&\"right\"===S?s.r+s.w:O:s.w,2*g);var D=0,R=0;r.each((function(t){var e=k(t,i,g);D=Math.max(D,e),R+=e})),A=null;var F=0;if(u){var B=0,N=0,j=0;e.each((function(){var t=0,e=0;n.select(this).selectAll(\"g.traces\").each((function(r){var n=k(r,i,g),a=r[0].height;c.setTranslate(this,M[0],M[1]+f+m+a/2+e),e+=a,t=Math.max(t,n),T[r[0].trace.legendgroup]=t}));var r=t+m;N>0&&r+f+N>i._maxWidth?(F=Math.max(F,N),N=0,j+=B+w,B=e):B=Math.max(B,e),c.setTranslate(this,N,j),N+=r})),i._width=Math.max(F,N)+f,i._height=j+B+y}else{var U=r.size(),V=R+d+(U-1)*m<i._maxWidth,q=0,H=0,G=0,Z=0;r.each((function(t){var e=t[0].height,r=k(t,i,g),n=V?r:D;h||(n+=m),n+f+H-m>=i._maxWidth&&(F=Math.max(F,Z),H=0,G+=q,i._height+=q,q=0),c.setTranslate(this,M[0]+f+H,M[1]+f+G+e/2+m),Z=H+r+m,H+=n,q=Math.max(q,e)})),V?(i._width=H+d,i._height=q+y):(i._width=Math.max(F,Z)+d,i._height+=q+y)}}i._width=Math.ceil(Math.max(i._width+M[0],i._titleWidth+2*(f+p.titlePad))),i._height=Math.ceil(Math.max(i._height+M[1],i._titleHeight+2*(f+p.itemGap))),i._effHeight=Math.min(i._height,i._maxHeight);var W=t._context.edits,Y=W.legendText||W.legendPosition;r.each((function(t){var e=n.select(this).select(\".\"+o+\"toggle\"),r=t[0].height,a=t[0].trace.legendgroup,s=k(t,i,g);u&&\"\"!==a&&(s=T[a]);var f=Y?g:A||s;l||h||(f+=m/2),c.setRect(e,0,-r/2,f,r)}))}(t,Z,W,f)},function(){var e,u,v,x,_=d._size,b=f.borderwidth,k=\"paper\"===f.xref,M=\"paper\"===f.yref;if(H.text&&function(t,e,r){if(\"top center\"===e.title.side||\"top right\"===e.title.side){var n=e.title.font.size*m,i=0,a=t.node(),o=c.bBox(a).width;\"top center\"===e.title.side?i=.5*(e._width-2*r-2*p.titlePad-o):\"top right\"===e.title.side&&(i=e._width-2*r-2*p.titlePad-o),h.positionText(t,r+p.titlePad+i,r+n)}}(V,f,b),!T){var S,E;S=k?_.l+_.w*f.x-g[L(f)]*f._width:d.width*f.x-g[L(f)]*f._width,E=M?_.t+_.h*(1-f.y)-g[I(f)]*f._effHeight:d.height*(1-f.y)-g[I(f)]*f._effHeight;var C=function(t,e,r,n){var i=t._fullLayout,o=i[e],s=L(o),l=I(o),c=\"paper\"===o.xref,u=\"paper\"===o.yref;t._fullLayout._reservedMargin[e]={};var h=o.y<.5?\"b\":\"t\",f=o.x<.5?\"l\":\"r\",p={r:i.width-r,l:r+o._width,b:i.height-n,t:n+o._effHeight};if(c&&u)return a.autoMargin(t,e,{x:o.x,y:o.y,l:o._width*g[s],r:o._width*y[s],b:o._effHeight*y[l],t:o._effHeight*g[l]});c?t._fullLayout._reservedMargin[e][h]=p[h]:u||\"v\"===o.orientation?t._fullLayout._reservedMargin[e][f]=p[f]:t._fullLayout._reservedMargin[e][h]=p[h]}(t,w,S,E);if(C)return;if(d.margin.autoexpand){var P=S,z=E;S=k?i.constrain(S,0,d.width-f._width):P,E=M?i.constrain(E,0,d.height-f._effHeight):z,S!==P&&i.log(\"Constrain \"+w+\".x to make legend fit inside graph\"),E!==z&&i.log(\"Constrain \"+w+\".y to make legend fit inside graph\")}c.setTranslate(N,S,E)}if(G.on(\".drag\",null),N.on(\"wheel\",null),T||f._height<=f._maxHeight||t._context.staticPlot){var O=f._effHeight;T&&(O=f._height),U.attr({width:f._width-b,height:O-b,x:b/2,y:b/2}),c.setTranslate(q,0,0),j.select(\"rect\").attr({width:f._width-2*b,height:O-2*b,x:b,y:b}),c.setClipUrl(q,r,t),c.setRect(G,0,0,0,0),delete f._scrollY}else{var D,R,F,B=Math.max(p.scrollBarMinHeight,f._effHeight*f._effHeight/f._height),Z=f._effHeight-B-2*p.scrollBarMargin,W=f._height-f._effHeight,Y=Z/W,X=Math.min(f._scrollY||0,W);U.attr({width:f._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:f._effHeight-b,x:b/2,y:b/2}),j.select(\"rect\").attr({width:f._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:f._effHeight-2*b,x:b,y:b+X}),c.setClipUrl(q,r,t),K(X,B,Y),N.on(\"wheel\",(function(){K(X=i.constrain(f._scrollY+n.event.deltaY/Z*W,0,W),B,Y),0!==X&&X!==W&&n.event.preventDefault()}));var $=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;D=\"touchstart\"===t.type?t.changedTouches[0].clientY:t.clientY,F=X})).on(\"drag\",(function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(R=\"touchmove\"===t.type?t.changedTouches[0].clientY:t.clientY,X=function(t,e,r){var n=(r-e)/Y+t;return i.constrain(n,0,W)}(F,D,R),K(X,B,Y))}));G.call($);var J=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;\"touchstart\"===t.type&&(D=t.changedTouches[0].clientY,F=X)})).on(\"drag\",(function(){var t=n.event.sourceEvent;\"touchmove\"===t.type&&(R=t.changedTouches[0].clientY,X=function(t,e,r){var n=(e-r)/Y+t;return i.constrain(n,0,W)}(F,D,R),K(X,B,Y))}));q.call(J)}function K(e,r,n){f._scrollY=t._fullLayout[w]._scrollY=e,c.setTranslate(q,0,-e),c.setRect(G,f._width,p.scrollBarMargin+e*n,p.scrollBarWidth,r),j.select(\"rect\").attr(\"y\",b+e)}t._context.edits.legendPosition&&(N.classed(\"cursor-move\",!0),l.init({element:N.node(),gd:t,prepFn:function(t){if(t.target!==G.node()){var e=c.getTranslate(N);v=e.x,x=e.y}},moveFn:function(t,r){if(void 0!==v&&void 0!==x){var n=v+t,i=x+r;c.setTranslate(N,n,i),e=l.align(n,f._width,_.l,_.l+_.w,f.xanchor),u=l.align(i+f._height,-f._height,_.t+_.h,_.t,f.yanchor)}},doneFn:function(){if(void 0!==e&&void 0!==u){var r={};r[w+\".x\"]=e,r[w+\".y\"]=u,o.call(\"_guiRelayout\",t,r)}},clickFn:function(e,r){var n=s.selectAll(\"g.traces\").filter((function(){var t=this.getBoundingClientRect();return r.clientX>=t.left&&r.clientX<=t.right&&r.clientY>=t.top&&r.clientY<=t.bottom}));n.size()>0&&A(t,N,n,e,r)}}))}],t)}}function k(t,e,r){var n=t[0],i=n.width,a=e.entrywidthmode,o=n.trace.legendwidth||e.entrywidth;return\"fraction\"===a?e._maxWidth*o:r+(o||i)}function A(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label);var c=s.triggerHandler(t,\"plotly_legendclick\",l);if(1===n){if(!1===c)return;e._clickTimeout=setTimeout((function(){t._fullLayout&&f(r,t,n)}),t._context.doubleClickDelay)}else 2===n&&(e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&!1!==c&&f(r,t,n))}function M(t,e,r){var n,a,s=P(r),l=t.data()[0][0],u=l.trace,f=o.traceIs(u,\"pie-like\"),d=!r._inHover&&e._context.edits.legendText&&!f,m=r._maxNameLength;l.groupTitle?(n=l.groupTitle.text,a=l.groupTitle.font):(a=r.font,r.entries?n=l.text:(n=f?l.label:u.name,u._meta&&(n=i.templateString(n,u._meta))));var g=i.ensureSingle(t,\"text\",s+\"text\");g.attr(\"text-anchor\",\"start\").call(c.font,a).text(d?S(n,m):n);var y=r.indentation+r.itemwidth+2*p.itemGap;h.positionText(g,y,0),d?g.call(h.makeEditable,{gd:e,text:n}).call(C,t,e,r).on(\"edit\",(function(n){this.text(S(n,m)).call(C,t,e,r);var a=l.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var c=o.getTransformIndices(a,\"groupby\"),h=c[c.length-1],f=i.keyedContainer(a,\"transforms[\"+h+\"].styles\",\"target\",\"value.name\");f.set(l.trace._group,n),s=f.constructUpdate()}else s.name=n;return a._isShape?o.call(\"_guiRelayout\",e,\"shapes[\"+u.index+\"].name\",s.name):o.call(\"_guiRestyle\",e,s,u.index)})):C(g,t,e,r)}function S(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function E(t,e,r){var a,o=e._context.doubleClickDelay,s=1,l=i.ensureSingle(t,\"rect\",r+\"toggle\",(function(t){e._context.staticPlot||t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\"),t.call(u.fill,\"rgba(0,0,0,0)\")}));e._context.staticPlot||(l.on(\"mousedown\",(function(){(a=(new Date).getTime())-e._legendMouseDownTime<o?s+=1:(s=1,e._legendMouseDownTime=a)})),l.on(\"mouseup\",(function(){if(!e._dragged&&!e._editing){var i=e._fullLayout[r];(new Date).getTime()-e._legendMouseDownTime>o&&(s=Math.max(s-1,1)),A(e,i,t,s,n.event)}})))}function C(t,e,r,n,i){n._inHover&&t.attr(\"data-notex\",!0),h.convertToTspans(t,r,(function(){!function(t,e,r,n){var i=t.data()[0][0];if(r._inHover||!i||i.trace.showlegend){var a=t.select(\"g[class*=math-group]\"),o=a.node(),s=P(r);r||(r=e._fullLayout[s]);var l,u,f=r.borderwidth,d=(n===b?r.title.font:i.groupTitle?i.groupTitle.font:r.font).size*m;if(o){var g=c.bBox(o);l=g.height,u=g.width,n===b?c.setTranslate(a,f,f+.75*l):c.setTranslate(a,0,.25*l)}else{var y=\".\"+s+(n===b?\"title\":\"\")+\"text\",v=t.select(y),x=h.lineCount(v),_=v.node();if(l=d*x,u=_?c.bBox(_).width:0,n===b)\"left\"===r.title.side&&(u+=2*p.itemGap),h.positionText(v,f+p.titlePad,f+d);else{var w=2*p.itemGap+r.indentation+r.itemwidth;i.groupTitle&&(w=p.itemGap,u-=r.indentation+r.itemwidth),h.positionText(v,w,-d*((x-1)/2-.3))}}n===b?(r._titleWidth=u,r._titleHeight=l):(i.lineHeight=d,i.height=Math.max(l,16)+3,i.width=u)}else t.remove()}(e,r,n,i)}))}function L(t){return i.isRightAnchor(t)?\"right\":i.isCenterAnchor(t)?\"center\":\"left\"}function I(t){return i.isBottomAnchor(t)?\"bottom\":i.isMiddleAnchor(t)?\"middle\":\"top\"}function P(t){return t._id||\"legend\"}t.exports=function(t,e){if(e)T(t,e);else{var r=t._fullLayout,i=r._legends;r._infolayer.selectAll('[class^=\"legend\"]').each((function(){var t=n.select(this),e=t.attr(\"class\").split(\" \")[0];e.match(w)&&-1===i.indexOf(e)&&t.remove()}));for(var a=0;a<i.length;a++){var o=i[a];T(t,t._fullLayout[o])}}}},851:function(t,e,r){\"use strict\";var n=r(33626),i=r(57599);t.exports=function(t,e,r){var a,o,s=e._inHover,l=i.isGrouped(e),c=i.isReversed(e),u={},h=[],f=!1,p={},d=0,m=0;function g(t,n,a){if(!1!==e.visible&&(!r||t===e._id))if(\"\"!==n&&i.isGrouped(e))-1===h.indexOf(n)?(h.push(n),f=!0,u[n]=[a]):u[n].push(a);else{var o=\"~~i\"+d;h.push(o),u[o]=[a],d++}}for(a=0;a<t.length;a++){var y=t[a],v=y[0],x=v.trace,_=x.legend,b=x.legendgroup;if(s||x.visible&&x.showlegend)if(n.traceIs(x,\"pie-like\"))for(p[b]||(p[b]={}),o=0;o<y.length;o++){var w=y[o].label;p[b][w]||(g(_,b,{label:w,color:y[o].color,i:y[o].i,trace:x,pts:y[o].pts}),p[b][w]=!0,m=Math.max(m,(w||\"\").length))}else g(_,b,v),m=Math.max(m,(x.name||\"\").length)}if(!h.length)return[];var T=!f||!l,k=[];for(a=0;a<h.length;a++){var A=u[h[a]];T?k.push(A[0]):k.push(A)}for(T&&(k=[k]),a=0;a<k.length;a++){var M=1/0;for(o=0;o<k[a].length;o++){var S=k[a][o].trace.legendrank;M>S&&(M=S)}k[a][0]._groupMinRank=M,k[a][0]._preGroupSort=a}var E=function(t,e){return t.trace.legendrank-e.trace.legendrank||t._preSort-e._preSort};for(k.forEach((function(t,e){t[0]._preGroupSort=e})),k.sort((function(t,e){return t[0]._groupMinRank-e[0]._groupMinRank||t[0]._preGroupSort-e[0]._preGroupSort})),a=0;a<k.length;a++){k[a].forEach((function(t,e){t._preSort=e})),k[a].sort(E);var C=k[a][0].trace,L=null;for(o=0;o<k[a].length;o++){var I=k[a][o].trace.legendgrouptitle;if(I&&I.text){L=I,s&&(I.font=e._groupTitleFont);break}}if(c&&k[a].reverse(),L){var P=!1;for(o=0;o<k[a].length;o++)if(n.traceIs(k[a][o].trace,\"pie-like\")){P=!0;break}k[a].unshift({i:-1,groupTitle:L,noClick:P,trace:{showlegend:C.showlegend,legendgroup:C.legendgroup,visible:\"toggleitem\"===e.groupclick||C.visible}})}for(o=0;o<k[a].length;o++)k[a][o]=[k[a][o]]}return e._lgroupsLength=k.length,e._maxNameLength=m,k}},22165:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=i.pushUnique,o=!0;t.exports=function(t,e,r){var s=e._fullLayout;if(!e._dragged&&!e._editing){var l,c=s.legend.itemclick,u=s.legend.itemdoubleclick,h=s.legend.groupclick;if(1===r&&\"toggle\"===c&&\"toggleothers\"===u&&o&&e.data&&e._context.showTips?(i.notifier(i._(e,\"Double-click on legend to isolate one trace\"),\"long\"),o=!1):o=!1,1===r?l=c:2===r&&(l=u),l){var f=\"togglegroup\"===h,p=s.hiddenlabels?s.hiddenlabels.slice():[],d=t.data()[0][0];if(!d.groupTitle||!d.noClick){var m=e._fullData,g=(s.shapes||[]).filter((function(t){return t.showlegend})),y=m.concat(g),v=d.trace;v._isShape&&(v=v._fullInput);var x,_,b,w,T,k=v.legendgroup,A={},M=[],S=[],E=[],C=(s.shapes||[]).map((function(t){return t._input})),L=!1,I=v.legend,P=v._fullInput;if(P&&P._isShape||!n.traceIs(v,\"pie-like\")){var z,O=k&&k.length,D=[];if(O)for(x=0;x<y.length;x++)(z=y[x]).visible&&z.legendgroup===k&&D.push(x);if(\"toggle\"===l){var R;switch(v.visible){case!0:R=\"legendonly\";break;case!1:R=!1;break;case\"legendonly\":R=!0}if(O)if(f)for(x=0;x<y.length;x++){var F=y[x];!1!==F.visible&&F.legendgroup===k&&tt(F,R)}else tt(v,R);else tt(v,R)}else if(\"toggleothers\"===l){var B,N,j,U,V=!0;for(x=0;x<y.length;x++)if(B=(U=y[x])===v,N=!0!==U.showlegend,!(B||N||O&&U.legendgroup===k||U.legend!==I||!0!==U.visible||n.traceIs(U,\"notLegendIsolatable\"))){V=!1;break}for(x=0;x<y.length;x++)if(!1!==(U=y[x]).visible&&U.legend===I&&!n.traceIs(U,\"notLegendIsolatable\"))switch(v.visible){case\"legendonly\":tt(U,!0);break;case!0:j=!!V||\"legendonly\",B=U===v,N=!0!==U.showlegend&&!U.legendgroup,tt(U,!!(B||O&&U.legendgroup===k||N)||j)}}for(x=0;x<S.length;x++)if(b=S[x]){var q=b.constructUpdate(),H=Object.keys(q);for(_=0;_<H.length;_++)w=H[_],(A[w]=A[w]||[])[E[x]]=q[w]}for(T=Object.keys(A),x=0;x<T.length;x++)for(w=T[x],_=0;_<M.length;_++)A[w].hasOwnProperty(_)||(A[w][_]=void 0);L?n.call(\"_guiUpdate\",e,A,{shapes:C},M):n.call(\"_guiRestyle\",e,A,M)}else{var G=d.label,Z=p.indexOf(G);if(\"toggle\"===l)-1===Z?p.push(G):p.splice(Z,1);else if(\"toggleothers\"===l){var W=-1!==Z,Y=[];for(x=0;x<e.calcdata.length;x++){var X=e.calcdata[x];for(_=0;_<X.length;_++){var $=X[_].label;I===X[0].trace.legend&&G!==$&&(-1===p.indexOf($)&&(W=!0),a(p,$),Y.push($))}}if(!W)for(var J=0;J<Y.length;J++){var K=p.indexOf(Y[J]);-1!==K&&p.splice(K,1)}}n.call(\"_guiRelayout\",e,\"hiddenlabels\",p)}}}}function Q(t,e){var r=M.indexOf(t),n=A.visible;return n||(n=A.visible=[]),-1===M.indexOf(t)&&(M.push(t),r=M.length-1),n[r]=e,r}function tt(t,e){if(!d.groupTitle||f){var r,a=t._fullInput||t,o=a._isShape,s=a.index;if(void 0===s&&(s=a._index),n.hasTransform(a,\"groupby\")){var l=S[s];if(!l){var c=n.getTransformIndices(a,\"groupby\"),u=c[c.length-1];l=i.keyedContainer(a,\"transforms[\"+u+\"].styles\",\"target\",\"value.visible\"),S[s]=l}var h=l.get(t._group);void 0===h&&(h=!0),!1!==h&&l.set(t._group,e),E[s]=Q(s,!1!==a.visible)}else{var p=!1!==a.visible&&e;o?(r=p,C[s].visible=r,L=!0):Q(s,p)}}}}},57599:function(t,e){\"use strict\";e.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},e.isVertical=function(t){return\"h\"!==t.orientation},e.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},82494:function(t,e,r){\"use strict\";t.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:r(86405),supplyLayoutDefaults:r(73970),draw:r(6134),style:r(14375)}},14375:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(34809),o=a.strTranslate,s=r(62203),l=r(78766),c=r(65477).extractOpts,u=r(64726),h=r(32891),f=r(37252).castOption,p=r(72783);function d(t,e){return(e?\"radial\":\"horizontal\")+(t?\"\":\"reversed\")}function m(t){var e=t[0].trace,r=e.contours,n=u.hasLines(e),i=u.hasMarkers(e),a=e.visible&&e.fill&&\"none\"!==e.fill,o=!1,s=!1;if(r){var l=r.coloring;\"lines\"===l?o=!0:n=\"none\"===l||\"heatmap\"===l||r.showlines,\"constraint\"===r.type?a=\"=\"!==r._operation:\"fill\"!==l&&\"heatmap\"!==l||(s=!0)}return{showMarker:i,showLine:n,showFill:a,showGradientLine:o,showGradientFill:s,anyLine:n||o,anyFill:a||s}}function g(t,e,r){return t&&a.isArrayOrTypedArray(t)?e:t>r?r:t}t.exports=function(t,e,r){var y=e._fullLayout;r||(r=y.legend);var v=\"constant\"===r.itemsizing,x=r.itemwidth,_=(x+2*p.itemGap)/2,b=o(_,0),w=function(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)};function T(t,a,o){var u=t[0].trace,h=u.marker||{},f=h.line||{},p=h.cornerradius?\"M6,3a3,3,0,0,1-3,3H-3a3,3,0,0,1-3-3V-3a3,3,0,0,1,3-3H3a3,3,0,0,1,3,3Z\":\"M6,6H-6V-6H6Z\",d=o?u.visible&&u.type===o:i.traceIs(u,\"bar\"),m=n.select(a).select(\"g.legendpoints\").selectAll(\"path.legend\"+o).data(d?[t]:[]);m.enter().append(\"path\").classed(\"legend\"+o,!0).attr(\"d\",p).attr(\"transform\",b),m.exit().remove(),m.each((function(t){var i=n.select(this),a=t[0],o=w(a.mlw,h.line,5,2);i.style(\"stroke-width\",o+\"px\");var p=a.mcc;if(!r._inHover&&\"mc\"in a){var d=c(h),m=d.mid;void 0===m&&(m=(d.max+d.min)/2),p=s.tryColorscale(h,\"\")(m)}var y=p||a.mc||h.color,v=h.pattern,x=v&&s.getPatternAttr(v.shape,0,\"\");if(x){var _=s.getPatternAttr(v.bgcolor,0,null),b=s.getPatternAttr(v.fgcolor,0,null),T=v.fgopacity,k=g(v.size,8,10),A=g(v.solidity,.5,1),M=\"legend-\"+u.uid;i.call(s.pattern,\"legend\",e,M,x,k,A,p,v.fillmode,_,b,T)}else i.call(l.fill,y);o&&l.stroke(i,a.mlc||f.color)}))}function k(t,r,o){var s=t[0],l=s.trace,c=o?l.visible&&l.type===o:i.traceIs(l,o),u=n.select(r).select(\"g.legendpoints\").selectAll(\"path.legend\"+o).data(c?[t]:[]);if(u.enter().append(\"path\").classed(\"legend\"+o,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",b),u.exit().remove(),u.size()){var p=l.marker||{},d=w(f(p.line.width,s.pts),p.line,5,2),m=\"pieLike\",g=a.minExtend(l,{marker:{line:{width:d}}},m),y=a.minExtend(s,{trace:g},m);h(u,y,g,e)}}t.each((function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var s=r.indentation,l=r.valign,c=t[0].lineHeight,u=t[0].height;if(\"middle\"===l&&0===s||!c||!u)i.attr(\"transform\",null);else{var h={top:1,bottom:-1}[l]*(.5*(c-u+3))||0,f=r.indentation;i.attr(\"transform\",o(f,h))}i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var p=i.selectAll(\"g.legendsymbols\").data([t]);p.enter().append(\"g\").classed(\"legendsymbols\",!0),p.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)})).each((function(t){var r,i=t[0].trace,o=[];if(i.visible)switch(i.type){case\"histogram2d\":case\"heatmap\":o=[[\"M-15,-2V4H15V-2Z\"]],r=!0;break;case\"choropleth\":case\"choroplethmapbox\":case\"choroplethmap\":o=[[\"M-6,-6V6H6V-6Z\"]],r=!0;break;case\"densitymapbox\":case\"densitymap\":o=[[\"M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0\"]],r=\"radial\";break;case\"cone\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 L6,0Z\"]],r=!1;break;case\"streamtube\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z\"]],r=!1;break;case\"surface\":o=[[\"M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z\"],[\"M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z\"]],r=!0;break;case\"mesh3d\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!1;break;case\"volume\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!0;break;case\"isosurface\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6 A12,24 0 0,0 6,-6 L0,6Z\"]],r=!1}var u=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legend3dandfriends\").data(o);u.enter().append(\"path\").classed(\"legend3dandfriends\",!0).attr(\"transform\",b).style(\"stroke-miterlimit\",1),u.exit().remove(),u.each((function(t,o){var u,h=n.select(this),f=c(i),p=f.colorscale,m=f.reversescale;if(p){if(!r){var g=p.length;u=0===o?p[m?g-1:0][1]:1===o?p[m?0:g-1][1]:p[Math.floor((g-1)/2)][1]}}else{var y=i.vertexcolor||i.facecolor||i.color;u=a.isArrayOrTypedArray(y)?y[o]||y[0]:y}h.attr(\"d\",t[0]),u?h.call(l.fill,u):h.call((function(t){if(t.size()){var n=\"legendfill-\"+i.uid;s.gradient(t,e,n,d(m,\"radial\"===r),p,\"fill\")}}))}))})).each((function(t){var e=t[0].trace,r=\"waterfall\"===e.type;if(t[0]._distinct&&r){var i=t[0].trace[t[0].dir].marker;return t[0].mc=i.color,t[0].mlw=i.line.width,t[0].mlc=i.line.color,T(t,this,\"waterfall\")}var a=[];e.visible&&r&&(a=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(a);o.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",b).style(\"stroke-miterlimit\",1),o.exit().remove(),o.each((function(t){var r=n.select(this),i=e[t[0]].marker,a=w(void 0,i.line,5,2);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(l.fill,i.color),a&&r.call(l.stroke,i.line.color)}))})).each((function(t){T(t,this,\"funnel\")})).each((function(t){T(t,this)})).each((function(t){var r=t[0].trace,o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(r.visible&&i.traceIs(r,\"box-violin\")?[t]:[]);o.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",b),o.exit().remove(),o.each((function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==l.opacity(r.fillcolor)||0!==l.opacity((r.line||{}).color)){var i=w(void 0,r.line,5,2);t.style(\"stroke-width\",i+\"px\").call(l.fill,r.fillcolor),i&&l.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?12:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});o.call(s.pointStyle,c,e)}}))})).each((function(t){k(t,this,\"funnelarea\")})).each((function(t){k(t,this,\"pie\")})).each((function(t){var r,i,o=m(t),l=o.showFill,h=o.showLine,f=o.showGradientLine,p=o.showGradientFill,g=o.anyFill,y=o.anyLine,v=t[0],_=v.trace,b=c(_),T=b.colorscale,k=b.reversescale,A=u.hasMarkers(_)||!g?\"M5,0\":y?\"M5,-2\":\"M5,-3\",M=n.select(this),S=M.select(\".legendfill\").selectAll(\"path\").data(l||p?[t]:[]);if(S.enter().append(\"path\").classed(\"js-fill\",!0),S.exit().remove(),S.attr(\"d\",A+\"h\"+x+\"v6h-\"+x+\"z\").call((function(t){if(t.size())if(l)s.fillGroupStyle(t,e,!0);else{var r=\"legendfill-\"+_.uid;s.gradient(t,e,r,d(k),T,\"fill\")}})),h||f){var E=w(void 0,_.line,10,5);i=a.minExtend(_,{line:{width:E}}),r=[a.minExtend(v,{trace:i})]}var C=M.select(\".legendlines\").selectAll(\"path\").data(h||f?[r]:[]);C.enter().append(\"path\").classed(\"js-line\",!0),C.exit().remove(),C.attr(\"d\",A+(f?\"l\"+x+\",0.0001\":\"h\"+x)).call(h?s.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+_.uid;s.lineGroupStyle(t),s.gradient(t,e,r,d(k),T,\"stroke\")}})})).each((function(t){var r,i,o=m(t),l=o.anyFill,c=o.anyLine,h=o.showLine,f=o.showMarker,p=t[0],d=p.trace,g=!f&&!c&&!l&&u.hasText(d);function y(t,e,r,n){var i=a.nestedProperty(d,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function x(t){return p._distinct&&p.index&&t[p.index]?t[p.index]:t[0]}if(f||g||h){var _={},w={};if(f){_.mc=y(\"marker.color\",x),_.mx=y(\"marker.symbol\",x),_.mo=y(\"marker.opacity\",a.mean,[.2,1]),_.mlc=y(\"marker.line.color\",x),_.mlw=y(\"marker.line.width\",a.mean,[0,5],2),w.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var T=y(\"marker.size\",a.mean,[2,16],12);_.ms=T,w.marker.size=T}h&&(w.line={width:y(\"line.width\",x,[0,10],5)}),g&&(_.tx=\"Aa\",_.tp=y(\"textposition\",x),_.ts=10,_.tc=y(\"textfont.color\",x),_.tf=y(\"textfont.family\",x),_.tw=y(\"textfont.weight\",x),_.ty=y(\"textfont.style\",x),_.tv=y(\"textfont.variant\",x),_.tC=y(\"textfont.textcase\",x),_.tE=y(\"textfont.lineposition\",x),_.tS=y(\"textfont.shadow\",x)),r=[a.minExtend(p,_)],(i=a.minExtend(d,w)).selectedpoints=null,i.texttemplate=null}var k=n.select(this).select(\"g.legendpoints\"),A=k.selectAll(\"path.scatterpts\").data(f?r:[]);A.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",b),A.exit().remove(),A.call(s.pointStyle,i,e),f&&(r[0].mrc=3);var M=k.selectAll(\"g.pointtext\").data(g?r:[]);M.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",b),M.exit().remove(),M.selectAll(\"text\").call(s.textPointStyle,i,e)})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(e.visible&&\"candlestick\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"})).attr(\"transform\",b).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=w(void 0,a.line,5,2);i.style(\"stroke-width\",o+\"px\").call(l.fill,a.fillcolor),o&&l.stroke(i,a.line.color)}))})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(e.visible&&\"ohlc\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"})).attr(\"transform\",b).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=w(void 0,a.line,5,2);i.style(\"fill\",\"none\").call(s.dashLine,a.line.dash,o),o&&l.stroke(i,a.line.color)}))}))}},50308:function(t,e,r){\"use strict\";r(87632),t.exports={editType:\"modebar\",orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},add:{valType:\"string\",arrayOk:!0,dflt:\"\",editType:\"modebar\"},remove:{valType:\"string\",arrayOk:!0,dflt:\"\",editType:\"modebar\"}}},5832:function(t,e,r){\"use strict\";var n=r(33626),i=r(44122),a=r(5975),o=r(35188),s=r(28231).eraseActiveShape,l=r(34809),c=l._,u=t.exports={};function h(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=c._cartesianSpikesEnabled;if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,m=(1+d)/2,g=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l)void 0===r._rangeInitial0&&void 0===r._rangeInitial1?u[p+\".autorange\"]=!0:void 0===r._rangeInitial0?(u[p+\".autorange\"]=r._autorangeInitial,u[p+\".range\"]=[null,r._rangeInitial1]):void 0===r._rangeInitial1?(u[p+\".range\"]=[r._rangeInitial0,null],u[p+\".autorange\"]=r._autorangeInitial):u[p+\".range\"]=[r._rangeInitial0,r._rangeInitial1],void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"));else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],v=[m*y[0]+g*y[1],m*y[1]+g*y[0]];u[p+\".range[0]\"]=r.l2r(v[0]),u[p+\".range[1]\"]=r.l2r(v[1])}}else\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l||(l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l)),u[s]=l;c._cartesianSpikesEnabled=f,n.call(\"_guiRelayout\",t,u)}function f(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function p(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=\"resetLastSave\"===r,a=\"resetDefault\"===r,o=t._fullLayout,s=o._subplots.gl3d||[],l={},c=0;c<s.length;c++){var u,h=s[c],f=h+\".camera\",p=h+\".aspectratio\",d=h+\".aspectmode\",m=o[h]._scene;i?(l[f+\".up\"]=m.viewInitial.up,l[f+\".eye\"]=m.viewInitial.eye,l[f+\".center\"]=m.viewInitial.center,u=!0):a&&(l[f+\".up\"]=null,l[f+\".eye\"]=null,l[f+\".center\"]=null,u=!0),u&&(l[p+\".x\"]=m.viewInitial.aspectratio.x,l[p+\".y\"]=m.viewInitial.aspectratio.y,l[p+\".z\"]=m.viewInitial.aspectratio.z,l[d]=m.viewInitial.aspectmode)}n.call(\"_guiRelayout\",t,l)}function d(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d||[],o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],m=u+\".\"+d+\".showspikes\";l[m]=!1,s[m]=h[d].showspikes}}r._previousVal=s}return l}function m(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}}\"reset\"===i&&b(t,\"geo\")}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function y(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function v(t,e){_(t,e,\"mapbox\")}function x(t,e){_(t,e,\"map\")}function _(t,e,r){for(var i=e.currentTarget.getAttribute(\"data-val\"),a=t._fullLayout,o=a._subplots[r]||[],s={},l=0;l<o.length;l++){var c=o[l],u=a[c].zoom,h=\"in\"===i?1.05*u:u/1.05;s[c+\".zoom\"]=h}n.call(\"_guiRelayout\",t,s)}function b(t,e){for(var r=t._fullLayout,i=r._subplots[e]||[],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}u.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return c(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:o.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};l.notifier(c(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&l.isIE()&&(l.notifier(c(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach((function(t){t in e&&(r[t]=e[t])})),n.call(\"downloadImage\",t,r).then((function(e){l.notifier(c(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")})).catch((function(){l.notifier(c(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")}))}},u.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.disk,click:function(t){i.sendDataToCloud(t)}},u.editInChartStudio={name:\"editInChartStudio\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.pencil,click:function(t){i.sendDataToCloud(t)}},u.zoom2d={name:\"zoom2d\",_cat:\"zoom\",title:function(t){return c(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:o.zoombox,click:h},u.pan2d={name:\"pan2d\",_cat:\"pan\",title:function(t){return c(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:o.pan,click:h},u.select2d={name:\"select2d\",_cat:\"select\",title:function(t){return c(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:o.selectbox,click:h},u.lasso2d={name:\"lasso2d\",_cat:\"lasso\",title:function(t){return c(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:o.lasso,click:h},u.drawclosedpath={name:\"drawclosedpath\",title:function(t){return c(t,\"Draw closed freeform\")},attr:\"dragmode\",val:\"drawclosedpath\",icon:o.drawclosedpath,click:h},u.drawopenpath={name:\"drawopenpath\",title:function(t){return c(t,\"Draw open freeform\")},attr:\"dragmode\",val:\"drawopenpath\",icon:o.drawopenpath,click:h},u.drawline={name:\"drawline\",title:function(t){return c(t,\"Draw line\")},attr:\"dragmode\",val:\"drawline\",icon:o.drawline,click:h},u.drawrect={name:\"drawrect\",title:function(t){return c(t,\"Draw rectangle\")},attr:\"dragmode\",val:\"drawrect\",icon:o.drawrect,click:h},u.drawcircle={name:\"drawcircle\",title:function(t){return c(t,\"Draw circle\")},attr:\"dragmode\",val:\"drawcircle\",icon:o.drawcircle,click:h},u.eraseshape={name:\"eraseshape\",title:function(t){return c(t,\"Erase active shape\")},icon:o.eraseshape,click:s},u.zoomIn2d={name:\"zoomIn2d\",_cat:\"zoomin\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:h},u.zoomOut2d={name:\"zoomOut2d\",_cat:\"zoomout\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:h},u.autoScale2d={name:\"autoScale2d\",_cat:\"autoscale\",title:function(t){return c(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:o.autoscale,click:h},u.resetScale2d={name:\"resetScale2d\",_cat:\"resetscale\",title:function(t){return c(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:o.home,click:h},u.hoverClosestCartesian={name:\"hoverClosestCartesian\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:h},u.hoverCompareCartesian={name:\"hoverCompareCartesian\",_cat:\"hoverCompare\",title:function(t){return c(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:o.tooltip_compare,gravity:\"ne\",click:h},u.zoom3d={name:\"zoom3d\",_cat:\"zoom\",title:function(t){return c(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:o.zoombox,click:f},u.pan3d={name:\"pan3d\",_cat:\"pan\",title:function(t){return c(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:o.pan,click:f},u.orbitRotation={name:\"orbitRotation\",title:function(t){return c(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:o[\"3d_rotate\"],click:f},u.tableRotation={name:\"tableRotation\",title:function(t){return c(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:o[\"z-axis\"],click:f},u.resetCameraDefault3d={name:\"resetCameraDefault3d\",_cat:\"resetCameraDefault\",title:function(t){return c(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:o.home,click:p},u.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",_cat:\"resetCameraLastSave\",title:function(t){return c(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:o.movie,click:p},u.hoverClosest3d={name:\"hoverClosest3d\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);n.call(\"_guiRelayout\",t,r)}},u.zoomInGeo={name:\"zoomInGeo\",_cat:\"zoomin\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:m},u.zoomOutGeo={name:\"zoomOutGeo\",_cat:\"zoomout\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:m},u.resetGeo={name:\"resetGeo\",_cat:\"reset\",title:function(t){return c(t,\"Reset\")},attr:\"reset\",val:null,icon:o.autoscale,click:m},u.hoverClosestGeo={name:\"hoverClosestGeo\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:y},u.hoverClosestGl2d={name:\"hoverClosestGl2d\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:y},u.hoverClosestPie={name:\"hoverClosestPie\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:y},u.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return c(t,\"Reset view\")},icon:o.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},u.toggleHover={name:\"toggleHover\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},u.resetViews={name:\"resetViews\",title:function(t){return c(t,\"Reset views\")},icon:o.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),h(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),p(t,e),b(t,\"geo\"),b(t,\"mapbox\"),b(t,\"map\")}},u.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return c(t,\"Toggle Spike Lines\")},icon:o.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled=\"on\"===r?\"off\":\"on\",n.call(\"_guiRelayout\",t,function(t){for(var e=\"on\"===t._fullLayout._cartesianSpikesEnabled,r=a.list(t,null,!0),n={},i=0;i<r.length;i++){var o=r[i];n[o._name+\".showspikes\"]=!!e||o._showSpikeInitial}return n}(t))}},u.resetViewMapbox={name:\"resetViewMapbox\",_cat:\"resetView\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){b(t,\"mapbox\")}},u.resetViewMap={name:\"resetViewMap\",_cat:\"resetView\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){b(t,\"map\")}},u.zoomInMapbox={name:\"zoomInMapbox\",_cat:\"zoomin\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:v},u.zoomInMap={name:\"zoomInMap\",_cat:\"zoomin\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:x},u.zoomOutMapbox={name:\"zoomOutMapbox\",_cat:\"zoomout\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:v},u.zoomOutMap={name:\"zoomOutMap\",_cat:\"zoomout\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:x}},87632:function(t,e,r){\"use strict\";var n=r(5832),i=Object.keys(n),a=[\"drawline\",\"drawopenpath\",\"drawclosedpath\",\"drawcircle\",\"drawrect\",\"eraseshape\"],o=[\"v1hovermode\",\"hoverclosest\",\"hovercompare\",\"togglehover\",\"togglespikelines\"].concat(a),s=[];i.forEach((function(t){!function(t){if(-1===o.indexOf(t._cat||t.name)){var e=t.name,r=(t._cat||t.name).toLowerCase();-1===s.indexOf(e)&&s.push(e),-1===s.indexOf(r)&&s.push(r)}}(n[t])})),s.sort(),t.exports={DRAW_MODES:a,backButtons:o,foreButtons:s}},17683:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(78032),o=r(50308);t.exports=function(t,e){var r=t.modebar||{},s=a.newContainer(e,\"modebar\");function l(t,e){return n.coerce(r,s,o,t,e)}l(\"orientation\"),l(\"bgcolor\",i.addOpacity(e.paper_bgcolor,.5));var c=i.contrast(i.rgb(e.modebar.bgcolor));l(\"color\",i.addOpacity(c,.3)),l(\"activecolor\",i.addOpacity(c,.7)),l(\"uirevision\",e.uirevision),l(\"add\"),l(\"remove\")}},95433:function(t,e,r){\"use strict\";t.exports={moduleType:\"component\",name:\"modebar\",layoutAttributes:r(50308),supplyLayoutDefaults:r(17683),manage:r(75442)}},75442:function(t,e,r){\"use strict\";var n=r(5975),i=r(64726),a=r(33626),o=r(36040).isUnifiedHover,s=r(85393),l=r(5832),c=r(87632).DRAW_MODES,u=r(34809).extendDeep;t.exports=function(t){var e=t._fullLayout,r=t._context,h=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var f,p=r.modeBarButtons;f=Array.isArray(p)&&p.length?function(t){for(var e=u([],t),r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var a=n[i];if(\"string\"==typeof a){if(void 0===l[a])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));e[r][i]=l[a]}}return e}(p):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context;function u(t,e){if(\"string\"==typeof e){if(e.toLowerCase()===t.toLowerCase())return!0}else{var r=e.name,n=e._cat||e.name;if(r===t||n===t.toLowerCase())return!0}return!1}var h=e.modebar.add;\"string\"==typeof h&&(h=[h]);var f=e.modebar.remove;\"string\"==typeof f&&(f=[f]);var p=s.modeBarButtonsToAdd.concat(h.filter((function(t){for(var e=0;e<s.modeBarButtonsToRemove.length;e++)if(u(t,s.modeBarButtonsToRemove[e]))return!1;return!0}))),d=s.modeBarButtonsToRemove.concat(f.filter((function(t){for(var e=0;e<s.modeBarButtonsToAdd.length;e++)if(u(t,s.modeBarButtonsToAdd[e]))return!1;return!0}))),m=e._has(\"cartesian\"),g=e._has(\"gl3d\"),y=e._has(\"geo\"),v=e._has(\"pie\"),x=e._has(\"funnelarea\"),_=e._has(\"gl2d\"),b=e._has(\"ternary\"),w=e._has(\"mapbox\"),T=e._has(\"map\"),k=e._has(\"polar\"),A=e._has(\"smith\"),M=e._has(\"sankey\"),S=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),E=o(e.hovermode),C=[];function L(t){if(t.length){for(var e=[],r=0;r<t.length;r++){for(var n=t[r],i=l[n],a=i.name.toLowerCase(),o=(i._cat||i.name).toLowerCase(),s=!1,c=0;c<d.length;c++){var u=d[c].toLowerCase();if(u===a||u===o){s=!0;break}}s||e.push(l[n])}C.push(e)}}var I=[\"toImage\"];s.showEditInChartStudio?I.push(\"editInChartStudio\"):s.showSendToCloud&&I.push(\"sendDataToCloud\"),L(I);var P=[],z=[],O=[],D=[];(m||_||v||x||b)+y+g+w+T+k+A>1?(z=[\"toggleHover\"],O=[\"resetViews\"]):y?(P=[\"zoomInGeo\",\"zoomOutGeo\"],z=[\"hoverClosestGeo\"],O=[\"resetGeo\"]):g?(z=[\"hoverClosest3d\"],O=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):w?(P=[\"zoomInMapbox\",\"zoomOutMapbox\"],z=[\"toggleHover\"],O=[\"resetViewMapbox\"]):T?(P=[\"zoomInMap\",\"zoomOutMap\"],z=[\"toggleHover\"],O=[\"resetViewMap\"]):_?z=[\"hoverClosestGl2d\"]:v?z=[\"hoverClosestPie\"]:M?(z=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],O=[\"resetViewSankey\"]):z=[\"toggleHover\"],m&&z.push(\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"),(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0}(r)||E)&&(z=[]),!m&&!_||S||(P=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==O[0]&&(O=[\"resetScale2d\"])),g?D=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(m||_)&&!S||b?D=[\"zoom2d\",\"pan2d\"]:w||T||y?D=[\"pan2d\"]:k&&(D=[\"zoom2d\"]),function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e}(r)&&D.push(\"select2d\",\"lasso2d\");var R=[],F=function(t){-1===R.indexOf(t)&&-1!==z.indexOf(t)&&R.push(t)};if(Array.isArray(p)){for(var B=[],N=0;N<p.length;N++){var j=p[N];\"string\"==typeof j?(j=j.toLowerCase(),-1!==c.indexOf(j)?(e._has(\"mapbox\")||e._has(\"map\")||e._has(\"cartesian\"))&&D.push(j):\"togglespikelines\"===j?F(\"toggleSpikelines\"):\"togglehover\"===j?F(\"toggleHover\"):\"hovercompare\"===j?F(\"hoverCompareCartesian\"):\"hoverclosest\"===j?(F(\"hoverClosestCartesian\"),F(\"hoverClosestGeo\"),F(\"hoverClosest3d\"),F(\"hoverClosestGl2d\"),F(\"hoverClosestPie\")):\"v1hovermode\"===j&&(F(\"hoverClosestCartesian\"),F(\"hoverCompareCartesian\"),F(\"hoverClosestGeo\"),F(\"hoverClosest3d\"),F(\"hoverClosestGl2d\"),F(\"hoverClosestPie\"))):B.push(j)}p=B}return L(D),L(P.concat(O)),L(R),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(C,p)}(t),h?h.update(t,f):e._modeBar=s(t,f)}else h&&(h.destroy(),delete e._modeBar)}},85393:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(34809),o=r(35188),s=r(29697).version,l=new DOMParser;function c(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var u=c.prototype;u.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},u.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach((function(t){var r=e.createGroup();t.forEach((function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)})),e.element.appendChild(r)}))},u.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},u.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",(function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)})),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},u.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}return t.svg&&(e=l.parseFromString(t.svg,\"application/xml\").childNodes[0]),e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},u.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach((function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}}))},u.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},u.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plotly.com/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly.js\")+\" (v\"+s+\")\"),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},u.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},u.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},t.exports=function(t,e){var r=t._fullLayout,i=new c({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},91032:function(t,e,r){\"use strict\";var n=r(80337),i=r(10229),a=(0,r(78032).templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});t.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},68508:function(t){\"use strict\";t.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},86255:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(78032),o=r(59008),s=r(91032),l=r(68508);function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}t.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var m=function(t,e,r){for(var n=r.filter((function(r){return e[r].anchor===t._id})),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",m[0]),d(\"y\",m[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var g=d(\"bgcolor\");d(\"activecolor\",i.contrast(g,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},45431:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(44122),o=r(78766),s=r(62203),l=r(34809),c=l.strTranslate,u=r(30635),h=r(5975),f=r(4530),p=f.LINE_SPACING,d=f.FROM_TL,m=f.FROM_BR,g=r(68508),y=r(16383);function v(t){return t._id}function x(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function _(t,e,r,n){var i,a;l.ensureSingle(t,\"text\",\"selector-text\",(function(t){t.attr(\"text-anchor\",\"middle\")})).call(s.font,e.font).text((i=r,a=n._fullLayout._meta,i.label?a?l.templateString(i.label,a):i.label:\"all\"===i.step?\"all\":i.count+i.step.charAt(0))).call((function(t){u.convertToTspans(t,n)}))}t.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=h.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),v);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each((function(e){var r=n.select(this),o=e,h=o.rangeselector,f=r.selectAll(\"g.button\").data(l.filterVisible(h.buttons));f.enter().append(\"g\").classed(\"button\",!0),f.exit().remove(),f.each((function(e){var r=n.select(this),a=y(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(x,h,e),r.call(_,h,e,t),r.on(\"click\",(function(){t._dragged||i.call(\"_guiRelayout\",t,a)})),r.on(\"mouseover\",(function(){e._isHovered=!0,r.call(x,h,e)})),r.on(\"mouseout\",(function(){e._isHovered=!1,r.call(x,h,e)}))})),function(t,e,r,i,o){var h=0,f=0,y=r.borderwidth;e.each((function(){var t=n.select(this).select(\".selector-text\"),e=r.font.size*p,i=Math.max(e*u.lineCount(t),16)+3;f=Math.max(f,i)})),e.each((function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*p,l=u.lineCount(i),d=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",c(y+h,y)),e.attr({x:0,y:0,width:d,height:f}),u.positionText(i,d/2,f/2-(l-1)*o/2+3),h+=d+5}));var v=t._fullLayout._size,x=v.l+v.w*r.x,_=v.t+v.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(x-=h,b=\"right\"),l.isCenterAnchor(r)&&(x-=h/2,b=\"center\");var w=\"top\";l.isBottomAnchor(r)&&(_-=f,w=\"bottom\"),l.isMiddleAnchor(r)&&(_-=f/2,w=\"middle\"),h=Math.ceil(h),f=Math.ceil(f),x=Math.round(x),_=Math.round(_),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:h*d[b],r:h*m[b],b:f*m[w],t:f*d[w]}),o.attr(\"transform\",c(x,_))}(t,f,h,o._name,r)}))}},16383:function(t,e,r){\"use strict\";var n=r(50936),i=r(34809).titleCase;t.exports=function(t,e){var r=t._name,a={};if(\"all\"===e.step)a[r+\".autorange\"]=!0;else{var o=function(t,e){var r,a=t.range,o=new Date(t.r2l(a[1])),s=e.step,l=n[\"utc\"+i(s)],c=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+l.offset(o,-c));break;case\"todate\":var u=l.offset(o,-c);r=t.l2r(+l.ceil(u))}return[r,a[1]]}(t,e);a[r+\".range[0]\"]=o[0],a[r+\".range[1]\"]=o[1]}return a}},44453:function(t,e,r){\"use strict\";t.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:r(91032)}}},layoutAttributes:r(91032),handleDefaults:r(86255),draw:r(45431)}},63608:function(t,e,r){\"use strict\";var n=r(10229);t.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},46223:function(t,e,r){\"use strict\";var n=r(5975).list,i=r(32919).getAutoRange,a=r(20604);t.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},20604:function(t){\"use strict\";t.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},41295:function(t,e,r){\"use strict\";var n=r(34809),i=r(78032),a=r(5975),o=r(63608),s=r(66249);t.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(b(\"visible\")){b(\"bgcolor\",e.plot_bgcolor),b(\"bordercolor\"),b(\"borderwidth\"),b(\"thickness\"),b(\"autorange\",!c.isValidRange(f.range)),b(\"range\");var d=e._subplots;if(d)for(var m=d.cartesian.filter((function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)})).map((function(t){return t.substr(t.indexOf(\"y\"),t.length)})),g=n.simpleMap(m,a.id2name),y=0;y<g.length;y++){var v=g[y];u=f[v]||{},h=i.newContainer(p,v,\"yaxis\");var x,_=e[v];u.range&&_.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",_.range.slice())}p._input=f}}function b(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},88887:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(44122),o=r(34809),s=o.strTranslate,l=r(62203),c=r(78766),u=r(17240),h=r(37703),f=r(5975),p=r(14751),d=r(27983),m=r(20604);function g(t){return\"number\"==typeof t.clientX?t.clientX:t.touches&&t.touches.length>0?t.touches[0].clientX:0}function y(t,e,r,n){var i=o.ensureSingle(t,\"rect\",m.bgClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,u=-n._offsetShift,h=l.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:s(u,u),\"stroke-width\":h}).call(c.stroke,n.bordercolor).call(c.fill,n.bgcolor)}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,(function(t){t.append(\"rect\").attr({x:0,y:0})})).select(\"rect\").attr({width:n._width,height:n._height})}function x(t,e,r,i){var s,c=e.calcdata,u=t.selectAll(\"g.\"+m.rangePlotClassName).data(r._subplotsWith,o.identity);u.enter().append(\"g\").attr(\"class\",(function(t){return m.rangePlotClassName+\" \"+t})).call(l.setClipUrl,i._clipId,e),u.order(),u.exit().remove(),u.each((function(t,o){var l=n.select(this),u=0===o,p=f.getFromId(e,t,\"y\"),d=p._name,m=i[d],g={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(g.layout.xaxis.rangebreaks=r.rangebreaks),g.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==m.rangemode?m.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(g.layout[d].rangebreaks=p.rangebreaks),a.supplyDefaults(g);var y=g._fullLayout.xaxis,v=g._fullLayout[d];y.clearCalc(),y.setScale(),v.clearCalc(),v.setScale();var x={id:t,plotgroup:l,xaxis:y,yaxis:v,isRangePlot:!0};u?s=x:(x.mainplot=\"xy\",x.mainplotinfo=s),h.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))}))}function _(t,e,r,n,i){o.ensureSingle(t,\"rect\",m.maskMinClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,m.maskColor),o.ensureSingle(t,\"rect\",m.maskMaxClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,m.maskColor),\"match\"!==i.rangemode&&(o.ensureSingle(t,\"rect\",m.maskMinOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).call(c.fill,m.maskOppAxisColor),o.ensureSingle(t,\"rect\",m.maskMaxOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).style(\"border-top\",m.maskOppBorder).call(c.fill,m.maskOppAxisColor))}function b(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",m.slideBoxClassName,(function(t){t.attr({y:0,cursor:m.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})})).attr({height:n._height,fill:m.slideBoxFill})}function w(t,e,r,n){var i=o.ensureSingle(t,\"g\",m.grabberMinClassName),a=o.ensureSingle(t,\"g\",m.grabberMaxClassName),s={x:0,width:m.handleWidth,rx:m.handleRadius,fill:c.background,stroke:c.defaultLine,\"stroke-width\":m.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},l={y:Math.round(n._height/4),height:Math.round(n._height/2)};o.ensureSingle(i,\"rect\",m.handleMinClassName,(function(t){t.attr(s)})).attr(l),o.ensureSingle(a,\"rect\",m.handleMaxClassName,(function(t){t.attr(s)})).attr(l);var u={width:m.grabAreaWidth,x:0,y:0,fill:m.grabAreaFill,cursor:e._context.staticPlot?void 0:m.grabAreaCursor};o.ensureSingle(i,\"rect\",m.grabAreaMinClassName,(function(t){t.attr(u)})).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",m.grabAreaMaxClassName,(function(t){t.attr(u)})).attr(\"height\",n._height)}t.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var l=r[a][m.name];l._clipId=l._id+\"-\"+e._uid}var c=e._infolayer.selectAll(\"g.\"+m.containerClassName).data(r,(function(t){return t._name}));c.exit().each((function(t){var r=t[m.name];e._topdefs.select(\"#\"+r._clipId).remove()})).remove(),0!==r.length&&(c.enter().append(\"g\").classed(m.containerClassName,!0).attr(\"pointer-events\",\"all\"),c.each((function(r){var a=n.select(this),l=r[m.name],c=e[f.id2name(r.anchor)],h=l[f.id2name(r.anchor)];if(l.range){var T,k=o.simpleMap(l.range,r.r2l),A=o.simpleMap(r.range,r.r2l);T=A[0]<A[1]?[Math.min(k[0],A[0]),Math.max(k[1],A[1])]:[Math.max(k[0],A[0]),Math.min(k[1],A[1])],l.range=l._input.range=o.simpleMap(T,r.l2r)}r.cleanRange(\"rangeslider.range\");var M=e._size,S=r.domain;l._width=M.w*(S[1]-S[0]);var E=Math.round(M.l+M.w*S[0]),C=Math.round(M.t+M.h*(1-r._counterDomainMin)+(\"bottom\"===r.side?r._depth:0)+l._offsetShift+m.extraPad);a.attr(\"transform\",s(E,C)),l._rl=o.simpleMap(l.range,r.r2l);var L=l._rl[0],I=l._rl[1],P=I-L;if(l.p2d=function(t){return t/l._width*P+L},l.d2p=function(t){return(t-L)/P*l._width},r.rangebreaks){var z=r.locateBreaks(L,I);if(z.length){var O,D,R=0;for(O=0;O<z.length;O++)R+=(D=z[O]).max-D.min;var F=l._width/(I-L-R),B=[-F*L];for(O=0;O<z.length;O++)D=z[O],B.push(B[B.length-1]-F*(D.max-D.min));for(l.d2p=function(t){for(var e=B[0],r=0;r<z.length;r++){var n=z[r];if(t>=n.max)e=B[r+1];else if(t<n.min)break}return e+F*t},O=0;O<z.length;O++)(D=z[O]).pmin=l.d2p(D.min),D.pmax=l.d2p(D.max);l.p2d=function(t){for(var e=B[0],r=0;r<z.length;r++){var n=z[r];if(t>=n.pmax)e=B[r+1];else if(t<n.pmin)break}return(t-e)/F}}}if(\"match\"!==h.rangemode){var N=c.r2l(h.range[0]),j=c.r2l(h.range[1])-N;l.d2pOppAxis=function(t){return(t-N)/j*l._height}}a.call(y,t,r,l).call(v,t,r,l).call(x,t,r,l).call(_,t,r,l,h).call(b,t,r,l).call(w,t,r,l),function(t,e,r,a){if(!e._context.staticPlot){var s=t.select(\"rect.\"+m.slideBoxClassName).node(),l=t.select(\"rect.\"+m.grabAreaMinClassName).node(),c=t.select(\"rect.\"+m.grabAreaMaxClassName).node();t.on(\"mousedown\",u),t.on(\"touchstart\",u)}function u(){var u=n.event,h=u.target,f=g(u),m=f-t.node().getBoundingClientRect().left,y=a.d2p(r._rl[0]),v=a.d2p(r._rl[1]),x=p.coverSlip();function _(t){var u,p,_,b=+g(t)-f;switch(h){case s:if(_=\"ew-resize\",y+b>r._length||v+b<0)return;u=y+b,p=v+b;break;case l:if(_=\"col-resize\",y+b>r._length)return;u=y+b,p=v;break;case c:if(_=\"col-resize\",v+b<0)return;u=y,p=v+b;break;default:_=\"ew-resize\",u=m,p=m+b}if(p<u){var w=p;p=u,u=w}a._pixelMin=u,a._pixelMax=p,d(n.select(x),_),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame((function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])}))}(0,e,r,a)}function b(){x.removeEventListener(\"mousemove\",_),x.removeEventListener(\"mouseup\",b),this.removeEventListener(\"touchmove\",_),this.removeEventListener(\"touchend\",b),o.removeElement(x)}this.addEventListener(\"touchmove\",_),this.addEventListener(\"touchend\",b),x.addEventListener(\"mousemove\",_),x.addEventListener(\"mouseup\",b)}}(a,t,r,l),function(t,e,r,n,i,a){var l=m.handleWidth/2;function c(t){return o.constrain(t,0,n._width)}function u(t){return o.constrain(t,0,n._height)}function h(t){return o.constrain(t,-l,n._width+l)}var f=c(n.d2p(r._rl[0])),p=c(n.d2p(r._rl[1]));if(t.select(\"rect.\"+m.slideBoxClassName).attr(\"x\",f).attr(\"width\",p-f),t.select(\"rect.\"+m.maskMinClassName).attr(\"width\",f),t.select(\"rect.\"+m.maskMaxClassName).attr(\"x\",p).attr(\"width\",n._width-p),\"match\"!==a.rangemode){var d=n._height-u(n.d2pOppAxis(i._rl[1])),g=n._height-u(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+m.maskMinOppAxisClassName).attr(\"x\",f).attr(\"height\",d).attr(\"width\",p-f),t.select(\"rect.\"+m.maskMaxOppAxisClassName).attr(\"x\",f).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",p-f),t.select(\"rect.\"+m.slideBoxClassName).attr(\"y\",d).attr(\"height\",g-d)}var y=.5,v=Math.round(h(f-l))-y,x=Math.round(h(p-l))+y;t.select(\"g.\"+m.grabberMinClassName).attr(\"transform\",s(v,y)),t.select(\"g.\"+m.grabberMaxClassName).attr(\"transform\",s(x,y))}(a,0,r,l,c,h),\"bottom\"===r.side&&u.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:C+l._height+l._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})})))}},80400:function(t,e,r){\"use strict\";var n=r(5975),i=r(30635),a=r(20604),o=r(4530).LINE_SPACING,s=a.name;function l(t){var e=t&&t[s];return e&&e.visible}e.isVisible=l,e.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var a=0;a<e.length;a++){var o=e[a];if(l(o)){i.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},e.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;return\"bottom\"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(i.BR_TAG_ALL)||[]).length*e.title.font.size*o)),{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:a.extraPad+2*n._offsetShift}}},55429:function(t,e,r){\"use strict\";var n=r(34809),i=r(63608),a=r(66249),o=r(80400);t.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:r(63608),handleDefaults:r(41295),calcAutorange:r(46223),draw:r(88887),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},66249:function(t){\"use strict\";t.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},4327:function(t,e,r){\"use strict\";var n=r(50222),i=r(36640).line,a=r(94850).T,o=r(93049).extendFlat,s=r(13582).overrideAll,l=r(78032).templatedArray;r(35081),t.exports=s(l(\"selection\",{type:{valType:\"enumerated\",values:[\"rect\",\"path\"]},xref:o({},n.xref,{}),yref:o({},n.yref,{}),x0:{valType:\"any\"},x1:{valType:\"any\"},y0:{valType:\"any\"},y1:{valType:\"any\"},path:{valType:\"string\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:.7,editType:\"arraydraw\"},line:{color:i.color,width:o({},i.width,{min:1,dflt:1}),dash:o({},a,{dflt:\"dot\"})}}),\"arraydraw\",\"from-root\")},78865:function(t){\"use strict\";t.exports={BENDPX:1.5,MINSELECT:12,SELECTDELAY:100,SELECTID:\"-select\"}},2272:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(59008),o=r(4327),s=r(49728);function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var l=a(\"path\"),c=\"path\"!==a(\"type\",l?\"path\":\"rect\");c&&delete e.path,a(\"opacity\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var u=[\"x\",\"y\"],h=0;h<2;h++){var f,p,d,m=u[h],g={_fullLayout:r},y=i.coerceRef(t,e,g,m);if((f=i.getFromId(g,y))._selectionIndices.push(e._index),d=s.rangeToShapePosition(f),p=s.shapePositionToRange(f),c){var v=m+\"0\",x=m+\"1\",_=t[v],b=t[x];t[v]=p(t[v],!0),t[x]=p(t[x],!0),i.coercePosition(e,g,a,y,v),i.coercePosition(e,g,a,y,x);var w=e[v],T=e[x];void 0!==w&&void 0!==T&&(e[v]=d(w),e[x]=d(T),t[v]=_,t[x]=b)}}c&&n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}t.exports=function(t,e){a(t,e,{name:\"selections\",handleItemDefaults:l});for(var r=e.selections,n=0;n<r.length;n++){var i=r[n];i&&void 0===i.path&&(void 0!==i.x0&&void 0!==i.x1&&void 0!==i.y0&&void 0!==i.y1||(e.selections[n]=null))}}},7028:function(t,e,r){\"use strict\";var n=r(81055).readPaths,i=r(561),a=r(78534).clearOutlineControllers,o=r(78766),s=r(62203),l=r(78032).arrayEditor,c=r(49728),u=c.getPathString;function h(t){var e=t._fullLayout;for(var r in a(t),e._selectionLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].selectionLayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.selections.length;i++)p(t,i)}function f(t){return t._context.editSelection}function p(t,e){t._fullLayout._paperdiv.selectAll('.selectionlayer [data-index=\"'+e+'\"]').remove();var r=c.makeSelectionsOptionsAndPlotinfo(t,e),a=r.options,p=r.plotinfo;a._input&&function(r){var c=u(t,a),g={\"data-index\":e,\"fill-rule\":\"evenodd\",d:c},y=a.opacity,v=\"rgba(0,0,0,0)\",x=a.line.color||o.contrast(t._fullLayout.plot_bgcolor),_=a.line.width,b=a.line.dash;_||(_=5,b=\"solid\");var w=f(t)&&t._fullLayout._activeSelectionIndex===e;w&&(v=t._fullLayout.activeselection.fillcolor,y=t._fullLayout.activeselection.opacity);for(var T=[],k=1;k>=0;k--){var A=r.append(\"path\").attr(g).style(\"opacity\",k?.1:y).call(o.stroke,x).call(o.fill,v).call(s.dashLine,k?\"solid\":b,k?4+_:_);if(d(A,t,a),w){var M=l(t.layout,\"selections\",a);A.style({cursor:\"move\"});var S={element:A.node(),plotinfo:p,gd:t,editHelpers:M,isActiveSelection:!0},E=n(c,t);i(E,A,S)}else A.style(\"pointer-events\",k?\"all\":\"none\");T[k]=A}var C=T[0];T[1].node().addEventListener(\"click\",(function(){return function(t,e){if(f(t)){var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeSelectionIndex)return void m(t);t._fullLayout._activeSelectionIndex=r,t._fullLayout._deactivateSelection=m,h(t)}}}(t,C)}))}(t._fullLayout._selectionLayer)}function d(t,e,r){var n=r.xref+r.yref;s.setClipUrl(t,\"clip\"+e._fullLayout._uid+n,e)}function m(t){f(t)&&t._fullLayout._activeSelectionIndex>=0&&(a(t),delete t._fullLayout._activeSelectionIndex,h(t))}t.exports={draw:h,drawOne:p,activateLastSelection:function(t){if(f(t)){var e=t._fullLayout.selections.length-1;t._fullLayout._activeSelectionIndex=e,t._fullLayout._deactivateSelection=m,h(t)}}}},52307:function(t,e,r){\"use strict\";var n=r(94850).T,i=r(93049).extendFlat;t.exports={newselection:{mode:{valType:\"enumerated\",values:[\"immediate\",\"gradual\"],dflt:\"immediate\",editType:\"none\"},line:{color:{valType:\"color\",editType:\"none\"},width:{valType:\"number\",min:1,dflt:1,editType:\"none\"},dash:i({},n,{dflt:\"dot\",editType:\"none\"}),editType:\"none\"},editType:\"none\"},activeselection:{fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"none\"},editType:\"none\"}}},43028:function(t){\"use strict\";t.exports=function(t,e,r){r(\"newselection.mode\"),r(\"newselection.line.width\")&&(r(\"newselection.line.color\"),r(\"newselection.line.dash\")),r(\"activeselection.fillcolor\"),r(\"activeselection.opacity\")}},51817:function(t,e,r){\"use strict\";var n=r(70414).selectMode,i=r(78534).clearOutline,a=r(81055),o=a.readPaths,s=a.writePaths,l=a.fixDatesForPaths;t.exports=function(t,e){if(t.length){var r=t[0][0];if(r){var a=r.getAttribute(\"d\"),c=e.gd,u=c._fullLayout.newselection,h=e.plotinfo,f=h.xaxis,p=h.yaxis,d=e.isActiveSelection,m=e.dragmode,g=(c.layout||{}).selections||[];if(!n(m)&&void 0!==d){var y=c._fullLayout._activeSelectionIndex;if(y<g.length)switch(c._fullLayout.selections[y].type){case\"rect\":m=\"select\";break;case\"path\":m=\"lasso\"}}var v,x=o(a,c,h,d),_={xref:f._id,yref:p._id,opacity:u.opacity,line:{color:u.line.color,width:u.line.width,dash:u.line.dash}};1===x.length&&(v=x[0]),v&&5===v.length&&\"select\"===m?(_.type=\"rect\",_.x0=v[0][1],_.y0=v[0][2],_.x1=v[2][1],_.y1=v[2][2]):(_.type=\"path\",f&&p&&l(x,f,p),_.path=s(x),v=null),i(c);for(var b=e.editHelpers,w=(b||{}).modifyItem,T=[],k=0;k<g.length;k++){var A=c._fullLayout.selections[k];if(A){if(T[k]=A._input,void 0!==d&&k===c._fullLayout._activeSelectionIndex){var M=_;switch(A.type){case\"rect\":w(\"x0\",M.x0),w(\"x1\",M.x1),w(\"y0\",M.y0),w(\"y1\",M.y1);break;case\"path\":w(\"path\",M.path)}}}else T[k]=A}return void 0===d?(T.push(_),T):b?b.getUpdateObj():{}}}}},49801:function(t,e,r){\"use strict\";var n=r(34809).strTranslate;function i(t,e){switch(t.type){case\"log\":return t.p2d(e);case\"date\":return t.p2r(e,0,t.calendar);default:return t.p2r(e)}}t.exports={p2r:i,r2p:function(t,e){switch(t.type){case\"log\":return t.d2p(e);case\"date\":return t.r2p(e,0,t.calendar);default:return t.r2p(e)}},axValue:function(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return i(t,r[e])}},getTransform:function(t){return n(t.xaxis._offset,t.yaxis._offset)}}},44844:function(t,e,r){\"use strict\";var n=r(7028),i=r(88666);t.exports={moduleType:\"component\",name:\"selections\",layoutAttributes:r(4327),supplyLayoutDefaults:r(2272),supplyDrawNewSelectionDefaults:r(43028),includeBasePlot:r(20706)(\"selections\"),draw:n.draw,drawOne:n.drawOne,reselect:i.reselect,prepSelect:i.prepSelect,clearOutline:i.clearOutline,clearSelectionsCache:i.clearSelectionsCache,selectOnClick:i.selectOnClick}},88666:function(t,e,r){\"use strict\";var n=r(11516),i=r(52773),a=r(33626),o=r(62203).dashStyle,s=r(78766),l=r(32141),c=r(36040).makeEventData,u=r(70414),h=u.freeMode,f=u.rectMode,p=u.drawMode,d=u.openMode,m=u.selectMode,g=r(49728),y=r(2956),v=r(561),x=r(78534).clearOutline,_=r(81055),b=_.handleEllipse,w=_.readPaths,T=r(87562).newShapes,k=r(51817),A=r(7028).activateLastSelection,M=r(34809),S=M.sorterAsc,E=r(80899),C=r(64025),L=r(5975).getFromId,I=r(34823),P=r(71817).redrawReglTraces,z=r(78865),O=z.MINSELECT,D=E.filter,R=E.tester,F=r(49801),B=F.p2r,N=F.axValue,j=F.getTransform;function U(t){return void 0!==t.subplot}function V(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,m,g,y=e._hoverdata,x=e._fullLayout.clickmode.indexOf(\"event\")>-1,_=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(y)){Z(t,e,a);var b=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(y,s=X(e,r,n,i));if(b.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,b):function(t){var e,r,n=0;for(r=0;r<t.length;r++)if((e=t[r].cd[0].trace).selectedpoints){if(e.selectedpoints.length>1)return!1;if((n+=e.selectedpoints.length)>1)return!1}return 1===n}(s)&&(f=J(b))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);K(e,s),W(a),x&&ft(e)}else{for(p=t.shiftKey&&(void 0!==f?f:J(b)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:!!r}}(b.pointNumber,b.searchInfo,p),u=G(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=tt(s[g]._module.selectPoints(s[g],u),s[g]),_.length)for(var w=0;w<h.length;w++)_.push(h[w]);else _=h;if(K(e,s,m={points:_}),c&&a&&a.selectionDefs.push(c),o){var T=a.mergedPolygons,k=d(a.dragmode);v(et(T,k),o,a)}x&&ht(e,m)}}}function q(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function H(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:!!t.subtract}}function G(t){if(t.length){for(var e=[],r=q(t[0])?0:t[0][0][0],n=r,i=q(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(q(t[o]))e.push(H(t[o]));else{var s=R(t[o]);s.subtract=!!t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!e[o].subtract);return a},isRect:!1,degenerate:!1}}}function Z(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=r.dragmode,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,s=(t.shiftKey||t.altKey)&&!(p(a)&&d(a));o&&s&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):s&&i.selection||W(r),o||(x(e),n._lastSelectedSubplot=i.id)}function W(t,e){var r=t.dragmode,n=t.plotinfo,i=t.gd;(function(t){return t._fullLayout._activeShapeIndex>=0})(i)&&i._fullLayout._deactivateShape(i),function(t){return t._fullLayout._activeSelectionIndex>=0}(i)&&i._fullLayout._deactivateSelection(i);var o=i._fullLayout._zoomlayer,s=p(r),l=m(r);if(s||l){var c,u,h=o.selectAll(\".select-outline-\"+n.id);h&&i._fullLayout._outlining&&(s&&(c=T(h,t)),c&&a.call(\"_guiRelayout\",i,{shapes:c}),l&&!U(t)&&(u=k(h,t)),u&&(i._fullLayout._noEmitSelectedAtStart=!0,a.call(\"_guiRelayout\",i,{selections:u}).then((function(){e&&A(i)}))),i._fullLayout._outlining=!1)}n.selection={},n.selection.selectionDefs=t.selectionDefs=[],n.selection.mergedPolygons=t.mergedPolygons=[]}function Y(t){return t._id}function X(t,e,r,n){if(!t.calcdata)return[];var i,a,o,s=[],l=e.map(Y),c=r.map(Y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!U({subplot:n})||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type){if(a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=$(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}}else if(\"sankey\"===a.type){var h=$(a._module,i,e[0],r[0]);s.push(h)}else{if(!(-1!==l.indexOf(a.xaxis)||a._xA&&a._xA.overlaying))continue;if(!(-1!==c.indexOf(a.yaxis)||a._yA&&a._yA.overlaying))continue;s.push($(a._module,i,L(t,a.xaxis),L(t,a.yaxis)))}else s.push($(a._module,i,e[0],r[0]));return s}function $(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}function J(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function K(t,e,r){var n,i;for(n=0;n<e.length;n++){var o=e[n].cd[0].trace._fullInput,s=t._fullLayout._tracePreGUI[o.uid]||{};void 0===s.selectedpoints&&(s.selectedpoints=o._input.selectedpoints||null)}if(r){var l=r.points||[];for(n=0;n<e.length;n++)(i=e[n].cd[0].trace)._input.selectedpoints=i._fullInput.selectedpoints=[],i._fullInput!==i&&(i.selectedpoints=[]);for(var c=0;c<l.length;c++){var u=l[c],h=u.data,f=u.fullData,p=u.pointIndex,d=u.pointIndices;d?([].push.apply(h.selectedpoints,d),i._fullInput!==i&&[].push.apply(f.selectedpoints,d)):(h.selectedpoints.push(p),i._fullInput!==i&&f.selectedpoints.push(p))}}else for(n=0;n<e.length;n++)delete(i=e[n].cd[0].trace).selectedpoints,delete i._input.selectedpoints,i._fullInput!==i&&delete i._fullInput.selectedpoints;!function(t,e){for(var r=!1,n=0;n<e.length;n++){var i=e[n],o=i.cd;a.traceIs(o[0].trace,\"regl\")&&(r=!0);var s=i._module,l=s.styleOnSelect||s.style;l&&(l(t,o,o[0].node3),o[0].nodeRangePlot3&&l(t,o,o[0].nodeRangePlot3))}r&&(I(t),P(t))}(t,e)}function Q(t,e,r){for(var i=(r?n.difference:n.union)({regions:t},{regions:[e]}).regions.reverse(),a=0;a<i.length;a++){var o=i[a];o.subtract=st(o,i.slice(0,a))}return i}function tt(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=c(t[i],n,r);return t}function et(t,e){for(var r=[],n=0;n<t.length;n++){r[n]=[];for(var i=0;i<t[n].length;i++){r[n][i]=[],r[n][i][0]=i?\"L\":\"M\";for(var a=0;a<t[n][i].length;a++)r[n][i].push(t[n][i][a])}e||r[n].push([\"Z\",r[n][0][1],r[n][0][2]])}return r}function rt(t,e){for(var r,n,i=[],a=[],o=0;o<e.length;o++){var s=e[o];n=s._module.selectPoints(s,t),a.push(n),r=tt(n,s),i=i.concat(r)}return i}function nt(t,e,r,n,i){var a,o,s,l=!!n;i&&(a=i.plotinfo,o=i.xaxes[0]._id,s=i.yaxes[0]._id);var c=[],u=[],h=ot(t),f=t._fullLayout;if(a){var d=f._zoomlayer,g=f.dragmode,y=p(g),v=m(g);if(y||v){var x=L(t,o,\"x\"),_=L(t,s,\"y\");if(x&&_){var b=d.selectAll(\".select-outline-\"+a.id);if(b&&t._fullLayout._outlining&&b.length){for(var T=b[0][0].getAttribute(\"d\"),k=w(T,t,a),A=[],M=0;M<k.length;M++){for(var S=k[M],E=[],C=0;C<S.length;C++)E.push([lt(x,S[C][1]),lt(_,S[C][2])]);E.xref=o,E.yref=s,E.subtract=st(E,A),A.push(E)}h=h.concat(A)}}}}var I=o&&s?[o+s]:f._subplots.cartesian;!function(t){var e=t.calcdata;if(e)for(var r=0;r<e.length;r++){var n=e[r][0].trace,i=t._fullLayout._splomScenes;if(i){var a=i[n.uid];a&&(a.selectBatch=[])}}}(t);for(var P={},z=0;z<I.length;z++){var O=I[z],D=O.indexOf(\"y\"),R=O.slice(0,D),F=O.slice(D),B=o&&s?r:void 0;if(B=at(h,R,F,B)){var N=n;if(!l){var j=L(t,R,\"x\"),U=L(t,F,\"y\");N=X(t,[j],[U],O);for(var V=0;V<N.length;V++){var q=N[V],H=q.cd[0],G=H.trace;if(\"scattergl\"===q._module.name&&!H.t.xpx){var Z=G.x,W=G.y,Y=G._length;H.t.xpx=[],H.t.ypx=[];for(var $=0;$<Y;$++)H.t.xpx[$]=j.c2p(Z[$]),H.t.ypx[$]=U.c2p(W[$])}\"splom\"===q._module.name&&(P[G.uid]||(P[G.uid]=!0))}}var J=rt(B,N);c=c.concat(J),u=u.concat(N)}}var Q={points:c};K(t,u,Q);var tt=f.clickmode.indexOf(\"event\")>-1&&e;if(!a&&e){var et=ot(t,!0);if(et.length){var nt=et[0].xref,pt=et[0].yref;if(nt&&pt){var dt=ct(et);ut([L(t,nt,\"x\"),L(t,pt,\"y\")])(Q,dt)}}t._fullLayout._noEmitSelectedAtStart?t._fullLayout._noEmitSelectedAtStart=!1:tt&&ht(t,Q),f._reselect=!1}if(!a&&f._deselect){var mt=f._deselect;(function(t,e,r){for(var n=0;n<r.length;n++){var i=r[n];if(i.xaxis&&i.xaxis._id===t&&i.yaxis&&i.yaxis._id===e)return!0}return!1})(o=mt.xref,s=mt.yref,u)||it(t,o,s,n),tt&&(Q.points.length?ht(t,Q):ft(t)),f._deselect=!1}return{eventData:Q,selectionTesters:r}}function it(t,e,r,n){n=X(t,[L(t,e,\"x\")],[L(t,r,\"y\")],e+r);for(var i=0;i<n.length;i++){var a=n[i];a._module.selectPoints(a,!1)}K(t,n)}function at(t,e,r,n){for(var i,a=0;a<t.length;a++){var o=t[a];e===o.xref&&r===o.yref&&(i?n=G(i=Q(i,o,!!o.subtract)):(i=[o],n=R(o)))}return n}function ot(t,e){for(var r=[],n=t._fullLayout,i=n.selections,a=i.length,o=0;o<a;o++)if(!e||o===n._activeSelectionIndex){var s=i[o];if(s){var l,c,u,h,f,p=s.xref,d=s.yref,m=L(t,p,\"x\"),v=L(t,d,\"y\");if(\"rect\"===s.type){f=[];var x=lt(m,s.x0),_=lt(m,s.x1),b=lt(v,s.y0),w=lt(v,s.y1);f=[[x,b],[x,w],[_,w],[_,b]],l=Math.min(x,_),c=Math.max(x,_),u=Math.min(b,w),h=Math.max(b,w),f.xmin=l,f.xmax=c,f.ymin=u,f.ymax=h,f.xref=p,f.yref=d,f.subtract=!1,f.isRect=!0,r.push(f)}else if(\"path\"===s.type)for(var T=s.path.split(\"Z\"),k=[],A=0;A<T.length;A++){var M=T[A];if(M){M+=\"Z\";var S=g.extractPathCoords(M,y.paramIsX,\"raw\"),E=g.extractPathCoords(M,y.paramIsY,\"raw\");l=1/0,c=-1/0,u=1/0,h=-1/0,f=[];for(var C=0;C<S.length;C++){var I=lt(m,S[C]),P=lt(v,E[C]);f.push([I,P]),l=Math.min(I,l),c=Math.max(I,c),u=Math.min(P,u),h=Math.max(P,h)}f.xmin=l,f.xmax=c,f.ymin=u,f.ymax=h,f.xref=p,f.yref=d,f.subtract=st(f,k),k.push(f),r.push(f)}}}}return r}function st(t,e){for(var r=!1,n=0;n<e.length;n++)for(var a=e[n],o=0;o<t.length;o++)if(i(t[o],a)){r=!r;break}return r}function lt(t,e){return\"date\"===t.type&&(e=e.replace(\"_\",\" \")),\"log\"===t.type?t.c2p(e):t.r2p(e,null,t.calendar)}function ct(t){for(var e=t.length,r=[],n=0;n<e;n++){var i=t[n];r=(r=r.concat(i)).concat([i[0]])}return(a=r).isRect=5===a.length&&a[0][0]===a[4][0]&&a[0][1]===a[4][1]&&a[0][0]===a[1][0]&&a[2][0]===a[3][0]&&a[0][1]===a[3][1]&&a[1][1]===a[2][1]||a[0][1]===a[1][1]&&a[2][1]===a[3][1]&&a[0][0]===a[3][0]&&a[1][0]===a[2][0],a.isRect&&(a.xmin=Math.min(a[0][0],a[2][0]),a.xmax=Math.max(a[0][0],a[2][0]),a.ymin=Math.min(a[0][1],a[2][1]),a.ymax=Math.max(a[0][1],a[2][1])),a;var a}function ut(t){return function(e,r){for(var n,i,a=0;a<t.length;a++){var o=t[a],s=o._id,l=s.charAt(0);if(r.isRect){n||(n={});var c=r[l+\"min\"],u=r[l+\"max\"];void 0!==c&&void 0!==u&&(n[s]=[B(o,c),B(o,u)].sort(S))}else i||(i={}),i[s]=r.map(N(o))}n&&(e.range=n),i&&(e.lassoPoints=i)}}function ht(t,e){e&&(e.selections=(t.layout||{}).selections||[]),t.emit(\"plotly_selected\",e)}function ft(t){t.emit(\"plotly_deselect\",null)}t.exports={reselect:nt,prepSelect:function(t,e,r,n,i){var c=!U(n),u=h(i),g=f(i),y=d(i),x=p(i),_=m(i),w=\"drawcircle\"===i,T=\"drawline\"===i||w,k=n.gd,A=k._fullLayout,S=_&&\"immediate\"===A.newselection.mode&&c,E=A._zoomlayer,L=n.element.getBoundingClientRect(),I=n.plotinfo,P=j(I),F=e-L.left,B=r-L.top;A._calcInverseTransform(k);var N=M.apply3DTransform(A._invTransform)(F,B);F=N[0],B=N[1];var q,H,Y,$,J,tt,at,ot=A._invScaleX,st=A._invScaleY,lt=F,pt=B,dt=\"M\"+F+\",\"+B,mt=n.xaxes[0],gt=n.yaxes[0],yt=mt._length,vt=gt._length,xt=t.altKey&&!(p(i)&&y);Z(t,k,n),u&&(q=D([[F,B]],z.BENDPX));var _t=E.selectAll(\"path.select-outline-\"+I.id).data([1]),bt=x?A.newshape:A.newselection;x&&(n.hasText=bt.label.text||bt.label.texttemplate);var wt=x&&!y?bt.fillcolor:\"rgba(0,0,0,0)\",Tt=bt.line.color||(c?s.contrast(k._fullLayout.plot_bgcolor):\"#7f7f7f\");_t.enter().append(\"path\").attr(\"class\",\"select-outline select-outline-\"+I.id).style({opacity:x?bt.opacity/2:1,\"stroke-dasharray\":o(bt.line.dash,bt.line.width),\"stroke-width\":bt.line.width+\"px\",\"shape-rendering\":\"crispEdges\"}).call(s.stroke,Tt).call(s.fill,wt).attr(\"fill-rule\",\"evenodd\").classed(\"cursor-move\",!!x).attr(\"transform\",P).attr(\"d\",dt+\"Z\");var kt=E.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:s.background,stroke:s.defaultLine,\"stroke-width\":1}).attr(\"transform\",P).attr(\"d\",\"M0,0Z\");if(x&&n.hasText){var At=E.select(\".label-temp\");At.empty()&&(At=E.append(\"g\").classed(\"label-temp\",!0).classed(\"select-outline\",!0).style({opacity:.8}))}var Mt=A._uid+z.SELECTID,St=[],Et=X(k,n.xaxes,n.yaxes,n.subplot);S&&!t.shiftKey&&(n._clearSubplotSelections=function(){if(c){var t=mt._id,e=gt._id;it(k,t,e,Et);for(var r=(k.layout||{}).selections||[],n=[],i=!1,o=0;o<r.length;o++){var s=A.selections[o];s.xref!==t||s.yref!==e?n.push(r[o]):i=!0}i&&(k._fullLayout._noEmitSelectedAtStart=!0,a.call(\"_guiRelayout\",k,{selections:n}))}});var Ct=function(t){return t.plotinfo.fillRangeItems||ut(t.xaxes.concat(t.yaxes))}(n);n.moveFn=function(t,e){n._clearSubplotSelections&&(n._clearSubplotSelections(),n._clearSubplotSelections=void 0),lt=Math.max(0,Math.min(yt,ot*t+F)),pt=Math.max(0,Math.min(vt,st*e+B));var r=Math.abs(lt-F),i=Math.abs(pt-B);if(g){var a,o,s;if(_){var l=A.selectdirection;switch(a=\"any\"===l?i<Math.min(.6*r,O)?\"h\":r<Math.min(.6*i,O)?\"v\":\"d\":l){case\"h\":o=w?vt/2:0,s=vt;break;case\"v\":o=w?yt/2:0,s=yt}}if(x)switch(A.newshape.drawdirection){case\"vertical\":a=\"h\",o=w?vt/2:0,s=vt;break;case\"horizontal\":a=\"v\",o=w?yt/2:0,s=yt;break;case\"ortho\":r<i?(a=\"h\",o=B,s=pt):(a=\"v\",o=F,s=lt);break;default:a=\"d\"}\"h\"===a?(($=T?b(w,[lt,o],[lt,s]):[[F,o],[F,s],[lt,s],[lt,o]]).xmin=T?lt:Math.min(F,lt),$.xmax=T?lt:Math.max(F,lt),$.ymin=Math.min(o,s),$.ymax=Math.max(o,s),kt.attr(\"d\",\"M\"+$.xmin+\",\"+(B-O)+\"h-4v\"+2*O+\"h4ZM\"+($.xmax-1)+\",\"+(B-O)+\"h4v\"+2*O+\"h-4Z\")):\"v\"===a?(($=T?b(w,[o,pt],[s,pt]):[[o,B],[o,pt],[s,pt],[s,B]]).xmin=Math.min(o,s),$.xmax=Math.max(o,s),$.ymin=T?pt:Math.min(B,pt),$.ymax=T?pt:Math.max(B,pt),kt.attr(\"d\",\"M\"+(F-O)+\",\"+$.ymin+\"v-4h\"+2*O+\"v4ZM\"+(F-O)+\",\"+($.ymax-1)+\"v4h\"+2*O+\"v-4Z\")):\"d\"===a&&(($=T?b(w,[F,B],[lt,pt]):[[F,B],[F,pt],[lt,pt],[lt,B]]).xmin=Math.min(F,lt),$.xmax=Math.max(F,lt),$.ymin=Math.min(B,pt),$.ymax=Math.max(B,pt),kt.attr(\"d\",\"M0,0Z\"))}else u&&(q.addPt([lt,pt]),$=q.filtered);if(n.selectionDefs&&n.selectionDefs.length?(Y=Q(n.mergedPolygons,$,xt),$.subtract=xt,H=G(n.selectionDefs.concat([$]))):(Y=[$],H=R($)),v(et(Y,y),_t,n),_){var c,h=nt(k,!1),f=h.eventData?h.eventData.points.slice():[];h=nt(k,!1,H,Et,n),H=h.selectionTesters,at=h.eventData,c=q?q.filtered:ct(Y),C.throttle(Mt,z.SELECTDELAY,(function(){for(var t=(St=rt(H,Et)).slice(),e=0;e<f.length;e++){for(var r=f[e],n=!1,i=0;i<t.length;i++)if(t[i].curveNumber===r.curveNumber&&t[i].pointNumber===r.pointNumber){n=!0;break}n||t.push(r)}t.length&&(at||(at={}),at.points=t),Ct(at,c),function(t,e){t.emit(\"plotly_selecting\",e)}(k,at)}))}},n.clickFn=function(t,e){if(kt.remove(),k._fullLayout._activeShapeIndex>=0)k._fullLayout._deactivateShape(k);else if(!x){var r=A.clickmode;C.done(Mt).then((function(){if(C.clear(Mt),2===t){for(_t.remove(),J=0;J<Et.length;J++)(tt=Et[J])._module.selectPoints(tt,!1);if(K(k,Et),W(n),ft(k),Et.length){var i=Et[0].xaxis,o=Et[0].yaxis;if(i&&o){for(var s=[],c=k._fullLayout.selections,u=0;u<c.length;u++){var h=c[u];h&&(h.xref===i._id&&h.yref===o._id||s.push(h))}s.length<c.length&&(k._fullLayout._noEmitSelectedAtStart=!0,a.call(\"_guiRelayout\",k,{selections:s}))}}}else r.indexOf(\"select\")>-1&&V(e,k,n.xaxes,n.yaxes,n.subplot,n,_t),\"event\"===r&&ht(k,void 0);l.click(k,e,I.id)})).catch(M.error)}},n.doneFn=function(){kt.remove(),C.done(Mt).then((function(){C.clear(Mt),!S&&$&&n.selectionDefs&&($.subtract=xt,n.selectionDefs.push($),n.mergedPolygons.length=0,[].push.apply(n.mergedPolygons,Y)),(S||x)&&W(n,S),n.doneFnCompleted&&n.doneFnCompleted(St),_&&ht(k,at)})).catch(M.error)}},clearOutline:x,clearSelectionsCache:W,selectOnClick:V}},43144:function(t,e,r){\"use strict\";var n=r(50222),i=r(80337),a=r(36640).line,o=r(94850).T,s=r(93049).extendFlat,l=r(78032).templatedArray,c=(r(35081),r(9829)),u=r(3208).LF,h=r(41235);t.exports=l(\"shape\",{visible:s({},c.visible,{editType:\"calc+arraydraw\"}),showlegend:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},legend:s({},c.legend,{editType:\"calc+arraydraw\"}),legendgroup:s({},c.legendgroup,{editType:\"calc+arraydraw\"}),legendgrouptitle:{text:s({},c.legendgrouptitle.text,{editType:\"calc+arraydraw\"}),font:i({editType:\"calc+arraydraw\"}),editType:\"calc+arraydraw\"},legendrank:s({},c.legendrank,{editType:\"calc+arraydraw\"}),legendwidth:s({},c.legendwidth,{editType:\"calc+arraydraw\"}),type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\",\"between\"],dflt:\"above\",editType:\"arraydraw\"},xref:s({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},x0shift:{valType:\"number\",dflt:0,min:-1,max:1,editType:\"calc\"},x1shift:{valType:\"number\",dflt:0,min:-1,max:1,editType:\"calc\"},yref:s({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},y0shift:{valType:\"number\",dflt:0,min:-1,max:1,editType:\"calc\"},y1shift:{valType:\"number\",dflt:0,min:-1,max:1,editType:\"calc\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:s({},a.color,{editType:\"arraydraw\"}),width:s({},a.width,{editType:\"calc+arraydraw\"}),dash:s({},o,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"arraydraw\"},editable:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},label:{text:{valType:\"string\",dflt:\"\",editType:\"arraydraw\"},texttemplate:u({},{keys:Object.keys(h)}),font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\",\"start\",\"middle\",\"end\"],editType:\"arraydraw\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],editType:\"calc+arraydraw\"},padding:{valType:\"number\",dflt:3,min:0,editType:\"arraydraw\"},editType:\"arraydraw\"},editType:\"arraydraw\"})},44959:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(2956),o=r(49728);function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,m=f>0?f+c:c;return{ppad:c,ppadplus:u?d:m,ppadminus:u?m:d}}return{ppad:c}}function u(t,e,r){var n,i,s=\"x\"===t._id.charAt(0)?\"x\":\"y\",l=\"category\"===t.type||\"multicategory\"===t.type,c=0,u=0,h=l?t.r2c:t.d2c;if(\"scaled\"===e[s+\"sizemode\"]?(n=e[s+\"0\"],i=e[s+\"1\"],l&&(c=e[s+\"0shift\"],u=e[s+\"1shift\"])):(n=e[s+\"anchor\"],i=e[s+\"anchor\"]),void 0!==n)return[h(n)+c,h(i)+u];if(e.path){var f,p,d,m,g=1/0,y=-1/0,v=e.path.match(a.segmentRE);for(\"date\"===t.type&&(h=o.decodeDate(h)),f=0;f<v.length;f++)void 0!==(p=r[v[f].charAt(0)].drawn)&&(!(d=v[f].substr(1).match(a.paramRE))||d.length<p||((m=h(d[p]))<g&&(g=m),m>y&&(y=m)));return y>=g?[g,y]:void 0}}t.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];f._extremes={};var p=i.getRefType(f.xref),d=i.getRefType(f.yref);\"paper\"!==f.xref&&\"domain\"!==p&&(h=u(c=i.getFromId(t,f.xref),f,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f))),\"paper\"!==f.yref&&\"domain\"!==d&&(h=u(c=i.getFromId(t,f.yref),f,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}},2956:function(t){\"use strict\";t.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},74367:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(59008),o=r(43144),s=r(49728);function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(e._isShape=!0,a(\"visible\")){a(\"showlegend\")&&(a(\"legend\"),a(\"legendwidth\"),a(\"legendgroup\"),a(\"legendgrouptitle.text\"),n.coerceFont(a,\"legendgrouptitle.font\"),a(\"legendrank\"));var l=a(\"path\"),c=a(\"type\",l?\"path\":\"rect\"),u=\"path\"!==c;u&&delete e.path,a(\"editable\"),a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"fillrule\"),a(\"line.width\")&&(a(\"line.color\"),a(\"line.dash\"));for(var h=a(\"xsizemode\"),f=a(\"ysizemode\"),p=[\"x\",\"y\"],d=0;d<2;d++){var m,g,y,v=p[d],x=v+\"anchor\",_=\"x\"===v?h:f,b={_fullLayout:r},w=i.coerceRef(t,e,b,v,void 0,\"paper\");if(\"range\"===i.getRefType(w)?((m=i.getFromId(b,w))._shapeIndices.push(e._index),y=s.rangeToShapePosition(m),g=s.shapePositionToRange(m),\"category\"!==m.type&&\"multicategory\"!==m.type||(a(v+\"0shift\"),a(v+\"1shift\"))):g=y=n.identity,u){var T=v+\"0\",k=v+\"1\",A=t[T],M=t[k];t[T]=g(t[T],!0),t[k]=g(t[k],!0),\"pixel\"===_?(a(T,0),a(k,10)):(i.coercePosition(e,b,a,w,T,.25),i.coercePosition(e,b,a,w,k,.75)),e[T]=y(e[T]),e[k]=y(e[k]),t[T]=A,t[k]=M}if(\"pixel\"===_){var S=t[x];t[x]=g(t[x],!0),i.coercePosition(e,b,a,w,x,.25),e[x]=y(e[x]),t[x]=S}}u&&n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"]);var E,C,L=\"line\"===c;if(u&&(E=a(\"label.texttemplate\")),E||(C=a(\"label.text\")),C||E){a(\"label.textangle\");var I=a(\"label.textposition\",L?\"middle\":\"middle center\");a(\"label.xanchor\"),a(\"label.yanchor\",function(t,e){return t?\"bottom\":-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\"}(L,I)),a(\"label.padding\"),n.coerceFont(a,\"label.font\",r.font)}}}t.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},44433:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(30635),o=r(62203),s=r(81055).readPaths,l=r(49728),c=l.getPathString,u=r(41235),h=r(4530).FROM_TL;t.exports=function(t,e,r,f){if(f.selectAll(\".shape-label\").remove(),r.label.text||r.label.texttemplate){var p;if(r.label.texttemplate){var d={};if(\"path\"!==r.type){var m=i.getFromId(t,r.xref),g=i.getFromId(t,r.yref);for(var y in u){var v=u[y](r,m,g);void 0!==v&&(d[y]=v)}}p=n.texttemplateStringForShapes(r.label.texttemplate,{},t._fullLayout._d3locale,d)}else p=r.label.text;var x,_,b,w,T={\"data-index\":e},k=r.label.font,A=f.append(\"g\").attr(T).classed(\"shape-label\",!0).append(\"text\").attr({\"data-notex\":1}).classed(\"shape-label-text\",!0).text(p);if(r.path){var M=c(t,r),S=s(M,t);x=1/0,b=1/0,_=-1/0,w=-1/0;for(var E=0;E<S.length;E++)for(var C=0;C<S[E].length;C++)for(var L=S[E][C],I=1;I<L.length;I+=2){var P=L[I],z=L[I+1];x=Math.min(x,P),_=Math.max(_,P),b=Math.min(b,z),w=Math.max(w,z)}}else{var O=i.getFromId(t,r.xref),D=r.x0shift,R=r.x1shift,F=i.getRefType(r.xref),B=i.getFromId(t,r.yref),N=r.y0shift,j=r.y1shift,U=i.getRefType(r.yref),V=function(e,r){return l.getDataToPixel(t,O,r,!1,F)(e)},q=function(e,r){return l.getDataToPixel(t,B,r,!0,U)(e)};x=V(r.x0,D),_=V(r.x1,R),b=q(r.y0,N),w=q(r.y1,j)}var H=r.label.textangle;\"auto\"===H&&(H=\"line\"===r.type?function(t,e,r,n){var i,a;return a=Math.abs(r-t),i=r>=t?e-n:n-e,-180/Math.PI*Math.atan2(i,a)}(x,b,_,w):0),A.call((function(e){return e.call(o.font,k).attr({}),a.convertToTspans(e,t),e}));var G=function(t,e,r,n,i,a,o){var s,l,c,u,f=i.label.textposition,p=i.label.textangle,d=i.label.padding,m=i.type,g=Math.PI/180*a,y=Math.sin(g),v=Math.cos(g),x=i.label.xanchor,_=i.label.yanchor;if(\"line\"===m){\"start\"===f?(s=t,l=e):\"end\"===f?(s=r,l=n):(s=(t+r)/2,l=(e+n)/2),\"auto\"===x&&(x=\"start\"===f?\"auto\"===p?r>t?\"left\":r<t?\"right\":\"center\":r>t?\"right\":r<t?\"left\":\"center\":\"end\"===f?\"auto\"===p?r>t?\"right\":r<t?\"left\":\"center\":r>t?\"left\":r<t?\"right\":\"center\":\"center\");var b={bottom:-1,middle:0,top:1};if(\"auto\"===p){var w=b[_];c=-d*y*w,u=d*v*w}else c=d*{left:1,center:0,right:-1}[x],u=d*b[_];s+=c,l+=u}else c=d+3,-1!==f.indexOf(\"right\")?(s=Math.max(t,r)-c,\"auto\"===x&&(x=\"right\")):-1!==f.indexOf(\"left\")?(s=Math.min(t,r)+c,\"auto\"===x&&(x=\"left\")):(s=(t+r)/2,\"auto\"===x&&(x=\"center\")),l=-1!==f.indexOf(\"top\")?Math.min(e,n):-1!==f.indexOf(\"bottom\")?Math.max(e,n):(e+n)/2,u=d,\"bottom\"===_?l-=u:\"top\"===_&&(l+=u);var T=h[_],k=i.label.font.size,A=o.height;return{textx:s+(A*T-k)*y,texty:l+-(A*T-k)*v,xanchor:x}}(x,b,_,w,r,H,o.bBox(A.node())),Z=G.textx,W=G.texty,Y=G.xanchor;A.attr({\"text-anchor\":{left:\"start\",center:\"middle\",right:\"end\"}[Y],y:W,x:Z,transform:\"rotate(\"+H+\",\"+Z+\",\"+W+\")\"}).call(a.positionText,Z,W)}}},561:function(t,e,r){\"use strict\";var n=r(34809).strTranslate,i=r(14751),a=r(70414),o=a.drawMode,s=a.selectMode,l=r(33626),c=r(78766),u=r(93391),h=u.i000,f=u.i090,p=u.i180,d=u.i270,m=r(78534).clearOutlineControllers,g=r(81055),y=g.pointsOnRectangle,v=g.pointsOnEllipse,x=g.writePaths,_=r(87562).newShapes,b=r(87562).createShapeObj,w=r(51817),T=r(44433);function k(t,e){var r,n,i,a=t[e][1],o=t[e][2],s=t.length;return n=t[r=(e+1)%s][1],i=t[r][2],n===a&&i===o&&(n=t[r=(e+2)%s][1],i=t[r][2]),[r,n,i]}t.exports=function t(e,r,a,u){u||(u=0);var g=a.gd;function A(){t(e,r,a,u++),(v(e[0])||a.hasText)&&M({redrawing:!0})}function M(t){var e={};void 0!==a.isActiveShape&&(a.isActiveShape=!1,e=_(r,a)),void 0!==a.isActiveSelection&&(a.isActiveSelection=!1,e=w(r,a),g._fullLayout._reselect=!0),Object.keys(e).length&&l.call((t||{}).redrawing?\"relayout\":\"_guiRelayout\",g,e)}var S,E,C,L,I,P=g._fullLayout._zoomlayer,z=a.dragmode,O=o(z),D=s(z);if((O||D)&&(g._fullLayout._outlining=!0),m(g),r.attr(\"d\",x(e)),u||!a.isActiveShape&&!a.isActiveSelection||(I=function(t,e){for(var r=0;r<e.length;r++){var n=e[r];t[r]=[];for(var i=0;i<n.length;i++){t[r][i]=[];for(var a=0;a<n[i].length;a++)t[r][i][a]=n[i][a]}}return t}([],e),function(t){S=[];for(var r=0;r<e.length;r++){var o=e[r],s=y(o),l=!s&&v(o);S[r]=[];for(var u=o.length,m=0;m<u;m++)if(\"Z\"!==o[m][0]&&(!l||m===h||m===f||m===p||m===d)){var x,_=s&&a.isActiveSelection;_&&(x=k(o,m));var b=o[m][1],w=o[m][2],T=t.append(_?\"rect\":\"circle\").attr(\"data-i\",r).attr(\"data-j\",m).style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,\"shape-rendering\":\"crispEdges\"});if(_){var A=x[1]-b,M=x[2]-w,E=M?5:Math.max(Math.min(25,Math.abs(A)-5),5),C=A?5:Math.max(Math.min(25,Math.abs(M)-5),5);T.classed(M?\"cursor-ew-resize\":\"cursor-ns-resize\",!0).attr(\"width\",E).attr(\"height\",C).attr(\"x\",b-E/2).attr(\"y\",w-C/2).attr(\"transform\",n(A/2,M/2))}else T.classed(\"cursor-grab\",!0).attr(\"r\",5).attr(\"cx\",b).attr(\"cy\",w);S[r][m]={element:T.node(),gd:g,prepFn:B,doneFn:j,clickFn:U},i.init(S[r][m])}}}(P.append(\"g\").attr(\"class\",\"outline-controllers\")),function(){if(E=[],e.length){E[0]={element:r[0][0],gd:g,prepFn:q,doneFn:H,clickFn:G},i.init(E[0])}}()),O&&a.hasText){var R=P.select(\".label-temp\"),F=b(r,a,a.dragmode);T(g,\"label-temp\",F,R)}function B(t){C=+t.srcElement.getAttribute(\"data-i\"),L=+t.srcElement.getAttribute(\"data-j\"),S[C][L].moveFn=N}function N(t,r){if(e.length){var n=I[C][L][1],i=I[C][L][2],o=e[C],s=o.length;if(y(o)){var l=t,c=r;a.isActiveSelection&&(k(o,L)[1]===o[L][1]?c=0:l=0);for(var u=0;u<s;u++)if(u!==L){var h=o[u];h[1]===o[L][1]&&(h[1]=n+l),h[2]===o[L][2]&&(h[2]=i+c)}if(o[L][1]=n+l,o[L][2]=i+c,!y(o))for(var f=0;f<s;f++)for(var p=0;p<o[f].length;p++)o[f][p]=I[C][f][p]}else o[L][1]=n+t,o[L][2]=i+r;A()}}function j(){M()}function U(t,r){if(2===t){C=+r.srcElement.getAttribute(\"data-i\"),L=+r.srcElement.getAttribute(\"data-j\");var n=e[C];y(n)||v(n)||function(){if(e.length&&e[C]&&e[C].length){for(var t=[],r=0;r<e[C].length;r++)r!==L&&t.push(e[C][r]);t.length>1&&(2!==t.length||\"Z\"!==t[1][0])&&(0===L&&(t[0][0]=\"M\"),e[C]=t,A(),M())}}()}}function V(t,r){!function(t,r){if(e.length)for(var n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)for(var a=0;a+2<e[n][i].length;a+=2)e[n][i][a+1]=I[n][i][a+1]+t,e[n][i][a+2]=I[n][i][a+2]+r}(t,r),A()}function q(t){(C=+t.srcElement.getAttribute(\"data-i\"))||(C=0),E[C].moveFn=V}function H(){M()}function G(t){2===t&&function(t){if(s(t._fullLayout.dragmode)){m(t);var e=t._fullLayout._activeSelectionIndex,r=(t.layout||{}).selections||[];if(e<r.length){for(var n=[],i=0;i<r.length;i++)i!==e&&n.push(r[i]);delete t._fullLayout._activeSelectionIndex;var a=t._fullLayout.selections[e];t._fullLayout._deselect={xref:a.xref,yref:a.yref},l.call(\"_guiRelayout\",t,{selections:n})}}}(g)}}},28231:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(34809),o=r(29714),s=r(81055).readPaths,l=r(561),c=r(44433),u=r(78534).clearOutlineControllers,h=r(78766),f=r(62203),p=r(78032).arrayEditor,d=r(14751),m=r(27983),g=r(2956),y=r(49728),v=y.getPathString;function x(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._shapeUpperLayer.selectAll(\"text\").remove(),e._shapeLowerLayer.selectAll(\"text\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&(n.selectAll(\"path\").remove(),n.selectAll(\"text\").remove())}for(var i=0;i<e.shapes.length;i++)!0===e.shapes[i].visible&&w(t,i)}function _(t){return!!t._fullLayout._outlining}function b(t){return!t._context.edits.shapePosition}function w(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=y.makeShapesOptionsAndPlotinfo(t,e),u=r.options,w=r.plotinfo;function M(r){var M=v(t,u),S={\"data-index\":e,\"fill-rule\":u.fillrule,d:M},E=u.opacity,C=u.fillcolor,L=u.line.width?u.line.color:\"rgba(0,0,0,0)\",I=u.line.width,P=u.line.dash;I||!0!==u.editable||(I=5,P=\"solid\");var z=\"Z\"!==M[M.length-1],O=b(t)&&u.editable&&t._fullLayout._activeShapeIndex===e;O&&(C=z?\"rgba(0,0,0,0)\":t._fullLayout.activeshape.fillcolor,E=t._fullLayout.activeshape.opacity);var D,R=r.append(\"g\").classed(\"shape-group\",!0).attr({\"data-index\":e}),F=R.append(\"path\").attr(S).style(\"opacity\",E).call(h.stroke,L).call(h.fill,C).call(f.dashLine,P,I);if(T(R,t,u),c(t,e,u,R),(O||t._context.edits.shapePosition)&&(D=p(t.layout,\"shapes\",u)),O){F.style({cursor:\"move\"});var B={element:F.node(),plotinfo:w,gd:t,editHelpers:D,hasText:u.label.text||u.label.texttemplate,isActiveShape:!0},N=s(M,t);l(N,F,B)}else t._context.edits.shapePosition?function(t,e,r,s,l,u){var h,p,x,b,w,A,M,S,E,C,L,I,P,z,O,D,R=10,F=10,B=\"pixel\"===r.xsizemode,N=\"pixel\"===r.ysizemode,j=\"line\"===r.type,U=\"path\"===r.type,V=u.modifyItem,q=n.select(e.node().parentNode),H=o.getFromId(t,r.xref),G=o.getRefType(r.xref),Z=o.getFromId(t,r.yref),W=o.getRefType(r.yref),Y=r.x0shift,X=r.x1shift,$=r.y0shift,J=r.y1shift,K=function(e,r){return y.getDataToPixel(t,H,r,!1,G)(e)},Q=function(e,r){return y.getDataToPixel(t,Z,r,!0,W)(e)},tt=y.getPixelToData(t,H,!1,G),et=y.getPixelToData(t,Z,!0,W),rt=j?function(){var t=10,n=Math.max(r.line.width,t),i=l.append(\"g\").attr(\"data-index\",s).attr(\"drag-helper\",!0);i.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":n,\"stroke-opacity\":\"0\"});var a={\"fill-opacity\":\"0\"},o=Math.max(n/2,t);return i.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:B?K(r.xanchor)+r.x0:K(r.x0,Y),cy:N?Q(r.yanchor)-r.y0:Q(r.y0,$),r:o}).style(a).classed(\"cursor-grab\",!0),i.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:B?K(r.xanchor)+r.x1:K(r.x1,X),cy:N?Q(r.yanchor)-r.y1:Q(r.y1,J),r:o}).style(a).classed(\"cursor-grab\",!0),i}():e,nt={element:rt.node(),gd:t,prepFn:function(n){_(t)||(B&&(w=K(r.xanchor)),N&&(A=Q(r.yanchor)),\"path\"===r.type?O=r.path:(h=B?r.x0:K(r.x0),p=N?r.y0:Q(r.y0),x=B?r.x1:K(r.x1),b=N?r.y1:Q(r.y1)),h<x?(E=h,P=\"x0\",C=x,z=\"x1\"):(E=x,P=\"x1\",C=h,z=\"x0\"),!N&&p<b||N&&p>b?(M=p,L=\"y0\",S=b,I=\"y1\"):(M=b,L=\"y1\",S=p,I=\"y0\"),it(n),st(l,r),function(t,e,r){var n=e.xref,i=e.yref,a=o.getFromId(r,n),s=o.getFromId(r,i),l=\"\";\"paper\"===n||a.autorange||(l+=n),\"paper\"===i||s.autorange||(l+=i),f.setClipUrl(t,l?\"clip\"+r._fullLayout._uid+l:null,r)}(e,r,t),nt.moveFn=\"move\"===D?at:ot,nt.altKey=n.altKey)},doneFn:function(){_(t)||(m(e),lt(l),T(e,t,r),i.call(\"_guiRelayout\",t,u.getUpdateObj()))},clickFn:function(){_(t)||lt(l)}};function it(r){if(_(t))D=null;else if(j)D=\"path\"===r.target.tagName?\"move\":\"start-point\"===r.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var n=nt.element.getBoundingClientRect(),i=n.right-n.left,a=n.bottom-n.top,o=r.clientX-n.left,s=r.clientY-n.top,l=!U&&i>R&&a>F&&!r.shiftKey?d.getCursor(o/i,1-s/a):\"move\";m(e,l),D=l.split(\"-\")[0]}}function at(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,u=a;B?V(\"xanchor\",r.xanchor=tt(w+n)):(o=function(t){return tt(K(t)+n)},H&&\"date\"===H.type&&(o=y.encodeDate(o))),N?V(\"yanchor\",r.yanchor=et(A+i)):(u=function(t){return et(Q(t)+i)},Z&&\"date\"===Z.type&&(u=y.encodeDate(u))),V(\"path\",r.path=k(O,o,u))}else B?V(\"xanchor\",r.xanchor=tt(w+n)):(V(\"x0\",r.x0=tt(h+n)),V(\"x1\",r.x1=tt(x+n))),N?V(\"yanchor\",r.yanchor=et(A+i)):(V(\"y0\",r.y0=et(p+i)),V(\"y1\",r.y1=et(b+i)));e.attr(\"d\",v(t,r)),st(l,r),c(t,s,r,q)}function ot(n,i){if(U){var a=function(t){return t},o=a,u=a;B?V(\"xanchor\",r.xanchor=tt(w+n)):(o=function(t){return tt(K(t)+n)},H&&\"date\"===H.type&&(o=y.encodeDate(o))),N?V(\"yanchor\",r.yanchor=et(A+i)):(u=function(t){return et(Q(t)+i)},Z&&\"date\"===Z.type&&(u=y.encodeDate(u))),V(\"path\",r.path=k(O,o,u))}else if(j){if(\"resize-over-start-point\"===D){var f=h+n,d=N?p-i:p+i;V(\"x0\",r.x0=B?f:tt(f)),V(\"y0\",r.y0=N?d:et(d))}else if(\"resize-over-end-point\"===D){var m=x+n,g=N?b-i:b+i;V(\"x1\",r.x1=B?m:tt(m)),V(\"y1\",r.y1=N?g:et(g))}}else{var _=function(t){return-1!==D.indexOf(t)},T=_(\"n\"),G=_(\"s\"),W=_(\"w\"),Y=_(\"e\"),X=T?M+i:M,$=G?S+i:S,J=W?E+n:E,rt=Y?C+n:C;N&&(T&&(X=M-i),G&&($=S-i)),(!N&&$-X>F||N&&X-$>F)&&(V(L,r[L]=N?X:et(X)),V(I,r[I]=N?$:et($))),rt-J>R&&(V(P,r[P]=B?J:tt(J)),V(z,r[z]=B?rt:tt(rt)))}e.attr(\"d\",v(t,r)),st(l,r),c(t,s,r,q)}function st(t,e){(B||N)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var i=K(B?e.xanchor:a.midRange(r?[e.x0,e.x1]:y.extractPathCoords(e.path,g.paramIsX))),o=Q(N?e.yanchor:a.midRange(r?[e.y0,e.y1]:y.extractPathCoords(e.path,g.paramIsY)));if(i=y.roundPositionForSharpStrokeRendering(i,1),o=y.roundPositionForSharpStrokeRendering(o,1),B&&N){var s=\"M\"+(i-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(B){var l=\"M\"+(i-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(i-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function lt(t){t.selectAll(\".visual-cue\").remove()}d.init(nt),rt.node().onmousemove=it}(t,F,u,e,r,D):!0===u.editable&&F.style(\"pointer-events\",z||h.opacity(C)*E<=.5?\"stroke\":\"all\");F.node().addEventListener(\"click\",(function(){return function(t,e){if(b(t)){var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeShapeIndex)return void A(t);t._fullLayout._activeShapeIndex=r,t._fullLayout._deactivateShape=A,x(t)}}}(t,F)}))}u._input&&!0===u.visible&&(\"above\"===u.layer?M(t._fullLayout._shapeUpperLayer):\"paper\"===u.xref||\"paper\"===u.yref?M(t._fullLayout._shapeLowerLayer):\"between\"===u.layer?M(w.shapelayerBetween):w._hadPlotinfo?M((w.mainplotinfo||w).shapelayer):M(t._fullLayout._shapeLowerLayer))}function T(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\").replace(/[xyz][1-9]* *domain/g,\"\");f.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function k(t,e,r){return t.replace(g.segmentRE,(function(t){var n=0,i=t.charAt(0),a=g.paramIsX[i],o=g.paramIsY[i],s=g.numParams[i];return i+t.substr(1).replace(g.paramRE,(function(t){return n>=s||(a[n]?t=e(t):o[n]&&(t=r(t)),n++),t}))}))}function A(t){b(t)&&t._fullLayout._activeShapeIndex>=0&&(u(t),delete t._fullLayout._activeShapeIndex,x(t))}t.exports={draw:x,drawOne:w,eraseActiveShape:function(t){if(b(t)){u(t);var e=t._fullLayout._activeShapeIndex,r=(t.layout||{}).shapes||[];if(e<r.length){for(var n=[],a=0;a<r.length;a++)a!==e&&n.push(r[a]);return delete t._fullLayout._activeShapeIndex,i.call(\"_guiRelayout\",t,{shapes:n})}}},drawLabel:c}},64101:function(t,e,r){\"use strict\";var n=r(13582).overrideAll,i=r(9829),a=r(80337),o=r(94850).T,s=r(93049).extendFlat,l=r(3208).LF,c=r(41235);t.exports=n({newshape:{visible:s({},i.visible,{}),showlegend:{valType:\"boolean\",dflt:!1},legend:s({},i.legend,{}),legendgroup:s({},i.legendgroup,{}),legendgrouptitle:{text:s({},i.legendgrouptitle.text,{}),font:a({})},legendrank:s({},i.legendrank,{}),legendwidth:s({},i.legendwidth,{}),line:{color:{valType:\"color\"},width:{valType:\"number\",min:0,dflt:4},dash:s({},o,{dflt:\"solid\"})},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\"},opacity:{valType:\"number\",min:0,max:1,dflt:1},layer:{valType:\"enumerated\",values:[\"below\",\"above\",\"between\"],dflt:\"above\"},drawdirection:{valType:\"enumerated\",values:[\"ortho\",\"horizontal\",\"vertical\",\"diagonal\"],dflt:\"diagonal\"},name:s({},i.name,{}),label:{text:{valType:\"string\",dflt:\"\"},texttemplate:l({newshape:!0},{keys:Object.keys(c)}),font:a({}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\",\"start\",\"middle\",\"end\"]},textangle:{valType:\"angle\",dflt:\"auto\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"]},padding:{valType:\"number\",dflt:3,min:0}}},activeshape:{fillcolor:{valType:\"color\",dflt:\"rgb(255,0,255)\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5}}},\"none\",\"from-root\")},93391:function(t){\"use strict\";t.exports={CIRCLE_SIDES:32,i000:0,i090:8,i180:16,i270:24,cos45:Math.cos(Math.PI/4),sin45:Math.sin(Math.PI/4),SQRT2:Math.sqrt(2)}},85522:function(t,e,r){\"use strict\";var n=r(78766),i=r(34809);t.exports=function(t,e,r){if(r(\"newshape.visible\"),r(\"newshape.name\"),r(\"newshape.showlegend\"),r(\"newshape.legend\"),r(\"newshape.legendwidth\"),r(\"newshape.legendgroup\"),r(\"newshape.legendgrouptitle.text\"),i.coerceFont(r,\"newshape.legendgrouptitle.font\"),r(\"newshape.legendrank\"),r(\"newshape.drawdirection\"),r(\"newshape.layer\"),r(\"newshape.fillcolor\"),r(\"newshape.fillrule\"),r(\"newshape.opacity\"),r(\"newshape.line.width\")){var a=(t||{}).plot_bgcolor||\"#FFF\";r(\"newshape.line.color\",n.contrast(a)),r(\"newshape.line.dash\")}var o=\"drawline\"===t.dragmode,s=r(\"newshape.label.text\"),l=r(\"newshape.label.texttemplate\");if(s||l){r(\"newshape.label.textangle\");var c=r(\"newshape.label.textposition\",o?\"middle\":\"middle center\");r(\"newshape.label.xanchor\"),r(\"newshape.label.yanchor\",function(t,e){return t?\"bottom\":-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\"}(o,c)),r(\"newshape.label.padding\"),i.coerceFont(r,\"newshape.label.font\",e.font)}r(\"activeshape.fillcolor\"),r(\"activeshape.opacity\")}},81055:function(t,e,r){\"use strict\";var n=r(26953),i=r(93391),a=i.CIRCLE_SIDES,o=i.SQRT2,s=r(49801),l=s.p2r,c=s.r2p,u=[0,3,4,5,6,1,2],h=[0,3,4,1,2];function f(t,e){return Math.abs(t-e)<=1e-6}function p(t,e){var r=e[1]-t[1],n=e[2]-t[2];return Math.sqrt(r*r+n*n)}e.writePaths=function(t){var e=t.length;if(!e)return\"M0,0Z\";for(var r=\"\",n=0;n<e;n++)for(var i=t[n].length,a=0;a<i;a++){var o=t[n][a][0];if(\"Z\"===o)r+=\"Z\";else for(var s=t[n][a].length,l=0;l<s;l++){var c=l;\"Q\"===o||\"S\"===o?c=h[l]:\"C\"===o&&(c=u[l]),r+=t[n][a][c],l>0&&l<s-1&&(r+=\",\")}}return r},e.readPaths=function(t,e,r,i){var o,s,u,h=n(t),f=[],p=-1,d=0,m=0,g=function(){s=d,u=m};g();for(var y=0;y<h.length;y++){var v,x,_,b,w=[],T=h[y][0],k=T;switch(T){case\"M\":f[++p]=[],d=+h[y][1],m=+h[y][2],w.push([k,d,m]),g();break;case\"Q\":case\"S\":v=+h[y][1],_=+h[y][2],d=+h[y][3],m=+h[y][4],w.push([k,d,m,v,_]);break;case\"C\":v=+h[y][1],_=+h[y][2],x=+h[y][3],b=+h[y][4],d=+h[y][5],m=+h[y][6],w.push([k,d,m,v,_,x,b]);break;case\"T\":case\"L\":d=+h[y][1],m=+h[y][2],w.push([k,d,m]);break;case\"H\":k=\"L\",d=+h[y][1],w.push([k,d,m]);break;case\"V\":k=\"L\",m=+h[y][1],w.push([k,d,m]);break;case\"A\":k=\"L\";var A=+h[y][1],M=+h[y][2];+h[y][4]||(A=-A,M=-M);var S=d-A,E=m;for(o=1;o<=a/2;o++){var C=2*Math.PI*o/a;w.push([k,S+A*Math.cos(C),E+M*Math.sin(C)])}break;case\"Z\":d===s&&m===u||(d=s,m=u,w.push([k,d,m]))}for(var L=(r||{}).domain,I=e._fullLayout._size,P=r&&\"pixel\"===r.xsizemode,z=r&&\"pixel\"===r.ysizemode,O=!1===i,D=0;D<w.length;D++){for(o=0;o+2<7;o+=2){var R=w[D][o+1],F=w[D][o+2];void 0!==R&&void 0!==F&&(d=R,m=F,r&&(r.xaxis&&r.xaxis.p2r?(O&&(R-=r.xaxis._offset),R=P?c(r.xaxis,r.xanchor)+R:l(r.xaxis,R)):(O&&(R-=I.l),L?R=L.x[0]+R/I.w:R/=I.w),r.yaxis&&r.yaxis.p2r?(O&&(F-=r.yaxis._offset),F=z?c(r.yaxis,r.yanchor)-F:l(r.yaxis,F)):(O&&(F-=I.t),F=L?L.y[1]-F/I.h:1-F/I.h)),w[D][o+1]=R,w[D][o+2]=F)}f[p].push(w[D].slice())}}return f},e.pointsOnRectangle=function(t){if(5!==t.length)return!1;for(var e=1;e<3;e++){if(!f(t[0][e]-t[1][e],t[3][e]-t[2][e]))return!1;if(!f(t[0][e]-t[3][e],t[1][e]-t[2][e]))return!1}return!(!f(t[0][1],t[1][1])&&!f(t[0][1],t[3][1])||!(p(t[0],t[1])*p(t[0],t[3])))},e.pointsOnEllipse=function(t){var e=t.length;if(e!==a+1)return!1;e=a;for(var r=0;r<e;r++){var n=(2*e-r)%e,i=(e/2+n)%e,o=(e/2+r)%e;if(!f(p(t[r],t[o]),p(t[n],t[i])))return!1}return!0},e.handleEllipse=function(t,r,n){if(!t)return[r,n];var i=e.ellipseOver({x0:r[0],y0:r[1],x1:n[0],y1:n[1]}),s=(i.x1+i.x0)/2,l=(i.y1+i.y0)/2,c=(i.x1-i.x0)/2,u=(i.y1-i.y0)/2;c||(c=u/=o),u||(u=c/=o);for(var h=[],f=0;f<a;f++){var p=2*f*Math.PI/a;h.push([s+c*Math.cos(p),l+u*Math.sin(p)])}return h},e.ellipseOver=function(t){var e=t.x0,r=t.y0,n=t.x1,i=t.y1,a=n-e,s=i-r,l=((e-=a)+n)/2,c=((r-=s)+i)/2;return{x0:l-(a*=o),y0:c-(s*=o),x1:l+a,y1:c+s}},e.fixDatesForPaths=function(t,e,r){var n=\"date\"===e.type,i=\"date\"===r.type;if(!n&&!i)return t;for(var a=0;a<t.length;a++)for(var o=0;o<t[a].length;o++)for(var s=0;s+2<t[a][o].length;s+=2)n&&(t[a][o][s+1]=t[a][o][s+1].replace(\" \",\"_\")),i&&(t[a][o][s+2]=t[a][o][s+2].replace(\" \",\"_\"));return t}},87562:function(t,e,r){\"use strict\";var n=r(70414),i=n.drawMode,a=n.openMode,o=r(93391),s=o.i000,l=o.i090,c=o.i180,u=o.i270,h=o.cos45,f=o.sin45,p=r(49801),d=p.p2r,m=p.r2p,g=r(78534).clearOutline,y=r(81055),v=y.readPaths,x=y.writePaths,_=y.ellipseOver,b=y.fixDatesForPaths;function w(t,e,r){var n,i=t[0][0],o=e.gd,p=i.getAttribute(\"d\"),g=o._fullLayout.newshape,y=e.plotinfo,w=e.isActiveShape,T=y.xaxis,k=y.yaxis,A=!!y.domain||!y.xaxis,M=!!y.domain||!y.yaxis,S=a(r),E=v(p,o,y,w),C={editable:!0,visible:g.visible,name:g.name,showlegend:g.showlegend,legend:g.legend,legendwidth:g.legendwidth,legendgroup:g.legendgroup,legendgrouptitle:{text:g.legendgrouptitle.text,font:g.legendgrouptitle.font},legendrank:g.legendrank,label:g.label,xref:A?\"paper\":T._id,yref:M?\"paper\":k._id,layer:g.layer,opacity:g.opacity,line:{color:g.line.color,width:g.line.width,dash:g.line.dash}};if(S||(C.fillcolor=g.fillcolor,C.fillrule=g.fillrule),1===E.length&&(n=E[0]),n&&5===n.length&&\"drawrect\"===r)C.type=\"rect\",C.x0=n[0][1],C.y0=n[0][2],C.x1=n[2][1],C.y1=n[2][2];else if(n&&\"drawline\"===r)C.type=\"line\",C.x0=n[0][1],C.y0=n[0][2],C.x1=n[1][1],C.y1=n[1][2];else if(n&&\"drawcircle\"===r){C.type=\"circle\";var L=n[s][1],I=n[l][1],P=n[c][1],z=n[u][1],O=n[s][2],D=n[l][2],R=n[c][2],F=n[u][2],B=y.xaxis&&(\"date\"===y.xaxis.type||\"log\"===y.xaxis.type),N=y.yaxis&&(\"date\"===y.yaxis.type||\"log\"===y.yaxis.type);B&&(L=m(y.xaxis,L),I=m(y.xaxis,I),P=m(y.xaxis,P),z=m(y.xaxis,z)),N&&(O=m(y.yaxis,O),D=m(y.yaxis,D),R=m(y.yaxis,R),F=m(y.yaxis,F));var j=(I+z)/2,U=(O+R)/2,V=_({x0:j,y0:U,x1:j+(z-I+P-L)/2*h,y1:U+(F-D+R-O)/2*f});B&&(V.x0=d(y.xaxis,V.x0),V.x1=d(y.xaxis,V.x1)),N&&(V.y0=d(y.yaxis,V.y0),V.y1=d(y.yaxis,V.y1)),C.x0=V.x0,C.y0=V.y0,C.x1=V.x1,C.y1=V.y1}else C.type=\"path\",T&&k&&b(E,T,k),C.path=x(E),n=null;return C}t.exports={newShapes:function(t,e){if(t.length&&t[0][0]){var r=e.gd,n=e.isActiveShape,a=e.dragmode,o=(r.layout||{}).shapes||[];if(!i(a)&&void 0!==n){var s=r._fullLayout._activeShapeIndex;if(s<o.length)switch(r._fullLayout.shapes[s].type){case\"rect\":a=\"drawrect\";break;case\"circle\":a=\"drawcircle\";break;case\"line\":a=\"drawline\";break;case\"path\":var l=o[s].path||\"\";a=\"Z\"===l[l.length-1]?\"drawclosedpath\":\"drawopenpath\"}}var c=w(t,e,a);g(r);for(var u=e.editHelpers,h=(u||{}).modifyItem,f=[],p=0;p<o.length;p++){var d=r._fullLayout.shapes[p];if(f[p]=d._input,void 0!==n&&p===r._fullLayout._activeShapeIndex){var m=c;switch(d.type){case\"line\":case\"rect\":case\"circle\":h(\"x0\",m.x0-(d.x0shift||0)),h(\"x1\",m.x1-(d.x1shift||0)),h(\"y0\",m.y0-(d.y0shift||0)),h(\"y1\",m.y1-(d.y1shift||0));break;case\"path\":h(\"path\",m.path)}}}return void 0===n?(f.push(c),f):u?u.getUpdateObj():{}}},createShapeObj:w}},78534:function(t){\"use strict\";t.exports={clearOutlineControllers:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".outline-controllers\").remove()},clearOutline:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".select-outline\").remove(),t._fullLayout._outlining=!1}}},49728:function(t,e,r){\"use strict\";var n=r(2956),i=r(34809),a=r(29714);function o(t,e){var r=0;return(e=e||0)&&t&&(\"category\"===t.type||\"multicategory\"===t.type)&&(r=(t.r2p(1)-t.r2p(0))*e),r}e.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},e.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},e.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},e.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},e.extractPathCoords=function(t,e,r){var a=[];return t.match(n.segmentRE).forEach((function(t){var o=e[t.charAt(0)].drawn;if(void 0!==o){var s=t.substr(1).match(n.paramRE);if(s&&!(s.length<o)){var l=s[o],c=r?l:i.cleanNumber(l);a.push(c)}}})),a},e.getDataToPixel=function(t,r,n,i,a){var s,l=t._fullLayout._size;if(r)if(\"domain\"===a)s=function(t){return r._length*(i?1-t:t)+r._offset};else{var c=e.shapePositionToRange(r);s=function(t){var e=o(r,n);return r._offset+r.r2p(c(t,!0))+e},\"date\"===r.type&&(s=e.decodeDate(s))}else s=i?function(t){return l.t+l.h*(1-t)}:function(t){return l.l+l.w*t};return s},e.getPixelToData=function(t,r,n,i){var a,o=t._fullLayout._size;if(r)if(\"domain\"===i)a=function(t){var e=(t-r._offset)/r._length;return n?1-e:e};else{var s=e.rangeToShapePosition(r);a=function(t){return s(r.p2r(t-r._offset))}}else a=n?function(t){return 1-(t-o.t)/o.h}:function(t){return(t-o.l)/o.w};return a},e.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n},e.makeShapesOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.shapes[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return n?n._hadPlotinfo=!0:(n={},r.xref&&\"paper\"!==r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&\"paper\"!==r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),n.xsizemode=r.xsizemode,n.ysizemode=r.ysizemode,n.xanchor=r.xanchor,n.yanchor=r.yanchor,{options:r,plotinfo:n}},e.makeSelectionsOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.selections[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return n?n._hadPlotinfo=!0:(n={},r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),{options:r,plotinfo:n}},e.getPathString=function(t,r){var s,l,c,u,h,f,p,d,m=r.type,g=a.getRefType(r.xref),y=a.getRefType(r.yref),v=a.getFromId(t,r.xref),x=a.getFromId(t,r.yref),_=t._fullLayout._size,b=o(v,r.x0shift),w=o(v,r.x1shift),T=o(x,r.y0shift),k=o(x,r.y1shift);if(v?\"domain\"===g?l=function(t){return v._offset+v._length*t}:(s=e.shapePositionToRange(v),l=function(t){return v._offset+v.r2p(s(t,!0))}):l=function(t){return _.l+_.w*t},x?\"domain\"===y?u=function(t){return x._offset+x._length*(1-t)}:(c=e.shapePositionToRange(x),u=function(t){return x._offset+x.r2p(c(t,!0))}):u=function(t){return _.t+_.h*(1-t)},\"path\"===m)return v&&\"date\"===v.type&&(l=e.decodeDate(l)),x&&\"date\"===x.type&&(u=e.decodeDate(u)),function(t,e,r){var a=t.path,o=t.xsizemode,s=t.ysizemode,l=t.xanchor,c=t.yanchor;return a.replace(n.segmentRE,(function(t){var a=0,u=t.charAt(0),h=n.paramIsX[u],f=n.paramIsY[u],p=n.numParams[u],d=t.substr(1).replace(n.paramRE,(function(t){return h[a]?t=\"pixel\"===o?e(l)+Number(t):e(t):f[a]&&(t=\"pixel\"===s?r(c)-Number(t):r(t)),++a>p&&(t=\"X\"),t}));return a>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),u+d}))}(r,l,u);if(\"pixel\"===r.xsizemode){var A=l(r.xanchor);h=A+r.x0+b,f=A+r.x1+w}else h=l(r.x0)+b,f=l(r.x1)+w;if(\"pixel\"===r.ysizemode){var M=u(r.yanchor);p=M-r.y0+T,d=M-r.y1+k}else p=u(r.y0)+T,d=u(r.y1)+k;if(\"line\"===m)return\"M\"+h+\",\"+p+\"L\"+f+\",\"+d;if(\"rect\"===m)return\"M\"+h+\",\"+p+\"H\"+f+\"V\"+d+\"H\"+h+\"Z\";var S=(h+f)/2,E=(p+d)/2,C=Math.abs(S-h),L=Math.abs(E-p),I=\"A\"+C+\",\"+L,P=S+C+\",\"+E;return\"M\"+P+I+\" 0 1,1 \"+S+\",\"+(E-L)+I+\" 0 0,1 \"+P+\"Z\"}},43701:function(t,e,r){\"use strict\";var n=r(28231);t.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:r(43144),supplyLayoutDefaults:r(74367),supplyDrawNewShapeDefaults:r(85522),includeBasePlot:r(20706)(\"shapes\"),calcAutorange:r(44959),draw:n.draw,drawOne:n.drawOne}},41235:function(t){\"use strict\";function e(t,e){return e?e.d2l(t):t}function r(t,e){return e?e.l2d(t):t}function n(t){return t.x0shift||0}function i(t){return t.x1shift||0}function a(t){return t.y0shift||0}function o(t){return t.y1shift||0}function s(t,r){return e(t.x1,r)+i(t)-e(t.x0,r)-n(t)}function l(t,r,n){return e(t.y1,n)+o(t)-e(t.y0,n)-a(t)}t.exports={x0:function(t){return t.x0},x1:function(t){return t.x1},y0:function(t){return t.y0},y1:function(t){return t.y1},slope:function(t,e,r){return\"line\"!==t.type?void 0:l(t,0,r)/s(t,e)},dx:s,dy:l,width:function(t,e){return Math.abs(s(t,e))},height:function(t,e,r){return Math.abs(l(t,0,r))},length:function(t,e,r){return\"line\"!==t.type?void 0:Math.sqrt(Math.pow(s(t,e),2)+Math.pow(l(t,0,r),2))},xcenter:function(t,a){return r((e(t.x1,a)+i(t)+e(t.x0,a)+n(t))/2,a)},ycenter:function(t,n,i){return r((e(t.y1,i)+o(t)+e(t.y0,i)+a(t))/2,i)}}},8606:function(t,e,r){\"use strict\";var n=r(80337),i=r(57891),a=r(93049).extendDeepAll,o=r(13582).overrideAll,s=r(49722),l=r(78032).templatedArray,c=r(64194),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});t.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},64194:function(t){\"use strict\";t.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},74537:function(t,e,r){\"use strict\";var n=r(34809),i=r(59008),a=r(8606),o=r(64194).name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}t.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},44097:function(t,e,r){\"use strict\";var n=r(45568),i=r(44122),a=r(78766),o=r(62203),s=r(34809),l=s.strTranslate,c=r(30635),u=r(78032).arrayEditor,h=r(64194),f=r(4530),p=f.LINE_SPACING,d=f.FROM_TL,m=f.FROM_BR;function g(t){return h.autoMarginIdRoot+t._index}function y(t){return t._index}function v(t,e){var r=o.tester.selectAll(\"g.\"+h.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(h.labelGroupClass,!0);var a=0,l=0;r.each((function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);l=Math.max(l,i.height),a=Math.max(a,i.width)}})),r.remove();var u=e._dims={};u.inputAreaWidth=Math.max(h.railWidth,h.gripHeight);var f=t._fullLayout._size;u.lx=f.l+f.w*e.x,u.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?u.outerLength=Math.round(f.w*e.len):u.outerLength=e.len,u.inputAreaStart=0,u.inputAreaLength=Math.round(u.outerLength-e.pad.l-e.pad.r);var p=(u.inputAreaLength-2*h.stepInset)/(e._stepCount-1),y=a+h.labelPadding;if(u.labelStride=Math.max(1,Math.ceil(y/p)),u.labelHeight=l,u.currentValueMaxWidth=0,u.currentValueHeight=0,u.currentValueTotalHeight=0,u.currentValueMaxLines=1,e.currentvalue.visible){var v=o.tester.append(\"g\");r.each((function(t){var r=x(v,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=c.lineCount(r);u.currentValueMaxWidth=Math.max(u.currentValueMaxWidth,Math.ceil(n.width)),u.currentValueHeight=Math.max(u.currentValueHeight,Math.ceil(n.height)),u.currentValueMaxLines=Math.max(u.currentValueMaxLines,i)})),u.currentValueTotalHeight=u.currentValueHeight+e.currentvalue.offset,v.remove()}u.height=u.currentValueTotalHeight+h.tickOffset+e.ticklen+h.labelOffset+u.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(u.lx-=u.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(u.lx-=u.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(u.ly-=u.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(u.ly-=u.height/2,w=\"middle\"),u.outerLength=Math.ceil(u.outerLength),u.height=Math.ceil(u.height),u.lx=Math.round(u.lx),u.ly=Math.round(u.ly);var T={y:e.y,b:u.height*m[w],t:u.height*d[w]};\"fraction\"===e.lenmode?(T.l=0,T.xl=e.x-e.len*d[_],T.r=0,T.xr=e.x+e.len*m[_]):(T.x=e.x,T.l=u.outerLength*d[_],T.r=u.outerLength*m[_]),i.autoMargin(t,g(e),T)}function x(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-h.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=h.currentValueInset,i=\"left\"}var l=s.ensureSingle(t,\"text\",h.labelClass,(function(t){t.attr({\"text-anchor\":i,\"data-notex\":1})})),u=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)u+=r;else{var f=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(f=s.templateString(f,d)),u+=f}e.currentvalue.suffix&&(u+=e.currentvalue.suffix),l.call(o.font,e.currentvalue.font).text(u).call(c.convertToTspans,e._gd);var m=c.lineCount(l),g=(a.currentValueMaxLines+1-m)*e.currentvalue.font.size*p;return c.positionText(l,n,g),l}}function _(t,e,r){s.ensureSingle(t,\"rect\",h.gripRectClass,(function(n){n.call(A,e,t,r).style(\"pointer-events\",\"all\")})).attr({width:h.gripWidth,height:h.gripHeight,rx:h.gripRadius,ry:h.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",h.labelClass,(function(t){t.attr({\"text-anchor\":\"middle\",\"data-notex\":1})})),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(c.convertToTspans,r._gd),n}function w(t,e){var r=s.ensureSingle(t,\"g\",h.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+h.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(h.labelGroupClass,!0),a.exit().remove(),a.each((function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,E(e,t.fraction),h.tickOffset+e.ticklen+e.font.size*p+h.labelOffset+i.currentValueTotalHeight)}))}function T(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,u(t.layout,h.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(S,r,o),e.call(x,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame((function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)}))))}function A(t,e,r){if(!e._context.staticPlot){var i=r.node(),o=n.select(e);t.on(\"mousedown\",l),t.on(\"touchstart\",l)}function s(){return r.data()[0]}function l(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+h.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=C(t,n.mouse(i)[0]);function u(){var t=s(),a=C(t,n.mouse(i)[0]);T(e,r,t,a,!1)}function f(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),o.on(\"touchend\",null),o.on(\"touchmove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})}T(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",u),o.on(\"touchmove\",u),o.on(\"mouseup\",f),o.on(\"touchend\",f)}}function M(t,e){var r=t.selectAll(\"rect.\"+h.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(h.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each((function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,E(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?h.tickOffset:h.minorTickOffset)+i.currentValueTotalHeight)}))}function S(t,e,r){for(var n=t.select(\"rect.\"+h.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=E(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",l(o-.5*h.gripWidth,e._dims.currentValueTotalHeight))}}function E(t,e){var r=t._dims;return r.inputAreaStart+h.stepInset+(r.inputAreaLength-2*h.stepInset)*Math.min(1,Math.max(0,e))}function C(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-h.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*h.stepInset-2*r.inputAreaStart)))}function L(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",h.railTouchRectClass,(function(n){n.call(A,e,t,r).style(\"pointer-events\",\"all\")}));i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,h.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function I(t,e){var r=e._dims,n=r.inputAreaLength-2*h.railInset,i=s.ensureSingle(t,\"rect\",h.railRectClass);i.attr({width:n,height:h.railWidth,rx:h.railRadius,ry:h.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,h.railInset,.5*(r.inputAreaWidth-h.railWidth)+r.currentValueTotalHeight)}t.exports=function(t){var e=t._context.staticPlot,r=t._fullLayout,a=function(t,e){for(var r=t[h.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(r,t),s=r._infolayer.selectAll(\"g.\"+h.containerClassName).data(a.length>0?[0]:[]);function l(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(s.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",e?null:\"ew-resize\"),s.exit().each((function(){n.select(this).selectAll(\"g.\"+h.groupClassName).each(l)})).remove(),0!==a.length){var c=s.selectAll(\"g.\"+h.groupClassName).data(a,y);c.enter().append(\"g\").classed(h.groupClassName,!0),c.exit().each(l).remove();for(var u=0;u<a.length;u++){var f=a[u];v(t,f)}c.each((function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,(function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))})),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index),e.call(x,r).call(I,r).call(w,r).call(M,r).call(L,t,r).call(_,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(S,r,!1),e.call(x,r)}(t,n.select(this),e)}))}}},15359:function(t,e,r){\"use strict\";var n=r(64194);t.exports={moduleType:\"component\",name:n.name,layoutAttributes:r(8606),supplyLayoutDefaults:r(74537),draw:r(44097)}},17240:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(44122),o=r(33626),s=r(34809),l=s.strTranslate,c=r(62203),u=r(78766),h=r(30635),f=r(20438),p=r(4530).OPPOSITE_SIDE,d=/ [XY][0-9]* /;t.exports={draw:function(t,e,r){var m,g=t._fullLayout,y=r.propContainer,v=r.propName,x=r.placeholder,_=r.traceIndex,b=r.avoid||{},w=r.attributes,T=r.transform,k=r.containerGroup,A=1,M=y.title,S=(M&&M.text?M.text:\"\").trim(),E=!1,C=M&&M.font?M.font:{},L=C.family,I=C.size,P=C.color,z=C.weight,O=C.style,D=C.variant,R=C.textcase,F=C.lineposition,B=C.shadow,N=!!r.subtitlePropName,j=r.subtitlePlaceholder,U=(y.title||{}).subtitle||{text:\"\",font:{}},V=U.text.trim(),q=!1,H=1,G=U.font,Z=G.family,W=G.size,Y=G.color,X=G.weight,$=G.style,J=G.variant,K=G.textcase,Q=G.lineposition,tt=G.shadow;\"title.text\"===v?m=\"titleText\":-1!==v.indexOf(\"axis\")?m=\"axisTitleText\":v.indexOf(!0)&&(m=\"colorbarTitleText\");var et=t._context.edits[m];function rt(t,e){return void 0!==t&&void 0!==e&&t.replace(d,\" % \")===e.replace(d,\" % \")}\"\"===S?A=0:rt(S,x)&&(et||(S=\"\"),A=.2,E=!0),N&&(\"\"===V?H=0:rt(V,j)&&(et||(V=\"\"),H=.2,q=!0)),r._meta?S=s.templateString(S,r._meta):g._meta&&(S=s.templateString(S,g._meta));var nt,it=S||V||et;k||(k=s.ensureSingle(g._infolayer,\"g\",\"g-\"+e),nt=g._hColorbarMoveTitle);var at=k.selectAll(\"text.\"+e).data(it?[0]:[]);at.enter().append(\"text\"),at.text(S).attr(\"class\",e),at.exit().remove();var ot=null,st=e+\"-subtitle\",lt=V||et;if(N&&lt&&((ot=k.selectAll(\"text.\"+st).data(lt?[0]:[])).enter().append(\"text\"),ot.text(V).attr(\"class\",st),ot.exit().remove()),!it)return k;function ct(t,e){s.syncOrAsync([ut,ht],{title:t,subtitle:e})}function ut(r){var i,o=r.title,f=r.subtitle;if(!T&&nt&&(T={}),T?(i=\"\",T.rotate&&(i+=\"rotate(\"+[T.rotate,w.x,w.y]+\")\"),(T.offset||nt)&&(i+=l(0,(T.offset||0)-(nt||0)))):i=null,o.attr(\"transform\",i),o.style(\"opacity\",A*u.opacity(P)).call(c.font,{color:u.rgb(P),size:n.round(I,2),family:L,weight:z,style:O,variant:D,textcase:R,shadow:B,lineposition:F}).attr(w).call(h.convertToTspans,t,(function(t){if(t){var e=n.select(t.node().parentNode).select(\".\"+st);if(!e.empty()){var r=t.node().getBBox();if(r.height){var i=r.y+r.height+1.6*W;e.attr(\"y\",i)}}}})),f){var p=k.select(\".\"+e+\"-math-group\"),d=o.node().getBBox(),m=p.node()?p.node().getBBox():void 0,g=m?m.y+m.height+1.6*W:d.y+d.height+1.6*W,y=s.extendFlat({},w,{y:g});f.attr(\"transform\",i),f.style(\"opacity\",H*u.opacity(Y)).call(c.font,{color:u.rgb(Y),size:n.round(W,2),family:Z,weight:X,style:$,variant:J,textcase:K,shadow:tt,lineposition:Q}).attr(y).call(h.convertToTspans,t)}return a.previousPromises(t)}function ht(e){var r=e.title,a=n.select(r.node().parentNode);if(b&&b.selection&&b.side&&S){a.attr(\"transform\",null);var o=p[b.side],u=\"left\"===b.side||\"top\"===b.side?-1:1,h=i(b.pad)?b.pad:2,f=c.bBox(a.node()),d={t:0,b:0,l:0,r:0},m=t._fullLayout._reservedMargin;for(var v in m)for(var x in m[v]){var _=m[v][x];d[x]=Math.max(d[x],_)}var w={left:d.l,top:d.t,right:g.width-d.r,bottom:g.height-d.b},T=b.maxShift||u*(w[b.side]-f[b.side]),k=0;if(T<0)k=T;else{var A=b.offsetLeft||0,M=b.offsetTop||0;f.left-=A,f.right-=A,f.top-=M,f.bottom-=M,b.selection.each((function(){var t=c.bBox(this);s.bBoxIntersect(f,t,h)&&(k=Math.max(k,u*(t[b.side]-f[o])+h))})),k=Math.min(T,k),y._titleScoot=Math.abs(k)}if(k>0||T<0){var E={left:[-k,0],right:[k,0],top:[0,-k],bottom:[0,k]}[b.side];a.attr(\"transform\",l(E[0],E[1]))}}}function ft(t,e){t.text(e).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(f.SHOW_PLACEHOLDER).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(f.HIDE_PLACEHOLDER).style(\"opacity\",0)}))}if(at.call(ct,ot),et&&(S?at.on(\".opacity\",null):(ft(at,x),E=!0),at.call(h.makeEditable,{gd:t}).on(\"edit\",(function(e){void 0!==_?o.call(\"_guiRestyle\",t,v,e,_):o.call(\"_guiRelayout\",t,v,e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(ct)})).on(\"input\",(function(t){this.text(t||\" \").call(h.positionText,w.x,w.y)})),N)){if(N&&!S){var pt=at.node().getBBox(),dt=pt.y+pt.height+1.6*W;ot.attr(\"y\",dt)}V?ot.on(\".opacity\",null):(ft(ot,j),q=!0),ot.call(h.makeEditable,{gd:t}).on(\"edit\",(function(e){o.call(\"_guiRelayout\",t,\"title.subtitle.text\",e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(ct)})).on(\"input\",(function(t){this.text(t||\" \").call(h.positionText,ot.attr(\"x\"),ot.attr(\"y\"))}))}return at.classed(\"js-placeholder\",E),ot&&ot.classed(\"js-placeholder\",q),k},SUBTITLE_PADDING_EM:1.6,SUBTITLE_PADDING_MATHJAX_EM:1.6}},85389:function(t,e,r){\"use strict\";var n=r(80337),i=r(10229),a=r(93049).extendFlat,o=r(13582).overrideAll,s=r(57891),l=r(78032).templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},args2:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});t.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},71559:function(t){\"use strict\";t.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\u25c4\",right:\"\u25ba\",up:\"\u25b2\",down:\"\u25bc\"}}},42746:function(t,e,r){\"use strict\";var n=r(34809),i=r(59008),a=r(85389),o=r(71559).name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"args2\"),r(\"label\"),r(\"execute\"))}t.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},40974:function(t,e,r){\"use strict\";var n=r(45568),i=r(44122),a=r(78766),o=r(62203),s=r(34809),l=r(30635),c=r(78032).arrayEditor,u=r(4530).LINE_SPACING,h=r(71559),f=r(21736);function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function m(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?y(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),g(t,n,i,a,e),s||y(t,n,i,a,e))}function g(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,(function(t){t.style(\"pointer-events\",\"all\")})),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(v,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,(function(t){t.attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])})).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",(function(){r.call(S,String(d(r,i)?-1:i._index)),y(t,e,r,n,i)})),a.on(\"mouseover\",(function(){a.call(w)})),a.on(\"mouseout\",(function(){a.call(T,i)})),o.setTranslate(e,l.lx,l.ly)}function y(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,g=0,y=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?g=y.headerHeight+h.gapButtonHeader:d=y.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(g=-h.gapButtonHeader+h.gapButton-y.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-y.openWidth);var _={x:y.lx+d+o.pad.l,y:y.ly+g+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},k={l:_.x+o.borderwidth,t:_.y+o.borderwidth};u.each((function(s,l){var c=n.select(this);c.call(v,o,s,t).call(M,o,_),c.on(\"click\",(function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(m(t,o,0,e,r,a,-1),i.executeAPICommand(t,s.method,s.args2)):(m(t,o,0,e,r,a,l),i.executeAPICommand(t,s.method,s.args))),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))})),c.on(\"mouseover\",(function(){c.call(w)})),c.on(\"mouseout\",(function(){c.call(T,o),u.call(b,o)}))})),u.call(b,o),x?(k.w=Math.max(y.openWidth,y.headerWidth),k.h=_.y-k.t):(k.w=_.x-k.l,k.h=Math.max(y.openHeight,y.headerHeight)),k.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,k):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){e=!1,r||t.disable()})),r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){r=!1,e||t.disable()}))}(a))}function v(t,e,r,n){t.call(x,e).call(_,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,(function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})})).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function _(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,(function(t){t.attr({\"text-anchor\":\"start\",\"data-notex\":1})})),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function b(t,e){var r=e.active;t.each((function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)}))}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function T(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function k(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each((function(i,a){var s=n.select(this);s.call(v,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),m=e.font.size*u,g=l.lineCount(f),y=Math.max(m*g,h.minHeight)+h.textOffsetY;y=Math.ceil(y),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=y,r.height1=Math.max(r.height1,y),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=y+h.gapButton,r.openHeight+=y+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,y),r.openHeight=r.totalHeight)})),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var m=\"left\";s.isRightAnchor(e)&&(r.lx-=f,m=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,m=\"center\");var g=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,g=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,g=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[m]||0),r:f*({left:1,center:.5}[m]||0),b:p*({top:1,middle:.5}[g]||0),t:p*({bottom:1,middle:.5}[g]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var m=e.font.size*u,g=(l.lineCount(a)-1)*m/2;l.positionText(a,h.textOffsetX,d/2-g+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}t.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each((function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)})).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,(function(t){t.style(\"pointer-events\",\"all\")})),u=0;u<r.length;u++){var v=r[u];k(t,v)}var x=\"updatemenus\"+e._uid,_=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each((function(t){c.call(S),a(t)})).remove(),l.each((function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,(function(n){m(t,e,e.buttons[n.index],r,a,_,n.index,!0)})),\"dropdown\"===e.type?(g(t,r,c,_,e),d(c,e)&&y(t,r,c,_,e)):y(t,r,null,null,e)}))}}},46230:function(t,e,r){\"use strict\";var n=r(71559);t.exports={moduleType:\"component\",name:n.name,layoutAttributes:r(85389),supplyLayoutDefaults:r(42746),draw:r(40974)}},21736:function(t,e,r){\"use strict\";t.exports=s;var n=r(45568),i=r(78766),a=r(62203),o=r(34809);function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,m=this.position.w,g=this.position.t,y=this.position.h,v=this.position.direction,x=\"down\"===v,_=\"left\"===v,b=\"up\"===v,w=m,T=y;x||_||\"right\"===v||b||(this.position.direction=\"down\",x=!0),x||b?(h=(u=d)+w,x?(f=g,T=(p=Math.min(f+T,c))-f):T=(p=g+T)-(f=Math.max(p-T,0))):(p=(f=g)+T,_?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:T};var k=m>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=g+y;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(k?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),k?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=y>T,I=s.barWidth+2*s.barPad,P=s.barLength+2*s.barPad,z=d+m,O=g;z+I>l&&(z=l-I);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:O,width:I,height:P}),this._vbarYMin=O+P/2,this._vbarTranslateMax=T-P):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+I+.5:h+.5,N=f-.5,j=k?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(k||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),k||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:g,width:m,height:y})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),k||L){var V=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault()})).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()})).on(\"drag\",this._onBarDrag.bind(this));k&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},4530:function(t){\"use strict\";t.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},35081:function(t){\"use strict\";t.exports={axisRefDescription:function(t,e,r){return[\"If set to a\",t,\"axis id (e.g. *\"+t+\"* or\",\"*\"+t+\"2*), the `\"+t+\"` position refers to a\",t,\"coordinate. If set to *paper*, the `\"+t+\"`\",\"position refers to the distance from the\",e,\"of the plotting\",\"area in normalized coordinates where *0* (*1*) corresponds to the\",e,\"(\"+r+\"). If set to a\",t,\"axis ID followed by\",\"*domain* (separated by a space), the position behaves like for\",\"*paper*, but refers to the distance in fractions of the domain\",\"length from the\",e,\"of the domain of that axis: e.g.,\",\"*\"+t+\"2 domain* refers to the domain of the second\",t,\" axis and a\",t,\"position of 0.5 refers to the\",\"point between the\",e,\"and the\",r,\"of the domain of the\",\"second\",t,\"axis.\"].join(\" \")}}},20909:function(t){\"use strict\";t.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\u25bc\"}}},87296:function(t){\"use strict\";t.exports={FORMAT_LINK:\"https://github.com/d3/d3-format/tree/v1.4.5#d3-format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-time-format/tree/v2.2.3#locale_format\"}},20726:function(t){\"use strict\";t.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},84770:function(t){\"use strict\";t.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},49467:function(t){\"use strict\";t.exports={circle:\"\u25cf\",\"circle-open\":\"\u25cb\",square:\"\u25a0\",\"square-open\":\"\u25a1\",diamond:\"\u25c6\",\"diamond-open\":\"\u25c7\",cross:\"+\",x:\"\u274c\"}},20438:function(t){\"use strict\";t.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},63821:function(t){\"use strict\";t.exports={BADNUM:void 0,FP_SAFE:1e-4*Number.MAX_VALUE,ONEMAXYEAR:316224e5,ONEAVGYEAR:315576e5,ONEMINYEAR:31536e6,ONEMAXQUARTER:79488e5,ONEAVGQUARTER:78894e5,ONEMINQUARTER:76896e5,ONEMAXMONTH:26784e5,ONEAVGMONTH:26298e5,ONEMINMONTH:24192e5,ONEWEEK:6048e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,ONEMILLI:1,ONEMICROSEC:.001,EPOCHJD:2440587.5,ALMOST_EQUAL:.999999,LOG_CLIP:10,MINUS_SIGN:\"\u2212\"}},1837:function(t,e){\"use strict\";e.CSS_DECLARATIONS=[[\"image-rendering\",\"optimizeSpeed\"],[\"image-rendering\",\"-moz-crisp-edges\"],[\"image-rendering\",\"-o-crisp-edges\"],[\"image-rendering\",\"-webkit-optimize-contrast\"],[\"image-rendering\",\"optimize-contrast\"],[\"image-rendering\",\"crisp-edges\"],[\"image-rendering\",\"pixelated\"]],e.STYLE=e.CSS_DECLARATIONS.map((function(t){return t.join(\": \")+\"; \"})).join(\"\")},62972:function(t,e){\"use strict\";e.xmlns=\"http://www.w3.org/2000/xmlns/\",e.svg=\"http://www.w3.org/2000/svg\",e.xlink=\"http://www.w3.org/1999/xlink\",e.svgAttrs={xmlns:e.svg,\"xmlns:xlink\":e.xlink}},17430:function(t,e,r){\"use strict\";e.version=r(29697).version,r(71116),r(6713);for(var n=r(33626),i=e.register=n.register,a=r(90742),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(e[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(r(69693)),i([r(3599),r(83348),r(44844),r(43701),r(15553),r(46230),r(15359),r(55429),r(44453),r(83595),r(77901),r(88856),r(96919),r(82494),r(32141),r(95433)]),i([r(30227),r(44611)]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(i(window.PlotlyLocales),delete window.PlotlyLocales),e.Icons=r(35188);var c=r(32141),u=r(44122);e.Plots={resize:u.resize,graphJson:u.graphJson,sendDataToCloud:u.sendDataToCloud},e.Fx={hover:c.hover,unhover:c.unhover,loneHover:c.loneHover,loneUnhover:c.loneUnhover},e.Snapshot=r(6170),e.PlotSchema=r(57297)},35188:function(t){\"use strict\";t.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawopenpath:{width:70,height:70,path:\"M33.21,85.65a7.31,7.31,0,0,1-2.59-.48c-8.16-3.11-9.27-19.8-9.88-41.3-.1-3.58-.19-6.68-.35-9-.15-2.1-.67-3.48-1.43-3.79-2.13-.88-7.91,2.32-12,5.86L3,32.38c1.87-1.64,11.55-9.66,18.27-6.9,2.13.87,4.75,3.14,5.17,9,.17,2.43.26,5.59.36,9.25a224.17,224.17,0,0,0,1.5,23.4c1.54,10.76,4,12.22,4.48,12.4.84.32,2.79-.46,5.76-3.59L43,80.07C41.53,81.57,37.68,85.64,33.21,85.65ZM74.81,69a11.34,11.34,0,0,0,6.09-6.72L87.26,44.5,74.72,32,56.9,38.35c-2.37.86-5.57,3.42-6.61,6L38.65,72.14l8.42,8.43ZM55,46.27a7.91,7.91,0,0,1,3.64-3.17l14.8-5.3,8,8L76.11,60.6l-.06.19a6.37,6.37,0,0,1-3,3.43L48.25,74.59,44.62,71Zm16.57,7.82A6.9,6.9,0,1,0,64.64,61,6.91,6.91,0,0,0,71.54,54.09Zm-4.05,0a2.85,2.85,0,1,1-2.85-2.85A2.86,2.86,0,0,1,67.49,54.09Zm-4.13,5.22L60.5,56.45,44.26,72.7l2.86,2.86ZM97.83,35.67,84.14,22l-8.57,8.57L89.26,44.24Zm-13.69-8,8,8-2.85,2.85-8-8Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawclosedpath:{width:90,height:90,path:\"M88.41,21.12a26.56,26.56,0,0,0-36.18,0l-2.07,2-2.07-2a26.57,26.57,0,0,0-36.18,0,23.74,23.74,0,0,0,0,34.8L48,90.12a3.22,3.22,0,0,0,4.42,0l36-34.21a23.73,23.73,0,0,0,0-34.79ZM84,51.24,50.16,83.35,16.35,51.25a17.28,17.28,0,0,1,0-25.47,20,20,0,0,1,27.3,0l4.29,4.07a3.23,3.23,0,0,0,4.44,0l4.29-4.07a20,20,0,0,1,27.3,0,17.27,17.27,0,0,1,0,25.46ZM66.76,47.68h-33v6.91h33ZM53.35,35H46.44V68h6.91Z\",transform:\"matrix(1 0 0 1 -5 -5)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawline:{width:70,height:70,path:\"M60.64,62.3a11.29,11.29,0,0,0,6.09-6.72l6.35-17.72L60.54,25.31l-17.82,6.4c-2.36.86-5.57,3.41-6.6,6L24.48,65.5l8.42,8.42ZM40.79,39.63a7.89,7.89,0,0,1,3.65-3.17l14.79-5.31,8,8L61.94,54l-.06.19a6.44,6.44,0,0,1-3,3.43L34.07,68l-3.62-3.63Zm16.57,7.81a6.9,6.9,0,1,0-6.89,6.9A6.9,6.9,0,0,0,57.36,47.44Zm-4,0a2.86,2.86,0,1,1-2.85-2.85A2.86,2.86,0,0,1,53.32,47.44Zm-4.13,5.22L46.33,49.8,30.08,66.05l2.86,2.86ZM83.65,29,70,15.34,61.4,23.9,75.09,37.59ZM70,21.06l8,8-2.84,2.85-8-8ZM87,80.49H10.67V87H87Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawrect:{width:80,height:80,path:\"M78,22V79H21V22H78m9-9H12V88H87V13ZM68,46.22H31V54H68ZM53,32H45.22V69H53Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},drawcircle:{width:80,height:80,path:\"M50,84.72C26.84,84.72,8,69.28,8,50.3S26.84,15.87,50,15.87,92,31.31,92,50.3,73.16,84.72,50,84.72Zm0-60.59c-18.6,0-33.74,11.74-33.74,26.17S31.4,76.46,50,76.46,83.74,64.72,83.74,50.3,68.6,24.13,50,24.13Zm17.15,22h-34v7.11h34Zm-13.8-13H46.24v34h7.11Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},eraseshape:{width:80,height:80,path:\"M82.77,78H31.85L6,49.57,31.85,21.14H82.77a8.72,8.72,0,0,1,8.65,8.77V69.24A8.72,8.72,0,0,1,82.77,78ZM35.46,69.84H82.77a.57.57,0,0,0,.49-.6V29.91a.57.57,0,0,0-.49-.61H35.46L17,49.57Zm32.68-34.7-24,24,5,5,24-24Zm-19,.53-5,5,24,24,5-5Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:[\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'>\",\"<defs>\",\" <style>\",\"  .cls-0{fill:#000;}\",\"  .cls-1{fill:#FFF;}\",\"  .cls-2{fill:#F26;}\",\"  .cls-3{fill:#D69;}\",\"  .cls-4{fill:#BAC;}\",\"  .cls-5{fill:#9EF;}\",\" </style>\",\"</defs>\",\" <title>plotly-logomark</title>\",\" <g id='symbol'>\",\"  <rect class='cls-0' x='0' y='0' width='132' height='132' rx='18' ry='18'/>\",\"  <circle class='cls-5' cx='102' cy='30' r='6'/>\",\"  <circle class='cls-4' cx='78' cy='30' r='6'/>\",\"  <circle class='cls-4' cx='78' cy='54' r='6'/>\",\"  <circle class='cls-3' cx='54' cy='30' r='6'/>\",\"  <circle class='cls-2' cx='30' cy='30' r='6'/>\",\"  <circle class='cls-2' cx='30' cy='54' r='6'/>\",\"  <path class='cls-1' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/>\",\"  <path class='cls-1' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/>\",\"  <path class='cls-1' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/>\",\"  <path class='cls-1' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/>\",\" </g>\",\"</svg>\"].join(\"\")}}},32546:function(t,e){\"use strict\";e.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},e.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},e.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},e.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},e.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},e.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},44313:function(t,e,r){\"use strict\";var n=r(98953),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,m=l([r,n]);function g(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}m?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var y,v=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,v,r]+\" \"+g(t,e)}return m?y=null===p?\"M\"+g(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+g(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+g(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(y=\"M\"+g(d,u)+x(d,f,0),c&&(y+=\"L0,0Z\")):y=\"M\"+g(p,u)+\"L\"+g(d,u)+x(d,f,0)+\"L\"+g(p,f)+x(p,u,1)+\"Z\",y}t.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},87800:function(t,e,r){\"use strict\";var n=r(93229).decode,i=r(56174),a=Array.isArray,o=ArrayBuffer,s=DataView;function l(t){return o.isView(t)&&!(t instanceof s)}function c(t){return a(t)||l(t)}e.isTypedArray=l,e.isArrayOrTypedArray=c,e.isArray1D=function(t){return!c(t[0])},e.ensureArray=function(t,e){return a(t)||(t=[]),t.length=e,t};var u={u1c:\"undefined\"==typeof Uint8ClampedArray?void 0:Uint8ClampedArray,i1:\"undefined\"==typeof Int8Array?void 0:Int8Array,u1:\"undefined\"==typeof Uint8Array?void 0:Uint8Array,i2:\"undefined\"==typeof Int16Array?void 0:Int16Array,u2:\"undefined\"==typeof Uint16Array?void 0:Uint16Array,i4:\"undefined\"==typeof Int32Array?void 0:Int32Array,u4:\"undefined\"==typeof Uint32Array?void 0:Uint32Array,f4:\"undefined\"==typeof Float32Array?void 0:Float32Array,f8:\"undefined\"==typeof Float64Array?void 0:Float64Array};function h(t){return t.constructor===ArrayBuffer}function f(t,e,r){if(c(t)){if(c(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}u.uint8c=u.u1c,u.uint8=u.u1,u.int8=u.i1,u.uint16=u.u2,u.int16=u.i2,u.uint32=u.u4,u.int32=u.i4,u.float32=u.f4,u.float64=u.f8,e.isArrayBuffer=h,e.decodeTypedArraySpec=function(t){var e=[],r=function(t){return{bdata:t.bdata,dtype:t.dtype,shape:t.shape}}(t),i=r.dtype,a=u[i];if(!a)throw new Error('Error in dtype: \"'+i+'\"');var o=a.BYTES_PER_ELEMENT,s=r.bdata;h(s)||(s=n(s));var l=void 0===r.shape?[s.byteLength/o]:(\"\"+r.shape).split(\",\");l.reverse();var c,f,p=l.length,d=+l[0],m=o*d,g=0;if(1===p)e=new a(s);else if(2===p)for(c=+l[1],f=0;f<c;f++)e[f]=new a(s,g,d),g+=m;else{if(3!==p)throw new Error(\"ndim: \"+p+'is not supported with the shape:\"'+r.shape+'\"');c=+l[1];for(var y=+l[2],v=0;v<y;v++)for(e[v]=[],f=0;f<c;f++)e[v][f]=new a(s,g,d),g+=m}return e.bdata=r.bdata,e.dtype=r.dtype,e.shape=l.reverse().join(\",\"),t._inputArray=e,e},e.isTypedArraySpec=function(t){return i(t)&&t.hasOwnProperty(\"dtype\")&&\"string\"==typeof t.dtype&&t.hasOwnProperty(\"bdata\")&&(\"string\"==typeof t.bdata||h(t.bdata))&&(void 0===t.shape||t.hasOwnProperty(\"shape\")&&(\"string\"==typeof t.shape||\"number\"==typeof t.shape))},e.concat=function(){var t,e,r,n,i,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(n=arguments[r]).length)&&(e?c.push(n):(e=n,i=o),a(n)?t=!1:(u=!1,h?t!==n.constructor&&(t=!1):t=n.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)n=c[r],s.set(n,i),i+=n.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(n=c[r],l=0;l<n.length;l++)s[i+l]=n[l];i+=l}return s},e.maxRowLength=function(t){return f(t,Math.max,0)},e.minRowLength=function(t){return f(t,Math.min,1/0)}},44498:function(t,e,r){\"use strict\";var n=r(10721),i=r(63821).BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;t.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},34823:function(t){\"use strict\";t.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each((function(t){t.regl&&t.regl.clear({color:!0,depth:!0})}))}},23493:function(t){\"use strict\";t.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},34220:function(t,e,r){\"use strict\";var n=r(10721),i=r(65657),a=r(93049).extendFlat,o=r(9829),s=r(19017),l=r(78766),c=r(20438).DESELECTDIM,u=r(35632),h=r(90694).counter,f=r(98953).modHalf,p=r(87800).isArrayOrTypedArray,d=r(87800).isTypedArraySpec,m=r(87800).decodeTypedArraySpec;function g(t,r){var n=e.valObjectMeta[r.valType];if(r.arrayOk&&p(t))return!0;if(n.validateFunction)return n.validateFunction(t,r);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,r),a!==i}e.valObjectMeta={data_array:{coerceFunction:function(t,e,r){e.set(p(t)?t:d(t)?m(t):r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){d(t)&&(t=m(t)),!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){-1===(i.extras||[]).indexOf(t)?(d(t)&&(t=m(t)),t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)):e.set(t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){d(t)&&(t=m(t)),i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every((function(t){return i(t).isValid()}))?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(s.get(t,r))}},angle:{coerceFunction:function(t,e,r){d(t)&&(t=m(t)),\"auto\"===t?e.set(\"auto\"):n(t)?e.set(f(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||h(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!h(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(-1===(n.extras||[]).indexOf(t))if(\"string\"==typeof t){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(r);else e.set(t)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(d(t)?m(t):t)}},info_array:{coerceFunction:function(t,r,n,i){function a(t,r,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=r.dflt),e.valObjectMeta[r.valType].coerceFunction(t,a,n,r),i}if(d(t)&&(t=m(t)),p(t)){var o,s,l,c,u,h,f=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&p(t[0]),g=i.items,y=[],v=Array.isArray(g),x=v&&f&&p(g[0]),_=f&&v&&!x,b=v&&!_?g.length:t.length;if(n=Array.isArray(n)?n:[],f)for(o=0;o<b;o++)for(y[o]=[],l=p(t[o])?t[o]:[],u=_?g.length:v?g[o].length:l.length,s=0;s<u;s++)c=_?g[s]:v?g[o][s]:g,void 0!==(h=a(l[s],c,(n[o]||[])[s]))&&(y[o][s]=h);else for(o=0;o<b;o++)void 0!==(h=a(t[o],v?g[o]:g,n[o]))&&(y[o]=h);r.set(y)}else r.set(n)},validateFunction:function(t,e){if(!p(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!p(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!g(t[a][o],n?r[a][o]:r))return!1}else if(!g(t[a],n?r[a]:r))return!1;return!0}}},e.coerce=function(t,r,n,i,a){var o=u(n,i).get(),s=u(t,i),l=u(r,i),c=s.get(),h=r._template;if(void 0===c&&h&&(c=u(h,i).get(),h=0),void 0===a&&(a=o.dflt),o.arrayOk){if(p(c))return l.set(c),c;if(d(c))return c=m(c),l.set(c),c}var f=e.valObjectMeta[o.valType].coerceFunction;f(c,l,a,o);var y=l.get();return h&&y===a&&!g(c,o)&&(f(c=u(h,i).get(),l,a,o),y=l.get()),y},e.coerce2=function(t,r,n,i,a){var o=u(t,i),s=e.coerce(t,r,n,i,a);return null!=o.get()&&s},e.coerceFont=function(t,e,r,n){n||(n={}),r=a({},r);var i={family:t(e+\".family\",(r=a(r,n.overrideDflt||{})).family),size:t(e+\".size\",r.size),color:t(e+\".color\",r.color),weight:t(e+\".weight\",r.weight),style:t(e+\".style\",r.style)};if(n.noFontVariant||(i.variant=t(e+\".variant\",r.variant)),n.noFontLineposition||(i.lineposition=t(e+\".lineposition\",r.lineposition)),n.noFontTextcase||(i.textcase=t(e+\".textcase\",r.textcase)),!n.noFontShadow){var o=r.shadow;\"none\"===o&&n.autoShadowDflt&&(o=\"auto\"),i.shadow=t(e+\".shadow\",o)}return i},e.coercePattern=function(t,e,r,n){if(t(e+\".shape\")){t(e+\".solidity\"),t(e+\".size\");var i=\"overlay\"===t(e+\".fillmode\");if(!n){var a=t(e+\".bgcolor\",i?r:void 0);t(e+\".fgcolor\",i?l.contrast(a):r)}t(e+\".fgopacity\",i?.5:1)}},e.coerceHoverinfo=function(t,r,n){var i,a=r._module.attributes,s=a.hoverinfo?a:o,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return e.coerce(t,r,s,\"hoverinfo\",i)},e.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;void 0!==i&&(p(i)||t.selected||t.unselected||(r=i,n=c*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n))}},e.validate=g},92596:function(t,e,r){\"use strict\";var n,i,a=r(42696).DC,o=r(10721),s=r(48636),l=r(98953).mod,c=r(63821),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,m=c.EPOCHJD,g=r(33626),y=r(42696).aL,v=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,_=(new Date).getFullYear()-70;function b(t){return t&&g.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}e.dateTick0=function(t,r){var n=function(t,e){return b(t)?e?g.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:g.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"}(t,!!r);if(r<2)return n;var i=e.dateTime2ms(n,t);return i+=h*(r-1),e.ms2DateTime(i,0,t)},e.dfltRange=function(t){return b(t)?g.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},e.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},e.dateTime2ms=function(t,r){if(e.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=b(r),y=t.charAt(0);!c||\"G\"!==y&&\"g\"!==y||(t=t.substr(1),r=\"\");var w=c&&\"chinese\"===r.substr(0,7),T=t.match(w?x:v);if(!T)return u;var k=T[1],A=T[3]||\"1\",M=Number(T[5]||1),S=Number(T[7]||0),E=Number(T[9]||0),C=Number(T[11]||0);if(c){if(2===k.length)return u;var L;k=Number(k);try{var I=g.getComponentMethod(\"calendars\",\"getCal\")(r);if(w){var P=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=I.newDate(k,I.toMonthIndex(k,A,P),M)}else L=I.newDate(k,Number(A),M)}catch(t){return u}return L?(L.toJD()-m)*h+S*f+E*p+C*d:u}k=2===k.length?(Number(k)+2e3-_)%100+_:Number(k),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(k),z.getUTCMonth()!==A||z.getUTCDate()!==M?u:z.getTime()+C*d},n=e.MIN_MS=e.dateTime2ms(\"-9999\"),i=e.MAX_MS=e.dateTime2ms(\"9999-12-31 23:59:59.9999\"),e.isDateTime=function(t,r){return e.dateTime2ms(t,r)!==u};var T=90*h,k=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}e.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,v,x,_=Math.floor(10*l(t+.05,1)),w=Math.round(t-_/10);if(b(r)){var S=Math.floor(w/h)+m,E=Math.floor(l(t,h));try{a=g.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=y(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<T?Math.floor(E/f):0,s=e<T?Math.floor(E%f/p):0,c=e<k?Math.floor(E%p/d):0,v=e<A?E%d*10+_:0}else x=new Date(w),a=y(\"%Y-%m-%d\")(x),o=e<T?x.getUTCHours():0,s=e<T?x.getUTCMinutes():0,c=e<k?x.getUTCSeconds():0,v=e<A?10*x.getUTCMilliseconds()+_:0;return M(a,o,s,c,v)},e.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},e.cleanDate=function(t,r,n){if(t===u)return r;if(e.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(b(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),r;if(!(t=e.ms2DateTimeLocal(+t))&&void 0!==r)return r}else if(!e.isDateTime(t,n))return s.error(\"unrecognized date\",t),r;return t};var S=/%\\d?f/g,E=/%h/g,C={1:\"1\",2:\"1\",3:\"2\",4:\"2\"};function L(t,e,r,n){t=t.replace(S,(function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"}));var i=new Date(Math.floor(e+.05));if(t=t.replace(E,(function(){return C[r(\"%q\")(i)]})),b(n))try{t=g.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var I=[59,59.9,59.99,59.999,59.9999];e.formatDate=function(t,e,r,n,i,a){if(i=b(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),I[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+L(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return L(e,t,n,i)};var P=3*h;e.incrementMonth=function(t,e,r){r=b(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+m,a=g.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-m)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+P);return c.setUTCMonth(c.getUTCMonth()+e)+n-P},e.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=b(e)&&g.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+m)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},95425:function(t,e,r){\"use strict\";var n=r(45568),i=r(48636),a=r(15236),o=r(11191);function s(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function l(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}function c(t){var e=window.getComputedStyle(t,null),r=e.getPropertyValue(\"-webkit-transform\")||e.getPropertyValue(\"-moz-transform\")||e.getPropertyValue(\"-ms-transform\")||e.getPropertyValue(\"-o-transform\")||e.getPropertyValue(\"transform\");return\"none\"===r?null:r.replace(\"matrix\",\"\").replace(\"3d\",\"\").slice(1,-1).split(\",\").map((function(t){return+t}))}function u(t){for(var e=[];h(t);)e.push(t),t=t.parentNode,\"function\"==typeof ShadowRoot&&t instanceof ShadowRoot&&(t=t.host);return e}function h(t){return t&&(t instanceof Element||t instanceof HTMLElement)}t.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:s,addStyleRule:function(t,e){l(\"global\",t,e)},addRelatedStyleRule:l,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&s(r)},getFullTransformMatrix:function(t){var e=u(t),r=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];return e.forEach((function(t){var e=c(t);if(e){var n=a.convertCssMatrix(e);r=o.multiply(r,r,n)}})),r},getElementTransformMatrix:c,getElementAndAncestors:u,equalDomRects:function(t,e){return t&&e&&t.top===e.top&&t.left===e.left&&t.right===e.right&&t.bottom===e.bottom}}},68596:function(t,e,r){\"use strict\";var n=r(7683).EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};t.exports=i},93049:function(t,e,r){\"use strict\";var n=r(56174),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p,d=t[0],m=t.length;if(2===m&&i(d)&&i(t[1])&&0===d.length){if(p=function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],d),p)return d;d.splice(0,d.length)}for(var g=1;g<m;g++)for(l in s=t[g])c=d[l],u=s[l],o&&i(u)?d[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},d[l]=a([f,u],e,r,o)):(void 0!==u||r)&&(d[l]=u);return d}e.extendFlat=function(){return a(arguments,!1,!1,!1)},e.extendDeep=function(){return a(arguments,!0,!1,!1)},e.extendDeepAll=function(){return a(arguments,!0,!0,!1)},e.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},48965:function(t){\"use strict\";t.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},78926:function(t){\"use strict\";function e(t){return!0===t.visible}function r(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}t.exports=function(t){for(var n,i=(n=t,Array.isArray(n)&&Array.isArray(n[0])&&n[0][0]&&n[0][0].trace?r:e),a=[],o=0;o<t.length;o++){var s=t[o];i(s)&&a.push(s)}return a}},3994:function(t,e,r){\"use strict\";var n=r(45568),i=r(78171),{area:a}=r(61990),{centroid:o}=r(30035),{bbox:s}=r(25368),l=r(29527),c=r(48636),u=r(56174),h=r(35632),f=r(80899),p=Object.keys(i),d={\"ISO-3\":l,\"USA-states\":l,\"country names\":function(t){for(var e=0;e<p.length;e++){var r=p[e];if(new RegExp(i[r]).test(t.trim().toLowerCase()))return r}return c.log(\"Unrecognized country name: \"+t+\".\"),!1}};function m(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n=\"string\"==typeof e?r[e]:e;return u(n)?n:(c.error(\"Oops ... something went wrong when fetching \"+e),!1)}t.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,i,a,o=d[t](e);if(o){if(\"USA-states\"===t)for(n=[],a=0;a<r.length;a++)(i=r[a]).properties&&i.properties.gu&&\"USA\"===i.properties.gu&&n.push(i);else n=r;for(a=0;a<n.length;a++)if((i=n[a]).id===o)return i;c.log([\"Location with id\",o,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1},feature2polygons:function(t){var e,r,n,i,a=t.geometry,o=a.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===s||\"FJI\"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];l.push(f.tester(e))}:\"ATA\"===s?function(t){var e=c(t);if(null===e)return l.push(f.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var a=f.tester(r);a.pts.pop(),l.push(a)}:function(t){l.push(f.tester(t))},a.type){case\"MultiPolygon\":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case\"Polygon\":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:m,extractTraceFeature:function(t){var e=t[0].trace,r=m(e);if(!r)return!1;var n,i={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(i[l.loc]=l)}function u(t){var r=h(t,e.featureidkey||\"id\").get(),n=i[r];if(n){var l=t.geometry;if(\"Polygon\"===l.type||\"MultiPolygon\"===l.type){var u={type:\"Feature\",id:r,geometry:l,properties:{}};u.geometry.coordinates.length>0?u.properties.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,i=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=a(l);c>i&&(i=c,e=l)}else e=r;return o(e).geometry.coordinates}(u):u.properties.ct=[NaN,NaN],n.fIn=t,n.fOut=u,s.push(u)}else c.log([\"Location\",n.loc,\"does not have a valid GeoJSON geometry.\",\"Traces with locationmode *geojson-id* only support\",\"*Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete i[r]}switch(r.type){case\"FeatureCollection\":var f=r.features;for(n=0;n<f.length;n++)u(f[n]);break;case\"Feature\":u(r);break;default:return c.warn([\"Invalid GeoJSON type\",(r.type||\"none\")+\".\",\"Traces with locationmode *geojson-id* only support\",\"*FeatureCollection* and *Feature* types.\"].join(\" \")),!1}for(var p in i)c.log([\"Location *\"+p+\"*\",\"does not have a matching feature with id-key\",\"*\"+e.featureidkey+\"*.\"].join(\" \"));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function i(t){return new Promise((function(r,i){n.json(t,(function(n,a){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return i(new Error(o))}return e[t]=a,r(a)}))}))}function a(t){return new Promise((function(r,n){var i=0,a=setInterval((function(){return e[t]&&\"pending\"!==e[t]?(clearInterval(a),r(e[t])):i>100?(clearInterval(a),n(\"Unexpected error while fetching from \"+t)):void i++}),50)}))}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;\"string\"==typeof s&&(e[s]?\"pending\"===e[s]&&r.push(a(s)):(e[s]=\"pending\",r.push(i(s))))}return r},computeBbox:function(t){return s(t)}}},39532:function(t,e,r){\"use strict\";var n=r(63821).BADNUM;e.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},e.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},e.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},e.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},3447:function(t,e,r){\"use strict\";var n,i,a,o=r(98953).mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var m=(c*p-u*f)/d,g=(c*h-l*f)/d;return g<0||g>1||m<0||m>1?null:{x:t+l*m,y:e+h*m}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}e.segmentsIntersect=s,e.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,m=f*f+p*p,g=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,m,t-i,e-a),l(f,p,m,r-i,n-a));return Math.sqrt(g)},e.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},e.clearLocationCache=function(){i=null},e.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},e.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},46998:function(t,e,r){\"use strict\";var n=r(10721),i=r(65657),a=r(162),o=r(88856),s=r(10229).defaultLine,l=r(87800).isArrayOrTypedArray,c=a(s);function u(t,e){var r=t;return r[3]*=e,r}function h(t){if(n(t))return c;var e=a(t);return e.length?e:c}function f(t){return n(t)?t:1}t.exports={formatColor:function(t,e,r){var n=t.color;n&&n._inputArray&&(n=n._inputArray);var i,s,p,d,m,g=l(n),y=l(e),v=o.extractOpts(t),x=[];if(i=void 0!==v.colorscale?o.makeColorScaleFuncFromTrace(t):h,s=g?function(t,e){return void 0===t[e]?c:a(i(t[e]))}:h,p=y?function(t,e){return void 0===t[e]?1:f(t[e])}:f,g||y)for(var _=0;_<r;_++)d=s(n,_),m=p(e,_),x[_]=u(d,m);else x=u(a(n),e);return x},parseColorScale:function(t){var e=o.extractOpts(t),r=e.colorscale;return e.reversescale&&(r=o.flipScale(e.colorscale)),r.map((function(t){var e=t[0],r=i(t[1]).toRgb();return{index:e,rgb:[r.r,r.g,r.b,r.a]}}))}}},71293:function(t,e,r){\"use strict\";var n=r(29527);function i(t){return[t]}t.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},29527:function(t){\"use strict\";t.exports=function(t){return t}},10688:function(t){\"use strict\";t.exports=function(t,e){if(!e)return t;var r=1/Math.abs(e),n=r>1?(r*t+r*e)/r:t+e,i=String(n).length;if(i>16){var a=String(e).length;if(i>=String(t).length+a){var o=parseFloat(n).toPrecision(12);-1===o.indexOf(\"e+\")&&(n=+o)}}return n}},34809:function(t,e,r){\"use strict\";var n=r(45568),i=r(42696).aL,a=r(36464).GP,o=r(10721),s=r(63821),l=s.FP_SAFE,c=-l,u=s.BADNUM,h=t.exports={};h.adjustFormat=function(t){return!t||/^\\d[.]\\df/.test(t)||/[.]\\d%/.test(t)?t:\"0.f\"===t?\"~f\":/^\\d%/.test(t)?\"~%\":/^\\ds/.test(t)?\"~s\":!/^[~,.0$]/.test(t)&&/[&fps]/.test(t)?\"~\"+t:t};var f={};h.warnBadFormat=function(t){var e=String(t);f[e]||(f[e]=1,h.warn('encountered bad format: \"'+e+'\"'))},h.noFormat=function(t){return String(t)},h.numberFormat=function(t){var e;try{e=a(h.adjustFormat(t))}catch(e){return h.warnBadFormat(t),h.noFormat}return e},h.nestedProperty=r(35632),h.keyedContainer=r(34967),h.relativeAttr=r(82047),h.isPlainObject=r(56174),h.toLogRange=r(8083),h.relinkPrivateKeys=r(80428);var p=r(87800);h.isArrayBuffer=p.isArrayBuffer,h.isTypedArray=p.isTypedArray,h.isArrayOrTypedArray=p.isArrayOrTypedArray,h.isArray1D=p.isArray1D,h.ensureArray=p.ensureArray,h.concat=p.concat,h.maxRowLength=p.maxRowLength,h.minRowLength=p.minRowLength;var d=r(98953);h.mod=d.mod,h.modHalf=d.modHalf;var m=r(34220);h.valObjectMeta=m.valObjectMeta,h.coerce=m.coerce,h.coerce2=m.coerce2,h.coerceFont=m.coerceFont,h.coercePattern=m.coercePattern,h.coerceHoverinfo=m.coerceHoverinfo,h.coerceSelectionMarkerOpacity=m.coerceSelectionMarkerOpacity,h.validate=m.validate;var g=r(92596);h.dateTime2ms=g.dateTime2ms,h.isDateTime=g.isDateTime,h.ms2DateTime=g.ms2DateTime,h.ms2DateTimeLocal=g.ms2DateTimeLocal,h.cleanDate=g.cleanDate,h.isJSDate=g.isJSDate,h.formatDate=g.formatDate,h.incrementMonth=g.incrementMonth,h.dateTick0=g.dateTick0,h.dfltRange=g.dfltRange,h.findExactDates=g.findExactDates,h.MIN_MS=g.MIN_MS,h.MAX_MS=g.MAX_MS;var y=r(98813);h.findBin=y.findBin,h.sorterAsc=y.sorterAsc,h.sorterDes=y.sorterDes,h.distinctVals=y.distinctVals,h.roundUp=y.roundUp,h.sort=y.sort,h.findIndexOfMin=y.findIndexOfMin,h.sortObjectKeys=r(62994);var v=r(89258);h.aggNums=v.aggNums,h.len=v.len,h.mean=v.mean,h.geometricMean=v.geometricMean,h.median=v.median,h.midRange=v.midRange,h.variance=v.variance,h.stdev=v.stdev,h.interp=v.interp;var x=r(15236);h.init2dArray=x.init2dArray,h.transposeRagged=x.transposeRagged,h.dot=x.dot,h.translationMatrix=x.translationMatrix,h.rotationMatrix=x.rotationMatrix,h.rotationXYMatrix=x.rotationXYMatrix,h.apply3DTransform=x.apply3DTransform,h.apply2DTransform=x.apply2DTransform,h.apply2DTransform2=x.apply2DTransform2,h.convertCssMatrix=x.convertCssMatrix,h.inverseTransformMatrix=x.inverseTransformMatrix;var _=r(44313);h.deg2rad=_.deg2rad,h.rad2deg=_.rad2deg,h.angleDelta=_.angleDelta,h.angleDist=_.angleDist,h.isFullCircle=_.isFullCircle,h.isAngleInsideSector=_.isAngleInsideSector,h.isPtInsideSector=_.isPtInsideSector,h.pathArc=_.pathArc,h.pathSector=_.pathSector,h.pathAnnulus=_.pathAnnulus;var b=r(32546);h.isLeftAnchor=b.isLeftAnchor,h.isCenterAnchor=b.isCenterAnchor,h.isRightAnchor=b.isRightAnchor,h.isTopAnchor=b.isTopAnchor,h.isMiddleAnchor=b.isMiddleAnchor,h.isBottomAnchor=b.isBottomAnchor;var w=r(3447);h.segmentsIntersect=w.segmentsIntersect,h.segmentDistance=w.segmentDistance,h.getTextLocation=w.getTextLocation,h.clearLocationCache=w.clearLocationCache,h.getVisibleSegment=w.getVisibleSegment,h.findPointOnPath=w.findPointOnPath;var T=r(93049);h.extendFlat=T.extendFlat,h.extendDeep=T.extendDeep,h.extendDeepAll=T.extendDeepAll,h.extendDeepNoArrays=T.extendDeepNoArrays;var k=r(48636);h.log=k.log,h.warn=k.warn,h.error=k.error;var A=r(90694);h.counterRegex=A.counter;var M=r(64025);h.throttle=M.throttle,h.throttleDone=M.done,h.clearThrottle=M.clear;var S=r(95425);function E(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}h.getGraphDiv=S.getGraphDiv,h.isPlotDiv=S.isPlotDiv,h.removeElement=S.removeElement,h.addStyleRule=S.addStyleRule,h.addRelatedStyleRule=S.addRelatedStyleRule,h.deleteRelatedStyleRule=S.deleteRelatedStyleRule,h.getFullTransformMatrix=S.getFullTransformMatrix,h.getElementTransformMatrix=S.getElementTransformMatrix,h.getElementAndAncestors=S.getElementAndAncestors,h.equalDomRects=S.equalDomRects,h.clearResponsive=r(23493),h.preserveDrawingBuffer=r(32521),h.makeTraceGroups=r(75944),h._=r(38514),h.notifier=r(87355),h.filterUnique=r(48965),h.filterVisible=r(78926),h.pushUnique=r(36539),h.increment=r(10688),h.cleanNumber=r(44498),h.ensureNumber=function(t){return o(t)?(t=Number(t))>l||t<c?u:t:u},h.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&o(t)&&t>=0&&t%1==0},h.noop=r(4969),h.identity=r(29527),h.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},h.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=h.nestedProperty(t,a.replace(\"?\",r)),s=h.nestedProperty(t,a.replace(\"?\",n)),l=o.get();o.set(s.get()),s.set(l)}},h.raiseToTop=function(t){t.parentNode.appendChild(t)},h.cancelTransition=function(t){return t.transition().duration(0)},h.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},h.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},h.simpleMap=function(t,e,r,n,i){for(var a=t.length,o=new Array(a),s=0;s<a;s++)o[s]=e(t[s],r,n,i);return o},h.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),l=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var c=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)l=Math.floor(Math.random()*n).toString(n)+l;c&&(o=Math.pow(n,c),l=Math.floor(Math.random()*o).toString(n)+l);var u=parseInt(l,n);return e&&e[l]||u!==1/0&&u>=Math.pow(2,r)?i>10?(h.warn(\"randstr failed uniqueness\"),l):t(e,r,n,(i||0)+1):l},h.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},h.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},h.syncOrAsync=function(t,e,r){var n;function i(){return h.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i);return r&&r(e)},h.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},h.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},h.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(h.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},h.mergeArrayCastPositive=function(t,e,r){return h.mergeArray(t,e,r,(function(t){var e=+t;return isFinite(e)&&e>0?e:0}))},h.fillArray=function(t,e,r,n){if(n=n||h.identity,h.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},h.castOption=function(t,e,r,n){n=n||h.identity;var i=h.nestedProperty(t,r).get();return h.isArrayOrTypedArray(i)?Array.isArray(e)&&h.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},h.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=h.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},h.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=E(o));for(var s=0;s<a.length;s++){var l=a[s];if(h.isIndex(l)||h.isArrayOrTypedArray(l)&&h.isIndex(l[0])&&h.isIndex(l[1])){var c=n?n[l]:l,u=r?r[c]:c;void 0!==(i=u)&&i<t.length&&(t[u].selected=1)}}},h.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=E(r),i=[],a=0;a<e.length;a++){var o=e[a];if(h.isIndex(o)){var s=n[o];h.isIndex(s)&&i.push(s)}}return i}return e},h.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=h.nestedProperty(t,r).get();return!!h.isArrayOrTypedArray(n)&&n}return!!h.isArrayOrTypedArray(r)&&r},h.minExtend=function t(e,r,n){var i={};\"object\"!=typeof r&&(r={});var a,o,s,l=\"pieLike\"===n?-1:3,c=Object.keys(e);for(a=0;a<c.length;a++)s=e[o=c[a]],\"_\"!==o.charAt(0)&&\"function\"!=typeof s&&(\"module\"===o?i[o]=s:Array.isArray(s)?i[o]=\"colorscale\"===o||-1===l?s.slice():s.slice(0,l):h.isTypedArray(s)?i[o]=-1===l?s.subarray():s.subarray(0,l):i[o]=s&&\"object\"==typeof s?t(e[o],r[o],n):s);for(c=Object.keys(r),a=0;a<c.length;a++)\"object\"==typeof(s=r[o=c[a]])&&o in i&&\"object\"==typeof i[o]||(i[o]=s);return i},h.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},h.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},h.isIE=function(){return void 0!==window.navigator.msSaveBlob};var C=/Version\\/[\\d\\.]+.*Safari/;h.isSafari=function(){return C.test(window.navigator.userAgent)};var L=/iPad|iPhone|iPod/;h.isIOS=function(){return L.test(window.navigator.userAgent)};var I=/Firefox\\/(\\d+)\\.\\d+/;h.getFirefoxVersion=function(){var t=I.exec(window.navigator.userAgent);if(t&&2===t.length){var e=parseInt(t[1]);if(!isNaN(e))return e}return null},h.isD3Selection=function(t){return t instanceof n.selection},h.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},h.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},h.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var P=/^([^\\[\\.]+)\\.(.+)?/,z=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;function O(t){return\"__\"===t.slice(0,2)}h.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)if(t.hasOwnProperty(r))if(e=r.match(P)){if(i=t[r],O(n=e[1]))continue;delete t[r],t[n]=h.extendDeepNoArrays(t[n]||{},h.objectFromPath(r,h.expandObjectPaths(i))[n])}else if(e=r.match(z)){if(i=t[r],O(n=e[1]))continue;if(a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3])s=e[4],o=t[n][a]=t[n][a]||{},h.extendDeepNoArrays(o,h.objectFromPath(s,h.expandObjectPaths(i)));else{if(O(n))continue;t[n][a]=h.expandObjectPaths(i)}}else{if(O(r))continue;t[r]=h.expandObjectPaths(t[r])}return t},h.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},h.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)([:|\\|][^}]*)?}/g;var D=/^\\w*$/;h.templateString=function(t,e){var r={};return t.replace(h.TEMPLATE_STRING_REGEX,(function(t,n){var i;return D.test(n)?i=e[n]:(r[n]=r[n]||h.nestedProperty(e,n).get,i=r[n]()),h.isValidTextValue(i)?i:\"\"}))};var R={max:10,count:0,name:\"hovertemplate\"};h.hovertemplateString=function(){return U.apply(R,arguments)};var F={max:10,count:0,name:\"texttemplate\"};h.texttemplateString=function(){return U.apply(F,arguments)};var B=/^(\\S+)([\\*\\/])(-?\\d+(\\.\\d+)?)$/,N={max:10,count:0,name:\"texttemplate\",parseMultDiv:!0};h.texttemplateStringForShapes=function(){return U.apply(N,arguments)};var j=/^[:|\\|]/;function U(t,e,r){var n=this,a=arguments;e||(e={});var o={};return t.replace(h.TEMPLATE_STRING_REGEX,(function(t,s,l){var c=\"_xother\"===s||\"_yother\"===s,u=\"_xother_\"===s||\"_yother_\"===s,f=\"xother_\"===s||\"yother_\"===s,p=\"xother\"===s||\"yother\"===s||c||f||u,d=s;(c||u)&&(d=d.substring(1)),(f||u)&&(d=d.substring(0,d.length-1));var m,g,y,v=null,x=null;if(n.parseMultDiv){var _=function(t){var e=t.match(B);return e?{key:e[1],op:e[2],number:Number(e[3])}:{key:t,op:null,number:null}}(d);d=_.key,v=_.op,x=_.number}if(p){if(void 0===(m=e[d]))return\"\"}else for(y=3;y<a.length;y++)if(g=a[y]){if(g.hasOwnProperty(d)){m=g[d];break}if(D.test(d)||(m=h.nestedProperty(g,d).get(),(m=o[d]||h.nestedProperty(g,d).get())&&(o[d]=m)),void 0!==m)break}if(void 0!==m&&(\"*\"===v&&(m*=x),\"/\"===v&&(m/=x)),void 0===m&&n)return n.count<n.max&&(h.warn(\"Variable '\"+d+\"' in \"+n.name+\" could not be found!\"),m=t),n.count===n.max&&h.warn(\"Too many \"+n.name+\" warnings - additional warnings will be suppressed\"),n.count++,t;if(l){var b;if(\":\"===l[0]&&(b=r?r.numberFormat:h.numberFormat,\"\"!==m&&(m=b(l.replace(j,\"\"))(m))),\"|\"===l[0]){b=r?r.timeFormat:i;var w=h.dateTime2ms(m);m=h.formatDate(w,l.replace(j,\"\"),!1,b)}}else{var T=d+\"Label\";e.hasOwnProperty(T)&&(m=e[T])}return p&&(m=\"(\"+m+\")\",(c||u)&&(m=\" \"+m),(f||u)&&(m+=\" \")),m}))}h.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var V=2e9;h.seedPseudoRandom=function(){V=2e9},h.pseudoRandom=function(){var t=V;return V=(69069*V+1)%4294967296,Math.abs(V-t)<429496729?h.pseudoRandom():V/4294967296},h.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=h.extractOption(t,e,\"htx\",\"hovertext\");if(h.isValidTextValue(i))return n(i);var a=h.extractOption(t,e,\"tx\",\"text\");return h.isValidTextValue(a)?n(a):void 0},h.isValidTextValue=function(t){return t||0===t},h.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},h.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e},h.strTranslate=function(t,e){return t||e?\"translate(\"+t+\",\"+e+\")\":\"\"},h.strRotate=function(t){return t?\"rotate(\"+t+\")\":\"\"},h.strScale=function(t){return 1!==t?\"scale(\"+t+\")\":\"\"},h.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,c=t.scale;return c?c>1&&(c=1):c=0,h.strTranslate(i-c*(r+o),a-c*(n+s))+h.strScale(c)+(l?\"rotate(\"+l+(e?\"\":\" \"+r+\" \"+n)+\")\":\"\")},h.setTransormAndDisplay=function(t,e){t.attr(\"transform\",h.getTextTransform(e)),t.style(\"display\",e.scale?null:\"none\")},h.ensureUniformFontSize=function(t,e){var r=h.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r},h.join2=function(t,e,r){var n=t.length;return n>1?t.slice(0,-1).join(e)+r+t[n-1]:t.join(e)},h.bigFont=function(t){return Math.round(1.2*t)};var q=h.getFirefoxVersion(),H=null!==q&&q<86;h.getPositionFromD3Event=function(){return H?[n.event.layerX,n.event.layerY]:[n.event.offsetX,n.event.offsetY]}},56174:function(t){\"use strict\";t.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t).hasOwnProperty(\"hasOwnProperty\")}},34967:function(t,e,r){\"use strict\";var n=r(35632),i=/^\\w*$/;t.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n||(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e),f},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},38514:function(t,e,r){\"use strict\";var n=r(33626);t.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},48636:function(t,e,r){\"use strict\";var n=r(24452).dfltConfig,i=r(87355),a=t.exports={};a.log=function(){var t;if(n.logging>1){var e=[\"LOG:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);console.trace.apply(console,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"long\")}},a.warn=function(){var t;if(n.logging>0){var e=[\"WARN:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);console.trace.apply(console,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}},a.error=function(){var t;if(n.logging>0){var e=[\"ERROR:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);console.error.apply(console,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}}},75944:function(t,e,r){\"use strict\";var n=r(45568);t.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,(function(t){return t[0].trace.uid}));i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each((function(t){t[0][a]=n.select(this)})),i}},15236:function(t,e,r){\"use strict\";var n=r(11191);e.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},e.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},e.dot=function(t,r){if(!t.length||!r.length||t.length!==r.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=e.dot(t[i],r);else if(r[0].length){var o=e.transposeRagged(r);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=e.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*r[i];return n},e.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},e.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},e.rotationXYMatrix=function(t,r,n){return e.dot(e.dot(e.translationMatrix(r,n),e.rotationMatrix(t)),e.translationMatrix(-r,-n))},e.apply3DTransform=function(t){return function(){var r=arguments,n=1===arguments.length?r[0]:[r[0],r[1],r[2]||0];return e.dot(t,[n[0],n[1],n[2],1]).slice(0,3)}},e.apply2DTransform=function(t){return function(){var r=arguments;3===r.length&&(r=r[0]);var n=1===arguments.length?r[0]:[r[0],r[1]];return e.dot(t,[n[0],n[1],1]).slice(0,2)}},e.apply2DTransform2=function(t){var r=e.apply2DTransform(t);return function(t){return r(t.slice(0,2)).concat(r(t.slice(2,4)))}},e.convertCssMatrix=function(t){if(t){var e=t.length;if(16===e)return t;if(6===e)return[t[0],t[1],0,0,t[2],t[3],0,0,0,0,1,0,t[4],t[5],0,1]}return[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]},e.inverseTransformMatrix=function(t){var e=[];return n.invert(e,t),[[e[0],e[1],e[2],e[3]],[e[4],e[5],e[6],e[7]],[e[8],e[9],e[10],e[11]],[e[12],e[13],e[14],e[15]]]}},98953:function(t){\"use strict\";t.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},35632:function(t,e,r){\"use strict\";var n=r(10721),i=r(87800).isArrayOrTypedArray;function a(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=a(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if(\"number\"==typeof r&&!i(c))return;if(\"object\"!=typeof(c=c[r])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}t.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";var r,i,o,s,c=e.split(\".\");for(s=0;s<c.length;s++)if(\"__\"===String(c[s]).slice(0,2))throw\"bad property string\";for(s=0;s<c.length;){if(r=String(c[s]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw\"bad property string\";c.splice(0,1)}for(i=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<i.length;o++)s++,c.splice(s,0,Number(i[o]))}s++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:a(t,c),astr:e,parts:c,obj:t}};var o=/(^|\\.)args\\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var a,o,l=t,f=\"\",p=[[t,f]],d=s(n,r);for(o=0;o<e.length-1;o++){if(\"number\"==typeof(a=e[o])&&!i(l))throw\"array index but container is not an array\";if(-1===a){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!h(l,a,e[o+1],d))break;if(\"object\"!=typeof(l=l[a])||null===l)throw\"container is not an object\";f=c(f,a),p.push([l,f])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function u(t,e,r,n){var a,o=i(r),c=!0,u=r,f=n.replace(\"-1\",0),p=!o&&s(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),o&&(p=s(u=r[a%r.length],f)),p&&(c=!1),h(t,a,d,p)&&l(t[a],e,n.replace(\"-1\",a))(u);return c}function h(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},4969:function(t){\"use strict\";t.exports=function(){}},87355:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=[];t.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each((function(t){var i=n.select(this);i.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",(function(){i.transition().call(s)}));for(var a=i.append(\"p\"),o=t.split(/<br\\s*\\/?>/g),l=0;l<o.length;l++)l&&a.append(\"br\"),a.append(\"span\").text(o[l]);\"stick\"===e?i.transition().duration(350).style(\"opacity\",1):i.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)}))}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",(function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()}))}}},93134:function(t,e,r){\"use strict\";var n=r(27983),i=\"data-savedcursor\";t.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},80899:function(t,e,r){\"use strict\";var n=r(15236).dot,i=r(63821).BADNUM,a=t.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r[r.length-1][0]===r[0][0]&&r[r.length-1][1]===r[0][1]||r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,m=r.length,g=r[0][0],y=r[0][1],v=0;for(u=1;u<m;u++)if(h=g,f=y,g=r[u][0],y=r[u][1],!(l<(p=Math.min(h,g))||l>Math.max(h,g)||c>Math.max(f,y)))if(c<Math.min(f,y))l!==p&&v++;else{if(c===(d=g===h?c:f+(l-h)*(y-f)/(g-h)))return 1!==u||!e;c<=d&&l!==p&&v++}return v%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}return t.length>1&&o(t.pop()),{addPt:o,raw:t,filtered:r}}},22459:function(t,e,r){\"use strict\";var n=r(97464),i=r(81330);t.exports=function(t,e,a){var o=t._fullLayout,s=!0;return o._glcanvas.each((function(n){if(n.regl)n.regl.preloadCachedCode(a);else if(!n.pick||o._has(\"parcoords\")){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.g.devicePixelRatio,extensions:e||[],cachedCode:a||{}})}catch(t){s=!1}n.regl||(s=!1),s&&this.addEventListener(\"webglcontextlost\",(function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})}),!1)}})),s||n({container:o._glcontainer.node()}),s}},32521:function(t,e,r){\"use strict\";var n=r(10721),i=r(13087);t.exports=function(t){var e;if(\"string\"!=typeof(e=t&&t.hasOwnProperty(\"userAgent\")?t.userAgent:function(){var t;return\"undefined\"!=typeof navigator&&(t=navigator.userAgent),t&&t.headers&&\"string\"==typeof t.headers[\"user-agent\"]&&(t=t.headers[\"user-agent\"]),t}()))return!0;var r=i({ua:{headers:{\"user-agent\":e}},tablet:!0,featureDetect:!1});if(!r)for(var a=e.split(\" \"),o=1;o<a.length;o++)if(-1!==a[o].indexOf(\"Safari\"))for(var s=o-1;s>-1;s--){var l=a[s];if(\"Version/\"===l.substr(0,8)){var c=l.substr(8).split(\".\")[0];if(n(c)&&(c=+c),c>=13)return!0}}return r}},36539:function(t){\"use strict\";t.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},40486:function(t,e,r){\"use strict\";var n=r(34809),i=r(24452).dfltConfig,a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}},plotDo:function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)}};t.exports=a},90694:function(t,e){\"use strict\";e.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},82047:function(t){\"use strict\";var e=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,r=/^[^\\.\\[\\]]+$/;t.exports=function(t,n){for(;n;){var i=t.match(e);if(i)t=i[1];else{if(!t.match(r))throw new Error(\"bad relativeAttr call:\"+[t,n]);t=\"\"}if(\"^\"!==n.charAt(0))break;n=n.slice(1)}return t&&\"[\"!==n.charAt(0)?t+\".\"+n:t+n}},80428:function(t,e,r){\"use strict\";var n=r(87800).isArrayOrTypedArray,i=r(56174);t.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},98813:function(t,e,r){\"use strict\";var n=r(10721),i=r(48636),a=r(29527),o=r(63821).BADNUM,s=1e-9;function l(t,e){return t<e}function c(t,e){return t<=e}function u(t,e){return t>e}function h(t,e){return t>=e}e.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-s)-1:Math.floor((t-e.start)/e.size+s);var a,o,f=0,p=e.length,d=0,m=p>1?(e[p-1]-e[0])/(p-1):1;for(o=m>=0?r?l:c:r?h:u,t+=m*s*(r?-1:1)*(m>=0?1:-1);f<p&&d++<100;)o(e[a=Math.floor((f+p)/2)],t)?f=a+1:p=a;return d>90&&i.log(\"Long binary search...\"),f-1},e.sorterAsc=function(t,e){return t-e},e.sorterDes=function(t,e){return e-t},e.distinctVals=function(t){var r,n=t.slice();for(n.sort(e.sorterAsc),r=n.length-1;r>-1&&n[r]===o;r--);for(var i,a=n[r]-n[0]||1,s=a/(r||1)/1e4,l=[],c=0;c<=r;c++){var u=n[c],h=u-i;void 0===i?(l.push(u),i=u):h>s&&(a=Math.min(a,h),l.push(u),i=u)}return{vals:l,minDiff:a}},e.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},e.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},e.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},27983:function(t){\"use strict\";t.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach((function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)})),e&&t.classed(\"cursor-\"+e,!0)}},97464:function(t,e,r){\"use strict\";var n=r(78766),i=function(){};t.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},62994:function(t){\"use strict\";t.exports=function(t){return Object.keys(t).sort()}},89258:function(t,e,r){\"use strict\";var n=r(10721),i=r(87800).isArrayOrTypedArray;e.aggNums=function(t,r,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(r)||(r=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=e.aggNums(t,r,a[s]);a=l}for(s=0;s<o;s++)n(r)?n(a[s])&&(r=t(+r,+a[s])):r=a[s];return r},e.len=function(t){return e.aggNums((function(t){return t+1}),0,t)},e.mean=function(t,r){return r||(r=e.len(t)),e.aggNums((function(t,e){return t+e}),0,t)/r},e.geometricMean=function(t,r){return r||(r=e.len(t)),Math.pow(e.aggNums((function(t,e){return t*e}),1,t),1/r)},e.midRange=function(t){if(void 0!==t&&0!==t.length)return(e.aggNums(Math.max,null,t)+e.aggNums(Math.min,null,t))/2},e.variance=function(t,r,i){return r||(r=e.len(t)),n(i)||(i=e.mean(t,r)),e.aggNums((function(t,e){return t+Math.pow(e-i,2)}),0,t)/r},e.stdev=function(t,r,n){return Math.sqrt(e.variance(t,r,n))},e.median=function(t){var r=t.slice().sort();return e.interp(r,.5)},e.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},55010:function(t,e,r){\"use strict\";var n=r(162);t.exports=function(t){return t?n(t):[0,0,0,1]}},95544:function(t,e,r){\"use strict\";var n=r(1837),i=r(62203),a=r(34809),o=null;t.exports=function(){if(null!==o)return o;o=!1;var t=a.isIE()||a.isSafari()||a.isIOS();if(window.navigator.userAgent&&!t){var e=Array.from(n.CSS_DECLARATIONS).reverse(),r=window.CSS&&window.CSS.supports||window.supportsCSS;if(\"function\"==typeof r)o=e.some((function(t){return r.apply(null,t)}));else{var s=i.tester.append(\"image\").attr(\"style\",n.STYLE),l=window.getComputedStyle(s.node()).imageRendering;o=e.some((function(t){var e=t[1];return l===e||l===e.toLowerCase()})),s.remove()}}return o}},30635:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=i.strTranslate,o=r(62972),s=r(4530).LINE_SPACING,l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;e.convertToTspans=function(t,r,g){var S=t.text(),E=!t.attr(\"data-notex\")&&r&&r._context.typesetMath&&\"undefined\"!=typeof MathJax&&S.match(l),I=n.select(t.node().parentNode);if(!I.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",I.selectAll(\"svg.\"+P).remove(),I.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),E?(r&&r._promises||[]).push(new Promise((function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),o={fontSize:r};!function(t,e,r){var a,o,s,l,f=parseInt((MathJax.version||\"\").split(\".\")[0]);if(2===f||3===f){var p=function(){var r=\"math-output-\"+i.randstr({},64),a=(l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\",\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \"))).node();return 2===f?MathJax.Hub.Typeset(a):MathJax.typeset([a])},d=function(){var e=l.select(2===f?\".MathJax_SVG\":\".MathJax\"),a=!e.empty()&&l.select(\"svg\").node();if(a){var o,s=a.getBoundingClientRect();o=2===f?n.select(\"body\").select(\"#MathJax_SVG_glyphs\"):e.select(\"defs\"),r(e,o,s)}else i.log(\"There was an error in the tex syntax.\",t),r();l.remove()};2===f?MathJax.Hub.Queue((function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:h},displayAlign:\"left\"})}),(function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")}),p,d,(function(){if(\"SVG\"!==a)return MathJax.Hub.setRenderer(a)}),(function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})):3===f&&(o=i.extendDeepAll({},MathJax.config),MathJax.config.tex||(MathJax.config.tex={}),MathJax.config.tex.inlineMath=h,\"svg\"!==(a=MathJax.config.startup.output)&&(MathJax.config.startup.output=\"svg\"),MathJax.startup.defaultReady(),MathJax.startup.promise.then((function(){p(),d(),\"svg\"!==a&&(MathJax.config.startup.output=a),MathJax.config=o})))}else i.warn(\"No MathJax version:\",MathJax.version)}(E[2],o,(function(n,i,o){I.selectAll(\"svg.\"+P).remove(),I.selectAll(\"g.\"+P+\"-group\").remove();var s=n&&n.select(\"svg\");if(!s||!s.node())return z(),void e();var l=I.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(s.node()),i&&i.node()&&s.node().insertBefore(i.node().cloneNode(!0),s.node().firstChild);var c=o.width,u=o.height;s.attr({class:P,height:u,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var h=t.node().style.fill||\"black\",f=s.select(\"g\");f.attr({fill:h,stroke:h});var p=f.node().getBoundingClientRect(),d=p.width,m=p.height;(d>c||m>u)&&(s.style(\"overflow\",\"hidden\"),d=(p=s.node().getBoundingClientRect()).width,m=p.height);var y=+t.attr(\"x\"),v=+t.attr(\"y\"),x=-(r||t.node().getBoundingClientRect().height)/4;if(\"y\"===P[0])l.attr({transform:\"rotate(\"+[-90,y,v]+\")\"+a(-d/2,x-m/2)});else if(\"l\"===P[0])v=x-m/2;else if(\"a\"===P[0]&&0!==P.indexOf(\"atitle\"))y=0,v=x;else{var _=t.attr(\"text-anchor\");y-=d*(\"middle\"===_?.5:\"end\"===_?1:0),v=v+x-m/2}s.attr({x:y,y:v}),g&&g.call(t,l),e(l)}))}))):z(),t}function z(){I.empty()||(P=t.attr(\"class\")+\"-math\",I.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\");var r=function(t,e){e=e.replace(y,\" \");var r,a=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(o.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*s+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var a=1;a<i.length;a++)h(i[a])}function h(t){var e,i=t.type,a={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(a={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(a.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(a.style=t.style);var h=document.createElementNS(o.svg,e);if(\"sup\"===i||\"sub\"===i){g(r,m),r.appendChild(h);var f=document.createElementNS(o.svg,\"tspan\");g(f,m),n.select(f).attr(\"dy\",d[i]),a.dy=p[i],r.appendChild(h),r.appendChild(f)}else r.appendChild(h);n.select(h).attr(a),r=t.node=h,l.push(t)}function g(t,e){t.appendChild(document.createTextNode(e))}function S(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}_.test(e)?u():(r=t,l=[{node:t}]);for(var E=e.split(v),I=0;I<E.length;I++){var P=E[I],z=P.match(x),O=z&&z[2].toLowerCase(),D=f[O];if(\"br\"===O)u();else if(void 0===D)g(r,C(P));else if(z[1])S(O);else{var R=z[4],F={type:O},B=A(R,b);if(B?(B=B.replace(M,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===O){a=!0;var N=A(R,w);if(N){var j=L(N);j&&(F.href=j,F.target=A(R,T)||\"_blank\",F.popup=A(R,k))}}h(F)}}return a}(t.node(),S);r&&t.style(\"pointer-events\",\"all\"),e.positionText(t),g&&g.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g,h=[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]],f={sup:\"font-size:70%\",sub:\"font-size:70%\",s:\"text-decoration:line-through\",u:\"text-decoration:underline\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},p={sub:\"0.3em\",sup:\"-0.6em\"},d={sub:\"-0.21em\",sup:\"0.42em\"},m=\"\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],y=e.NEWLINES=/(\\r\\n?|\\n)/g,v=/(<[^<>]*>)/,x=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,_=/<br(\\s+.*)?>/i;e.BR_TAG_ALL=/<br(\\s+.*)?>/gi;var b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,w=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,T=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function A(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&C(n)}var M=/(^|;)\\s*color:/;e.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=t.split(v),a=[],o=\"\",s=0,l=0;l<i.length;l++){var c=i[l],u=c.match(x),h=u&&u[2].toLowerCase();if(h)-1!==n.indexOf(h)&&(a.push(c),o=h);else{var f=c.length;if(s+f<r)a.push(c),s+=f;else if(s<r){var p=r-s;o&&(\"br\"!==o||p<=3||f<=3)&&a.pop(),r>3?a.push(c.substr(0,p-3)+\"...\"):a.push(c.substr(0,p));break}o=\"\"}}return a.join(\"\")};var S={mu:\"\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\u00a0\",times:\"\u00d7\",plusmn:\"\u00b1\",deg:\"\u00b0\"},E=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function C(t){return t.replace(E,(function(t,e){return(\"#\"===e.charAt(0)?function(t){if(!(t>1114111)){var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):S[e])||t}))}function L(t){var e=encodeURI(decodeURI(t)),r=document.createElement(\"a\"),n=document.createElement(\"a\");r.href=t,n.href=e;var i=r.protocol,a=n.protocol;return-1!==g.indexOf(i)&&-1!==g.indexOf(a)?e:\"\"}function I(t,e,r){var n,a,o,s=r.horizontalAlign,l=r.verticalAlign||\"top\",c=t.node().getBoundingClientRect(),u=e.node().getBoundingClientRect();return a=\"bottom\"===l?function(){return c.bottom-n.height}:\"middle\"===l?function(){return c.top+(c.height-n.height)/2}:function(){return c.top},o=\"right\"===s?function(){return c.right-n.width}:\"center\"===s?function(){return c.left+(c.width-n.width)/2}:function(){return c.left},function(){n=this.node().getBoundingClientRect();var t=o()-u.left,e=a()-u.top,s=r.gd||{};if(r.gd){s._fullLayout._calcInverseTransform(s);var l=i.apply3DTransform(s._fullLayout._invTransform)(t,e);t=l[0],e=l[1]}return this.style({top:e+\"px\",left:t+\"px\",\"z-index\":1e3}),this}}e.convertEntities=C,e.sanitizeHTML=function(t){t=t.replace(y,\" \");for(var e=document.createElement(\"p\"),r=e,i=[],a=t.split(v),o=0;o<a.length;o++){var s=a[o],l=s.match(x),c=l&&l[2].toLowerCase();if(c in f)if(l[1])i.length&&(r=i.pop());else{var u=l[4],h=A(u,b),p=h?{style:h}:{};if(\"a\"===c){var d=A(u,w);if(d){var m=L(d);if(m){p.href=m;var g=A(u,T);g&&(p.target=g)}}}var _=document.createElement(c);r.appendChild(_),n.select(_).attr(p),r=_,i.push(_)}else r.appendChild(document.createTextNode(C(s)))}return e.innerHTML},e.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},e.positionText=function(t,e,r){return t.each((function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})}))};var P=\"1px \";e.makeTextShadow=function(t){return P+P+P+t+\", -\"+P+\"-\"+P+P+t+\", \"+P+\"-\"+P+P+t+\", -\"+P+P+P+t},e.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){var i,s,c,u,h;i=n.select(r).select(\".svg-container\"),s=i.append(\"div\"),c=t.node().style,u=parseFloat(c.fontSize||12),void 0===(h=e.text)&&(h=t.attr(\"data-unformatted\")),s.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":c.fontFamily||\"Arial\",\"font-size\":u,color:e.fill||c.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-u/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(h).call(I(t,i,e)).on(\"blur\",(function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)})).on(\"focus\",(function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",(function(){if(n.event.target===t)return!1;document.activeElement===s.node()&&s.node().blur()}))})).on(\"keyup\",(function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",(function(){return!1})).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(I(t,i,e)))})).on(\"keydown\",(function(){13===n.event.which&&this.blur()})).call(l),t.style({opacity:0});var f,p=o.attr(\"class\");(f=p?\".\"+p.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(f).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},64025:function(t,e){\"use strict\";var r={};function n(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}e.throttle=function(t,e,i){var a=r[t],o=Date.now();if(!a){for(var s in r)r[s].ts<o-6e4&&delete r[s];a=r[t]={ts:0,timer:null}}function l(){i(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}n(a),o>a.ts+e?l():a.timer=setTimeout((function(){l(),a.timer=null}),e)},e.done=function(t){var e=r[t];return e&&e.timer?new Promise((function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}})):Promise.resolve()},e.clear=function(t){if(t)n(r[t]),delete r[t];else for(var i in r)e.clear(i)}},8083:function(t,e,r){\"use strict\";var n=r(10721);t.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},11577:function(t,e,r){\"use strict\";var n=t.exports={},i=r(74285).locationmodeToLayer,a=r(48640).N4;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},44611:function(t){\"use strict\";t.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},30227:function(t){\"use strict\";t.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},56037:function(t,e,r){\"use strict\";var n=r(33626);t.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},13582:function(t,e,r){\"use strict\";var n=r(93049).extendFlat,i=r(56174),a={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},s=a.flags.slice().concat([\"fullReplot\"]),l=o.flags.slice().concat(\"layoutReplot\");function c(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function u(t,e,r){var a=n({},t);for(var o in a){var s=a[o];i(s)&&(a[o]=h(s,e,0,o))}return\"from-root\"===r&&(a.editType=e),a}function h(t,e,r,i){if(t.valType){var a=n({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=h(t.items[o],e)}return a}return u(t,e,\"_\"===i.charAt(0)?\"nested\":\"from-root\")}t.exports={traces:a,layout:o,traceFlags:function(){return c(s)},layoutFlags:function(){return c(l)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:u}},10887:function(t,e,r){\"use strict\";var n=r(10721),i=r(36472),a=r(33626),o=r(34809),s=r(44122),l=r(5975),c=r(78766),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n,!0))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function m(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function g(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function y(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function v(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}e.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},e.cleanLayout=function(t){var r,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,m=Object.keys(t);for(r=0;r<m.length;r++){var g=m[r];if(a&&a.test(g)){var y=t[g];y.anchor&&\"free\"!==y.anchor&&(y.anchor=u(y.anchor)),y.overlaying&&(y.overlaying=u(y.overlaying)),y.type||(y.isdate?y.type=\"date\":y.islog?y.type=\"log\":!1===y.isdate&&!1===y.islog&&(y.type=\"linear\")),\"withzero\"!==y.autorange&&\"tozero\"!==y.autorange||(y.autorange=!0,y.rangemode=\"tozero\"),y.insiderange&&delete y.range,delete y.islog,delete y.isdate,delete y.categories,v(y,\"domain\")&&delete y.domain,void 0!==y.autotick&&(void 0===y.tickmode&&(y.tickmode=y.autotick?\"auto\":\"linear\"),delete y.autotick),d(y)}else if(l&&l.test(g))d(t[g].radialaxis);else if(h&&h.test(g)){var x=t[g];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(g)){var _=t[g],b=_.cameraposition;if(Array.isArray(b)&&4===b[0].length){var w=b[0],T=b[1],k=b[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=T[n]+k*A[2+4*n];_.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:T[0],y:T[1],z:T[2]},up:{x:0,y:0,z:1}},delete _.cameraposition}d(_.xaxis),d(_.yaxis),d(_.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(r=0;r<S;r++){var E=t.annotations[r];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(r=0;r<C;r++){var L=t.shapes[r];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var I=Array.isArray(t.images)?t.images.length:0;for(r=0;r<I;r++){var P=t.images[r];o.isPlainObject(P)&&(p(P,\"xref\"),p(P,\"yref\"))}var z=t.legend;return z&&(z.x>3?(z.x=1.02,z.xanchor=\"left\"):z.x<-2&&(z.x=-.02,z.xanchor=\"right\"),z.y>3?(z.y=1.02,z.yanchor=\"bottom\"):z.y<-2&&(z.y=-.02,z.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&e.cleanLayout(t.template.layout),t},e.cleanData=function(t){for(var r=0;r<t.length;r++){var n,i=t[r];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[r%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",e.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&e.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=y(i.textposition[n]);else i.textposition&&(i.textposition=y(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,_=x?i[x]:i;_&&_.colorscale&&(\"YIGnBu\"===_.colorscale&&(_.colorscale=\"YlGnBu\"),\"YIOrRd\"===_.colorscale&&(_.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var b=[\"x\",\"y\",\"z\"];for(n=0;n<b.length;n++){var w=i.contours[b[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var T=!1!==(i.increasing||{}).showlegend,k=!1!==(i.decreasing||{}).showlegend,A=m(i.increasing),M=m(i.decreasing);if(!1!==A&&!1!==M){var S=g(A,M,T,k);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,I=Object.keys(L);C.styles=[];for(var P=0;P<I.length;P++)C.styles.push({target:I[P],value:L[I[P]]})}}}}v(i,\"line\")&&delete i.line,\"marker\"in i&&(v(i.marker,\"line\")&&delete i.marker.line,v(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},e.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},e.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map((function(t,e){return e}));if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},e.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function _(t){var e=t.search(x);if(e>0)return t.substr(0,e)}e.hasParent=function(t,e){for(var r=_(e);r;){if(r in t)return!0;r=_(r)}return!1};var b=[\"x\",\"y\",\"z\"];e.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,b[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},90742:function(t,e,r){\"use strict\";var n=r(31420);e._doPlot=n._doPlot,e.newPlot=n.newPlot,e.restyle=n.restyle,e.relayout=n.relayout,e.redraw=n.redraw,e.update=n.update,e._guiRestyle=n._guiRestyle,e._guiRelayout=n._guiRelayout,e._guiUpdate=n._guiUpdate,e._storeDirectGUIEdit=n._storeDirectGUIEdit,e.react=n.react,e.extendTraces=n.extendTraces,e.prependTraces=n.prependTraces,e.addTraces=n.addTraces,e.deleteTraces=n.deleteTraces,e.moveTraces=n.moveTraces,e.purge=n.purge,e.addFrames=n.addFrames,e.deleteFrames=n.deleteFrames,e.animate=n.animate,e.setPlotConfig=n.setPlotConfig;var i=r(95425).getGraphDiv,a=r(28231).eraseActiveShape;e.deleteActiveShape=function(t){return a(i(t))},e.toImage=r(80491),e.validate=r(2466),e.downloadImage=r(26452);var o=r(53853);e.makeTemplate=o.makeTemplate,e.validateTemplate=o.validateTemplate},85844:function(t,e,r){\"use strict\";var n=r(56174),i=r(4969),a=r(48636),o=r(98813).sorterAsc,s=r(33626);e.containerArrayMatch=r(56037);var l=e.isAddVal=function(t){return\"add\"===t||n(t)},c=e.isRemoveVal=function(t){return null===t||\"remove\"===t};e.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),m=n.replot||n.recalc||f===i||p===i,g=t.layout,y=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var v=r[\"\"][\"\"];if(c(v))e.set(null);else{if(!Array.isArray(v))return a.warn(\"Unrecognized full array edit value\",h,v),!0;e.set(v)}return!m&&(f(g,y),p(t),!0)}var x,_,b,w,T,k,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(y,h).get(),I=[],P=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[b=S[x]],T=Object.keys(w),k=w[\"\"],A=l(k),b<0||b>C.length-(A?0:1))a.warn(\"index out of range\",h,b);else if(void 0!==k)T.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,b),c(k)?I.push(b):A?(\"add\"===k&&(k={}),C.splice(b,0,k),L&&L.splice(b,0,{})):a.warn(\"Unrecognized full object edit value\",h,b,k),-1===P&&(P=b);else for(_=0;_<T.length;_++)M=h+\"[\"+b+\"].\",u(C[b],T[_],M).set(w[T[_]]);for(x=I.length-1;x>=0;x--)C.splice(I[x],1),L&&L.splice(I[x],1);if(C.length?E||e.set(C):e.set(null),m)return!1;if(f(g,y),d!==i){var O;if(-1===P)O=S;else{for(z=Math.max(C.length,z),O=[],x=0;x<S.length&&!((b=S[x])>=P);x++)O.push(b);for(x=P;x<z;x++)O.push(x)}for(x=0;x<O.length;x++)d(t,O[x])}else p(t);return!0}},31420:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(39784),o=r(34809),s=o.nestedProperty,l=r(68596),c=r(40486),u=r(33626),h=r(57297),f=r(44122),p=r(29714),d=r(90259),m=r(25829),g=r(62203),y=r(78766),v=r(95284).initInteractions,x=r(62972),_=r(44844).clearOutline,b=r(24452).dfltConfig,w=r(85844),T=r(10887),k=r(71817),A=r(13582),M=r(54826).AX_NAME_PATTERN,S=0;function E(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function C(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function L(t,e){C(t,y.combine(e,\"white\"))}function I(t,e){if(!t._context){t._context=o.extendDeep({},b);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=L:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1,f.map=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1,f.map=1)}function P(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function z(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function O(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(void 0===e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),z(t,e,\"currentIndices\"),void 0===r||Array.isArray(r)||(r=[r]),void 0!==r&&z(t,r,\"newIndices\"),void 0!==r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function D(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(void 0===r)throw new Error(\"indices must be an integer or array of integers\");for(var a in z(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=P(r,t.data.length-1),e)for(var m=0;m<r.length;m++){if(a=t.data[r[m]],l=(c=s(a,d)).get(),u=e[d][m],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+m+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][m]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function R(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function F(t,r,n,i){t=o.getGraphDiv(t),T.clearPromiseQueue(t);var a={};if(\"string\"==typeof r)a[r]=n;else{if(!o.isPlainObject(r))return o.warn(\"Restyle fail.\",r,n,i),Promise.reject();a=o.extendFlat({},r),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=T.coerceTraceIndices(t,i),l=U(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&T.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(e._doPlot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),G(h)),u.style&&h.push(k.doTraceStyle),u.colorbars&&h.push(k.doColorBars),h.push(E)),h.push(f.rehover,f.redrag,f.reselect),c.add(t,F,[t,l.undoit,l.traces],F,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then((function(){return t.emit(\"plotly_restyle\",l.eventData),t}))}function B(t){return void 0===t?null:t}function N(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){j((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function j(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)j(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)j(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=B(e))}function U(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,d=N(i._preGUI,c),m=o.extendDeepAll({},e);V(e);var g,y=A.traceFlags(),v={},x={};function _(){return r.map((function(){}))}function b(t){var e=p.id2name(t);-1===g.indexOf(e)&&g.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function k(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach((function(t){S(t,a,o)}));else if(!(n in e)&&!T.hasParent(e,n)){var s;if(\"LAYOUT\"===n.substr(0,6))s=d(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=N(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=_()),void 0===x[n][o]&&(x[n][o]=B(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(T.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var I,P,z,O,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),v[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=_(),n=0;n<r.length;n++)if(I=l[r[n]],P=M(r[n]),O=(z=N(i._tracePreGUI[P._fullInput.uid],c)(I,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var j=z.parts[z.parts.length-1],U=L.substr(0,L.length-j.length-1),q=U?U+\".\":\"\",H=U?s(P,U).get():P;if((R=h.getTraceValObject(P,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==j&&\"lenmode\"!==j||O===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===O)||\"funnelarea\"===D!=(\"funnelarea\"===O))){var Z=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==O||\"h\"!==I.orientation||(Z=\"y\",W=\"x\"),o.swapAttrs(I,[\"?\",\"?src\"],\"labels\",Z),o.swapAttrs(I,[\"d?\",\"?0\"],\"label\",Z),o.swapAttrs(I,[\"?\",\"?src\"],\"values\",W),\"pie\"===O||\"funnelarea\"===O?(s(I,\"marker.color\").set(s(I,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(I,\"cartesian\")&&s(I,\"marker.colors\").set(s(I,\"marker.color\").get())}}else{var Y=i._size,X=H.orient,$=\"top\"===X||\"bottom\"===X;if(\"thicknessmode\"===j){var J=$?Y.h:Y.w;S(q+\"thickness\",H.thickness*(\"fraction\"===D?1/J:J),n)}else{var K=$?Y.w:Y.h;S(q+\"len\",H.len*(\"fraction\"===D?1/K:K),n)}}if(x[L][n]=B(O),-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=I.x&&!I.y?\"h\":\"v\";if((z.get()||Q)===P.orientation)continue}else\"orientationaxes\"===L&&(I.orientation={v:\"h\",h:\"v\"}[P.orientation]);T.swapXYData(I),y.calc=y.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(T.manageArrayContainers(z,D,x),y.calc=!0):(R?R.arrayOk&&!u.traceIs(P,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(O))?y.calc=!0:A.update(y,R):y.calc=!0,z.set(D))}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&p.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\"),et=tt.get();\"x\"===et?tt.set(\"y\"):\"y\"===et?tt.set(\"x\"):\"x unified\"===et?tt.set(\"y unified\"):\"y unified\"===et&&tt.set(\"x unified\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(g=[],n=0;n<r.length;n++){var rt=l[r[n]];u.traceIs(rt,\"cartesian\")&&(b(rt.xaxis||\"x\"),b(rt.yaxis||\"y\"))}S(g.map(w),!0,0),S(g.map(k),[0,1],0)}}else z=d(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[B(z.get())],z.set(Array.isArray(F)?F[0]:F),y.calc=!0}return(y.calc||y.plot)&&(y.fullReplot=!0),{flags:y,undoit:x,redoit:v,traces:r,eventData:o.extendDeepNoArrays([],[m,r])}}function V(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1&&-1===r.indexOf(\"grouptitlefont\")?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function q(t,e,r){t=o.getGraphDiv(t),T.clearPromiseQueue(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=X(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(k.layoutReplot):Object.keys(n).length&&(H(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(k.doLegend),a.layoutstyle&&s.push(k.layoutStyles),a.axrange&&G(s,i.rangesAltered),a.ticks&&s.push(k.doTicksRelayout),a.modebar&&s.push(k.doModeBar),a.camera&&s.push(k.doCamera),a.colorbars&&s.push(k.doColorBars),s.push(E)),s.push(f.rehover,f.redrag,f.reselect),c.add(t,q,[t,i.undoit],q,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then((function(){return t.emit(\"plotly_relayout\",i.eventData),t}))}function H(t,e,r){var n,i,a=t._fullLayout;if(!e.axrange)return!1;for(var s in e)if(\"axrange\"!==s&&e[s])return!1;var l=function(t,e){return o.coerce(n,i,m,t,e)},c={};for(var u in r.rangesAltered){var h=p.id2name(u);if(n=t.layout[h],i=a[h],d(n,i,l,c),i._matchGroup)for(var f in i._matchGroup)if(f!==u){var g=a[p.id2name(f)];g.autorange=i.autorange,g.range=i.range.slice(),g._input.range=i.range.slice()}}return!0}function G(t,e){var r=e?function(t){var r=[];for(var n in e){var i=p.getFromId(t,n);if(r.push(n),-1!==(i.ticklabelposition||\"\").indexOf(\"inside\")&&i._anchorAxis&&r.push(i._anchorAxis._id),i._matchGroup)for(var a in i._matchGroup)e[a]||r.push(a)}return p.draw(t,r,{skipTitle:!0})}:function(t){return p.draw(t,\"redraw\")};t.push(_,k.doAutoRangeAndConstraints,r,k.drawData,k.finalDraw)}var Z=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,W=/^[xyz]axis[0-9]*\\.autorange$/,Y=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function X(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=N(l._preGUI,c),d=Object.keys(e),m=p.list(t),g=o.extendDeepAll({},e),y={};for(V(e),d=Object.keys(e),n=0;n<d.length;n++)if(0===d[n].indexOf(\"allaxes\")){for(i=0;i<m.length;i++){var v=m[i]._id.substr(1),x=-1!==v.indexOf(\"scene\")?v+\".\":\"\",_=d[n].replace(\"allaxes\",x+m[i]._name);e[_]||(e[_]=e[d[n]])}delete e[d[n]]}var b=A.layoutFlags(),k={},S={};function E(t,r){if(Array.isArray(t))t.forEach((function(t){E(t,r)}));else if(!(t in e)&&!T.hasParent(e,t)){var n=f(a,t);t in S||(S[t]=B(n.get())),void 0!==r&&n.set(r)}}var C,L={};function I(t){var e=p.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var P in e){if(T.hasParent(e,P))throw new Error(\"cannot set \"+P+\" and a parent attribute simultaneously\");for(var z=f(a,P),O=e[P],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,j=z.parts.slice(0,D).join(\".\"),U=s(t.layout,j).get(),q=s(l,j).get(),H=z.get();if(void 0!==O){k[P]=O,S[P]=\"reverse\"===R?O:B(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==O)for(var X in G.impliedEdits)E(o.relativeAttr(P,X),G.impliedEdits[X]);if(-1!==[\"width\",\"height\"].indexOf(P))if(O){E(\"autosize\",null);var J=\"height\"===P?\"width\":\"height\";E(J,l[J])}else l[P]=t._initialAutoSize[P];else if(\"autosize\"===P)E(\"width\",O?null:l.width),E(\"height\",O?null:l.height);else if(F.match(Z))I(F),s(l,j+\"._inputRange\").set(null);else if(F.match(W)){I(F),s(l,j+\"._inputRange\").set(null);var K=s(l,j).get();K._inputDomain&&(K._input.domain=K._inputDomain.slice())}else F.match(Y)&&s(l,j+\"._inputDomain\").set(null);if(\"type\"===R){C=U;var Q=\"linear\"===q.type&&\"log\"===O,tt=\"log\"===q.type&&\"linear\"===O;if(Q||tt){if(C&&C.range)if(q.autorange)Q&&(C.range=C.range[1]>C.range[0]?[1,2]:[2,1]);else{var et=C.range[0],rt=C.range[1];Q?(et<=0&&rt<=0&&E(j+\".autorange\",!0),et<=0?et=rt/1e6:rt<=0&&(rt=et/1e6),E(j+\".range[0]\",Math.log(et)/Math.LN10),E(j+\".range[1]\",Math.log(rt)/Math.LN10)):(E(j+\".range[0]\",Math.pow(10,et)),E(j+\".range[1]\",Math.pow(10,rt)))}else E(j+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,O,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,O,E)}else E(j+\".autorange\",!0),E(j+\".range\",null);s(l,j+\"._inputRange\").set(null)}else if(R.match(M)){var nt=s(l,P).get(),it=(O||{}).type;it&&\"-\"!==it||(it=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,nt,it,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,nt,it,E)}var at=w.containerArrayMatch(P);if(at){r=at.array,n=at.index;var ot=at.property,st=G||{editType:\"calc\"};\"\"!==n&&\"\"===ot&&(w.isAddVal(O)?S[P]=null:w.isRemoveVal(O)?S[P]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(b,st),y[r]||(y[r]={});var lt=y[r][n];lt||(lt=y[r][n]={}),lt[ot]=O,delete e[P]}else\"reverse\"===R?(U.range?U.range.reverse():(E(j+\".autorange\",!0),U.range=[1,0]),q.autorange?b.calc=!0:b.plot=!0):(\"dragmode\"===P&&(!1===O&&!1!==H||!1!==O&&!1===H)||l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===P&&(\"lasso\"===O||\"select\"===O)&&\"lasso\"!==H&&\"select\"!==H||l._has(\"gl2d\")?b.plot=!0:G?A.update(b,G):b.calc=!0,z.set(O))}}for(r in y)w.applyContainerArrayChanges(t,f(a,r),y[r],b,f)||(b.plot=!0);for(var ct in L){var ut=(C=p.getFromId(t,ct))&&C._constraintGroup;if(ut)for(var ht in b.calc=!0,ut)L[ht]||(p.getFromId(t,ht)._constraintShrinkable=!0)}($(t)||e.height||e.width)&&(b.plot=!0);var ft=l.shapes;for(n=0;n<ft.length;n++)if(ft[n].showlegend){b.calc=!0;break}return(b.plot||b.calc)&&(b.layoutReplot=!0),{flags:b,rangesAltered:L,undoit:S,redoit:k,eventData:g}}function $(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function J(t,r,n,i){t=o.getGraphDiv(t),T.clearPromiseQueue(t),o.isPlainObject(r)||(r={}),o.isPlainObject(n)||(n={}),Object.keys(r).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=T.coerceTraceIndices(t,i),s=U(t,o.extendFlat({},r),a),l=s.flags,u=X(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&T.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(k.layoutReplot):l.fullReplot?p.push(e._doPlot):(p.push(f.previousPromises),H(t,h,u)||f.supplyDefaults(t),l.style&&p.push(k.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(k.doColorBars),h.legend&&p.push(k.doLegend),h.layoutstyle&&p.push(k.layoutStyles),h.axrange&&G(p,u.rangesAltered),h.ticks&&p.push(k.doTicksRelayout),h.modebar&&p.push(k.doModeBar),h.camera&&p.push(k.doCamera),p.push(E)),p.push(f.rehover,f.redrag,f.reselect),c.add(t,J,[t,s.undoit,u.undoit,s.traces],J,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then((function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t}))}function K(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var Q=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center|fitbounds)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^(map\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],tt=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function et(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i){var a=i[1]||\"\";return{head:a,tail:t.substr(a.length+1),attr:n.attr}}}}function rt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function nt(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function at(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function ot(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(Z.test(l)||W.test(l))&&(u.rangesAltered[r[0]]=1),Y.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function m(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var g=t[a],y=e[a],v=r.concat(a);if(l=v.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof g&&g!==y){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(v))&&(!i._compareAsJSON||JSON.stringify(g)!==JSON.stringify(y))){var _,b=i.valType,w=m(i),T=Array.isArray(g),k=Array.isArray(y);if(T&&k){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===y)w&&T?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var I=Math.min(g.length,y.length),P=Math.max(g.length,y.length);if(I!==P){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(_=0;_<I;_++)ot(g[_],y[_],v.concat(_),o.extendFlat({inArray:a,arrayIndex:_},n));if(L)for(_=I;_<P;_++)C.push(_)}else!b&&o.isPlainObject(g)?ot(g,y,v,n):w?T&&k?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):T!==k?u.calc=!0:d():T&&k&&g.length===y.length&&String(g)===String(y)||d()}}}for(a in e)if(!(a in t)&&\"_\"!==a.charAt(0)&&\"function\"!=typeof e[a]){if(m(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function st(t,e){var r;for(r in t)if(\"_\"!==r.charAt(0)){var n=t[r],i=e[r];if(n!==i)if(o.isPlainObject(n)&&o.isPlainObject(i)){if(st(n,i))return!0}else{if(!Array.isArray(n)||!Array.isArray(i))return!0;if(n.length!==i.length)return!0;for(var a=0;a<n.length;a++)if(n[a]!==i[a]){if(!o.isPlainObject(n[a])||!o.isPlainObject(i[a]))return!0;if(st(n[a],i[a]))return!0}}}}function lt(t){var e=t._fullLayout,r=t.getBoundingClientRect();if(!o.equalDomRects(r,e._lastBBox)){var n=e._invTransform=o.inverseTransformMatrix(o.getFullTransformMatrix(t));e._invScaleX=Math.sqrt(n[0][0]*n[0][0]+n[0][1]*n[0][1]+n[0][2]*n[0][2]),e._invScaleY=Math.sqrt(n[1][0]*n[1][0]+n[1][1]*n[1][1]+n[1][2]*n[1][2]),e._lastBBox=r}}e.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise((function(a,u){function h(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&function(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,T.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then((function(){e.onComplete&&e.onComplete()})),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}()};e()}var p,d,m=0;function g(t){return Array.isArray(i)?m>=i.length?t.transitionOpts=i[m]:t.transitionOpts=i[0]:t.transitionOpts=i,m++,t}var y=[],v=null==e,x=Array.isArray(e);if(v||x||!o.isPlainObject(e)){if(v||-1!==[\"string\",\"number\"].indexOf(typeof e))for(p=0;p<n._frames.length;p++)(d=n._frames[p])&&(v||String(d.group)===String(e))&&y.push({type:\"byname\",name:String(d.name),data:g({name:d.name})});else if(x)for(p=0;p<e.length;p++){var _=e[p];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:g({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:g(o.extendFlat({},_))})}}else y.push({type:\"object\",data:g(o.extendFlat({},e))});for(p=0;p<y.length;p++)if(\"byname\"===(d=y[p]).type&&!n._frameHash[d.data.name])return o.warn('animate failure: frame not found: \"'+d.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var b=t._fullLayout._currentFrame;if(b&&r.fromcurrent){var w=-1;for(p=0;p<y.length;p++)if(\"byname\"===(d=y[p]).type&&d.name===b){w=p;break}if(w>0&&w<y.length-1){var k=[];for(p=0;p<y.length;p++)d=y[p],(\"byname\"!==y[p].type||p>w)&&k.push(d);y=k}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var p=l(i),d=s(i);d.duration=Math.min(d.duration,p.duration);var m={frame:o,name:e[i].name,frameOpts:p,transitionOpts:d};i===e.length-1&&(m.onComplete=c(a,2),m.onInterrupt=u),n._frameQueue.push(m)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||h()}}(y):(t.emit(\"plotly_animated\"),a())}))},e.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var m=e[n].name,g=(u[m]||d[m]||{}).name,y=e[n].name,v=u[g]||d[g];g&&y&&\"number\"==typeof y&&v&&S<5&&(S++,o.warn('addFrames: overwriting frame \"'+(u[g]||d[g]).name+'\" with a frame whose name of type \"number\" also equates to \"'+g+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===S&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[m]={name:m},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort((function(t,e){return t.index>e.index?-1:t.index<e.index?1:0}));var x=[],_=[],b=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),_.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,b)),x.push({type:\"insert\",index:s,value:i}),_.unshift({type:\"delete\",index:s}),b++}var w=f.modifyFrames,T=f.modifyFrames,k=[t,_],A=[t,x];return c&&c.add(t,w,k,T,A),f.modifyFrames(t,x)},e.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},e.addTraces=function t(r,n,i){r=o.getGraphDiv(r);var a,s,l=[],u=e.deleteTraces,h=t,f=[r,l],p=[r,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(void 0===e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(void 0===r||Array.isArray(r)||(r=[r]),void 0!==r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(r,n,i),Array.isArray(n)||(n=[n]),n=n.map((function(t){return o.extendFlat({},t)})),T.cleanData(n),a=0;a<n.length;a++)r.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(void 0===i)return s=e.redraw(r),c.add(r,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{O(r,l,i)}catch(t){throw r.data.splice(r.data.length-n.length,n.length),t}return c.startSequence(r),c.add(r,u,f,h,p),s=e.moveTraces(r,l,i),c.stopSequence(r),s},e.deleteTraces=function t(r,n){r=o.getGraphDiv(r);var i,a,s=[],l=e.addTraces,u=t,h=[r,s,n],f=[r,n];if(void 0===n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),z(r,n,\"indices\"),(n=P(n,r.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=r.data.splice(n[i],1)[0],s.push(a);var p=e.redraw(r);return c.add(r,l,h,u,f),p},e.extendTraces=function t(r,n,i,a){var s=D(r=o.getGraphDiv(r),n,i,a,(function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=R(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]})),l=e.redraw(r),u=[r,s.update,i,s.maxPoints];return c.add(r,e.prependTraces,u,t,arguments),l},e.moveTraces=function t(r,n,i){var a,s=[],l=[],u=t,h=t,f=[r=o.getGraphDiv(r),i,n],p=[r,n,i];if(O(r,n,i),n=Array.isArray(n)?n:[n],void 0===i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=P(n,r.data.length-1),i=P(i,r.data.length-1),a=0;a<r.data.length;a++)-1===n.indexOf(a)&&s.push(r.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:r.data[n[a]]});for(l.sort((function(t,e){return t.newIndex-e.newIndex})),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);r.data=s;var d=e.redraw(r);return c.add(r,u,f,h,p),d},e.prependTraces=function t(r,n,i,a){var s=D(r=o.getGraphDiv(r),n,i,a,(function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=R(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]})),l=e.redraw(r),u=[r,s.update,i,s.maxPoints];return c.add(r,e.extendTraces,u,t,arguments),l},e.newPlot=function(t,r,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),e._doPlot(t,r,n,i)},e._doPlot=function(t,r,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(r)){var c=r;r=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[r,i,a]))return Promise.reject();r||i||o.isPlotDiv(t)||o.warn(\"Calling _doPlot as if redrawing but this container doesn't yet have a plot.\",t),I(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(r);Array.isArray(r)&&(T.cleanData(r),h?t.data=r:t.data.push.apply(t.data,r),t.empty=!1),t.layout&&!h||(t.layout=T.cleanLayout(i)),f.supplyDefaults(t);var d=t._fullLayout,m=d._has(\"cartesian\");d._replotting=!0,(h||d._shouldCreateBgLayer)&&(function(t){var e=n.select(t),r=t._fullLayout;if(r._calcInverseTransform=lt,r._calcInverseTransform(t),r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"user-select-none\",!0).classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),delete r._modeBar,r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each((function(){this.id&&(i[this.id.split(\"-\")[1]]=1)})),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(x.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._smithlayer=r._paper.append(\"g\").classed(\"smithlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._iciclelayer=r._paper.append(\"g\").classed(\"iciclelayer\",!0),r._treemaplayer=r._paper.append(\"g\").classed(\"treemaplayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._selectionLayer=r._toppaper.append(\"g\").classed(\"selectionlayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}(t),d._shouldCreateBgLayer&&delete d._shouldCreateBgLayer),g.initGradients(t),g.initPatterns(t),h&&p.saveShowSpikeInitial(t);var y=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;y&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var b=o.extendFlat({},d._size),w=0;function A(){if(f.clearAutoMarginIds(t),k.drawMarginPushers(t),p.allowAutoMargin(t),t._fullLayout.title.text&&t._fullLayout.title.automargin&&f.allowAutoMargin(t,\"title.automargin\"),d._has(\"pie\"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];\"pie\"===n.type&&n.automargin&&f.allowAutoMargin(t,\"pie.\"+n.uid+\".automargin\")}return f.doAutoMargin(t),f.previousPromises(t)}function M(){t._transitioning||(k.doAutoRangeAndConstraints(t),h&&p.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var S=[f.previousPromises,function(){if(s)return e.addFrames(t,s)},function e(){for(var r=d._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);!d._glcanvas&&d._has(\"gl\")&&(d._glcanvas=d._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],(function(t){return t.key})),d._glcanvas.enter().append(\"canvas\").attr(\"class\",(function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")})).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"}));var i=t._context.plotGlPixelRatio;if(d._glcanvas){d._glcanvas.attr(\"width\",d.width*i).attr(\"height\",d.height*i).style(\"width\",d.width+\"px\").style(\"height\",d.height+\"px\");var a=d._glcanvas.data()[0].regl;if(a&&(Math.floor(d.width*i)!==a._gl.drawingBufferWidth||Math.floor(d.height*i)!==a._gl.drawingBufferHeight)){var s=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!w)return o.log(s+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,d),f.supplyDefaults(t),d=t._fullLayout,f.doCalcdata(t),w++,e();o.error(s)}}return\"h\"===d.modebar.orientation?d._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):d._modebardiv.style(\"width\",null).style(\"height\",d.height+\"px\"),f.previousPromises(t)},A,function(){if(f.didMarginChange(b,d._size))return o.syncOrAsync([A,k.layoutStyles],t)}];m&&S.push((function(){if(y)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),M],t);M()})),S.push(k.layoutStyles),m&&S.push((function(){return p.draw(t,h?\"\":\"redraw\")}),(function(t){var e=t._fullLayout._insideTickLabelsUpdaterange;if(e)return t._fullLayout._insideTickLabelsUpdaterange=void 0,q(t,e).then((function(){p.saveRangeInitial(t,!0)}))})),S.push(k.drawData,k.finalDraw,v,f.addLinks,f.rehover,f.redrag,f.reselect,f.doAutoMargin,f.previousPromises);var C=o.syncOrAsync(S,t);return C&&C.then||(C=Promise.resolve()),C.then((function(){return E(t),t}))},e.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},e.react=function(t,r,n,i){var a,l;t=o.getGraphDiv(t),T.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(r)){var d=r;r=d.data,n=d.layout,i=d.config,a=d.frames}var m=!1;if(i){var g=o.extendDeep({},t._context);t._context=void 0,I(t,i),m=st(g,t._context)}t.data=r||[],T.cleanData(t.data),t.layout=n||{},T.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d,m,g=n._preGUI,y=[],v={},x={};for(i in g){if(u=et(i,Q)){if(d=u.head,m=u.tail,a=u.attr||d+\".uirevision\",(c=(l=s(n,a).get())&&rt(a,e))&&c===l){if(null===(h=g[i])&&(h=void 0),at(p=(f=s(e,i)).get(),h)){void 0===p&&\"autorange\"===m&&y.push(d),f.set(B(s(n,i).get()));continue}if(\"autorange\"===m||\"range[\"===m.substr(0,6)){var _=g[d+\".range[0]\"],b=g[d+\".range[1]\"],w=g[d+\".autorange\"];if(w||null===w&&null===_&&null===b){if(!(d in v)){var T=s(e,d).get();v[d]=T&&(T.autorange||!1!==T.autorange&&(!T.range||2!==T.range.length))}if(v[d]){f.set(B(s(n,i).get()));continue}}}}}else o.warn(\"unrecognized GUI edit: \"+i);delete g[i],u&&\"range[\"===u.tail.substr(0,6)&&(x[u.head]=1)}for(var k=0;k<y.length;k++){var A=y[k];if(x[A]){var M=s(e,A).get();M&&delete M.autorange}}var S=n._tracePreGUI;for(var E in S){var C,L=S[E],I=null;for(i in L){if(!I){var P=nt(E,r);if(P<0){delete S[E];break}var z=it(E,t,(C=r[P]._fullInput).index);if(z<0){delete S[E];break}I=t[z]}if(u=et(i,tt)){if(u.attr?c=(l=s(n,u.attr).get())&&rt(u.attr,e):(l=C.uirevision,void 0===(c=I.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=L[i])&&(h=void 0),at(p=(f=s(I,i)).get(),h))){f.set(B(s(C,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+E);delete L[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var y=t._fullData,v=t._fullLayout,x=void 0===v.datarevision,_=v.transition,b=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,ot(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,v,x,_),w=b.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,ot(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,y,x,_,w);if($(t)&&(b.layoutReplot=!0),M.calc||b.calc){t.calcdata=void 0;for(var S=Object.getOwnPropertyNames(v),C=0;C<S.length;C++){var L=S[C],P=L.substring(0,5);if(\"xaxis\"===P||\"yaxis\"===P){var z=v[L]._emptyCategories;z&&z()}}}else f.supplyDefaultsUpdateCalc(t.calcdata,y);var O=[];if(a&&(t._transitionData={},f.createTransitionData(t),O.push((function(){return e.addFrames(t,a)}))),v.transition&&!m&&(M.anim||b.anim))b.ticks&&O.push(k.doTicksRelayout),f.doCalcdata(t),k.doAutoRangeAndConstraints(t),O.push((function(){return f.transitionFromReact(t,M,b,p)}));else if(M.fullReplot||b.layoutReplot||m)t._fullLayout._skipDefaults=!0,O.push(e._doPlot);else{for(var D in b.arrays){var R=b.arrays[D];if(R.length){var F=u.getComponentMethod(D,\"drawOne\");if(F!==o.noop)for(var N=0;N<R.length;N++)F(t,R[N]);else{var j=u.getComponentMethod(D,\"draw\");if(j===o.noop)throw new Error(\"cannot draw components: \"+D);j(t)}}}O.push(f.previousPromises),M.style&&O.push(k.doTraceStyle),(M.colorbars||b.colorbars)&&O.push(k.doColorBars),b.legend&&O.push(k.doLegend),b.layoutstyle&&O.push(k.layoutStyles),b.axrange&&G(O),b.ticks&&O.push(k.doTicksRelayout),b.modebar&&O.push(k.doModeBar),b.camera&&O.push(k.doCamera),O.push(E)}O.push(f.rehover,f.redrag,f.reselect),(l=o.syncOrAsync(O,t))&&l.then||(l=Promise.resolve(t))}else l=e.newPlot(t,r,n,i);return l.then((function(){return t.emit(\"plotly_react\",{data:r,layout:n}),t}))},e.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return T.cleanData(t.data),T.cleanLayout(t.layout),t.calcdata=void 0,e._doPlot(t).then((function(){return t.emit(\"plotly_redraw\"),t}))},e.relayout=q,e.restyle=F,e.setPlotConfig=function(t){return o.extendFlat(b,t)},e.update=J,e._guiRelayout=K(q),e._guiRestyle=K(F),e._guiUpdate=K(J),e._storeDirectGUIEdit=function(t,e,r){for(var n in r)j(n,s(t,n).get(),r[n],e)}},24452:function(t){\"use strict\";var e={staticPlot:{valType:\"boolean\",dflt:!1},typesetMath:{valType:\"boolean\",dflt:!0},plotlyServerURL:{valType:\"string\",dflt:\"\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},editSelection:{valType:\"boolean\",dflt:!0},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\",\"map\"],extras:[!0,!1],dflt:\"gl3d+geo+map\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"integer\",min:0,max:2,dflt:1},notifyOnLogging:{valType:\"integer\",min:0,max:2,dflt:0},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},r={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(e,r),t.exports={configAttributes:e,dfltConfig:r}},57297:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(9829),o=r(6704),s=r(58935),l=r(49722),c=r(24452).configAttributes,u=r(13582),h=i.extendDeepAll,f=i.isPlainObject,p=i.isArrayOrTypedArray,d=i.nestedProperty,m=i.valObjectMeta,g=\"_isSubplotObj\",y=\"_isLinkedToArray\",v=\"_deprecated\",x=[g,y,\"_arrayAttrRegexps\",v];function _(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(b(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!f(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!b(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!b(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!b(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function b(t){return t===Math.round(t)&&t>=0}function w(){var t,e,r={};for(t in h(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)k(r,e,e.attr[i]);else k(r,e,\"subplot\"===e.attr?e.name:e.attr);for(t in n.componentsRegistry){var a=(e=n.componentsRegistry[t]).schema;if(a&&(a.subplots||a.layout)){var s=a.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l];delete r.xaxis.shift,delete r.xaxis.autoshift}else\"colorscale\"===e.name?h(r,e.layoutAttributes):e.layoutAttributes&&A(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}function T(t){return function(t){e.crawl(t,(function(t,r,n){e.isValObject(t)?!0!==t.arrayOk&&\"data_array\"!==t.valType||(n[r+\"src\"]={valType:\"string\",editType:\"none\"}):f(t)&&(t.role=\"object\")}))}(t),function(t){e.crawl(t,(function(t,e,r){if(t){var n=t[y];n&&(delete t[y],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\")}}))}(t),function(t){!function t(e){for(var r in e)if(f(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function k(t,e,r){var n=d(t,r),i=h({},e.layoutAttributes);i[g]=!0,n.set(i)}function A(t,e,r){var n=d(t,r);n.set(h(n.get()||{},e))}e.IS_SUBPLOT_OBJ=g,e.IS_LINKED_TO_ARRAY=y,e.DEPRECATED=v,e.UNDERSCORE_ATTRS=x,e.get=function(){var t={};n.allTypes.forEach((function(r){t[r]=function(t){var r,i;i=(r=n.modules[t]._module).basePlotModule;var o={type:null},s=h({},a),l=h({},r.attributes);e.crawl(l,(function(t,e,r,n,i){d(s,i).set(void 0),void 0===t&&d(l,i).set(void 0)})),h(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity,n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup),n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel),r.selectPoints||delete o.selectedpoints,h(o,l),i.attributes&&h(o,i.attributes),o.type=t;var c={meta:r.meta||{},categories:r.categories||{},animatable:Boolean(r.animatable),type:t,attributes:T(o)};if(r.layoutAttributes){var u={};h(u,r.layoutAttributes),c.layoutAttributes=T(u)}return r.animatable||e.crawl(c,(function(t){e.isValObject(t)&&\"anim\"in t&&delete t.anim})),c}(r)}));var r,i={};return Object.keys(n.transformsRegistry).forEach((function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=h({},e.attributes);return Object.keys(n.componentsRegistry).forEach((function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach((function(e){A(r,i.schema.transforms[t][e],e)}))})),{attributes:T(r)}}(t)})),{defs:{valObjects:m,metaKeys:x.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:u.traces,layout:u.layout},impliedEdits:{}},traces:t,layout:w(),transforms:i,frames:(r={frames:h({},s)},T(r),r.frames),animation:T(l),config:T(c)}},e.crawl=function(t,r,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach((function(n){var o=t[n];if(-1===x.indexOf(n)){var s=(i?i+\".\":\"\")+n;r(o,n,t,a,s),e.isValObject(o)||f(o)&&\"impliedEdits\"!==n&&e.crawl(o,r,a+1,s)}}))},e.isValObject=function(t){return t&&void 0!==t.valType},e.findArrayAttributes=function(t){var r,n,i=[],o=[],s=[];function l(t,e,n,i){o=o.slice(0,i).concat([e]),s=s.slice(0,i).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&(\"colorbar\"!==o[i-1]||\"ticktext\"!==e&&\"tickvals\"!==e)&&c(r,0,\"\")}function c(t,e,r){var a=t[o[e]],l=r+o[e];if(e===o.length-1)p(a)&&i.push(n+l);else if(s[e]){if(Array.isArray(a))for(var u=0;u<a.length;u++)f(a[u])&&c(a[u],e+1,l+\"[\"+u+\"].\")}else f(a)&&c(a,e+1,l+\".\")}r=t,n=\"\",e.crawl(a,l),t._module&&t._module.attributes&&e.crawl(t._module.attributes,l);var u=t.transforms;if(u)for(var h=0;h<u.length;h++){var d=u[h],m=d._module;m&&(n=\"transforms[\"+h+\"].\",r=d,e.crawl(m.attributes,l))}return i},e.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!b(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else{var u=t._module;if(u||(u=(n.modules[t.type||a.type.dflt]||{})._module),!u)return!1;if(!(i=(r=u.attributes)&&r[o])){var h=u.basePlotModule;h&&h.attributes&&(i=h.attributes[o])}i||(i=a[o])}return _(i,e,s)},e.getLayoutValObject=function(t,e){var r=function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var h=t._modules;if(h)for(r=0;r<h.length;r++)if((s=h[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}return e in o&&o[e]}(t,e[0]);return _(r,e,1)}},78032:function(t,e,r){\"use strict\";var n=r(34809),i=r(9829),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},e.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},e.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},e.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},e.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},e.arrayDefaultKey=l,e.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},71817:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(44122),o=r(34809),s=r(30635),l=r(34823),c=r(78766),u=r(62203),h=r(17240),f=r(95433),p=r(29714),d=r(4530),m=r(84391),g=m.enforce,y=m.clean,v=r(32919).doAutoRange,x=\"start\",_=r(54826).zindexSeparator;function b(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&a[0]<e[1]&&a[1]>e[0])return!0}return!1}function w(t){var r,i,s,l,h,m,g=t._fullLayout,y=g._size,v=y.p,x=p.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(u.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),e.drawMainTitle(t),f.manage(t),!g._has(\"cartesian\"))return a.previousPromises(t);function w(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-v-n:e._offset+e._length+v+n:y.t+y.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+v+n:e._offset-v-n:y.l+y.w*(t.position||0)+n%1}for(r=0;r<x.length;r++){var k=(l=x[r])._anchorAxis;l._linepositions={},l._lw=u.crispRound(t,l.linewidth,1),l._mainLinePosition=w(l,k,l.side),l._mainMirrorPosition=l.mirror&&k?w(l,k,d.OPPOSITE_SIDE[l.side]):null}var M=[],S=[],E=[],C=1===c.opacity(g.paper_bgcolor)&&1===c.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((s=g._plots[i]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var L=s.xaxis.domain,I=s.yaxis.domain,P=s.plotgroup;if(b(L,I,E)&&-1===i.indexOf(_)){var z=P.node(),O=s.bg=o.ensureSingle(P,\"rect\",\"bg\");z.insertBefore(O.node(),z.childNodes[0]),S.push(i)}else P.select(\"rect.bg\").remove(),E.push([L,I]),C||(M.push(i),S.push(i))}var D,R,F,B,N,j,U,V,q,H,G,Z,W,Y=g._bgLayer.selectAll(\".bg\").data(M);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each((function(t){g._plots[t].bg=n.select(this)})),r=0;r<S.length;r++)s=g._plots[S[r]],h=s.xaxis,m=s.yaxis,s.bg&&void 0!==h._offset&&void 0!==m._offset&&s.bg.call(u.setRect,h._offset-v,m._offset-v,h._length+2*v,m._length+2*v).call(c.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){s=g._plots[i],h=s.xaxis,m=s.yaxis;var X,$,J=s.clipId=\"clip\"+g._uid+i+\"plot\",K=o.ensureSingleById(g._clips,\"clipPath\",J,(function(t){t.classed(\"plotclip\",!0).append(\"rect\")}));s.clipRect=K.select(\"rect\").attr({width:h._length,height:m._length}),u.setTranslate(s.plot,h._offset,m._offset),s._hasClipOnAxisFalse?(X=null,$=J):(X=J,$=null),u.setClipUrl(s.plot,X,t),s.layerClipId=$}function Q(t){return\"M\"+D+\",\"+t+\"H\"+R}function tt(t){return\"M\"+h._offset+\",\"+t+\"h\"+h._length}function et(t){return\"M\"+t+\",\"+V+\"V\"+U}function rt(t){return void 0!==m._shift&&(t+=m._shift),\"M\"+t+\",\"+m._offset+\"v\"+m._length}function nt(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){s=g._plots[i],h=s.xaxis,m=s.yaxis;var it=\"M0,0\";T(h,i)&&(N=A(h,\"left\",m,x),D=h._offset-(N?v+N:0),j=A(h,\"right\",m,x),R=h._offset+h._length+(j?v+j:0),F=w(h,m,\"bottom\"),B=w(h,m,\"top\"),!(W=!h._anchorAxis||i!==h._mainSubplot)||\"allticks\"!==h.mirror&&\"all\"!==h.mirror||(h._linepositions[i]=[F,B]),it=nt(h,Q,tt),W&&h.showline&&(\"all\"===h.mirror||\"allticks\"===h.mirror)&&(it+=Q(F)+Q(B)),s.xlines.style(\"stroke-width\",h._lw+\"px\").call(c.stroke,h.showline?h.linecolor:\"rgba(0,0,0,0)\")),s.xlines.attr(\"d\",it);var at=\"M0,0\";T(m,i)&&(G=A(m,\"bottom\",h,x),U=m._offset+m._length+(G?v:0),Z=A(m,\"top\",h,x),V=m._offset-(Z?v:0),q=w(m,h,\"left\"),H=w(m,h,\"right\"),!(W=!m._anchorAxis||i!==m._mainSubplot)||\"allticks\"!==m.mirror&&\"all\"!==m.mirror||(m._linepositions[i]=[q,H]),at=nt(m,et,rt),W&&m.showline&&(\"all\"===m.mirror||\"allticks\"===m.mirror)&&(at+=et(q)+et(H)),s.ylines.style(\"stroke-width\",m._lw+\"px\").call(c.stroke,m.showline?m.linecolor:\"rgba(0,0,0,0)\")),s.ylines.attr(\"d\",at)}return p.makeClipPaths(t),a.previousPromises(t)}function T(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function k(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=d.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(k(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&k(t,e,a))return a._lw}return 0}function M(t){return\"top\"===t?d.CAP_SHIFT+.3+\"em\":\"bottom\"===t?\"-0.3em\":d.MID_SHIFT+\"em\"}e.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},e.drawMainTitle=function(t){var e=t._fullLayout.title,r=t._fullLayout,i=function(t){var e=t.title,r=\"middle\";return o.isRightAnchor(e)?r=\"end\":o.isLeftAnchor(e)&&(r=x),r}(r),l=function(t){var e=t.title,r=\"0em\";return o.isTopAnchor(e)?r=d.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=d.MID_SHIFT+\"em\"),r}(r),c=function(t,e){var r=t.title,n=t._size,i=0;return\"0em\"!==e&&e?e===d.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b,\"auto\"===r.y?n.t/2:\"paper\"===r.yref?n.t+n.h-n.h*r.y+i:t.height-t.height*r.y+i}(r,l),f=function(t,e){var r=t.title,n=t._size,i=0;return e===x?i=r.pad.l:\"end\"===e&&(i=-r.pad.r),\"paper\"===r.xref?n.l+n.w*r.x+i:t.width*r.x+i}(r,i);if(h.draw(t,\"gtitle\",{propContainer:r,propName:\"title.text\",subtitlePropName:\"title.subtitle.text\",placeholder:r._dfltTitle.plot,subtitlePlaceholder:r._dfltTitle.subtitle,attributes:{x:f,y:c,\"text-anchor\":i,dy:l}}),e.text&&e.automargin){var p=n.selectAll(\".gtitle\"),m=u.bBox(n.selectAll(\".g-gtitle\").node()).height,g=function(t,e,r){var n=e.y,i=e.yanchor,a=n>.5?\"t\":\"b\",o=t._fullLayout.margin[a],s=0;return\"paper\"===e.yref?s=r+e.pad.t+e.pad.b:\"container\"===e.yref&&(s=function(t,e,r,n,i){var a=0;return\"middle\"===r&&(a+=i/2),\"t\"===t?(\"top\"===r&&(a+=i),a+=n-e*n):(\"bottom\"===r&&(a+=i),a+=e*n),a}(a,n,i,t._fullLayout.height,r)+e.pad.t+e.pad.b),s>o?s:0}(t,e,m);if(g>0){!function(t,e,r,n){var i=\"title.automargin\",s=t._fullLayout.title,l=s.y>.5?\"t\":\"b\",c={x:s.x,y:s.y,t:0,b:0},u={};\"paper\"===s.yref&&function(t,e,r,n,i){var a=\"paper\"===e.yref?t._fullLayout._size.h:t._fullLayout.height,s=o.isTopAnchor(e)?n:n-i,l=\"b\"===r?a-s:s;return!(o.isTopAnchor(e)&&\"t\"===r||o.isBottomAnchor(e)&&\"b\"===r)&&l<i}(t,s,l,e,n)?c[l]=r:\"container\"===s.yref&&(u[l]=r,t._fullLayout._reservedMargin[i]=u),a.allowAutoMargin(t,i),a.autoMargin(t,i,c)}(t,c,g,m),p.attr({x:f,y:c,\"text-anchor\":i,dy:M(e.yanchor)}).call(s.positionText,f,c);var y=(e.text.match(s.BR_TAG_ALL)||[]).length;if(y){var v=d.LINE_SPACING*y+d.MID_SHIFT;0===e.y&&(v=-v),p.selectAll(\".line\").each((function(){var t=+this.getAttribute(\"dy\").slice(0,-2)-v+\"em\";this.setAttribute(\"dy\",t)}))}var _=n.selectAll(\".gtitle-subtitle\");if(_.node()){var b=p.node().getBBox(),w=b.y+b.height+h.SUBTITLE_PADDING_EM*e.subtitle.font.size;_.attr({x:f,y:w,\"text-anchor\":i,dy:M(e.yanchor)}).call(s.positionText,f,w)}}}},e.doTraceStyle=function(t){var r,n=t.calcdata,o=[];for(r=0;r<n.length;r++){var s=n[r],c=s[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(s,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(r=0;r<o.length;r++){var d=o[r];d.fn(t,d.cd0)}l(t),e.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},e.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},e.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"_doPlot\",t,\"\",e)},e.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},e.doTicksRelayout=function(t){return p.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),l(t),e.redrawReglTraces(t)),e.drawMainTitle(t),a.previousPromises(t)},e.doModeBar=function(t){var e=t._fullLayout;f.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},e.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]];i._scene.setViewport(i)}},e.drawData=function(t){var r=t._fullLayout;l(t);for(var n=r._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return e.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"selections\",\"draw\")(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),r._replotting=!1,a.previousPromises(t)},e.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},e.doAutoRangeAndConstraints=function(t){for(var e,r=p.list(t,\"\",!0),n={},i=0;i<r.length;i++)if(!n[(e=r[i])._id]){n[e._id]=1,y(t,e),v(t,e);var a=e._matchGroup;if(a)for(var o in a){var s=p.getFromId(t,o);v(t,s,e.range),n[o]=1}}g(t)},e.finalDraw=function(t){i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},e.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},53853:function(t,e,r){\"use strict\";var n=r(34809),i=n.isPlainObject,a=r(57297),o=r(44122),s=r(9829),l=r(78032),c=r(24452).dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],p=m(t,c,a),d=m(t,c,o),g=r(d);if(!g){var y=h(c);y!==c&&(g=r(d=m(t,y,o)))}if(!(s&&s===g||!g||g._noTemplating||\"data_array\"===g.valType||g.arrayOk&&Array.isArray(u)))if(!g.valType&&i(u))f(u,e,r,p,d);else if(g._isLinkedToArray&&Array.isArray(u))for(var v=!1,x=0,_={},b=0;b<u.length;b++){var w=u[b];if(i(w)){var T=w.name;if(T)_[T]||(f(w,e,r,m(u,x,p),m(u,x,d)),x++,_[T]=1);else if(!v){var k=m(t,l.arrayDefaultKey(c),a),A=m(u,x,p);f(w,e,r,A,m(u,x,d));var M=n.nestedProperty(e,A);n.nestedProperty(e,k).set(M.get()),M.set(null),v=!0}}}else n.nestedProperty(e,p).set(u)}}function p(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}function d(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}function m(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function g(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function y(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}e.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var a={data:{},layout:{}};e.forEach((function(t){var e={};f(t,e,d.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=a.data[r];i||(i=a.data[r]=[]),i.push(e)})),f(r,a.layout,p.bind(null,r)),delete a.layout.template;var l=r.template;if(i(l)){var h,m,g,y,v,x,_=l.layout;i(_)&&u(_,a.layout);var b=l.data;if(i(b)){for(m in a.data)if(g=b[m],Array.isArray(g)){for(x=(v=a.data[m]).length,y=g.length,h=0;h<x;h++)u(g[h%y],v[h]);for(h=x;h<y;h++)v.push(n.extendDeep({},g[h]))}for(m in b)m in a.data||(a.data[m]=n.extendDeep([],b[m]))}}return a},e.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,p=r._fullData,d={};if(i(s)?(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(m(e,n,r[a])),o!==n&&s.push(m(e,o,r[a]));for(a=0;a<s.length;a++)d[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=m(e,n,r);d[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var v,x={},_=0;_<p.length;_++){var b=p[_];x[v=b.type]=(x[v]||0)+1,b._fullInput._template||u.push({code:\"missing\",index:b._fullInput.index,traceType:v})}for(v in l){var w=l[v].length,T=x[v]||0;w>T?u.push({code:\"unused\",traceType:v,templateCount:w,dataCount:T}):T>w&&u.push({code:\"reused\",traceType:v,templateCount:w,dataCount:T})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=m(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&g(a)&&t(a,o)}}({data:p,layout:f},\"\"),u.length)return u.map(y)}},80491:function(t,e,r){\"use strict\";var n=r(10721),i=r(31420),a=r(44122),o=r(34809),s=r(84619),l=r(6243),c=r(72914),u=r(29697).version,h={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\",\"full-json\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};t.exports=function(t,e){var r,f,p,d;function m(t){return!(t in e)||o.validate(e[t],h[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],f=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),f=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!m(\"width\")&&null!==e.width||!m(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!m(\"format\"))throw new Error(\"Export format is not \"+o.join2(h.format.values,\", \",\" or \")+\".\");var g={};function y(t,r){return o.coerce(e,g,h,t,r)}var v=y(\"format\"),x=y(\"width\"),_=y(\"height\"),b=y(\"scale\"),w=y(\"setBackground\"),T=y(\"imageDataOnly\"),k=document.createElement(\"div\");k.style.position=\"absolute\",k.style.left=\"-5000px\",document.body.appendChild(k);var A=o.extendFlat({},f);x?A.width=x:null===e.width&&n(d.width)&&(A.width=d.width),_?A.height=_:null===e.height&&n(d.height)&&(A.height=d.height);var M=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(k);function E(){return new Promise((function(t){setTimeout(t,s.getDelay(k._fullLayout))}))}function C(){return new Promise((function(t,e){var r=l(k,v,b),n=k._fullLayout.width,h=k._fullLayout.height;function f(){i.purge(k),document.body.removeChild(k)}if(\"full-json\"===v){var p=a.graphJson(k,!1,\"keepdata\",\"object\",!0,!0);return p.version=u,p=JSON.stringify(p),f(),t(T?p:s.encodeJSON(p))}if(f(),\"svg\"===v)return t(T?r:s.encodeSVG(r));var d=document.createElement(\"canvas\");d.id=o.randstr(),c({format:v,width:n,height:h,scale:b,canvas:d,svg:r,promise:!0}).then(t).catch(e)}))}return new Promise((function(t,e){i.newPlot(k,r,A,M).then(S).then(E).then(C).then((function(e){t(function(t){return T?t.replace(s.IMAGE_URL_PREFIX,\"\"):t}(e))})).catch((function(t){e(t)}))}))}},2466:function(t,e,r){\"use strict\";var n=r(34809),i=r(44122),a=r(57297),o=r(24452).dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var g=h[f];if(\"transforms\"!==g){var y=o.slice();y.push(g);var v=t[g],x=e[g],_=m(r,g),b=(_||{}).valType,w=\"info_array\"===b,T=\"colorscale\"===b,k=(_||{}).items;if(d(r,g))if(s(v)&&s(x)&&\"any\"!==b)u(v,x,_,i,a,y);else if(w&&l(v)){v.length>x.length&&i.push(p(\"unused\",a,y.concat(x.length)));var A,M,S,E,C,L=x.length,I=Array.isArray(k);if(I&&(L=Math.min(L,k.length)),2===_.dimensions)for(M=0;M<L;M++)if(l(v[M])){v[M].length>x[M].length&&i.push(p(\"unused\",a,y.concat(M,x[M].length)));var P=x[M].length;for(A=0;A<(I?Math.min(P,k[M].length):P);A++)S=I?k[M][A]:k,E=v[M][A],C=x[M][A],n.validate(E,S)?C!==E&&C!==+E&&i.push(p(\"dynamic\",a,y.concat(M,A),E,C)):i.push(p(\"value\",a,y.concat(M,A),E))}else i.push(p(\"array\",a,y.concat(M),v[M]));else for(M=0;M<L;M++)S=I?k[M]:k,E=v[M],C=x[M],n.validate(E,S)?C!==E&&C!==+E&&i.push(p(\"dynamic\",a,y.concat(M),E,C)):i.push(p(\"value\",a,y.concat(M),E))}else if(_.items&&!w&&l(v)){var z,O,D=k[Object.keys(k)[0]],R=[];for(z=0;z<x.length;z++){var F=x[z]._index||z;if((O=y.slice()).push(F),s(v[F])&&s(x[z])){R.push(F);var B=v[F],N=x[z];s(B)&&!1!==B.visible&&!1===N.visible?i.push(p(\"invisible\",a,O)):u(B,N,D,i,a,O)}}for(z=0;z<v.length;z++)(O=y.slice()).push(z),s(v[z])?-1===R.indexOf(z)&&i.push(p(\"unused\",a,O)):i.push(p(\"object\",a,O,v[z]))}else!s(v)&&s(x)?i.push(p(\"object\",a,y,v)):c(v)||!c(x)||w||T?g in e?n.validate(v,_)?\"enumerated\"===_.valType&&(_.coerceNumber&&v!==+x||v!==x)&&i.push(p(\"dynamic\",a,y,v,x)):i.push(p(\"value\",a,y,v)):i.push(p(\"unused\",a,y,v)):i.push(p(\"array\",a,y,v));else i.push(p(\"schema\",a,y))}}return i}t.exports=function(t,e){void 0===t&&(t=[]),void 0===e&&(e={});var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var m=d._fullData,g=r.length,y=0;y<g;y++){var v=r[y],x=[\"data\",y];if(s(v)){var _=m[y],b=_.type,w=h.traces[b].attributes;w.type={valType:\"enumerated\",values:[b]},!1===_.visible&&!1!==v.visible&&f.push(p(\"invisible\",x)),u(v,_,w,f,x);var T=v.transforms,k=_.transforms;if(T){l(T)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<T.length;A++){var M=[\"transforms\",A],S=T[A].type;if(s(T[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(T[A],k[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}var C=d._fullLayout,L=function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,m);return u(c,C,L,f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=y(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function m(t,e){return e in t?t[e]:t[y(e).keyMinusId]}var g=n.counterRegex(\"([a-z]+)\");function y(t){var e=t.match(g);return{keyMinusId:e&&e[1],id:e&&e[2]}}},49722:function(t){\"use strict\";t.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},59008:function(t,e,r){\"use strict\";var n=r(34809),i=r(78032);t.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var m=Math.min(c.length,h.length);for(a=0;a<m;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},9829:function(t,e,r){\"use strict\";var n=r(80337),i=r(70192);t.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legend:{valType:\"subplotid\",dflt:\"legend\",editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},legendgrouptitle:{text:{valType:\"string\",dflt:\"\",editType:\"style\"},font:n({editType:\"style\"}),editType:\"style\"},legendrank:{valType:\"number\",dflt:1e3,editType:\"style\"},legendwidth:{valType:\"number\",min:0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:i.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},40528:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=i.dateTime2ms,o=i.incrementMonth,s=r(63821).ONEAVGMONTH;t.exports=function(t,e,r,i){if(\"date\"!==e.type)return{vals:i};var l=t[r+\"periodalignment\"];if(!l)return{vals:i};var c,u=t[r+\"period\"];if(n(u)){if((u=+u)<=0)return{vals:i}}else if(\"string\"==typeof u&&\"M\"===u.charAt(0)){var h=+u.substring(1);if(!(h>0&&Math.round(h)===h))return{vals:i};c=h}for(var f=e.calendar,p=\"start\"===l,d=\"end\"===l,m=t[r+\"period0\"],g=a(m,f)||0,y=[],v=[],x=[],_=i.length,b=0;b<_;b++){var w,T,k,A=i[b];if(c){for(w=Math.round((A-g)/(c*s)),k=o(g,c*w,f);k>A;)k=o(k,-c,f);for(;k<=A;)k=o(k,c,f);T=o(k,-c,f)}else{for(k=g+(w=Math.round((A-g)/u))*u;k>A;)k-=u;for(;k<=A;)k+=u;T=k-u}y[b]=p?T:d?k:(T+k)/2,v[b]=T,x[b]=k}return{vals:y,starts:v,ends:x}}},55126:function(t){\"use strict\";t.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},32919:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(34809),o=r(63821).FP_SAFE,s=r(33626),l=r(62203),c=r(5975),u=c.getFromId,h=c.isLinked;function f(t,e){var r,n,i=[],o=t._fullLayout,s=d(o,e,0),l=d(o,e,1),c=g(t,e),u=c.min,h=c.max;if(0===u.length||0===h.length)return a.simpleMap(e.range,e.r2l);var f=u[0].val,m=h[0].val;for(r=1;r<u.length&&f===m;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===m;r++)m=Math.max(m,h[r].val);var y=e.autorange,v=\"reversed\"===y||\"min reversed\"===y||\"max reversed\"===y;if(!v&&e.range){var x=a.simpleMap(e.range,e.r2l);v=x[1]<x[0]}\"reversed\"===e.autorange&&(e.autorange=!0);var _,b,w,T,A,M,S=e.rangemode,E=\"tozero\"===S,C=\"nonnegative\"===S,L=e._length,I=L/10,P=0;for(r=0;r<u.length;r++)for(_=u[r],n=0;n<h.length;n++)(M=(b=h[n]).val-_.val-p(e,_.val,b.val))>0&&((A=L-s(_)-l(b))>I?M/A>P&&(w=_,T=b,P=M/A):M/L>P&&(w={val:_.val,nopad:1},T={val:b.val,nopad:1},P=M/L));if(f===m){var z=f-1,O=f+1;if(E)if(0===f)i=[0,1];else{var D=(f>0?h:u).reduce((function(t,e){return Math.max(t,l(e))}),0),R=f/(1-Math.min(.5,D/L));i=f>0?[0,R]:[R,0]}else i=C?[Math.max(0,z),Math.max(1,O)]:[z,O]}else E?(w.val>=0&&(w={val:0,nopad:1}),T.val<=0&&(T={val:0,nopad:1})):C&&(w.val-P*s(w)<0&&(w={val:0,nopad:1}),T.val<=0&&(T={val:1,nopad:1})),P=(T.val-w.val-p(e,_.val,b.val))/(L-s(w)-l(T)),i=[w.val-P*s(w),T.val+P*l(T)];return i=k(i,e),e.limitRange&&e.limitRange(),v&&i.reverse(),a.simpleMap(i,e.l2r||Number)}function p(t,e,r){var n=0;if(t.rangebreaks)for(var i=t.locateBreaks(e,r),a=0;a<i.length;a++){var o=i[a];n+=o.max-o.min}return n}function d(t,e,r){var i=.05*e._length,o=e._anchorAxis||{};if(-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")||-1!==(o.ticklabelposition||\"\").indexOf(\"inside\")){var s=e.isReversed();if(!s){var c=a.simpleMap(e.range,e.r2l);s=c[1]<c[0]}s&&(r=!r)}var u=0;return h(t,e._id)||(u=function(t,e,r){var i=0,o=\"x\"===e._id.charAt(0);for(var s in t._plots){var c=t._plots[s];if(e._id===c.xaxis._id||e._id===c.yaxis._id){var u=(o?c.yaxis:c.xaxis)||{};if(-1!==(u.ticklabelposition||\"\").indexOf(\"inside\")&&(!r&&(\"left\"===u.side||\"bottom\"===u.side)||r&&(\"top\"===u.side||\"right\"===u.side))){if(u._vals){var h=a.deg2rad(u._tickAngles[u._id+\"tick\"]||0),f=Math.abs(Math.cos(h)),p=Math.abs(Math.sin(h));if(!u._vals[0].bb){var d=u._id+\"tick\";u._selections[d].each((function(t){var e=n.select(this);e.select(\".text-math-group\").empty()&&(t.bb=l.bBox(e.node()))}))}for(var g=0;g<u._vals.length;g++){var y=u._vals[g].bb;if(y){var v=2*m+y.width,x=2*m+y.height;i=Math.max(i,o?Math.max(v*f,x*p):Math.max(x*f,v*p))}}}\"inside\"===u.ticks&&\"inside\"===u.ticklabelposition&&(i+=u.ticklen||0)}}}return i}(t,e,r)),i=Math.max(u,i),\"domain\"===e.constrain&&e._inputDomain&&(i*=(e._inputDomain[1]-e._inputDomain[0])/(e.domain[1]-e.domain[0])),function(t){return t.nopad?0:t.pad+(t.extrapad?i:u)}}t.exports={applyAutorangeOptions:k,getAutoRange:f,makePadFn:d,doAutoRange:function(t,e,r){if(e.setScale(),e.autorange){e.range=r?r.slice():f(t,e),e._r=e.range.slice(),e._rl=a.simpleMap(e._r,e.r2l);var n=e._input,i={};i[e._attr+\".range\"]=e.range,i[e._attr+\".autorange\"]=e.autorange,s.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i),n.range=e.range.slice(),n.autorange=e.autorange}var o=e._anchorAxis;if(o&&o.rangeslider){var l=o.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=f(t,e)),o._input.rangeslider[e._name]=a.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={}),t._m||t.setScale();var n,a,s,l,c,u,h,f,p,d=[],m=[],g=e.length,x=r.padded||!1,b=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,T=!1,k=r.vpadLinearized||!1;function A(t){if(Array.isArray(t))return T=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var M=A((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=A((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=A(r.vpadplus||r.vpad),C=A(r.vpadminus||r.vpad);if(!T){if(f=1/0,p=-1/0,w)for(n=0;n<g;n++)(a=e[n])<f&&a>0&&(f=a),a>p&&a<o&&(p=a);else for(n=0;n<g;n++)(a=e[n])<f&&a>-o&&(f=a),a>p&&a<o&&(p=a);e=[f,p],g=2}var L={tozero:b,extrapad:x};function I(r){s=e[r],i(s)&&(u=M(r),h=S(r),k?(l=t.c2l(s)-C(r),c=t.c2l(s)+E(r)):(f=s-C(r),p=s+E(r),w&&f<p/10&&(f=p/10),l=t.c2l(f),c=t.c2l(p)),b&&(l=Math.min(0,l),c=Math.max(0,c)),_(l)&&y(d,l,h,L),_(c)&&v(m,c,u,L))}var P=Math.min(6,g);for(n=0;n<P;n++)I(n);for(n=g-1;n>=P;n--)I(n);return{min:d,max:m,opts:r}},concatExtremes:g};var m=3;function g(t,e,r){var n,i,a,o=e._id,s=t._fullData,l=t._fullLayout,c=[],h=[];function f(t,e){for(n=0;n<e.length;n++){var r=t[e[n]],s=(r._extremes||{})[o];if(!0===r.visible&&s){for(i=0;i<s.min.length;i++)a=s.min[i],y(c,a.val,a.pad,{extrapad:a.extrapad});for(i=0;i<s.max.length;i++)a=s.max[i],v(h,a.val,a.pad,{extrapad:a.extrapad})}}}if(f(s,e._traceIndices),f(l.annotations||[],e._annIndices||[]),f(l.shapes||[],e._shapeIndices||[]),e._matchGroup&&!r)for(var p in e._matchGroup)if(p!==e._id){var d=u(t,p),m=g(t,d,!0),x=e._length/d._length;for(i=0;i<m.min.length;i++)a=m.min[i],y(c,a.val,a.pad*x,{extrapad:a.extrapad});for(i=0;i<m.max.length;i++)a=m.max[i],v(h,a.val,a.pad*x,{extrapad:a.extrapad})}return{min:c,max:h}}function y(t,e,r,n){x(t,e,r,n,b)}function v(t,e,r,n){x(t,e,r,n,w)}function x(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function _(t){return i(t)&&Math.abs(t)<o}function b(t,e){return t<=e}function w(t,e){return t>=e}function T(t,e,r){return void 0===e||void 0===r||(e=t.d2l(e))<t.d2l(r)}function k(t,e){if(!e||!e.autorangeoptions)return t;var r=t[0],n=t[1],i=e.autorangeoptions.include;if(void 0!==i){var o=e.d2l(r),s=e.d2l(n);a.isArrayOrTypedArray(i)||(i=[i]);for(var l=0;l<i.length;l++){var c=e.d2l(i[l]);o>=c&&(o=c,r=c),s<=c&&(s=c,n=c)}}return r=function(t,e){var r=e.autorangeoptions;return r&&void 0!==r.minallowed&&T(e,r.minallowed,r.maxallowed)?r.minallowed:r&&void 0!==r.clipmin&&T(e,r.clipmin,r.clipmax)?Math.max(t,e.d2l(r.clipmin)):t}(r,e),n=function(t,e){var r=e.autorangeoptions;return r&&void 0!==r.maxallowed&&T(e,r.minallowed,r.maxallowed)?r.maxallowed:r&&void 0!==r.clipmax&&T(e,r.clipmin,r.clipmax)?Math.min(t,e.d2l(r.clipmax)):t}(n,e),[r,n]}},75511:function(t){\"use strict\";t.exports=function(t,e,r){var n,i;if(r){var a=\"reversed\"===e||\"min reversed\"===e||\"max reversed\"===e;n=r[a?1:0],i=r[a?0:1]}var o=t(\"autorangeoptions.minallowed\",null===i?n:void 0),s=t(\"autorangeoptions.maxallowed\",null===n?i:void 0);void 0===o&&t(\"autorangeoptions.clipmin\"),void 0===s&&t(\"autorangeoptions.clipmax\"),t(\"autorangeoptions.include\")}},29714:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(44122),o=r(33626),s=r(34809),l=s.strTranslate,c=r(30635),u=r(17240),h=r(78766),f=r(62203),p=r(25829),d=r(68599),m=r(63821),g=m.ONEMAXYEAR,y=m.ONEAVGYEAR,v=m.ONEMINYEAR,x=m.ONEMAXQUARTER,_=m.ONEAVGQUARTER,b=m.ONEMINQUARTER,w=m.ONEMAXMONTH,T=m.ONEAVGMONTH,k=m.ONEMINMONTH,A=m.ONEWEEK,M=m.ONEDAY,S=M/2,E=m.ONEHOUR,C=m.ONEMIN,L=m.ONESEC,I=m.ONEMILLI,P=m.ONEMICROSEC,z=m.MINUS_SIGN,O=m.BADNUM,D={K:\"zeroline\"},R={K:\"gridline\",L:\"path\"},F={K:\"minor-gridline\",L:\"path\"},B={K:\"tick\",L:\"path\"},N={K:\"tick\",L:\"text\"},j={width:[\"x\",\"r\",\"l\",\"xl\",\"xr\"],height:[\"y\",\"t\",\"b\",\"yt\",\"yb\"],right:[\"r\",\"xr\"],left:[\"l\",\"xl\"],top:[\"t\",\"yt\"],bottom:[\"b\",\"yb\"]},U=r(4530),V=U.MID_SHIFT,q=U.CAP_SHIFT,H=U.LINE_SPACING,G=U.OPPOSITE_SIDE,Z=t.exports={};Z.setConvert=r(19091);var W=r(9666),Y=r(5975),X=Y.idSort,$=Y.isLinked;Z.id2name=Y.id2name,Z.name2id=Y.name2id,Z.cleanId=Y.cleanId,Z.list=Y.list,Z.listIds=Y.listIds,Z.getFromId=Y.getFromId,Z.getFromTrace=Y.getFromTrace;var J=r(32919);Z.getAutoRange=J.getAutoRange,Z.findExtremes=J.findExtremes;var K=1e-4;function Q(t){var e=(t[1]-t[0])*K;return[t[0]-e,t[1]+e]}Z.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||(\"string\"==typeof a?a:a[0])),a||(a=i),l=l.concat(l.map((function(t){return t+\" domain\"}))),u[c]={valType:\"enumerated\",values:l.concat(a?\"string\"==typeof a?[a]:a:[]),dflt:i},s.coerce(t,e,u,c)},Z.getRefType=function(t){return void 0===t?t:\"paper\"===t?\"paper\":\"pixel\"===t?\"pixel\":/( domain)$/.test(t)?\"domain\":\"range\"},Z.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"range\"!==Z.getRefType(n))o=s.ensureNumber,l=r(i,a);else{var c=Z.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},Z.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:Z.getFromId(e,r).cleanPos)(t)},Z.redrawComponents=function(t,e){e=e||Z.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[Z.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0),n(\"selections\",\"drawOne\",\"_selectionIndices\")};var tt=Z.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(s.isArrayOrTypedArray(a)){if(i={type:W(n,void 0,{autotypenumbers:t._fullLayout.autotypenumbers}),_categories:[]},Z.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=Z.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:rt,c2d:rt}:{d2c:et,c2d:et}};function et(t){return+t}function rt(t){return String(t)}function nt(t,e){return Math.abs((t/e+.5)%1-.5)<.001}function it(t,e){return Math.abs(t/e-1)<.001}function at(t){return+t.substring(1)}function ot(t,e){return t.rangebreaks&&(e=e.filter((function(e){return t.maskBreaks(e.x)!==O}))),e}function st(t){var e=t._mainAxis,r=[];if(e._vals)for(var n=0;n<e._vals.length;n++)if(!e._vals[n].noTick){var i=e.l2p(e._vals[n].x),a=t.p2l(i),o=Z.tickText(t,a);e._vals[n].minor&&(o.minor=!0,o.text=\"\"),r.push(o)}return ot(t,r)}function lt(t,e){var r=Q(s.simpleMap(t.range,t.r2l)),n=Math.min(r[0],r[1]),i=Math.max(r[0],r[1]),a=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var o=[],l=0;l<=1;l++)if((void 0===e||!(e&&l||!1===e&&!l))&&(!l||t.minor)){var c=l?t.minor.tickvals:t.tickvals,u=l?[]:t.ticktext;if(c){s.isArrayOrTypedArray(u)||(u=[]);for(var h=0;h<c.length;h++){var f=a(c[h]);if(f>n&&f<i){var p=Z.tickText(t,f,!1,String(u[h]));l&&(p.minor=!0,p.text=\"\"),o.push(p)}}}}return ot(t,o)}Z.getDataToCoordFunc=function(t,e,r,n){return tt(t,e,r,n).d2c},Z.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},Z.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},Z.saveRangeInitial=function(t,e){for(var r=Z.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial0&&void 0===a._rangeInitial1,s=o||a.range[0]!==a._rangeInitial0||a.range[1]!==a._rangeInitial1,l=a.autorange;(o&&!0!==l||e&&s)&&(a._rangeInitial0=\"min\"===l||\"max reversed\"===l?void 0:a.range[0],a._rangeInitial1=\"max\"===l||\"min reversed\"===l?void 0:a.range[1],a._autorangeInitial=l,n=!0)}return n},Z.saveShowSpikeInitial=function(t,e){for(var r=Z.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},Z.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},Z.setConvert(l),o=o&&d.dtick(o,l.type))l.dtick=o,l.tick0=d.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),p=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),m=p*s.roundUp(f.minDiff/p,[.9,1.9,4.9,9.9],!0);h=Math.max(m,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}Z.autoTicks(l,h)}var g,y=l.dtick,v=Z.tickIncrement(Z.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(v,t,l,c,u),g=v+(1+Math.floor((u-v)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(v=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=Z.tickIncrement(t,\"M6\",\"reverse\")+1.5*M:a.exactMonths>.8?t=Z.tickIncrement(t,\"M1\",\"reverse\")+15.5*M:t-=S;var l=Z.tickIncrement(t,r);if(l<=n)return l}return t}(v,t,y,c,a)),g=v;g<=u;)g=Z.tickIncrement(g,y,!1,a);return{start:e.c2r(v,0,a),end:e.c2r(g,0,a),size:y,_dataSpan:u-c}},Z.prepMinorTicks=function(t,e,r){if(!e.minor.dtick){delete t.dtick;var n,a=e.dtick&&i(e._tmin);if(a){var o=Z.tickIncrement(e._tmin,e.dtick,!0);n=[e._tmin,.99*o+.01*e._tmin]}else{var l=s.simpleMap(e.range,e.r2l);n=[l[0],.8*l[0]+.2*l[1]]}if(t.range=s.simpleMap(n,e.l2r),t._isMinor=!0,Z.prepTicks(t,r),a){var c=i(e.dtick),u=i(t.dtick),h=c?e.dtick:+e.dtick.substring(1),f=u?t.dtick:+t.dtick.substring(1);c&&u?nt(h,f)?h===2*A&&f===2*M&&(t.dtick=A):h===2*A&&f===3*M?t.dtick=A:h!==A||(e._input.minor||{}).nticks?it(h/f,2.5)?t.dtick=h/2:t.dtick=h:t.dtick=M:\"M\"===String(e.dtick).charAt(0)?u?t.dtick=\"M1\":nt(h,f)?h>=12&&2===f&&(t.dtick=\"M3\"):t.dtick=e.dtick:\"L\"===String(t.dtick).charAt(0)?\"L\"===String(e.dtick).charAt(0)?nt(h,f)||(t.dtick=it(h/f,2.5)?e.dtick/2:e.dtick):t.dtick=\"D1\":\"D2\"===t.dtick&&+e.dtick>1&&(t.dtick=1)}t.range=e.range}void 0===e.minor._tick0Init&&(t.tick0=e.tick0)},Z.prepTicks=function(t,e){var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"auto\"===t.tickmode||!t.dtick){var n,a=t.nticks;a||(\"category\"===t.type||\"multicategory\"===t.type?(n=t.tickfont?s.bigFont(t.tickfont.size||12):15,a=t._length/n):(n=\"y\"===t._id.charAt(0)?40:80,a=s.constrain(t._length/n,4,9)+1),\"radialaxis\"===t._name&&(a*=2)),t.minor&&\"array\"!==t.minor.tickmode||\"array\"===t.tickmode&&(a*=100),t._roughDTick=Math.abs(r[1]-r[0])/a,Z.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}\"period\"===t.ticklabelmode&&function(t){var e;function r(){return!(i(t.dtick)||\"M\"!==t.dtick.charAt(0))}var n=r(),a=Z.getTickFormat(t);if(a){var o=t._dtickInit!==t.dtick;/%[fLQsSMX]/.test(a)||(/%[HI]/.test(a)?(e=E,o&&!n&&t.dtick<E&&(t.dtick=E)):/%p/.test(a)?(e=S,o&&!n&&t.dtick<S&&(t.dtick=S)):/%[Aadejuwx]/.test(a)?(e=M,o&&!n&&t.dtick<M&&(t.dtick=M)):/%[UVW]/.test(a)?(e=A,o&&!n&&t.dtick<A&&(t.dtick=A)):/%[Bbm]/.test(a)?(e=T,o&&(n?at(t.dtick)<1:t.dtick<k)&&(t.dtick=\"M1\")):/%[q]/.test(a)?(e=_,o&&(n?at(t.dtick)<3:t.dtick<b)&&(t.dtick=\"M3\")):/%[Yy]/.test(a)&&(e=y,o&&(n?at(t.dtick)<12:t.dtick<v)&&(t.dtick=\"M12\")))}(n=r())&&t.tick0===t._dowTick0&&(t.tick0=t._rawTick0),t._definedDelta=e}(t),t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),yt(t)},Z.calcTicks=function(t,e){for(var r,n,a,o,l=t.type,c=t.calendar,u=t.ticklabelstep,h=\"period\"===t.ticklabelmode,f=t.range[0]>t.range[1],p=!t.ticklabelindex||s.isArrayOrTypedArray(t.ticklabelindex)?t.ticklabelindex:[t.ticklabelindex],d=s.simpleMap(t.range,t.r2l,void 0,void 0,e),m=d[1]<d[0],z=Math.min(d[0],d[1]),D=Math.max(d[0],d[1]),R=Math.max(1e3,t._length||0),F=[],B=[],N=[],j=[],U=[],V=t.minor&&(t.minor.ticks||t.minor.showgrid),q=1;q>=(V?0:1);q--){var H=!q;q?(t._dtickInit=t.dtick,t._tick0Init=t.tick0):(t.minor._dtickInit=t.minor.dtick,t.minor._tick0Init=t.minor.tick0);var G=q?t:s.extendFlat({},t,t.minor);if(H?Z.prepMinorTicks(G,t,e):Z.prepTicks(G,e),\"array\"!==G.tickmode)if(\"sync\"!==G.tickmode){var W=Q(d),Y=W[0],X=W[1],$=i(G.dtick),J=\"log\"===l&&!($||\"L\"===G.dtick.charAt(0)),K=Z.tickFirst(G,e);if(q){if(t._tmin=K,K<Y!==m)break;\"category\"!==l&&\"multicategory\"!==l||(X=m?Math.max(-.5,X):Math.min(t._categories.length-.5,X))}var tt,et,rt=null,nt=K;q&&($?et=t.dtick:\"date\"===l?\"string\"==typeof t.dtick&&\"M\"===t.dtick.charAt(0)&&(et=T*t.dtick.substring(1)):et=t._roughDTick,tt=Math.round((t.r2l(nt)-t.r2l(t.tick0))/et)-1);var it=G.dtick;for(G.rangebreaks&&G._tick0Init!==G.tick0&&(nt=Ft(nt,t),m||(nt=Z.tickIncrement(nt,it,!m,c))),q&&h&&(nt=Z.tickIncrement(nt,it,!m,c),tt--);m?nt>=X:nt<=X;nt=Z.tickIncrement(nt,it,m,c)){if(q&&tt++,G.rangebreaks&&!m){if(nt<Y)continue;if(G.maskBreaks(nt)===O&&Ft(nt,G)>=D)break}if(N.length>R||nt===rt)break;rt=nt;var at={value:nt};q?(J&&nt!==(0|nt)&&(at.simpleLabel=!0),u>1&&tt%u&&(at.skipLabel=!0),N.push(at)):(at.minor=!0,j.push(at))}}else N=[],F=st(t);else q?(N=[],F=lt(t,!H)):(j=[],B=lt(t,!H))}!j||j.length<2?p=!1:(r=(j[1].value-j[0].value)*(f?-1:1),n=t.tickformat,(/%f/.test(n)?r>=P:/%L/.test(n)?r>=I:/%[SX]/.test(n)?r>=L:/%M/.test(n)?r>=C:/%[HI]/.test(n)?r>=E:/%p/.test(n)?r>=S:/%[Aadejuwx]/.test(n)?r>=M:/%[UVW]/.test(n)?r>=A:/%[Bbm]/.test(n)?r>=k:/%[q]/.test(n)?r>=b:!/%[Yy]/.test(n)||r>=v)||(p=!1));if(p){var ot=N.concat(j);h&&N.length&&(ot=ot.slice(1)),(ot=ot.sort((function(t,e){return t.value-e.value})).filter((function(t,e,r){return 0===e||t.value!==r[e-1].value}))).map((function(t,e){return void 0!==t.minor||t.skipLabel?null:e})).filter((function(t){return null!==t})).forEach((function(t){p.map((function(e){var r=t+e;r>=0&&r<ot.length&&s.pushUnique(U,ot[r])}))}))}else U=N;if(V&&!(\"inside\"===t.minor.ticks&&\"outside\"===t.ticks||\"outside\"===t.minor.ticks&&\"inside\"===t.ticks)){for(var ct=N.map((function(t){return t.value})),ut=[],ht=0;ht<j.length;ht++){var ft=j[ht],pt=ft.value;if(-1===ct.indexOf(pt)){for(var dt=!1,mt=0;!dt&&mt<N.length;mt++)1e7+N[mt].value===1e7+pt&&(dt=!0);dt||ut.push(ft)}}j=ut}if(h&&function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n].value,a=n,o=n+1;n<t.length-1?(a=n,o=n+1):n>0?(a=n-1,o=n):(a=n,o=n);var s,l=t[a].value,c=t[o].value,u=Math.abs(c-l),h=r||u,f=0;h>=v?f=u>=v&&u<=g?u:y:r===_&&h>=b?f=u>=b&&u<=x?u:_:h>=k?f=u>=k&&u<=w?u:T:r===A&&h>=A?f=A:h>=M?f=M:r===S&&h>=S?f=S:r===E&&h>=E&&(f=E),f>=u&&(f=u,s=!0);var p=i+f;if(e.rangebreaks&&f>0){for(var d=0,m=0;m<84;m++){var C=(m+.5)/84;e.maskBreaks(i*(1-C)+C*p)!==O&&d++}(f*=d/84)||(t[n].drop=!0),s&&u>A&&(f=u)}(f>0||0===n)&&(t[n].periodX=i+f/2)}}(U,t,t._definedDelta),t.rangebreaks){var gt=\"y\"===t._id.charAt(0),yt=1;\"auto\"===t.tickmode&&(yt=t.tickfont?t.tickfont.size:12);var vt=NaN;for(a=N.length-1;a>-1;a--)if(N[a].drop)N.splice(a,1);else{N[a].value=Ft(N[a].value,t);var xt=t.c2p(N[a].value);(gt?vt>xt-yt:vt<xt+yt)?N.splice(m?a+1:a,1):vt=xt}}Rt(t)&&360===Math.abs(d[1]-d[0])&&N.pop(),t._tmax=(N[N.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;var _t,bt=function(e){e.text=\"\",t._prevDateHead=o};function wt(t,e){var r=Z.tickText(t,e.value,!1,e.simpleLabel),n=e.periodX;return void 0!==n&&(r.periodX=n,(n>D||n<z)&&(n>D&&(r.periodX=D),n<z&&(r.periodX=z),bt(r))),r}for(N=N.concat(j),a=0;a<N.length;a++){var Tt=N[a].minor,kt=N[a].value;Tt?((_t=p&&-1!==U.indexOf(N[a])?wt(t,N[a]):{x:kt}).minor=!0,B.push(_t)):(o=t._prevDateHead,_t=wt(t,N[a]),(N[a].skipLabel||p&&-1===U.indexOf(N[a]))&&bt(_t),F.push(_t))}return F=F.concat(B),t._inCalcTicks=!1,h&&F.length&&(F[0].noTick=!0),F};var ct=[2,5,10],ut=[1,2,3,6,12],ht=[1,2,5,10,15,30],ft=[1,2,3,7,14],pt=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],dt=[-.301,0,.301,.699,1],mt=[15,30,45,90,180];function gt(t,e,r){return e*s.roundUp(t/e,r)}function yt(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=M&&a<=10||e>=15*M)t._tickround=\"d\";else if(e>=C&&a<=16||e>=E)t._tickround=\"M\";else if(e>=L&&a<=19||e>=C)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01),u=void 0===t.minexponent?3:t.minexponent;Math.abs(c)>u&&(_t(t.exponentformat)&&!bt(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function vt(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontWeight:n.weight,fontStyle:n.style,fontVariant:n.variant,fontTextcase:n.textcase,fontLineposition:n.lineposition,fontShadow:n.shadow,fontColor:n.color}}Z.autoTicks=function(t,e,r){var n;function a(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar,0);var o=2*e;if(o>y)e/=y,n=a(10),t.dtick=\"M\"+12*gt(e,n,ct);else if(o>T)e/=T,t.dtick=\"M\"+gt(e,1,ut);else if(o>M){if(t.dtick=gt(e,M,t._hasDayOfWeekBreaks?[1,2,7,14]:ft),!r){var l=Z.getTickFormat(t),c=\"period\"===t.ticklabelmode;c&&(t._rawTick0=t.tick0),/%[uVW]/.test(l)?t.tick0=s.dateTick0(t.calendar,2):t.tick0=s.dateTick0(t.calendar,1),c&&(t._dowTick0=t.tick0)}}else o>E?t.dtick=gt(e,E,ut):o>C?t.dtick=gt(e,C,ht):o>L?t.dtick=gt(e,L,ht):(n=a(10),t.dtick=gt(e,n,ct))}else if(\"log\"===t.type){t.tick0=0;var u=s.simpleMap(t.range,t.r2l);if(t._isMinor&&(e*=1.5),e>.7)t.dtick=Math.ceil(e);else if(Math.abs(u[1]-u[0])<1){var h=1.5*Math.abs((u[1]-u[0])/e);e=Math.abs(Math.pow(10,u[1])-Math.pow(10,u[0]))/h,n=a(10),t.dtick=\"L\"+gt(e,n,ct)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):Rt(t)?(t.tick0=0,n=1,t.dtick=gt(e,n,mt)):(t.tick0=0,n=a(10),t.dtick=gt(e,n,ct));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var f=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(f)}},Z.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return s.increment(t,o*e);var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?dt:pt,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},Z.tickFirst=function(t,e){var r=t.r2l||Number,a=s.simpleMap(t.range,r,void 0,void 0,e),o=a[1]<a[0],l=o?Math.floor:Math.ceil,c=Q(a)[0],u=t.dtick,h=r(t.tick0);if(i(u)){var f=l((c-h)/u)*u+h;return\"category\"!==t.type&&\"multicategory\"!==t.type||(f=s.constrain(f,0,t._categories.length-1)),f}var p=u.charAt(0),d=Number(u.substr(1));if(\"M\"===p){for(var m,g,y,v=0,x=h;v<10;){if(((m=Z.tickIncrement(x,u,o,t.calendar))-c)*(x-c)<=0)return o?Math.min(x,m):Math.max(x,m);g=(c-(x+m)/2)/(m-x),y=p+(Math.abs(Math.round(g))||1)*d,x=Z.tickIncrement(x,y,g<0?!o:o,t.calendar),v++}return s.error(\"tickFirst did not converge\",t),x}if(\"L\"===p)return Math.log(l((Math.pow(10,c)-h)/d)*d+h)/Math.LN10;if(\"D\"===p){var _=\"D2\"===u?dt:pt,b=s.roundUp(s.mod(c,1),_,o);return Math.floor(c)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(u)},Z.tickText=function(t,e,r,n){var a,o=vt(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l,f=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};if(l&&s.isArrayOrTypedArray(t.ticktext)){var p=s.simpleMap(t.range,t.r2l),d=(Math.abs(p[1]-p[0])-(t._lBreaks||0))/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<d);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o.xbnd=[f(o.x-.5),f(o.x+t.dtick-.5)],o}function m(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&m(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||Z.getTickFormat(t);(n=!o&&n)&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");if(-1!==u&&(l=c.substr(u+1),c=c.substr(0,u)),n&&(void 0===l||\"00:00:00\"!==c&&\"00:00\"!==c?8===c.length&&(c=c.replace(/:00$/,\"\")):(c=l,l=\"\")),l)if(r)\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\");else if(t._inCalcTicks&&t._prevDateHead===l){var h=Bt(t),f=t._trueSide||t.side;(!h&&\"top\"===f||h&&\"bottom\"===f)&&(c+=\"<br> \")}else t._prevDateHead=l,c+=\"<br>\"+l;e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);if(\"never\"===a&&(a=\"\"),n&&\"L\"!==u&&(o=\"L3\",u=\"L\"),c||\"L\"===u)e.text=wt(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||_t(p)&&bt(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":z)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":z)+f:(e.text=wt(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\"),e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):Rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=wt(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){for(var r=1;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=wt(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\u03c0\":e.text=o[0]+\"\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\u2044\",\"<sub>\",o[1],\"</sub>\",\"\u03c0\"].join(\"\"),l&&(e.text=z+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\"),e.text=wt(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!m(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!m(t.showticksuffix)&&(o.text+=t.ticksuffix)),t.labelalias&&t.labelalias.hasOwnProperty(o.text)){var y=t.labelalias[o.text];\"string\"==typeof y&&(o.text=y)}return(\"boundaries\"===t.tickson||t.showdividers)&&(o.xbnd=[f(o.x-.5),f(o.x+t.dtick-.5)]),o},Z.hoverLabelText=function(t,e,r){r&&(t=s.extendFlat({},t,{hoverformat:r}));var n=s.isArrayOrTypedArray(e)?e[0]:e,i=s.isArrayOrTypedArray(e)?e[1]:void 0;if(void 0!==i&&i!==n)return Z.hoverLabelText(t,n,r)+\" - \"+Z.hoverLabelText(t,i,r);var a=\"log\"===t.type&&n<=0,o=Z.tickText(t,t.c2l(a?-n:n),\"hover\").text;return a?0===n?\"0\":z+o:o};var xt=[\"f\",\"p\",\"n\",\"\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function _t(t){return\"SI\"===t||\"B\"===t}function bt(t){return t>14||t<-15}function wt(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=Z.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,minexponent:e.minexponent,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};yt(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,z);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var m=o;m<0;m++)t+=\"0\"}else{var g=(t=String(t)).indexOf(\".\")+1;g&&(t=t.substr(0,g+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}return c&&\"hide\"!==l&&(_t(l)&&bt(c)&&(l=\"power\"),p=c<0?z+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\u00d710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":_t(l)&&(t+=xt[c/3+5])),a?z+t:t}function Tt(t,e){if(t){var r=Object.keys(j).reduce((function(t,r){return-1!==e.indexOf(r)&&j[r].forEach((function(e){t[e]=1})),t}),{});Object.keys(t).forEach((function(e){r[e]||(1===e.length?t[e]=0:delete t[e])}))}}function kt(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(vt(t,s.interp(n[o],.5),o));return r}function At(t){return void 0!==t.periodX?t.periodX:t.x}function Mt(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function St(t){var e=t.title.font.size,r=(t.title.text.match(c.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty(\"standoff\")?e*(q+r*H):r?e*(r+1)*H:e}function Et(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function Ct(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function Lt(t){return t._id+\".automargin\"}function It(t){return Lt(t)+\".mirror\"}function Pt(t){return t._id+\".rangeslider\"}function zt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function Ot(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(Z.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(Z.getFromId(t,r[n]));var c=Object.keys(p),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var f=c[n],d=a[0][f],m=o[0][f],g=!0,y=!1,v=!1;if(\"_\"!==f.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(f)){for(i=1;i<a.length&&g;i++){var x=a[i][f];\"type\"===f&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?y=!0:x!==d&&(g=!1)}for(i=1;i<o.length&&g;i++){var _=o[i][f];\"type\"===f&&-1!==h.indexOf(m)&&-1!==h.indexOf(_)&&m!==_?v=!0:o[i][f]!==m&&(g=!1)}g&&(y&&(l[a[0]._name].type=\"linear\"),v&&(l[o[0]._name].type=\"linear\"),Dt(l,f,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var b=t._fullLayout.annotations[n];-1!==e.indexOf(b.xref)&&-1!==r.indexOf(b.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function Dt(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function Rt(t){return\"angularaxis\"===t._id}function Ft(t,e){for(var r=e._rangebreaks.length,n=0;n<r;n++){var i=e._rangebreaks[n];if(t>=i.min&&t<i.max)return i.max}return t}function Bt(t){return-1!==(t.ticklabelposition||\"\").indexOf(\"inside\")}function Nt(t,e){Bt(t._anchorAxis||{})&&t._hideCounterAxisInsideTickLabels&&t._hideCounterAxisInsideTickLabels(e)}function jt(t,e,r,n){var i,a=\"free\"===t.anchor||void 0!==t.overlaying&&!1!==t.overlaying?t.overlaying:t._id;i=n?\"right\"===t.side?e:-e:e,a in r||(r[a]={}),t.side in r[a]||(r[a][t.side]=0),r[a][t.side]+=i}Z.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*T}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},Z.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?Z.findSubplotsWithAxis(n,e):n;return i.sort((function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]})),i},Z.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},Z.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=Z.list(t,\"x\",!0),l=Z.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,(function(t){return t.x._id+t.y._id}));u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",(function(t){return\"clip\"+e._uid+t.x._id+t.y._id})).append(\"rect\"),u.exit().remove(),u.each((function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})}))}},Z.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each((function(t){var e=t[0],r=n._plots[e];if(r){var i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.minorGridlayer&&r.minorGridlayer.selectAll(\"path\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()}}));var i=e&&\"redraw\"!==e?e:Z.listIds(t),a=Z.list(t).filter((function(t){return t.autoshift})).map((function(t){return t.overlaying}));i.map((function(e){var r=Z.getFromId(t,e);if(\"sync\"===r.tickmode&&r.overlaying){var n=i.findIndex((function(t){return t===r.overlaying}));n>=0&&i.unshift(i.splice(n,1).shift())}}));var o={false:{left:0,right:0}};return s.syncOrAsync(i.map((function(e){return function(){if(e){var n=Z.getFromId(t,e);r||(r={}),r.axShifts=o,r.overlayingShiftedAx=a;var i=Z.drawOne(t,n,r);return n._shiftPusher&&jt(n,n._fullDepth||0,o,!0),n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}})))},Z.drawOne=function(t,e,r){var n,i,l,p=(r=r||{}).axShifts||{},d=r.overlayingShiftedAx||[];e.setScale();var m=t._fullLayout,g=e._id,y=g.charAt(0),v=Z.counterLetter(g),x=m._plots[e._mainSubplot];if(x){if(e._shiftPusher=e.autoshift||-1!==d.indexOf(e._id)||-1!==d.indexOf(e.overlaying),e._shiftPusher&\"free\"===e.anchor){var _=e.linewidth/2||0;\"inside\"===e.ticks&&(_+=e.ticklen),jt(e,_,p,!0),jt(e,e.shift||0,p,!1)}!0===r.skipTitle&&void 0!==e._shift||(e._shift=function(t,e){return t.autoshift?e[t.overlaying][t.side]:t.shift||0}(e,p));var b=x[y+\"axislayer\"],w=e._mainLinePosition,T=w+=e._shift,k=e._mainMirrorPosition,A=e._vals=Z.calcTicks(e),M=[e.mirror,T,k].join(\"_\");for(n=0;n<A.length;n++)A[n].axInfo=M;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var S={};if(e.visible){var E,C,L=Z.makeTransTickFn(e),I=Z.makeTransTickLabelFn(e),P=\"inside\"===e.ticks,z=\"outside\"===e.ticks;if(\"boundaries\"===e.tickson){var O=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,A);C=Z.clipEnds(e,O),E=P?C:O}else C=Z.clipEnds(e,A),E=P&&\"period\"!==e.ticklabelmode?C:A;var D,R=e._gridVals=C,F=function(t,e){var r,n,i=[],a=e.length&&e[e.length-1].x<e[0].x,o=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var l=e[r];l.text2!==n&&o(l,a?1:0),n=l.text2}o(e[r-1],a?0:1)}return i}(e,A);if(!m._hasOnlyLargeSploms){var B=e._subplotsWith,N={};for(n=0;n<B.length;n++){i=B[n];var j=(l=m._plots[i])[v+\"axis\"],U=j._mainAxis._id;if(!N[U]){N[U]=1;var W=\"x\"===y?\"M0,\"+j._offset+\"v\"+j._length:\"M\"+j._offset+\",0h\"+j._length;Z.drawGrid(t,e,{vals:R,counterAxis:j,layer:l.gridlayer.select(\".\"+g),minorLayer:l.minorGridlayer.select(\".\"+g),path:W,transFn:L}),Z.drawZeroLine(t,e,{counterAxis:j,layer:l.zerolinelayer,path:W,transFn:L})}}}var Y=Z.getTickSigns(e),X=Z.getTickSigns(e,\"minor\");if(e.ticks||e.minor&&e.minor.ticks){var $,J,K,Q,tt=Z.makeTickPath(e,T,Y[2]),et=Z.makeTickPath(e,T,X[2],{minor:!0});if(e._anchorAxis&&e.mirror&&!0!==e.mirror?($=Z.makeTickPath(e,k,Y[3]),J=Z.makeTickPath(e,k,X[3],{minor:!0}),K=tt+$,Q=et+J):($=\"\",J=\"\",K=tt,Q=et),e.showdividers&&z&&\"boundaries\"===e.tickson){var rt={};for(n=0;n<F.length;n++)rt[F[n].x]=1;D=function(t){return rt[t.x]?$:K}}else D=function(t){return t.minor?Q:K}}if(Z.drawTicks(t,e,{vals:E,layer:b,path:D,transFn:L}),\"allticks\"===e.mirror){var nt=Object.keys(e._linepositions||{});for(n=0;n<nt.length;n++){i=nt[n],l=m._plots[i];var it=e._linepositions[i]||[],at=it[0],ot=it[1],st=it[2],lt=Z.makeTickPath(e,at,st?Y[0]:X[0],{minor:st})+Z.makeTickPath(e,ot,st?Y[1]:X[1],{minor:st});Z.drawTicks(t,e,{vals:E,layer:l[y+\"axislayer\"],path:lt,transFn:L})}}var ct=[];if(ct.push((function(){return Z.drawLabels(t,e,{vals:A,layer:b,plotinfo:l,transFn:I,labelFns:Z.makeLabelFns(e,T)})})),\"multicategory\"===e.type){var ut={x:2,y:10}[y];ct.push((function(){var r={x:\"height\",y:\"width\"}[y],n=ft()[r]+ut+(e._tickAngles[g+\"tick\"]?e.tickfont.size*H:0);return Z.drawLabels(t,e,{vals:kt(e,A),layer:b,cls:g+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:L,labelFns:Z.makeLabelFns(e,T+n*Y[4])})})),ct.push((function(){return e._depth=Y[4]*(ft(\"tick2\")[e.side]-T),function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,Mt);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(h.stroke,e.dividercolor).style(\"stroke-width\",f.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:F,layer:b,path:Z.makeTickPath(e,T,Y[4],{len:e._depth}),transFn:L})}))}else e.title.hasOwnProperty(\"standoff\")&&ct.push((function(){e._depth=Y[4]*(ft()[e.side]-T)}));var ht=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return r.skipTitle||ht&&\"bottom\"===e.side||ct.push((function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size,s=(e.title.text.match(c.BR_TAG_ALL)||[]).length;if(e.title.hasOwnProperty(\"standoff\"))\"bottom\"===e.side||\"right\"===e.side?r=e._depth+e.title.standoff+o*q:\"top\"!==e.side&&\"left\"!==e.side||(r=e._depth+e.title.standoff+o*(V+s*H));else{var l=Bt(e);if(\"multicategory\"===e.type)r=e._depth;else{var h=1.5*o;l&&(h=.5*o,\"outside\"===e.ticks&&(h+=e.ticklen)),r=10+h+(e.linewidth?e.linewidth-1:0)}l||(r+=\"x\"===a?\"top\"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):\"right\"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0))}var p,d,m,g,y=Z.getPxPosition(t,e);if(\"x\"===a?(d=e._offset+e._length/2,m=\"top\"===e.side?y-r:y+r):(m=e._offset+e._length/2,d=\"right\"===e.side?y+r:y-r,p={rotate:\"-90\",offset:0}),\"multicategory\"!==e.type){var v=e._selections[e._id+\"tick\"];if(g={selection:v,side:e.side},v&&v.node()&&v.node().parentNode){var x=f.getTranslate(v.node().parentNode);g.offsetLeft=x.x,g.offsetTop=x.y}e.title.hasOwnProperty(\"standoff\")&&(g.pad=0)}return e._titleStandoff=r,u.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:g,transform:p,attributes:{x:d,y:m,\"text-anchor\":\"middle\"}})}(t,e)})),ct.push((function(){var r,n,i,s,l=e.side.charAt(0),c=G[e.side].charAt(0),u=Z.getPxPosition(t,e),h=z?e.ticklen:0;(e.automargin||ht||e._shiftPusher)&&(\"multicategory\"===e.type?r=ft(\"tick2\"):(r=ft(),\"x\"===y&&\"b\"===l&&(e._depth=Math.max(r.width>0?r.bottom-u:0,h))));var f=0,p=0;if(e._shiftPusher&&(f=Math.max(h,r.height>0?\"l\"===l?u-r.left:r.right-u:0),e.title.text!==m._dfltTitle[y]&&(p=(e._titleStandoff||0)+(e._titleScoot||0),\"l\"===l&&(p+=St(e))),e._fullDepth=Math.max(f,p)),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var d=[0,1],g=\"number\"==typeof e._shift?e._shift:0;if(\"x\"===y){if(\"b\"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?u-r.top:0,h),d.reverse()),r.width>0){var x=r.right-(e._offset+e._length);x>0&&(n.xr=1,n.r=x);var _=e._offset-r.left;_>0&&(n.xl=0,n.l=_)}}else if(\"l\"===l?(e._depth=Math.max(r.height>0?u-r.left:0,h),n[l]=e._depth-g):(e._depth=Math.max(r.height>0?r.right-u:0,h),n[l]=e._depth+g,d.reverse()),r.height>0){var b=r.bottom-(e._offset+e._length);b>0&&(n.yb=0,n.b=b);var w=e._offset-r.top;w>0&&(n.yt=1,n.t=w)}n[v]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[d[0]],e.title.text!==m._dfltTitle[y]&&(n[l]+=St(e)+(e.title.standoff||0)),e.mirror&&\"free\"!==e.anchor&&((i={x:0,y:0,r:0,l:0,t:0,b:0})[c]=e.linewidth,e.mirror&&!0!==e.mirror&&(i[c]+=h),!0===e.mirror||\"ticks\"===e.mirror?i[v]=e._anchorAxis.domain[d[1]]:\"all\"!==e.mirror&&\"allticks\"!==e.mirror||(i[v]=[e._counterDomainMin,e._counterDomainMax][d[1]]))}ht&&(s=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),\"string\"==typeof e.automargin&&(Tt(n,e.automargin),Tt(i,e.automargin)),a.autoMargin(t,Lt(e),n),a.autoMargin(t,It(e),i),a.autoMargin(t,Pt(e),s)})),s.syncOrAsync(ct)}}function ft(t){var r=g+(t||\"tick\");return S[r]||(S[r]=function(t,e,r){var n,i,a,o;if(t._selections[e].size())n=1/0,i=-1/0,a=1/0,o=-1/0,t._selections[e].each((function(){var t=Ct(this),e=f.bBox(t.node().parentNode);n=Math.min(n,e.top),i=Math.max(i,e.bottom),a=Math.min(a,e.left),o=Math.max(o,e.right)}));else{var s=Z.makeLabelFns(t,r);n=i=s.yFn({dx:0,dy:0,fontSize:0}),a=o=s.xFn({dx:0,dy:0,fontSize:0})}return{top:n,bottom:i,left:a,right:o,height:i-n,width:o-a}}(e,r,T)),S[r]}},Z.getTickSigns=function(t,e){var r=t._id.charAt(0),n={x:\"top\",y:\"right\"}[r],i=t.side===n?1:-1,a=[-1,1,i,-i];return\"inside\"!==(e?(t.minor||{}).ticks:t.ticks)==(\"x\"===r)&&(a=a.map((function(t){return-t}))),t.side&&a.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),a},Z.makeTransTickFn=function(t){return\"x\"===t._id.charAt(0)?function(e){return l(t._offset+t.l2p(e.x),0)}:function(e){return l(0,t._offset+t.l2p(e.x))}},Z.makeTransTickLabelFn=function(t){var e=function(t){var e=t.ticklabelposition||\"\",r=function(t){return-1!==e.indexOf(t)},n=r(\"top\"),i=r(\"left\"),a=r(\"right\"),o=r(\"bottom\"),s=r(\"inside\"),l=o||i||n||a;if(!l&&!s)return[0,0];var c=t.side,u=l?(t.tickwidth||0)/2:0,h=3,f=t.tickfont?t.tickfont.size:12;return(o||n)&&(u+=f*q,h+=(t.linewidth||0)/2),(i||a)&&(u+=(t.linewidth||0)/2,h+=3),s&&\"top\"===c&&(h-=f*(1-q)),(i||n)&&(u=-u),\"bottom\"!==c&&\"right\"!==c||(h=-h),[l?u:0,s?h:0]}(t),r=t.ticklabelshift||0,n=t.ticklabelstandoff||0,i=e[0],a=e[1],o=t.range[0]>t.range[1],s=t.ticklabelposition&&-1!==t.ticklabelposition.indexOf(\"inside\"),c=!s;if(r&&(r*=o?-1:1),n){var u=t.side;n*=s&&(\"top\"===u||\"left\"===u)||c&&(\"bottom\"===u||\"right\"===u)?1:-1}return\"x\"===t._id.charAt(0)?function(e){return l(i+t._offset+t.l2p(At(e))+r,a+n)}:function(e){return l(a+n,i+t._offset+t.l2p(At(e))+r)}},Z.makeTickPath=function(t,e,r,n){n||(n={});var i=n.minor;if(i&&!t.minor)return\"\";var a=void 0!==n.len?n.len:i?t.minor.ticklen:t.ticklen,o=t._id.charAt(0),s=(t.linewidth||1)/2;return\"x\"===o?\"M0,\"+(e+s*r)+\"v\"+a*r:\"M\"+(e+s*r)+\",0h\"+a*r},Z.makeLabelFns=function(t,e,r){var n=t.ticklabelposition||\"\",a=function(t){return-1!==n.indexOf(t)},o=a(\"top\"),l=a(\"left\"),c=a(\"right\"),u=a(\"bottom\")||l||o||c,h=a(\"inside\"),f=\"inside\"===n&&\"inside\"===t.ticks||!h&&\"outside\"===t.ticks&&\"boundaries\"!==t.tickson,p=0,d=0,m=f?t.ticklen:0;if(h?m*=-1:u&&(m=0),f&&(p+=m,r)){var g=s.deg2rad(r);p=m*Math.cos(g)+1,d=m*Math.sin(g)}t.showticklabels&&(f||t.showline)&&(p+=.2*t.tickfont.size);var y,v,x,_,b,w={labelStandoff:p+=(t.linewidth||1)/2*(h?-1:1),labelShift:d},T=0,k=t.side,A=t._id.charAt(0),M=t.tickangle;if(\"x\"===A)_=(b=!h&&\"bottom\"===k||h&&\"top\"===k)?1:-1,h&&(_*=-1),y=d*_,v=e+p*_,x=b?1:-.2,90===Math.abs(M)&&(h?x+=V:x=-90===M&&\"bottom\"===k?q:90===M&&\"top\"===k?V:.5,T=V/2*(M/90)),w.xFn=function(t){return t.dx+y+T*t.fontSize},w.yFn=function(t){return t.dy+v+t.fontSize*x},w.anchorFn=function(t,e){if(u){if(l)return\"end\";if(c)return\"start\"}return i(e)&&0!==e&&180!==e?e*_<0!==h?\"end\":\"start\":\"middle\"},w.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side!==h?-n:0};else if(\"y\"===A){if(_=(b=!h&&\"left\"===k||h&&\"right\"===k)?1:-1,h&&(_*=-1),y=p,v=d*_,x=0,h||90!==Math.abs(M)||(x=-90===M&&\"left\"===k||90===M&&\"right\"===k?q:.5),h){var S=i(M)?+M:0;if(0!==S){var E=s.deg2rad(S);T=Math.abs(Math.sin(E))*q*_,x=0}}w.xFn=function(t){return t.dx+e-(y+t.fontSize*x)*_+T*t.fontSize},w.yFn=function(t){return t.dy+v+t.fontSize*V},w.anchorFn=function(t,e){return i(e)&&90===Math.abs(e)?\"middle\":b?\"end\":\"start\"},w.heightFn=function(e,r,n){return\"right\"===t.side&&(r*=-1),r<-30?-n:r<30?-.5*n:0}}return w},Z.drawTicks=function(t,e,r){r=r||{};var i=e._id+\"tick\",a=[].concat(e.minor&&e.minor.ticks?r.vals.filter((function(t){return t.minor&&!t.noTick})):[]).concat(e.ticks?r.vals.filter((function(t){return!t.minor&&!t.noTick})):[]),o=r.layer.selectAll(\"path.\"+i).data(a,Mt);o.exit().remove(),o.enter().append(\"path\").classed(i,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).each((function(t){return h.stroke(n.select(this),t.minor?e.minor.tickcolor:e.tickcolor)})).style(\"stroke-width\",(function(r){return f.crispRound(t,r.minor?e.minor.tickwidth:e.tickwidth,1)+\"px\"})).attr(\"d\",r.path).style(\"display\",null),Nt(e,[B]),o.attr(\"transform\",r.transFn)},Z.drawGrid=function(t,e,r){if(r=r||{},\"sync\"!==e.tickmode){var i=e._id+\"grid\",a=e.minor&&e.minor.showgrid,o=a?r.vals.filter((function(t){return t.minor})):[],s=e.showgrid?r.vals.filter((function(t){return!t.minor})):[],l=r.counterAxis;if(l&&Z.shouldShowZeroLine(t,e,l))for(var c=\"array\"===e.tickmode,u=0;u<s.length;u++){var p=s[u].x;if(c?!p:Math.abs(p)<e.dtick/100){if(s=s.slice(0,u).concat(s.slice(u+1)),!c)break;u--}}e._gw=f.crispRound(t,e.gridwidth,1);for(var d=a?f.crispRound(t,e.minor.gridwidth,1):0,m=r.layer,g=r.minorLayer,y=1;y>=0;y--){var v=y?m:g;if(v){var x=v.selectAll(\"path.\"+i).data(y?s:o,Mt);x.exit().remove(),x.enter().append(\"path\").classed(i,1).classed(\"crisp\",!1!==r.crisp),x.attr(\"transform\",r.transFn).attr(\"d\",r.path).each((function(t){return h.stroke(n.select(this),t.minor?e.minor.gridcolor:e.gridcolor||\"#ddd\")})).style(\"stroke-dasharray\",(function(t){return f.dashStyle(t.minor?e.minor.griddash:e.griddash,t.minor?e.minor.gridwidth:e.gridwidth)})).style(\"stroke-width\",(function(t){return(t.minor?d:e._gw)+\"px\"})).style(\"display\",null),\"function\"==typeof r.path&&x.attr(\"d\",r.path)}}Nt(e,[R,F])}},Z.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=Z.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each((function(){r.layer.selectAll(\"path\").sort((function(t,e){return X(t.id,e.id)}))})),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(h.stroke,e.zerolinecolor||h.defaultLine).style(\"stroke-width\",f.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\").style(\"display\",null),Nt(e,[D])},Z.drawLabels=function(t,e,r){r=r||{};var a=t._fullLayout,o=e._id,u=r.cls||o+\"tick\",h=r.vals.filter((function(t){return t.text})),p=r.labelFns,d=r.secondary?0:e.tickangle,m=(e._prevTickAngles||{})[u],g=r.layer.selectAll(\"g.\"+u).data(e.showticklabels?h:[],Mt),y=[];function v(t,a){t.each((function(t){var o=n.select(this),s=o.select(\".text-math-group\"),u=p.anchorFn(t,a),h=r.transFn.call(o.node(),t)+(i(a)&&0!=+a?\" rotate(\"+a+\",\"+p.xFn(t)+\",\"+(p.yFn(t)-t.fontSize/2)+\")\":\"\"),d=c.lineCount(o),m=H*t.fontSize,g=p.heightFn(t,i(a)?+a:0,(d-1)*m);if(g&&(h+=l(0,g)),s.empty()){var y=o.select(\"text\");y.attr({transform:h,\"text-anchor\":u}),y.style(\"opacity\",1),e._adjustTickLabelsOverflow&&e._adjustTickLabelsOverflow()}else{var v=f.bBox(s.node()).width*{end:-.5,start:.5}[u];s.attr(\"transform\",h+l(v,0))}}))}g.enter().append(\"g\").classed(u,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),i=t._promises.length;r.call(c.positionText,p.xFn(e),p.yFn(e)).call(f.font,{family:e.font,size:e.fontSize,color:e.fontColor,weight:e.fontWeight,style:e.fontStyle,variant:e.fontVariant,textcase:e.fontTextcase,lineposition:e.fontLineposition,shadow:e.fontShadow}).text(e.text).call(c.convertToTspans,t),t._promises[i]?y.push(t._promises.pop().then((function(){v(r,d)}))):v(r,d)})),Nt(e,[N]),g.exit().remove(),r.repositionOnUpdate&&g.each((function(t){n.select(this).select(\"text\").call(c.positionText,p.xFn(t),p.yFn(t))})),e._adjustTickLabelsOverflow=function(){var r=e.ticklabeloverflow;if(r&&\"allow\"!==r){var i=-1!==r.indexOf(\"hide\"),o=\"x\"===e._id.charAt(0),l=0,c=o?t._fullLayout.width:t._fullLayout.height;if(-1!==r.indexOf(\"domain\")){var u=s.simpleMap(e.range,e.r2l);l=e.l2p(u[0])+e._offset,c=e.l2p(u[1])+e._offset}var h=Math.min(l,c),p=Math.max(l,c),d=e.side,m=1/0,y=-1/0;for(var v in g.each((function(t){var r=n.select(this);if(r.select(\".text-math-group\").empty()){var a=f.bBox(r.node()),s=0;o?(a.right>p||a.left<h)&&(s=1):(a.bottom>p||a.top+(e.tickangle?0:t.fontSize/4)<h)&&(s=1);var l=r.select(\"text\");s?i&&l.style(\"opacity\",0):(l.style(\"opacity\",1),m=\"bottom\"===d||\"right\"===d?Math.min(m,o?a.top:a.left):-1/0,y=\"top\"===d||\"left\"===d?Math.max(y,o?a.bottom:a.right):1/0)}})),a._plots){var x=a._plots[v];if(e._id===x.xaxis._id||e._id===x.yaxis._id){var _=o?x.yaxis:x.xaxis;_&&(_[\"_visibleLabelMin_\"+e._id]=m,_[\"_visibleLabelMax_\"+e._id]=y)}}}},e._hideCounterAxisInsideTickLabels=function(t){var r=\"x\"===e._id.charAt(0),i=[];for(var o in a._plots){var s=a._plots[o];e._id!==s.xaxis._id&&e._id!==s.yaxis._id||i.push(r?s.yaxis:s.xaxis)}i.forEach((function(r,i){r&&Bt(r)&&(t||[D,F,R,B,N]).forEach((function(t){var o=\"tick\"===t.K&&\"text\"===t.L&&\"period\"===e.ticklabelmode,s=a._plots[e._mainSubplot];(t.K===D.K?s.zerolinelayer.selectAll(\".\"+e._id+\"zl\"):t.K===F.K?s.minorGridlayer.selectAll(\".\"+e._id):t.K===R.K?s.gridlayer.selectAll(\".\"+e._id):s[e._id.charAt(0)+\"axislayer\"]).each((function(){var a=n.select(this);t.L&&(a=a.selectAll(t.L)),a.each((function(a){var s=e.l2p(o?At(a):a.x)+e._offset,l=n.select(this);s<e[\"_visibleLabelMax_\"+r._id]&&s>e[\"_visibleLabelMin_\"+r._id]?l.style(\"display\",\"none\"):\"tick\"!==t.K||i||l.style(\"display\",null)}))}))}))}))},v(g,m+1?m:d);var x=null;e._selections&&(e._selections[u]=g);var _=[function(){return y.length&&Promise.all(y)}];e.automargin&&a._redrawFromAutoMarginCount&&90===m?(x=m,_.push((function(){v(g,m)}))):_.push((function(){if(v(g,d),h.length&&e.autotickangles&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){x=e.autotickangles[0];var t,n=0,i=[],a=1;g.each((function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),o=Ct(this),s=f.bBox(o.node());a=Math.max(a,c.lineCount(o)),i.push({top:0,bottom:10,height:10,left:r-s.width/2,right:r+s.width/2+2,width:s.width+2})}));var o=(\"boundaries\"===e.tickson||e.showdividers)&&!r.secondary,l=h.length,u=Math.abs((h[l-1].x-h[0].x)*e._m)/(l-1),p=o?u/2:u,m=o?e.ticklen:1.25*n*a,y=p/Math.sqrt(Math.pow(p,2)+Math.pow(m,2)),_=e.autotickangles.map((function(t){return t*Math.PI/180})),b=_.find((function(t){return Math.abs(Math.cos(t))<=y}));void 0===b&&(b=_.reduce((function(t,e){return Math.abs(Math.cos(t))<Math.abs(Math.cos(e))?t:e}),_[0]));var w=b*(180/Math.PI);if(o){var T=2;for(e.ticks&&(T+=e.tickwidth/2),t=0;t<i.length;t++){var k=h[t].xbnd,A=i[t];if(null!==k[0]&&A.left-e.l2p(k[0])<T||null!==k[1]&&e.l2p(k[1])-A.right<T){x=w;break}}}else{var M=e.ticklabelposition||\"\",S=function(t){return-1!==M.indexOf(t)},E=S(\"top\"),C=S(\"left\"),L=S(\"right\"),I=S(\"bottom\")||C||E||L?(e.tickwidth||0)+6:0;for(t=0;t<i.length-1;t++)if(s.bBoxIntersect(i[t],i[t+1],I)){x=w;break}}x&&v(g,x)}})),e._tickAngles&&_.push((function(){e._tickAngles[u]=null===x?i(d)?d:0:x}));var b=function(){var t=0,r=0;return g.each((function(n,i){var a,o=Ct(this);o.select(\".text-math-group\").empty()&&(e._vals[i]&&(a=e._vals[i].bb||f.bBox(o.node()),e._vals[i].bb=a),t=Math.max(t,a.width),r=Math.max(r,a.height))})),{labelsMaxW:t,labelsMaxH:r}},w=e._anchorAxis;if(w&&(w.autorange||w.insiderange)&&Bt(e)&&!$(a,e._id)&&(a._insideTickLabelsUpdaterange||(a._insideTickLabelsUpdaterange={}),w.autorange&&(a._insideTickLabelsUpdaterange[w._name+\".autorange\"]=w.autorange,_.push(b)),w.insiderange)){var T=b(),k=\"y\"===e._id.charAt(0)?T.labelsMaxW:T.labelsMaxH;k+=6,\"inside\"===e.ticklabelposition&&(k+=e.ticklen||0);var A=\"right\"===e.side||\"top\"===e.side?1:-1,M=1===A?1:0,S=1===A?0:1,E=[];E[S]=w.range[S];var C=w.range,L=w.r2p(C[M]),I=w.r2p(C[S]),P=a._insideTickLabelsUpdaterange[w._name+\".range\"];if(P){var z=w.r2p(P[M]),O=w.r2p(P[S]),j=A*(\"y\"===e._id.charAt(0)?1:-1);j*L<j*z&&(L=z,E[M]=C[M]=P[M]),j*I>j*O&&(I=O,E[S]=C[S]=P[S])}var U=Math.abs(I-L);U-k>0?k*=1+k/(U-=k):k=0,\"y\"!==e._id.charAt(0)&&(k=-k),E[M]=w.p2r(w.r2p(C[M])+A*k),\"min\"===w.autorange||\"max reversed\"===w.autorange?(E[0]=null,w._rangeInitial0=void 0,w._rangeInitial1=void 0):\"max\"!==w.autorange&&\"min reversed\"!==w.autorange||(E[1]=null,w._rangeInitial0=void 0,w._rangeInitial1=void 0),a._insideTickLabelsUpdaterange[w._name+\".range\"]=E}var V=s.syncOrAsync(_);return V&&V.then&&t._promises.push(V),V},Z.getPxPosition=function(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=e._anchorAxis:\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w+e._shift,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0},Z.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===O)&&(Et(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(i){var a=t._fullLayout,o=e._id.charAt(0),s=Z.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length),c=a._plots[r._mainSubplot];if(!(c.mainplotinfo||c).overlays.length)return p(r);for(var u=Z.list(t,s),h=0;h<u.length;h++){var f=u[h];if(f._mainAxis===i&&p(f))return!0}}function p(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},Z.clipEnds=function(t,e){return e.filter((function(e){return Et(t,e.x)}))},Z.allowAutoMargin=function(t){for(var e=Z.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(a.allowAutoMargin(t,Lt(n)),n.mirror&&a.allowAutoMargin(t,It(n))),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,Pt(n))}},Z.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],zt(c.x,l.x),zt(c.y,l.y);zt(c.x,[o]),zt(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)Ot(t,r[n].x,r[n].y)}},9666:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(63821).BADNUM,o=i.isArrayOrTypedArray,s=i.isDateTime,l=i.cleanNumber,c=Math.round;function u(t,e){return e?n(t):\"number\"==typeof t}function h(t){return Math.max(1,(t-1)/1e3)}t.exports=function(t,e,r){var i=t,f=r.noMultiCategory;if(o(i)&&!i.length)return\"-\";if(!f&&function(t){return o(t[0])&&o(t[1])}(i))return\"multicategory\";if(f&&Array.isArray(i[0])){for(var p=[],d=0;d<i.length;d++)if(o(i[d]))for(var m=0;m<i[d].length;m++)p.push(i[d][m]);i=p}if(function(t,e){for(var r=t.length,i=h(r),a=0,o=0,l={},u=0;u<r;u+=i){var f=t[c(u)],p=String(f);l[p]||(l[p]=1,s(f,e)&&a++,n(f)&&o++)}return a>2*o}(i,e))return\"date\";var g=\"strict\"!==r.autotypenumbers;return function(t,e){for(var r=t.length,n=h(r),i=0,o=0,s={},u=0;u<r;u+=n){var f=t[c(u)],p=String(f);if(!s[p]){s[p]=1;var d=typeof f;\"boolean\"===d?o++:(e?l(f)!==a:\"number\"===d)?i++:\"string\"===d&&o++}}return o>2*i}(i,g)?\"category\":function(t,e){for(var r=t.length,n=0;n<r;n++)if(u(t[n],e))return!0;return!1}(i,g)?\"linear\":\"-\"}},97655:function(t,e,r){\"use strict\";var n=r(10721),i=r(33626),a=r(34809),o=r(78032),s=r(59008),l=r(25829),c=r(22777),u=r(87433),h=r(12036),f=r(54616),p=r(46473),d=r(97405),m=r(90259),g=r(19091),y=r(54826).WEEKDAY_PATTERN,v=r(54826).HOUR_PATTERN;function x(t,e,r){function i(r,n){return a.coerce(t,e,l.rangebreaks,r,n)}if(i(\"enabled\")){var o=i(\"bounds\");if(o&&o.length>=2){var s,c,u=\"\";if(2===o.length)for(s=0;s<2;s++)if(c=b(o[s])){u=y;break}var h=i(\"pattern\",u);if(h===y)for(s=0;s<2;s++)(c=b(o[s]))&&(e.bounds[s]=o[s]=c-1);if(h)for(s=0;s<2;s++)switch(c=o[s],h){case y:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[s]=o[s]=c;break;case v:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[s]=o[s]=c}if(!1===r.autorange){var f=r.range;if(f[0]<f[1]){if(o[0]<f[0]&&o[1]>f[1])return void(e.enabled=!1)}else if(o[0]>f[0]&&o[1]<f[1])return void(e.enabled=!1)}}else{var p=i(\"values\");if(!p||!p.length)return void(e.enabled=!1);i(\"dvalue\")}}}t.exports=function(t,e,r,n,v){var _,b=n.letter,w=n.font||{},T=n.splomStash||{},k=r(\"visible\",!n.visibleDflt),A=e._template||{},M=e.type||A.type||\"-\";\"date\"===M&&(i.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",n.calendar),n.noTicklabelmode||(_=r(\"ticklabelmode\"))),n.noTicklabelindex||\"date\"!==M&&\"linear\"!==M||r(\"ticklabelindex\");var S=\"\";n.noTicklabelposition&&\"multicategory\"!==M||(S=a.coerce(t,e,{ticklabelposition:{valType:\"enumerated\",dflt:\"outside\",values:\"period\"===_?[\"outside\",\"inside\"]:\"x\"===b?[\"outside\",\"inside\",\"outside left\",\"inside left\",\"outside right\",\"inside right\"]:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"]}},\"ticklabelposition\")),n.noTicklabeloverflow||r(\"ticklabeloverflow\",-1!==S.indexOf(\"inside\")?\"hide past domain\":\"category\"===M||\"multicategory\"===M?\"allow\":\"hide past div\"),g(e,v),m(t,e,r,n),p(t,e,r,n),\"category\"===M||n.noHover||r(\"hoverformat\");var E=r(\"color\"),C=E!==l.color.dflt?E:w.color,L=T.label||v._dfltTitle[b];if(f(t,e,r,M,n),!k)return e;r(\"title.text\",L),a.coerceFont(r,\"title.font\",w,{overrideDflt:{size:a.bigFont(w.size),color:C}}),c(t,e,r,M);var I=n.hasMinor;if(I&&(o.newContainer(e,\"minor\"),c(t,e,r,M,{isMinor:!0})),h(t,e,r,M,n),u(t,e,r,n),I){var P=n.isMinor;n.isMinor=!0,u(t,e,r,n),n.isMinor=P}d(t,e,r,{dfltColor:E,bgColor:n.bgColor,showGrid:n.showGrid,hasMinor:I,attributes:l}),!I||e.minor.ticks||e.minor.showgrid||delete e.minor,(e.showline||e.ticks)&&r(\"mirror\");var z,O=\"multicategory\"===M;if(n.noTickson||\"category\"!==M&&!O||!e.ticks&&!e.showgrid||(O&&(z=\"boundaries\"),\"boundaries\"===r(\"tickson\",z)&&delete e.ticklabelposition),O&&r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")),\"date\"===M)if(s(t,e,{name:\"rangebreaks\",inclusionAttr:\"enabled\",handleItemDefaults:x}),e.rangebreaks.length){for(var D=0;D<e.rangebreaks.length;D++)if(e.rangebreaks[D].pattern===y){e._hasDayOfWeekBreaks=!0;break}if(g(e,v),v._has(\"scattergl\")||v._has(\"splom\"))for(var R=0;R<n.data.length;R++){var F=n.data[R];\"scattergl\"!==F.type&&\"splom\"!==F.type||(F.visible=!1,a.warn(F.type+\" traces do not work on axes with rangebreaks. Setting trace \"+F.index+\" to `visible: false`.\"))}}else delete e.rangebreaks;return e};var _={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function b(t){if(\"string\"==typeof t)return _[t.substr(0,3).toLowerCase()]}},80712:function(t,e,r){\"use strict\";var n=r(87296),i=n.FORMAT_LINK,a=n.DATE_FORMAT_LINK;function o(t,e){return[\"Sets the \"+t+\" formatting rule\"+(e?\"for `\"+e+\"` \":\"\"),\"using d3 formatting mini-languages\",\"which are very similar to those in Python. For numbers, see: \"+i+\".\"].join(\" \")}function s(t,e){return o(t,e)+[\" And for dates see: \"+a+\".\",\"We add two items to d3's date formatter:\",\"*%h* for half of the year as a decimal number as well as\",\"*%{n}f* for fractional seconds\",\"with n digits. For example, *2016-10-13 09:15:23.456* with tickformat\",\"*%H~%M~%S.%2f* would display *09~15~23.46*\"].join(\" \")}t.exports={axisHoverFormat:function(t,e){return{valType:\"string\",dflt:\"\",editType:\"none\",description:(e?o:s)(\"hover text\",t)+[\"By default the values are formatted using \"+(e?\"generic number format\":\"`\"+t+\"axis.hoverformat`\")+\".\"].join(\" \")}},descriptionOnlyNumbers:o,descriptionWithDates:s}},5975:function(t,e,r){\"use strict\";var n=r(33626),i=r(54826);function a(t,e){if(e&&e.length)for(var r=0;r<e.length;r++)if(e[r][t])return!0;return!1}e.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.split(\" \")[0].substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},e.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},e.cleanId=function(t,e,r){var n=/( domain)$/.test(t);if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)&&(!n||r)){var a=t.split(\" \")[0].substr(1).replace(/^0+/,\"\");return\"1\"===a&&(a=\"\"),t.charAt(0)+a+(n&&r?\" domain\":\"\")}},e.list=function(t,r,n){var i=t._fullLayout;if(!i)return[];var a,o=e.listIds(t,r),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];r?s.push(u[r+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},e.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},e.getFromId=function(t,r,n){var i=t._fullLayout;return r=void 0===r||\"string\"!=typeof r?r:r.replace(\" domain\",\"\"),\"x\"===n?r=r.replace(/y[0-9]*/,\"\"):\"y\"===n&&(r=r.replace(/x[0-9]*/,\"\")),i[e.id2name(r)]},e.getFromTrace=function(t,r,i){var a=t._fullLayout,o=null;if(n.traceIs(r,\"gl3d\")){var s=r.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=e.getFromId(t,r[i+\"axis\"]||i);return o},e.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},e.ref2id=function(t){return!!/^[xyz]/.test(t)&&t.split(\" \")[0]},e.isLinked=function(t,e){return a(e,t._axisMatchGroups)||a(e,t._axisConstraintGroups)}},46473:function(t,e,r){\"use strict\";var n=r(87800).isTypedArraySpec;t.exports=function(t,e,r,i){if(\"category\"===e.type){var a,o=t.categoryarray,s=Array.isArray(o)&&o.length>0||n(o);s&&(a=\"array\");var l,c=r(\"categoryorder\",a);\"array\"===c&&(l=r(\"categoryarray\")),s||\"array\"!==c||(c=e.categoryorder=\"trace\"),\"trace\"===c?e._initialCategories=[]:\"array\"===c?e._initialCategories=l.slice():(l=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,i).sort(),\"category ascending\"===c?e._initialCategories=l:\"category descending\"===c&&(e._initialCategories=l.reverse()))}}},68599:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(63821),o=a.ONEDAY,s=a.ONEWEEK;e.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,a=\"category\"===e,s=i?o:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:a?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},e.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r,a%s==0?1:0)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},54826:function(t,e,r){\"use strict\";var n=r(90694).counter;t.exports={idRegex:{x:n(\"x\",\"( domain)?\"),y:n(\"y\",\"( domain)?\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*( domain)?$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:\"hour\",WEEKDAY_PATTERN:\"day of week\",MINDRAG:8,MINZOOM:20,DRAGGERSIZE:20,REDRAWDELAY:50,DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"imagelayer\",\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"},zindexSeparator:\"z\"}},84391:function(t,e,r){\"use strict\";var n=r(34809),i=r(32919),a=r(5975).id2name,o=r(25829),s=r(67611),l=r(19091),c=r(63821).ALMOST_EQUAL,u=r(4530).FROM_BL;function h(t,e,r){var i=r.axIds,s=r.layoutOut,l=r.hasImage,c=s._axisConstraintGroups,u=s._axisMatchGroups,h=e._id,m=h.charAt(0),g=((s._splomAxes||{})[m]||{})[h]||{},y=e._id,v=\"x\"===y.charAt(0);function x(r,i){return n.coerce(t,e,o,r,i)}e._matchGroup=null,e._constraintGroup=null,x(\"constrain\",l?\"domain\":\"range\"),n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:v?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:v?\"center\":\"middle\"}},\"constraintoward\");var _,b,w=e.type,T=[];for(_=0;_<i.length;_++)(b=i[_])!==y&&s[a(b)].type===w&&T.push(b);var k=p(c,y);if(k){var A=[];for(_=0;_<T.length;_++)k[b=T[_]]||A.push(b);T=A}var M,S,E=T.length;E&&(t.matches||g.matches)&&(M=n.coerce(t,e,{matches:{valType:\"enumerated\",values:T,dflt:-1!==T.indexOf(g.matches)?g.matches:void 0}},\"matches\"));var C=l&&!v?e.anchor:void 0;if(E&&!M&&(t.scaleanchor||C)&&(S=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:T.concat([!1])}},\"scaleanchor\",C)),M){e._matchGroup=d(u,y,M,1);var L=s[a(M)],I=f(s,e)/f(s,L);v!==(\"x\"===M.charAt(0))&&(I=(v?\"x\":\"y\")+I),d(c,y,M,I)}else t.matches&&-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid an infinite loop');if(S){var P=x(\"scaleratio\");P||(P=e.scaleratio=1),d(c,y,S,P)}else t.scaleanchor&&-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because this axis declares a *matches* constraint.')}function f(t,e){var r=e.domain;return r||(r=t[a(e.overlaying)].domain),r[1]-r[0]}function p(t,e){for(var r=0;r<t.length;r++)if(t[r][e])return t[r];return null}function d(t,e,r,n){var i,a,o,s,l,c=p(t,e);null===c?((c={})[e]=1,l=t.length,t.push(c)):l=t.indexOf(c);var u=Object.keys(c);for(i=0;i<t.length;i++)if(o=t[i],i!==l&&o[r]){var h=o[r];for(a=0;a<u.length;a++)o[s=u[a]]=m(h,m(n,c[s]));return void t.splice(l,1)}if(1!==n)for(a=0;a<u.length;a++){var f=u[a];c[f]=m(n,c[f])}c[r]=1}function m(t,e){var r,n,i=\"\",a=\"\";\"string\"==typeof t&&(r=(i=t.match(/^[xy]*/)[0]).length,t=+t.substr(r)),\"string\"==typeof e&&(n=(a=e.match(/^[xy]*/)[0]).length,e=+e.substr(n));var o=t*e;return r||n?r&&n&&i.charAt(0)!==a.charAt(0)?r===n?o:(r>n?i.substr(n):a.substr(r))+o:i+a+t*e:o}function g(t,e){for(var r=e._size,n=r.h/r.w,i={},a=Object.keys(t),o=0;o<a.length;o++){var s=a[o],l=t[s];if(\"string\"==typeof l){var c=l.match(/^[xy]*/)[0],u=c.length;l=+l.substr(u);for(var h=\"y\"===c.charAt(0)?n:1/n,f=0;f<u;f++)l*=h}i[s]=l}return i}function y(t,e){var r=t._inputDomain,n=u[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}e.handleDefaults=function(t,e,r){var i,o,s,c,u,f,p,d,m=r.axIds,g=r.axHasImage,y=e._axisConstraintGroups=[],v=e._axisMatchGroups=[];for(i=0;i<m.length;i++)h(u=t[c=a(m[i])],f=e[c],{axIds:m,layoutOut:e,hasImage:g[c]});function x(t,r){for(i=0;i<t.length;i++)for(s in o=t[i])e[a(s)][r]=o}for(x(v,\"_matchGroup\"),i=0;i<y.length;i++)for(s in o=y[i])if((f=e[a(s)]).fixedrange){for(var _ in o){var b=a(_);!1===(t[b]||{}).fixedrange&&n.warn(\"fixedrange was specified as false for axis \"+b+\" but was overridden because another axis in its constraint group has fixedrange true\"),e[b].fixedrange=!0}break}for(i=0;i<y.length;){for(s in o=y[i]){(f=e[a(s)])._matchGroup&&Object.keys(f._matchGroup).length===Object.keys(o).length&&(y.splice(i,1),i--);break}i++}x(y,\"_constraintGroup\");var w=[\"constrain\",\"range\",\"autorange\",\"rangemode\",\"rangebreaks\",\"categoryorder\",\"categoryarray\"],T=!1,k=!1;function A(){d=f[p],\"rangebreaks\"===p&&(k=f._hasDayOfWeekBreaks)}for(i=0;i<v.length;i++){o=v[i];for(var M=0;M<w.length;M++){var S;for(s in p=w[M],d=null,o)if(u=t[c=a(s)],f=e[c],p in f){if(!f.matches&&(S=f,p in u)){A();break}null===d&&p in u&&A()}if(\"range\"===p&&d&&u.range&&2===u.range.length&&null!==u.range[0]&&null!==u.range[1]&&(T=!0),\"autorange\"===p&&null===d&&T&&(d=!1),null===d&&p in S&&(d=S[p]),null!==d)for(s in o)(f=e[a(s)])[p]=\"range\"===p?d.slice():d,\"rangebreaks\"===p&&(f._hasDayOfWeekBreaks=k,l(f,e))}}},e.enforce=function(t){var e,r,n,o,l,u,h,f,p=t._fullLayout,d=p._axisConstraintGroups||[];for(e=0;e<d.length;e++){n=g(d[e],p);var m=Object.keys(n),v=1/0,x=0,_=1/0,b={},w={},T=!1;for(r=0;r<m.length;r++)w[o=m[r]]=l=p[a(o)],l._inputDomain?l.domain=l._inputDomain.slice():l._inputDomain=l.domain.slice(),l._inputRange||(l._inputRange=l.range.slice()),l.setScale(),b[o]=u=Math.abs(l._m)/n[o],v=Math.min(v,u),\"domain\"!==l.constrain&&l._constraintShrinkable||(_=Math.min(_,u)),delete l._constraintShrinkable,x=Math.max(x,u),\"domain\"===l.constrain&&(T=!0);if(!(v>c*x)||T)for(r=0;r<m.length;r++)if(u=b[o=m[r]],h=(l=w[o]).constrain,u!==_||\"domain\"===h)if(f=u/_,\"range\"===h)s(l,f);else{var k=l._inputDomain,A=(l.domain[1]-l.domain[0])/(k[1]-k[0]),M=(l.r2l(l.range[1])-l.r2l(l.range[0]))/(l.r2l(l._inputRange[1])-l.r2l(l._inputRange[0]));if((f/=A)*M<1){l.domain=l._input.domain=k.slice(),s(l,f);continue}if(M<1&&(l.range=l._input.range=l._inputRange.slice(),f*=M),l.autorange){var S=l.r2l(l.range[0]),E=l.r2l(l.range[1]),C=(S+E)/2,L=C,I=C,P=Math.abs(E-C),z=C-P*f*1.0001,O=C+P*f*1.0001,D=i.makePadFn(p,l,0),R=i.makePadFn(p,l,1);y(l,f);var F,B,N=Math.abs(l._m),j=i.concatExtremes(t,l),U=j.min,V=j.max;for(B=0;B<U.length;B++)(F=U[B].val-D(U[B])/N)>z&&F<L&&(L=F);for(B=0;B<V.length;B++)(F=V[B].val+R(V[B])/N)<O&&F>I&&(I=F);f/=(I-L)/(2*P),L=l.l2r(L),I=l.l2r(I),l.range=l._input.range=S<E?[L,I]:[I,L]}y(l,f)}}},e.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++)if(r[n][e])return\"g\"+n;return e},e.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},51680:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=i.numberFormat,o=r(65657),s=r(74043),l=r(33626),c=i.strTranslate,u=r(30635),h=r(78766),f=r(62203),p=r(32141),d=r(29714),m=r(27983),g=r(14751),y=r(70414),v=y.selectingOrDrawing,x=y.freeMode,_=r(4530).FROM_TL,b=r(34823),w=r(71817).redrawReglTraces,T=r(44122),k=r(5975).getFromId,A=r(44844).prepSelect,M=r(44844).clearOutline,S=r(44844).selectOnClick,E=r(67611),C=r(54826),L=C.MINDRAG,I=C.MINZOOM,P=!0;function z(t,e,r,n){var a=i.ensureSingle(t.draglayer,e,r,(function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)}));return a.call(m,n),a.node()}function O(t,e,r,i,a,o,s){var l=z(t,\"rect\",e,r);return n.select(l).call(f.setRect,i,a,o,s),l}function D(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function R(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange)if(o.rangebreaks){var s=\"y\"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+\".range[0]\"]=o.l2r(o.p2l(l*o._length)),n[o._name+\".range[1]\"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],h=o._rl[1]-u;n[o._name+\".range[0]\"]=o.l2r(u+h*e),n[o._name+\".range[1]\"]=o.l2r(u+h*r)}}if(i&&i.length){var f=(e+(1-r))/2;R(i,f,1-f,n,[])}}function F(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange){if(n.rangebreaks){var i=n._length,a=(n.p2l(0+e)-n.p2l(0)+(n.p2l(i+e)-n.p2l(i)))/2;n.range=[n.l2r(n._rl[0]-a),n.l2r(n._rl[1]-a)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)];n.limitRange&&n.limitRange()}}}function B(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function N(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",c(r,n)).attr(\"d\",i+\"Z\")}function j(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:h.background,stroke:h.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",c(e,r)).attr(\"d\",\"M0,0Z\")}function U(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),V(t,e,i,a)}function V(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function q(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function H(t){P&&t.data&&t._context.showTips&&(i.notifier(i._(t,\"Double-click to zoom back out\"),\"long\"),P=!1)}function G(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,I)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function Z(t,e,r,n,a){for(var o,s,l,c,u=!1,h={},f={},p=(a||{}).xaHash,d=(a||{}).yaHash,m=0;m<e.length;m++){var g=e[m];for(o in r)if(g[o]){for(l in g)a&&(p[l]||d[l])||(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=o);for(s in n)a&&(p[s]||d[s])||!g[s]||(u=!0)}for(s in n)if(g[s])for(c in g)a&&(p[c]||d[c])||(\"x\"===c.charAt(0)?r:n)[c]||(f[c]=s)}u&&(i.extendFlat(h,f),f={});var y={},v=[];for(l in h){var x=k(t,l);v.push(x),y[x._id]=x}var _={},b=[];for(c in f){var w=k(t,c);b.push(w),_[w._id]=w}return{xaHash:y,yaHash:_,xaxes:v,yaxes:b,xLinks:h,yLinks:f,isSubplotConstrained:u}}function W(t,e){if(s){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel?t.onmousewheel=e:t.isAddedWheelEvent||(t.isAddedWheelEvent=!0,t.addEventListener(\"wheel\",e,{passive:!1}))}function Y(t){var e=[];for(var r in t)e.push(t[r]);return e}t.exports={makeDragBox:function(t,e,r,s,c,h,m,y){var P,z,V,X,$,J,K,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht,ft,pt,dt,mt=t._fullLayout._zoomlayer,gt=m+y===\"nsew\",yt=1===(m+y).length;function vt(){if(P=e.xaxis,z=e.yaxis,tt=P._length,et=z._length,K=P._offset,Q=z._offset,(V={})[P._id]=P,(X={})[z._id]=z,m&&y)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;V[i._id]=i;var a=r[n].yaxis;X[a._id]=a}$=Y(V),J=Y(X),it=D($,y),at=D(J,m),ot=!at&&!it,nt=Z(t,t._fullLayout._axisMatchGroups,V,X);var o=(rt=Z(t,t._fullLayout._axisConstraintGroups,V,X,nt)).isSubplotConstrained||nt.isSubplotConstrained;st=y||o,lt=m||o;var s=t._fullLayout;ct=s._has(\"scattergl\"),ut=s._has(\"splom\"),ht=s._has(\"svg\")}r+=e.yaxis._shift,vt();var xt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(at+it,t._fullLayout.dragmode,gt),_t=O(e,m+y+\"drag\",xt,r,s,c,h);if(ot&&!gt)return _t.onmousedown=null,_t.style.pointerEvents=\"none\",_t;var bt,wt,Tt,kt,At,Mt,St,Et,Ct,Lt,It={element:_t,gd:t,plotinfo:e};function Pt(){It.plotinfo.selection=!1,M(t)}function zt(t,r){var i=It.gd;if(i._fullLayout._activeShapeIndex>=0)i._fullLayout._deactivateShape(i);else{var o=i._fullLayout.clickmode;if(q(i),2!==t||yt||Ht(),gt)o.indexOf(\"select\")>-1&&S(r,i,$,J,e.id,It),o.indexOf(\"event\")>-1&&p.click(i,r,e.id);else if(1===t&&yt){var s=m?z:P,c=\"s\"===m||\"w\"===y?0:1,h=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,n=t.range[e],i=Math.abs(n-t.range[1-e]);return\"date\"===t.type?n:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(i)/Math.LN10))+3,a(\".\"+r+\"g\")(Math.pow(10,n))):(r=Math.floor(Math.log(Math.abs(n))/Math.LN10)-Math.floor(Math.log(i)/Math.LN10)+4,a(\".\"+String(r)+\"g\")(n))}(s,c),d=\"left\",g=\"middle\";if(s.fixedrange)return;m?(g=\"n\"===m?\"top\":\"bottom\",\"right\"===s.side&&(d=\"right\")):\"e\"===y&&(d=\"right\"),i._context.showAxisRangeEntryBoxes&&n.select(_t).call(u.makeEditable,{gd:i,immediate:!0,background:i._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:d,verticalAlign:g}).on(\"edit\",(function(t){var e=s.d2r(t);void 0!==e&&l.call(\"_guiRelayout\",i,h,e)}))}}}function Ot(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min(tt,pt*e+bt)),i=Math.max(0,Math.min(et,dt*r+wt)),a=Math.abs(n-bt),o=Math.abs(i-wt);function s(){St=\"\",Tt.r=Tt.l,Tt.t=Tt.b,Ct.attr(\"d\",\"M0,0Z\")}if(Tt.l=Math.min(bt,n),Tt.r=Math.max(bt,n),Tt.t=Math.min(wt,i),Tt.b=Math.max(wt,i),rt.isSubplotConstrained)a>I||o>I?(St=\"xy\",a/tt>o/et?(o=a*et/tt,wt>i?Tt.t=wt-o:Tt.b=wt+o):(a=o*tt/et,bt>n?Tt.l=bt-a:Tt.r=bt+a),Ct.attr(\"d\",G(Tt))):s();else if(nt.isSubplotConstrained)if(a>I||o>I){St=\"xy\";var l=Math.min(Tt.l/tt,(et-Tt.b)/et),c=Math.max(Tt.r/tt,(et-Tt.t)/et);Tt.l=l*tt,Tt.r=c*tt,Tt.b=(1-l)*et,Tt.t=(1-c)*et,Ct.attr(\"d\",G(Tt))}else s();else!at||o<Math.min(Math.max(.6*a,L),I)?a<L||!it?s():(Tt.t=0,Tt.b=et,St=\"x\",Ct.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-I-.5)+\"h-3v\"+(2*I+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-I-.5)+\"h3v\"+(2*I+1)+\"h-3Z\"}(Tt,wt))):!it||a<Math.min(.6*o,I)?(Tt.l=0,Tt.r=tt,St=\"y\",Ct.attr(\"d\",function(t,e){return\"M\"+(e-I-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*I+1)+\"v3ZM\"+(e-I-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*I+1)+\"v-3Z\"}(Tt,bt))):(St=\"xy\",Ct.attr(\"d\",G(Tt)));Tt.w=Tt.r-Tt.l,Tt.h=Tt.b-Tt.t,St&&(Lt=!0),t._dragged=Lt,U(Et,Ct,Tt,At,Mt,kt),Dt(),t.emit(\"plotly_relayouting\",ft),Mt=!0}function Dt(){ft={},\"xy\"!==St&&\"x\"!==St||(R($,Tt.l/tt,Tt.r/tt,ft,rt.xaxes),Vt(\"x\",ft)),\"xy\"!==St&&\"y\"!==St||(R(J,(et-Tt.b)/et,(et-Tt.t)/et,ft,rt.yaxes),Vt(\"y\",ft))}function Rt(){Dt(),q(t),Gt(),H(t)}It.prepFn=function(e,r,n){var a=It.dragmode,s=t._fullLayout.dragmode;s!==a&&(It.dragmode=s),vt(),pt=t._fullLayout._invScaleX,dt=t._fullLayout._invScaleY,ot||(gt?e.shiftKey?\"pan\"===s?s=\"zoom\":v(s)||(s=\"pan\"):e.ctrlKey&&(s=\"pan\"):s=\"pan\"),x(s)?It.minDrag=1:It.minDrag=void 0,v(s)?(It.xaxes=$,It.yaxes=J,A(e,r,n,It,s)):(It.clickFn=zt,v(a)&&Pt(),ot||(\"zoom\"===s?(It.moveFn=Ot,It.doneFn=Rt,It.minDrag=1,function(e,r,n){var a=_t.getBoundingClientRect();bt=r-a.left,wt=n-a.top,t._fullLayout._calcInverseTransform(t);var s=i.apply3DTransform(t._fullLayout._invTransform)(bt,wt);bt=s[0],wt=s[1],Tt={l:bt,r:bt,w:0,t:wt,b:wt,h:0},kt=t._hmpixcount?t._hmlumcount/t._hmpixcount:o(t._fullLayout.plot_bgcolor).getLuminance(),Mt=!1,St=\"xy\",Lt=!1,Et=N(mt,kt,K,Q,At=\"M0,0H\"+tt+\"V\"+et+\"H0V0\"),Ct=j(mt,K,Q)}(0,r,n)):\"pan\"===s&&(It.moveFn=Ut,It.doneFn=Gt))),t._fullLayout._redrag=function(){var e=t._dragdata;if(e&&e.element===_t){var r=t._fullLayout.dragmode;v(r)||(vt(),Zt([0,0,tt,et]),It.moveFn(e.dx,e.dy))}}},g.init(It);var Ft=[0,0,tt,et],Bt=null,Nt=C.REDRAWDELAY,jt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ut(e,r){if(e*=pt,r*=dt,!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===it||\"ns\"===at){var n=it?-e:0,i=at?-r:0;if(nt.isSubplotConstrained){if(it&&at){var a=(e/tt-r/et)/2;n=-(e=a*tt),i=-(r=-a*et)}at?n=-i*tt/et:i=-n*et/tt}return it&&(F($,e),Vt(\"x\")),at&&(F(J,r),Vt(\"y\")),Zt([n,i,tt,et]),qt(),void t.emit(\"plotly_relayouting\",ft)}var o,s,l=\"w\"===it==(\"n\"===at)?1:-1;if(it&&at&&(rt.isSubplotConstrained||nt.isSubplotConstrained)){var c=(e/tt+l*r/et)/2;e=c*tt,r=l*c*et}if(\"w\"===it?e=p($,0,e):\"e\"===it?e=p($,1,-e):it||(e=0),\"n\"===at?r=p(J,1,r):\"s\"===at?r=p(J,0,-r):at||(r=0),o=\"w\"===it?e:0,s=\"n\"===at?r:0,rt.isSubplotConstrained&&!nt.isSubplotConstrained||nt.isSubplotConstrained&&it&&at&&l>0){var u;if(nt.isSubplotConstrained||!it&&1===at.length){for(u=0;u<$.length;u++)$[u].range=$[u]._r.slice(),E($[u],1-r/et);o=(e=r*tt/et)/2}if(nt.isSubplotConstrained||!at&&1===it.length){for(u=0;u<J.length;u++)J[u].range=J[u]._r.slice(),E(J[u],1-e/tt);s=(r=e*et/tt)/2}}nt.isSubplotConstrained&&at||Vt(\"x\"),nt.isSubplotConstrained&&it||Vt(\"y\");var h=tt-e,f=et-r;!nt.isSubplotConstrained||it&&at||(it?(s=o?0:e*et/tt,f=h*et/tt):(o=s?0:r*tt/et,h=f*tt/et)),Zt([o,s,h,f]),qt(),t.emit(\"plotly_relayouting\",ft)}function p(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/B(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Vt(t,e){for(var r=nt.isSubplotConstrained?{x:J,y:$}[t]:nt[t+\"axes\"],n=nt.isSubplotConstrained?{x:$,y:J}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=nt.xLinks[o]||nt.yLinks[o],l=n[0]||V[s]||X[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function qt(){var r,n=[];function i(t){for(r=0;r<t.length;r++)t[r].fixedrange||n.push(t[r]._id)}function a(t,e){for(r=0;r<t.length;r++){var i=t[r],a=i[e];i.fixedrange||\"sync\"!==a.tickmode||n.push(a._id)}}for(st&&(i($),i(rt.xaxes),i(nt.xaxes),a(e.overlays,\"xaxis\")),lt&&(i(J),i(rt.yaxes),i(nt.yaxes),a(e.overlays,\"yaxis\")),ft={},r=0;r<n.length;r++){var o=n[r],s=k(t,o);d.drawOne(t,s,{skipTitle:!0}),ft[s._name+\".range[0]\"]=s.range[0],ft[s._name+\".range[1]\"]=s.range[1]}d.redrawComponents(t,n)}function Ht(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];it&&(r=r.concat($)),at&&(r=r.concat(J)),nt.xaxes&&(r=r.concat(nt.xaxes)),nt.yaxes&&(r=r.concat(nt.yaxes));var n,i,a={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++){var o=(n=r[i])._rangeInitial0,s=n._rangeInitial1,c=void 0!==o||void 0!==s;if(c&&(void 0!==o&&o!==n.range[0]||void 0!==s&&s!==n.range[1])||!c&&!0!==n.autorange){e=\"reset\";break}}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(a[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((it||rt.isSubplotConstrained)&&(r=r.concat(rt.xaxes)),at&&!rt.isSubplotConstrained&&(r=r.concat(rt.yaxes)),rt.isSubplotConstrained&&(it?at||(r=r.concat(J)):r=r.concat($)),i=0;i<r.length;i++)if(!(n=r[i]).fixedrange){var u=n._name,h=n._autorangeInitial;void 0===n._rangeInitial0&&void 0===n._rangeInitial1?a[u+\".autorange\"]=!0:void 0===n._rangeInitial0?(a[u+\".autorange\"]=h,a[u+\".range\"]=[null,n._rangeInitial1]):void 0===n._rangeInitial1?(a[u+\".range\"]=[n._rangeInitial0,null],a[u+\".autorange\"]=h):a[u+\".range\"]=[n._rangeInitial0,n._rangeInitial1]}t.emit(\"plotly_doubleclick\",null),l.call(\"_guiRelayout\",t,a)}}function Gt(){Zt([0,0,tt,et]),i.syncOrAsync([T.previousPromises,function(){t._fullLayout._replotting=!1,l.call(\"_guiRelayout\",t,ft)}],t)}function Zt(e){var r,n,a,o,s=t._fullLayout,c=s._plots,u=s._subplots.cartesian;if(ut&&l.subplotsRegistry.splom.drag(t),ct)for(r=0;r<u.length;r++)if(a=(n=c[u[r]]).xaxis,o=n.yaxis,n._scene){a.limitRange&&a.limitRange(),o.limitRange&&o.limitRange();var h=i.simpleMap(a.range,a.r2l),p=i.simpleMap(o.range,o.r2l);n._scene.update({range:[h[0],p[0],h[1],p[1]]})}if((ut||ct)&&(b(t),w(t)),ht){var d=e[2]/P._length,g=e[3]/z._length;for(r=0;r<u.length;r++){a=(n=c[u[r]]).xaxis,o=n.yaxis;var v,x,_,T,k=(st||nt.isSubplotConstrained)&&!a.fixedrange&&V[a._id],A=(lt||nt.isSubplotConstrained)&&!o.fixedrange&&X[o._id];if(k?(v=d,_=y||nt.isSubplotConstrained?e[0]:Xt(a,v)):nt.xaHash[a._id]?(v=d,_=e[0]*a._length/P._length):nt.yaHash[a._id]?(v=g,_=\"ns\"===at?-e[1]*a._length/z._length:Xt(a,v,{n:\"top\",s:\"bottom\"}[at])):_=Yt(a,v=Wt(a,d,g)),v>1&&(void 0!==a.maxallowed&&st===(a.range[0]<a.range[1]?\"e\":\"w\")||void 0!==a.minallowed&&st===(a.range[0]<a.range[1]?\"w\":\"e\"))&&(v=1,_=0),A?(x=g,T=m||nt.isSubplotConstrained?e[1]:Xt(o,x)):nt.yaHash[o._id]?(x=g,T=e[1]*o._length/z._length):nt.xaHash[o._id]?(x=d,T=\"ew\"===it?-e[0]*o._length/P._length:Xt(o,x,{e:\"right\",w:\"left\"}[it])):T=Yt(o,x=Wt(o,d,g)),x>1&&(void 0!==o.maxallowed&&lt===(o.range[0]<o.range[1]?\"n\":\"s\")||void 0!==o.minallowed&&lt===(o.range[0]<o.range[1]?\"s\":\"n\"))&&(x=1,T=0),v||x){v||(v=1),x||(x=1);var M=a._offset-_/v,S=o._offset-T/x;n.clipRect.call(f.setTranslate,_,T).call(f.setScale,v,x),n.plot.call(f.setTranslate,M,S).call(f.setScale,1/v,1/x),v===n.xScaleFactor&&x===n.yScaleFactor||(f.setPointGroupScale(n.zoomScalePts,v,x),f.setTextPointsScale(n.zoomScaleTxt,v,x)),f.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=v,n.yScaleFactor=x}}}}function Wt(t,e,r){return t.fixedrange?0:st&&rt.xaHash[t._id]?e:lt&&(rt.isSubplotConstrained?rt.xaHash:rt.yaHash)[t._id]?r:0}function Yt(t,e){return e?(t.range=t._r.slice(),E(t,e),Xt(t,e)):0}function Xt(t,e,r){return t._length*(1-e)*_[r||t.constraintoward||\"middle\"]}return m.length*y.length!=1&&W(_t,(function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Pt(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();vt(),clearTimeout(Bt);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,a=Math.exp(-Math.min(Math.max(r,-20),20)/200),o=jt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),s=(e.clientX-o.left)/o.width,l=(o.bottom-e.clientY)/o.height;if(st){for(y||(s=.5),n=0;n<$.length;n++)c($[n],s,a);Vt(\"x\"),Ft[2]*=a,Ft[0]+=Ft[2]*s*(1/a-1)}if(lt){for(m||(l=.5),n=0;n<J.length;n++)c(J[n],l,a);Vt(\"y\"),Ft[3]*=a,Ft[1]+=Ft[3]*(1-l)*(1/a-1)}Zt(Ft),qt(),t.emit(\"plotly_relayouting\",ft),Bt=setTimeout((function(){t._fullLayout&&(Ft=[0,0,tt,et],Gt())}),Nt),e.preventDefault()}else i.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=i.simpleMap(t.range,t.r2l),a=n[0]+(n[1]-n[0])*e;t.range=n.map((function(e){return t.l2r(a+(e-a)*r)}))}}})),_t},makeDragger:z,makeRectDragger:O,makeZoombox:N,makeCorners:j,updateZoombox:U,xyCorners:G,transitionZoombox:V,removeZoombox:q,showDoubleClickNotifier:H,attachWheelEventHandler:W}},95284:function(t,e,r){\"use strict\";var n=r(45568),i=r(32141),a=r(14751),o=r(27983),s=r(51680).makeDragBox,l=r(54826).DRAGGERSIZE;e.initInteractions=function(t){var r=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(r._has(\"cartesian\")||r._has(\"splom\")){Object.keys(r._plots||{}).sort((function(t,e){if((r._plots[t].mainplot&&!0)===(r._plots[e].mainplot&&!0)){var n=t.split(\"y\"),i=e.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return r._plots[t].mainplot?1:-1})).forEach((function(e){var n=r._plots[e],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(r){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===e&&t._fullLayout._plots[e]&&i.hover(t,r,e)},i.hover(t,r,e),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=e},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(e===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(e===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}}));var o=r._hoverlayer.node();o.onmousemove=function(e){e.target=t._fullLayout._lasthover,i.hover(t,e,r._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},e.updateFx(t)}},e.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},20706:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(5975);t.exports=function(t){return function(e,r){var o=e[t];if(Array.isArray(o))for(var s=n.subplotsRegistry.cartesian,l=s.idRegex,c=r._subplots,u=c.xaxis,h=c.yaxis,f=c.cartesian,p=r._has(\"cartesian\")||r._has(\"gl2d\"),d=0;d<o.length;d++){var m=o[d];if(i.isPlainObject(m)){var g=a.cleanId(m.xref,\"x\",!1),y=a.cleanId(m.yref,\"y\",!1),v=l.x.test(g),x=l.y.test(y);if(v||x){p||i.pushUnique(r._basePlotModules,s);var _=!1;v&&-1===u.indexOf(g)&&(u.push(g),_=!0),x&&-1===h.indexOf(y)&&(h.push(y),_=!0),_&&v&&x&&f.push(g+y)}}}}}},37703:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(34809),o=r(44122),s=r(62203),l=r(4173).eV,c=r(5975),u=r(54826),h=r(62972),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,(function(t){t.datum(r)}))}var d=u.zindexSeparator;function m(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,m=d._zindices,g=d._modules,y=[],v=[],x=0;x<m.length;x++)for(var _=m[x],b=0;b<g.length;b++){var w=(c=g[b]).name,T=i.modules[w].categories;if(T.svg){var k=c.layerName||w+\"layer\",A=k+(x?Number(x)+1:\"\"),M=c.plot;f=(h=l(r,M,_))[0],r=h[1],f.length&&y.push({i:p.indexOf(k),zindex:x,className:A,plotMethod:M,cdModule:f}),T.zoomScale&&v.push(\".\"+A)}}y.sort((function(t,e){return(t.zindex||0)-(e.zindex||0)||t.i-e.i}));var S=e.plot.selectAll(\"g.mlayer\").data(y,(function(t){return t.className}));if(S.enter().append(\"g\").attr(\"class\",(function(t){return t.className})).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),S.exit().remove(),S.order(),S.each((function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)})),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),v.length)){var E=e.plot.selectAll(v.join(\",\")).selectAll(\".trace\");e.zoomScalePts=E.selectAll(\"path.point\"),e.zoomScaleTxt=E.selectAll(\".textpoint\")}}function g(t,e){var r=t._fullLayout,n=e.plotgroup,i=e.id,a=-1!==i.indexOf(d),o=u.layerValue2layerClass[e.xaxis.layer],s=u.layerValue2layerClass[e.yaxis.layer],l=r._hasOnlyLargeSploms;if(!e.mainplot||r._zindices.length>1)if(l)e.xlines=f(n,\"path\",\"xlines-above\"),e.ylines=f(n,\"path\",\"ylines-above\"),e.xaxislayer=f(n,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(n,\"g\",\"yaxislayer-above\");else{if(!a){var h=f(n,\"g\",\"layer-subplot\");e.shapelayer=f(h,\"g\",\"shapelayer\"),e.imagelayer=f(h,\"g\",\"imagelayer\"),e.minorGridlayer=f(n,\"g\",\"minor-gridlayer\"),e.gridlayer=f(n,\"g\",\"gridlayer\"),e.zerolinelayer=f(n,\"g\",\"zerolinelayer\");var m=f(n,\"g\",\"layer-between\");e.shapelayerBetween=f(m,\"g\",\"shapelayer\"),e.imagelayerBetween=f(m,\"g\",\"imagelayer\"),f(n,\"path\",\"xlines-below\"),f(n,\"path\",\"ylines-below\"),e.overlinesBelow=f(n,\"g\",\"overlines-below\"),f(n,\"g\",\"xaxislayer-below\"),f(n,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(n,\"g\",\"overaxes-below\")}e.overplot=f(n,\"g\",\"overplot\"),e.plot=f(e.overplot,\"g\",i),a||(e.xlines=f(n,\"path\",\"xlines-above\"),e.ylines=f(n,\"path\",\"ylines-above\"),e.overlinesAbove=f(n,\"g\",\"overlines-above\"),f(n,\"g\",\"xaxislayer-above\"),f(n,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(n,\"g\",\"overaxes-above\"),e.xlines=n.select(\".xlines-\"+o),e.ylines=n.select(\".ylines-\"+s),e.xaxislayer=n.select(\".xaxislayer-\"+o),e.yaxislayer=n.select(\".yaxislayer-\"+s))}else{var g=e.mainplotinfo,y=g.plotgroup,v=i+\"-x\",x=i+\"-y\";e.minorGridlayer=g.minorGridlayer,e.gridlayer=g.gridlayer,e.zerolinelayer=g.zerolinelayer,f(g.overlinesBelow,\"path\",v),f(g.overlinesBelow,\"path\",x),f(g.overaxesBelow,\"g\",v),f(g.overaxesBelow,\"g\",x),e.plot=f(g.overplot,\"g\",i),f(g.overlinesAbove,\"path\",v),f(g.overlinesAbove,\"path\",x),f(g.overaxesAbove,\"g\",v),f(g.overaxesAbove,\"g\",x),e.xlines=y.select(\".overlines-\"+o).select(\".\"+v),e.ylines=y.select(\".overlines-\"+s).select(\".\"+x),e.xaxislayer=y.select(\".overaxes-\"+o).select(\".\"+v),e.yaxislayer=y.select(\".overaxes-\"+s).select(\".\"+x)}a||(l||(p(e.minorGridlayer,\"g\",e.xaxis._id),p(e.minorGridlayer,\"g\",e.yaxis._id),e.minorGridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort),p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0))}function y(t,e){if(t){var r={};for(var i in t.each((function(t){var i=t[0];n.select(this).remove(),v(i,e),r[i]=!0})),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function v(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}e.name=\"cartesian\",e.attr=[\"xaxis\",\"yaxis\"],e.idRoot=[\"x\",\"y\"],e.idRegex=u.idRegex,e.attrRegex=u.attrRegex,e.attributes=r(55126),e.layoutAttributes=r(25829),e.supplyLayoutDefaults=r(74098),e.transitionAxes=r(84982),e.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var m=f[r].split(\"y\");p[m[0]]=1,d[\"y\"+m[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var g in n=\"\",i=\"\",t)u.attrRegex.test(g)&&(\"x\"===g.charAt(0)?(!n||+g.substr(5)<+n.substr(5))&&(n=g):(!i||+g.substr(5)<+i.substr(5))&&(i=g));n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},e.plot=function(t,e,r,n){var i,o=t._fullLayout,s=o._subplots.cartesian,l=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<l.length;i++)e.push(i);for(var c=o._zindices,u=0;u<c.length;u++){var h=c[u];for(i=0;i<s.length;i++){var f=s[i],p=o._plots[f];if(u>0){var g=p.id;if(-1!==g.indexOf(d))continue;g+=d+(u+1),p=a.extendFlat({},p,{id:g,plot:o._cartesianlayer.selectAll(\".subplot\").select(\".\"+g)})}for(var y,v=[],x=0;x<l.length;x++){var _=l[x],b=_[0].trace;h===(b.zorder||0)&&b.xaxis+b.yaxis===f&&((-1!==e.indexOf(b.index)||b.carpet)&&(y&&y[0].trace.xaxis+y[0].trace.yaxis===f&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(b.fill)&&-1===v.indexOf(y)&&v.push(y),v.push(_)),y=_)}m(t,p,v,r,n)}}},e.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var m=p[a];e[c.id2name(m)]||n._infolayer.selectAll(\".g-\"+m+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),x=e._has&&e._has(\"cartesian\");if(g&&!x)y(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups,delete n._axisMatchGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var _=u.cartesian[a];if(-1===_.indexOf(d)&&!l[_]){var b=\".\"+_+\",.\"+_+\"-x,.\"+_+\"-y\";n._cartesianlayer.selectAll(b).remove(),v(_,n)}}},e.drawFramework=function(t){var e,r=t._fullLayout,i=t.calcdata,o={};for(e=0;e<i.length;e++){var s=i[e][0],l=s.trace.zorder||0;o[l]||(o[l]=[]),o[l].push(s)}var c=Object.keys(o).map(Number).sort(a.sorterAsc);c.length||(c=[0]),r._zindices=c;var u=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._zindices.length,c=s._subplots.cartesian,u=c.length,h=[],f=[];for(e=0;e<u;e++){n=c[e],a=(i=s._plots[n]).xaxis,o=i.yaxis;var p=a._mainAxis,m=o._mainAxis,g=p._id+m._id,y=s._plots[g];i.overlays=[],g!==n&&y?(i.mainplot=g,i.mainplotinfo=y,f.push(n)):(i.mainplot=void 0,i.mainplotinfo=void 0,h.push(n))}for(e=0;e<f.length;e++)n=f[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=h.concat(f),x=[];for(e=0;e<u;e++){n=v[e],a=(i=s._plots[n]).xaxis,o=i.yaxis;for(var _=[],b=1;b<=l;b++){var w=\"\";for(b>1&&(w+=d+b),_.push(n+w),r=0;r<i.overlays.length;r++)_.push(i.overlays[r].id+w)}_=_.concat([a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"]),x.push(_)}return x}(t),h=u.length,p=[];for(e=0;e<h;e++)p[e]=u[e].slice();for(var m=1;m<c.length;m++){var v=[];for(e=0;e<h;e++)v[e]=u[e].slice(),v[e][0]+=d+(m+1);p=p.concat(v)}var x=r._cartesianlayer.selectAll(\".subplot\").data(p,String);x.enter().append(\"g\").attr(\"class\",(function(t){return\"subplot \"+t[0]})),x.order(),x.exit().call(y,r),x.each((function(e){var i=e[0],o=i.indexOf(d),s=-1!==o,l=s?i.slice(0,o):i,c=r._plots[i];c||(c=a.extendFlat({},r._plots[l]))&&(c.id=i,r._plots[i]=c,r._subplots.cartesian.push(i)),c&&(c.plotgroup=n.select(this),g(t,c),s||(c.draglayer=f(r._draggers,\"g\",i)))}))},e.rangePlot=function(t,e,r){g(t,e),m(t,e,r),o.style(t)},e.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this,r=t.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":r,preserveAspectRatio:\"none\",x:0,y:0,width:t.style.width,height:t.style.height})}))},e.updateFx=r(95284).updateFx},25829:function(t,e,r){\"use strict\";var n=r(80337),i=r(10229),a=r(94850).T,o=r(93049).extendFlat,s=r(78032).templatedArray,l=r(80712).descriptionWithDates,c=r(63821).ONEDAY,u=r(54826),h=u.HOUR_PATTERN,f=u.WEEKDAY_PATTERN,p={valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},d=o({},p,{values:p.values.slice().concat([\"sync\"])});function m(t){return{valType:\"integer\",min:0,dflt:t?5:0,editType:\"ticks\"}}var g={valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},y={valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},v={valType:\"data_array\",editType:\"ticks\"},x={valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"};function _(t){var e={valType:\"number\",min:0,editType:\"ticks\"};return t||(e.dflt=5),e}function b(t){var e={valType:\"number\",min:0,editType:\"ticks\"};return t||(e.dflt=1),e}var w={valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},T={valType:\"color\",dflt:i.lightLine,editType:\"ticks\"};function k(t){var e={valType:\"number\",min:0,editType:\"ticks\"};return t||(e.dflt=1),e}var A=o({},a,{editType:\"ticks\"}),M={valType:\"boolean\",editType:\"ticks\"};t.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),standoff:{valType:\"number\",min:0,editType:\"ticks\"},editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\",\"min reversed\",\"max reversed\",\"min\",\"max\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},autorangeoptions:{minallowed:{valType:\"any\",editType:\"plot\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},maxallowed:{valType:\"any\",editType:\"plot\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},clipmin:{valType:\"any\",editType:\"plot\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},clipmax:{valType:\"any\",editType:\"plot\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},include:{valType:\"any\",arrayOk:!0,editType:\"plot\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},editType:\"plot\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},minallowed:{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},maxallowed:{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},insiderange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},scaleanchor:{valType:\"enumerated\",values:[u.idRegex.x.toString(),u.idRegex.y.toString(),!1],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[u.idRegex.x.toString(),u.idRegex.y.toString()],editType:\"calc\"},rangebreaks:s(\"rangebreak\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},bounds:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},pattern:{valType:\"enumerated\",values:[f,h,\"\"],editType:\"calc\"},values:{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"any\",editType:\"calc\"}},dvalue:{valType:\"number\",editType:\"calc\",min:0,dflt:c},editType:\"calc\"}),tickmode:d,nticks:m(),tick0:g,dtick:y,ticklabelstep:{valType:\"integer\",min:1,dflt:1,editType:\"ticks\"},tickvals:v,ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:x,tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},ticklabelmode:{valType:\"enumerated\",values:[\"instant\",\"period\"],dflt:\"instant\",editType:\"ticks\"},ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside left\",\"inside left\",\"outside right\",\"inside right\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\",editType:\"calc\"},ticklabeloverflow:{valType:\"enumerated\",values:[\"allow\",\"hide past div\",\"hide past domain\"],editType:\"calc\"},ticklabelshift:{valType:\"integer\",dflt:0,editType:\"ticks\"},ticklabelstandoff:{valType:\"integer\",dflt:0,editType:\"ticks\"},ticklabelindex:{valType:\"integer\",arrayOk:!0,editType:\"calc\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:_(),tickwidth:b(),tickcolor:w,showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},labelalias:{valType:\"any\",dflt:!1,editType:\"ticks\"},automargin:{valType:\"flaglist\",flags:[\"height\",\"width\",\"left\",\"right\",\"top\",\"bottom\"],extras:[!0,!1],dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\",\"hovered data\"],dflt:\"hovered data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},autotickangles:{valType:\"info_array\",freeLength:!0,items:{valType:\"angle\"},dflt:[0,30,90],editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\",description:l(\"tick label\")},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\",description:l(\"hover text\")},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:M,gridcolor:T,gridwidth:k(),griddash:A,zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",u.idRegex.x.toString(),u.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",u.idRegex.x.toString(),u.idRegex.y.toString()],editType:\"plot\"},minor:{tickmode:p,nticks:m(\"minor\"),tick0:g,dtick:y,tickvals:v,ticks:x,ticklen:_(\"minor\"),tickwidth:b(\"minor\"),tickcolor:w,gridcolor:T,gridwidth:k(\"minor\"),griddash:A,showgrid:M,editType:\"ticks\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},autoshift:{valType:\"boolean\",dflt:!1,editType:\"plot\"},shift:{valType:\"number\",editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"geometric mean ascending\",\"geometric mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},74098:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(36040).isUnifiedHover,o=r(45265),s=r(78032),l=r(6704),c=r(25829),u=r(4392),h=r(97655),f=r(84391),p=r(40957),d=r(5975),m=d.id2name,g=d.name2id,y=r(54826).AX_ID_PATTERN,v=r(33626),x=v.traceIs,_=v.getComponentMethod;function b(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}t.exports=function(t,e,r){var v,w,T=e.autotypenumbers,k={},A={},M={},S={},E={},C={},L={},I={},P={},z={};for(v=0;v<r.length;v++){var O=r[v];if(x(O,\"cartesian\")||x(O,\"gl2d\")){var D,R;if(O.xaxis)D=m(O.xaxis),b(k,D,O);else if(O.xaxes)for(w=0;w<O.xaxes.length;w++)b(k,m(O.xaxes[w]),O);if(O.yaxis)R=m(O.yaxis),b(k,R,O);else if(O.yaxes)for(w=0;w<O.yaxes.length;w++)b(k,m(O.yaxes[w]),O);\"funnel\"===O.type?\"h\"===O.orientation?(D&&(A[D]=!0),R&&(L[R]=!0)):R&&(M[R]=!0):\"image\"===O.type?(R&&(I[R]=!0),D&&(I[D]=!0)):(R&&(E[R]=!0,C[R]=!0),x(O,\"carpet\")&&(\"carpet\"!==O.type||O._cheater)||D&&(S[D]=!0)),\"carpet\"===O.type&&O._cheater&&D&&(A[D]=!0),x(O,\"2dMap\")&&(P[D]=!0,P[R]=!0),x(O,\"oriented\")&&(z[\"h\"===O.orientation?R:D]=!0)}}var F=e._subplots,B=F.xaxis,N=F.yaxis,j=n.simpleMap(B,m),U=n.simpleMap(N,m),V=j.concat(U),q=i.background;B.length&&N.length&&(q=n.coerce(t,e,l,\"plot_bgcolor\"));var H,G,Z,W,Y,X=i.combine(q,e.paper_bgcolor);function $(){var t=k[H]||[];Y._traceIndices=t.map((function(t){return t._expandedIndex})),Y._annIndices=[],Y._shapeIndices=[],Y._selectionIndices=[],Y._imgIndices=[],Y._subplotsWith=[],Y._counterAxes=[],Y._name=Y._attr=H,Y._id=G}function J(t,e){return n.coerce(W,Y,c,t,e)}function K(t,e){return n.coerce2(W,Y,c,t,e)}function Q(t){return\"x\"===t?N:B}function tt(e,r){for(var n=\"x\"===e?j:U,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(g(o))}return i}var et={x:Q(\"x\"),y:Q(\"y\")},rt=et.x.concat(et.y),nt={},it=[];function at(){var t=W.matches;y.test(t)&&-1===rt.indexOf(t)&&(nt[t]=W.type,it=Object.keys(nt))}var ot=o(t,e),st=a(ot);for(v=0;v<V.length;v++){H=V[v],G=g(H),Z=H.charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],Y=s.newContainer(e,H,Z+\"axis\"),$();var lt=\"x\"===Z&&!S[H]&&A[H]||\"y\"===Z&&!E[H]&&M[H],ct=\"y\"===Z&&(!C[H]&&L[H]||I[H]),ut={hasMinor:!0,letter:Z,font:e.font,outerTicks:P[H],showGrid:!z[H],data:k[H]||[],bgColor:X,calendar:e.calendar,automargin:!0,visibleDflt:lt,reverseDflt:ct,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Z]||{})[G],noAutotickangles:\"y\"===Z};J(\"uirevision\",e.uirevision),u(W,Y,J,ut),h(W,Y,J,ut,e);var ht=st&&Z===ot.charAt(0),ft=K(\"spikecolor\",st?Y.color:void 0),pt=K(\"spikethickness\",st?1.5:void 0),dt=K(\"spikedash\",st?\"dot\":void 0),mt=K(\"spikemode\",st?\"across\":void 0),gt=K(\"spikesnap\");J(\"showspikes\",!!(ht||ft||pt||dt||mt||gt))||(delete Y.spikecolor,delete Y.spikethickness,delete Y.spikedash,delete Y.spikemode,delete Y.spikesnap);var yt=m(W.overlaying),vt=[0,1];if(void 0!==e[yt]){var xt=m(e[yt].anchor);void 0!==e[xt]&&(vt=e[xt].domain)}p(W,Y,J,{letter:Z,counterAxes:et[Z],overlayableAxes:tt(Z,H),grid:e.grid,overlayingDomain:vt}),J(\"title.standoff\"),at(),Y._input=W}for(v=0;v<it.length;){G=it[v++],Z=(H=m(G)).charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],Y=s.newContainer(e,H,Z+\"axis\"),$();var _t={letter:Z,font:e.font,outerTicks:P[H],showGrid:!z[H],data:[],bgColor:X,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Z]||{})[G]};J(\"uirevision\",e.uirevision),Y.type=nt[G]||\"linear\",h(W,Y,J,_t,e),p(W,Y,J,{letter:Z,counterAxes:et[Z],overlayableAxes:tt(Z,H),grid:e.grid}),J(\"fixedrange\"),at(),Y._input=W}var bt=_(\"rangeslider\",\"handleDefaults\"),wt=_(\"rangeselector\",\"handleDefaults\");for(v=0;v<j.length;v++)H=j[v],W=t[H],Y=e[H],bt(t,e,H),\"date\"===Y.type&&wt(W,Y,e,U,Y.calendar),J(\"fixedrange\");for(v=0;v<U.length;v++){H=U[v],W=t[H],Y=e[H];var Tt=e[m(Y.anchor)];J(\"fixedrange\",_(\"rangeslider\",\"isVisible\")(Tt))}f.handleDefaults(t,e,{axIds:rt.concat(it).sort(d.idSort),axHasImage:I})}},97405:function(t,e,r){\"use strict\";var n=r(65657).mix,i=r(10229),a=r(34809);t.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i.lightFraction).toRgbString()),f=l(\"gridwidth\"),p=l(\"griddash\");if(r(\"showgrid\",o.showGrid||!!h||!!f||!!p)||(delete e.gridcolor,delete e.gridwidth,delete e.griddash),o.hasMinor){var d=l(\"minor.gridcolor\",n(e.gridcolor,o.bgColor,67).toRgbString()),m=l(\"minor.gridwidth\",e.gridwidth||1),g=l(\"minor.griddash\",e.griddash||\"solid\");r(\"minor.showgrid\",!!d||!!m||!!g)||(delete e.minor.gridcolor,delete e.minor.gridwidth,delete e.minor.griddash)}if(!o.noZeroLine){var y=l(\"zerolinecolor\",s),v=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!y||!!v)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},40957:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809);t.exports=function(t,e,r,a){var o,s,l,c,u,h,f=a.counterAxes||[],p=a.overlayableAxes||[],d=a.letter,m=a.grid,g=a.overlayingDomain;m&&(s=m._domains[d][m._axisMap[e._id]],o=m._anchors[e._id],s&&(l=m[d+\"side\"].split(\" \")[0],c=m.domain[d][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":f[0]||\"free\"),l=l||(\"x\"===d?\"bottom\":\"left\"),c=c||0,u=0,h=!1;var y=i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(f),dflt:o}},\"anchor\"),v=i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===d?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");\"free\"===y&&(\"y\"===d&&(r(\"autoshift\")&&(c=\"left\"===v?g[0]:g[1],h=!e.automargin||e.automargin,u=\"left\"===v?-3:3),r(\"shift\",u)),r(\"position\",c)),r(\"automargin\",h);var x=!1;if(p.length&&(x=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(p),dflt:!1}},\"overlaying\")),!x){var _=r(\"domain\",s);_[0]>_[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s),\"sync\"===e.tickmode&&(e.tickmode=\"auto\")}return r(\"layer\"),e}},54616:function(t,e,r){\"use strict\";var n=r(87703);t.exports=function(t,e,r,i,a){a||(a={});var o=a.tickSuffixDflt,s=n(t);r(\"tickprefix\")&&r(\"showtickprefix\",s),r(\"ticksuffix\",o)&&r(\"showticksuffix\",s)}},90259:function(t,e,r){\"use strict\";var n=r(75511);t.exports=function(t,e,r,i){var a=e._template||{},o=e.type||a.type||\"-\";r(\"minallowed\"),r(\"maxallowed\");var s,l=r(\"range\");l||i.noInsiderange||\"log\"===o||(!(s=r(\"insiderange\"))||null!==s[0]&&null!==s[1]||(e.insiderange=!1,s=void 0),s&&(l=r(\"range\",s)));var c,u=e.getAutorangeDflt(l,i),h=r(\"autorange\",u);!l||(null!==l[0]||null!==l[1])&&(null!==l[0]&&null!==l[1]||\"reversed\"!==h&&!0!==h)&&(null===l[0]||\"min\"!==h&&\"max reversed\"!==h)&&(null===l[1]||\"max\"!==h&&\"min reversed\"!==h)||(l=void 0,delete e.range,e.autorange=!0,c=!0),c||(h=r(\"autorange\",u=e.getAutorangeDflt(l,i))),h&&(n(r,h,l),\"linear\"!==o&&\"-\"!==o||r(\"rangemode\")),e.cleanRange()}},67611:function(t,e,r){\"use strict\";var n=r(4530).FROM_BL;t.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)],t.setScale()}},19091:function(t,e,r){\"use strict\";var n=r(45568),i=r(42696).aL,a=r(34809),o=a.numberFormat,s=r(10721),l=a.cleanNumber,c=a.ms2DateTime,u=a.dateTime2ms,h=a.ensureNumber,f=a.isArrayOrTypedArray,p=r(63821),d=p.FP_SAFE,m=p.BADNUM,g=p.LOG_CLIP,y=p.ONEWEEK,v=p.ONEDAY,x=p.ONEHOUR,_=p.ONEMIN,b=p.ONESEC,w=r(5975),T=r(54826),k=T.HOUR_PATTERN,A=T.WEEKDAY_PATTERN;function M(t){return Math.pow(10,t)}function S(t){return null!=t}t.exports=function(t,e){e=e||{};var r=t._id||\"x\",p=r.charAt(0);function E(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*g*Math.abs(n-i))}return m}function C(e,r,n,i){if((i||{}).msUTC&&s(e))return+e;var o=u(e,n||t.calendar);if(o===m){if(!s(e))return m;e=+e;var l=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-l/10);o=u(new Date(c))+l/10}return o}function L(e,r,n){return c(e,r,n||t.calendar)}function I(e){return t._categories[Math.round(e)]}function P(e){if(S(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return m}function z(e){if(t._categoriesMap)return t._categoriesMap[e]}function O(t){var e=z(t);return void 0!==e?e:s(t)?+t:void 0}function D(t){return s(t)?+t:z(t)}function R(t,e,r){return n.round(r+e*t,2)}function F(t,e,r){return(t-r)/e}var B=function(e){return s(e)?R(e,t._m,t._b):m},N=function(e){return F(e,t._m,t._b)};if(t.rangebreaks){var j=\"y\"===p;B=function(e){if(!s(e))return m;var r=t._rangebreaks.length;if(!r)return R(e,t._m,t._b);var n=j;t.range[0]>t.range[1]&&(n=!n);for(var i=n?-1:1,a=i*e,o=0,l=0;l<r;l++){var c=i*t._rangebreaks[l].min,u=i*t._rangebreaks[l].max;if(a<c)break;if(!(a>u)){o=a<(c+u)/2?l:l+1;break}o=l+1}var h=t._B[o]||0;return isFinite(h)?R(e,t._m2,h):0},N=function(e){var r=t._rangebreaks.length;if(!r)return F(e,t._m,t._b);for(var n=0,i=0;i<r&&!(e<t._rangebreaks[i].pmin);i++)e>t._rangebreaks[i].pmax&&(n=i+1);return F(e,t._m2,t._B[n])}}t.c2l=\"log\"===t.type?E:h,t.l2c=\"log\"===t.type?M:h,t.l2p=B,t.p2l=N,t.c2p=\"log\"===t.type?function(t,e){return B(E(t,e))}:B,t.p2c=\"log\"===t.type?function(t){return M(N(t))}:N,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=l,t.c2d=t.c2r=t.l2d=t.l2r=h,t.d2p=t.r2p=function(e){return t.l2p(l(e))},t.p2d=t.p2r=N,t.cleanPos=h):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return E(l(t),e)},t.r2d=t.r2c=function(t){return M(l(t))},t.d2c=t.r2l=l,t.c2d=t.l2r=h,t.c2r=E,t.l2d=M,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return M(N(t))},t.r2p=function(e){return t.l2p(l(e))},t.p2r=N,t.cleanPos=h):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=C,t.c2d=t.c2r=t.l2d=t.l2r=L,t.d2p=t.r2p=function(e,r,n){return t.l2p(C(e,0,n))},t.p2d=t.p2r=function(t,e,r){return L(N(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,m,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=P,t.r2d=t.c2d=t.l2d=I,t.d2r=t.d2l_noadd=O,t.r2c=function(e){var r=D(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=h,t.r2l=D,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return I(N(t))},t.r2p=t.d2p,t.p2r=N,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:h(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=I,t.d2r=t.d2l_noadd=O,t.r2c=function(e){var r=O(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=z,t.l2r=t.c2r=h,t.r2l=O,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return I(N(t))},t.r2p=t.d2p,t.p2r=N,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:h(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=t._matchGroup;if(l&&0===t._categories.length)for(var c in l)if(c!==r){var u=e[w.id2name(c)];s=s.concat(u._traceIndices)}var h=[[0,{}],[0,{}]],d=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(p in m){var g=m[p],y=m._length||a.minRowLength(g);if(f(g[0])&&f(g[1]))for(o=0;o<y;o++){var v=g[0][o],x=g[1][o];S(v)&&S(x)&&(d.push([v,x]),v in h[0][1]||(h[0][1][v]=h[0][0]++),x in h[1][1]||(h[1][1][x]=h[1][0]++))}}}for(d.sort((function(t,e){var r=h[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=h[1][1];return i[t[1]]-i[e[1]]})),i=0;i<d.length;i++)P(d[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.limitRange=function(e){var r=t.minallowed,n=t.maxallowed;if(void 0!==r||void 0!==n){e||(e=\"range\");var i=a.nestedProperty(t,e).get(),o=a.simpleMap(i,t.r2l),s=o[1]<o[0];s&&o.reverse();var l=a.simpleMap([r,n],t.r2l);if(void 0!==r&&o[0]<l[0]&&(i[s?1:0]=r),void 0!==n&&o[1]>l[1]&&(i[s?0:1]=n),i[0]===i[1]){var c=t.l2r(r),u=t.l2r(n);if(void 0!==r){var h=c+1;void 0!==n&&(h=Math.min(h,u)),i[s?1:0]=h}if(void 0!==n){var f=u+1;void 0!==r&&(f=Math.max(f,c)),i[s?0:1]=f}}}},t.cleanRange=function(e,r){t._cleanRange(e,r),t.limitRange(e)},t._cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,i,o=a.nestedProperty(t,e).get();if(i=(i=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===p?T.DFLTRANGEY:\"realaxis\"===t._name?[0,1]:r.dfltRange||T.DFLTRANGEX).slice(),\"tozero\"!==t.rangemode&&\"nonnegative\"!==t.rangemode||(i[0]=0),o&&2===o.length){var l=null===o[0],c=null===o[1];for(\"date\"!==t.type||t.autorange||(o[0]=a.cleanDate(o[0],m,t.calendar),o[1]=a.cleanDate(o[1],m,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(o[n],t.calendar)){t[e]=i;break}if(t.r2l(o[0])===t.r2l(o[1])){var u=a.constrain(t.r2l(o[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);o[0]=t.l2r(u-1e3),o[1]=t.l2r(u+1e3);break}}else{if(!s(o[n])){if(l||c||!s(o[1-n])){t[e]=i;break}o[n]=o[1-n]*(n?10:.1)}if(o[n]<-d?o[n]=-d:o[n]>d&&(o[n]=d),o[0]===o[1]){var h=Math.max(1,Math.abs(1e-6*o[0]));o[0]-=h,o[1]+=h}}}else a.nestedProperty(t,e).set(i)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=w.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s,l,c=t.r2l(t[a][0],o),u=t.r2l(t[a][1],o),h=\"y\"===p;if(h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var f=h;c>u&&(f=!f),f&&t._rangebreaks.reverse();var d=f?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(h?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=B(l.min),l.pmax=B(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.maskBreaks=function(e){var r,n,i,o,s,c=t.rangebreaks||[];c._cachedPatterns||(c._cachedPatterns=c.map((function(e){return e.enabled&&e.bounds?a.simpleMap(e.bounds,e.pattern?l:t.d2c):null}))),c._cachedValues||(c._cachedValues=c.map((function(e){return e.enabled&&e.values?a.simpleMap(e.values,t.d2c).sort(a.sorterAsc):null})));for(var u=0;u<c.length;u++){var h=c[u];if(h.enabled)if(h.bounds){var f=h.pattern;switch(n=(r=c._cachedPatterns[u])[0],i=r[1],f){case A:o=(s=new Date(e)).getUTCDay(),n>i&&(i+=7,o<n&&(o+=7));break;case k:o=(s=new Date(e)).getUTCHours()+(s.getUTCMinutes()/60+s.getUTCSeconds()/3600+s.getUTCMilliseconds()/36e5),n>i&&(i+=24,o<n&&(o+=24));break;case\"\":o=e}if(o>=n&&o<i)return m}else for(var p=c._cachedValues[u],d=0;d<p.length;d++)if(i=(n=p[d])+h.dvalue,e>=n&&e<i)return m}return e},t.locateBreaks=function(e,r){var n,i,o,s,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort((function(t,e){return t.pattern===A&&e.pattern===k?-1:e.pattern===A&&t.pattern===k?1:0})),h=function(t,n){if((t=a.constrain(t,e,r))!==(n=a.constrain(n,e,r))){for(var i=!0,o=0;o<c.length;o++){var s=c[o];t<s.max&&n>=s.min&&(t<s.min&&(s.min=t),n>s.max&&(s.max=n),i=!1)}i&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var f=u[n];if(f.enabled)if(f.bounds){var p=e,d=r;f.pattern&&(p=Math.floor(p)),o=(i=a.simpleMap(f.bounds,f.pattern?l:t.r2l))[0],s=i[1];var m,g,w=new Date(p);switch(f.pattern){case A:g=y,m=(s-o+(s<o?7:0))*v,p+=o*v-(w.getUTCDay()*v+w.getUTCHours()*x+w.getUTCMinutes()*_+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;case k:g=v,m=(s-o+(s<o?24:0))*x,p+=o*x-(w.getUTCHours()*x+w.getUTCMinutes()*_+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;default:p=Math.min(i[0],i[1]),m=g=(d=Math.max(i[0],i[1]))-p}for(var T=p;T<d;T+=g)h(T,T+m)}else for(var M=a.simpleMap(f.values,t.d2c),S=0;S<M.length;S++)h(o=M[S],s=o+f.dvalue)}return c.sort((function(t,e){return t.min-e.min})),c},t.makeCalcdata=function(e,r,n){var i,o,s,l,c=t.type,u=\"date\"===c&&e[r+\"calendar\"];if(r in e){if(i=e[r],l=e._length||a.minRowLength(i),a.isTypedArray(i)&&(\"linear\"===c||\"log\"===c)){if(l===i.length)return i;if(i.subarray)return i.subarray(0,l)}if(\"multicategory\"===c)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=z([i,a])}return r}(i,l);for(o=new Array(l),s=0;s<l;s++)o[s]=t.d2c(i[s],0,u,n)}else{var h=r+\"0\"in e?t.d2c(e[r+\"0\"],0,u):0,f=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(i=e[{x:\"y\",y:\"x\"}[r]],l=e._length||i.length,o=new Array(l),s=0;s<l;s++)o[s]=h+s*f}if(t.rangebreaks)for(s=0;s<l;s++)o[s]=t.maskBreaks(o[s]);return o},t.isValidRange=function(e,r){return Array.isArray(e)&&2===e.length&&(r&&null===e[0]||s(t.r2l(e[0])))&&(r&&null===e[1]||s(t.r2l(e[1])))},t.getAutorangeDflt=function(e,r){var n=!t.isValidRange(e,\"nullOk\");return n&&r&&r.reverseDflt?n=\"reversed\":e&&(null===e[0]&&null===e[1]?n=!0:null===e[0]&&null!==e[1]?n=\"min\":null!==e[0]&&null===e[1]&&(n=\"max\")),n},t.isReversed=function(){var e=t.autorange;return\"reversed\"===e||\"min reversed\"===e||\"max reversed\"===e},t.isPtWithinRange=function(e,r){var n=t.c2l(e[p],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t._emptyCategories=function(){t._categories=[],t._categoriesMap={}},t.clearCalc=function(){var r=t._matchGroup;if(r){var n=null,i=null;for(var a in r){var o=e[w.id2name(a)];if(o._categories){n=o._categories,i=o._categoriesMap;break}}n&&i?(t._categories=n,t._categoriesMap=i):t._emptyCategories()}else t._emptyCategories();if(t._initialCategories)for(var s=0;s<t._initialCategories.length;s++)P(t._initialCategories[s])},t.sortByInitialCategories=function(){var n=[];if(t._emptyCategories(),t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)P(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[w.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var U=e._d3locale;\"date\"===t.type&&(t._dateFormat=U?U.timeFormat:i,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=U?U.numberFormat:o,delete t._minDtick,delete t._forceTick0}},87703:function(t){\"use strict\";t.exports=function(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter((function(e){return void 0!==t[e]}));if(e.every((function(r){return t[r]===t[e[0]]}))||1===e.length)return t[e[0]]}},12036:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766).contrast,a=r(25829),o=r(87703),s=r(59008);function l(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}t.exports=function(t,e,r,c,u){u||(u={});var h=r(\"labelalias\");n.isPlainObject(h)||delete e.labelalias;var f=o(t);if(r(\"showticklabels\")){u.noTicklabelshift||r(\"ticklabelshift\"),u.noTicklabelstandoff||r(\"ticklabelstandoff\");var p=u.font||{},d=e.color,m=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")?i(u.bgColor):d&&d!==a.color.dflt?d:p.color;if(n.coerceFont(r,\"tickfont\",p,{overrideDflt:{color:m}}),u.noTicklabelstep||\"multicategory\"===c||\"log\"===c||r(\"ticklabelstep\"),!u.noAng){var g=r(\"tickangle\");u.noAutotickangles||\"auto\"!==g||r(\"autotickangles\")}if(\"category\"!==c){var y=r(\"tickformat\");s(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:l}),e.tickformatstops.length||delete e.tickformatstops,u.noExp||y||\"date\"===c||(r(\"showexponent\",f),r(\"exponentformat\"),r(\"minexponent\"),r(\"separatethousands\"))}}}},87433:function(t,e,r){\"use strict\";var n=r(34809),i=r(25829);t.exports=function(t,e,r,a){var o=a.isMinor,s=o?t.minor||{}:t,l=o?e.minor:e,c=o?i.minor:i,u=o?\"minor.\":\"\",h=n.coerce2(s,l,c,\"ticklen\",o?.6*(e.ticklen||5):void 0),f=n.coerce2(s,l,c,\"tickwidth\",o?e.tickwidth||1:void 0),p=n.coerce2(s,l,c,\"tickcolor\",(o?e.tickcolor:void 0)||l.color);r(u+\"ticks\",!o&&a.outerTicks||h||f||p?\"outside\":\"\")||(delete l.ticklen,delete l.tickwidth,delete l.tickcolor)}},22777:function(t,e,r){\"use strict\";var n=r(68599),i=r(34809).isArrayOrTypedArray,a=r(87800).isTypedArraySpec,o=r(87800).decodeTypedArraySpec;t.exports=function(t,e,r,s,l){l||(l={});var c=l.isMinor,u=c?t.minor||{}:t,h=c?e.minor:e,f=c?\"minor.\":\"\";function p(t){var e=u[t];return a(e)&&(e=o(e)),void 0!==e?e:(h._template||{})[t]}var d=p(\"tick0\"),m=p(\"dtick\"),g=p(\"tickvals\"),y=r(f+\"tickmode\",i(g)?\"array\":m?\"linear\":\"auto\");if(\"auto\"===y||\"sync\"===y)r(f+\"nticks\");else if(\"linear\"===y){var v=h.dtick=n.dtick(m,s);h.tick0=n.tick0(d,s,e.calendar,v)}else\"multicategory\"!==s&&(void 0===r(f+\"tickvals\")?h.tickmode=\"auto\":c||r(\"ticktext\"))}},84982:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(34809),o=r(62203),s=r(29714);t.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,h,f,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push((function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr0&&(r[o._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[s._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)m(e[t].plotinfo)}))}()})),h=Date.now(),p=window.requestAnimationFrame((function n(){f=Date.now();for(var a=Math.min(1,(f-h)/r.duration),o=d(a),s=0;s<e.length;s++)g(e[s],o);f-h>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr1&&(r[o._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[s._name+\".range\"]=a.yr1.slice())}u&&u(),i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)m(e[t].plotinfo)}))}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)})),Promise.resolve()}function m(t){var e=t.xaxis,r=t.yaxis;c._defs.select(\"#\"+t.clipId+\"> rect\").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(o.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,l=n.yaxis,c=i._length,u=l._length,h=!!e.xr1,f=!!e.yr1,p=[];if(h){var d=a.simpleMap(e.xr0,i.r2l),m=a.simpleMap(e.xr1,i.r2l),g=d[1]-d[0],y=m[1]-m[0];p[0]=(d[0]*(1-r)+r*m[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*y/g),i.range[0]=i.l2r(d[0]*(1-r)+r*m[0]),i.range[1]=i.l2r(d[1]*(1-r)+r*m[1])}else p[0]=0,p[2]=c;if(f){var v=a.simpleMap(e.yr0,l.r2l),x=a.simpleMap(e.yr1,l.r2l),_=v[1]-v[0],b=x[1]-x[0];p[1]=(v[1]*(1-r)+r*x[1]-v[1])/(v[0]-v[1])*u,p[3]=u*(1-r+r*b/_),l.range[0]=i.l2r(v[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(v[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,i,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[i._id,l._id]);var w=h?c/p[2]:1,T=f?u/p[3]:1,k=h?p[0]:0,A=f?p[1]:0,M=h?p[0]/p[2]*c:0,S=f?p[1]/p[3]*u:0,E=i._offset-M,C=l._offset-S;n.clipRect.call(o.setTranslate,k,A).call(o.setScale,1/w,1/T),n.plot.call(o.setTranslate,E,C).call(o.setScale,w,T),o.setPointGroupScale(n.zoomScalePts,1/w,1/T),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/T)}s.redrawComponents(t)}},4392:function(t,e,r){\"use strict\";var n=r(33626).traceIs,i=r(9666);function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}t.exports=function(t,e,r,s){r(\"autotypenumbers\",s.autotypenumbersDflt),\"-\"===r(\"type\",(s.splomStash||{}).type)&&(function(t,e){if(\"-\"===t.type){var r,s=t._id,l=s.charAt(0);-1!==s.indexOf(\"scene\")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,s,l);if(c)if(\"histogram\"!==c.type||l!=={v:\"y\",h:\"x\"}[c.orientation||\"v\"]){var u=l+\"calendar\",h=c[u],f={noMultiCategory:!n(c,\"cartesian\")||n(c,\"noMultiCategory\")};if(\"box\"===c.type&&c._hasPreCompStats&&l==={h:\"x\",v:\"y\"}[c.orientation||\"v\"]&&(f.noMultiCategory=!0),f.autotypenumbers=t.autotypenumbers,o(c,l)){var p=a(c),d=[];for(r=0;r<e.length;r++){var m=e[r];n(m,\"box-violin\")&&(m[l+\"axis\"]||l)===s&&(void 0!==m[p]?d.push(m[p][0]):void 0!==m.name?d.push(m.name):d.push(\"text\"),m[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===c.type){var g=c.dimensions[c._axesDim[s]];g.visible&&(t.type=i(g.values,h,f))}else t.type=i(c[l]||[c[l+\"0\"]],h,f)}else t.type=\"linear\"}}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},90251:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809);function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,(function(t,e,n){r.push({type:\"layout\",prop:t,value:n})}),\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,(function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})}),\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach((function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}}))}e.manageCommandObserver=function(t,r,n,o){var s={},l=!0;r&&r._commandObserver&&(s=r._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=e.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(r&&r._commandObserver){if(c)return s;if(r._commandObserver.remove)return r._commandObserver.remove(),r._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},r&&(r._commandObserver=s),s},e.hasSimpleAPICommandBindings=function(t,r,n){var i,a,o=r.length;for(i=0;i<o;i++){var s,l=r[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=e.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},e.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch((function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)}))},e.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(0,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(0,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},13792:function(t,e,r){\"use strict\";var n=r(93049).extendFlat;e.u=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},e.N=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}var c=r(\"domain.x\",i),u=r(\"domain.y\",a);c[0]<c[1]||(t.domain.x=i.slice()),u[0]<u[1]||(t.domain.y=a.slice())}},80337:function(t){\"use strict\";t.exports=function(t){var e=t.variantValues,r=t.editType,n=t.colorEditType;void 0===n&&(n=r);var i={editType:r,valType:\"integer\",min:1,max:1e3,extras:[\"normal\",\"bold\"],dflt:\"normal\"};t.noNumericWeightValues&&(i.valType=\"enumerated\",i.values=i.extras,i.extras=void 0,i.min=void 0,i.max=void 0);var a={family:{valType:\"string\",noBlank:!0,strict:!0,editType:r},size:{valType:\"number\",min:1,editType:r},color:{valType:\"color\",editType:n},weight:i,style:{editType:r,valType:\"enumerated\",values:[\"normal\",\"italic\"],dflt:\"normal\"},variant:t.noFontVariant?void 0:{editType:r,valType:\"enumerated\",values:e||[\"normal\",\"small-caps\",\"all-small-caps\",\"all-petite-caps\",\"petite-caps\",\"unicase\"],dflt:\"normal\"},textcase:t.noFontTextcase?void 0:{editType:r,valType:\"enumerated\",values:[\"normal\",\"word caps\",\"upper\",\"lower\"],dflt:\"normal\"},lineposition:t.noFontLineposition?void 0:{editType:r,valType:\"flaglist\",flags:[\"under\",\"over\",\"through\"],extras:[\"none\"],dflt:\"none\"},shadow:t.noFontShadow?void 0:{editType:r,valType:\"string\",dflt:t.autoShadowDflt?\"auto\":\"none\"},editType:r};return t.autoSize&&(a.size.dflt=\"auto\"),t.autoColor&&(a.color.dflt=\"auto\"),t.arrayOk&&(a.family.arrayOk=!0,a.weight.arrayOk=!0,a.style.arrayOk=!0,t.noFontVariant||(a.variant.arrayOk=!0),t.noFontTextcase||(a.textcase.arrayOk=!0),t.noFontLineposition||(a.lineposition.arrayOk=!0),t.noFontShadow||(a.shadow.arrayOk=!0),a.size.arrayOk=!0,a.color.arrayOk=!0),a}},58935:function(t){\"use strict\";t.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},74285:function(t,e){\"use strict\";e.projNames={airy:\"airy\",aitoff:\"aitoff\",\"albers usa\":\"albersUsa\",albers:\"albers\",august:\"august\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",baker:\"baker\",bertin1953:\"bertin1953\",boggs:\"boggs\",bonne:\"bonne\",bottomley:\"bottomley\",bromley:\"bromley\",collignon:\"collignon\",\"conic conformal\":\"conicConformal\",\"conic equal area\":\"conicEqualArea\",\"conic equidistant\":\"conicEquidistant\",craig:\"craig\",craster:\"craster\",\"cylindrical equal area\":\"cylindricalEqualArea\",\"cylindrical stereographic\":\"cylindricalStereographic\",eckert1:\"eckert1\",eckert2:\"eckert2\",eckert3:\"eckert3\",eckert4:\"eckert4\",eckert5:\"eckert5\",eckert6:\"eckert6\",eisenlohr:\"eisenlohr\",\"equal earth\":\"equalEarth\",equirectangular:\"equirectangular\",fahey:\"fahey\",\"foucaut sinusoidal\":\"foucautSinusoidal\",foucaut:\"foucaut\",ginzburg4:\"ginzburg4\",ginzburg5:\"ginzburg5\",ginzburg6:\"ginzburg6\",ginzburg8:\"ginzburg8\",ginzburg9:\"ginzburg9\",gnomonic:\"gnomonic\",\"gringorten quincuncial\":\"gringortenQuincuncial\",gringorten:\"gringorten\",guyou:\"guyou\",hammer:\"hammer\",hill:\"hill\",homolosine:\"homolosine\",hufnagel:\"hufnagel\",hyperelliptical:\"hyperelliptical\",kavrayskiy7:\"kavrayskiy7\",lagrange:\"lagrange\",larrivee:\"larrivee\",laskowski:\"laskowski\",loximuthal:\"loximuthal\",mercator:\"mercator\",miller:\"miller\",mollweide:\"mollweide\",\"mt flat polar parabolic\":\"mtFlatPolarParabolic\",\"mt flat polar quartic\":\"mtFlatPolarQuartic\",\"mt flat polar sinusoidal\":\"mtFlatPolarSinusoidal\",\"natural earth\":\"naturalEarth\",\"natural earth1\":\"naturalEarth1\",\"natural earth2\":\"naturalEarth2\",\"nell hammer\":\"nellHammer\",nicolosi:\"nicolosi\",orthographic:\"orthographic\",patterson:\"patterson\",\"peirce quincuncial\":\"peirceQuincuncial\",polyconic:\"polyconic\",\"rectangular polyconic\":\"rectangularPolyconic\",robinson:\"robinson\",satellite:\"satellite\",\"sinu mollweide\":\"sinuMollweide\",sinusoidal:\"sinusoidal\",stereographic:\"stereographic\",times:\"times\",\"transverse mercator\":\"transverseMercator\",\"van der grinten\":\"vanDerGrinten\",\"van der grinten2\":\"vanDerGrinten2\",\"van der grinten3\":\"vanDerGrinten3\",\"van der grinten4\":\"vanDerGrinten4\",wagner4:\"wagner4\",wagner6:\"wagner6\",wiechel:\"wiechel\",\"winkel tripel\":\"winkel3\",winkel3:\"winkel3\"},e.axesNames=[\"lonaxis\",\"lataxis\"],e.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},e.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},e.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},e.clipPad=.001,e.precision=.1,e.landColor=\"#F0DC82\",e.waterColor=\"#3399FF\",e.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},e.sphereSVG={type:\"Sphere\"},e.fillLayers={ocean:1,land:1,lakes:1},e.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},e.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],e.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],e.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},6493:function(t,e,r){\"use strict\";var n=r(45568),i=r(70884),a=i.geoPath,o=i.geoDistance,s=r(75987),l=r(33626),c=r(34809),u=c.strTranslate,h=r(78766),f=r(62203),p=r(32141),d=r(44122),m=r(29714),g=r(32919).getAutoRange,y=r(14751),v=r(44844).prepSelect,x=r(44844).clearOutline,_=r(44844).selectOnClick,b=r(14309),w=r(74285),T=r(3994),k=r(11577),A=r(48640).N4;function M(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}var S=M.prototype;function E(t,e){var r=w.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}t.exports=function(t){return new M(t)},S.plot=function(t,e,r,n){var i=this;if(n)return i.update(t,e,!0);i._geoCalcData=t,i._fullLayout=e;var a=e[this.id],o=[],s=!1;for(var l in w.layerNameToAdjective)if(\"frame\"!==l&&a[\"show\"+l]){s=!0;break}for(var c=!1,u=0;u<t.length;u++){var h=t[0][0].trace;h._geo=i,h.locationmode&&(s=!0);var f=h.marker;if(f){var p=f.angle,d=f.angleref;(p||\"north\"===d||\"previous\"===d)&&(c=!0)}}if(this._hasMarkerAngles=c,s){var m=k.getTopojsonName(a);null!==i.topojson&&m===i.topojsonName||(i.topojsonName=m,void 0===PlotlyGeoAssets.topojson[i.topojsonName]&&o.push(i.fetchTopojson()))}o=o.concat(T.fetchTraceGeoData(t)),r.push(new Promise((function(r,n){Promise.all(o).then((function(){i.topojson=PlotlyGeoAssets.topojson[i.topojsonName],i.update(t,e),r()})).catch(n)})))},S.fetchTopojson=function(){var t=this,e=k.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise((function(r,i){n.json(e,(function(n,a){if(n)return 404===n.status?i(new Error([\"plotly.js could not find topojson file at\",e+\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):i(new Error([\"unexpected error while fetching topojson file at\",e].join(\" \")));PlotlyGeoAssets.topojson[t.topojsonName]=a,r()}))}))},S.update=function(t,e,r){var n=e[this.id];this.hasChoropleth=!1;for(var i=0;i<t.length;i++){var a=t[i],o=a[0].trace;\"choropleth\"===o.type&&(this.hasChoropleth=!0),!0===o.visible&&o._length>0&&o._module.calcGeoJSON(a,e)}if(!r){if(this.updateProjection(t,e))return;this.viewInitial&&this.scope===n.scope||this.saveViewInitial(n)}this.scope=n.scope,this.updateBaseLayers(e,n),this.updateDims(e,n),this.updateFx(e,n),d.generalUpdatePerTraceModule(this.graphDiv,this,t,n);var s=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=s.selectAll(\".point\"),this.dataPoints.text=s.selectAll(\"text\"),this.dataPaths.line=s.selectAll(\".js-line\");var l=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=l.selectAll(\"path\"),this._render()},S.updateProjection=function(t,e){var r=this.graphDiv,n=e[this.id],l=e._size,u=n.domain,h=n.projection,f=n.lonaxis,p=n.lataxis,d=f._ax,m=p._ax,y=this.projection=function(t){var e=t.projection,r=e.type,n=w.projNames[r];n=\"geo\"+c.titleCase(n);for(var l=(i[n]||s[n])(),u=t._isSatellite?180*Math.acos(1/e.distance)/Math.PI:t._isClipped?w.lonaxisSpan[r]/2:null,h=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],f=function(t){return t?l:[]},p=0;p<h.length;p++){var d=h[p];\"function\"!=typeof l[d]&&(l[d]=f)}return l.isLonLatOverEdges=function(t){if(null===l(t))return!0;if(u){var e=l.rotate();return o(t,[-e[0],-e[1]])>u*Math.PI/180}return!1},l.getPath=function(){return a().projection(l)},l.getBounds=function(t){return l.getPath().bounds(t)},l.precision(w.precision),t._isSatellite&&l.tilt(e.tilt).distance(e.distance),u&&l.clipAngle(u-w.clipPad),l}(n),v=[[l.l+l.w*u.x[0],l.t+l.h*(1-u.y[1])],[l.l+l.w*u.x[1],l.t+l.h*(1-u.y[0])]],x=n.center||{},_=h.rotation||{},b=f.range||[],T=p.range||[];if(n.fitbounds){d._length=v[1][0]-v[0][0],m._length=v[1][1]-v[0][1],d.range=g(r,d),m.range=g(r,m);var k=(d.range[0]+d.range[1])/2,A=(m.range[0]+m.range[1])/2;if(n._isScoped)x={lon:k,lat:A};else if(n._isClipped){x={lon:k,lat:A},_={lon:k,lat:A,roll:_.roll};var M=h.type,S=w.lonaxisSpan[M]/2||180,C=w.lataxisSpan[M]/2||90;b=[k-S,k+S],T=[A-C,A+C]}else x={lon:k,lat:A},_={lon:k,lat:_.lat,roll:_.roll}}y.center([x.lon-_.lon,x.lat-_.lat]).rotate([-_.lon,-_.lat,_.roll]).parallels(h.parallels);var L=E(b,T);y.fitExtent(v,L);var I=this.bounds=y.getBounds(L),P=this.fitScale=y.scale(),z=y.translate();if(n.fitbounds){var O=y.getBounds(E(d.range,m.range)),D=Math.min((I[1][0]-I[0][0])/(O[1][0]-O[0][0]),(I[1][1]-I[0][1])/(O[1][1]-O[0][1]));isFinite(D)?y.scale(D*P):c.warn(\"Something went wrong during\"+this.id+\"fitbounds computations.\")}else y.scale(h.scale*P);var R=this.midPt=[(I[0][0]+I[1][0])/2,(I[0][1]+I[1][1])/2];if(y.translate([z[0]+(R[0]-z[0]),z[1]+(R[1]-z[1])]).clipExtent(I),n._isAlbersUsa){var F=y([x.lon,x.lat]),B=y.translate();y.translate([B[0]-(F[0]-B[0]),B[1]-(F[1]-B[1])])}},S.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,o=r.basePaths;function s(t){return\"lonaxis\"===t||\"lataxis\"===t}function l(t){return Boolean(w.lineLayers[t])}function c(t){return Boolean(w.fillLayers[t])}var u=(this.hasChoropleth?w.layersForChoropleth:w.layers).filter((function(t){return l(t)||c(t)?e[\"show\"+t]:!s(t)||e[t].showgrid})),p=r.framework.selectAll(\".layer\").data(u,String);p.exit().each((function(t){delete a[t],delete o[t],n.select(this).remove()})),p.enter().append(\"g\").attr(\"class\",(function(t){return\"layer \"+t})).each((function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):s(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):l(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):c(t)&&(o[t]=e.append(\"path\").style(\"stroke\",\"none\"))})),p.order(),p.each((function(r){var n=o[r],a=w.layerNameToAdjective[r];\"frame\"===r?n.datum(w.sphereSVG):l(r)||c(r)?n.datum(A(i,i.objects[r])):s(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=w.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};m.setConvert(l,r);var c=m.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var u=c.length,h=new Array(u),f=0;f<u;f++)for(var p=c[f].x,d=h[f]=[],g=i[0];g<i[1]+2.5;g+=2.5)d.push(a(p,g));return{type:\"MultiLineString\",coordinates:h}}(r,e,t)).call(h.stroke,e[r].gridcolor).call(f.dashLine,e[r].griddash,e[r].gridwidth),l(r)?n.call(h.stroke,e[a+\"color\"]).call(f.dashLine,\"\",e[a+\"width\"]):c(r)&&n.call(h.fill,e[a+\"color\"])}))},S.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,o=r[1][0]-i+n,s=r[1][1]-a+n;f.setRect(this.clipRect,i,a,o,s),this.bgRect.call(f.setRect,i,a,o,s).call(h.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=o,this.yaxis._offset=a,this.yaxis._length=s},S.updateFx=function(t,e){var r=this,i=r.graphDiv,a=r.bgRect,o=t.dragmode,s=t.clickmode;if(!r.isStatic){var u={element:r.bgRect.node(),gd:i,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:function(t,e){e.isRect?(t.range={})[r.id]=[h([e.xmin,e.ymin]),h([e.xmax,e.ymax])]:(t.lassoPoints={})[r.id]=e.map(h)}},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(t){2===t&&x(i)}};\"pan\"===o?(a.node().onmousedown=null,a.call(b(r,e)),a.on(\"dblclick.zoom\",(function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];l.call(\"_guiRelayout\",i,e),i.emit(\"plotly_doubleclick\",null)})),i._context._scrollZoom.geo||a.on(\"wheel.zoom\",null)):\"select\"!==o&&\"lasso\"!==o||(a.on(\".zoom\",null),u.prepFn=function(t,e,r){v(t,e,r,u,o)},y.init(u)),a.on(\"mousemove\",(function(){var t=r.projection.invert(c.getPositionFromD3Event());if(!t)return y.unhover(i,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},p.hover(i,n.event,r.id)})),a.on(\"mouseout\",(function(){i._dragging||y.unhover(i,n.event)})),a.on(\"click\",(function(){\"select\"!==o&&\"lasso\"!==o&&(s.indexOf(\"select\")>-1&&_(n.event,i,[r.xaxis],[r.yaxis],r.id,u),s.indexOf(\"event\")>-1&&p.click(i,n.event))}))}function h(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},S.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(f.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},m.setConvert(t.mockAxis,r)},S.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,i=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,\"projection.scale\":n.scale},e=t._isScoped?{\"center.lon\":r.lon,\"center.lat\":r.lat}:t._isClipped?{\"projection.rotation.lon\":i.lon,\"projection.rotation.lat\":i.lat}:{\"center.lon\":r.lon,\"center.lat\":r.lat,\"projection.rotation.lon\":i.lon},c.extendFlat(this.viewInitial,e)},S.render=function(t){this._hasMarkerAngles&&t?this.plot(this._geoCalcData,this._fullLayout,[],!0):this._render()},S._render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?u(r[0],r[1]):null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",(function(t){return r(t.geojson)}));for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},47544:function(t,e,r){\"use strict\";var n=r(4173).fX,i=r(34809).counterRegex,a=r(6493),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},t.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:r(42194),supplyLayoutDefaults:r(31653),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},42194:function(t,e,r){\"use strict\";var n=r(10229),i=r(13792).u,a=r(94850).T,o=r(74285),s=r(13582).overrideAll,l=r(62994),c={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1},griddash:a};(t.exports=s({domain:i({name:\"geo\"},{}),fitbounds:{valType:\"enumerated\",values:[!1,\"locations\",\"geojson\"],dflt:!1,editType:\"plot\"},resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:l(o.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:l(o.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},tilt:{valType:\"number\",dflt:0},distance:{valType:\"number\",min:1.001,dflt:2},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},visible:{valType:\"boolean\",dflt:!0},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:o.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:o.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:o.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:o.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:c,lataxis:c},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},31653:function(t,e,r){\"use strict\";var n=r(34809),i=r(4448),a=r(4173).KO,o=r(74285),s=r(42194),l=o.axesNames;function c(t,e,r,i){var s=a(i.fullData,\"geo\",i.id).map((function(t){return t._expandedIndex})),c=r(\"resolution\"),u=r(\"scope\"),h=o.scopeDefaults[u],f=r(\"projection.type\",h.projType),p=e._isAlbersUsa=\"albers usa\"===f;p&&(u=e.scope=\"usa\");var d=e._isScoped=\"world\"!==u,m=e._isSatellite=\"satellite\"===f,g=e._isConic=-1!==f.indexOf(\"conic\")||\"albers\"===f,y=e._isClipped=!!o.lonaxisSpan[f];if(!1===t.visible){var v=n.extendDeep({},e._template);v.showcoastlines=!1,v.showcountries=!1,v.showframe=!1,v.showlakes=!1,v.showland=!1,v.showocean=!1,v.showrivers=!1,v.showsubunits=!1,v.lonaxis&&(v.lonaxis.showgrid=!1),v.lataxis&&(v.lataxis.showgrid=!1),e._template=v}for(var x=r(\"visible\"),_=0;_<l.length;_++){var b,w=l[_],T=[30,10][_];if(d)b=h[w+\"Range\"];else{var k=o[w+\"Span\"],A=(k[f]||k[\"*\"])/2,M=r(\"projection.rotation.\"+w.substr(0,3),h.projRotate[_]);b=[M-A,M+A]}var S=r(w+\".range\",b);r(w+\".tick0\"),r(w+\".dtick\",T),r(w+\".showgrid\",!!x&&void 0)&&(r(w+\".gridcolor\"),r(w+\".gridwidth\"),r(w+\".griddash\")),e[w]._ax={type:\"linear\",_id:w.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:S.slice(),_m:1,_input:{}}}var E=e.lonaxis.range,C=e.lataxis.range,L=E[0],I=E[1];L>0&&I<0&&(I+=360);var P,z,O,D=(L+I)/2;if(!p){var R=d?h.projRotate:[D,0,0];P=r(\"projection.rotation.lon\",R[0]),r(\"projection.rotation.lat\",R[1]),r(\"projection.rotation.roll\",R[2]),r(\"showcoastlines\",!d&&x)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\",!!x&&void 0)&&r(\"oceancolor\")}p?(z=-96.6,O=38.7):(z=d?D:P,O=(C[0]+C[1])/2),r(\"center.lon\",z),r(\"center.lat\",O),m&&(r(\"projection.tilt\"),r(\"projection.distance\")),g&&r(\"projection.parallels\",h.projParallels||[0,60]),r(\"projection.scale\"),r(\"showland\",!!x&&void 0)&&r(\"landcolor\"),r(\"showlakes\",!!x&&void 0)&&r(\"lakecolor\"),r(\"showrivers\",!!x&&void 0)&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",d&&\"usa\"!==u&&x)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===u||\"north america\"===u&&50===c)&&(r(\"showsubunits\",x),r(\"subunitcolor\"),r(\"subunitwidth\")),d||r(\"showframe\",x)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\"),r(\"fitbounds\")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):y?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}t.exports=function(t,e,r){i(t,e,r,{type:\"geo\",attributes:s,handleDefaults:c,fullData:r,partition:\"y\"})}},14309:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(33626),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),p(\"fitbounds\",!1),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",(function(){n.select(this).style(l)})).on(\"zoom\",(function(){e.scale(n.event.scale).translate(n.event.translate),t.render(!0);var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})})).on(\"zoomend\",(function(){n.select(this).style(c),h(t,e,i)})),r}function p(t,e){var r,i,a,o,s,f,p,d,m,g=u(0,e);function y(t){return e.invert(t)}function v(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return g.on(\"zoomstart\",(function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)})).on(\"zoom\",(function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>2||Math.abs(n[1]-t[1])>2}(r))return g.scale(e.scale()),void g.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),m=!0,t.render(!0);var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})})).on(\"zoomend\",(function(){n.select(this).style(c),m&&h(t,e,v)})),g}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){for(var e=0,r=arguments.length,i=[];++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function y(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",(function(){n.select(this).style(l);var t,c,u,h,y,_,b,w,T,k,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,y=Math.sin(c),_=Math.cos(c),b=Math.sin(u),w=Math.cos(u),T=Math.sin(h),[_*w*(k=Math.cos(h))+y*b*T,y*w*k-_*b*T,_*b*k+y*w*T,_*w*T-y*b*k]);r=m(e,M),d.call(a,\"zoom\",(function(){var t,a,o,l,c,u,h,p,d,y,_=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(m(e,_)){e.rotate(S).translate(C);var b=m(e,_),w=function(t,e){if(t&&e){var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}}(r,b),T=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((o=(t=L)[0],l=t[1],c=t[2],u=t[3],[o*(h=(a=w)[0])-l*(p=a[1])-c*(d=a[2])-u*(y=a[3]),o*p+l*h+c*y-u*d,o*d-l*y+c*h+u*p,o*y+l*d-c*p+u*h])),k=i.r=function(t,e,r){var n=v(e,2,t[0]);n=v(n,1,t[1]),n=v(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var m=180-a-2*p,y=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s;return g(r[0],r[1],a,y)<=g(r[0],r[1],m,x)?[a,y,r[2]]:[m,x,r[2]]}(T,r,E);isFinite(k[0])&&isFinite(k[1])&&isFinite(k[2])||(k=E),e.rotate(k),E=k}}else r=m(e,M=_);f.of(this,arguments)({type:\"zoom\"})})),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})})).on(\"zoomend\",(function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,y)})).on(\"zoom.redraw\",(function(){t.render(!0);var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})})),n.rebind(a,f,\"on\")}function m(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function g(t,e,r,n){var i=y(r-t),a=y(n-e);return Math.sqrt(i*i+a*a)}function y(t){return(t%360+540)%360-180}function v(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}t.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},4173:function(t,e,r){\"use strict\";var n=r(33626),i=r(54826).SUBPLOT_PATTERN;e.fX=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},e.eV=function(t,e,r){var i,a=[],o=[];if(!(i=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[a,t];for(var s=r,l=0;l<t.length;l++){var c=t[l],u=c[0].trace,h=void 0!==u.zorder;!0===u.visible&&0!==u._length&&(!u._module||u._module.plot!==i||h&&u.zorder!==s?o.push(c):a.push(c))}return[a,o]},e.KO=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},77055:function(t,e,r){\"use strict\";var n=r(99978),i=r(20573),a=r(44039),o=r(54826),s=r(74043);function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}t.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,m=o.MINZOOM*r.pixelRatio;function g(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var y=n/(h[2]-h[0])*(l[2]-l[0])+l[0],v=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=y,c.boxStart[1]=v,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=y,c.boxEnd[1]=v,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<m,_=Math.abs(c.dragStart[1]-i)<m;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&_)x&&(c.boxEnd[0]=c.boxStart[0]),_&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var b=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*b)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*b*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(b)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(b))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/b*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(b)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(b)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(g(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(g(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",(function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchmove\",(function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchend\",(function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()}),!!s&&{passive:!1}),c.wheelListener=i(e,(function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0}),!0),c}},10749:function(t,e,r){\"use strict\";var n=r(29714),i=r(55010);function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=1.5,n=e.title.font.size,i=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?n*(r+(i?1:0))-10:n*(r+(i?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+n*(r+(i?1:.5)):10+n*(r+(i?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},t.exports=function(t){return new a(t)}},24585:function(t,e,r){\"use strict\";var n=r(13582).overrideAll,i=r(27672),a=r(6704),o=r(62972),s=r(54826),l=r(37703),c=r(6811),u=r(4173).KO;e.name=\"gl2d\",e.attr=[\"xaxis\",\"yaxis\"],e.idRoot=[\"x\",\"y\"],e.idRegex=s.idRegex,e.attrRegex=s.attrRegex,e.attributes=r(55126),e.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},e.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),e.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),e.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},e.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];s._scene2d&&0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},e.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},e.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},e.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++)e._plots[r[n]]._scene2d.updateFx(e.dragmode)}},27672:function(t,e,r){\"use strict\";var n,i,a=r(33626),o=r(29714),s=r(32141),l=r(99098).gl_plot2d,c=r(99098).gl_spikes2d,u=r(99098).gl_select_box,h=r(22248),f=r(10749),p=r(77055),d=r(97464),m=r(84391),g=m.enforce,y=m.clean,v=r(32919).doAutoRange,x=r(70414),_=x.drawMode,b=x.selectMode,w=[\"xaxis\",\"yaxis\"],T=r(54826).SUBPLOT_PATTERN;function k(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}t.exports=k;var A=k.prototype;A.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r);var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",(function(){l.isMouseOver=!1,l.unhover()})),o.addEventListener(\"mouseover\",(function(){l.isMouseOver=!0}))},A.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\",{willReadFrequently:!0}),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},A.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},A.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},A.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(T),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},A.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},A.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},A.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},A.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map((function(e){t[e].dispose(),delete t[e]})),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},A.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:r._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis,_size:r._size}};y(s,this.xaxis),y(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[w[c]])._length=o.viewBox[c+2]-o.viewBox[c],v(this.graphDiv,l),l.setScale();g(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},A.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},A.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},A.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort((function(t,e){return t._trace.index-e._trace.index}))},A.updateFx=function(t){b(t)||_(t)?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},A.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},A.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var m=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),m.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var g=this.fullData[m.trace.index]||{},y=m.pointIndex,v=s.castHoverinfo(g,i,y);if(v&&\"all\"!==v){var x=v.split(\"+\");-1===x.indexOf(\"x\")&&(m.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(m.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(m.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(m.textLabel=void 0),-1===x.indexOf(\"name\")&&(m.name=void 0)}s.loneHover({x:m.screenCoord[0],y:m.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",m.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",m.traceCoord[1]),zLabel:m.traceCoord[2],text:m.textLabel,name:m.name,color:s.castHoverOption(g,y,\"bgcolor\")||m.color,borderColor:s.castHoverOption(g,y,\"bordercolor\"),fontFamily:s.castHoverOption(g,y,\"font.family\"),fontSize:s.castHoverOption(g,y,\"font.size\"),fontColor:s.castHoverOption(g,y,\"font.color\"),nameLength:s.castHoverOption(g,y,\"namelength\"),textAlign:s.castHoverOption(g,y,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},A.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},A.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},2487:function(t,e,r){\"use strict\";var n=r(13582).overrideAll,i=r(6811),a=r(20299),o=r(4173).KO,s=r(34809),l=r(62972),c=\"gl3d\",u=\"scene\";e.name=c,e.attr=u,e.idRoot=u,e.idRegex=e.attrRegex=s.counterRegex(\"scene\"),e.attributes=r(22597),e.layoutAttributes=r(77168),e.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),e.supplyLayoutDefaults=r(15250),e.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots[c],i=0;i<n.length;i++){var s=n[i],l=o(r,c,s),u=e[s],h=u.camera,f=u._scene;f||(f=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:h},e),u._scene=f),f.viewInitial||(f.viewInitial={up:{x:h.up.x,y:h.up.y,z:h.up.z},eye:{x:h.eye.x,y:h.eye.y,z:h.eye.z},center:{x:h.center.x,y:h.center.y,z:h.center.z}}),f.plot(l,e,t.layout)}},e.clean=function(t,e,r,n){for(var i=n._subplots[c]||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},e.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots[c],n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,u=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":u,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},e.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),u+e}},e.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots[c],n=0;n<r.length;n++)e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}},22597:function(t){\"use strict\";t.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},63397:function(t,e,r){\"use strict\";var n=r(78766),i=r(25829),a=r(93049).extendFlat,o=r(13582).overrideAll;t.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:{text:i.title.text,font:i.title.font},type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:i.autorange,autorangeoptions:{minallowed:i.autorangeoptions.minallowed,maxallowed:i.autorangeoptions.maxallowed,clipmin:i.autorangeoptions.clipmin,clipmax:i.autorangeoptions.clipmax,include:i.autorangeoptions.include,editType:\"plot\"},rangemode:i.rangemode,minallowed:i.minallowed,maxallowed:i.maxallowed,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.minor.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,labelalias:i.labelalias,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},34258:function(t,e,r){\"use strict\";var n=r(65657).mix,i=r(34809),a=r(78032),o=r(63397),s=r(4392),l=r(97655),c=[\"xaxis\",\"yaxis\",\"zaxis\"];t.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noAutotickangles:!0,noTicklabelindex:!0,noTickson:!0,noTicklabelmode:!0,noTicklabelshift:!0,noTicklabelstandoff:!0,noTicklabelstep:!0,noTicklabelposition:!0,noTicklabeloverflow:!0,noInsiderange:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,72.72727272727273).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},95701:function(t,e,r){\"use strict\";var n=r(55010),i=r(34809),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickFontWeight=[\"normal\",\"normal\",\"normal\",\"normal\"],this.tickFontStyle=[\"normal\",\"normal\",\"normal\",\"normal\"],this.tickFontVariant=[\"normal\",\"normal\",\"normal\",\"normal\"],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelFontWeight=[\"normal\",\"normal\",\"normal\",\"normal\"],this.labelFontStyle=[\"normal\",\"normal\",\"normal\",\"normal\"],this.labelFontVariant=[\"normal\",\"normal\",\"normal\",\"normal\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=this,o=0;o<3;++o){var s=e[a[o]];s.visible?(r.labels[o]=t._meta?i.templateString(s.title.text,t._meta):s.title.text,\"font\"in s.title&&(s.title.font.color&&(r.labelColor[o]=n(s.title.font.color)),s.title.font.family&&(r.labelFont[o]=s.title.font.family),s.title.font.size&&(r.labelSize[o]=s.title.font.size),s.title.font.weight&&(r.labelFontWeight[o]=s.title.font.weight),s.title.font.style&&(r.labelFontStyle[o]=s.title.font.style),s.title.font.variant&&(r.labelFontVariant[o]=s.title.font.variant)),\"showline\"in s&&(r.lineEnable[o]=s.showline),\"linecolor\"in s&&(r.lineColor[o]=n(s.linecolor)),\"linewidth\"in s&&(r.lineWidth[o]=s.linewidth),\"showgrid\"in s&&(r.gridEnable[o]=s.showgrid),\"gridcolor\"in s&&(r.gridColor[o]=n(s.gridcolor)),\"gridwidth\"in s&&(r.gridWidth[o]=s.gridwidth),\"log\"===s.type?r.zeroEnable[o]=!1:\"zeroline\"in s&&(r.zeroEnable[o]=s.zeroline),\"zerolinecolor\"in s&&(r.zeroLineColor[o]=n(s.zerolinecolor)),\"zerolinewidth\"in s&&(r.zeroLineWidth[o]=s.zerolinewidth),\"ticks\"in s&&s.ticks?r.lineTickEnable[o]=!0:r.lineTickEnable[o]=!1,\"ticklen\"in s&&(r.lineTickLength[o]=r._defaultLineTickLength[o]=s.ticklen),\"tickcolor\"in s&&(r.lineTickColor[o]=n(s.tickcolor)),\"tickwidth\"in s&&(r.lineTickWidth[o]=s.tickwidth),\"tickangle\"in s&&(r.tickAngle[o]=\"auto\"===s.tickangle?-3600:Math.PI*-s.tickangle/180),\"showticklabels\"in s&&(r.tickEnable[o]=s.showticklabels),\"tickfont\"in s&&(s.tickfont.color&&(r.tickColor[o]=n(s.tickfont.color)),s.tickfont.family&&(r.tickFont[o]=s.tickfont.family),s.tickfont.size&&(r.tickSize[o]=s.tickfont.size),s.tickfont.weight&&(r.tickFontWeight[o]=s.tickfont.weight),s.tickfont.style&&(r.tickFontStyle[o]=s.tickfont.style),s.tickfont.variant&&(r.tickFontVariant[o]=s.tickfont.variant)),\"mirror\"in s?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(s.mirror)?(r.lineTickMirror[o]=!0,r.lineMirror[o]=!0):!0===s.mirror?(r.lineTickMirror[o]=!1,r.lineMirror[o]=!0):(r.lineTickMirror[o]=!1,r.lineMirror[o]=!1):r.lineMirror[o]=!1,\"showbackground\"in s&&!1!==s.showbackground?(r.backgroundEnable[o]=!0,r.backgroundColor[o]=n(s.backgroundcolor)):r.backgroundEnable[o]=!1):(r.tickEnable[o]=!1,r.labelEnable[o]=!1,r.lineEnable[o]=!1,r.lineTickEnable[o]=!1,r.gridEnable[o]=!1,r.zeroEnable[o]=!1,r.backgroundEnable[o]=!1)}},t.exports=function(t,e){var r=new o;return r.merge(t,e),r}},15250:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(33626),o=r(4448),s=r(34258),l=r(77168),c=r(4173).KO,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var m=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:m,bgColor:l,calendar:n.calendar,autotypenumbersDflt:n.autotypenumbersDflt,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var g=n.getDfltFromLayout(\"dragmode\");if(!1!==g&&!g)if(g=\"orbit\",t.camera&&t.camera.up){var y=t.camera.up.x,v=t.camera.up.y,x=t.camera.up.z;0!==x&&(y&&v&&x?x/Math.sqrt(y*y+v*v+x*x)>.999&&(g=\"turntable\"):g=\"turntable\")}else g=\"turntable\";r(\"dragmode\",g),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}t.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},77168:function(t,e,r){\"use strict\";var n=r(63397),i=r(13792).u,a=r(93049).extendFlat,o=r(34809).counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}t.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},64087:function(t,e,r){\"use strict\";var n=r(55010),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},t.exports=function(t){var e=new a;return e.merge(t),e}},32412:function(t,e,r){\"use strict\";t.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u,{msUTC:!0}),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}for(e.ticks=l,c=0;c<3;++c)for(o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]),d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c];t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=r(29714),i=r(34809),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},25802:function(t){\"use strict\";function e(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}t.exports=function(t,r){return e(t.projection,e(t.view,e(t.model,[r[0],r[1],r[2],1])))}},20299:function(t,e,r){\"use strict\";var n,i,a=r(99098).gl_plot3d,o=a.createCamera,s=a.createScene,l=r(22248),c=r(74043),u=r(33626),h=r(34809),f=h.preserveDrawingBuffer(),p=r(29714),d=r(32141),m=r(55010),g=r(97464),y=r(25802),v=r(95701),x=r(64087),_=r(32412),b=r(32919).applyAutorangeOptions,w=!1;function T(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=x(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=u.getComponentMethod(\"annotations3d\",\"draw\"),this.initializeGLPlot()}var k=T.prototype;k.prepareOptions=function(){var t=this,e={canvas:t.canvas,gl:t.gl,glOptions:{preserveDrawingBuffer:f,premultipliedAlpha:!0,antialias:!0},container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:t.camera,pixelRatio:t.pixelRatio};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");e.gl=i,e.canvas=n}return e};var A=!0;k.tryCreatePlot=function(){var t=this,e=t.prepareOptions(),r=!0;try{t.glplot=s(e)}catch(n){if(t.staticMode||!A||f)r=!1;else{h.warn([\"webgl setup failed possibly due to\",\"false preserveDrawingBuffer config.\",\"The mobile/tablet device may not be detected by is-mobile module.\",\"Enabling preserveDrawingBuffer in second attempt to create webgl scene...\"].join(\" \"));try{f=e.glOptions.preserveDrawingBuffer=!0,t.glplot=s(e)}catch(t){f=e.glOptions.preserveDrawingBuffer=!1,r=!1}}}return A=!1,r},k.initializeGLCamera=function(){var t=this,e=t.fullSceneLayout.camera,r=\"orthographic\"===e.projection.type;t.camera=o(t.container,{center:[e.center.x,e.center.y,e.center.z],eye:[e.eye.x,e.eye.y,e.eye.z],up:[e.up.x,e.up.y,e.up.z],_ortho:r,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},k.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return g(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+\".camera\"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+\".aspectratio\"]=t.glplot.getAspectratio(),\"manual\"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+\".aspectmode\"]=\"manual\")),e},i=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas&&(t.glplot.canvas.addEventListener(\"mouseup\",(function(){i(t)})),t.glplot.canvas.addEventListener(\"touchstart\",(function(){w=!0})),t.glplot.canvas.addEventListener(\"wheel\",(function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,a=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*a.x,y:n*a.y,z:n*a.z})}i(t)}}),!!c&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",(function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit(\"plotly_relayouting\",e)}})),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",(function(r){e&&e.emit&&e.emit(\"plotly_webglcontextlost\",{event:r,layer:t.id})}),!1)),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},k.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,i=e.container.getBoundingClientRect();r._fullLayout._calcInverseTransform(r);var a=r._fullLayout._invScaleX,o=r._fullLayout._invScaleY,s=i.width*a,l=i.height*o;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+s+\" \"+l),n.setAttributeNS(null,\"width\",s),n.setAttributeNS(null,\"height\",l),_(e),e.glplot.axes.update(e.axesOptions);for(var c=Object.keys(e.traces),u=null,f=e.glplot.selection,m=0;m<c.length;++m)\"skip\"!==(t=e.traces[c[m]]).data.hoverinfo&&t.handlePick(f)&&(u=t),t.setContourLevels&&t.setContourLevels();function g(t,r,n){var i=e.fullSceneLayout[t+\"axis\"];return\"log\"!==i.type&&(r=i.d2l(r)),p.hoverLabelText(i,r,n)}if(null!==u){var v=y(e.glplot.cameraParams,f.dataCoordinate);t=u.data;var x,b=r._fullData[t.index],T=f.index,k={xLabel:g(\"x\",f.traceCoordinate[0],t.xhoverformat),yLabel:g(\"y\",f.traceCoordinate[1],t.yhoverformat),zLabel:g(\"z\",f.traceCoordinate[2],t.zhoverformat)},A=d.castHoverinfo(b,e.fullLayout,T),M=(A||\"\").split(\"+\"),S=A&&\"all\"===A;b.hovertemplate||S||(-1===M.indexOf(\"x\")&&(k.xLabel=void 0),-1===M.indexOf(\"y\")&&(k.yLabel=void 0),-1===M.indexOf(\"z\")&&(k.zLabel=void 0),-1===M.indexOf(\"text\")&&(f.textLabel=void 0),-1===M.indexOf(\"name\")&&(u.name=void 0));var E=[];\"cone\"===t.type||\"streamtube\"===t.type?(k.uLabel=g(\"x\",f.traceCoordinate[3],t.uhoverformat),(S||-1!==M.indexOf(\"u\"))&&E.push(\"u: \"+k.uLabel),k.vLabel=g(\"y\",f.traceCoordinate[4],t.vhoverformat),(S||-1!==M.indexOf(\"v\"))&&E.push(\"v: \"+k.vLabel),k.wLabel=g(\"z\",f.traceCoordinate[5],t.whoverformat),(S||-1!==M.indexOf(\"w\"))&&E.push(\"w: \"+k.wLabel),k.normLabel=f.traceCoordinate[6].toPrecision(3),(S||-1!==M.indexOf(\"norm\"))&&E.push(\"norm: \"+k.normLabel),\"streamtube\"===t.type&&(k.divergenceLabel=f.traceCoordinate[7].toPrecision(3),(S||-1!==M.indexOf(\"divergence\"))&&E.push(\"divergence: \"+k.divergenceLabel)),f.textLabel&&E.push(f.textLabel),x=E.join(\"<br>\")):\"isosurface\"===t.type||\"volume\"===t.type?(k.valueLabel=p.hoverLabelText(e._mockAxis,e._mockAxis.d2l(f.traceCoordinate[3]),t.valuehoverformat),E.push(\"value: \"+k.valueLabel),f.textLabel&&E.push(f.textLabel),x=E.join(\"<br>\")):x=f.textLabel;var C={x:f.traceCoordinate[0],y:f.traceCoordinate[1],z:f.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:T};d.appendArrayPointValue(C,b,T),t._module.eventData&&(C=b._module.eventData(C,f,b,{},T));var L={points:[C]};if(e.fullSceneLayout.hovermode){var I=[];d.loneHover({trace:b,x:(.5+.5*v[0]/v[3])*s,y:(.5-.5*v[1]/v[3])*l,xLabel:k.xLabel,yLabel:k.yLabel,zLabel:k.zLabel,text:x,name:u.name,color:d.castHoverOption(b,T,\"bgcolor\")||u.color,borderColor:d.castHoverOption(b,T,\"bordercolor\"),fontFamily:d.castHoverOption(b,T,\"font.family\"),fontSize:d.castHoverOption(b,T,\"font.size\"),fontColor:d.castHoverOption(b,T,\"font.color\"),nameLength:d.castHoverOption(b,T,\"namelength\"),textAlign:d.castHoverOption(b,T,\"align\"),hovertemplate:h.castOption(b,T,\"hovertemplate\"),hovertemplateLabels:h.extendFlat({},C,k),eventData:[C]},{container:n,gd:r,inOut_bbox:I}),C.bbox=I[0]}f.distance<5&&(f.buttons||w)?r.emit(\"plotly_click\",L):r.emit(\"plotly_hover\",L),this.oldEventData=L}else d.loneUnhover(n),this.oldEventData&&r.emit(\"plotly_unhover\",this.oldEventData),this.oldEventData=void 0;e.drawAnnotations(e)},k.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):h.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")};requestAnimationFrame(e)};var M=[\"xaxis\",\"yaxis\",\"zaxis\"];function S(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=M[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],u=e[\"_\"+o+\"length\"];if(h.isArrayOrTypedArray(l))for(var f,p=0;p<(u||l.length);p++)if(h.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],u-1)}}k.plot=function(t,e,r){var n=this;if(n.plotArgs=[t,e,r],!n.glplot.contextLost){var i,a,o,s,l,c,u=e[n.id],h=r[n.id];n.fullLayout=e,n.fullSceneLayout=u,n.axesOptions.merge(e,u),n.spikeOptions.merge(u),n.setViewport(u),n.updateFx(u.dragmode,u.hovermode),n.camera.enableWheel=n.graphDiv._context._scrollZoom.gl3d,n.glplot.setClearColor(m(u.bgcolor)),n.setConvert(l),t?Array.isArray(t)||(t=[t]):t=[];var f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(o=0;o<t.length;++o)!0===(i=t[o]).visible&&0!==i._length&&S(this,i,f);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=M[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,f);var p=[1,1,1];for(s=0;s<3;++s)f[1][s]===f[0][s]?p[s]=1:p[s]=1/(f[1][s]-f[0][s]);for(n.dataScale=p,n.convertAnnotations(this),o=0;o<t.length;++o)!0===(i=t[o]).visible&&0!==i._length&&((a=n.traces[i.uid])?a.data.type===i.type?a.update(i):(a.dispose(),a=i._module.plot(this,i),n.traces[i.uid]=a):(a=i._module.plot(this,i),n.traces[i.uid]=a),a.name=i.name);var d=Object.keys(n.traces);t:for(o=0;o<d.length;++o){for(s=0;s<t.length;++s)if(t[s].uid===d[o]&&!0===t[s].visible&&0!==t[s]._length)continue t;(a=n.traces[d[o]]).dispose(),delete n.traces[d[o]]}n.glplot.objects.sort((function(t,e){return t._trace.data.index-e._trace.data.index}));var g,y=[[0,0,0],[0,0,0]],v=[],x={};for(o=0;o<3;++o){var _;if((c=(l=u[M[o]]).type)in x?(x[c].acc*=p[o],x[c].count+=1):x[c]={acc:p[o],count:1},l.autorange){y[0][o]=1/0,y[1][o]=-1/0;var w=n.glplot.objects,T=n.fullSceneLayout.annotations||[],k=l._name.charAt(0);for(s=0;s<w.length;s++){var A=w[s],E=A.bounds,C=A._trace.data._pad||0;\"ErrorBars\"===A.constructor.name&&l._lowerLogErrorBound?y[0][o]=Math.min(y[0][o],l._lowerLogErrorBound):y[0][o]=Math.min(y[0][o],E[0][o]/p[o]-C),y[1][o]=Math.max(y[1][o],E[1][o]/p[o]+C)}for(s=0;s<T.length;s++){var L=T[s];if(L.visible){var I=l.r2l(L[k]);y[0][o]=Math.min(y[0][o],I),y[1][o]=Math.max(y[1][o],I)}}if(\"rangemode\"in l&&\"tozero\"===l.rangemode&&(y[0][o]=Math.min(y[0][o],0),y[1][o]=Math.max(y[1][o],0)),y[0][o]>y[1][o])y[0][o]=-1,y[1][o]=1;else{var P=y[1][o]-y[0][o];y[0][o]-=P/32,y[1][o]+=P/32}if(_=[y[0][o],y[1][o]],_=b(_,l),y[0][o]=_[0],y[1][o]=_[1],l.isReversed()){var z=y[0][o];y[0][o]=y[1][o],y[1][o]=z}}else _=l.range,y[0][o]=l.r2l(_[0]),y[1][o]=l.r2l(_[1]);y[0][o]===y[1][o]&&(y[0][o]-=1,y[1][o]+=1),v[o]=y[1][o]-y[0][o],l.range=[y[0][o],y[1][o]],l.limitRange(),n.glplot.setBounds(o,{min:l.range[0]*p[o],max:l.range[1]*p[o]})}var O=u.aspectmode;if(\"cube\"===O)g=[1,1,1];else if(\"manual\"===O){var D=u.aspectratio;g=[D.x,D.y,D.z]}else{if(\"auto\"!==O&&\"data\"!==O)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var R=[1,1,1];for(o=0;o<3;++o){var F=x[c=(l=u[M[o]]).type];R[o]=Math.pow(F.acc,1/F.count)/p[o]}g=\"data\"===O||Math.max.apply(null,R)/Math.min.apply(null,R)<=4?R:[1,1,1]}u.aspectratio.x=h.aspectratio.x=g[0],u.aspectratio.y=h.aspectratio.y=g[1],u.aspectratio.z=h.aspectratio.z=g[2],n.glplot.setAspectratio(u.aspectratio),n.viewInitial.aspectratio||(n.viewInitial.aspectratio={x:u.aspectratio.x,y:u.aspectratio.y,z:u.aspectratio.z}),n.viewInitial.aspectmode||(n.viewInitial.aspectmode=u.aspectmode);var B=u.domain||null,N=e._size||null;if(B&&N){var j=n.container.style;j.position=\"absolute\",j.left=N.l+B.x[0]*N.w+\"px\",j.top=N.t+(1-B.y[1])*N.h+\"px\",j.width=N.w*(B.x[1]-B.x[0])+\"px\",j.height=N.h*(B.y[1]-B.y[0])+\"px\"}n.glplot.redraw()}},k.destroy=function(){var t=this;t.glplot&&(t.camera.mouseListener.enabled=!1,t.container.removeEventListener(\"wheel\",t.camera.wheelListener),t.camera=null,t.glplot.dispose(),t.container.parentNode.removeChild(t.container),t.glplot=null)},k.getCamera=function(){var t,e=this;return e.camera.view.recalcMatrix(e.camera.view.lastT()),{up:{x:(t=e.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}},k.setViewport=function(t){var e,r=this,n=t.camera;r.camera.lookAt.apply(this,[[(e=n).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),r.glplot.setAspectratio(t.aspectratio),\"orthographic\"===n.projection.type!==r.camera._ortho&&(r.glplot.redraw(),r.glplot.clearRGBA(),r.glplot.dispose(),r.initializeGLPlot())},k.isCameraChanged=function(t){var e=this.getCamera(),r=h.nestedProperty(t,this.id+\".camera\").get();function n(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}var i=!1;if(void 0===r)i=!0;else{for(var a=0;a<3;a++)for(var o=0;o<3;o++)if(!n(e,r,a,o)){i=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(i=!0)}return i},k.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=h.nestedProperty(t,this.id+\".aspectratio\").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},k.saveLayout=function(t){var e,r,n,i,a,o,s=this,l=s.fullLayout,c=s.isCameraChanged(t),f=s.isAspectChanged(t),p=c||f;if(p){var d={};c&&(e=s.getCamera(),n=(r=h.nestedProperty(t,s.id+\".camera\")).get(),d[s.id+\".camera\"]=n),f&&(i=s.glplot.getAspectratio(),o=(a=h.nestedProperty(t,s.id+\".aspectratio\")).get(),d[s.id+\".aspectratio\"]=o),u.call(\"_storeDirectGUIEdit\",t,l._preGUI,d),c&&(r.set(e),h.nestedProperty(l,s.id+\".camera\").set(e)),f&&(a.set(i),h.nestedProperty(l,s.id+\".aspectratio\").set(i),s.glplot.redraw())}return p},k.updateFx=function(t,e){var r=this,n=r.camera;if(n)if(\"orbit\"===t)n.mode=\"orbit\",n.keyBindingMode=\"rotate\";else if(\"turntable\"===t){n.up=[0,0,1],n.mode=\"turntable\",n.keyBindingMode=\"rotate\";var i=r.graphDiv,a=i._fullLayout,o=r.fullSceneLayout.camera,s=o.up.x,l=o.up.y,c=o.up.z;if(c/Math.sqrt(s*s+l*l+c*c)<.999){var f=r.id+\".camera.up\",p={x:0,y:0,z:1},d={};d[f]=p;var m=i.layout;u.call(\"_storeDirectGUIEdit\",m,a._preGUI,d),o.up=p,h.nestedProperty(m,f).set(p)}}else n.keyBindingMode=t;r.fullSceneLayout.hovermode=e},k.toImage=function(t){var e=this;t||(t=\"png\"),e.staticMode&&e.container.appendChild(n),e.glplot.redraw();var r=e.glplot.gl,i=r.drawingBufferWidth,a=r.drawingBufferHeight;r.bindFramebuffer(r.FRAMEBUFFER,null);var o=new Uint8Array(i*a*4);r.readPixels(0,0,i,a,r.RGBA,r.UNSIGNED_BYTE,o),function(t,e,r){for(var n=0,i=r-1;n<i;++n,--i)for(var a=0;a<e;++a)for(var o=0;o<4;++o){var s=4*(e*n+a)+o,l=4*(e*i+a)+o,c=t[s];t[s]=t[l],t[l]=c}}(o,i,a),function(t,e,r){for(var n=0;n<r;++n)for(var i=0;i<e;++i){var a=4*(e*n+i),o=t[a+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[a+l]=Math.min(s*t[a+l],255)}}(o,i,a);var s=document.createElement(\"canvas\");s.width=i,s.height=a;var l,c=s.getContext(\"2d\",{willReadFrequently:!0}),u=c.createImageData(i,a);switch(u.data.set(o),c.putImageData(u,0,0),t){case\"jpeg\":l=s.toDataURL(\"image/jpeg\");break;case\"webp\":l=s.toDataURL(\"image/webp\");break;default:l=s.toDataURL(\"image/png\")}return e.staticMode&&e.container.removeChild(n),l},k.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[M[t]];p.setConvert(e,this.fullLayout),e.setScale=h.noop}},k.make4thDimension=function(){var t=this,e=t.graphDiv._fullLayout;t._mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},p.setConvert(t._mockAxis,e)},t.exports=T},88239:function(t){\"use strict\";t.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},6704:function(t,e,r){\"use strict\";var n=r(80337),i=r(49722),a=r(10229),o=r(64101),s=r(52307),l=r(57891),c=r(93049).extendFlat,u=n({editType:\"calc\"});u.family.dflt='\"Open Sans\", verdana, arial, sans-serif',u.size.dflt=12,u.color.dflt=a.defaultLine,t.exports={font:u,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),subtitle:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),editType:\"layoutstyle\"},xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:c(l({editType:\"layoutstyle\"}),{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},editType:\"layoutstyle\"},uniformtext:{mode:{valType:\"enumerated\",values:[!1,\"hide\",\"show\"],dflt:!1,editType:\"plot\"},minsize:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},minreducedwidth:{valType:\"number\",min:2,dflt:64,editType:\"plot\"},minreducedheight:{valType:\"number\",min:2,dflt:64,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},computed:{valType:\"any\",editType:\"none\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},newshape:o.newshape,activeshape:o.activeshape,newselection:s.newselection,activeselection:s.activeselection,meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:c({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},8814:function(t,e,r){\"use strict\";var n=r(62994),i=r(37071),a=\"https://basemaps.cartocdn.com/gl/positron-gl-style/style.json\",o=\"https://basemaps.cartocdn.com/gl/dark-matter-gl-style/style.json\",s=\"https://basemaps.cartocdn.com/gl/voyager-gl-style/style.json\",l={basic:s,streets:s,outdoors:s,light:a,dark:o,satellite:r(51962),\"satellite-streets\":i,\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'\u00a9 <a target=\"_blank\" href=\"https://www.openstreetmap.org/copyright\">OpenStreetMap</a> contributors',tiles:[\"https://tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"carto-positron\":a,\"carto-darkmatter\":o,\"carto-voyager\":s,\"carto-positron-nolabels\":\"https://basemaps.cartocdn.com/gl/positron-nolabels-gl-style/style.json\",\"carto-darkmatter-nolabels\":\"https://basemaps.cartocdn.com/gl/dark-matter-nolabels-gl-style/style.json\",\"carto-voyager-nolabels\":\"https://basemaps.cartocdn.com/gl/voyager-nolabels-gl-style/style.json\"},c=n(l);t.exports={styleValueDflt:\"basic\",stylesMap:l,styleValuesMap:c,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",missingStyleErrorMsg:[\"No valid maplibre style found, please set `map.style` to one of:\",c.join(\", \"),\"or use a tile service.\"].join(\"\\n\"),mapOnErrorMsg:\"Map error.\"}},4657:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},34091:function(t,e,r){\"use strict\";var n=r(34809),i=n.strTranslate,a=n.strScale,o=r(4173).fX,s=r(62972),l=r(45568),c=r(62203),u=r(30635),h=r(38793),f=\"map\";e.name=f,e.attr=\"subplot\",e.idRoot=f,e.idRegex=e.attrRegex=n.counterRegex(f),e.attributes={subplot:{valType:\"subplotid\",dflt:\"map\",editType:\"calc\"}},e.layoutAttributes=r(8257),e.supplyLayoutDefaults=r(97446),e.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[f],a=0;a<i.length;a++){var s=i[a],l=o(r,f,s),c=e[s],u=c._subplot;u||(u=new h(t,s),e[s]._subplot=u),u.viewInitial||(u.viewInitial={center:n.extendFlat({},c.center),zoom:c.zoom,bearing:c.bearing,pitch:c.pitch}),u.plot(l,e,t._promises)}},e.clean=function(t,e,r,n){for(var i=n._subplots[f]||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},e.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots[f],n=e._size,o=0;o<r.length;o++){var h=e[r[o]],p=h.domain,d=h._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:s.svg,\"xlink:href\":d,x:n.l+n.w*p.x[0],y:n.t+n.h*(1-p.y[1]),width:n.w*(p.x[1]-p.x[0]),height:n.h*(p.y[1]-p.y[0]),preserveAspectRatio:\"none\"});var m=l.select(h._subplot.div).select(\".maplibregl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),g=e._glimages.append(\"g\"),y=g.append(\"text\");y.text(m).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":m});var v=c.bBox(y.node()),x=n.w*(p.x[1]-p.x[0]);if(v.width>x/2){var _=m.split(\"|\").join(\"<br>\");y.text(_).attr(\"data-unformatted\",_).call(u.convertToTspans,t),v=c.bBox(y.node())}y.attr(\"transform\",i(-3,8-v.height)),g.insert(\"rect\",\".static-attribution\").attr({x:-v.width-6,y:-v.height-3,width:v.width+6,height:v.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var b=1;v.width+6>x&&(b=x/(v.width+6));var w=[n.l+n.w*p.x[1],n.t+n.h*(1-p.y[0])];g.attr(\"transform\",i(w[0],w[1])+a(b))}},e.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots[f],n=0;n<r.length;n++)e[r[n]]._subplot.updateFx(e)}},33389:function(t,e,r){\"use strict\";var n=r(34809),i=r(30635).sanitizeHTML,a=r(4657),o=r(8814);function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{\"icon-image\":i.icon+\"-15\",\"icon-size\":i.iconsize/10,\"text-field\":i.text,\"text-size\":i.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":i.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":i.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||JSON.stringify(this.source)!==JSON.stringify(t.source)||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.lookupBelow=function(){return this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates});var e=this.findFollowingMapLayerId(this.lookupBelow());null!==e&&this.subplot.map.moveLayer(this.idLayer,e)},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};return\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",a.tileSize=256):\"image\"===r&&(e=\"url\",a.coordinates=t.coordinates),a[e]=n,t.sourceattribution&&(a.attribution=i(t.sourceattribution)),a}(t);e.addSource(this.idSource,r)}},l.findFollowingMapLayerId=function(t){if(\"traces\"===t)for(var e=this.subplot.getMapLayers(),r=0;r<e.length;r++){var n=e[r].id;if(\"string\"==typeof n&&0===n.indexOf(o.traceLayerPrefix)){t=n;break}}return t},l.updateLayer=function(t){var e=this.subplot,r=u(t),n=this.lookupBelow(),i=this.findFollowingMapLayerId(n);this.removeLayer(),c(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:r.layout,paint:r.paint},i),this.layerType=t.type,this.below=n},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},t.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},8257:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766).defaultLine,a=r(13792).u,o=r(80337),s=r(36640).textposition,l=r(13582).overrideAll,c=r(78032).templatedArray,u=r(8814),h=o({noFontVariant:!0,noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(t.exports=l({_arrayAttrRegexps:[n.counterRegex(\"map\",\".layers\",!0)],domain:a({name:\"map\"}),style:{valType:\"any\",values:u.styleValuesMap,dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},bounds:{west:{valType:\"number\"},east:{valType:\"number\"},south:{valType:\"number\"},north:{valType:\"number\"}},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},97446:function(t,e,r){\"use strict\";var n=r(34809),i=r(4448),a=r(59008),o=r(8257);function s(t,e,r){r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\");var n=r(\"bounds.west\"),i=r(\"bounds.east\"),o=r(\"bounds.south\"),s=r(\"bounds.north\");void 0!==n&&void 0!==i&&void 0!==o&&void 0!==s||delete e.bounds,a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\",void 0,{noFontVariant:!0,noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0}),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}t.exports=function(t,e,r){i(t,e,r,{type:\"map\",attributes:o,handleDefaults:s,partition:\"y\"})}},38793:function(t,e,r){\"use strict\";var n=r(89380),i=r(34809),a=r(3994),o=r(33626),s=r(29714),l=r(14751),c=r(32141),u=r(70414),h=u.drawMode,f=u.selectMode,p=r(44844).prepSelect,d=r(44844).clearOutline,m=r(44844).clearSelectionsCache,g=r(44844).selectOnClick,y=r(8814),v=r(33389);function x(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=x.prototype;_.plot=function(t,e,r){var n,i=this;n=i.map?new Promise((function(r,n){i.updateMap(t,e,r,n)})):new Promise((function(r,n){i.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,i){var o=this,s=e[o.id],l=o.styleObj=w(s.style),c=s.bounds,u=c?[[c.west,c.south],[c.east,c.north]]:null,h=o.map=new n.Map({container:o.div,style:l.style,center:T(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,maxBounds:u,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0})),f={};h.on(\"styleimagemissing\",(function(t){var e=t.id;if(!f[e]&&e.includes(\"-15\")){f[e]=!0;var r=new Image(15,15);r.onload=function(){h.addImage(e,r)},r.crossOrigin=\"Anonymous\",r.src=\"https://unpkg.com/maki@2.1.0/icons/\"+e+\".svg\"}})),h.setTransformRequest((function(t){return{url:t=(t=(t=t.replace(\"https://fonts.openmaptiles.org/Open Sans Extrabold\",\"https://fonts.openmaptiles.org/Open Sans Extra Bold\")).replace(\"https://tiles.basemaps.cartocdn.com/fonts/Open Sans Extrabold\",\"https://fonts.openmaptiles.org/Open Sans Extra Bold\")).replace(\"https://fonts.openmaptiles.org/Open Sans Regular,Arial Unicode MS Regular\",\"https://fonts.openmaptiles.org/Klokantech Noto Sans Regular\")}})),h._canvas.style.left=\"0px\",h._canvas.style.top=\"0px\",o.rejectOnError(i),o.isStatic||o.initFx(t,e);var p=[];p.push(new Promise((function(t){h.once(\"load\",t)}))),p=p.concat(a.fetchTraceGeoData(t)),Promise.all(p).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(i)},_.updateMap=function(t,e,r,n){var i=this,o=i.map,s=e[this.id];i.rejectOnError(n);var l=[],c=w(s.style);JSON.stringify(i.styleObj)!==JSON.stringify(c)&&(i.styleObj=c,o.setStyle(c.style),i.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(a.fetchTraceGeoData(t)),Promise.all(l).then((function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var b={choroplethmap:0,densitymap:1,scattermap:2};function w(t){var e={};return i.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,y.stylesMap[t]?e.style=y.stylesMap[t]:e.style=t):(e.id=y.styleValueDflt,e.style=function(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}(y.styleValueDflt)),e.transition={duration:0,delay:0},e}function T(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort((function(t,e){return b[t[0].trace.type]-b[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=a[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(a[r.uid]=r._module.plot(this,s))}var c=Object.keys(a);t:for(n=0;n<c.length;n++){var u=c[n];for(i=0;i<t.length;i++)if(u===(r=t[i][0].trace).uid)continue t;(e=a[u]).dispose(),delete a[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(T(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.map?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function a(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}i.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var i=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e&&e._rehover&&e._rehover()}})),i.on(\"wheel\",(function(){r.wheeling=!0})),i.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect(),a=[t.originalEvent.offsetX,t.originalEvent.offsetY];t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return i.unproject(a).lng},r.yaxis.p2c=function(){return i.unproject(a).lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),i.on(\"dragstart\",(function(){r.dragging=!0,a()})),i.on(\"zoomstart\",a),i.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),i.on(\"drag\",s),i.on(\"zoom\",s),i.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(T(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))})),r.clearOutline=function(){m(r.dragOptions),d(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&g(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a=function(t,r){r.isRect?(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]:(t.lassoPoints={})[e.id]=r.map(c)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),f(o)||h(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearOutline),e.dragOptions.prepFn=function(t,r,n){p(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearOutline),e.div.onmousedown=null,e.div.ontouchstart=null,e.div.removeEventListener(\"touchstart\",e.div._ontouchstart),e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(v(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),i=parseInt(n.style.width),a=parseInt(n.style.height);return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([i,0]).toArray(),t.unproject([i,a]).toArray(),t.unproject([0,a]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},t.exports=x},44245:function(t,e,r){\"use strict\";var n=r(62994),i=\"1.13.4\",a='\u00a9 <a target=\"_blank\" href=\"https://www.openstreetmap.org/copyright\">OpenStreetMap</a> contributors',o=['\u00a9 <a target=\"_blank\" href=\"https://carto.com/\">Carto</a>',a].join(\" \"),s=['Map tiles by <a target=\"_blank\" href=\"https://stamen.com\">Stamen Design</a>','under <a target=\"_blank\" href=\"https://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a>',\"|\",'Data by <a target=\"_blank\" href=\"https://openstreetmap.org\">OpenStreetMap</a> contributors','under <a target=\"_blank\" href=\"https://www.openstreetmap.org/copyright\">ODbL</a>'].join(\" \"),l={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:a,tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:o,tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:o,tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:s,tiles:[\"https://tiles.stadiamaps.com/tiles/stamen_terrain/{z}/{x}/{y}.png?api_key=\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:s,tiles:[\"https://tiles.stadiamaps.com/tiles/stamen_toner/{z}/{x}/{y}.png?api_key=\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:['Map tiles by <a target=\"_blank\" href=\"https://stamen.com\">Stamen Design</a>','under <a target=\"_blank\" href=\"https://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a>',\"|\",'Data by <a target=\"_blank\" href=\"https://openstreetmap.org\">OpenStreetMap</a> contributors','under <a target=\"_blank\" href=\"https://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>'].join(\" \"),tiles:[\"https://tiles.stadiamaps.com/tiles/stamen_watercolor/{z}/{x}/{y}.jpg?api_key=\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}],glyphs:\"https://fonts.openmaptiles.org/{fontstack}/{range}.pbf\"}},c=n(l);t.exports={requiredVersion:i,styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:l,styleValuesNonMapbox:c,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install @plotly/mapbox-gl@\"+i+\".\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.newPlot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",c.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},2178:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},68192:function(t,e,r){\"use strict\";var n=r(32280),i=r(34809),a=i.strTranslate,o=i.strScale,s=r(4173).fX,l=r(62972),c=r(45568),u=r(62203),h=r(30635),f=r(5417),p=\"mapbox\",d=e.constants=r(44245);e.name=p,e.attr=\"subplot\",e.idRoot=p,e.idRegex=e.attrRegex=i.counterRegex(p);var m=[\"mapbox subplots and traces are deprecated!\",\"Please consider switching to `map` subplots and traces.\",\"Learn more at: https://plotly.com/javascript/maplibre-migration/\"].join(\" \");e.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},e.layoutAttributes=r(67514),e.supplyLayoutDefaults=r(86989);var g=!0;function y(t){return\"string\"==typeof t&&(-1!==d.styleValuesMapbox.indexOf(t)||0===t.indexOf(\"mapbox://\")||0===t.indexOf(\"stamen\"))}e.plot=function(t){g&&(g=!1,i.warn(m));var e=t._fullLayout,r=t.calcdata,a=e._subplots[p];if(n.version!==d.requiredVersion)throw new Error(d.wrongVersionErrorMsg);var o=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;y(c.style)&&(u?i.pushUnique(n,u):(y(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var h=o?d.noAccessTokenErrorMsg:d.missingStyleErrorMsg;throw i.error(h),new Error(h)}return n.length?(n.length>1&&i.warn(d.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,a);n.accessToken=o;for(var l=0;l<a.length;l++){var c=a[l],u=s(r,p,c),h=e[c],v=h._subplot;v||(v=new f(t,c),e[c]._subplot=v),v.viewInitial||(v.viewInitial={center:i.extendFlat({},h.center),zoom:h.zoom,bearing:h.bearing,pitch:h.pitch}),v.plot(u,e,t._promises)}},e.clean=function(t,e,r,n){for(var i=n._subplots[p]||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},e.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots[p],n=e._size,i=0;i<r.length;i++){var s=e[r[i]],f=s.domain,m=s._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":m,x:n.l+n.w*f.x[0],y:n.t+n.h*(1-f.y[1]),width:n.w*(f.x[1]-f.x[0]),height:n.h*(f.y[1]-f.y[0]),preserveAspectRatio:\"none\"});var g=c.select(s._subplot.div);if(null!==g.select(\".mapboxgl-ctrl-logo\").node().offsetParent){var y=e._glimages.append(\"g\");y.attr(\"transform\",a(n.l+n.w*f.x[0]+10,n.t+n.h*(1-f.y[0])-31)),y.append(\"path\").attr(\"d\",d.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),y.append(\"path\").attr(\"d\",d.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),y.append(\"path\").attr(\"d\",d.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),y.append(\"polygon\").attr(\"points\",d.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var v=g.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),x=e._glimages.append(\"g\"),_=x.append(\"text\");_.text(v).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":v});var b=u.bBox(_.node()),w=n.w*(f.x[1]-f.x[0]);if(b.width>w/2){var T=v.split(\"|\").join(\"<br>\");_.text(T).attr(\"data-unformatted\",T).call(h.convertToTspans,t),b=u.bBox(_.node())}_.attr(\"transform\",a(-3,8-b.height)),x.insert(\"rect\",\".static-attribution\").attr({x:-b.width-6,y:-b.height-3,width:b.width+6,height:b.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var k=1;b.width+6>w&&(k=w/(b.width+6));var A=[n.l+n.w*f.x[1],n.t+n.h*(1-f.y[0])];x.attr(\"transform\",a(A[0],A[1])+o(k))}},e.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots[p],n=0;n<r.length;n++)e[r[n]]._subplot.updateFx(e)}},51276:function(t,e,r){\"use strict\";var n=r(34809),i=r(30635).sanitizeHTML,a=r(2178),o=r(44245);function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{\"icon-image\":i.icon+\"-15\",\"icon-size\":i.iconsize/10,\"text-field\":i.text,\"text-size\":i.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":i.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":i.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||JSON.stringify(this.source)!==JSON.stringify(t.source)||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.lookupBelow=function(){return this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates});var e=this.findFollowingMapboxLayerId(this.lookupBelow());null!==e&&this.subplot.map.moveLayer(this.idLayer,e)},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};return\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",a.tileSize=256):\"image\"===r&&(e=\"url\",a.coordinates=t.coordinates),a[e]=n,t.sourceattribution&&(a.attribution=i(t.sourceattribution)),a}(t);e.addSource(this.idSource,r)}},l.findFollowingMapboxLayerId=function(t){if(\"traces\"===t)for(var e=this.subplot.getMapLayers(),r=0;r<e.length;r++){var n=e[r].id;if(\"string\"==typeof n&&0===n.indexOf(o.traceLayerPrefix)){t=n;break}}return t},l.updateLayer=function(t){var e=this.subplot,r=u(t),n=this.lookupBelow(),i=this.findFollowingMapboxLayerId(n);this.removeLayer(),c(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:r.layout,paint:r.paint},i),this.layerType=t.type,this.below=n},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},t.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},67514:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766).defaultLine,a=r(13792).u,o=r(80337),s=r(36640).textposition,l=r(13582).overrideAll,c=r(78032).templatedArray,u=r(44245),h=o({noFontVariant:!0,noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(t.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},bounds:{west:{valType:\"number\"},east:{valType:\"number\"},south:{valType:\"number\"},north:{valType:\"number\"}},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},86989:function(t,e,r){\"use strict\";var n=r(34809),i=r(4448),a=r(59008),o=r(67514);function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\");var i=r(\"bounds.west\"),o=r(\"bounds.east\"),s=r(\"bounds.south\"),c=r(\"bounds.north\");void 0!==i&&void 0!==o&&void 0!==s&&void 0!==c||delete e.bounds,a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\",void 0,{noFontVariant:!0,noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0}),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}t.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},5417:function(t,e,r){\"use strict\";var n=r(32280),i=r(34809),a=r(3994),o=r(33626),s=r(29714),l=r(14751),c=r(32141),u=r(70414),h=u.drawMode,f=u.selectMode,p=r(44844).prepSelect,d=r(44844).clearOutline,m=r(44844).clearSelectionsCache,g=r(44844).selectOnClick,y=r(44245),v=r(51276);function x(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=x.prototype;_.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash={},i.layerList=[]),n=i.map?new Promise((function(r,n){i.updateMap(t,e,r,n)})):new Promise((function(r,n){i.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,i){var o=this,s=e[o.id],l=o.styleObj=w(s.style,e);o.accessToken=s.accesstoken;var c=s.bounds,u=c?[[c.west,c.south],[c.east,c.north]]:null,h=o.map=new n.Map({container:o.div,style:l.style,center:k(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,maxBounds:u,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));h._canvas.style.left=\"0px\",h._canvas.style.top=\"0px\",o.rejectOnError(i),o.isStatic||o.initFx(t,e);var f=[];f.push(new Promise((function(t){h.once(\"load\",t)}))),f=f.concat(a.fetchTraceGeoData(t)),Promise.all(f).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(i)},_.updateMap=function(t,e,r,n){var i=this,o=i.map,s=e[this.id];i.rejectOnError(n);var l=[],c=w(s.style,e);JSON.stringify(i.styleObj)!==JSON.stringify(c)&&(i.styleObj=c,o.setStyle(c.style),i.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(a.fetchTraceGeoData(t)),Promise.all(l).then((function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var b={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function w(t,e){var r={};if(i.isPlainObject(t))r.id=t.id,r.style=t;else if(\"string\"==typeof t)if(r.id=t,-1!==y.styleValuesMapbox.indexOf(t))r.style=T(t);else if(y.stylesNonMapbox[t]){r.style=y.stylesNonMapbox[t];var n=r.style.sources[\"plotly-\"+t],a=n?n.tiles:void 0;a&&a[0]&&\"?api_key=\"===a[0].slice(-9)&&(a[0]+=e._mapboxAccessToken)}else r.style=t;else r.id=y.styleValueDflt,r.style=T(y.styleValueDflt);return r.transition={duration:0,delay:0},r}function T(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}function k(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort((function(t,e){return b[t[0].trace.type]-b[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=a[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(a[r.uid]=r._module.plot(this,s))}var c=Object.keys(a);t:for(n=0;n<c.length;n++){var u=c[n];for(i=0;i<t.length;i++)if(u===(r=t[i][0].trace).uid)continue t;(e=a[u]).dispose(),delete a[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(k(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function a(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}i.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var i=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}})),i.on(\"wheel\",(function(){r.wheeling=!0})),i.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect(),a=[t.originalEvent.offsetX,t.originalEvent.offsetY];t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return i.unproject(a).lng},r.yaxis.p2c=function(){return i.unproject(a).lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),i.on(\"dragstart\",(function(){r.dragging=!0,a()})),i.on(\"zoomstart\",a),i.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),i.on(\"drag\",s),i.on(\"zoom\",s),i.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(k(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))})),r.clearOutline=function(){m(r.dragOptions),d(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&g(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a=function(t,r){r.isRect?(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]:(t.lassoPoints={})[e.id]=r.map(c)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),f(o)||h(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearOutline),e.dragOptions.prepFn=function(t,r,n){p(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearOutline),e.div.onmousedown=null,e.div.ontouchstart=null,e.div.removeEventListener(\"touchstart\",e.div._ontouchstart),e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(v(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),i=parseInt(n.style.width),a=parseInt(n.style.height);return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([i,0]).toArray(),t.unproject([i,a]).toArray(),t.unproject([0,a]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},t.exports=x},57891:function(t){\"use strict\";t.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},44122:function(t,e,r){\"use strict\";var n=r(45568),i=r(42696).de,a=r(36464).OE,o=r(10721),s=r(93229),l=r(33626),c=r(57297),u=r(78032),h=r(34809),f=r(78766),p=r(63821).BADNUM,d=r(5975),m=r(78534).clearOutline,g=r(26667),y=r(49722),v=r(58935),x=r(4173).eV,_=h.relinkPrivateKeys,b=h._,w=t.exports={};h.extendFlat(w,l),w.attributes=r(9829),w.attributes.type.values=w.allTypes,w.fontAttrs=r(80337),w.layoutAttributes=r(6704);var T=w.transformsRegistry,k=r(90251);w.executeAPICommand=k.executeAPICommand,w.computeAPICommandBindings=k.computeAPICommandBindings,w.manageCommandObserver=k.manageCommandObserver,w.hasSimpleAPICommandBindings=k.hasSimpleAPICommandBindings,w.redrawText=function(t){return t=h.getGraphDiv(t),new Promise((function(e){setTimeout((function(){t._fullLayout&&(l.getComponentMethod(\"annotations\",\"draw\")(t),l.getComponentMethod(\"legend\",\"draw\")(t),l.getComponentMethod(\"colorbar\",\"draw\")(t),e(w.previousPromises(t)))}),300)}))},w.resize=function(t){var e;t=h.getGraphDiv(t);var r=new Promise((function(r,n){t&&!h.isHidden(t)||n(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout((function(){if(!t.layout||t.layout.width&&t.layout.height||h.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,l.call(\"relayout\",t,{autosize:!0}).then((function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))}))}}),100)}));return e&&e(r),r},w.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then((function(){t._promises=[]}))},w.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=h.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",(function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:f.defaultLine,\"pointer-events\":\"all\"}).each((function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)}))})),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),l=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",(function(){w.sendDataToCloud(t)}));else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&l.text()?\" - \":\"\")}},w.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit(\"plotly_beforeexport\");var r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=w.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1}};var A=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],M=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function S(t,e){var r=t._context.locale;r||(r=\"en-US\");var n=!1,i={};function a(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var o=0;o<2;o++){for(var s=t._context.locales,c=0;c<2;c++){var u=(s[r]||{}).format;if(u&&(a(u),n))break;s=l.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||a(l.localeRegistry.en.format),i}function E(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],h=n?t._id+u:u+t._id;o||(o=h);var f=d.getFromId(r,u);if(s&&f.overlaying===s){a=h;break}}}return a||o}function C(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||T[n.type];if(i&&i.makesData)return!0}return!1}function L(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=T[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function I(t){return\"string\"==typeof t&&\"px\"===t.substr(t.length-2)&&parseFloat(t)}function P(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={}),t._reservedMargin||(t._reservedMargin={})}w.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,n=t._fullLayout||{};if(n._skipDefaults)delete n._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],f=t._fullData=[],p=t.data||[],d=t.calcdata||[],g=t._context||{};t._transitionData||w.createTransitionData(t),s._dfltTitle={plot:b(t,\"Click to enter Plot title\"),subtitle:b(t,\"Click to enter Plot subtitle\"),x:b(t,\"Click to enter X axis title\"),y:b(t,\"Click to enter Y axis title\"),colorbar:b(t,\"Click to enter Colorscale title\"),annotation:b(t,\"new text\")},s._traceWord=b(t,\"trace\");var y=S(t,A);if(s._mapboxAccessToken=g.mapboxAccessToken,n._initialAutoSizeIsDone){var v=n.width,x=n.height;w.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=v),c.height||(s.height=x),w.sanitizeMargins(s)}else{w.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,k=s.autosize,E=g.autosizable;T&&(k||E)?w.plotAutoSize(t,c,s):T&&w.sanitizeMargins(s),!k&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),{numberFormat:function(e){try{e=a(t).format(h.adjustFormat(e))}catch(t){return h.warnBadFormat(e),h.noFormat}return e},timeFormat:i(t).utcFormat}}(y,s.separators),s._extraFormat=S(t,M),s._initialAutoSizeIsDone=!0,s._dataLength=p.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var C=s._subplots=function(){var t,e,r=l.collectableSubplotTypes,n={};if(!r){r=[];var i=l.subplotsRegistry;for(var a in i){var o=i[a].attr;if(o&&(r.push(a),Array.isArray(o)))for(e=0;e<o.length;e++)h.pushUnique(r,o[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),L=s._splomAxes={x:{},y:{}},I=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,l=new Array(i),c={};function u(t,e){l[e]=t,c[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!c[t])return u(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||r<s&&f(a[r].uid,r)||u(h.randstr(c),r)}return l}(u,p),s._globalTransforms=(t._context||{}).globalTransforms,w.supplyDataDefaults(p,f,c,s);var z=Object.keys(L.x),O=Object.keys(L.y);if(z.length>1&&O.length>1){for(l.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<z.length;o++)h.pushUnique(C.xaxis,z[o]);for(o=0;o<O.length;o++)h.pushUnique(C.yaxis,O[o]);for(var D in I)h.pushUnique(C.cartesian,D)}if(s._has=w._hasPlotType.bind(s),u.length===f.length)for(o=0;o<f.length;o++)_(f[o],u[o]);w.supplyLayoutModuleDefaults(c,s,f,t._transitionData);var R=s._visibleModules,F=[];for(o=0;o<R.length;o++){var B=R[o].crossTraceDefaults;B&&h.pushUnique(F,B)}for(o=0;o<F.length;o++)F[o](f,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&z.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,w.linkSubplots(f,s,u,n),w.cleanPlot(f,s,u,n);var N=!(!n._has||!n._has(\"gl2d\")),j=!(!s._has||!s._has(\"gl2d\")),U=!(!n._has||!n._has(\"cartesian\"))||N,V=!(!s._has||!s._has(\"cartesian\"))||j;U&&!V?n._bgLayer.remove():V&&!U&&(s._shouldCreateBgLayer=!0),n._zoomlayer&&!t._dragging&&m({_fullLayout:n}),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(f,s),_(s,n),l.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(f,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var q,H=s._tracePreGUI,G={};for(q in H)G[q]=\"old\";for(o=0;o<f.length;o++)G[q=f[o]._fullInput.uid]||(H[q]={}),G[q]=\"new\";for(q in G)\"old\"===G[q]&&delete H[q];P(s),l.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||d.length!==f.length||w.supplyDefaultsUpdateCalc(d,f)}},w.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,l,c=a._arrayAttrs;for(o=0;o<c.length;o++)s=c[o],l=h.nestedProperty(a,s).get().slice(),h.nestedProperty(n,s).set(l)}i.trace=n}}},w.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},w._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var a=l.modules[i];if(a&&a.categories[t])return!0}return!1},w.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++)if(h===t[a].uid)continue t;u&&n._infolayer.select(\".cb\"+h).remove()}},w.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,m=f[i],g=o[m],y=d.getFromId(u,m,\"x\"),v=d.getFromId(u,m,\"y\");for(g?p=s[m]=g:(p=s[m]={}).id=m,y._counterAxes.push(v._id),v._counterAxes.push(y._id),y._subplotsWith.push(m),v._subplotsWith.push(m),p.xaxis=y,p.yaxis=v,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var x=t[a];if(x.xaxis===p.xaxis._id&&x.yaxis===p.yaxis._id&&!1===x.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var _,b=d.list(u,null,!0);for(i=0;i<b.length;i++){var w=null;(_=b[i]).overlaying&&(w=d.getFromId(u,_.overlaying))&&w.overlaying&&(_.overlaying=!1,w=null),_._mainAxis=w||_,w&&(_.domain=w.domain.slice()),_._anchorAxis=\"free\"===_.anchor?null:d.getFromId(u,_.anchor)}for(i=0;i<b.length;i++)if((_=b[i])._counterAxes.sort(d.idSort),_._subplotsWith.sort(h.subplotSort),_._mainSubplot=E(_,e),_._counterAxes.length&&(_.spikemode&&-1!==_.spikemode.indexOf(\"across\")||_.automargin&&_.mirror&&\"free\"!==_.anchor||l.getComponentMethod(\"rangeslider\",\"isVisible\")(_))){var T=1,k=0;for(a=0;a<_._counterAxes.length;a++){var A=d.getFromId(u,_._counterAxes[a]);T=Math.min(T,A.domain[0]),k=Math.max(k,A.domain[1])}T<k&&(_._counterDomainMin=T,_._counterDomainMax=k)}},w.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],c.crawl(t._module.attributes,(function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))}))),n=0;n<e.length;n++)h.nestedProperty(t,\"_input.\"+e[n]).get()||h.nestedProperty(t,e[n]).set(null)},w.supplyDataDefaults=function(t,e,r,n){var i,a,o,s=n._modules,c=n._visibleModules,f=n._basePlotModules,p=0,d=0;function m(t){e.push(t);var r=t._module;r&&(h.pushUnique(s,r),!0===t.visible&&h.pushUnique(c,r),h.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var g={},y=[],v=(r.template||{}).data||{},x=u.traceTemplater(v);for(i=0;i<t.length;i++){if(o=t[i],(a=x.newTrace(o)).uid=n._traceUids[i],w.supplyTraceDefaults(o,a,d,n,i),a.index=i,a._input=o,a._expandedIndex=p,a.transforms&&a.transforms.length)for(var b=!1!==o.visible&&!1===a.visible,T=L(a,e,r,n),k=0;k<T.length;k++){var A=T[k],M={_template:a._template,type:a.type,uid:a.uid+k};b&&!1===A.visible&&delete A.visible,w.supplyTraceDefaults(A,M,p,n,i),_(M,A),M.index=i,M._input=o,M._fullInput=a,M._expandedIndex=p,M._expandedInput=A,m(M)}else a._fullInput=a,a._expandedInput=a,m(a);l.traceIs(a,\"carpetAxis\")&&(g[a.carpet]=a),l.traceIs(a,\"carpetDependent\")&&y.push(i)}for(i=0;i<y.length;i++)if((a=e[y[i]]).visible){var S=g[a.carpet];a._carpet=S,S&&S.visible?(a.xaxis=S.xaxis,a.yaxis=S.yaxis):a.visible=!1}},w.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return h.coerce(t||{},r,y,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=w.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=w.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=w.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=w.supplyAnimationTransitionDefaults(t.transition||{});return r},w.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return h.coerce(t||{},e,y.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},w.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return h.coerce(t||{},e,y.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},w.supplyFrameDefaults=function(t){var e={};function r(r,n){return h.coerce(t,e,v,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},w.supplyTraceDefaults=function(t,e,r,n,i){var a,o=n.colorway||f.defaults,s=o[r%o.length];function c(r,n){return h.coerce(t,e,w.attributes,r,n)}var u=c(\"visible\");c(\"type\"),c(\"name\",n._traceWord+\" \"+i),c(\"uirevision\",n.uirevision);var p=w.getModule(e);if(e._module=p,p){var d=p.basePlotModule,m=d.attr,g=d.attributes;if(m&&g){var y=n._subplots,v=\"\";if(u||\"gl2d\"!==d.name){if(Array.isArray(m))for(a=0;a<m.length;a++){var x=m[a],_=h.coerce(t,e,g,x);y[x]&&h.pushUnique(y[x],_),v+=_}else v=h.coerce(t,e,g,m);y[d.name]&&h.pushUnique(y[d.name],v)}}}if(u){if(c(\"customdata\"),c(\"ids\"),c(\"meta\"),l.traceIs(e,\"showLegend\")?(h.coerce(t,e,p.attributes.showlegend?p.attributes:w.attributes,\"showlegend\"),c(\"legend\"),c(\"legendwidth\"),c(\"legendgroup\"),c(\"legendgrouptitle.text\"),c(\"legendrank\"),e._dfltShowLegend=!0):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,s,n),l.traceIs(e,\"noOpacity\")||c(\"opacity\"),l.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),l.traceIs(e,\"noHover\")||(e.hovertemplate||h.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&l.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,s,n)),p&&p.selectPoints){var b=c(\"selectedpoints\");h.isTypedArray(b)&&(e.selectedpoints=Array.from(b))}w.supplyTransformDefaults(t,e,n)}return e},w.hasMakesDataTransform=C,w.supplyTransformDefaults=function(t,e,r){if(e._length||C(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],l=0;l<o.length;l++){var c,u=o[l],f=u.type,p=T[f],d=!(u._module&&u._module===p),m=p&&\"function\"==typeof p.transform;p||h.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||m)?((c=p.supplyDefaults(u,e,r,t)).type=f,c._module=p,h.pushUnique(i,p)):c=h.extendFlat({},u),s.push(c)}}},w.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return h.coerce(t,e,w.layoutAttributes,r,n)}var i=t.template;h.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data),n(\"autotypenumbers\");var a=h.coerceFont(n,\"font\"),o=a.size;h.coerceFont(n,\"title.font\",a,{overrideDflt:{size:Math.round(1.4*o)}}),n(\"title.text\",e._dfltTitle.plot),n(\"title.xref\");var s=n(\"title.yref\");n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\");var c=n(\"title.automargin\");n(\"title.x\"),n(\"title.xanchor\"),n(\"title.y\"),n(\"title.yanchor\"),n(\"title.subtitle.text\",e._dfltTitle.subtitle),h.coerceFont(n,\"title.subtitle.font\",a,{overrideDflt:{size:Math.round(.7*e.title.font.size)}}),c&&(\"paper\"===s&&(0!==e.title.y&&(e.title.y=1),\"auto\"===e.title.yanchor&&(e.title.yanchor=0===e.title.y?\"top\":\"bottom\")),\"container\"===s&&(\"auto\"===e.title.y&&(e.title.y=1),\"auto\"===e.title.yanchor&&(e.title.yanchor=e.title.y<.5?\"bottom\":\"top\"))),n(\"uniformtext.mode\")&&n(\"uniformtext.minsize\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"minreducedwidth\"),n(\"minreducedheight\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&w.sanitizeMargins(e),l.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var u=n(\"uirevision\");n(\"editrevision\",u),n(\"selectionrevision\",u),l.getComponentMethod(\"modebar\",\"supplyLayoutDefaults\")(t,e),l.getComponentMethod(\"shapes\",\"supplyDrawNewShapeDefaults\")(t,e,n),l.getComponentMethod(\"selections\",\"supplyDrawNewSelectionDefaults\")(t,e,n),n(\"meta\"),h.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),l.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),l.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n),h.coerce(t,e,g,\"scattermode\")},w.plotAutoSize=function(t,e,r){var n,i,a=t._context||{},s=a.frameMargins,l=h.isPlotDiv(t);if(l&&t.emit(\"plotly_autosize\"),a.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow=\"hidden\";else{var c=l?window.getComputedStyle(t):{};if(n=I(c.width)||I(c.maxWidth)||r.width,i=I(c.height)||I(c.maxHeight)||r.height,o(s)&&s>0){var u=1-2*s;n=Math.round(u*n),i=Math.round(u*i)}}var f=w.layoutAttributes.width.min,p=w.layoutAttributes.height.min;n<f&&(n=f),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,m=!e.height&&Math.abs(r.height-i)>1;(m||d)&&(d&&(r.width=n),m&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),w.sanitizeMargins(r)},w.supplyLayoutModuleDefaults=function(t,e,r,n){var i,a,o,s=l.componentsRegistry,c=e._basePlotModules,u=l.subplotsRegistry.cartesian;for(i in s)(o=s[i]).includeBasePlot&&o.includeBasePlot(t,e);for(var f in c.length||c.push(u),e._has(\"cartesian\")&&(l.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),u.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(h.subplotSort);for(a=0;a<c.length;a++)(o=c[a]).supplyLayoutDefaults&&o.supplyLayoutDefaults(t,e,r);var p=e._modules;for(a=0;a<p.length;a++)(o=p[a]).supplyLayoutDefaults&&o.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(a=0;a<d.length;a++)(o=d[a]).supplyLayoutDefaults&&o.supplyLayoutDefaults(t,e,r,n);for(i in s)(o=s[i]).supplyLayoutDefaults&&o.supplyLayoutDefaults(t,e,r)},w.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),h.clearThrottle(),h.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},w.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&h.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},w.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},w.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},w.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},w.autoMargin=function(t,e,r){var n=t._fullLayout,i=n.width,a=n.height,o=n.margin,s=n.minreducedwidth,l=n.minreducedheight,c=h.constrain(i-o.l-o.r,2,s),u=h.constrain(a-o.t-o.b,2,l),f=Math.max(0,i-c),p=Math.max(0,a-u),d=n._pushmargin,m=n._pushmarginIds;if(!1!==o.autoexpand){if(r){var g=r.pad;if(void 0===g&&(g=Math.min(12,o.l,o.r,o.t,o.b)),f){var y=(r.l+r.r)/f;y>1&&(r.l/=y,r.r/=y)}if(p){var v=(r.t+r.b)/p;v>1&&(r.t/=v,r.b/=v)}var x=void 0!==r.xl?r.xl:r.x,_=void 0!==r.xr?r.xr:r.x,b=void 0!==r.yt?r.yt:r.y,T=void 0!==r.yb?r.yb:r.y;d[e]={l:{val:x,size:r.l+g},r:{val:_,size:r.r+g},b:{val:T,size:r.b+g},t:{val:b,size:r.t+g}},m[e]=1}else delete d[e],delete m[e];if(!n._replotting)return w.doAutoMargin(t)}},w.doAutoMargin=function(t){var e=t._fullLayout,r=e.width,n=e.height;e._size||(e._size={}),P(e);var i=e._size,a=e.margin,s={t:0,b:0,l:0,r:0},c=h.extendFlat({},i),u=a.l,f=a.r,p=a.t,m=a.b,g=e._pushmargin,y=e._pushmarginIds,v=e.minreducedwidth,x=e.minreducedheight;if(!1!==a.autoexpand){for(var _ in g)y[_]||delete g[_];var b=t._fullLayout._reservedMargin;for(var T in b)for(var k in b[T]){var A=b[T][k];s[k]=Math.max(s[k],A)}for(var M in g.base={l:{val:0,size:u},r:{val:1,size:f},t:{val:1,size:p},b:{val:0,size:m}},s){var S=0;for(var E in g)\"base\"!==E&&o(g[E][M].size)&&(S=g[E][M].size>S?g[E][M].size:S);var C=Math.max(0,a[M]-S);s[M]=Math.max(0,s[M]-C)}for(var L in g){var I=g[L].l||{},z=g[L].b||{},O=I.val,D=I.size,R=z.val,F=z.size,B=r-s.r-s.l,N=n-s.t-s.b;for(var j in g){if(o(D)&&g[j].r){var U=g[j].r.val,V=g[j].r.size;if(U>O){var q=(D*U+(V-B)*O)/(U-O),H=(V*(1-O)+(D-B)*(1-U))/(U-O);q+H>u+f&&(u=q,f=H)}}if(o(F)&&g[j].t){var G=g[j].t.val,Z=g[j].t.size;if(G>R){var W=(F*G+(Z-N)*R)/(G-R),Y=(Z*(1-R)+(F-N)*(1-G))/(G-R);W+Y>m+p&&(m=W,p=Y)}}}}}var X=h.constrain(r-a.l-a.r,2,v),$=h.constrain(n-a.t-a.b,2,x),J=Math.max(0,r-X),K=Math.max(0,n-$);if(J){var Q=(u+f)/J;Q>1&&(u/=Q,f/=Q)}if(K){var tt=(m+p)/K;tt>1&&(m/=tt,p/=tt)}if(i.l=Math.round(u)+s.l,i.r=Math.round(f)+s.r,i.t=Math.round(p)+s.t,i.b=Math.round(m)+s.b,i.p=Math.round(a.pad),i.w=Math.round(r)-i.l-i.r,i.h=Math.round(n)-i.t-i.b,!e._replotting&&(w.didMarginChange(c,i)||function(t){if(\"_redrawFromAutoMarginCount\"in t._fullLayout)return!1;var e=d.list(t,\"\",!0);for(var r in e)if(e[r].autoshift||e[r].shift)return!0;return!1}(t))){\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var et=3*(1+Object.keys(y).length);if(e._redrawFromAutoMarginCount<et)return l.call(\"_doPlot\",t);e._size=c,h.warn(\"Too many auto-margin redraws.\")}!function(t){var e=d.list(t,\"\",!0);[\"_adjustTickLabelsOverflow\",\"_hideCounterAxisInsideTickLabels\"].forEach((function(t){for(var r=0;r<e.length;r++){var n=e[r][t];n&&n()}}))}(t)};var z=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function O(t,e,r){var n=!1,i=[w.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,w.rehover,w.reselect,function(){return t.emit(\"plotly_transitioning\",[]),new Promise((function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push((function(){n=!0})),r.redraw&&t._transitionData._interruptCallbacks.push((function(){return l.call(\"redraw\",t)})),t._transitionData._interruptCallbacks.push((function(){t.emit(\"plotly_transitioninterrupted\",[])}));var a=0,o=0;function s(){return a++,function(){var e;o++,n||o!==a||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then((function(){if(r.redraw)return l.call(\"redraw\",t)})).then((function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])})).then(e)))}}r.runFn(s),setTimeout(s())}))}],a=h.syncOrAsync(i,t);return a&&a.then||(a=Promise.resolve()),a.then((function(){return t}))}w.didMarginChange=function(t,e){for(var r=0;r<z.length;r++){var n=z[r],i=t[n],a=e[n];if(!o(i)||Math.abs(a-i)>1)return!0}return!1},w.graphJson=function(t,e,r,n,i,a){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&w.supplyDefaults(t);var o=i?t._fullData:t.data,l=i?t._fullLayout:t.layout,c=(t._transitionData||{})._frames;function u(t,e){if(\"function\"==typeof t)return e?\"_function_\":null;if(h.isPlainObject(t)){var n,i={};return Object.keys(t).sort().forEach((function(a){if(-1===[\"_\",\"[\"].indexOf(a.charAt(0)))if(\"function\"!=typeof t[a]){if(\"keepdata\"===r){if(\"src\"===a.substr(a.length-3))return}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0&&!h.isPlainObject(t.stream))return}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0)return;i[a]=u(t[a],e)}else e&&(i[a]=\"_function\")})),i}var a=Array.isArray(t),o=h.isTypedArray(t);if((a||o)&&t.dtype&&t.shape){var l=t.bdata;return u({dtype:t.dtype,shape:t.shape,bdata:h.isArrayBuffer(l)?s.encode(l):l},e)}return a?t.map((function(t){return u(t,e)})):o?h.simpleMap(t,h.identity):h.isJSDate(t)?h.ms2DateTimeLocal(+t):t}var f={data:(o||[]).map((function(t){var r=u(t);return e&&delete r.fit,r}))};if(!e&&(f.layout=u(l),i)){var p=l._size;f.layout.computed={margin:{b:p.b,l:p.l,r:p.r,t:p.t}}}return c&&(f.frames=u(c)),a&&(f.config=u(t._context,!0)),\"object\"===n?f:JSON.stringify(f)},w.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},w.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=w.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=w.extendTrace(u.data[a],s.data[r]))}return u},w.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},w.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,l,c,u=h.extendDeepNoArrays({},e||{}),f=h.expandObjectPaths(u),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=h.nestedProperty(f,r[a])).get())?h.nestedProperty(p,r[a]).set(null):(n.set(null),h.nestedProperty(p,r[a]).set(i));if(t=h.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(l=h.nestedProperty(p,r[a]).get()){for(c=(s=h.nestedProperty(t,r[a])).get(),Array.isArray(c)||(c=[],s.set(c)),o=0;o<l.length;o++){var d=l[o];c[o]=null===d?null:w.extendObjectWithContainers(c[o],d)}s.set(c)}return t},w.dataArrayContainers=[\"transforms\",\"dimensions\"],w.layoutArrayContainers=l.layoutArrayContainers,w.extendTrace=function(t,e){return w.extendObjectWithContainers(t,e,w.dataArrayContainers)},w.extendLayout=function(t,e){return w.extendObjectWithContainers(t,e,w.layoutArrayContainers)},w.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},l=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var c=a[o],u=t._fullData[c]._module;if(u){if(u.animatable){var f=u.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(c)}t.data[a[o]]=w.extendTrace(t.data[a[o]],e[o])}}var p=h.expandObjectPaths(h.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var m in p)d.test(m)&&delete p[m].range;w.extendLayout(t.layout,p),delete t.calcdata,w.supplyDefaults(t),w.doCalcdata(t);var g=h.expandObjectPaths(r);if(g){var y=t._fullLayout._plots;for(var v in y){var x=y[v],_=x.xaxis,b=x.yaxis,T=_.range.slice(),k=b.range.slice(),A=null,M=null,S=null,E=null;Array.isArray(g[_._name+\".range\"])?A=g[_._name+\".range\"].slice():Array.isArray((g[_._name]||{}).range)&&(A=g[_._name].range.slice()),Array.isArray(g[b._name+\".range\"])?M=g[b._name+\".range\"].slice():Array.isArray((g[b._name]||{}).range)&&(M=g[b._name].range.slice()),T&&A&&(_.r2l(T[0])!==_.r2l(A[0])||_.r2l(T[1])!==_.r2l(A[1]))&&(S={xr0:T,xr1:A}),k&&M&&(b.r2l(k[0])!==b.r2l(M[0])||b.r2l(k[1])!==b.r2l(M[1]))&&(E={yr0:k,yr1:M}),(S||E)&&l.push(h.extendFlat({plotinfo:x},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,c=l.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,l,a,e);for(var u in c?((n=h.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[u];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},O(t,a,o)},w.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var l=t[a],c=l.xaxis,u=l.yaxis,f=n[c._name].range.slice(),p=n[u._name].range.slice(),d=c.range.slice(),m=u.range.slice();c.setScale(),u.setScale();var g=null,y=null;c.r2l(f[0])===c.r2l(d[0])&&c.r2l(f[1])===c.r2l(d[1])||(g={xr0:f,xr1:d}),u.r2l(p[0])===u.r2l(m[0])&&u.r2l(p[1])===u.r2l(m[1])||(y={yr0:p,yr1:m}),(g||y)&&s.push(h.extendFlat({plotinfo:l},g,y))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,l=t._fullData,c=t._fullLayout._basePlotModules,u=[],f=0;f<l.length;f++)u.push(f);function p(){if(t._fullLayout)for(var e=0;e<c.length;e++)c[e].transitionAxes&&c[e].transitionAxes(t,s,n,r)}function d(){if(t._fullLayout)for(var e=0;e<c.length;e++)c[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=h.extendFlat({},a,{duration:0}),o=u,i=a,setTimeout(p,a.duration),d()):(n=a,o=null,i=h.extendFlat({},a,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=a,p()):e.anim&&(o=u,i=a,d())},O(t,a,o)},w.doCalcdata=function(t,e){var r,n,i,a,o=d.list(t),s=t._fullData,u=t._fullLayout,f=new Array(s.length),m=(t.calcdata||[]).slice();for(t.calcdata=f,u._numBoxes=0,u._numViolins=0,u._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,u._piecolormap={},u._sunburstcolormap={},u._treemapcolormap={},u._iciclecolormap={},u._funnelareacolormap={},i=0;i<s.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(f[i]=m[i]);for(i=0;i<s.length;i++)(r=s[i])._arrayAttrs=c.findArrayAttributes(r),r._extremes={};var g=u._subplots.polar||[];for(i=0;i<g.length;i++)o.push(u[g[i]].radialaxis,u[g[i]].angularaxis);for(var y in u._colorAxes){var v=u[y];!1!==v.cauto&&(delete v.cmin,delete v.cmax)}var x=!1;function _(e){if(r=s[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(a=0;a<r.transforms.length;a++){var o=r.transforms[a];(n=T[o.type])&&n.calcTransform&&(r._hasCalcTransform=!0,x=!0,n.calcTransform(t,r,o))}}}function b(e,i){if(r=s[e],!!(n=r._module).isContainer===i){var o=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var l=r.transforms||[];for(a=l.length-1;a>=0;a--)if(l[a].enabled){r._indexToPoints=l[a]._indexToPoints;break}n&&n.calc&&(o=n.calc(t,r))}Array.isArray(o)&&o[0]||(o=[{x:p,y:p}]),o[0].t||(o[0].t={}),o[0].trace=r,f[e]=o}}for(R(o,s,u),i=0;i<s.length;i++)b(i,!0);for(i=0;i<s.length;i++)_(i);for(x&&R(o,s,u),i=0;i<s.length;i++)b(i,!0);for(i=0;i<s.length;i++)b(i,!1);F(t);var w=function(t,e){var r,n,i,a,o,s=[];function c(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=d.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e||s&&t===n[e].length-1||l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var u={min:function(t){return h.aggNums(Math.min,null,t)},max:function(t){return h.aggNums(Math.max,null,t)},sum:function(t){return h.aggNums((function(t,e){return t+e}),null,t)},total:function(t){return h.aggNums((function(t,e){return t+e}),null,t)},mean:function(t){return h.mean(t)},\"geometric mean\":function(t){return h.geometricMean(t)},median:function(t){return h.median(t)}};function f(t,e){return t[1]-e[1]}function p(t,e){return e[1]-t[1]}for(r=0;r<t.length;r++){var m=t[r];if(\"category\"===m.type){var g=m.categoryorder.match(D);if(g){var y=g[1],v=g[2],x=m._id.charAt(0),_=\"x\"===x,b=[];for(n=0;n<m._categories.length;n++)b.push([m._categories[n],[]]);for(n=0;n<m._traceIndices.length;n++){var w=m._traceIndices[n],T=e._fullData[w];if(!0===T.visible){var k=T.type;l.traceIs(T,\"histogram\")&&(delete T._xautoBinFinished,delete T._yautoBinFinished);var A=\"splom\"===k,M=\"scattergl\"===k,S=e.calcdata[w];for(i=0;i<S.length;i++){var E,C,L=S[i];if(A){var I=T._axesDim[m._id];if(!_){var P=T._diag[I][0];P&&(m=e._fullLayout[d.id2name(P)])}var z=L.trace.dimensions[I].values;for(a=0;a<z.length;a++)for(E=m._categoriesMap[z[a]],o=0;o<L.trace.dimensions.length;o++)if(o!==I){var O=L.trace.dimensions[o];b[E][1].push(O.values[a])}}else if(M){for(a=0;a<L.t.x.length;a++)_?(E=L.t.x[a],C=L.t.y[a]):(E=L.t.y[a],C=L.t.x[a]),b[E][1].push(C);L.t&&L.t._scene&&delete L.t._scene.dirty}else if(L.hasOwnProperty(\"z\")){C=L.z;var R=c(T.type,m,C);for(a=0;a<C.length;a++)for(o=0;o<C[a].length;o++)(E=R(o,a))+1&&b[E][1].push(C[a][o])}else for(void 0===(E=L.p)&&(E=L[x]),void 0===(C=L.s)&&(C=L.v),void 0===C&&(C=_?L.y:L.x),Array.isArray(C)||(C=void 0===C?[]:[C]),a=0;a<C.length;a++)b[E][1].push(C[a])}}}m._categoriesValue=b;var F=[];for(n=0;n<b.length;n++)F.push([b[n][0],u[y](b[n][1])]);F.sort(\"descending\"===v?p:f),m._categoriesAggregatedValue=F,m._initialCategories=F.map((function(t){return t[0]})),s=s.concat(m.sortByInitialCategories())}}}return s}(o,t);if(w.length){for(u._numBoxes=0,u._numViolins=0,i=0;i<w.length;i++)b(w[i],!0);for(i=0;i<w.length;i++)b(w[i],!1);F(t)}l.getComponentMethod(\"fx\",\"calc\")(t),l.getComponentMethod(\"errorbars\",\"calc\")(t)};var D=/(total|sum|min|max|mean|geometric mean|median) (ascending|descending)/;function R(t,e,r){var n={};function i(t){t.clearCalc(),\"multicategory\"===t.type&&t.setupMultiCategory(e),n[t._id]=1}h.simpleMap(t,i);for(var a=r._axisMatchGroups||[],o=0;o<a.length;o++)for(var s in a[o])n[s]||i(r[d.id2name(s)])}function F(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],l=s.crossTraceCalc;if(l){var c=s.basePlotModule.name;o[c]?h.pushUnique(o[c],l):o[c]=[l]}}for(n in o){var u=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<u.length;r++)u[r](t,d,p)}else for(r=0;r<u.length;r++)u[r](t)}}w.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},w.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},w.reselect=function(t){var e=t._fullLayout,r=(t.layout||{}).selections,n=e._previousSelections;e._previousSelections=r;var i=e._reselect||JSON.stringify(r)!==JSON.stringify(n);l.getComponentMethod(\"selections\",\"reselect\")(t,i)},w.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],l=s[0].trace;l.visible&&(o[l.type]=o[l.type]||[],o[l.type].push(s))}for(var c in a)if(!o[c]){var u=a[c][0];u[0].trace.visible=!1,o[c]=[u]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,h.filterVisible(p),n)}e.traceHash=o},w.plotBasePlot=function(t,e,r,n,i){var a=l.getModule(t),o=x(e.calcdata,a)[0];a.plot(e,o,n,i)},w.cleanBasePlot=function(t,e,r,n,i){var a=i._has&&i._has(t),o=r._has&&r._has(t);a&&!o&&i[\"_\"+t+\"layer\"].selectAll(\"g.trace\").remove()}},26484:function(t){\"use strict\";t.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},95928:function(t,e,r){\"use strict\";var n=r(34809),i=r(80899).tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function m(t){return n.mod(t,h)}function g(t){return o(t,[e,r])}var y=a(i,(function(t){return g(t)?l(t,e):1/0})),v=d(i[y],i[m(y-1)],e);for(f.push(v),s=y,u=0;u<h;s++,u++){var x=i[m(s)];if(!g(x))break;f.push(p(x))}var _=a(i,(function(t){return g(t)?l(t,r):1/0})),b=d(i[_],i[m(_+1)],r);return f.push(b),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}t.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,(function(e){var r=s(e,t);return r>0?r:1/0})),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},31645:function(t,e,r){\"use strict\";var n=r(4173).fX,i=r(34809).counterRegex,a=r(35785),o=r(26484),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},t.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:r(42219),supplyLayoutDefaults:r(84588),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:r(37703).toSVG}},42219:function(t,e,r){\"use strict\";var n=r(10229),i=r(25829),a=r(13792).u,o=r(34809).extendFlat,s=r(13582).overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth,griddash:i.griddash},\"plot\",\"from-root\"),c=s({tickmode:i.minor.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,ticklabelstep:i.ticklabelstep,showticklabels:i.showticklabels,labelalias:i.labelalias,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorangeoptions:{minallowed:i.autorangeoptions.minallowed,maxallowed:i.autorangeoptions.maxallowed,clipmin:i.autorangeoptions.clipmin,clipmax:i.autorangeoptions.clipmax,include:i.autorangeoptions.include,editType:\"plot\"},autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},minallowed:o({},i.minallowed,{editType:\"plot\"}),maxallowed:o({},i.maxallowed,{editType:\"plot\"}),range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},autotickangles:i.autotickangles,side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:{text:o({},i.title.text,{editType:\"plot\",dflt:\"\"}),font:o({},i.title.font,{editType:\"plot\"}),editType:\"plot\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:i.autotypenumbers,categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),t.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},84588:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(78032),o=r(4448),s=r(4173).KO,l=r(22777),c=r(87433),u=r(12036),h=r(54616),f=r(46473),p=r(97405),d=r(75511),m=r(9666),g=r(42219),y=r(51937),v=r(26484),x=v.axisNames;function _(t,e,r,o){var m=r(\"bgcolor\");o.bgColor=i.combine(m,o.paper_bgcolor);var _=r(\"sector\");r(\"hole\");var w,T=s(o.fullData,v.name,o.id),k=o.layoutOut;function A(t,e){return r(w+\".\"+t,e)}for(var M=0;M<x.length;M++){w=x[M],n.isPlainObject(t[w])||(t[w]={});var S=t[w],E=a.newContainer(e,w);E._id=E._name=w,E._attr=o.id+\".\"+w,E._traceIndices=T.map((function(t){return t._expandedIndex}));var C=v.axisName2dataArray[w],L=b(S,E,A,T,C,o);f(S,E,A,{axData:T,dataAttr:C});var I=A(\"visible\");switch(y(E,e,k),A(\"uirevision\",e.uirevision),E._m=1,w){case\"radialaxis\":A(\"minallowed\"),A(\"maxallowed\");var P,z=A(\"range\"),O=E.getAutorangeDflt(z),D=A(\"autorange\",O);!z||(null!==z[0]||null!==z[1])&&(null!==z[0]&&null!==z[1]||\"reversed\"!==D&&!0!==D)&&(null===z[0]||\"min\"!==D&&\"max reversed\"!==D)&&(null===z[1]||\"max\"!==D&&\"min reversed\"!==D)||(z=void 0,delete E.range,E.autorange=!0,P=!0),P||(D=A(\"autorange\",O=E.getAutorangeDflt(z))),S.autorange=D,D&&(d(A,D,z),\"linear\"!==L&&\"-\"!==L||A(\"rangemode\"),E.isReversed()&&(E._m=-1)),E.cleanRange(\"range\",{dfltRange:[0,1]});break;case\"angularaxis\":if(\"date\"===L){n.log(\"Polar plots do not support date angular axes yet.\");for(var R=0;R<T.length;R++)T[R].visible=!1;L=S.type=E.type=\"linear\"}A(\"linear\"===L?\"thetaunit\":\"period\");var F=A(\"direction\");A(\"rotation\",{counterclockwise:0,clockwise:90}[F])}if(h(S,E,A,E.type,{tickSuffixDflt:\"degrees\"===E.thetaunit?\"\u00b0\":void 0}),I){var B,N,j,U,V,q,H,G,Z,W,Y=o.font||{};N=(B=A(\"color\"))===S.color?B:Y.color,j=Y.size,U=Y.family,V=Y.weight,q=Y.style,H=Y.variant,G=Y.textcase,Z=Y.lineposition,W=Y.shadow,l(S,E,A,E.type),u(S,E,A,E.type,{font:{weight:V,style:q,variant:H,textcase:G,lineposition:Z,shadow:W,color:N,size:j,family:U},noAutotickangles:\"angularaxis\"===w,noTicklabelshift:!0,noTicklabelstandoff:!0}),c(S,E,A,{outerTicks:!0}),p(S,E,A,{dfltColor:B,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:g[w]}),A(\"layer\"),\"radialaxis\"===w&&(A(\"side\"),A(\"angle\",_[0]),A(\"title.text\"),n.coerceFont(A,\"title.font\",{weight:V,style:q,variant:H,textcase:G,lineposition:Z,shadow:W,color:N,size:n.bigFont(j),family:U}))}\"category\"!==L&&A(\"hoverformat\"),E._input=S}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function b(t,e,r,n,i,a){var o=r(\"autotypenumbers\",a.autotypenumbersDflt);if(\"-\"===r(\"type\")){for(var s,l=0;l<n.length;l++)if(n[l].visible){s=n[l];break}s&&s[i]&&(e.type=m(s[i],\"gregorian\",{noMultiCategory:!0,autotypenumbers:o})),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}t.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:g,handleDefaults:_,font:e.font,autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},35785:function(t,e,r){\"use strict\";var n=r(45568),i=r(65657),a=r(33626),o=r(34809),s=o.strRotate,l=o.strTranslate,c=r(78766),u=r(62203),h=r(44122),f=r(29714),p=r(19091),d=r(51937),m=r(32919).doAutoRange,g=r(51680),y=r(14751),v=r(32141),x=r(17240),_=r(44844).prepSelect,b=r(44844).selectOnClick,w=r(44844).clearOutline,T=r(27983),k=r(34823),A=r(71817).redrawReglTraces,M=r(4530).MID_SHIFT,S=r(26484),E=r(95928),C=r(52007),L=C.smith,I=C.reactanceArc,P=C.resistanceArc,z=C.smithTransform,O=o._,D=o.mod,R=o.deg2rad,F=o.rad2deg;function B(t,e,r){this.isSmith=r||!1,this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var n=t._fullLayout,i=\"clip\"+n._uid+e;this.clipIds.forTraces=i+\"-for-traces\",this.clipPaths.forTraces=n._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=n[\"_\"+(r?\"smith\":\"polar\")+\"layer\"].append(\"g\").attr(\"class\",e),this.getHole=function(t){return this.isSmith?0:t.hole},this.getSector=function(t){return this.isSmith?[0,360]:t.sector},this.getRadial=function(t){return this.isSmith?t.realaxis:t.radialaxis},this.getAngular=function(t){return this.isSmith?t.imaginaryaxis:t.angularaxis},r||(this.radialTickLayout=null,this.angularTickLayout=null)}var N=B.prototype;function j(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function U(t,e){return e[o.findIndexOfMin(e,(function(e){return o.angleDist(t,e)}))]}function V(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}t.exports=function(t,e,r){return new B(t,e,r)},N.plot=function(t,e){for(var r=this,n=e[r.id],i=!1,a=0;a<t.length;a++)if(!1===t[a][0].trace.cliponaxis){i=!0;break}r._hasClipOnAxisFalse=i,r.updateLayers(e,n),r.updateLayout(e,n),h.generalUpdatePerTraceModule(r.gd,r,t,n),r.updateFx(e,n),r.isSmith&&(delete n.realaxis.range,delete n.imaginaryaxis.range)},N.updateLayers=function(t,e){var r=this,i=r.isSmith,a=r.layers,o=r.getRadial(e),s=r.getAngular(e),l=S.layerNames,c=l.indexOf(\"frontplot\"),u=l.slice(0,c),h=\"below traces\"===s.layer,f=\"below traces\"===o.layer;h&&u.push(\"angular-line\"),f&&u.push(\"radial-line\"),h&&u.push(\"angular-axis\"),f&&u.push(\"radial-axis\"),u.push(\"frontplot\"),h||u.push(\"angular-line\"),f||u.push(\"radial-line\"),h||u.push(\"angular-axis\"),f||u.push(\"radial-axis\");var p=(i?\"smith\":\"polar\")+\"sublayer\",d=r.framework.selectAll(\".\"+p).data(u,String);d.enter().append(\"g\").attr(\"class\",(function(t){return p+\" \"+t})).each((function(t){var e=a[t]=n.select(this);switch(t){case\"frontplot\":i||e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":a.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}})),d.order()},N.updateLayout=function(t,e){var r=this,n=r.layers,i=t._size,a=r.getRadial(e),o=r.getAngular(e),s=e.domain.x,h=e.domain.y;r.xOffset=i.l+i.w*s[0],r.yOffset=i.t+i.h*(1-h[1]);var f=r.xLength=i.w*(s[1]-s[0]),p=r.yLength=i.h*(h[1]-h[0]),d=r.getSector(e);r.sectorInRad=d.map(R);var m,g,y,v,x,_=r.sectorBBox=function(t){var e,r=t[0],n=t[1]-r,i=D(r,360),a=i+n,o=Math.cos(R(i)),s=Math.sin(R(i)),l=Math.cos(R(a)),c=Math.sin(R(a));return e=i<=90&&a>=90||i>90&&a>=450?1:s<=0&&c<=0?0:Math.max(s,c),[i<=180&&a>=180||i>180&&a>=540?-1:o>=0&&l>=0?0:Math.min(o,l),i<=270&&a>=270||i>270&&a>=630?-1:s>=0&&c>=0?0:Math.min(s,c),a>=360?1:o<=0&&l<=0?0:Math.max(o,l),e]}(d),b=_[2]-_[0],w=_[3]-_[1],T=p/f,k=Math.abs(w/b);T>k?(m=f,x=(p-(g=f*k))/i.h/2,y=[s[0],s[1]],v=[h[0]+x,h[1]-x]):(g=p,x=(f-(m=p/k))/i.w/2,y=[s[0]+x,s[1]-x],v=[h[0],h[1]]),r.xLength2=m,r.yLength2=g,r.xDomain2=y,r.yDomain2=v;var A,M=r.xOffset2=i.l+i.w*y[0],S=r.yOffset2=i.t+i.h*(1-v[1]),E=r.radius=m/b,C=r.innerRadius=r.getHole(e)*E,L=r.cx=M-E*_[0],I=r.cy=S+E*_[3],P=r.cxx=L-M,z=r.cyy=I-S,O=a.side;\"counterclockwise\"===O?(A=O,O=\"top\"):\"clockwise\"===O&&(A=O,O=\"bottom\"),r.radialAxis=r.mockAxis(t,e,a,{_id:\"x\",side:O,_trueSide:A,domain:[C/i.w,E/i.w]}),r.angularAxis=r.mockAxis(t,e,o,{side:\"right\",domain:[0,Math.PI],autorange:!1}),r.doAutoRange(t,e),r.updateAngularAxis(t,e),r.updateRadialAxis(t,e),r.updateRadialAxisTitle(t,e),r.xaxis=r.mockCartesianAxis(t,e,{_id:\"x\",domain:y}),r.yaxis=r.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var F=r.pathSubplot();r.clipPaths.forTraces.select(\"path\").attr(\"d\",F).attr(\"transform\",l(P,z)),n.frontplot.attr(\"transform\",l(M,S)).call(u.setClipUrl,r._hasClipOnAxisFalse?null:r.clipIds.forTraces,r.gd),n.bg.attr(\"d\",F).attr(\"transform\",l(L,I)).call(c.fill,e.bgcolor)},N.mockAxis=function(t,e,r,n){var i=o.extendFlat({},r,n);return d(i,e,t),i},N.mockCartesianAxis=function(t,e,r){var n=this,i=n.isSmith,a=r._id,s=o.extendFlat({type:\"linear\"},r);p(s,t);var l={x:[0,2],y:[1,3]};return s.setRange=function(){var t=n.sectorBBox,r=l[a],i=n.radialAxis._rl,o=(i[1]-i[0])/(1-n.getHole(e));s.range=[t[r[0]]*o,t[r[1]]*o]},s.isPtWithinRange=\"x\"!==a||i?function(){return!0}:function(t){return n.isPtInside(t)},s.setRange(),s.setScale(),s},N.doAutoRange=function(t,e){var r=this,n=r.gd,i=r.radialAxis,a=r.getRadial(e);m(n,i);var o=i.range;if(a.range=o.slice(),a._input.range=o.slice(),i._rl=[i.r2l(o[0],null,\"gregorian\"),i.r2l(o[1],null,\"gregorian\")],void 0!==i.minallowed){var s=i.r2l(i.minallowed);i._rl[0]>i._rl[1]?i._rl[1]=Math.max(i._rl[1],s):i._rl[0]=Math.max(i._rl[0],s)}if(void 0!==i.maxallowed){var l=i.r2l(i.maxallowed);i._rl[0]<i._rl[1]?i._rl[1]=Math.min(i._rl[1],l):i._rl[0]=Math.min(i._rl[0],l)}},N.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,h=r.cx,p=r.cy,d=r.getRadial(e),m=D(r.getSector(e)[0],360),g=r.radialAxis,y=u<a,v=r.isSmith;v||(r.fillViewInitialKey(\"radialaxis.angle\",d.angle),r.fillViewInitialKey(\"radialaxis.range\",g.range.slice()),g.setGeometry()),\"auto\"===g.tickangle&&m>90&&m<=270&&(g.tickangle=180);var x=v?function(t){var e=z(r,L([t.x,0]));return l(e[0]-h,e[1]-p)}:function(t){return l(g.l2p(t.x)+u,0)},_=v?function(t){return P(r,t.x,-1/0,1/0)}:function(t){return r.pathArc(g.r2p(t.x)+u)},b=j(d);if(r.radialTickLayout!==b&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=b),y){g.setScale();var w=0,T=v?(g.tickvals||[]).filter((function(t){return t>=0})).map((function(t){return f.tickText(g,t,!0,!1)})):f.calcTicks(g),k=v?T:f.clipEnds(g,T),A=f.getTickSigns(g)[2];v&&((\"top\"===g.ticks&&\"bottom\"===g.side||\"bottom\"===g.ticks&&\"top\"===g.side)&&(A=-A),\"top\"===g.ticks&&\"top\"===g.side&&(w=-g.ticklen),\"bottom\"===g.ticks&&\"bottom\"===g.side&&(w=g.ticklen)),f.drawTicks(n,g,{vals:T,layer:i[\"radial-axis\"],path:f.makeTickPath(g,0,A),transFn:x,crisp:!1}),f.drawGrid(n,g,{vals:k,layer:i[\"radial-grid\"],path:_,transFn:o.noop,crisp:!1}),f.drawLabels(n,g,{vals:T,layer:i[\"radial-axis\"],transFn:x,labelFns:f.makeLabelFns(g,w)})}var M=r.radialAxisAngle=r.vangles?F(U(R(d.angle),r.vangles)):d.angle,S=l(h,p),E=S+s(-M);V(i[\"radial-axis\"],y&&(d.showticklabels||d.ticks),{transform:E}),V(i[\"radial-grid\"],y&&d.showgrid,{transform:v?\"\":S}),V(i[\"radial-line\"].select(\"line\"),y&&d.showline,{x1:v?-a:u,y1:0,x2:a,y2:0,transform:E}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},N.updateRadialAxisTitle=function(t,e,r){if(!this.isSmith){var n=this,i=n.gd,a=n.radius,o=n.cx,s=n.cy,l=n.getRadial(e),c=n.id+\"title\",h=0;if(l.title){var f=u.bBox(n.layers[\"radial-axis\"].node()).height,p=l.title.font.size,d=l.side;h=\"top\"===d?p:\"counterclockwise\"===d?-(f+.4*p):f+.8*p}var m=void 0!==r?r:n.radialAxisAngle,g=R(m),y=Math.cos(g),v=Math.sin(g),_=o+a/2*y+h*v,b=s-a/2*v+h*y;n.layers[\"radial-axis-title\"]=x.draw(i,c,{propContainer:l,propName:n.id+\".radialaxis.title\",placeholder:O(i,\"Click to enter radial axis title\"),attributes:{x:_,y:b,\"text-anchor\":\"middle\"},transform:{rotate:-m}})}},N.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,h=r.cx,p=r.cy,d=r.getAngular(e),m=r.angularAxis,g=r.isSmith;g||(r.fillViewInitialKey(\"angularaxis.rotation\",d.rotation),m.setGeometry(),m.setScale());var y=g?function(t){var e=z(r,L([0,t.x]));return Math.atan2(e[0]-h,e[1]-p)-Math.PI/2}:function(t){return m.t2g(t.x)};\"linear\"===m.type&&\"radians\"===m.thetaunit&&(m.tick0=F(m.tick0),m.dtick=F(m.dtick));var v=function(t){return l(h+a*Math.cos(t),p-a*Math.sin(t))},x=g?function(t){var e=z(r,L([0,t.x]));return l(e[0],e[1])}:function(t){return v(y(t))},_=g?function(t){var e=z(r,L([0,t.x])),n=Math.atan2(e[0]-h,e[1]-p)-Math.PI/2;return l(e[0],e[1])+s(-F(n))}:function(t){var e=y(t);return v(e)+s(-F(e))},b=g?function(t){return I(r,t.x,0,1/0)}:function(t){var e=y(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[h+u*r,p-u*n]+\"L\"+[h+a*r,p-a*n]},w=f.makeLabelFns(m,0).labelStandoff,T={xFn:function(t){var e=y(t);return Math.cos(e)*w},yFn:function(t){var e=y(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(w+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*M)},anchorFn:function(t){var e=y(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=y(t);return-.5*(1+Math.sin(n))*r}},k=j(d);r.angularTickLayout!==k&&(i[\"angular-axis\"].selectAll(\".\"+m._id+\"tick\").remove(),r.angularTickLayout=k);var A,S=g?[1/0].concat(m.tickvals||[]).map((function(t){return f.tickText(m,t,!0,!1)})):f.calcTicks(m);if(g&&(S[0].text=\"\u221e\",S[0].fontSize*=1.75),\"linear\"===e.gridshape?(A=S.map(y),o.angleDelta(A[0],A[1])<0&&(A=A.slice().reverse())):A=null,r.vangles=A,\"category\"===m.type&&(S=S.filter((function(t){return o.isAngleInsideSector(y(t),r.sectorInRad)}))),m.visible){var E=\"inside\"===m.ticks?-1:1,C=(m.linewidth||1)/2;f.drawTicks(n,m,{vals:S,layer:i[\"angular-axis\"],path:\"M\"+E*C+\",0h\"+E*m.ticklen,transFn:_,crisp:!1}),f.drawGrid(n,m,{vals:S,layer:i[\"angular-grid\"],path:b,transFn:o.noop,crisp:!1}),f.drawLabels(n,m,{vals:S,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:x,labelFns:T})}V(i[\"angular-line\"].select(\"path\"),d.showline,{d:r.pathSubplot(),transform:l(h,p)}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},N.updateFx=function(t,e){this.gd._context.staticPlot||(!this.isSmith&&(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1)),this.updateHoverAndMainDrag(t))},N.updateHoverAndMainDrag=function(t){var e,r,s=this,c=s.isSmith,u=s.gd,h=s.layers,f=t._zoomlayer,p=S.MINZOOM,d=S.OFFEDGE,m=s.radius,x=s.innerRadius,T=s.cx,k=s.cy,A=s.cxx,M=s.cyy,C=s.sectorInRad,L=s.vangles,I=s.radialAxis,P=E.clampTiny,z=E.findXYatLength,O=E.findEnclosingVertexAngles,D=S.cornerHalfWidth,R=S.cornerLen/2,F=g.makeDragger(h,\"path\",\"maindrag\",!1===t.dragmode?\"none\":\"crosshair\");n.select(F).attr(\"d\",s.pathSubplot()).attr(\"transform\",l(T,k)),F.onmousemove=function(t){v.hover(u,t,s.id),u._fullLayout._lasthover=F,u._fullLayout._hoversubplot=s.id},F.onmouseout=function(t){u._dragging||y.unhover(u,t)};var B,N,j,U,V,q,H,G,Z,W={element:F,gd:u,subplot:s.id,plotinfo:{id:s.id,xaxis:s.xaxis,yaxis:s.yaxis},xaxes:[s.xaxis],yaxes:[s.yaxis]};function Y(t,e){return Math.sqrt(t*t+e*e)}function X(t,e){return Y(t-A,e-M)}function $(t,e){return Math.atan2(M-e,t-A)}function J(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function K(t,e){if(0===t)return s.pathSector(2*D);var r=R/t,n=e-r,i=e+r,a=Math.max(0,Math.min(t,m)),o=a-D,l=a+D;return\"M\"+J(o,n)+\"A\"+[o,o]+\" 0,0,0 \"+J(o,i)+\"L\"+J(l,i)+\"A\"+[l,l]+\" 0,0,1 \"+J(l,n)+\"Z\"}function Q(t,e,r){if(0===t)return s.pathSector(2*D);var n,i,a=J(t,e),o=J(t,r),l=P((a[0]+o[0])/2),c=P((a[1]+o[1])/2);if(l&&c){var u=c/l,h=-1/u,f=z(D,u,l,c);n=z(R,h,f[0][0],f[0][1]),i=z(R,h,f[1][0],f[1][1])}else{var p,d;c?(p=R,d=D):(p=D,d=R),n=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return\"M\"+n.join(\"L\")+\"L\"+i.reverse().join(\"L\")+\"Z\"}function tt(t,e){return e=Math.max(Math.min(e,m),x),t<d?t=0:m-t<d?t=m:e<d?e=0:m-e<d&&(e=m),Math.abs(e-t)>p?(t<e?(j=t,U=e):(j=e,U=t),!0):(j=null,U=null,!1)}function et(t,e){t=t||V,e=e||\"M0,0Z\",G.attr(\"d\",t),Z.attr(\"d\",e),g.transitionZoombox(G,Z,q,H),q=!0;var r={};ot(r),u.emit(\"plotly_relayouting\",r)}function rt(t,n){var i,a,o=B+(t*=e),l=N+(n*=r),c=X(B,N),u=Math.min(X(o,l),m),h=$(B,N);tt(c,u)&&(i=V+s.pathSector(U),j&&(i+=s.pathSector(j)),a=K(j,h)+K(U,h)),et(i,a)}function nt(t,e,r,n){var i=E.findIntersectionXY(r,n,r,[t-A,M-e]);return Y(i[0],i[1])}function it(t,e){var r,n,i=B+t,a=N+e,o=$(B,N),l=$(i,a),c=O(o,L),u=O(l,L);tt(nt(B,N,c[0],c[1]),Math.min(nt(i,a,u[0],u[1]),m))&&(r=V+s.pathSector(U),j&&(r+=s.pathSector(j)),n=[Q(j,c[0],c[1]),Q(U,c[0],c[1])].join(\" \")),et(r,n)}function at(){if(g.removeZoombox(u),null!==j&&null!==U){var t={};ot(t),g.showDoubleClickNotifier(u),a.call(\"_guiRelayout\",u,t)}}function ot(t){var e=I._rl,r=(e[1]-e[0])/(1-x/m)/m,n=[e[0]+(j-x)*r,e[0]+(U-x)*r];t[s.id+\".radialaxis.range\"]=n}function st(t,e){var r=u._fullLayout.clickmode;if(g.removeZoombox(u),2===t){var n={};for(var i in s.viewInitial)n[s.id+\".\"+i]=s.viewInitial[i];u.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",u,n)}r.indexOf(\"select\")>-1&&1===t&&b(e,u,[s.xaxis],[s.yaxis],s.id,W),r.indexOf(\"event\")>-1&&v.click(u,e,s.id)}W.prepFn=function(t,n,a){var l=u._fullLayout.dragmode,h=F.getBoundingClientRect();u._fullLayout._calcInverseTransform(u);var p=u._fullLayout._invTransform;e=u._fullLayout._invScaleX,r=u._fullLayout._invScaleY;var d=o.apply3DTransform(p)(n-h.left,a-h.top);if(B=d[0],N=d[1],L){var y=E.findPolygonOffset(m,C[0],C[1],L);B+=A+y[0],N+=M+y[1]}switch(l){case\"zoom\":W.clickFn=st,c||(W.moveFn=L?it:rt,W.doneFn=at,function(){j=null,U=null,V=s.pathSubplot(),q=!1;var t=u._fullLayout[s.id];H=i(t.bgcolor).getLuminance(),(G=g.makeZoombox(f,H,T,k,V)).attr(\"fill-rule\",\"evenodd\"),Z=g.makeCorners(f,T,k),w(u)}());break;case\"select\":case\"lasso\":_(t,n,a,W,l)}},y.init(W)},N.updateRadialDrag=function(t,e,r){var i=this,c=i.gd,u=i.layers,h=i.radius,f=i.innerRadius,p=i.cx,d=i.cy,m=i.radialAxis,v=S.radialDragBoxSize,x=v/2;if(m.visible){var _,b,T,M=R(i.radialAxisAngle),E=m._rl,C=E[0],L=E[1],I=E[r],P=.75*(E[1]-E[0])/(1-i.getHole(e))/h;r?(_=p+(h+x)*Math.cos(M),b=d-(h+x)*Math.sin(M),T=\"radialdrag\"):(_=p+(f-x)*Math.cos(M),b=d-(f-x)*Math.sin(M),T=\"radialdrag-inner\");var z,O,D,B=g.makeRectDragger(u,T,\"crosshair\",-x,-x,v,v),N={element:B,gd:c};!1===t.dragmode&&(N.dragmode=!1),V(n.select(B),m.visible&&f<h,{transform:l(_,b)}),N.prepFn=function(){z=null,O=null,D=null,N.moveFn=j,N.doneFn=q,w(c)},N.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<S.MINDRAG&&(t=0,e=0),[t,e]},y.init(N)}function j(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(M),Math.sin(M)],s=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(s)||(z=s<.5?H:G)}var l={};!function(t){null!==O?t[i.id+\".radialaxis.angle\"]=O:null!==D&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=D)}(l),c.emit(\"plotly_relayouting\",l)}function q(){null!==O?a.call(\"_guiRelayout\",c,i.id+\".radialaxis.angle\",O):null!==D&&a.call(\"_guiRelayout\",c,i.id+\".radialaxis.range[\"+r+\"]\",D)}function H(t,e){if(0!==r){var n=_+t,a=b+e;O=Math.atan2(d-a,n-p),i.vangles&&(O=U(O,i.vangles)),O=F(O);var o=l(p,d)+s(-O);u[\"radial-axis\"].attr(\"transform\",o),u[\"radial-line\"].select(\"line\").attr(\"transform\",o);var c=i.gd._fullLayout,h=c[i.id];i.updateRadialAxisTitle(c,h,O)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(M),Math.sin(M)]);if(D=I-P*n,P>0==(r?D>C:D<L)){var s=c._fullLayout,l=s[i.id];m.range[r]=D,m._rl[r]=D,i.updateRadialAxis(s,l),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],p=o.filterVisible(f);f[0][0].trace._module.plot(c,i,p,l),a.traceIs(h,\"gl\")&&p.length&&(u=!0)}u&&(k(c),A(c))}else D=null}},N.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,c=e.radius,h=e.angularAxis,f=e.cx,p=e.cy,d=e.cxx,m=e.cyy,v=S.angularDragBoxSize,x=g.makeDragger(i,\"path\",\"angulardrag\",!1===t.dragmode?\"none\":\"move\"),_={element:x,gd:r};function b(t,e){return Math.atan2(m+v-e,t-d-v)}!1===t.dragmode?_.dragmode=!1:n.select(x).attr(\"d\",e.pathAnnulus(c,c+v)).attr(\"transform\",l(f,p)).call(T,\"move\");var M,E,C,L,I,P,z=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),O=z.selectAll(\".point\"),D=z.selectAll(\".textpoint\");function R(c,g){var y=e.gd._fullLayout,v=y[e.id],x=b(M+c*t._invScaleX,E+g*t._invScaleY),_=F(x-P);if(L=C+_,i.frontplot.attr(\"transform\",l(e.xOffset2,e.yOffset2)+s([-_,d,m])),e.vangles){I=e.radialAxisAngle+_;var w=l(f,p)+s(-_),T=l(f,p)+s(-I);i.bg.attr(\"transform\",w),i[\"radial-grid\"].attr(\"transform\",w),i[\"radial-axis\"].attr(\"transform\",T),i[\"radial-line\"].select(\"line\").attr(\"transform\",T),e.updateRadialAxisTitle(y,v,I)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",l(d,m)+s(_));O.each((function(){var t=n.select(this),e=u.getTranslate(t);t.attr(\"transform\",l(e.x,e.y)+s([_]))})),D.each((function(){var t=n.select(this),e=t.select(\"text\"),r=u.getTranslate(t);t.attr(\"transform\",s([_,e.attr(\"x\"),e.attr(\"y\")])+l(r.x,r.y))})),h.rotation=o.modHalf(L,360),e.updateAngularAxis(y,v),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&z.call(u.hideOutsideRangePoints,e);var S=!1;for(var R in e.traceHash)if(a.traceIs(R,\"gl\")){var N=e.traceHash[R],j=o.filterVisible(N);N[0][0].trace._module.plot(r,e,j,v),j.length&&(S=!0)}S&&(k(r),A(r));var U={};B(U),r.emit(\"plotly_relayouting\",U)}function B(t){t[e.id+\".angularaxis.rotation\"]=L,e.vangles&&(t[e.id+\".radialaxis.angle\"]=I)}function N(){D.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}_.prepFn=function(n,i,a){var s=t[e.id];C=s.angularaxis.rotation;var l=x.getBoundingClientRect();M=i-l.left,E=a-l.top,r._fullLayout._calcInverseTransform(r);var c=o.apply3DTransform(t._invTransform)(M,E);M=c[0],E=c[1],P=b(M,E),_.moveFn=R,_.doneFn=N,w(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(_.prepFn=o.noop,T(n.select(x),null)),y.init(_)},N.isPtInside=function(t){if(this.isSmith)return!0;var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?E.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},N.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathArc)(t,e[0],e[1],r)},N.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathSector)(t,e[0],e[1],r)},N.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?E.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},N.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},N.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},51937:function(t,e,r){\"use strict\";var n=r(34809),i=r(19091),a=n.deg2rad,o=n.rad2deg;t.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,r){var n,i,a=e[r],o=e._length,s=function(r){return t.d2c(r,e.thetaunit)};if(a)for(n=new Array(o),i=0;i<o;i++)n[i]=s(a[i]);else{var l=r+\"0\",c=\"d\"+r,u=l in e?s(e[l]):0,h=e[c]?s(e[c]):(t.period||2*Math.PI)/o;for(n=new Array(o),i=0;i<o;i++)n[i]=u+i*h}return n},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},m=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(m).map(o);break;case\"category\":var g=t._categories.length,y=t.period?Math.max(t.period,g):g;0===y&&(y=1),s=c=function(t){return 2*t*Math.PI/y},i=l=function(t){return t*y/Math.PI/2},t.range=[0,y]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(m(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(m(t))}}}(t,e)}}},70951:function(t){\"use strict\";t.exports={attr:\"subplot\",name:\"smith\",axisNames:[\"realaxis\",\"imaginaryaxis\"],axisName2dataArray:{imaginaryaxis:\"imag\",realaxis:\"real\"}}},52007:function(t){\"use strict\";function e(t){return t<0?-1:t>0?1:0}function r(t){var e=t[0],r=t[1];if(!isFinite(e)||!isFinite(r))return[1,0];var n=(e+1)*(e+1)+r*r;return[(e*e+r*r-1)/n,2*r/n]}function n(t,e){var r=e[0],n=e[1];return[r*t.radius+t.cx,-n*t.radius+t.cy]}function i(t,e){return e*t.radius}t.exports={smith:r,reactanceArc:function(t,e,a,o){var s=n(t,r([a,e])),l=s[0],c=s[1],u=n(t,r([o,e])),h=u[0],f=u[1];if(0===e)return[\"M\"+l+\",\"+c,\"L\"+h+\",\"+f].join(\" \");var p=i(t,1/Math.abs(e));return[\"M\"+l+\",\"+c,\"A\"+p+\",\"+p+\" 0 0,\"+(e<0?1:0)+\" \"+h+\",\"+f].join(\" \")},resistanceArc:function(t,a,o,s){var l=i(t,1/(a+1)),c=n(t,r([a,o])),u=c[0],h=c[1],f=n(t,r([a,s])),p=f[0],d=f[1];if(e(o)!==e(s)){var m=n(t,r([a,0]));return[\"M\"+u+\",\"+h,\"A\"+l+\",\"+l+\" 0 0,\"+(0<o?0:1)+\" \"+m[0]+\",\"+m[1],\"A\"+l+\",\"+l+\" 0 0,\"+(s<0?0:1)+p+\",\"+d].join(\" \")}return[\"M\"+u+\",\"+h,\"A\"+l+\",\"+l+\" 0 0,\"+(s<o?0:1)+\" \"+p+\",\"+d].join(\" \")},smithTransform:n}},50358:function(t,e,r){\"use strict\";var n=r(4173).fX,i=r(34809).counterRegex,a=r(35785),o=r(70951),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},t.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:r(93288),supplyLayoutDefaults:r(31359),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s,!0),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;if(!e[o]&&s)for(var c in s.framework.remove(),s.clipPaths)s.clipPaths[c].remove()}},toSVG:r(37703).toSVG}},93288:function(t,e,r){\"use strict\";var n=r(10229),i=r(25829),a=r(13792).u,o=r(34809).extendFlat,s=r(13582).overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth,griddash:i.griddash},\"plot\",\"from-root\"),c=s({ticklen:i.ticklen,tickwidth:o({},i.tickwidth,{dflt:2}),tickcolor:i.tickcolor,showticklabels:i.showticklabels,labelalias:i.labelalias,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,tickfont:i.tickfont,tickformat:i.tickformat,hoverformat:i.hoverformat,layer:i.layer},\"plot\",\"from-root\"),u=o({visible:o({},i.visible,{dflt:!0}),tickvals:{dflt:[.2,.5,1,2,5],valType:\"data_array\",editType:\"plot\"},tickangle:o({},i.tickangle,{dflt:90}),ticks:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"\"],editType:\"ticks\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},editType:\"calc\"},l,c),h=o({visible:o({},i.visible,{dflt:!0}),tickvals:{valType:\"data_array\",editType:\"plot\"},ticks:i.ticks,editType:\"calc\"},l,c);t.exports={domain:a({name:\"smith\",editType:\"plot\"}),bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},realaxis:u,imaginaryaxis:h,editType:\"calc\"}},31359:function(t,e,r){\"use strict\";var n,i,a,o=r(34809),s=r(78766),l=r(78032),c=r(4448),u=r(4173).KO,h=r(54616),f=r(12036),p=r(97405),d=r(19091),m=r(93288),g=r(70951),y=g.axisNames,v=(n=function(t){return o.isTypedArray(t)&&(t=Array.from(t)),t.slice().reverse().map((function(t){return-t})).concat([0]).concat(t)},i=String,a={},function(t){var e=i?i(t):t;if(e in a)return a[e];var r=n(t);return a[e]=r,r});function x(t,e,r,n){var i=r(\"bgcolor\");n.bgColor=s.combine(i,n.paper_bgcolor);var a,c=u(n.fullData,g.name,n.id),x=n.layoutOut;function _(t,e){return r(a+\".\"+t,e)}for(var b=0;b<y.length;b++){a=y[b],o.isPlainObject(t[a])||(t[a]={});var w=t[a],T=l.newContainer(e,a);T._id=T._name=a,T._attr=n.id+\".\"+a,T._traceIndices=c.map((function(t){return t._expandedIndex}));var k=_(\"visible\");if(T.type=\"linear\",d(T,x),h(w,T,_,T.type),k){var A,M,S,E,C=\"realaxis\"===a;C&&_(\"side\"),C?_(\"tickvals\"):_(\"tickvals\",v(e.realaxis.tickvals||m.realaxis.tickvals.dflt)),o.isTypedArray(T.tickvals)&&(T.tickvals=Array.from(T.tickvals));var L=n.font||{};k&&(M=(A=_(\"color\"))===w.color?A:L.color,S=L.size,E=L.family),f(w,T,_,T.type,{noAutotickangles:!0,noTicklabelshift:!0,noTicklabelstandoff:!0,noTicklabelstep:!0,noAng:!C,noExp:!0,font:{color:M,size:S,family:E}}),o.coerce2(t,e,m,a+\".ticklen\"),o.coerce2(t,e,m,a+\".tickwidth\"),o.coerce2(t,e,m,a+\".tickcolor\",e.color),_(\"ticks\")||(delete e[a].ticklen,delete e[a].tickwidth,delete e[a].tickcolor),p(w,T,_,{dfltColor:A,bgColor:n.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:m[a]}),_(\"layer\")}_(\"hoverformat\"),delete T.type,T._input=w}}t.exports=function(t,e,r){c(t,e,r,{noUirevision:!0,type:g.name,attributes:m,handleDefaults:x,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},4448:function(t,e,r){\"use strict\";var n=r(34809),i=r(78032),a=r(13792).N;t.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,m=d&&p[0].replace(/\\d+$/,\"\");function g(t,e){return n.coerce(s,l,u,t,e)}for(var y=0;y<d;y++){var v=p[y];s=t[v]?t[v]:t[v]={},l=i.newContainer(e,v,m),o.noUirevision||g(\"uirevision\",e.uirevision);var x={};x[f]=[y/d,(y+1)/d],a(l,e,g,x),o.id=v,h(s,l,g,o)}}},3208:function(t,e,r){\"use strict\";var n=r(87296);function i(t){var e=t.description?\" \"+t.description:\"\",r=t.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";e+=\"Finally, the template string has access to \",e=1===r.length?e+\"variable \"+n[0]:e+\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return e}n.FORMAT_LINK,n.DATE_FORMAT_LINK,e.rb=function(t,e){t=t||{},i(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},e.ay=function(t,e){t=t||{},i(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"calc\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},e.LF=function(t,e){return e=e||{},(t=t||{}).newshape,i(e),{valType:\"string\",dflt:\"\",editType:t.editType||\"arraydraw\"}}},7638:function(t,e,r){\"use strict\";var n=r(83637),i=r(4173).fX,a=r(34809).counterRegex,o=\"ternary\";e.name=o;var s=e.attr=\"subplot\";e.idRoot=o,e.idRegex=e.attrRegex=a(o),(e.attributes={})[s]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},e.layoutAttributes=r(77416),e.supplyLayoutDefaults=r(25247),e.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots[o],s=0;s<a.length;s++){var l=a[s],c=i(r,o,l),u=e[l]._subplot;u||(u=new n({id:l,graphDiv:t,container:e._ternarylayer.node()},e),e[l]._subplot=u),u.plot(c,e,t._promises)}},e.clean=function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.plotContainer.remove(),l.clipDef.remove(),l.clipDefRelative.remove(),l.layers[\"a-title\"].remove(),l.layers[\"b-title\"].remove(),l.layers[\"c-title\"].remove())}},e.updateFx=function(t){var e=t._fullLayout;e._ternarylayer.selectAll(\"g.toplevel\").style(\"cursor\",\"pan\"===e.dragmode?\"move\":\"crosshair\")}},77416:function(t,e,r){\"use strict\";var n=r(10229),i=r(13792).u,a=r(25829),o=r(13582).overrideAll,s=r(93049).extendFlat,l={title:{text:a.title.text,font:a.title.font},color:a.color,tickmode:a.minor.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,ticklabelstep:a.ticklabelstep,showticklabels:a.showticklabels,labelalias:a.labelalias,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,griddash:a.griddash,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=t.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},25247:function(t,e,r){\"use strict\";var n=r(78766),i=r(78032),a=r(34809),o=r(4448),s=r(12036),l=r(54616),c=r(87433),u=r(22777),h=r(97405),f=r(77416),p=[\"aaxis\",\"baxis\",\"caxis\"];function d(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<p.length;h++)s=t[o=p[h]]||{},(l=i.newContainer(e,o))._name=o,m(s,l,a,e);var f=e.aaxis,d=e.baxis,g=e.caxis;f.min+d.min+g.min>=u&&(f.min=0,d.min=0,g.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function m(t,e,r,n){var i=f[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var p=o(\"color\"),d=p!==i.color.dflt?p:r.font.color,m=e._name.charAt(0).toUpperCase(),g=\"Component \"+m,y=o(\"title.text\",g);e._hovertitle=y===g?y:m,a.coerceFont(o,\"title.font\",r.font,{overrideDflt:{size:a.bigFont(r.font.size),color:d}}),o(\"min\"),u(t,e,o,\"linear\"),l(t,e,o,\"linear\"),s(t,e,o,\"linear\",{noAutotickangles:!0,noTicklabelshift:!0,noTicklabelstandoff:!0}),c(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",r.font,{overrideDflt:{color:d}}),o(\"tickangle\"),o(\"tickformat\")),h(t,e,o,{dfltColor:p,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}t.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:f,handleDefaults:d,font:e.font,paper_bgcolor:e.paper_bgcolor})}},83637:function(t,e,r){\"use strict\";var n=r(45568),i=r(65657),a=r(33626),o=r(34809),s=o.strTranslate,l=o._,c=r(78766),u=r(62203),h=r(19091),f=r(93049).extendFlat,p=r(44122),d=r(29714),m=r(14751),g=r(32141),y=r(70414),v=y.freeMode,x=y.rectMode,_=r(17240),b=r(44844).prepSelect,w=r(44844).selectOnClick,T=r(44844).clearOutline,k=r(44844).clearSelectionsCache,A=r(54826);function M(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.updateFx(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}t.exports=M;var S=M.prototype;S.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},S.plot=function(t,e){var r=this,n=e[r.id],i=e._size;r._hasClipOnAxisFalse=!1;for(var a=0;a<t.length;a++)if(!1===t[a][0].trace.cliponaxis){r._hasClipOnAxisFalse=!0;break}r.updateLayers(n),r.adjustLayout(n,i),p.generalUpdatePerTraceModule(r.graphDiv,r,t,n),r.layers.plotbg.select(\"path\").call(c.fill,n.bgcolor)},S.makeFramework=function(t){var e=this,r=e.graphDiv,n=t[e.id],i=e.clipId=\"clip\"+e.layoutId+e.id,a=e.clipIdRelative=\"clip-relative\"+e.layoutId+e.id;e.clipDef=o.ensureSingleById(t._clips,\"clipPath\",i,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),e.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",a,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),e.plotContainer=o.ensureSingle(e.container,\"g\",e.id),e.updateLayers(n),u.setClipUrl(e.layers.backplot,i,r),u.setClipUrl(e.layers.grids,i,r)},S.updateFx=function(t){t._ternarylayer.selectAll(\"g.toplevel\").style(\"cursor\",\"pan\"===t.dragmode?\"move\":\"crosshair\")},S.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",(function(t){return\"toplevel \"+t})).each((function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach((function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)}))})),i.order()};var E=Math.sqrt(4/3);S.adjustLayout=function(t,e){var r,n,i,a,o,l,p=this,d=t.domain,m=(d.x[0]+d.x[1])/2,g=(d.y[0]+d.y[1])/2,y=d.x[1]-d.x[0],v=d.y[1]-d.y[0],x=y*e.w,_=v*e.h,b=t.sum,w=t.aaxis.min,T=t.baxis.min,k=t.caxis.min;x>E*_?i=(a=_)*E:a=(i=x)/E,o=y*i/x,l=v*a/_,r=e.l+e.w*m-i/2,n=e.t+e.h*(1-g)-a/2,p.x0=r,p.y0=n,p.w=i,p.h=a,p.sum=b,p.xaxis={type:\"linear\",range:[w+2*k-b,b-w-2*T],domain:[m-o/2,m+o/2],_id:\"x\"},h(p.xaxis,p.graphDiv._fullLayout),p.xaxis.setScale(),p.xaxis.isPtWithinRange=function(t){return t.a>=p.aaxis.range[0]&&t.a<=p.aaxis.range[1]&&t.b>=p.baxis.range[1]&&t.b<=p.baxis.range[0]&&t.c>=p.caxis.range[1]&&t.c<=p.caxis.range[0]},p.yaxis={type:\"linear\",range:[w,b-T-k],domain:[g-l/2,g+l/2],_id:\"y\"},h(p.yaxis,p.graphDiv._fullLayout),p.yaxis.setScale(),p.yaxis.isPtWithinRange=function(){return!0};var A=p.yaxis.domain[0],M=p.aaxis=f({},t.aaxis,{range:[w,b-T-k],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});h(M,p.graphDiv._fullLayout),M.setScale();var S=p.baxis=f({},t.baxis,{range:[b-w-k,T],side:\"bottom\",domain:p.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});h(S,p.graphDiv._fullLayout),S.setScale();var C=p.caxis=f({},t.caxis,{range:[b-w-T,k],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});h(C,p.graphDiv._fullLayout),C.setScale();var L=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDef.select(\"path\").attr(\"d\",L),p.layers.plotbg.select(\"path\").attr(\"d\",L);var I=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDefRelative.select(\"path\").attr(\"d\",I);var P=s(r,n);p.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),p.clipDefRelative.select(\"path\").attr(\"transform\",null);var z=s(r-S._offset,n+a);p.layers.baxis.attr(\"transform\",z),p.layers.bgrid.attr(\"transform\",z);var O=s(r+i/2,n)+\"rotate(30)\"+s(0,-M._offset);p.layers.aaxis.attr(\"transform\",O),p.layers.agrid.attr(\"transform\",O);var D=s(r+i/2,n)+\"rotate(-30)\"+s(0,-C._offset);p.layers.caxis.attr(\"transform\",D),p.layers.cgrid.attr(\"transform\",D),p.drawAxes(!0),p.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(c.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),p.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(c.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),p.layers.cline.select(\"path\").attr(\"d\",C.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(c.stroke,C.linecolor||\"#000\").style(\"stroke-width\",(C.linewidth||0)+\"px\"),p.graphDiv._context.staticPlot||p.initInteractions(),u.setClipUrl(p.layers.frontplot,p._hasClipOnAxisFalse?null:p.clipId,p.graphDiv)},S.drawAxes=function(t){var e=this,r=e.graphDiv,n=e.id.substr(7)+\"title\",i=e.layers,a=e.aaxis,o=e.baxis,s=e.caxis;if(e.drawAx(a),e.drawAx(o),e.drawAx(s),t){var c=Math.max(a.showticklabels?a.tickfont.size/2:0,(s.showticklabels?.75*s.tickfont.size:0)+(\"outside\"===s.ticks?.87*s.ticklen:0)),u=(o.showticklabels?o.tickfont.size:0)+(\"outside\"===o.ticks?o.ticklen:0)+3;i[\"a-title\"]=_.draw(r,\"a\"+n,{propContainer:a,propName:e.id+\".aaxis.title\",placeholder:l(r,\"Click to enter Component A title\"),attributes:{x:e.x0+e.w/2,y:e.y0-a.title.font.size/3-c,\"text-anchor\":\"middle\"}}),i[\"b-title\"]=_.draw(r,\"b\"+n,{propContainer:o,propName:e.id+\".baxis.title\",placeholder:l(r,\"Click to enter Component B title\"),attributes:{x:e.x0-u,y:e.y0+e.h+.83*o.title.font.size+u,\"text-anchor\":\"middle\"}}),i[\"c-title\"]=_.draw(r,\"c\"+n,{propContainer:s,propName:e.id+\".caxis.title\",placeholder:l(r,\"Click to enter Component C title\"),attributes:{x:e.x0+e.w+u,y:e.y0+e.h+.83*s.title.font.size+u,\"text-anchor\":\"middle\"}})}},S.drawAx=function(t){var e,r=this,n=r.graphDiv,i=t._name,a=i.charAt(0),s=t._id,l=r.layers[i],c=a+\"tickLayout\",u=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);r[c]!==u&&(l.selectAll(\".\"+s+\"tick\").remove(),r[c]=u),t.setScale();var h=d.calcTicks(t),f=d.clipEnds(t,h),p=d.makeTransTickFn(t),m=d.getTickSigns(t)[2],g=o.deg2rad(30),y=m*(t.linewidth||1)/2,v=m*t.ticklen,x=r.w,_=r.h,b=\"b\"===a?\"M0,\"+y+\"l\"+Math.sin(g)*v+\",\"+Math.cos(g)*v:\"M\"+y+\",0l\"+Math.cos(g)*v+\",\"+-Math.sin(g)*v,w={a:\"M0,0l\"+_+\",-\"+x/2,b:\"M0,0l-\"+x/2+\",-\"+_,c:\"M0,0l-\"+_+\",\"+x/2}[a];d.drawTicks(n,t,{vals:\"inside\"===t.ticks?f:h,layer:l,path:b,transFn:p,crisp:!1}),d.drawGrid(n,t,{vals:f,layer:r.layers[a+\"grid\"],path:w,transFn:p,crisp:!1}),d.drawLabels(n,t,{vals:h,layer:l,transFn:p,labelFns:d.makeLabelFns(t,0,30)})};var C=A.MINZOOM/2+.87,L=\"m-0.87,.5h\"+C+\"v3h-\"+(C+5.2)+\"l\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l2.6,1.5l-\"+C/2+\",\"+.87*C+\"Z\",I=\"m0.87,.5h-\"+C+\"v3h\"+(C+5.2)+\"l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-2.6,1.5l\"+C/2+\",\"+.87*C+\"Z\",P=\"m0,1l\"+C/2+\",\"+.87*C+\"l2.6,-1.5l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-\"+(C/2+2.6)+\",\"+(.87*C+4.5)+\"l2.6,1.5l\"+C/2+\",-\"+.87*C+\"Z\",z=!0;function O(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}S.clearOutline=function(){k(this.dragOptions),T(this.dragOptions.gd)},S.initInteractions=function(){var t,e,r,n,h,f,p,d,y,_,T,k,M=this,S=M.layers.plotbg.select(\"path\").node(),C=M.graphDiv,D=C._fullLayout._zoomlayer;function R(t){var e={};return e[M.id+\".aaxis.min\"]=t.a,e[M.id+\".baxis.min\"]=t.b,e[M.id+\".caxis.min\"]=t.c,e}function F(t,e){var r=C._fullLayout.clickmode;O(C),2===t&&(C.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",C,R({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&w(e,C,[M.xaxis],[M.yaxis],M.id,M.dragOptions),r.indexOf(\"event\")>-1&&g.click(C,e,M.id)}function B(t,e){return 1-e/M.h}function N(t,e){return 1-(t+(M.h-e)/Math.sqrt(3))/M.w}function j(t,e){return(t-(M.h-e)/Math.sqrt(3))/M.w}function U(i,a){var o=r+i*t,s=n+a*e,l=Math.max(0,Math.min(1,B(0,n),B(0,s))),c=Math.max(0,Math.min(1,N(r,n),N(o,s))),u=Math.max(0,Math.min(1,j(r,n),j(o,s))),m=(l/2+u)*M.w,g=(1-l/2-c)*M.w,v=(m+g)/2,x=g-m,b=(1-l)*M.h,w=b-x/E;x<A.MINZOOM?(p=h,T.attr(\"d\",y),k.attr(\"d\",\"M0,0Z\")):(p={a:h.a+l*f,b:h.b+c*f,c:h.c+u*f},T.attr(\"d\",y+\"M\"+m+\",\"+b+\"H\"+g+\"L\"+v+\",\"+w+\"L\"+m+\",\"+b+\"Z\"),k.attr(\"d\",\"M\"+r+\",\"+n+\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2ZM\"+m+\",\"+b+L+\"M\"+g+\",\"+b+I+\"M\"+v+\",\"+w+P)),_||(T.transition().style(\"fill\",d>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),k.transition().style(\"opacity\",1).duration(200),_=!0),C.emit(\"plotly_relayouting\",R(p))}function V(){O(C),p!==h&&(a.call(\"_guiRelayout\",C,R(p)),z&&C.data&&C._context.showTips&&(o.notifier(l(C,\"Double-click to zoom back out\"),\"long\"),z=!1))}function q(t,e){var r=t/M.xaxis._m,n=e/M.yaxis._m,i=[(p={a:h.a-n,b:h.b+(r+n)/2,c:h.c-(r-n)/2}).a,p.b,p.c].sort(o.sorterAsc),a=i.indexOf(p.a),l=i.indexOf(p.b),c=i.indexOf(p.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),p={a:i[a],b:i[l],c:i[c]},e=(h.a-p.a)*M.yaxis._m,t=(h.c-p.c-h.b+p.b)*M.xaxis._m);var f=s(M.x0+t,M.y0+e);M.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",f);var d=s(-t,-e);M.clipDefRelative.select(\"path\").attr(\"transform\",d),M.aaxis.range=[p.a,M.sum-p.b-p.c],M.baxis.range=[M.sum-p.a-p.c,p.b],M.caxis.range=[M.sum-p.a-p.b,p.c],M.drawAxes(!1),M._hasClipOnAxisFalse&&M.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(u.hideOutsideRangePoints,M),C.emit(\"plotly_relayouting\",R(p))}function H(){a.call(\"_guiRelayout\",C,R(p))}this.dragOptions={element:S,gd:C,plotinfo:{id:M.id,domain:C._fullLayout[M.id].domain,xaxis:M.xaxis,yaxis:M.yaxis},subplot:M.id,prepFn:function(a,l,u){M.dragOptions.xaxes=[M.xaxis],M.dragOptions.yaxes=[M.yaxis],t=C._fullLayout._invScaleX,e=C._fullLayout._invScaleY;var m=M.dragOptions.dragmode=C._fullLayout.dragmode;v(m)?M.dragOptions.minDrag=1:M.dragOptions.minDrag=void 0,\"zoom\"===m?(M.dragOptions.moveFn=U,M.dragOptions.clickFn=F,M.dragOptions.doneFn=V,function(t,e,a){var l=S.getBoundingClientRect();r=e-l.left,n=a-l.top,C._fullLayout._calcInverseTransform(C);var u=C._fullLayout._invTransform,m=o.apply3DTransform(u)(r,n);r=m[0],n=m[1],h={a:M.aaxis.range[0],b:M.baxis.range[1],c:M.caxis.range[1]},p=h,f=M.aaxis.range[1]-h.a,d=i(M.graphDiv._fullLayout[M.id].bgcolor).getLuminance(),y=\"M0,\"+M.h+\"L\"+M.w/2+\", 0L\"+M.w+\",\"+M.h+\"Z\",_=!1,T=D.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",s(M.x0,M.y0)).style({fill:d>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",y),k=D.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",s(M.x0,M.y0)).style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),M.clearOutline(C)}(0,l,u)):\"pan\"===m?(M.dragOptions.moveFn=q,M.dragOptions.clickFn=F,M.dragOptions.doneFn=H,h={a:M.aaxis.range[0],b:M.baxis.range[1],c:M.caxis.range[1]},p=h,M.clearOutline(C)):(x(m)||v(m))&&b(a,l,u,M.dragOptions,m)}},S.onmousemove=function(t){g.hover(C,t,M.id),C._fullLayout._lasthover=S,C._fullLayout._hoversubplot=M.id},S.onmouseout=function(t){C._dragging||m.unhover(C,t)},m.init(this.dragOptions)}},33626:function(t,e,r){\"use strict\";var n=r(48636),i=r(4969),a=r(36539),o=r(56174),s=r(95425).addStyleRule,l=r(93049),c=r(9829),u=r(6704),h=l.extendFlat,f=l.extendDeepAll;function p(t){var i=t.name,a=t.categories,o=t.meta;if(e.modules[i])n.log(\"Type \"+i+\" already registered\");else{e.subplotsRegistry[t.basePlotModule.name]||function(t){var r=t.name;if(e.subplotsRegistry[r])n.log(\"Plot type \"+r+\" already registered.\");else for(var i in y(t),e.subplotsRegistry[r]=t,e.componentsRegistry)_(i,t.name)}(t.basePlotModule);for(var l={},c=0;c<a.length;c++)l[a[c]]=!0,e.allCategories[a[c]]=!0;for(var u in e.modules[i]={_module:t,categories:l},o&&Object.keys(o).length&&(e.modules[i].meta=o),e.allTypes.push(i),e.componentsRegistry)v(u,i);t.layoutAttributes&&h(e.traceLayoutAttributes,t.layoutAttributes);var f=t.basePlotModule,p=f.name;if(\"mapbox\"===p){var d=f.constants.styleRules;for(var m in d)s(\".js-plotly-plot .plotly .mapboxgl-\"+m,d[m])}\"map\"===p&&r(96144),\"geo\"!==p&&\"mapbox\"!==p&&\"map\"!==p||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var r=t.name;for(var n in e.componentsRegistry[r]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(e.layoutArrayContainers,r),y(t)),e.modules)v(r,n);for(var i in e.subplotsRegistry)_(r,i);for(var o in e.transformsRegistry)x(r,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function m(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var r=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(r+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([r+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(r+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(r+\" registered without a *supplyDefaults* method.\"),e.transformsRegistry[t.name]=t,e.componentsRegistry)x(s,t.name)}function g(t){var r=t.name,n=r.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=e.localeRegistry,c=l[r];if(c||(l[r]=c={}),n!==r){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function y(t){if(t.layoutAttributes){var r=t.layoutAttributes._arrayAttrRegexps;if(r)for(var n=0;n<r.length;n++)a(e.layoutArrayRegexes,r[n])}}function v(t,r){var n=e.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[r];i&&f(e.modules[r]._module.attributes,i)}}function x(t,r){var n=e.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[r];i&&f(e.transformsRegistry[r].attributes,i)}}function _(t,r){var n=e.componentsRegistry[t].schema;if(n&&n.subplots){var i=e.subplotsRegistry[r],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function b(t){return\"object\"==typeof t&&(t=t.type),t}e.modules={},e.allCategories={},e.allTypes=[],e.subplotsRegistry={},e.transformsRegistry={},e.componentsRegistry={},e.layoutArrayContainers=[],e.layoutArrayRegexes=[],e.traceLayoutAttributes={},e.localeRegistry={},e.apiMethodRegistry={},e.collectableSubplotTypes=null,e.register=function(t){if(e.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var r=0;r<t.length;r++){var n=t[r];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":m(n);break;case\"component\":d(n);break;case\"locale\":g(n);break;case\"apiMethod\":var i=n.name;e.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},e.getModule=function(t){var r=e.modules[b(t)];return!!r&&r._module},e.traceIs=function(t,r){if(\"various\"===(t=b(t)))return!1;var i=e.modules[t];return i||(t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=e.modules[c.type.dflt]),!!i.categories[r]},e.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},e.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},e.getComponentMethod=function(t,r){var n=e.componentsRegistry[t];return n&&n[r]||i},e.call=function(){var t=arguments[0],r=[].slice.call(arguments,1);return e.apiMethodRegistry[t].apply(null,r)}},3164:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}t.exports=function(t,e){var r,i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var m=Object.keys(h).filter((function(t){return t.match(/^scene\\d*$/)}));if(m.length){var g={};for(\"thumbnail\"===e.tileClass&&(g={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<m.length;r++){var y=h[m[r]];y.xaxis||(y.xaxis={}),y.yaxis||(y.yaxis={}),y.zaxis||(y.zaxis={}),a(y.xaxis,g),a(y.yaxis,g),a(y.zaxis,g),y._scene=null}}var v=document.createElement(\"div\");e.tileClass&&(v.className=e.tileClass);var x={gd:v,td:v,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},26452:function(t,e,r){\"use strict\";var n=r(34809),i=r(80491),a=r(33353),o=r(84619);t.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.width=e.width||null,e.height=e.height||null,e.imageDataOnly=!0,new Promise((function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format.replace(\"-\",\".\"),c.then((function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)})).then((function(t){s(t)})).catch((function(t){r&&(r._snapshotInProgress=!1),l(t)}))}))}},33353:function(t,e,r){\"use strict\";var n=r(34809),i=r(84619);t.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise((function(s,l){var c,u;if(n.isIE())return c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e);if(o)return c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e);if(n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}l(new Error(\"download error\"))}))}},84619:function(t,e,r){\"use strict\";var n=r(33626);e.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\")||t._has(\"map\"))?500:0},e.getRedrawFunc=function(t){return function(){n.getComponentMethod(\"colorbar\",\"draw\")(t)}},e.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)},e.encodeJSON=function(t){return\"data:application/json,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;e.createObjectURL=function(t){return i.createObjectURL(t)},e.revokeObjectURL=function(t){return i.revokeObjectURL(t)},e.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});if(\"full-json\"===e)return new window.Blob([t],{type:\"application/json;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},e.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},e.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,e.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},6170:function(t,e,r){\"use strict\";var n=r(84619),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:r(3164),toSVG:r(6243),svgToImg:r(72914),toImage:r(76896),downloadImage:r(26452)};t.exports=i},72914:function(t,e,r){\"use strict\";var n=r(34809),i=r(7683).EventEmitter,a=r(84619);t.exports=function(t){var e=t.emitter||new i,r=new Promise((function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,m=t.width||300,g=t.height||150,y=d*m,v=d*g,x=p.getContext(\"2d\",{willReadFrequently:!0}),_=new s;\"svg\"===c||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=y,p.height=v,_.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(_,0,0,y,v),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},_.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},_.src=f}));return t.promise?r:e}},76896:function(t,e,r){\"use strict\";var n=r(7683).EventEmitter,i=r(33626),a=r(34809),o=r(84619),s=r(3164),l=r(6243),c=r(72914);t.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"_doPlot\",h,u.data,u.layout,u.config).then(f).then((function(){var t=o.getDelay(h._fullLayout);setTimeout((function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}}),t)})).catch((function(t){r.emit(\"error\",t)})),r}},6243:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(78766),s=r(62972),l=/\"/g,c=\"TOBESTRIPPED\",u=new RegExp('(\"'+c+\")|(\"+c+'\")',\"g\");t.exports=function(t,e,r){var h,f=t._fullLayout,p=f._paper,d=f._toppaper,m=f.width,g=f.height;p.insert(\"rect\",\":first-child\").call(a.setRect,0,0,m,g).call(o.fill,f.paper_bgcolor);var y=f._basePlotModules||[];for(h=0;h<y.length;h++){var v=y[h];v.toSVG&&v.toSVG(t)}if(d){var x=d.node().childNodes,_=Array.prototype.slice.call(x);for(h=0;h<_.length;h++){var b=_[h];b.childNodes.length&&p.node().appendChild(b)}}f._draggers&&f._draggers.remove(),p.node().style.background=\"\",p.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each((function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,c));var r=this.style.fontWeight;!r||\"normal\"!==r&&\"400\"!==r||t.style(\"font-weight\",void 0);var i=this.style.fontStyle;i&&\"normal\"===i&&t.style(\"font-style\",void 0);var a=this.style.fontVariant;a&&\"normal\"===a&&t.style(\"font-variant\",void 0)}else t.remove()})),p.selectAll(\".gradient_filled,.pattern_filled\").each((function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,c));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,c))})),\"pdf\"!==e&&\"eps\"!==e||p.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),p.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),p.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(p.attr(\"width\",r*m),p.attr(\"height\",r*g),p.attr(\"viewBox\",\"0 0 \"+m+\" \"+g));var w=(new window.XMLSerializer).serializeToString(p.node());return w=(w=(w=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,(function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()}));return e.remove(),r}(w)).replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(u,\"'\"),i.isIE()&&(w=(w=(w=w.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),w}},35374:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},81481:function(t,e,r){\"use strict\";var n=r(36640),i=r(80712).axisHoverFormat,a=r(3208).rb,o=r(3208).ay,s=r(87163),l=r(80337),c=r(56155),u=r(94850).k,h=r(93049).extendFlat,f=l({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),p=h({},n.marker.line.width,{dflt:0}),d=h({width:p,editType:\"calc\"},s(\"marker.line\")),m=h({line:d,editType:\"calc\"},s(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"},pattern:u,cornerradius:{valType:\"any\",editType:\"calc\"}});t.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),text:n.text,texttemplate:o({editType:\"plot\"},{keys:c.eventDataKeys}),hovertext:n.hovertext,hovertemplate:a({},{keys:c.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:h({},f,{}),insidetextfont:h({},f,{}),outsidetextfont:h({},f,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:h({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:m,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},zorder:n.zorder,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},67565:function(t,e,r){\"use strict\";var n=r(29714),i=r(40528),a=r(65477).hasColorscale,o=r(28379),s=r(35374),l=r(48861);t.exports=function(t,e){var r,c,u,h,f,p,d=n.getFromId(t,e.xaxis||\"x\"),m=n.getFromId(t,e.yaxis||\"y\"),g={msUTC:!(!e.base&&0!==e.base)};\"h\"===e.orientation?(r=d.makeCalcdata(e,\"x\",g),u=m.makeCalcdata(e,\"y\"),h=i(e,m,\"y\",u),f=!!e.yperiodalignment,p=\"y\"):(r=m.makeCalcdata(e,\"y\",g),u=d.makeCalcdata(e,\"x\"),h=i(e,d,\"x\",u),f=!!e.xperiodalignment,p=\"x\"),c=h.vals;for(var y=Math.min(c.length,r.length),v=new Array(y),x=0;x<y;x++)v[x]={p:c[x],s:r[x]},f&&(v[x].orig_p=u[x],v[x][p+\"End\"]=h.ends[x],v[x][p+\"Start\"]=h.starts[x]),e.ids&&(v[x].id=String(e.ids[x]));return a(e,\"marker\")&&o(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),a(e,\"marker.line\")&&o(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),s(v,e),l(v,e),v}},56155:function(t){\"use strict\";t.exports={TEXTPAD:3,eventDataKeys:[\"value\",\"label\"]}},24782:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809).isArrayOrTypedArray,a=r(63821).BADNUM,o=r(33626),s=r(29714),l=r(84391).getAxisGroup,c=r(2880);function u(t,e,r,o,u){if(o.length){var _,b,w,T;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(_=[],b=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.offset?b.push(T):_.push(T);b.length&&function(t,e,r,n,i){var o=new c(n,{posAxis:e,sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),g=l(i,e._id)+c[0][0].trace.orientation,y=i._alignmentOpts[g]||{},v=0;v<u;v++){var x,_,b=c[v],w=b[0].trace,T=y[w.alignmentgroup]||{},k=Object.keys(T.offsetGroups||{}).length,A=(x=k?f/k:h?f/u:f)*(1-(n.groupgap||0));_=k?((2*w._offsetIndex+1-k)*x-A)/2:h?((2*v+1-u)*x-A)/2:-A/2;var M=b[0].t;M.barwidth=A,M.poffset=_,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),m(e,r,h)})(t,e,o,i),function(t,e){for(var r=t.traces,n=0;n<r.length;n++){var i=r[n];if(void 0===i[0].trace.base)for(var o=new c([i],{posAxis:e,sepNegVal:!0,overlapNoMerge:!0}),s=0;s<i.length;s++){var l=i[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o,e),i.norm?(y(o),v(r,o,i)):g(r,o)}(t,e,r,b,u),_.length&&h(e,r,_,u);break;case\"stack\":case\"relative\":for(_=[],b=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.base?b.push(T):_.push(T);!function(t){if(!(t.length<2)){var e,r,i,a,o,s;for(e=0;e<t.length&&void 0===(a=(r=t[e][0].trace).marker?r.marker.cornerradius:void 0);e++);if(void 0!==a)for(o=n(a)?+a:+a.slice(0,-1),s=n(a)?\"px\":\"%\",e=0;e<t.length;e++)(i=t[e][0].t).cornerradiusvalue=o,i.cornerradiusform=s}}(b),b.length&&function(t,e,r,n,i){var o=new c(n,{posAxis:e,sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(\"funnel\"===(i=(n=f[l])[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){o=\"funnel\"===(i=(n=f[l])[0].trace).type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var m=e.put(u.p,d),g=m+d;u.b=m,u[h]=g,r.norm||(p.push(g),u.hasB&&p.push(m))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];p.s!==a&&p.b+p.s===o.get(p.p,p.s)&&(p._outmost=!0)}i.norm&&v(r,o,i)}(0,e,r,b,u),_.length&&h(e,r,_,u)}!function(t){var e,r,i,a,o,s,l;for(e=0;e<t.length;e++)i=(r=t[e])[0].trace,void 0===(a=r[0].t).cornerradiusvalue&&void 0!==(o=i.marker?i.marker.cornerradius:void 0)&&(s=n(o)?+o:+o.slice(0,-1),l=n(o)?\"px\":\"%\",a.cornerradiusvalue=s,a.cornerradiusform=l)}(o),function(t,e){var r,a,o,s=x(e),l={},c=1/0,u=-1/0;for(r=0;r<t.length;r++)for(o=t[r],a=0;a<o.length;a++){var h=o[a].p;n(h)&&(c=Math.min(c,h),u=Math.max(u,h))}var f=1e4/(u-c),p=l.round=function(t){return String(Math.round(f*(t-c)))},d={},m={},g=t.some((function(t){var e=t[0].trace;return\"marker\"in e&&e.marker.cornerradius}));for(r=0;r<t.length;r++){(o=t[r])[0].t.extents=l;var y=o[0].t.poffset,v=i(y);for(a=0;a<o.length;a++){var _=o[a],b=_[s]-_.w/2;if(n(b)){var w=_[s]+_.w/2,T=p(_.p);l[T]?l[T]=[Math.min(b,l[T][0]),Math.max(w,l[T][1])]:l[T]=[b,w]}if(_.p0=_.p+(v?y[a]:y),_.p1=_.p0+_.w,_.s0=_.b,_.s1=_.s0+_.s,g){var k=Math.min(_.s0,_.s1)||0,A=Math.max(_.s0,_.s1)||0,M=_[s];d[M]=M in d?Math.min(d[M],k):k,m[M]=M in m?Math.max(m[M],A):A}}}g&&function(t,e,r,n){for(var i=x(n),a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s],c=l[i];l._sMin=e[c],l._sMax=r[c]}}(t,d,m,e)}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{posAxis:t,sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(y(o),v(e,o,n)):g(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),m(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var m=Array.prototype.slice.call(p,0,s.length);for(r=0;r<m.length;r++)n(m[r])||(m[r]=d);for(r=m.length;r<s.length;r++)m.push(d);if(u.barwidth=m,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-m[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),a=0;a<r.length;a++)for(var o=r[a],s=o[0].t,l=s.poffset,c=i(l),u=s.barwidth,h=i(u),f=0;f<o.length;f++){var p=o[f],d=p.w=h?u[f]:u;void 0===p.p&&(p.p=p[n],p[\"orig_\"+n]=p[n]);var m=(c?l[f]:l)+d/2;p[n]=p.p+m}}function m(t,e,r){var n=e.traces,a=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var o=0;o<n.length;o++){var l,c,u,h,f=n[o],p=f[0],d=p.trace,m=[];for(h=0;h<f.length;h++)c=(l=f[h]).p-a,u=l.p+a,m.push(c,u);if(d.width||d.offset){var g=p.t,y=g.poffset,v=g.barwidth,x=i(y),_=i(v);for(h=0;h<f.length;h++){l=f[h];var b=x?y[h]:y,w=_?v[h]:v;u=(c=l.p+b)+w,m.push(c,u)}}d._extremes[t._id]=s.findExtremes(t,m,{padded:!1})}}function g(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=\"scatter\"===o.type,c=\"v\"===o.orientation,u=[],h=!1,f=0;f<a.length;f++){var p=a[f],d=l?0:p.b,m=l?c?p.y:p.x:d+p.s;p[n]=m,u.push(m),p.hasB&&u.push(d),p.hasB&&p.b||(h=!0)}o._extremes[t._id]=s.findExtremes(t,u,{tozero:h,padded:!0})}}function y(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function v(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],m=d[0].trace,g=[],y=!1,v=!1,_=0;_<d.length;_++){var b=d[_];if(b.s!==a){var w=Math.abs(l/e.get(b.p,b.s));b.b*=w,b.s*=w;var T=b.b,k=T+b.s;b[o]=k,g.push(k),v=v||f(k),b.hasB&&(g.push(T),v=v||f(T)),b.hasB&&b.b||(y=!0)}}m._extremes[t._id]=s.findExtremes(t,g,{tozero:y,padded:v})}}function x(t){return t._id.charAt(0)}t.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];if(!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]),f._computePh))for(var p=t.calcdata[h],d=0;d<p.length;d++)\"function\"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),\"function\"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var m={xCat:\"category\"===r.type||\"multicategory\"===r.type,yCat:\"category\"===n.type||\"multicategory\"===n.type,mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,m),u(t,n,r,l,m)},setGroupPositions:u}},17550:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(78766),o=r(33626),s=r(99867),l=r(99669),c=r(59760),u=r(36301),h=r(81481),f=i.coerceFont;function p(t){if(n(t)){if((t=+t)>=0)return t}else if(\"string\"==typeof t&&\"%\"===(t=t.trim()).slice(-1)&&n(t.slice(0,-1))&&(t=+t.slice(0,-1))>=0)return t+\"%\"}function d(t,e,r,n,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),u=!(!1===o.moduleHasCliponaxis),h=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,m=Array.isArray(a)||\"auto\"===a,g=m||\"inside\"===a,y=m||\"outside\"===a;if(g||y){var v=f(n,\"textfont\",r.font),x=i.extendFlat({},v),_=!(t.textfont&&t.textfont.color);if(_&&delete x.color,f(n,\"insidetextfont\",x),d){var b=i.extendFlat({},v);_&&delete b.color,f(n,\"pathbar.textfont\",b)}y&&f(n,\"outsidetextfont\",v),s&&n(\"selected.textfont.color\"),l&&n(\"unselected.textfont.color\"),c&&n(\"constraintext\"),u&&n(\"cliponaxis\"),h&&n(\"textangle\"),n(\"texttemplate\")}g&&p&&n(\"insidetextanchor\")}t.exports={supplyDefaults:function(t,e,r,n){function u(r,n){return i.coerce(t,e,h,r,n)}if(s(t,e,n,u)){l(t,e,n,u),u(\"xhoverformat\"),u(\"yhoverformat\"),u(\"zorder\"),u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var f=u(\"textposition\");d(t,0,n,u,f,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),c(t,e,u,r,n);var p=(e.marker.line||{}).color,m=o.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,p||a.defaultLine,{axis:\"y\"}),m(t,e,p||a.defaultLine,{axis:\"x\",inherit:\"y\"}),i.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r,n;function a(t,e){return i.coerce(n._input,n,h,t,e)}for(var o=0;o<t.length;o++)if(\"bar\"===(n=t[o]).type){r=n._input;var s=a(\"marker.cornerradius\",e.barcornerradius);n.marker&&(n.marker.cornerradius=p(s)),\"group\"===e.barmode&&u(r,n,e,a)}},handleText:d,validateCornerradius:p}},59541:function(t){\"use strict\";t.exports=function(t,e,r){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),\"h\"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},42843:function(t,e,r){\"use strict\";var n=r(10721),i=r(65657),a=r(34809).isArrayOrTypedArray;e.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},e.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},e.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},e.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},e.getValue=function(t,e){var r;return a(t)?e<t.length&&(r=t[e]):r=t,r},e.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},91664:function(t,e,r){\"use strict\";var n=r(32141),i=r(33626),a=r(78766),o=r(34809).fillText,s=r(42843).getLineWidth,l=r(29714).hoverLabelText,c=r(63821).BADNUM;function u(t,e,r,i,a){var s,u,h,f,p,d,m,g=t.cd,y=g[0].trace,v=g[0].t,x=\"closest\"===i,_=\"waterfall\"===y.type,b=t.maxHoverDistance,w=t.maxSpikeDistance;\"h\"===y.orientation?(s=r,u=e,h=\"y\",f=\"x\",p=O,d=P):(s=e,u=r,h=\"x\",f=\"y\",d=O,p=P);var T=y[h+\"period\"],k=x||T;function A(t){return S(t,-1)}function M(t){return S(t,1)}function S(t,e){var r=t.w;return t[h]+e*r/2}function E(t){return t[h+\"End\"]-t[h+\"Start\"]}var C=x?A:T?function(t){return t.p-E(t)/2}:function(t){return Math.min(A(t),t.p-v.bardelta/2)},L=x?M:T?function(t){return t.p+E(t)/2}:function(t){return Math.max(M(t),t.p+v.bardelta/2)};function I(t,e,r){return a.finiteRange&&(r=0),n.inbox(t-s,e-s,r+Math.min(1,Math.abs(e-t)/m)-1)}function P(t){return I(C(t),L(t),b)}function z(t){var e=t[f];if(_){var r=Math.abs(t.rawS)||0;u>0?e+=r:u<0&&(e-=r)}return e}function O(t){var e=u,r=t.b,i=z(t);return n.inbox(r-e,i-e,b+(i-e)/(i-r)-1)}var D=t[h+\"a\"],R=t[f+\"a\"];m=Math.abs(D.r2c(D.range[1])-D.r2c(D.range[0]));var F=n.getDistanceFunction(i,p,d,(function(t){return(p(t)+d(t))/2}));if(n.getClosest(g,F,t),!1!==t.index&&g[t.index].p!==c){k||(C=function(t){return Math.min(A(t),t.p-v.bargroupwidth/2)},L=function(t){return Math.max(M(t),t.p+v.bargroupwidth/2)});var B=g[t.index],N=y.base?B.b+B.s:B.s;t[f+\"0\"]=t[f+\"1\"]=R.c2p(B[f],!0),t[f+\"LabelVal\"]=N;var j=v.extents[v.extents.round(B.p)];t[h+\"0\"]=D.c2p(x?C(B):j[0],!0),t[h+\"1\"]=D.c2p(x?L(B):j[1],!0);var U=void 0!==B.orig_p;return t[h+\"LabelVal\"]=U?B.orig_p:B.p,t.labelLabel=l(D,t[h+\"LabelVal\"],y[h+\"hoverformat\"]),t.valueLabel=l(R,t[f+\"LabelVal\"],y[f+\"hoverformat\"]),t.baseLabel=l(R,B.b,y[f+\"hoverformat\"]),t.spikeDistance=(function(t){var e=u,r=t.b,i=z(t);return n.inbox(r-e,i-e,w+(i-e)/(i-r)-1)}(B)+function(t){return I(A(t),M(t),w)}(B))/2,t[h+\"Spike\"]=D.c2p(B.p,!0),o(B,y,t),t.hovertemplate=y.hovertemplate,t}}function h(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}t.exports={hoverPoints:function(t,e,r,n,a){var o=u(t,e,r,n,a);if(o){var s=o.cd,l=s[0].trace,c=s[o.index];return o.color=h(l,c),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(c,l,o),[o]}},hoverOnBars:u,getTraceColor:h}},58218:function(t,e,r){\"use strict\";t.exports={attributes:r(81481),layoutAttributes:r(25412),supplyDefaults:r(17550).supplyDefaults,crossTraceDefaults:r(17550).crossTraceDefaults,supplyLayoutDefaults:r(78931),calc:r(67565),crossTraceCalc:r(24782).crossTraceCalc,colorbar:r(21146),arraysToCalcdata:r(35374),plot:r(32995).plot,style:r(6851).style,styleOnSelect:r(6851).styleOnSelect,hoverPoints:r(91664).hoverPoints,eventData:r(59541),selectPoints:r(88384),moduleType:\"trace\",name:\"bar\",basePlotModule:r(37703),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],animatable:!0,meta:{}}},25412:function(t){\"use strict\";t.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},barcornerradius:{valType:\"any\",editType:\"calc\"}}},78931:function(t,e,r){\"use strict\";var n=r(33626),i=r(29714),a=r(34809),o=r(25412),s=r(17550).validateCornerradius;t.exports=function(t,e,r){function l(r,n){return a.coerce(t,e,o,r,n)}for(var c=!1,u=!1,h=!1,f={},p=l(\"barmode\"),d=0;d<r.length;d++){var m=r[d];if(n.traceIs(m,\"bar\")&&m.visible){if(c=!0,\"group\"===p){var g=m.xaxis+m.yaxis;f[g]&&(h=!0),f[g]=!0}m.visible&&\"histogram\"===m.type&&\"category\"!==i.getFromId({_fullLayout:e},m[\"v\"===m.orientation?\"xaxis\":\"yaxis\"]).type&&(u=!0)}}if(c){\"overlay\"!==p&&l(\"barnorm\"),l(\"bargap\",u&&!h?0:.2),l(\"bargroupgap\");var y=l(\"barcornerradius\");e.barcornerradius=s(y)}else delete e.barmode}},32995:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(34809),o=r(30635),s=r(78766),l=r(62203),c=r(33626),u=r(29714).tickText,h=r(84102),f=h.recordMinTextSize,p=h.clearMinTextSize,d=r(6851),m=r(42843),g=r(56155),y=r(81481),v=y.text,x=y.textposition,_=r(36040).appendArrayPointValue,b=g.TEXTPAD;function w(t){return t.id}function T(t){if(t.ids)return w}function k(t){return(t>0)-(t<0)}function A(t,e){return t<e?1:-1}function M(t,e,r,n){var i;return!e.uniformtext.mode&&S(r)?(n&&(i=n()),t.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){i&&i()})).each(\"interrupt\",(function(){i&&i()}))):t}function S(t){return t&&t.duration>0}function E(t,e,r,n,i){return!(t<0||e<0)&&(r<=t&&n<=e||r<=e&&n<=t||(i?t>=r*(e/n):e>=n*(t/r)))}function C(t){return\"auto\"===t?0:t}function L(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),i=Math.abs(Math.cos(r));return{x:t.width*i+t.height*n,y:t.width*n+t.height*i}}function I(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor,u=\"end\"===c,h=\"start\"===c,f=((a.leftToRight||0)+1)/2,p=1-f,d=a.hasB,m=a.r,g=a.overhead,y=i.width,v=i.height,x=Math.abs(e-t),_=Math.abs(n-r),w=x>2*b&&_>2*b?b:0;x-=2*w,_-=2*w;var T=C(l);\"auto\"!==l||y<=x&&v<=_||!(y>x||v>_)||(y>_||v>x)&&y<v==x<_||(T+=90);var k,M,S=L(i,T);if(m&&m-g>b){var E=function(t,e,r,n,i,a,o,s,l){var c,u,h,f,p=Math.max(0,Math.abs(e-t)-2*b),d=Math.max(0,Math.abs(n-r)-2*b),m=a-b,g=o?m-Math.sqrt(m*m-(m-o)*(m-o)):m,y=l?2*m:s?m-o:2*g,v=l?2*m:s?2*g:m-o;return i.y/i.x>=d/(p-y)?f=d/i.y:i.y/i.x<=(d-v)/p?f=p/i.x:!l&&s?(c=i.x*i.x+i.y*i.y/4,h=(p-m)*(p-m)+(d/2-m)*(d/2-m)-m*m,f=(-(u=-2*i.x*(p-m)-i.y*(d/2-m))+Math.sqrt(u*u-4*c*h))/(2*c)):l?(c=(i.x*i.x+i.y*i.y)/4,h=(p/2-m)*(p/2-m)+(d/2-m)*(d/2-m)-m*m,f=(-(u=-i.x*(p/2-m)-i.y*(d/2-m))+Math.sqrt(u*u-4*c*h))/(2*c)):(c=i.x*i.x/4+i.y*i.y,h=(p/2-m)*(p/2-m)+(d-m)*(d-m)-m*m,f=(-(u=-i.x*(p/2-m)-2*i.y*(d-m))+Math.sqrt(u*u-4*c*h))/(2*c)),{scale:f=Math.min(1,f),pad:s?Math.max(0,m-Math.sqrt(Math.max(0,m*m-(m-(d-i.y*f)/2)*(m-(d-i.y*f)/2)))-o):Math.max(0,m-Math.sqrt(Math.max(0,m*m-(m-(p-i.x*f)/2)*(m-(p-i.x*f)/2)))-o)}}(t,e,r,n,S,m,g,o,d);k=E.scale,M=E.pad}else k=1,s&&(k=Math.min(1,x/S.x,_/S.y)),M=0;var I=i.left*p+i.right*f,P=(i.top+i.bottom)/2,z=(t+b)*p+(e-b)*f,O=(r+n)/2,D=0,R=0;if(h||u){var F=(o?S.x:S.y)/2;m&&(u||d)&&(w+=M);var B=o?A(t,e):A(r,n);o?h?(z=t+B*w,D=-B*F):(z=e-B*w,D=B*F):h?(O=r+B*w,R=-B*F):(O=n-B*w,R=B*F)}return{textX:I,textY:P,targetX:z,targetY:O,anchorX:D,anchorY:R,scale:k,rotate:T}}t.exports={plot:function(t,e,r,h,g,y){var w=e.xaxis,P=e.yaxis,z=t._fullLayout,O=t._context.staticPlot;g||(g={mode:z.barmode,norm:z.barmode,gap:z.bargap,groupgap:z.bargroupgap},p(\"bar\",z));var D=a.makeTraceGroups(h,r,\"trace bars\").each((function(r){var c=n.select(this),h=r[0].trace,p=r[0].t,D=\"waterfall\"===h.type,R=\"funnel\"===h.type,F=\"histogram\"===h.type,B=\"bar\"===h.type,N=B||R,j=0;D&&h.connector.visible&&\"between\"===h.connector.mode&&(j=h.connector.line.width/2);var U=\"h\"===h.orientation,V=S(g),q=a.ensureSingle(c,\"g\",\"points\"),H=T(h),G=q.selectAll(\"g.point\").data(a.identity,H);G.enter().append(\"g\").classed(\"point\",!0),G.exit().remove(),G.each((function(c,T){var S,D,R=n.select(this),q=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,P,U),H=q[0][0],G=q[0][1],Z=q[1][0],W=q[1][1],Y=0==(U?G-H:W-Z);if(Y&&N&&m.getLineWidth(h,c)&&(Y=!1),Y||(Y=!(i(H)&&i(G)&&i(Z)&&i(W))),c.isBlank=Y,Y&&(U?G=H:W=Z),j&&!Y&&(U?(H-=A(H,G)*j,G+=A(H,G)*j):(Z-=A(Z,W)*j,W+=A(Z,W)*j)),\"waterfall\"===h.type){if(!Y){var X=h[c.dir].marker;S=X.line.width,D=X.color}}else S=m.getLineWidth(h,c),D=c.mc||h.marker.color;function $(t){var e=n.round(S/2%1,2);return 0===g.gap&&0===g.groupgap?n.round(Math.round(t)-e,2):t}var J=s.opacity(D)<1||S>.01?$:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?$(t):t>e?Math.ceil(t):Math.floor(t)};t._context.staticPlot||(H=J(H,G,U),G=J(G,H,U),Z=J(Z,W,!U),W=J(W,Z,!U));var K,Q=U?w.c2p:P.c2p;K=c.s0>0?c._sMax:c.s0<0?c._sMin:c.s1>0?c._sMax:c._sMin;var tt,et,rt=B||F?function(t,e){if(!t)return 0;var r,n=U?Math.abs(W-Z):Math.abs(G-H),i=U?Math.abs(G-H):Math.abs(W-Z),a=J(Math.abs(Q(K,!0)-Q(0,!0))),o=c.hasB?Math.min(n/2,i/2):Math.min(n/2,a);return r=\"%\"===e?n*(Math.min(50,t)/100):t,J(Math.max(Math.min(r,o),0))}(p.cornerradiusvalue,p.cornerradiusform):0,nt=\"M\"+H+\",\"+Z+\"V\"+W+\"H\"+G+\"V\"+Z+\"Z\",it=0;if(rt&&c.s){var at=0===k(c.s0)||k(c.s)===k(c.s0)?c.s1:c.s0;if((it=J(c.hasB?0:Math.abs(Q(K,!0)-Q(at,!0))))<rt){var ot=A(H,G),st=A(Z,W),lt=ot===-st?1:0;if(U)if(c.hasB)tt=\"M\"+(H+rt*ot)+\",\"+Z+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+H+\",\"+(Z+rt*st)+\"V\"+(W-rt*st)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+(H+rt*ot)+\",\"+W+\"H\"+(G-rt*ot)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+G+\",\"+(W-rt*st)+\"V\"+(Z+rt*st)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+(G-rt*ot)+\",\"+Z+\"Z\";else{var ct=(et=Math.abs(G-H)+it)<rt?rt-Math.sqrt(et*(2*rt-et)):0,ut=it>0?Math.sqrt(it*(2*rt-it)):0,ht=ot>0?Math.max:Math.min;tt=\"M\"+H+\",\"+Z+\"V\"+(W-ct*st)+\"H\"+ht(G-(rt-it)*ot,H)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+G+\",\"+(W-rt*st-ut)+\"V\"+(Z+rt*st+ut)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+ht(G-(rt-it)*ot,H)+\",\"+(Z+ct*st)+\"Z\"}else if(c.hasB)tt=\"M\"+(H+rt*ot)+\",\"+Z+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+H+\",\"+(Z+rt*st)+\"V\"+(W-rt*st)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+(H+rt*ot)+\",\"+W+\"H\"+(G-rt*ot)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+G+\",\"+(W-rt*st)+\"V\"+(Z+rt*st)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+(G-rt*ot)+\",\"+Z+\"Z\";else{var ft=(et=Math.abs(W-Z)+it)<rt?rt-Math.sqrt(et*(2*rt-et)):0,pt=it>0?Math.sqrt(it*(2*rt-it)):0,dt=st>0?Math.max:Math.min;tt=\"M\"+(H+ft*ot)+\",\"+Z+\"V\"+dt(W-(rt-it)*st,Z)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+(H+rt*ot-pt)+\",\"+W+\"H\"+(G-rt*ot+pt)+\"A \"+rt+\",\"+rt+\" 0 0 \"+lt+\" \"+(G-ft*ot)+\",\"+dt(W-(rt-it)*st,Z)+\"V\"+Z+\"Z\"}}else tt=nt}else tt=nt;var mt=M(a.ensureSingle(R,\"path\"),z,g,y);if(mt.style(\"vector-effect\",O?\"none\":\"non-scaling-stroke\").attr(\"d\",isNaN((G-H)*(W-Z))||Y&&t._context.staticPlot?\"M0,0Z\":tt).call(l.setClipUrl,e.layerClipId,t),!z.uniformtext.mode&&V){var gt=l.makePointStyleFns(h);l.singlePointStyle(c,mt,h,gt,t)}!function(t,e,r,n,i,s,c,h,p,g,y,w,T){var k,S=e.xaxis,P=e.yaxis,z=t._fullLayout;function O(e,r,n){return a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+k,\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t)}var D=n[0].trace,R=\"h\"===D.orientation,F=function(t,e,r,n,i){var o,s=e[0].trace;return o=s.texttemplate?function(t,e,r,n,i){var o=e[0].trace,s=a.castOption(o,r,\"texttemplate\");if(!s)return\"\";var l,c,h,f,p=\"histogram\"===o.type,d=\"waterfall\"===o.type,m=\"funnel\"===o.type,g=\"h\"===o.orientation;function y(t){return u(f,f.c2l(t),!0).text}g?(l=\"y\",c=i,h=\"x\",f=n):(l=\"x\",c=n,h=\"y\",f=i);var v,x=e[r],b={};b.label=x.p,b.labelLabel=b[l+\"Label\"]=(v=x.p,u(c,c.c2l(v),!0).text);var w=a.castOption(o,x.i,\"text\");(0===w||w)&&(b.text=w),b.value=x.s,b.valueLabel=b[h+\"Label\"]=y(x.s);var T={};_(T,o,x.i),(p||void 0===T.x)&&(T.x=g?b.value:b.label),(p||void 0===T.y)&&(T.y=g?b.label:b.value),(p||void 0===T.xLabel)&&(T.xLabel=g?b.valueLabel:b.labelLabel),(p||void 0===T.yLabel)&&(T.yLabel=g?b.labelLabel:b.valueLabel),d&&(b.delta=+x.rawS||x.s,b.deltaLabel=y(b.delta),b.final=x.v,b.finalLabel=y(b.final),b.initial=b.final-b.delta,b.initialLabel=y(b.initial)),m&&(b.value=x.s,b.valueLabel=y(b.value),b.percentInitial=x.begR,b.percentInitialLabel=a.formatPercent(x.begR),b.percentPrevious=x.difR,b.percentPreviousLabel=a.formatPercent(x.difR),b.percentTotal=x.sumR,b.percenTotalLabel=a.formatPercent(x.sumR));var k=a.castOption(o,x.i,\"customdata\");return k&&(b.customdata=k),a.texttemplateString(s,b,t._d3locale,T,b,o._meta||{})}(t,e,r,n,i):s.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){return u(o?r:n,+t,!0).text}var h,f,p=i.textinfo,d=t[e],m=p.split(\"+\"),g=[],y=function(t){return-1!==m.indexOf(t)};if(y(\"label\")&&g.push((f=t[e].p,u(o?n:r,f,!0).text)),y(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&g.push(h),s){var v=+d.rawS||d.s,x=d.v,_=x-v;y(\"initial\")&&g.push(c(_)),y(\"delta\")&&g.push(c(v)),y(\"final\")&&g.push(c(x))}if(l){y(\"value\")&&g.push(c(d.s));var b=0;y(\"percent initial\")&&b++,y(\"percent previous\")&&b++,y(\"percent total\")&&b++;var w=b>1;y(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),g.push(h)),y(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),g.push(h)),y(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),g.push(h))}return g.join(\"<br>\")}(e,r,n,i):m.getValue(s.text,r),m.coerceString(v,o)}(z,n,i,S,P);k=function(t,e){var r=m.getValue(t.textposition,e);return m.coerceEnumerated(x,r)}(D,i);var B=\"stack\"===w.mode||\"relative\"===w.mode,N=n[i],j=!B||N._outmost,U=N.hasB,V=g&&g-y>b;if(F&&\"none\"!==k&&(!N.isBlank&&s!==c&&h!==p||\"auto\"!==k&&\"inside\"!==k)){var q=z.font,H=d.getBarColor(n[i],D),G=d.getInsideTextFont(D,i,q,H),Z=d.getOutsideTextFont(D,i,q),W=D.insidetextanchor||\"end\",Y=r.datum();R?\"log\"===S.type&&Y.s0<=0&&(s=S.range[0]<S.range[1]?0:S._length):\"log\"===P.type&&Y.s0<=0&&(h=P.range[0]<P.range[1]?P._length:0);var X,$,J,K,Q,tt=Math.abs(c-s),et=Math.abs(p-h),rt=tt-2*b,nt=et-2*b;if(\"outside\"===k&&(j||N.hasB||(k=\"inside\")),\"auto\"===k)if(j){k=\"inside\",X=O(r,F,Q=a.ensureUniformFontSize(t,G)),J=($=l.bBox(X.node())).width,K=$.height;var it,at=J>0&&K>0;it=V?U?E(rt-2*g,nt,J,K,R)||E(rt,nt-2*g,J,K,R):R?E(rt-(g-y),nt,J,K,R)||E(rt,nt-2*(g-y),J,K,R):E(rt,nt-(g-y),J,K,R)||E(rt-2*(g-y),nt,J,K,R):E(rt,nt,J,K,R),at&&it?k=\"inside\":(k=\"outside\",X.remove(),X=null)}else k=\"inside\";if(!X){var ot=(X=O(r,F,Q=a.ensureUniformFontSize(t,\"outside\"===k?Z:G))).attr(\"transform\");if(X.attr(\"transform\",\"\"),J=($=l.bBox(X.node())).width,K=$.height,X.attr(\"transform\",ot),J<=0||K<=0)return void X.remove()}var st,lt=D.textangle;st=\"outside\"===k?function(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*b?b:0:f>2*b?b:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var m=C(c),g=L(i,m),y=(s?g.x:g.y)/2,v=(i.left+i.right)/2,x=(i.top+i.bottom)/2,_=(t+e)/2,w=(r+n)/2,T=0,k=0,M=s?A(e,t):A(r,n);return s?(_=e-M*o,T=M*y):(w=n+M*o,k=-M*y),{textX:v,textY:x,targetX:_,targetY:w,anchorX:T,anchorY:k,scale:d,rotate:m}}(s,c,h,p,$,{isHorizontal:R,constrained:\"both\"===D.constraintext||\"outside\"===D.constraintext,angle:lt}):I(s,c,h,p,$,{isHorizontal:R,constrained:\"both\"===D.constraintext||\"inside\"===D.constraintext,angle:lt,anchor:W,hasB:U,r:g,overhead:y}),st.fontSize=Q.size,f(\"histogram\"===D.type?\"bar\":D.type,st,z),N.transform=st;var ct=M(X,z,w,T);a.setTransormAndDisplay(ct,st)}else r.select(\"text\").remove()}(t,e,R,r,T,H,G,Z,W,rt,it,g,y),e.layerClipId&&l.hideOutsideRangePoint(c,R.select(\"text\"),w,P,h.xcalendar,h.ycalendar)}));var Z=!1===h.cliponaxis;l.setClipUrl(c,Z?null:e.layerClipId,t)}));c.getComponentMethod(\"errorbars\",\"plot\")(t,D,e,g)},toMoveInsideBar:I}},88384:function(t){\"use strict\";function e(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}t.exports=function(t,r){var n,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===r)for(n=0;n<i.length;n++)i[n].selected=0;else for(n=0;n<i.length;n++){var h=i[n],f=\"ct\"in h?h.ct:e(h,a,o,c,l);r.contains(f,!1,n,t)?(u.push({pointNumber:n,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},2880:function(t,e,r){\"use strict\";t.exports=i;var n=r(34809).distinctVals;function i(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,i=e.posAxis._id.charAt(0),a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l],u=c.p;void 0===u&&(u=c[i]),void 0!==u&&a.push(u)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var h=n(a);this.distinctPositions=h.vals,1===h.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(h.minDiff,r);var f=(e.posAxis||{}).type;\"category\"!==f&&\"multicategory\"!==f||(this.minDiff=1),this.binWidth=this.minDiff,this.bins={}}i.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},i.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},i.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},6851:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(62203),o=r(34809),s=r(33626),l=r(84102).resizeText,c=r(81481),u=c.textfont,h=c.insidetextfont,f=c.outsidetextfont,p=r(42843);function d(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),m(t,e,r)}function m(t,e,r){t.selectAll(\"text\").each((function(t){var i=n.select(this),s=o.ensureUniformFontSize(r,g(i,t,e,r));a.font(i,s)}))}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=v(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=x(r,e.i,i));return a}function y(t,e,r){return _(u,t.textfont,e,r)}function v(t,e,r,n){var a=y(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size,weight:a.weight,style:a.style,variant:a.variant,textcase:a.textcase,lineposition:a.lineposition,shadow:a.shadow}),_(h,t.insidetextfont,e,a)}function x(t,e,r){var n=y(t,e,r);return _(f,t.outsidetextfont,e,n)}function _(t,e,r,n){e=e||{};var i=p.getValue(e.family,r),a=p.getValue(e.size,r),o=p.getValue(e.color,r),s=p.getValue(e.weight,r),l=p.getValue(e.style,r),c=p.getValue(e.variant,r),u=p.getValue(e.textcase,r),h=p.getValue(e.lineposition,r),f=p.getValue(e.shadow,r);return{family:p.coerceString(t.family,i,n.family),size:p.coerceNumber(t.size,a,n.size),color:p.coerceColor(t.color,o,n.color),weight:p.coerceString(t.weight,s,n.weight),style:p.coerceString(t.style,l,n.style),variant:p.coerceString(t.variant,c,n.variant),textcase:p.coerceString(t.variant,u,n.textcase),lineposition:p.coerceString(t.variant,h,n.lineposition),shadow:p.coerceString(t.variant,f,n.shadow)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mcc||t.mc||e.marker.color}t.exports={style:function(t){var e=n.select(t).selectAll('g[class^=\"barlayer\"]').selectAll(\"g.trace\");l(t,e,\"bar\");var r=e.size(),i=t._fullLayout;e.style(\"opacity\",(function(t){return t[0].trace.opacity})).each((function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")})),e.selectAll(\"g.points\").each((function(e){d(n.select(this),e[0].trace,t)})),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:m,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each((function(t){var i,s=n.select(this);if(t.selected){i=o.ensureUniformFontSize(r,g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)}))}(t.selectAll(\"text\"),e,r)}(r,i,t):(d(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:v,getOutsideTextFont:x,getBarColor:b,resizeText:l}},59760:function(t,e,r){\"use strict\";var n=r(78766),i=r(65477).hasColorscale,a=r(39356),o=r(34809).coercePattern;t.exports=function(t,e,r,s,l){var c=r(\"marker.color\",s),u=i(t,\"marker\");u&&a(t,e,l,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,l,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),o(r,\"marker.pattern\",c,u),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},84102:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809);function a(t){return\"_\"+t+\"Text_minsize\"}t.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=a(t),i=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<i,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,i)))}},clearMinTextSize:function(t,e){e[a(t)]=void 0},resizeText:function(t,e,r){var a=t._fullLayout,o=a[\"_\"+r+\"Text_minsize\"];if(o){var s,l=\"hide\"===a.uniformtext.mode;switch(r){case\"funnelarea\":case\"pie\":case\"sunburst\":s=\"g.slice\";break;case\"treemap\":case\"icicle\":s=\"g.slice, g.pathbar\";break;default:s=\"g.points > g.point\"}e.selectAll(s).each((function(t){var e=t.transform;if(e){e.scale=l&&e.hide?0:o/e.fontSize;var r=n.select(this).select(\"text\");i.setTransormAndDisplay(r,e)}}))}}}},32225:function(t,e,r){\"use strict\";var n,i=r(3208).rb,a=r(93049).extendFlat,o=r(8738),s=r(81481);t.exports={r:o.r,theta:o.theta,r0:o.r0,dr:o.dr,theta0:o.theta0,dtheta:o.dtheta,thetaunit:o.thetaunit,base:a({},s.base,{}),offset:a({},s.offset,{}),width:a({},s.width,{}),text:a({},s.text,{}),hovertext:a({},s.hovertext,{}),marker:(n=a({},s.marker),delete n.cornerradius,n),hoverinfo:o.hoverinfo,hovertemplate:i(),selected:s.selected,unselected:s.unselected}},27941:function(t,e,r){\"use strict\";var n=r(65477).hasColorscale,i=r(28379),a=r(34809).isArrayOrTypedArray,o=r(35374),s=r(24782).setGroupPositions,l=r(48861),c=r(33626).traceIs,u=r(34809).extendFlat;t.exports={calc:function(t,e){for(var r=t._fullLayout,s=e.subplot,c=r[s].radialaxis,u=r[s].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d=new Array(p),m=h,g=f,y=0;y<p;y++)d[y]={p:g[y],s:m[y]};function v(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=a(r)?u.makeCalcdata(e,t):u.d2c(r,e.thetaunit))}return\"linear\"===u.type&&(v(\"width\"),v(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(d,e),l(d,e),d},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var o=n[a],l=o[0].trace;!0===l.visible&&c(l,\"bar\")&&l.subplot===r&&i.push(o)}var h=u({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;s(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},77318:function(t,e,r){\"use strict\";var n=r(34809),i=r(73749).handleRThetaDefaults,a=r(59760),o=r(32225);t.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},83080:function(t,e,r){\"use strict\";var n=r(32141),i=r(34809),a=r(91664).getTraceColor,o=i.fillText,s=r(29709).makeHoverPointText,l=r(95928).isPtInsidePolygon;t.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,m=d?l:i.isPtInsideSector,g=t.maxHoverDistance,y=p._period||2*Math.PI,v=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);if(f.range[0]>f.range[1]&&(x+=Math.PI),n.getClosest(c,(function(t){return m(v,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?g+Math.min(1,Math.abs(t.thetag1-t.thetag0)/y)-1+(t.rp1-v)/(t.rp1-t.rp0)-1:1/0}),t),!1!==t.index){var _=c[t.index];t.x0=t.x1=_.ct[0],t.y0=t.y1=_.ct[1];var b=i.extendFlat({},_,{r:_.s,theta:_.p});return o(_,u,t),s(b,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,_),t.xLabelVal=t.yLabelVal=void 0,_.s<0&&(t.idealAlign=\"left\"),[t]}}},89362:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:r(31645),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:r(32225),layoutAttributes:r(42956),supplyDefaults:r(77318),supplyLayoutDefaults:r(60507),calc:r(27941).calc,crossTraceCalc:r(27941).crossTraceCalc,plot:r(11627),colorbar:r(21146),formatLabels:r(33368),style:r(6851).style,styleOnSelect:r(6851).styleOnSelect,hoverPoints:r(83080),selectPoints:r(88384),meta:{}}},42956:function(t){\"use strict\";t.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},60507:function(t,e,r){\"use strict\";var n=r(34809),i=r(42956);t.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},11627:function(t,e,r){\"use strict\";var n=r(45568),i=r(10721),a=r(34809),o=r(62203),s=r(95928);t.exports=function(t,e,r){var l=t._context.staticPlot,c=e.xaxis,u=e.yaxis,h=e.radialAxis,f=e.angularAxis,p=function(t){var e=t.cxx,r=t.cyy;return t.vangles?function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=[s.findEnclosingVertexAngles(c,t.vangles)[0],(c+u)/2,s.findEnclosingVertexAngles(u,t.vangles)[1]];return s.pathPolygonAnnulus(n,i,c,u,h,e,r)}:function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),d=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(d,r,\"trace bars\").each((function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",l?\"none\":\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each((function(t){var e,r=n.select(this),o=t.rp0=h.c2p(t.s0),s=t.rp1=h.c2p(t.s1),l=t.thetag0=f.c2g(t.p0),d=t.thetag1=f.c2g(t.p1);if(i(o)&&i(s)&&i(l)&&i(d)&&o!==s&&l!==d){var m=h.c2g(t.s1),g=(l+d)/2;t.ct=[c.c2p(m*Math.cos(g)),u.c2p(m*Math.sin(g))],e=p(o,s,l,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)})),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)}))}},64625:function(t,e,r){\"use strict\";var n=r(19326),i=r(36640),a=r(81481),o=r(10229),s=r(80712).axisHoverFormat,l=r(3208).rb,c=r(93049).extendFlat,u=i.marker,h=u.line;t.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",editType:\"calc\"},dy:{valType:\"number\",editType:\"calc\"},xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,xhoverformat:s(\"x\"),yhoverformat:s(\"y\"),name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},q1:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},median:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},q3:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},lowerfence:{valType:\"data_array\",editType:\"calc\"},upperfence:{valType:\"data_array\",editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},notchspan:{valType:\"data_array\",editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},sdmultiple:{valType:\"number\",min:0,editType:\"calc\",dflt:1},sizemode:{valType:\"enumerated\",values:[\"quartiles\",\"sd\"],editType:\"calc\",dflt:\"quartiles\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],editType:\"calc\"},mean:{valType:\"data_array\",editType:\"calc\"},sd:{valType:\"data_array\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},quartilemethod:{valType:\"enumerated\",values:[\"linear\",\"exclusive\",\"inclusive\"],dflt:\"linear\",editType:\"calc\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:c({},u.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:c({},u.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),angle:c({},u.angle,{arrayOk:!1,editType:\"calc\"}),size:c({},u.size,{arrayOk:!1,editType:\"calc\"}),color:c({},u.color,{arrayOk:!1,editType:\"style\"}),line:{color:c({},h.color,{arrayOk:!1,dflt:o.defaultLine,editType:\"style\"}),width:c({},h.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n(),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},showwhiskers:{valType:\"boolean\",editType:\"calc\"},offsetgroup:a.offsetgroup,alignmentgroup:a.alignmentgroup,selected:{marker:i.selected.marker,editType:\"style\"},unselected:{marker:i.unselected.marker,editType:\"style\"},text:c({},i.text,{}),hovertext:c({},i.hovertext,{}),hovertemplate:l({}),hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"},zorder:i.zorder}},89429:function(t,e,r){\"use strict\";var n=r(10721),i=r(29714),a=r(40528),o=r(34809),s=r(63821).BADNUM,l=o._;t.exports=function(t,e){var r,c,v,x,_,b,w,T=t._fullLayout,k=i.getFromId(t,e.xaxis||\"x\"),A=i.getFromId(t,e.yaxis||\"y\"),M=[],S=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(v=k,x=\"x\",_=A,b=\"y\",w=!!e.yperiodalignment):(v=A,x=\"y\",_=k,b=\"x\",w=!!e.xperiodalignment);var E,C,L,I,P,z,O=function(t,e,r,i){var s,l=e+\"0\"in t;if(e in t||l&&\"d\"+e in t){var c=r.makeCalcdata(t,e);return[a(t,r,e,c).vals,c]}s=l?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||o.isDateTime(t.name)&&\"date\"===r.type)?t.name:i;for(var u=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]),h=t._length,f=new Array(h),p=0;p<h;p++)f[p]=u;return[f]}(e,b,_,T[S]),D=O[0],R=O[1],F=o.distinctVals(D,_),B=F.vals,N=F.minDiff/2,j=\"all\"===(e.boxpoints||e.points)?o.identity:function(t){return t.v<E.lf||t.v>E.uf};if(e._hasPreCompStats){var U=e[x],V=function(t){return v.d2c((e[t]||[])[r])},q=1/0,H=-1/0;for(r=0;r<e._length;r++){var G=D[r];if(n(G)){if((E={}).pos=E[b]=G,w&&R&&(E.orig_p=R[r]),E.q1=V(\"q1\"),E.med=V(\"median\"),E.q3=V(\"q3\"),C=[],U&&o.isArrayOrTypedArray(U[r]))for(c=0;c<U[r].length;c++)(z=v.d2c(U[r][c]))!==s&&(u(P={v:z,i:[r,c]},e,[r,c]),C.push(P));if(E.pts=C.sort(h),I=(L=E[x]=C.map(f)).length,E.med!==s&&E.q1!==s&&E.q3!==s&&E.med>=E.q1&&E.q3>=E.med){var Z=V(\"lowerfence\");E.lf=Z!==s&&Z<=E.q1?Z:p(E,L,I);var W=V(\"upperfence\");E.uf=W!==s&&W>=E.q3?W:d(E,L,I);var Y=V(\"mean\");E.mean=Y!==s?Y:I?o.mean(L,I):(E.q1+E.q3)/2;var X=V(\"sd\");E.sd=Y!==s&&X>=0?X:I?o.stdev(L,I,E.mean):E.q3-E.q1,E.lo=m(E),E.uo=g(E);var $=V(\"notchspan\");$=$!==s&&$>0?$:y(E,I),E.ln=E.med-$,E.un=E.med+$;var J=E.lf,K=E.uf;e.boxpoints&&L.length&&(J=Math.min(J,L[0]),K=Math.max(K,L[I-1])),e.notched&&(J=Math.min(J,E.ln),K=Math.max(K,E.un)),E.min=J,E.max=K}else{var Q;o.warn([\"Invalid input - make sure that q1 <= median <= q3\",\"q1 = \"+E.q1,\"median = \"+E.med,\"q3 = \"+E.q3].join(\"\\n\")),Q=E.med!==s?E.med:E.q1!==s?E.q3!==s?(E.q1+E.q3)/2:E.q1:E.q3!==s?E.q3:0,E.med=Q,E.q1=E.q3=Q,E.lf=E.uf=Q,E.mean=E.sd=Q,E.ln=E.un=Q,E.min=E.max=Q}q=Math.min(q,E.min),H=Math.max(H,E.max),E.pts2=C.filter(j),M.push(E)}}e._extremes[v._id]=i.findExtremes(v,[q,H],{padded:!0})}else{var tt=v.makeCalcdata(e,x),et=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(B,N),rt=B.length,nt=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(rt);for(r=0;r<e._length;r++)if(z=tt[r],n(z)){var it=o.findBin(D[r],et);it>=0&&it<rt&&(u(P={v:z,i:r},e,r),nt[it].push(P))}var at=1/0,ot=-1/0,st=e.quartilemethod,lt=\"exclusive\"===st,ct=\"inclusive\"===st;for(r=0;r<rt;r++)if(nt[r].length>0){var ut,ht;(E={}).pos=E[b]=B[r],C=E.pts=nt[r].sort(h),I=(L=E[x]=C.map(f)).length,E.min=L[0],E.max=L[I-1],E.mean=o.mean(L,I),E.sd=o.stdev(L,I,E.mean)*e.sdmultiple,E.med=o.interp(L,.5),I%2&&(lt||ct)?(lt?(ut=L.slice(0,I/2),ht=L.slice(I/2+1)):ct&&(ut=L.slice(0,I/2+1),ht=L.slice(I/2)),E.q1=o.interp(ut,.5),E.q3=o.interp(ht,.5)):(E.q1=o.interp(L,.25),E.q3=o.interp(L,.75)),E.lf=p(E,L,I),E.uf=d(E,L,I),E.lo=m(E),E.uo=g(E);var ft=y(E,I);E.ln=E.med-ft,E.un=E.med+ft,at=Math.min(at,E.ln),ot=Math.max(ot,E.un),E.pts2=C.filter(j),M.push(E)}e.notched&&o.isTypedArray(tt)&&(tt=Array.from(tt)),e._extremes[v._id]=i.findExtremes(v,e.notched?tt.concat([at,ot]):tt,{padded:!0})}return function(t,e){if(o.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],i={},a=0;a<n.length;a++)i[n[a].i]=a;o.tagSelected(n,e,i)}}(M,e),M.length>0?(M[0].t={num:T[S],dPos:N,posLetter:b,valLetter:x,labels:{med:l(t,\"median:\"),min:l(t,\"min:\"),q1:l(t,\"q1:\"),q3:l(t,\"q3:\"),max:l(t,\"max:\"),mean:\"sd\"===e.boxmean||\"sd\"===e.sizemode?l(t,\"mean \u00b1 \u03c3:\").replace(\"\u03c3\",1===e.sdmultiple?\"\u03c3\":e.sdmultiple+\"\u03c3\"):l(t,\"mean:\"),lf:l(t,\"lower fence:\"),uf:l(t,\"upper fence:\")}},T[S]++,M):[{t:{empty:!0}}]};var c={text:\"tx\",hovertext:\"htx\"};function u(t,e,r){for(var n in c)o.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?o.isArrayOrTypedArray(e[n][r[0]])&&(t[c[n]]=e[n][r[0]][r[1]]):t[c[n]]=e[n][r])}function h(t,e){return t.v-e.v}function f(t){return t.v}function p(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(o.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function d(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(o.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function m(t){return 4*t.q1-3*t.q3}function g(t){return 4*t.q3-3*t.q1}function y(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},81606:function(t,e,r){\"use strict\";var n=r(29714),i=r(34809),a=r(84391).getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],m=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),m+=(c[l].pts2||[]).length;if(d.length){var g=i.distinctVals(d);\"category\"!==o.type&&\"multicategory\"!==o.type||(g.minDiff=1);var y=g.minDiff/2;n.minDtick(o,g.minDiff,g.vals[0],!0);var v=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&v>1,_=1-h[t+\"gap\"],b=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,T,k,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,I=E.side;if(L)w=T=A=L/2,k=0;else if(w=y,x){var P=a(h,o._id)+E.orientation,z=(h._alignmentOpts[P]||{})[E.alignmentgroup]||{},O=Object.keys(z.offsetGroups||{}).length,D=O||v;T=w*_*b/D,k=2*w*(((O?E._offsetIndex:C.num)+.5)/D-.5)*_,A=w*_/D}else T=w*_*b,k=0,A=w;C.dPos=w,C.bPos=k,C.bdPos=T,C.wHover=A;var R,F,B,N,j,U,V=k+T,q=Boolean(L);if(\"positive\"===I?(M=w*(L?1:.5),R=V,S=R=k):\"negative\"===I?(M=R=k,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&m>0){var H=E.pointpos,G=E.jitter,Z=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Z,B=W):W>R&&(j=Z,B=M)),W<=M&&(B=M);var Y=0;H-G<=0&&((Y=-V*(H-G))>S?(q=!0,U=Z,N=Y):Y>F&&(U=Z,N=S)),Y<=S&&(N=S)}else B=M,N=S;var X=new Array(c.length);for(l=0;l<c.length;l++)X[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,X,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}t.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},62294:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626),a=r(78766),o=r(99669),s=r(36301),l=r(9666),c=r(64625);function u(t,e,r,a){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function s(e){return n.validate(t[e],c[e])}var u,h=r(\"y\"),f=r(\"x\");if(\"box\"===e.type){var p=r(\"q1\"),d=r(\"median\"),m=r(\"q3\");e._hasPreCompStats=p&&p.length&&d&&d.length&&m&&m.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(m))}var g,y,v=o(h),x=o(f),_=v&&n.minRowLength(h),b=x&&n.minRowLength(f),w=a.calendar,T={autotypenumbers:a.autotypenumbers};if(e._hasPreCompStats)switch(String(x)+String(v)){case\"00\":var k=s(\"x0\")||s(\"dx\");g=!s(\"y0\")&&!s(\"dy\")||k?\"v\":\"h\",y=u;break;case\"10\":g=\"v\",y=Math.min(u,b);break;case\"20\":g=\"h\",y=Math.min(u,f.length);break;case\"01\":g=\"h\",y=Math.min(u,_);break;case\"02\":g=\"v\",y=Math.min(u,h.length);break;case\"12\":g=\"v\",y=Math.min(u,b,h.length);break;case\"21\":g=\"h\",y=Math.min(u,f.length,_);break;case\"11\":y=0;break;case\"22\":var A,M=!1;for(A=0;A<f.length;A++)if(\"category\"===l(f[A],w,T)){M=!0;break}if(M)g=\"v\",y=Math.min(u,b,h.length);else{for(A=0;A<h.length;A++)if(\"category\"===l(h[A],w,T)){M=!0;break}M?(g=\"h\",y=Math.min(u,f.length,_)):(g=\"v\",y=Math.min(u,b,h.length))}}else v>0?(g=\"v\",y=x>0?Math.min(b,_):Math.min(_)):x>0?(g=\"h\",y=Math.min(b)):y=0;if(y){e._length=y;var S=r(\"orientation\",g);e._hasPreCompStats?\"v\"===S&&0===x?(r(\"x0\",0),r(\"dx\",1)):\"h\"===S&&0===v&&(r(\"y0\",0),r(\"dy\",1)):\"v\"===S&&0===x?r(\"x0\"):\"h\"===S&&0===v&&r(\"y0\"),i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a)}else e.visible=!1}function h(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,c,\"marker.outliercolor\"),s=r(\"marker.line.outliercolor\"),l=\"outliers\";e._hasPreCompStats?l=\"all\":(o||s)&&(l=\"suspectedoutliers\");var u=r(a+\"points\",l);u?(r(\"jitter\",\"all\"===u?.3:0),r(\"pointpos\",\"all\"===u?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.angle\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===u&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var h=r(\"hoveron\");\"all\"!==h&&-1===h.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}t.exports={supplyDefaults:function(t,e,r,i){function s(r,i){return n.coerce(t,e,c,r,i)}if(u(t,e,s,i),!1!==e.visible){o(t,e,i,s),s(\"xhoverformat\"),s(\"yhoverformat\");var l=e._hasPreCompStats;l&&(s(\"lowerfence\"),s(\"upperfence\")),s(\"line.color\",(t.marker||{}).color||r),s(\"line.width\"),s(\"fillcolor\",a.addOpacity(e.line.color,.5));var f=!1;if(l){var p=s(\"mean\"),d=s(\"sd\");p&&p.length&&(f=!0,d&&d.length&&(f=\"sd\"))}s(\"whiskerwidth\");var m,g=s(\"sizemode\");\"quartiles\"===g&&(m=s(\"boxmean\",f)),s(\"showwhiskers\",\"quartiles\"===g),\"sd\"!==g&&\"sd\"!==m||s(\"sdmultiple\"),s(\"width\"),s(\"quartilemethod\");var y=!1;if(l){var v=s(\"notchspan\");v&&v.length&&(y=!0)}else n.validate(t.notchwidth,c.notchwidth)&&(y=!0);s(\"notched\",y)&&s(\"notchwidth\"),h(t,e,s,{prefix:\"box\"}),s(\"zorder\")}},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,c,t)}for(var o=0;o<t.length;o++){var l=(i=t[o]).type;\"box\"!==l&&\"violin\"!==l||(r=i._input,\"group\"===e[l+\"mode\"]&&s(r,i,e,a))}},handleSampleDefaults:u,handlePointsDefaults:h}},76429:function(t){\"use strict\";t.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},11448:function(t,e,r){\"use strict\";var n=r(29714),i=r(34809),a=r(32141),o=r(78766),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,m,g,y,v,x,_,b,w=t.cd,T=t.xa,k=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=M.bdPos,C=M.wHover,L=function(t){return u.c2l(t.pos)+M.bPos-u.c2l(p)};S&&\"both\"!==A.side?(\"positive\"===A.side&&(g=function(t){var e=L(t);return a.inbox(e,e+C,y)},x=E,_=0),\"negative\"===A.side&&(g=function(t){var e=L(t);return a.inbox(e-C,e,y)},x=0,_=E)):(g=function(t){var e=L(t);return a.inbox(e-C,e+C,y)},x=_=E),b=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,y)}:function(t){return a.inbox(t.min-f,t.max-f,y)},\"h\"===A.orientation?(f=e,p=r,d=b,m=g,l=\"y\",u=k,c=\"x\",h=T):(f=r,p=e,d=g,m=b,l=\"x\",u=T,c=\"y\",h=k);var I=Math.min(1,E/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function P(t){return(d(t)+m(t))/2}y=t.maxHoverDistance-I,v=t.maxSpikeDistance-I;var z=a.getDistanceFunction(s,d,m,P);if(a.getClosest(w,z,t),!1===t.index)return[];var O=w[t.index],D=A.line.color,R=(A.marker||{}).color;o.opacity(D)&&A.line.width?t.color=D:o.opacity(R)&&A.boxpoints?t.color=R:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(O.pos+M.bPos-_,!0),t[l+\"1\"]=u.c2p(O.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=void 0!==O.orig_p?O.orig_p:O.pos;var F=l+\"Spike\";t.spikeDistance=P(O)*v/y,t[F]=u.c2p(O.pos,!0);var B=A.boxmean||\"sd\"===A.sizemode||(A.meanline||{}).visible,N=A.boxpoints||A.points,j=N&&B?[\"max\",\"uf\",\"q3\",\"med\",\"mean\",\"q1\",\"lf\",\"min\"]:N&&!B?[\"max\",\"uf\",\"q3\",\"med\",\"q1\",\"lf\",\"min\"]:!N&&B?[\"max\",\"q3\",\"med\",\"mean\",\"q1\",\"min\"]:[\"max\",\"q3\",\"med\",\"q1\",\"min\"],U=h.range[1]<h.range[0];A.orientation===(U?\"v\":\"h\")&&j.reverse();for(var V=t.spikeDistance,q=t[F],H=[],G=0;G<j.length;G++){var Z=j[G];if(Z in O){var W=O[Z],Y=h.c2p(W,!0),X=i.extendFlat({},t);X.attr=Z,X[c+\"0\"]=X[c+\"1\"]=Y,X[c+\"LabelVal\"]=W,X[c+\"Label\"]=(M.labels?M.labels[Z]+\" \":\"\")+n.hoverLabelText(h,W,A[c+\"hoverformat\"]),X.hoverOnBox=!0,\"mean\"!==Z||!(\"sd\"in O)||\"sd\"!==A.boxmean&&\"sd\"!==A.sizemode||(X[c+\"err\"]=O.sd),X.hovertemplate=!1,H.push(X)}}t.name=\"\",t.spikeDistance=void 0,t[F]=void 0;for(var $=0;$<H.length;$++)\"med\"!==H[$].attr?(H[$].name=\"\",H[$].spikeDistance=void 0,H[$][F]=void 0):(H[$].spikeDistance=V,H[$][F]=q);return H}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),m=a.quadrature((function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)}),(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)})),g=!1,y=0;y<c.length;y++){o=c[y];for(var v=0;v<(o.pts||[]).length;v++){var x=m(l=o.pts[v]);x<=t.distance&&(t.distance=x,g=[y,v])}}if(!g)return!1;l=(o=c[g[0]]).pts[g[1]];var _=u.c2p(l.x,!0),b=h.c2p(l.y,!0),w=l.mrc||1;n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-w,x1:_+w,y0:b-w,y1:b+w,spikeDistance:t.distance,hovertemplate:f.hovertemplate});var T,k=o.orig_p,A=void 0!==k?k:o.pos;return\"h\"===f.orientation?(T=h,n.xLabelVal=l.x,n.yLabelVal=A):(T=u,n.xLabelVal=A,n.yLabelVal=l.y),n[T._id.charAt(0)+\"Spike\"]=T.c2p(o.pos,!0),s(l,f,n),n}t.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},53794:function(t,e,r){\"use strict\";t.exports={attributes:r(64625),layoutAttributes:r(64636),supplyDefaults:r(62294).supplyDefaults,crossTraceDefaults:r(62294).crossTraceDefaults,supplyLayoutDefaults:r(65067).supplyLayoutDefaults,calc:r(89429),crossTraceCalc:r(81606).crossTraceCalc,plot:r(95419).plot,style:r(59979).style,styleOnSelect:r(59979).styleOnSelect,hoverPoints:r(11448).hoverPoints,eventData:r(76429),selectPoints:r(72488),moduleType:\"trace\",name:\"box\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},64636:function(t){\"use strict\";t.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},65067:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(64636);function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}t.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,(function(r,n){return i.coerce(t,e,a,r,n)}),\"box\")},_supply:o}},95419:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203);function o(t,e,r,a,o){var s,l,c=\"h\"===r.orientation,u=e.val,h=e.pos,f=!!h.rangebreaks,p=a.bPos,d=a.wdPos||0,m=a.bPosPxOffset||0,g=r.whiskerwidth||0,y=!1!==r.showwhiskers,v=r.notched||!1,x=v?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(s=a.bdPos[0],l=a.bdPos[1]):(s=a.bdPos,l=a.bdPos);var _=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);_.enter().append(\"path\").style(\"vector-effect\",o?\"none\":\"non-scaling-stroke\").attr(\"class\",\"box\"),_.exit().remove(),_.each((function(t){if(t.empty)return n.select(this).attr(\"d\",\"M0,0Z\");var e=h.c2l(t.pos+p,!0),a=h.l2p(e-s)+m,o=h.l2p(e+l)+m,_=f?(a+o)/2:h.l2p(e)+m,b=r.whiskerwidth,w=f?a*b+(1-b)*_:h.l2p(e-d)+m,T=f?o*b+(1-b)*_:h.l2p(e+d)+m,k=h.l2p(e-s*x)+m,A=h.l2p(e+l*x)+m,M=\"sd\"===r.sizemode,S=u.c2p(M?t.mean-t.sd:t.q1,!0),E=M?u.c2p(t.mean+t.sd,!0):u.c2p(t.q3,!0),C=i.constrain(M?u.c2p(t.mean,!0):u.c2p(t.med,!0),Math.min(S,E)+1,Math.max(S,E)-1),L=void 0===t.lf||!1===r.boxpoints||M,I=u.c2p(L?t.min:t.lf,!0),P=u.c2p(L?t.max:t.uf,!0),z=u.c2p(t.ln,!0),O=u.c2p(t.un,!0);c?n.select(this).attr(\"d\",\"M\"+C+\",\"+k+\"V\"+A+\"M\"+S+\",\"+a+\"V\"+o+(v?\"H\"+z+\"L\"+C+\",\"+A+\"L\"+O+\",\"+o:\"\")+\"H\"+E+\"V\"+a+(v?\"H\"+O+\"L\"+C+\",\"+k+\"L\"+z+\",\"+a:\"\")+\"Z\"+(y?\"M\"+S+\",\"+_+\"H\"+I+\"M\"+E+\",\"+_+\"H\"+P+(0===g?\"\":\"M\"+I+\",\"+w+\"V\"+T+\"M\"+P+\",\"+w+\"V\"+T):\"\")):n.select(this).attr(\"d\",\"M\"+k+\",\"+C+\"H\"+A+\"M\"+a+\",\"+S+\"H\"+o+(v?\"V\"+z+\"L\"+A+\",\"+C+\"L\"+o+\",\"+O:\"\")+\"V\"+E+\"H\"+a+(v?\"V\"+O+\"L\"+k+\",\"+C+\"L\"+a+\",\"+z:\"\")+\"Z\"+(y?\"M\"+_+\",\"+S+\"V\"+I+\"M\"+_+\",\"+E+\"V\"+P+(0===g?\"\":\"M\"+w+\",\"+I+\"H\"+T+\"M\"+w+\",\"+P+\"H\"+T):\"\"))}))}function s(t,e,r,n){var o=e.x,s=e.y,l=n.bdPos,c=n.bPos,u=r.boxpoints||r.points;i.seedPseudoRandom();var h=t.selectAll(\"g.points\").data(u?function(t){return t.forEach((function(t){t.t=n,t.trace=r})),t}:[]);h.enter().append(\"g\").attr(\"class\",\"points\"),h.exit().remove();var f=h.selectAll(\"path\").data((function(t){var e,n,a=t.pts2,o=Math.max((t.max-t.min)/10,t.q3-t.q1),s=1e-9*o,h=.01*o,f=[],p=0;if(r.jitter){if(0===o)for(p=1,f=new Array(a.length),e=0;e<a.length;e++)f[e]=1;else for(e=0;e<a.length;e++){var d=Math.max(0,e-5),m=a[d].v,g=Math.min(a.length-1,e+5),y=a[g].v;\"all\"!==u&&(a[e].v<t.lf?y=Math.min(y,t.lf):m=Math.max(m,t.uf));var v=Math.sqrt(h*(g-d)/(y-m+s))||0;v=i.constrain(Math.abs(v),0,1),f.push(v),p=Math.max(v,p)}n=2*r.jitter/(p||1)}for(e=0;e<a.length;e++){var x=a[e],_=x.v,b=r.jitter?n*f[e]*(i.pseudoRandom()-.5):0,w=t.pos+c+l*(r.pointpos+b);\"h\"===r.orientation?(x.y=w,x.x=_):(x.x=w,x.y=_),\"suspectedoutliers\"===u&&_<t.uo&&_>t.lo&&(x.so=!0)}return a}));f.enter().append(\"path\").classed(\"point\",!0),f.exit().remove(),f.call(a.translatePoints,o,s)}function l(t,e,r,a){var o,s,l=e.val,c=e.pos,u=!!c.rangebreaks,h=a.bPos,f=a.bPosPxOffset||0,p=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var d=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);d.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),d.exit().remove(),d.each((function(t){var e=c.c2l(t.pos+h,!0),i=c.l2p(e-o)+f,a=c.l2p(e+s)+f,d=u?(i+a)/2:c.l2p(e)+f,m=l.c2p(t.mean,!0),g=l.c2p(t.mean-t.sd,!0),y=l.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+m+\",\"+i+\"V\"+a+(\"sd\"===p?\"m0,0L\"+g+\",\"+d+\"L\"+m+\",\"+i+\"L\"+y+\",\"+d+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+m+\"H\"+a+(\"sd\"===p?\"m0,0L\"+d+\",\"+g+\"L\"+i+\",\"+m+\"L\"+d+\",\"+y+\"Z\":\"\"))}))}t.exports={plot:function(t,e,r,a){var c=t._context.staticPlot,u=e.xaxis,h=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each((function(t){var e,r,i=n.select(this),a=t[0],f=a.t,p=a.trace;f.wdPos=f.bdPos*p.whiskerwidth,!0!==p.visible||f.empty?i.remove():(\"h\"===p.orientation?(e=h,r=u):(e=u,r=h),o(i,{pos:e,val:r},p,f,c),s(i,{x:u,y:h},p,f),l(i,{pos:e,val:r},p,f))}))},plotBoxAndWhiskers:o,plotPoints:s,plotBoxMean:l}},72488:function(t){\"use strict\";t.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},59979:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(62203);t.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each((function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}}));else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}}))},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},24319:function(t,e,r){\"use strict\";var n=r(34809).extendFlat,i=r(80712).axisHoverFormat,a=r(86706),o=r(64625);function s(t){return{line:{color:n({},o.line.color,{dflt:t}),width:o.line.width,editType:\"style\"},fillcolor:o.fillcolor,editType:\"style\"}}t.exports={xperiod:a.xperiod,xperiod0:a.xperiod0,xperiodalignment:a.xperiodalignment,xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),x:a.x,open:a.open,high:a.high,low:a.low,close:a.close,line:{width:n({},o.line.width,{}),editType:\"style\"},increasing:s(a.increasing.line.color.dflt),decreasing:s(a.decreasing.line.color.dflt),text:a.text,hovertext:a.hovertext,whiskerwidth:n({},o.whiskerwidth,{dflt:0}),hoverlabel:a.hoverlabel,zorder:o.zorder}},63679:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(40528),o=r(95694).calcCommon;function s(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}t.exports=function(t,e){var r=t._fullLayout,l=i.getFromId(t,e.xaxis),c=i.getFromId(t,e.yaxis),u=l.makeCalcdata(e,\"x\"),h=a(e,l,\"x\",u).vals,f=o(t,e,u,h,c,s);return f.length?(n.extendFlat(f[0].t,{num:r._numBoxes,dPos:n.distinctVals(h).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,f):[{t:{empty:!0}}]}},57336:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(28270),o=r(99669),s=r(24319);function l(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}t.exports=function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}a(t,e,c,i)?(o(t,e,i,c,{x:!0}),c(\"xhoverformat\"),c(\"yhoverformat\"),c(\"line.width\"),l(0,e,c,\"increasing\"),l(0,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0,c(\"zorder\")):e.visible=!1}},51252:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:r(24319),layoutAttributes:r(64636),supplyLayoutDefaults:r(65067).supplyLayoutDefaults,crossTraceCalc:r(81606).crossTraceCalc,supplyDefaults:r(57336),calc:r(63679),plot:r(95419).plot,layerName:\"boxlayer\",style:r(59979).style,hoverPoints:r(93245).hoverPoints,selectPoints:r(49343)}},8432:function(t,e,r){\"use strict\";var n=r(6038),i=r(78032);t.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach((function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={noAutotickangles:!0,noTicklabelshift:!0,noTicklabelstandoff:!0,noTicklabelstep:!0,tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,autotypenumbersDflt:r.autotypenumbers,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})}))}(t,e,r,o)}},97052:function(t,e,r){\"use strict\";var n=r(34809).isArrayOrTypedArray;function i(t,e){if(!n(t)||e>=10)return null;for(var r=1/0,a=-1/0,o=t.length,s=0;s<o;s++){var l=t[s];if(n(l)){var c=i(l,e+1);c&&(r=Math.min(c[0],r),a=Math.max(c[1],a))}else r=Math.min(l,r),a=Math.max(l,a)}return[r,a]}t.exports=function(t){return i(t,0)}},43745:function(t,e,r){\"use strict\";var n=r(80337),i=r(86961),a=r(10229),o=n({editType:\"calc\"}),s=r(36640).zorder;o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,t.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0,zorder:s}},94903:function(t,e,r){\"use strict\";var n=r(34809).isArrayOrTypedArray;t.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,m,g,y,v=n(r)?\"a\":\"b\",x=(\"a\"===v?t.aaxis:t.baxis).smoothing,_=\"a\"===v?t.a2i:t.b2j,b=\"a\"===v?r:i,w=\"a\"===v?i:r,T=\"a\"===v?e.a.length:e.b.length,k=\"a\"===v?e.b.length:e.a.length,A=Math.floor(\"a\"===v?t.b2j(w):t.a2i(w)),M=\"a\"===v?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(k-2,A)),l=A-s,o=\"a\"===v?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=_(b[0]),E=_(b[1]),C=S<E?1:-1,L=1e-8*(E-S),I=C>0?Math.floor:Math.ceil,P=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,O=C>0?Math.max:Math.min,D=I(S+L),R=P(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],m=O(S,a),y=(g=z(E,a+C))-m,u=Math.max(0,Math.min(T-2,Math.floor(.5*(m+g)))),f=M(g),x&&(p=o(u,m-u),d=o(u,g-u),c.push([h[0]+p[0]/3*y,h[1]+p[1]/3*y]),c.push([f[0]-d[0]/3*y,f[1]-d[1]/3*y])),c.push(f),F.push(c),h=f;return F}},86961:function(t,e,r){\"use strict\";var n=r(80337),i=r(10229),a=r(25829),o=r(80712).descriptionWithDates,s=r(13582).overrideAll,l=r(94850).T,c=r(93049).extendFlat;t.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autotypenumbers:a.autotypenumbers,autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},labelalias:c({},a.labelalias,{editType:\"calc\"}),tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\",description:o(\"tick label\")},tickformatstops:s(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},griddash:c({},l,{editType:\"calc\"}),showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgriddash:c({},l,{editType:\"calc\"}),minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},6038:function(t,e,r){\"use strict\";var n=r(43745),i=r(78766).addOpacity,a=r(33626),o=r(34809),s=r(22777),l=r(12036),c=r(54616),u=r(46473),h=r(19091),f=r(9666);t.exports=function(t,e,r){var p=r.letter,d=r.font||{},m=n[p+\"axis\"];function g(r,n){return o.coerce(t,e,m,r,n)}function y(r,n){return o.coerce2(t,e,m,r,n)}r.name&&(e._name=r.name,e._id=r.name),g(\"autotypenumbers\",r.autotypenumbersDflt);var v=g(\"type\");\"-\"===v&&(r.data&&function(t,e){if(\"-\"===t.type){var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=f(e,n,{autotypenumbers:t.autotypenumbers})}}(e,r.data),\"-\"===e.type?e.type=\"linear\":v=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",p+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"minexponent\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=p,\"date\"===v&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar),h(e,r.fullLayout),e.c2p=o.identity;var x=g(\"color\",r.dfltColor),_=x===t.color?x:d.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",d,{overrideDflt:{size:o.bigFont(d.size),color:_}}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,v),c(t,e,g,v,r),l(t,e,g,v,r),u(t,e,g,{data:r.data,dataAttr:p});var b=y(\"gridcolor\",i(x,.3)),w=y(\"gridwidth\"),T=y(\"griddash\"),k=g(\"showgrid\");k||(delete e.gridcolor,delete e.gridwidth,delete e.griddash);var A=y(\"startlinecolor\",x),M=y(\"startlinewidth\",w);g(\"startline\",e.showgrid||!!A||!!M)||(delete e.startlinecolor,delete e.startlinewidth);var S=y(\"endlinecolor\",x),E=y(\"endlinewidth\",w);return g(\"endline\",e.showgrid||!!S||!!E)||(delete e.endlinecolor,delete e.endlinewidth),k?(g(\"minorgridcount\"),g(\"minorgridwidth\",w),g(\"minorgriddash\",T),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgriddash,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridwidth,delete e.griddash),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.minexponent,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},67525:function(t,e,r){\"use strict\";var n=r(29714),i=r(34809).isArray1D,a=r(89992),o=r(97052),s=r(4753),l=r(93923),c=r(39373),u=r(93877),h=r(13007),f=r(87869),p=r(76842);t.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),m=e.aaxis,g=e.baxis,y=e.x,v=e.y,x=[];y&&i(y)&&x.push(\"x\"),v&&i(v)&&x.push(\"y\"),x.length&&f(e,m,g,\"a\",\"b\",x);var _=e._a=e._a||e.a,b=e._b=e._b||e.b;y=e._x||e.x,v=e._y||e.y;var w={};if(e._cheater){var T=\"index\"===m.cheatertype?_.length:_,k=\"index\"===g.cheatertype?b.length:b;y=a(T,k,e.cheaterslope)}e._x=y=u(y),e._y=v=u(v),h(y,_,b),h(v,_,b),p(e),e.setScale();var A=o(y),M=o(v),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]),I=1.3;return A=[E-S*I,E+S*I],M=[L-C*I,L+C*I],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,m),l(e,g),w.clipsegments=c(e._xctrl,e._yctrl,m,g),w.x=y,w.y=v,w.a=_,w.b=b,[w]}},39373:function(t){\"use strict\";t.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},4753:function(t,e,r){\"use strict\";var n=r(29714),i=r(93049).extendFlat;t.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,m,g,y,v,x=t[\"_\"+e],_=t[e+\"axis\"],b=_._gridlines=[],w=_._minorgridlines=[],T=_._boundarylines=[],k=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===_.tickmode&&(_.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,I=t._b.length;n.prepTicks(_),\"array\"===_.tickmode&&delete _.tickvals;var P=_.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,m,g,y=[],v=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(I-2,a))),s=a-o,x.length=I,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),y.push(l[0]+p[0]/3),v.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),y.push(h[0]-d[0]/3),v.push(h[1]-d[1]/3)),y.push(h[0]),v.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=I,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<I;a++)o=Math.min(I-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(m=t.dxydj([],c,a-1,u,0),y.push(l[0]+m[0]/3),v.push(l[1]+m[1]/3),g=t.dxydj([],c,a-1,u,1),y.push(h[0]-g[0]/3),v.push(h[1]-g[1]/3)),y.push(h[0]),v.push(h[1]),l=h;return x.axisLetter=e,x.axis=_,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=y,x.y=v,x.smoothing=A.smoothing,x}function O(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=k.length,\"b\"===e)for(o=Math.max(0,Math.min(I-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*P][i],u[i]=S[n*P][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*P],u[i]=S[i][n*P];return h.axisLetter=e,h.axis=_,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===_.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-_.arraytick0)/_.arraydtick*(1+l)),Math.ceil(-_.arraytick0/_.arraydtick/(1+l))].sort((function(t,e){return t-e})))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=_.arraytick0+_.arraydtick*f)<0||o>x.length-1||b.push(i(O(o),{color:_.gridcolor,width:_.gridwidth,dash:_.griddash}));for(f=u;f<h;f++)if(s=_.arraytick0+_.arraydtick*f,m=Math.min(s+_.arraydtick,x.length-1),!(s<0||s>x.length-1||m<0||m>x.length-1))for(g=x[s],y=x[m],a=0;a<_.minorgridcount;a++)(v=m-s)<=0||(d=g+(y-g)*(a+1)/(_.minorgridcount+1)*(_.arraydtick/v))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:_.minorgridcolor,width:_.minorgridwidth,dash:_.minorgriddash}));_.startline&&T.push(i(O(0),{color:_.startlinecolor,width:_.startlinewidth})),_.endline&&T.push(i(O(x.length-1),{color:_.endlinecolor,width:_.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-_.tick0)/_.dtick*(1+l)),Math.ceil((x[0]-_.tick0)/_.dtick/(1+l))].sort((function(t,e){return t-e})))[0],h=c[1],f=u;f<=h;f++)p=_.tick0+_.dtick*f,b.push(i(z(p),{color:_.gridcolor,width:_.gridwidth,dash:_.griddash}));for(f=u-1;f<h+1;f++)for(p=_.tick0+_.dtick*f,a=0;a<_.minorgridcount;a++)(d=p+_.dtick*(a+1)/(_.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:_.minorgridcolor,width:_.minorgridwidth,dash:_.minorgriddash}));_.startline&&T.push(i(z(x[0]),{color:_.startlinecolor,width:_.startlinewidth})),_.endline&&T.push(i(z(x[x.length-1]),{color:_.endlinecolor,width:_.endlinewidth}))}}},93923:function(t,e,r){\"use strict\";var n=r(29714),i=r(93049).extendFlat;t.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},49109:function(t){\"use strict\";t.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},89992:function(t,e,r){\"use strict\";var n=r(34809).isArrayOrTypedArray;t.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var m=1/0,g=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,m=Math.min(c,m),g=Math.max(c,g),u[a][i]=c;var y=1/(g-m),v=-m*y;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=y*u[a][i]+v;return u}},57075:function(t,e,r){\"use strict\";var n=r(49109),i=r(34809).ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}t.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,m,g,y,v,x=r[0].length,_=r.length,b=s?3*x-2:x,w=l?3*_-2:_;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],b),e[h]=i(e[h],b);for(u=0,f=0;u<_;u++,f+=l?3:1)for(p=t[f],d=e[f],m=r[u],g=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=m[c],d[h]=g[c];if(s)for(u=0,f=0;u<_;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)y=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=y[0][0],e[f][h-1]=y[0][1],t[f][h+1]=y[1][0],e[f][h+1]=y[1][1];v=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=v[0],e[f][1]=v[1],v=a([t[f][b-1],e[f][b-1]],[t[f][b-3],e[f][b-3]],[t[f][b-4],e[f][b-4]]),t[f][b-2]=v[0],e[f][b-2]=v[1]}if(l)for(h=0;h<b;h++){for(f=3;f<w-3;f+=3)y=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=y[0][0],e[f-1][h]=y[0][1],t[f+1][h]=y[1][0],e[f+1][h]=y[1][1];v=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=v[0],e[1][h]=v[1],v=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=v[0],e[w-2][h]=v[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<b-3;h+=3)y=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+y[0][0]),e[f][h-1]=.5*(e[f][h-1]+y[0][1]),t[f][h+1]=.5*(t[f][h+1]+y[1][0]),e[f][h+1]=.5*(e[f][h+1]+y[1][1]);v=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+v[0]),e[f][1]=.5*(e[f][1]+v[1]),v=a([t[f][b-1],e[f][b-1]],[t[f][b-3],e[f][b-3]],[t[f][b-4],e[f][b-4]]),t[f][b-2]=.5*(t[f][b-2]+v[0]),e[f][b-2]=.5*(e[f][b-2]+v[1])}return[t,e]}},45923:function(t){\"use strict\";t.exports={RELATIVE_CULL_TOLERANCE:1e-6}},39848:function(t){\"use strict\";t.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,m=p*i*2,g=-3*d,y=3*(d-m),v=3*(m-f),x=3*f,_=a*a,b=_*a,w=1-a,T=w*w,k=T*w;for(h=0;h<t.length;h++)o=g*(u=t[h])[n][r]+y*u[n][r+1]+v*u[n][r+2]+x*u[n][r+3],s=g*u[n+1][r]+y*u[n+1][r+1]+v*u[n+1][r+2]+x*u[n+1][r+3],l=g*u[n+2][r]+y*u[n+2][r+1]+v*u[n+2][r+2]+x*u[n+2][r+3],c=g*u[n+3][r]+y*u[n+3][r+1]+v*u[n+3][r+2]+x*u[n+3][r+3],e[h]=k*o+3*(T*a*s+w*_*l)+b*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,m=3*(f-p),g=3*(p-u),y=3*u,v=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+m*c[n][r+1]+g*c[n][r+2]+y*c[n][r+3],s=d*c[n+1][r]+m*c[n+1][r+1]+g*c[n+1][r+2]+y*c[n+1][r+3],e[l]=v*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,m=d*d,g=m*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=g*o+3*(m*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},41839:function(t){\"use strict\";t.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,m=d*d,g=m*d,y=a*a,v=1-a,x=v*v,_=v*a*2,b=-3*x,w=3*(x-_),T=3*(_-y),k=3*y;for(h=0;h<t.length;h++)o=b*(u=t[h])[n][r]+w*u[n+1][r]+T*u[n+2][r]+k*u[n+3][r],s=b*u[n][r+1]+w*u[n+1][r+1]+T*u[n+2][r+1]+k*u[n+3][r+1],l=b*u[n][r+2]+w*u[n+1][r+2]+T*u[n+2][r+2]+k*u[n+3][r+2],c=b*u[n][r+3]+w*u[n+1][r+3]+T*u[n+2][r+3]+k*u[n+3][r+3],e[h]=g*o+3*(m*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,m=d*d,g=m*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=g*o+3*(m*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,m=-3*p,g=3*(p-d),y=3*(d-h),v=3*h;for(l=0;l<t.length;l++)o=m*(c=t[l])[n][r]+g*c[n+1][r]+y*c[n+2][r]+v*c[n+3][r],s=m*c[n][r+1]+g*c[n+1][r+1]+y*c[n+2][r+1]+v*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},13828:function(t){\"use strict\";t.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),m=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var g=d*d,y=g*d,v=1-d,x=v*v,_=x*v,b=m*m,w=b*m,T=1-m,k=T*T,A=k*T;for(h=0;h<t.length;h++)i=_*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+v*g*u[p][f+2])+y*u[p][f+3],s=_*u[p+1][f]+3*(x*d*u[p+1][f+1]+v*g*u[p+1][f+2])+y*u[p+1][f+3],l=_*u[p+2][f]+3*(x*d*u[p+2][f+1]+v*g*u[p+2][f+2])+y*u[p+2][f+3],c=_*u[p+3][f]+3*(x*d*u[p+3][f+1]+v*g*u[p+3][f+2])+y*u[p+3][f+3],e[h]=A*i+3*(k*m*s+T*b*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),m=Math.max(0,Math.min(1,n-p));f*=3;var g=d*d,y=g*d,v=1-d,x=v*v,_=x*v,b=1-m;for(u=0;u<t.length;u++)i=b*(h=t[u])[p][f]+m*h[p+1][f],s=b*h[p][f+1]+m*h[p+1][f+1],l=b*h[p][f+2]+m*h[p+1][f+1],c=b*h[p][f+3]+m*h[p+1][f+1],e[u]=_*i+3*(x*d*s+v*g*l)+y*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),m=Math.max(0,Math.min(1,n-p));p*=3;var g=m*m,y=g*m,v=1-m,x=v*v,_=x*v,b=1-d;for(u=0;u<t.length;u++)i=b*(h=t[u])[p][f]+d*h[p][f+1],s=b*h[p+1][f]+d*h[p+1][f+1],l=b*h[p+2][f]+d*h[p+2][f+1],c=b*h[p+3][f]+d*h[p+3][f+1],e[u]=_*i+3*(x*m*s+v*g*l)+y*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,m=1-f;for(l=0;l<t.length;l++)i=m*(c=t[l])[h][u]+f*c[h][u+1],s=m*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},13254:function(t,e,r){\"use strict\";var n=r(34809),i=r(10820),a=r(8432),o=r(43745),s=r(10229);t.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);n.coerceFont(c,\"font\",l.font),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\"),c(\"zorder\")):e.visible=!1}},48050:function(t,e,r){\"use strict\";t.exports={attributes:r(43745),supplyDefaults:r(13254),plot:r(87947),calc:r(67525),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\",\"noHover\",\"noSortingByValue\"],meta:{}}},26571:function(t){\"use strict\";t.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet))return a}return r}},3685:function(t){\"use strict\";t.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},6720:function(t,e,r){\"use strict\";var n=r(34809).isArrayOrTypedArray;t.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},33163:function(t){\"use strict\";t.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},87947:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(6720),o=r(3685),s=r(33163),l=r(30635),c=r(34809),u=c.strRotate,h=c.strTranslate,f=r(4530);function p(t,e,r,s,l,c,u){var h=\"const-\"+l+\"-lines\",f=r.selectAll(\".\"+h).data(c);f.enter().append(\"path\").classed(h,!0).style(\"vector-effect\",u?\"none\":\"non-scaling-stroke\"),f.each((function(r){var s=r,l=s.x,c=s.y,u=a([],l,t.c2p),h=a([],c,e.c2p),f=\"M\"+o(u,h,s.smoothing);n.select(this).attr(\"d\",f).style(\"stroke-width\",s.width).style(\"stroke\",s.color).style(\"stroke-dasharray\",i.dashStyle(s.dash,s.width)).style(\"fill\",\"none\")})),f.exit().remove()}function d(t,e,r,a,o,c,f,p){var d=c.selectAll(\"text.\"+p).data(f);d.enter().append(\"text\").classed(p,!0);var m=0,g={};return d.each((function(o,c){var f;if(\"auto\"===o.axis.tickangle)f=s(a,e,r,o.xy,o.dxy);else{var p=(o.axis.tickangle+180)*Math.PI/180;f=s(a,e,r,o.xy,[Math.cos(p),Math.sin(p)])}c||(g={angle:f.angle,flip:f.flip});var d=(o.endAnchor?-1:1)*f.flip,y=n.select(this).attr({\"text-anchor\":d>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);y.attr(\"transform\",h(f.p[0],f.p[1])+u(f.angle)+h(o.axis.labelpadding*d,.3*v.height)),m=Math.max(m,v.width+o.axis.labelpadding)})),d.exit().remove(),g.maxExtent=m,g}t.exports=function(t,e,r,i){var l=t._context.staticPlot,u=e.xaxis,h=e.yaxis,f=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each((function(e){var r=n.select(this),i=e[0],m=i.trace,g=m.aaxis,v=m.baxis,x=c.ensureSingle(r,\"g\",\"minorlayer\"),_=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),w=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",m.opacity),p(u,h,_,0,\"a\",g._gridlines,!0),p(u,h,_,0,\"b\",v._gridlines,!0),p(u,h,x,0,\"a\",g._minorgridlines,!0),p(u,h,x,0,\"b\",v._minorgridlines,!0),p(u,h,b,0,\"a-boundary\",g._boundarylines,l),p(u,h,b,0,\"b-boundary\",v._boundarylines,l);var T=d(t,u,h,m,0,w,g._labels,\"a-label\"),k=d(t,u,h,m,0,w,v._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),m=c.aggNums(Math.max,null,r.a),g=c.aggNums(Math.min,null,r.b),v=c.aggNums(Math.max,null,r.b);u=.5*(d+m),h=g,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h))),y(t,e,r,0,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(g+v),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h))),y(t,e,r,0,f,p,r.baxis,i,a,l,\"b-title\")}(t,w,m,0,u,h,T,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,m=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),m.push(o(l,u,s.bicubic));var g=\"M\"+m.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",g)}(m,i,f,u,h)}))};var m=f.LINE_SPACING,g=(1-f.MID_SHIFT)/m+1;function y(t,e,r,a,o,c,f,p,d,y,v){var x=[];f.title.text&&x.push(f.title.text);var _=e.selectAll(\"text.\"+v).data(x),b=y.maxExtent;_.enter().append(\"text\").classed(v,!0),_.each((function(){var e=s(r,p,d,o,c);-1===[\"start\",\"both\"].indexOf(f.showticklabels)&&(b=0);var a=f.title.font.size;b+=a+f.title.offset;var v=(y.angle+(y.flip<0?180:0)-e.angle+450)%360,x=v>90&&v<270,_=n.select(this);_.text(f.title.text).call(l.convertToTspans,t),x&&(b=(-l.lineCount(_)+g)*m*a-b),_.attr(\"transform\",h(e.p[0],e.p[1])+u(e.angle)+h(0,b)).attr(\"text-anchor\",\"middle\").call(i.font,f.title.font)})),_.exit().remove()}},76842:function(t,e,r){\"use strict\";var n=r(45923),i=r(98813).findBin,a=r(57075),o=r(13828),s=r(39848),l=r(41839);t.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],m=r[0],g=r[u-1],y=e[e.length-1]-e[0],v=r[r.length-1]-r[0],x=y*n.RELATIVE_CULL_TOLERANCE,_=v*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,m-=_,g+=_,t.isVisible=function(t,e){return t>p&&t<d&&e>m&&e<g},t.isOccluded=function(t,e){return t<p||t>d||e<m||e>g},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,m=0,g=0,y=[];n<e[0]?(h=0,f=0,m=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,m=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,g=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,g=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),m&&(t.dxydi(y,h,p,f,d),l[0]+=y[0]*m,l[1]+=y[1]*m),g&&(t.dxydj(y,h,p,f,d),l[0]+=y[0]*g,l[1]+=y[1]*g)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=v*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},13007:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,m,g,y,v,x,_,b,w,T=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),T=Math.max(T,Math.abs(t[a][i]));if(!s.length)return t;var k=0,A=0,M=s.length;do{for(k=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,I,P,z=0,O=0;0===i?(C=e[I=Math.min(c-1,2)],L=e[1],S=t[a][I],O+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[I=Math.max(0,c-3)],L=e[c-2],S=t[a][I],O+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],O+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[P=Math.min(u-1,2)],L=r[1],S=t[P][i],O+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[P=Math.max(0,u-3)],L=r[u-2],S=t[P][i],O+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],O+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?O/=z:(d=e[i+1]-e[i],m=e[i]-e[i-1],x=(g=r[a+1]-r[a])*(y=r[a]-r[a-1])*(g+y),O=((v=d*m*(d+m))*(y*t[a+1][i]+g*t[a-1][i])+x*(m*t[a][i+1]+d*t[a][i-1]))/(x*(m+d)+v*(y+g))),k+=(b=(_=O-t[a][i])/T)*b,w=z?0:.85,t[a][i]+=_*(1+w)}k=Math.sqrt(k)}while(A++<100&&k>1e-5);return n.log(\"Smoother converged to\",k,\"after\",A,\"iterations\"),t}},10820:function(t,e,r){\"use strict\";var n=r(34809).isArray1D;t.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},92802:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(6893),a=r(87163),o=r(9829),s=r(10229).defaultLine,l=r(93049).extendFlat,c=i.marker.line;t.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},geojson:l({},i.geojson,{}),featureidkey:i.featureidkey,text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},12702:function(t,e,r){\"use strict\";var n=r(10721),i=r(63821).BADNUM,a=r(28379),o=r(99203),s=r(48861);function l(t){return t&&\"string\"==typeof t}t.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},51893:function(t,e,r){\"use strict\";var n=r(34809),i=r(39356),a=r(92802);t.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,h=s(\"geojson\");(\"string\"==typeof h&&\"\"!==h||n.isPlainObject(h))&&(u=\"geojson-id\"),\"geojson-id\"===s(\"locationmode\",u)&&s(\"featureidkey\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},38414:function(t){\"use strict\";t.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t.ct=a.ct,t}},94125:function(t,e,r){\"use strict\";var n=r(29714),i=r(92802),a=r(34809).fillText;t.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot,p=[e,r],d=[e+360,r];for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains(p)&&(c=!c),o._polygons[l].contains(d)&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(!e.hovertemplate){var n=r.hi||e.hoverinfo,o=String(r.loc),s=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),l=-1!==s.indexOf(\"name\"),c=-1!==s.indexOf(\"location\"),u=-1!==s.indexOf(\"z\"),h=-1!==s.indexOf(\"text\"),f=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&f.push(o)),u&&f.push(t.zLabel),h&&a(r,e,f),t.extraText=f.join(\"<br>\")}}(t,h,o),[t]}},58075:function(t,e,r){\"use strict\";t.exports={attributes:r(92802),supplyDefaults:r(51893),colorbar:r(12431),calc:r(12702),calcGeoJSON:r(4700).calcGeoJSON,plot:r(4700).plot,style:r(59342).style,styleOnSelect:r(59342).styleOnSelect,hoverPoints:r(94125),eventData:r(38414),selectPoints:r(43727),moduleType:\"trace\",name:\"choropleth\",basePlotModule:r(47544),categories:[\"geo\",\"noOpacity\",\"showLegend\"],meta:{}}},4700:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(3994),o=r(11577).getTopojsonFeatures,s=r(32919).findExtremes,l=r(59342).style;t.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],i=n._subplot,l=r.locationmode,c=r._length,u=\"geojson-id\"===l?a.extractTraceFeature(t):o(r,i.topojson),h=[],f=[],p=0;p<c;p++){var d=t[p],m=\"geojson-id\"===l?d.fOut:a.locationToFeature(l,d.loc,u);if(m){d.geojson=m,d.ct=m.properties.ct,d._polygons=a.feature2polygons(m);var g=a.computeBbox(m);h.push(g[0],g[2]),f.push(g[1],g[3])}else d.geojson=null}if(\"geojson\"===n.fitbounds&&\"geojson-id\"===l){var y=a.computeBbox(a.getTraceGeojson(r));h=[y[0],y[2]],f=[y[1],y[3]]}var v={padded:!0};r._extremes.lon=s(n.lonaxis._ax,h,v),r._extremes.lat=s(n.lataxis._ax,f,v)},plot:function(t,e,r){var a=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(a,r,\"trace choropleth\").each((function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)}))}}},43727:function(t){\"use strict\";t.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},59342:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(62203),o=r(88856);function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each((function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)})),a.selectedPointStyle(s,r)}t.exports={style:function(t,e){e&&s(0,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n):s(0,e)}}},34770:function(t,e,r){\"use strict\";var n=r(92802),i=r(87163),a=r(3208).rb,o=r(9829),s=r(93049).extendFlat;t.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},40980:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(88856),o=r(62203),s=r(39532).makeBlank,l=r(3994);function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=a.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=i.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return i.extendFlat(n.fill.paint,{\"fill-opacity\":e}),i.extendFlat(n.line.paint,{\"line-opacity\":e}),n}t.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},h=e._opts={fill:o,line:u,geojson:s()};if(!r)return h;var f=l.extractTraceFeature(t);if(!f)return h;var p,d,m,g=a.makeColorScaleFuncFromTrace(e),y=e.marker,v=y.line||{};i.isArrayOrTypedArray(y.opacity)&&(p=function(t){var e=t.mo;return n(e)?+i.constrain(e,0,1):0}),i.isArrayOrTypedArray(v.color)&&(d=function(t){return t.mlc}),i.isArrayOrTypedArray(v.width)&&(m=function(t){return t.mlw});for(var x=0;x<t.length;x++){var _=t[x],b=_.fOut;if(b){var w=b.properties;w.fc=g(_.z),p&&(w.mo=p(_)),d&&(w.mlc=d(_)),m&&(w.mlw=m(_)),_.ct=w.ct,_._polygons=l.feature2polygons(b)}}var T=p?{type:\"identity\",property:\"mo\"}:y.opacity;return i.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),i.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:v.color,\"line-width\":m?{type:\"identity\",property:\"mlw\"}:v.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",h.geojson={type:\"FeatureCollection\",features:f},c(t),h},convertOnSelect:c}},94149:function(t,e,r){\"use strict\";var n=r(34809),i=r(39356),a=r(34770);t.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},9419:function(t,e,r){\"use strict\";t.exports={attributes:r(34770),supplyDefaults:r(94149),colorbar:r(12431),calc:r(12702),plot:r(30316),hoverPoints:r(94125),eventData:r(38414),selectPoints:r(43727),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmap\",basePlotModule:r(34091),categories:[\"map\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_map\"}}},30316:function(t,e,r){\"use strict\";var n=r(40980).convert,i=r(40980).convertOnSelect,a=r(8814).traceLayerPrefix;function o(t,e){this.type=\"choroplethmap\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t)),t[0].trace._glTrace=this},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},t.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},86227:function(t,e,r){\"use strict\";var n=r(92802),i=r(87163),a=r(3208).rb,o=r(9829),s=r(93049).extendFlat;t.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},51335:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(88856),o=r(62203),s=r(39532).makeBlank,l=r(3994);function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=a.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=i.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return i.extendFlat(n.fill.paint,{\"fill-opacity\":e}),i.extendFlat(n.line.paint,{\"line-opacity\":e}),n}t.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},h=e._opts={fill:o,line:u,geojson:s()};if(!r)return h;var f=l.extractTraceFeature(t);if(!f)return h;var p,d,m,g=a.makeColorScaleFuncFromTrace(e),y=e.marker,v=y.line||{};i.isArrayOrTypedArray(y.opacity)&&(p=function(t){var e=t.mo;return n(e)?+i.constrain(e,0,1):0}),i.isArrayOrTypedArray(v.color)&&(d=function(t){return t.mlc}),i.isArrayOrTypedArray(v.width)&&(m=function(t){return t.mlw});for(var x=0;x<t.length;x++){var _=t[x],b=_.fOut;if(b){var w=b.properties;w.fc=g(_.z),p&&(w.mo=p(_)),d&&(w.mlc=d(_)),m&&(w.mlw=m(_)),_.ct=w.ct,_._polygons=l.feature2polygons(b)}}var T=p?{type:\"identity\",property:\"mo\"}:y.opacity;return i.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),i.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:v.color,\"line-width\":m?{type:\"identity\",property:\"mlw\"}:v.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",h.geojson={type:\"FeatureCollection\",features:f},c(t),h},convertOnSelect:c}},8244:function(t,e,r){\"use strict\";var n=r(34809),i=r(39356),a=r(86227);t.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},28128:function(t,e,r){\"use strict\";[\"*choroplethmapbox* trace is deprecated!\",\"Please consider switching to the *choroplethmap* trace type and `map` subplots.\",\"Learn more at: https://plotly.com/javascript/maplibre-migration/\"].join(\" \"),t.exports={attributes:r(86227),supplyDefaults:r(8244),colorbar:r(12431),calc:r(12702),plot:r(33501),hoverPoints:r(94125),eventData:r(38414),selectPoints:r(43727),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:r(68192),categories:[\"mapbox\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_mapbox\"}}},33501:function(t,e,r){\"use strict\";var n=r(51335).convert,i=r(51335).convertOnSelect,a=r(44245).traceLayerPrefix;function o(t,e){this.type=\"choroplethmapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t)),t[0].trace._glTrace=this},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},t.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},49865:function(t,e,r){\"use strict\";var n=r(87163),i=r(80712).axisHoverFormat,a=r(3208).rb,o=r(42450),s=r(9829),l=r(93049).extendFlat,c={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\",\"raw\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:a({editType:\"calc\"},{keys:[\"norm\"]}),uhoverformat:i(\"u\",1),vhoverformat:i(\"v\",1),whoverformat:i(\"w\",1),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),showlegend:l({},s.showlegend,{dflt:!1})};l(c,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"})),[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){c[t]=o[t]})),c.hoverinfo=l({},s.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),c.transforms=void 0,t.exports=c},93805:function(t,e,r){\"use strict\";var n=r(28379);t.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},49393:function(t,e,r){\"use strict\";var n=r(99098).gl_cone3d,i=r(99098).gl_cone3d.createConeMesh,a=r(34809).simpleMap,o=r(46998).parseColorScale,s=r(88856).extractOpts,l=r(34809).isArrayOrTypedArray,c=r(88239);function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var c=this.data.hovertext||this.data.text;return l(c)&&void 0!==c[e]?t.textLabel=c[e]:c&&(t.textLabel=c),!0}};var f={xaxis:0,yaxis:1,zaxis:2},p={tip:1,tail:0,cm:.25,center:.5},d={tip:1,tail:1,cm:.75,center:.5};function m(t,e){var r=t.fullSceneLayout,i=t.dataScale,l={};function u(t,e){var n=r[e],o=i[f[e]];return a(t,(function(t){return n.d2l(t)*o}))}l.vectors=c(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),l.positions=c(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var h=s(e);l.colormap=o(e),l.vertexIntensityBounds=[h.min/e._normMax,h.max/e._normMax],l.coneOffset=p[e.anchor];var m=e.sizemode;\"scaled\"===m?l.coneSize=e.sizeref||.5:\"absolute\"===m?l.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5:\"raw\"===m&&(l.coneSize=e.sizeref),l.coneSizemode=m;var g=n(l),y=e.lightposition;return g.lightPosition=[y.x,y.y,y.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=d[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}h.update=function(t){this.data=t;var e=m(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},t.exports=function(t,e){var r=t.glplot.gl,n=m(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},17326:function(t,e,r){\"use strict\";var n=r(34809),i=r(39356),a=r(49865);t.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");if(l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length){var d=s(\"sizemode\");s(\"sizeref\",\"raw\"===d?1:.5),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"uhoverformat\"),s(\"vhoverformat\"),s(\"whoverformat\"),s(\"xhoverformat\"),s(\"yhoverformat\"),s(\"zhoverformat\"),e._length=null}else e.visible=!1}},47050:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:r(2487),categories:[\"gl3d\",\"showLegend\"],attributes:r(49865),supplyDefaults:r(17326),colorbar:{min:\"cmin\",max:\"cmax\"},calc:r(93805),plot:r(49393),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},52240:function(t,e,r){\"use strict\";var n=r(81658),i=r(36640),a=r(80712),o=a.axisHoverFormat,s=a.descriptionOnlyNumbers,l=r(87163),c=r(94850).T,u=r(80337),h=r(93049).extendFlat,f=r(20726),p=f.COMPARISON_OPS2,d=f.INTERVAL_OPS,m=i.line;t.exports=h({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),zhoverformat:o(\"z\",1),hovertemplate:n.hovertemplate,texttemplate:h({},n.texttemplate,{}),textfont:h({},n.textfont,{}),hoverongaps:n.hoverongaps,connectgaps:h({},n.connectgaps,{}),fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:u({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\",description:s(\"contour label\")},operation:{valType:\"enumerated\",values:[].concat(p).concat(d),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:h({},m.color,{editType:\"style+colorbars\"}),width:{valType:\"number\",min:0,editType:\"style+colorbars\"},dash:c,smoothing:h({},m.smoothing,{}),editType:\"plot\"},zorder:i.zorder},l(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},40352:function(t,e,r){\"use strict\";var n=r(88856),i=r(51670),a=r(62475),o=r(48715);t.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var m=h-p/2;l=[m,m+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},49886:function(t){\"use strict\";t.exports=function(t,e){var r,n=t[0],i=n.z;switch(e.type){case\"levels\":var a=Math.min(i[0][0],i[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(a>o.level||o.starts.length&&a===o.level)}break;case\"constraint\":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,i[r][0]),u=Math.min(u,i[r][s-1]),c=Math.max(c,i[r][0]),c=Math.max(c,i[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,i[0][r]),u=Math.min(u,i[l-1][r]),c=Math.max(c,i[0][r]),c=Math.max(c,i[l-1][r]);var h,f,p=e.value;switch(e._operation){case\">\":p>c&&(n.prefixBoundary=!0);break;case\"<\":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case\"[]\":h=Math.min(p[0],p[1]),((f=Math.max(p[0],p[1]))<u||h>c||n.starts.length&&f===u)&&(n.prefixBoundary=!0);break;case\"][\":h=Math.min(p[0],p[1]),f=Math.max(p[0],p[1]),h<u&&f>c&&(n.prefixBoundary=!0)}}}},92697:function(t,e,r){\"use strict\";var n=r(88856),i=r(16438),a=r(48715);t.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n.extractOpts(e);r._fillgradient=h.reversescale?n.flipScale(h.colorscale):h.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},53156:function(t){\"use strict\";t.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},29503:function(t,e,r){\"use strict\";var n=r(10721),i=r(20576),a=r(78766),o=a.addOpacity,s=a.opacity,l=r(20726),c=r(34809).isArrayOrTypedArray,u=l.CONSTRAINT_REDUCTION,h=l.COMPARISON_OPS2;t.exports=function(t,e,r,a,l,f){var p,d,m,g=e.contours,y=r(\"contours.operation\");g._operation=u[y],function(t,e){var r;-1===h.indexOf(e.operation)?(t(\"contours.value\",[0,1]),c(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(c(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===y?p=g.showlines=!0:(p=r(\"contours.showlines\"),m=r(\"fillcolor\",o((t.line||{}).color||l,.5))),p&&(d=r(\"line.color\",m&&s(m)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\")),r(\"line.smoothing\"),i(r,a,d,f)}},22783:function(t,e,r){\"use strict\";var n=r(20726),i=r(10721);function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}t.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},47495:function(t){\"use strict\";t.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},1999:function(t,e,r){\"use strict\";var n=r(34809);function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}t.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));for(;o.starts.length;)a.starts.push(l(o.starts.shift()));return[a]}}},57543:function(t,e,r){\"use strict\";var n=r(34809),i=r(86073),a=r(99669),o=r(29503),s=r(47495),l=r(39889),c=r(63814),u=r(52240);t.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,u,r,i)}if(i(t,e,f,h)){a(t,e,h,f),f(\"xhoverformat\"),f(\"yhoverformat\"),f(\"text\"),f(\"hovertext\"),f(\"hoverongaps\"),f(\"hovertemplate\");var p=\"constraint\"===f(\"contours.type\");f(\"connectgaps\",n.isArray1D(e.z)),p?o(t,e,f,h,r):(s(t,e,f,(function(r){return n.coerce2(t,e,u,r)})),l(t,e,f,h)),e.contours&&\"heatmap\"===e.contours.coloring&&c(f,h),f(\"zorder\")}else e.visible=!1}},86828:function(t,e,r){\"use strict\";var n=r(34809),i=r(22783),a=r(48715);t.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},48715:function(t){\"use strict\";t.exports=function(t){return t.end+t.size/1e6}},27657:function(t,e,r){\"use strict\";var n=r(34809),i=r(53156);function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=t.crossings[u],f=function(t,e,r){var n=0,a=0;return t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1,[n,a]}(h,r,e),p=[s(t,e,[-f[0],-f[1]])],d=t.z.length,m=t.z[0].length,g=e.slice(),y=f.slice();for(c=0;c<1e4;c++){if(h>20?(h=i.CHOOSESADDLE[h][(f[0]||f[1])<0?0:1],t.crossings[u]=i.SADDLEREMAINDER[h]):delete t.crossings[u],!(f=i.NEWDELTA[h])){n.log(\"Found bad marching index:\",h,e,t.level);break}p.push(s(t,e,f)),e[0]+=f[0],e[1]+=f[1],u=e.join(\",\"),a(p[p.length-1],p[p.length-2],o,l)&&p.pop();var v=f[0]&&(e[0]<0||e[0]>m-2)||f[1]&&(e[1]<0||e[1]>d-2);if(e[0]===g[0]&&e[1]===g[1]&&f[0]===y[0]&&f[1]===y[1]||r&&v)break;h=t.crossings[u]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,_,b,w,T,k,A,M,S,E,C,L,I,P,z,O=a(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)L=p[c],I=p[c-1],void 0,void 0,P=L[2]-I[2],z=L[3]-I[3],D+=A=Math.sqrt(P*P+z*z),F.push(A);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(b=0,_=c-1;_>=B&&x+F[_]<N;_--)x+=F[_];if(O&&c===p.length-2)for(b=0;b<_&&x+F[b]<N;b++)x+=F[b];T=c-_+b+1,k=Math.floor((c+_+b+2)/2),w=O||c!==p.length-2?O||-1!==_?T%2?j(k):[(j(k)[0]+j(k+1)[0])/2,(j(k)[1]+j(k+1)[1])/2]:p[0]:p[p.length-1],p.splice(_+1,c-_+1,w),c=_+1,b&&(B=b),O&&(c===p.length-2?p[b]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(O)p.pop(),t.paths.push(p);else{r||n.log(\"Unclosed interior contour?\",t.level,g.join(\",\"),p.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],p[p.length-1],o,l)){p.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],p[0],o,l)){V=!0,p.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(p.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(p,E));break}V||(t.edgepaths[M]=p.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[M]=E.concat(p),U=!0);U||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a),c=(1!==l?(1-l)*o.c2l(t.x[n]):0)+(0!==l?l*o.c2l(t.x[n+1]):0);return[o.c2p(o.l2c(c),!0),s.c2p(t.y[i],!0),n+l,i]}var u=(t.level-a)/(t.z[i+1][n]-a),h=(1!==u?(1-u)*s.c2l(t.y[i]):0)+(0!==u?u*s.c2l(t.y[i+1]):0);return[o.c2p(t.x[n],!0),s.c2p(s.l2c(h),!0),n,i+u]}t.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},29815:function(t,e,r){\"use strict\";var n=r(78766),i=r(93125);t.exports=function(t,e,r,a,o){o||(o={}),o.isContour=!0;var s=i(t,e,r,a,o);return s&&s.forEach((function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))})),s}},91405:function(t,e,r){\"use strict\";t.exports={attributes:r(52240),supplyDefaults:r(57543),calc:r(40352),plot:r(8850).plot,style:r(1328),colorbar:r(92697),hoverPoints:r(29815),moduleType:\"trace\",name:\"contour\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},20576:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",a,{overrideDflt:{color:r}}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},16438:function(t,e,r){\"use strict\";var n=r(45568),i=r(88856),a=r(48715);t.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,m=new Array(d),g=new Array(d),y=u.min,v=u.max;if(\"heatmap\"===e.coloring){for(f=0;f<d;f++)h=p[f],m[f]=h[0]*(v-y)+y,g[f]=h[1];var x=n.extent([y,v,e.start,e.start+s*(l-1)]),_=x[y<v?0:1],b=x[y<v?1:0];_!==y&&(m.splice(0,0,_),g.splice(0,0,g[0])),b!==v&&(m.push(b),g.push(g[g.length-1]))}else{var w=t._input&&\"number\"==typeof t._input.zmin&&\"number\"==typeof t._input.zmax;for(w&&(r<=y||o>=v)&&(r<=y&&(r=y),o>=v&&(o=v),l=Math.floor((o-r)/s)+1,c=0),f=0;f<d;f++)h=p[f],m[f]=(h[0]*(l+c-1)-c/2)*s+r,g[f]=h[1];(w||t.autocontour)&&(m[0]>y&&(m.unshift(y),g.unshift(g[0])),m[m.length-1]<v&&(m.push(v),g.push(g[g.length-1])))}return i.makeColorScaleFunc({domain:m,range:g},{noNumericCheck:!0})}},83545:function(t,e,r){\"use strict\";var n=r(53156);function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}t.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,m=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),m&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},8850:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(88856),s=r(30635),l=r(29714),c=r(19091),u=r(19236),h=r(83545),f=r(27657),p=r(86828),d=r(1999),m=r(49886),g=r(53156),y=g.LABELOPTIMIZER;function v(t,e){var r,n,o,s,l,c,u,h=\"\",f=0,p=t.edgepaths.map((function(t,e){return e})),d=!0;function m(t){return Math.abs(t[1]-e[2][1])<.01}function g(t){return Math.abs(t[0]-e[0][0])<.01}function y(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!y(r)?n=e[1]:g(r)?n=e[0]:m(r)?n=e[3]:y(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var v=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-v[0])<.01&&(v[1]-r[1])*(n[1]-v[1])>=0&&(n=v,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-v[1])<.01&&(v[0]-r[0])*(n[0]-v[0])>=0&&(n=v,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,v)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function x(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=y.EDGECOST*(1/(f-1)+1/(p-1));d+=y.ANGLECOST*c*c;for(var m=s-u,g=l-h,v=s+u,x=l+h,_=0;_<r.length;_++){var b=r[_],w=Math.cos(b.theta)*b.width/2,T=Math.sin(b.theta)*b.width/2,k=2*i.segmentDistance(m,g,v,x,b.x-w,b.y-T,b.x+w,b.y+T)/(e.height+b.height),A=b.level===e.level,M=A?y.SAMELEVELDISTANCE:1;if(k<=M)return 1/0;d+=y.NEIGHBORCOST*(A?y.SAMELEVELFACTOR:1)/(k-M)}return d}function _(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)i[(r=n[e])[0]][r[1]]=0;return t.zmask=i,i}e.plot=function(t,r,o,s){var l=r.xaxis,c=r.yaxis;i.makeTraceGroups(s,o,\"contour\").each((function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,w=y.y,T=x.contours,k=p(T,r,y),A=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),M=[];\"heatmap\"===T.coloring&&(M=[o]),u(t,r,M,A),h(k),f(k);var S=l.c2p(b[0],!0),E=l.c2p(b[b.length-1],!0),C=c.c2p(w[0],!0),L=c.c2p(w[w.length-1],!0),I=[[S,L],[E,L],[E,C],[S,C]],P=k;\"constraint\"===T.type&&(P=d(k,T._operation)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,I,T),function(t,e,r,a){var o=\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation,s=\"M\"+r.join(\"L\")+\"Z\";o&&m(e,a);var l=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(o?e:[]);l.enter().append(\"path\"),l.exit().remove(),l.each((function(t){var e=(t.prefixBoundary?s:\"\")+v(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(s,P,I,T),function(t,r,o,s,l){var c=o._context.staticPlot,u=i.ensureSingle(t,\"g\",\"contourlines\"),h=!1!==l.showlines,f=l.showlabels,p=h&&f,d=e.createLines(u,h||f,r,c),m=e.createLineClip(u,p,o,s.trace.uid),y=t.selectAll(\"g.contourlabels\").data(f?[0]:[]);if(y.exit().remove(),y.enter().append(\"g\").classed(\"contourlabels\",!0),f){var v=[],x=[];i.clearLocationCache();var _=e.labelFormatter(o,s),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),w=r[0].xaxis,T=r[0].yaxis,k=w._length,A=T._length,M=w.range,S=T.range,E=i.aggNums(Math.min,null,s.x),C=i.aggNums(Math.max,null,s.x),L=i.aggNums(Math.min,null,s.y),I=i.aggNums(Math.max,null,s.y),P=Math.max(w.c2p(E,!0),0),z=Math.min(w.c2p(C,!0),k),O=Math.max(T.c2p(I,!0),0),D=Math.min(T.c2p(L,!0),A),R={};M[0]<M[1]?(R.left=P,R.right=z):(R.left=z,R.right=P),S[0]<S[1]?(R.top=O,R.bottom=D):(R.top=D,R.bottom=O),R.middle=(R.top+R.bottom)/2,R.center=(R.left+R.right)/2,v.push([[R.left,R.top],[R.right,R.top],[R.right,R.bottom],[R.left,R.bottom]]);var F=Math.sqrt(k*k+A*A),B=g.LABELDISTANCE*F/Math.max(1,r.length/g.LABELINCREASE);d.each((function(t){var r=e.calcTextOpts(t.level,_,b,o);n.select(this).selectAll(\"path\").each((function(){var t=i.getVisibleSegment(this,R,r.height/2);if(t&&!(t.len<(r.width+r.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/B),g.LABELMAX),a=0;a<n;a++){var o=e.findBestTextLocation(this,t,r,x,R);if(!o)break;e.addLabelData(o,r,x,v)}}))})),b.remove(),e.drawLabels(y,x,o,m,p?v:null)}f&&!h&&d.remove()}(s,k,t,y,T),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c=\"clip\"+s.uid,u=l.selectAll(\"#\"+c).data(s.connectgaps?[]:[0]);if(u.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:_(n),smoothing:0};h([p]),f([p]),m([p],{type:\"levels\"}),i.ensureSingle(u,\"path\",\"\").attr(\"d\",(p.prefixBoundary?\"M\"+o.join(\"L\")+\"Z\":\"\")+v(p,o))}else c=null;a.setClipUrl(t,c,r)}(s,r,t,y,I)}))},e.createLines=function(t,e,r,n){var i=r[0].smoothing,o=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(o.exit().remove(),o.enter().append(\"g\").classed(\"contourlevel\",!0),e){var s=o.selectAll(\"path.openline\").data((function(t){return t.pedgepaths||t.edgepaths}));s.exit().remove(),s.enter().append(\"path\").classed(\"openline\",!0),s.attr(\"d\",(function(t){return a.smoothopen(t,i)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",n?\"none\":\"non-scaling-stroke\");var l=o.selectAll(\"path.closedline\").data((function(t){return t.ppaths||t.paths}));l.exit().remove(),l.enter().append(\"path\").classed(\"closedline\",!0),l.attr(\"d\",(function(t){return a.smoothclosed(t,i)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",n?\"none\":\"non-scaling-stroke\")}return o},e.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},e.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,a=n.contours,s={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"};if(a.labelformat)s.tickformat=a.labelformat,c(s,r);else{var u=o.extractOpts(n);if(u&&u.colorbar&&u.colorbar._axis)s=u.colorbar._axis;else{if(\"constraint\"===a.type){var h=a.value;i.isArrayOrTypedArray(h)?s.range=[h[0],h[h.length-1]]:s.range=[h,h]}else s.range=[a.start,a.end],s.nticks=(a.end-a.start)/a.size;s.range[0]===s.range[1]&&(s.range[1]+=s.range[0]||1),s.nticks||(s.nticks=1e3),c(s,r),l.prepTicks(s),s._tmin=null,s._tmax=null}}return function(t){return l.tickText(s,t).text}},e.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(s.convertToTspans,n);var o=r.node(),l=a.bBox(o,!0);return{text:i,width:l.width,height:l.height,fontSize:+o.style[\"font-size\"].replace(\"px\",\"\"),level:t,dy:(l.top+l.bottom)/2}},e.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/y.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(y.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<y.ITERATIONS;p++){for(var d=o;d<l;d+=s){var m=i.getTextLocation(t,e.total,d,h),g=x(m,r,n,a);g<f&&(f=g,u=m,c=d)}if(f>2*y.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=y.MAXCOST)return u},e.addLabelData=function(t,e,r,n){var i=e.fontSize,a=e.width+i/3,o=Math.max(0,e.height-i/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),h=Math.cos(c),f=function(t,e){return[s+t*h-e*u,l+t*u+e*h]},p=[f(-a/2,-o/2),f(-a/2,o/2),f(a/2,o/2),f(a/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:a,height:o}),n.push(p)},e.drawLabels=function(t,e,r,a,o){var l=t.selectAll(\"text\").data(e,(function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta}));if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each((function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(s.convertToTspans,r)})),o){for(var c=\"\",u=0;u<o.length;u++)c+=\"M\"+o[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},62475:function(t,e,r){\"use strict\";var n=r(29714),i=r(34809);function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}t.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),r.size>0||(c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c)}}},1328:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(12774),o=r(16438);t.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each((function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)}));var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each((function(t){i.font(n.select(this),{weight:d.weight,style:d.style,variant:d.variant,textcase:d.textcase,lineposition:d.lineposition,shadow:d.shadow,family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})})),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var m;e.selectAll(\"g.contourfill path\").style(\"fill\",(function(t){return void 0===m&&(m=t.level),p(t.level+.5*l)})),void 0===m&&(m=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(m-.5*l))}})),a(t)}},39889:function(t,e,r){\"use strict\";var n=r(39356),i=r(20576);t.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},66365:function(t,e,r){\"use strict\";var n=r(81658),i=r(52240),a=r(87163),o=r(93049).extendFlat,s=i.contours;t.exports=o({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:i.line.color,width:i.line.width,dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},zorder:i.zorder,transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},80849:function(t,e,r){\"use strict\";var n=r(28379),i=r(34809),a=r(87869),o=r(93877),s=r(69295),l=r(78106),c=r(80924),u=r(50538),h=r(26571),f=r(62475);t.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var m=function(t,e){var r,u,h,f,p,d,m,g=e._carpetTrace,y=g.aaxis,v=g.baxis;y._minDtick=0,v._minDtick=0,i.isArray1D(e.z)&&a(e,y,v,\"a\",\"b\",[\"z\"]),r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?y.makeCalcdata(e,\"_a\"):[],f=f?v.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,m=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(m),s(m,e._emptypoints);var x=i.maxRowLength(m),_=\"scaled\"===e.xtype?\"\":r,b=c(e,_,u,h,x,y),w=\"scaled\"===e.ytype?\"\":f,T={a:b,b:c(e,w,p,d,m.length,v),z:m};return\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:m,containerStr:\"\",cLetter:\"z\"}),[T]}(t,e);return f(e,e._z),m}}},50538:function(t,e,r){\"use strict\";var n=r(34809),i=r(86073),a=r(66365),o=r(29503),s=r(47495),l=r(39889);t.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,(function(r){return n.coerce2(t,e,a,r)})),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null;u(\"zorder\")}},34406:function(t,e,r){\"use strict\";t.exports={attributes:r(66365),supplyDefaults:r(50538),colorbar:r(92697),calc:r(80849),plot:r(71815),style:r(1328),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\",\"noHover\",\"noSortingByValue\"],meta:{}}},71815:function(t,e,r){\"use strict\";var n=r(45568),i=r(6720),a=r(3685),o=r(62203),s=r(34809),l=r(83545),c=r(27657),u=r(8850),h=r(53156),f=r(1999),p=r(86828),d=r(49886),m=r(26571),g=r(94903);function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function v(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}t.exports=function(t,e,r,_){var b=e.xaxis,w=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each((function(r){var _=n.select(this),T=r[0],k=T.trace,A=k._carpetTrace=m(t,k),M=t.calcdata[A.index][0];if(A.visible&&\"legendonly\"!==A.visible){var S=T.a,E=T.b,C=k.contours,L=p(C,e,T),I=\"constraint\"===C.type,P=C._operation,z=I?\"=\"===P?\"lines\":\"fill\":C.coloring,O=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(L);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(L,D,R);var F,B,N,j,U=L;\"constraint\"===C.type&&(U=f(L,P)),function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}(L,H);var V=[];for(j=M.clipsegments.length-1;j>=0;j--)F=M.clipsegments[j],B=i([],F.x,b.c2p),N=i([],F.y,w.c2p),B.reverse(),N.reverse(),V.push(a(B,N,F.bicubic));var q=\"M\"+V.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,M.clipsegments,b,w,I,z),function(t,e,r,i,a,l,c,u,h,f,p){var m=\"fill\"===f;m&&d(a,t.contours);var y=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(m?a:[]);y.enter().append(\"path\"),y.exit().remove(),y.each((function(t){var e=(t.prefixBoundary?p:\"\")+function(t,e,r,n,i,a,l,c){var u,h,f,p,d,m,y,v=\"\",x=e.edgepaths.map((function(t,e){return e})),_=!0,b=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function T(t){return Math.abs(t[1]-r[0][1])<w}function k(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<b}function M(t){return Math.abs(t[0]-r[2][0])<b}function S(t,e){var r,n,o,s,u=\"\";for(T(t)&&!M(t)||k(t)&&!A(t)?(s=i.aaxis,o=g(i,a,[t[0],e[0]],.5*(t[1]+e[1]))):(s=i.baxis,o=g(i,a,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?\"C\":\"L\",n=0;n<o[r].length;n++){var h=o[r][n];u+=[l.c2p(h[0]),c.c2p(h[1])]+\" \"}return u}for(u=0,h=null;x.length;){var E=e.edgepaths[u][0];for(h&&(v+=S(h,E)),y=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),v+=_?y:y.replace(/^M/,\"L\"),x.splice(x.indexOf(u),1),h=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!h){s.log(\"Missing end?\",u,e);break}for(T(h)&&!M(h)?f=r[1]:A(h)?f=r[0]:k(h)?f=r[3]:M(h)&&(f=r[2]),m=0;m<e.edgepaths.length;m++){var C=e.edgepaths[m][0];Math.abs(h[0]-f[0])<b?Math.abs(h[0]-C[0])<b&&(C[1]-h[1])*(f[1]-C[1])>=0&&(f=C,d=m):Math.abs(h[1]-f[1])<w?Math.abs(h[1]-C[1])<w&&(C[0]-h[0])*(f[0]-C[0])>=0&&(f=C,d=m):s.log(\"endpt to newendpt is not vert. or horz.\",h,f,C)}if(d>=0)break;v+=S(h,f),h=f}if(d===e.edgepaths.length){s.log(\"unclosed perimeter path\");break}u=d,(_=-1===x.indexOf(u))&&(u=x[0],v+=S(h,f)+\"Z\",h=null)}for(u=0;u<e.paths.length;u++)v+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return v}(0,t,l,c,u,h,r,i);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(k,_,b,w,U,O,H,A,M,z,q),function(t,e,r,i,a,l,c){var f=r._context.staticPlot,p=s.ensureSingle(t,\"g\",\"contourlines\"),d=!1!==a.showlines,m=a.showlabels,g=d&&m,_=u.createLines(p,d||m,e,f),b=u.createLineClip(p,g,r,i.trace.uid),w=t.selectAll(\"g.contourlabels\").data(m?[0]:[]);if(w.exit().remove(),w.enter().append(\"g\").classed(\"contourlabels\",!0),m){var T=l.xaxis,k=l.yaxis,A=T._length,M=k._length,S=[[[0,0],[A,0],[A,M],[0,M]]],E=[];s.clearLocationCache();var C=u.labelFormatter(r,i),L=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),I={left:0,right:A,center:A/2,top:0,bottom:M,middle:M/2},P=Math.sqrt(A*A+M*M),z=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);_.each((function(t){var e=u.calcTextOpts(t.level,C,L,r);n.select(this).selectAll(\"path\").each((function(r){var n=this,i=s.getVisibleSegment(n,I,e.height/2);if(i&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(o){var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1],f=y(t,0,1),p=y(t,n.total,n.total-1),d=g(o[0],f),m=n.total-g(o[o.length-1],p);n.min<d&&(n.min=d),n.max>m&&(n.max=m),n.len=n.max-n.min}function g(t,e){var r,n=0,o=.1;return(Math.abs(t[0]-l)<o||Math.abs(t[0]-c)<o)&&(r=v(i.dxydb_rough(t[0],t[1],o)),n=Math.max(n,a*x(e,r)/2)),(Math.abs(t[1]-u)<o||Math.abs(t[1]-h)<o)&&(r=v(i.dxyda_rough(t[0],t[1],o)),n=Math.max(n,a*x(e,r)/2)),n}}(n,r,t,i,c,e.height),!(i.len<(e.width+e.height)*h.LABELMIN)))for(var a=Math.min(Math.ceil(i.len/z),h.LABELMAX),o=0;o<a;o++){var l=u.findBestTextLocation(n,i,e,E,I);if(!l)break;u.addLabelData(l,e,E,S)}}))})),L.remove(),u.drawLabels(w,E,r,b,g?S:null)}m&&!d&&_.remove()}(_,L,t,T,C,e,A),o.setClipUrl(_,A._clipPathId,t)}function H(t){var e=A.ab2xy(t[0],t[1],!0);return[b.c2p(e[0]),w.c2p(e[1])]}}))}},70690:function(t,e,r){\"use strict\";var n=r(87163),i=r(3208).rb,a=r(9829),o=r(71388),s=r(93049).extendFlat;t.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},91582:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809).isArrayOrTypedArray,a=r(63821).BADNUM,o=r(28379),s=r(34809)._;t.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var m=c[h];f.z=n(m)?m:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},95012:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(78766),o=r(88856),s=r(63821).BADNUM,l=r(39532).makeBlank;t.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,m=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var g=t[u],y=g.lonlat;if(y[0]!==s){var v={};if(d){var x=g.z;v.z=x!==s?x:0}m&&(v.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:y},properties:v})}}var _=o.extractOpts(e),b=_.reversescale?o.flipScale(_.colorscale):_.colorscale,w=b[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<b.length;u++)T.push(b[u][0],b[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],_.min,0,_.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(_.max-_.min),\"heatmap-color\":T,\"heatmap-radius\":m?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},9653:function(t,e,r){\"use strict\";var n=r(34809),i=r(39356),a=r(70690);t.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},16302:function(t){\"use strict\";t.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},28045:function(t,e,r){\"use strict\";var n=r(29714),i=r(67275).hoverPoints,a=r(67275).getExtraText;t.exports=function(t,e,r){var o=i(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=n.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=a(c,u,l[0].t.labels),[s]}}},91995:function(t,e,r){\"use strict\";t.exports={attributes:r(70690),supplyDefaults:r(9653),colorbar:r(12431),formatLabels:r(66762),calc:r(91582),plot:r(99932),hoverPoints:r(28045),eventData:r(16302),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymap\",basePlotModule:r(34091),categories:[\"map\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_map\"}}},99932:function(t,e,r){\"use strict\";var n=r(95012),i=r(8814).traceLayerPrefix;function a(t,e){this.type=\"densitymap\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},t.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},17347:function(t,e,r){\"use strict\";var n=r(87163),i=r(3208).rb,a=r(9829),o=r(95833),s=r(93049).extendFlat;t.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},60675:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809).isArrayOrTypedArray,a=r(63821).BADNUM,o=r(28379),s=r(34809)._;t.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var m=c[h];f.z=n(m)?m:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},78391:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(78766),o=r(88856),s=r(63821).BADNUM,l=r(39532).makeBlank;t.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,m=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var g=t[u],y=g.lonlat;if(y[0]!==s){var v={};if(d){var x=g.z;v.z=x!==s?x:0}m&&(v.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:y},properties:v})}}var _=o.extractOpts(e),b=_.reversescale?o.flipScale(_.colorscale):_.colorscale,w=b[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<b.length;u++)T.push(b[u][0],b[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],_.min,0,_.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(_.max-_.min),\"heatmap-color\":T,\"heatmap-radius\":m?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},1892:function(t,e,r){\"use strict\";var n=r(34809),i=r(39356),a=r(17347);t.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},8919:function(t){\"use strict\";t.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},54478:function(t,e,r){\"use strict\";var n=r(29714),i=r(18016).hoverPoints,a=r(18016).getExtraText;t.exports=function(t,e,r){var o=i(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=n.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=a(c,u,l[0].t.labels),[s]}}},81264:function(t,e,r){\"use strict\";[\"*densitymapbox* trace is deprecated!\",\"Please consider switching to the *densitymap* trace type and `map` subplots.\",\"Learn more at: https://plotly.com/javascript/maplibre-migration/\"].join(\" \"),t.exports={attributes:r(17347),supplyDefaults:r(1892),colorbar:r(12431),formatLabels:r(69009),calc:r(60675),plot:r(5165),hoverPoints:r(54478),eventData:r(8919),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:r(68192),categories:[\"mapbox\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_mapbox\"}}},5165:function(t,e,r){\"use strict\";var n=r(78391),i=r(44245).traceLayerPrefix;function a(t,e){this.type=\"densitymapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},t.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},43179:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},62824:function(t,e,r){\"use strict\";var n,i=r(81481),a=r(36640).line,o=r(9829),s=r(80712).axisHoverFormat,l=r(3208).rb,c=r(3208).ay,u=r(87948),h=r(93049).extendFlat,f=r(78766);t.exports={x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,xhoverformat:s(\"x\"),yhoverformat:s(\"y\"),hovertext:i.hovertext,hovertemplate:l({},{keys:u.eventDataKeys}),hoverinfo:h({},o.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:c({editType:\"plot\"},{keys:u.eventDataKeys.concat([\"label\",\"value\"])}),text:i.text,textposition:i.textposition,insidetextanchor:h({},i.insidetextanchor,{dflt:\"middle\"}),textangle:h({},i.textangle,{dflt:0}),textfont:i.textfont,insidetextfont:i.insidetextfont,outsidetextfont:i.outsidetextfont,constraintext:i.constraintext,cliponaxis:i.cliponaxis,orientation:h({},i.orientation,{}),offset:h({},i.offset,{arrayOk:!1}),width:h({},i.width,{arrayOk:!1}),marker:(n=h({},i.marker),delete n.pattern,delete n.cornerradius,n),connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:h({},a.color,{dflt:f.defaultLine}),width:h({},a.width,{dflt:0,editType:\"plot\"}),dash:a.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,zorder:i.zorder}},28152:function(t,e,r){\"use strict\";var n=r(29714),i=r(40528),a=r(43179),o=r(48861),s=r(63821).BADNUM;function l(t){return t===s?0:t}t.exports=function(t,e){var r,c,u,h,f,p,d,m,g=n.getFromId(t,e.xaxis||\"x\"),y=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=g.makeCalcdata(e,\"x\"),u=y.makeCalcdata(e,\"y\"),h=i(e,y,\"y\",u),f=!!e.yperiodalignment,p=\"y\"):(r=y.makeCalcdata(e,\"y\"),u=g.makeCalcdata(e,\"x\"),h=i(e,g,\"x\",u),f=!!e.xperiodalignment,p=\"x\"),c=h.vals;var v,x=Math.min(c.length,r.length),_=new Array(x);for(e._base=[],d=0;d<x;d++){r[d]<0&&(r[d]=s);var b=!1;r[d]!==s&&d+1<x&&r[d+1]!==s&&(b=!0),m=_[d]={p:c[d],s:r[d],cNext:b},e._base[d]=-.5*m.s,f&&(_[d].orig_p=u[d],_[d][p+\"End\"]=h.ends[d],_[d][p+\"Start\"]=h.starts[d]),e.ids&&(m.id=String(e.ids[d])),0===d&&(_[0].vTotal=0),_[0].vTotal+=l(m.s),m.begR=l(m.s)/l(_[0].s)}for(d=0;d<x;d++)(m=_[d]).s!==s&&(m.sumR=m.s/_[0].vTotal,m.difR=void 0!==v?m.s/v:1,v=m.s);return a(_,e),o(_,e),_}},87948:function(t){\"use strict\";t.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},82539:function(t,e,r){\"use strict\";var n=r(24782).setGroupPositions;t.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var m={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,m),n(t,c,l,f,m),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++)g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0,r[g].nextP1=r[g+1].p1,r[g].nextS1=r[g+1].s1)}}},30495:function(t,e,r){\"use strict\";var n=r(34809),i=r(36301),a=r(17550).handleText,o=r(99867),s=r(99669),l=r(62824),c=r(78766);t.exports={supplyDefaults:function(t,e,r,i){function u(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,u)){s(t,e,i,u),u(\"xhoverformat\"),u(\"yhoverformat\"),u(\"orientation\",e.y&&!e.x?\"v\":\"h\"),u(\"offset\"),u(\"width\");var h=u(\"text\");u(\"hovertext\"),u(\"hovertemplate\");var f=u(\"textposition\");a(t,e,i,u,f,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"===e.textposition||e.texttemplate||u(\"textinfo\",n.isArrayOrTypedArray(h)?\"text+value\":\"value\");var p=u(\"marker.color\",r);u(\"marker.line.color\",c.defaultLine),u(\"marker.line.width\"),u(\"connector.visible\")&&(u(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return c.addOpacity(e,.5*c.opacity(e))}(p)),u(\"connector.line.width\")&&(u(\"connector.line.color\"),u(\"connector.line.dash\"))),u(\"zorder\")}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.funnelmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},29412:function(t){\"use strict\";t.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},27759:function(t,e,r){\"use strict\";var n=r(78766).opacity,i=r(91664).hoverOnBars,a=r(34809).formatPercent;t.exports=function(t,e,r,o,s){var l=i(t,e,r,o,s);if(l){var c=l.cd,u=c[0].trace,h=\"h\"===u.orientation,f=c[l.index];l[(h?\"x\":\"y\")+\"LabelVal\"]=f.s,l.percentInitial=f.begR,l.percentInitialLabel=a(f.begR,1),l.percentPrevious=f.difR,l.percentPreviousLabel=a(f.difR,1),l.percentTotal=f.sumR,l.percentTotalLabel=a(f.sumR,1);var p=f.hi||u.hoverinfo,d=[];if(p&&\"none\"!==p&&\"skip\"!==p){var m=\"all\"===p,g=p.split(\"+\"),y=function(t){return m||-1!==g.indexOf(t)};y(\"percent initial\")&&d.push(l.percentInitialLabel+\" of initial\"),y(\"percent previous\")&&d.push(l.percentPreviousLabel+\" of previous\"),y(\"percent total\")&&d.push(l.percentTotalLabel+\" of total\")}return l.extraText=d.join(\"<br>\"),l.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;return n(i)?i:n(a)&&o?a:void 0}(u,f),[l]}}},52213:function(t,e,r){\"use strict\";t.exports={attributes:r(62824),layoutAttributes:r(93795),supplyDefaults:r(30495).supplyDefaults,crossTraceDefaults:r(30495).crossTraceDefaults,supplyLayoutDefaults:r(34980),calc:r(28152),crossTraceCalc:r(82539),plot:r(83482),style:r(7240).style,hoverPoints:r(27759),eventData:r(29412),selectPoints:r(88384),moduleType:\"trace\",name:\"funnel\",basePlotModule:r(37703),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},93795:function(t){\"use strict\";t.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},34980:function(t,e,r){\"use strict\";var n=r(34809),i=r(93795);t.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},83482:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(63821).BADNUM,s=r(32995),l=r(84102).clearMinTextSize;function c(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}t.exports=function(t,e,r,u){var h=t._fullLayout;l(\"funnel\",h),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),h=r[0].trace,f=i.ensureSingle(s,\"g\",\"regions\");if(h.connector&&h.connector.visible){var p=\"h\"===h.orientation,d=f.selectAll(\"g.region\").data(i.identity);d.enter().append(\"g\").classed(\"region\",!0),d.exit().remove();var m=d.size();d.each((function(r,s){if(s===m-1||r.cNext){var h=c(r,l,u,p),f=h[0],d=h[1],g=\"\";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&f[2]!==o&&d[2]!==o&&f[3]!==o&&d[3]!==o&&(g+=p?\"M\"+f[0]+\",\"+d[1]+\"L\"+f[2]+\",\"+d[2]+\"H\"+f[3]+\"L\"+f[1]+\",\"+d[1]+\"Z\":\"M\"+f[1]+\",\"+d[1]+\"L\"+f[2]+\",\"+d[3]+\"V\"+d[2]+\"L\"+f[1]+\",\"+d[0]+\"Z\"),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each((function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each((function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,f),h=u[0],p=u[1],m=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(m+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],m+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(m+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],m+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,u),s.plot(t,e,r,u,{mode:h.funnelmode,norm:h.funnelmode,gap:h.funnelgap,groupgap:h.funnelgroupgap})}},7240:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(78766),o=r(20438).DESELECTDIM,s=r(6851),l=r(84102).resizeText,c=s.styleTextPoints;t.exports={style:function(t,e,r){var s=r||n.select(t).selectAll('g[class^=\"funnellayer\"]').selectAll(\"g.trace\");l(t,s,\"funnel\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".regions\").each((function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,s.connector.fillcolor)})),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},63447:function(t,e,r){\"use strict\";var n=r(55412),i=r(9829),a=r(13792).u,o=r(3208).rb,s=r(3208).ay,l=r(93049).extendFlat;t.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:\"calc\"},pattern:n.marker.pattern,editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),texttemplate:s({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),hoverinfo:l({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),textposition:l({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},86817:function(t,e,r){\"use strict\";var n=r(44122);e.name=\"funnelarea\",e.plot=function(t,r,i,a){n.plotBasePlot(e.name,t,r,i,a)},e.clean=function(t,r,i,a){n.cleanBasePlot(e.name,t,r,i,a)}},2807:function(t,e,r){\"use strict\";var n=r(44148);t.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},79824:function(t,e,r){\"use strict\";var n=r(34809),i=r(63447),a=r(13792).N,o=r(17550).handleText,s=r(46979).handleLabelsAndValues,l=r(46979).handleMarkerDefaults;t.exports=function(t,e,r,c){function u(r,a){return n.coerce(t,e,i,r,a)}var h=u(\"labels\"),f=u(\"values\"),p=s(h,f),d=p.len;if(e._hasLabels=p.hasLabels,e._hasValues=p.hasValues,!e._hasLabels&&e._hasValues&&(u(\"label0\"),u(\"dlabel\")),d){e._length=d,l(t,e,c,u),u(\"scalegroup\");var m,g=u(\"text\"),y=u(\"texttemplate\");if(y||(m=u(\"textinfo\",Array.isArray(g)?\"text+percent\":\"percent\")),u(\"hovertext\"),u(\"hovertemplate\"),y||m&&\"none\"!==m){var v=u(\"textposition\");o(t,e,c,u,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}else\"none\"===m&&u(\"textposition\",\"none\");a(e,c,u),u(\"title.text\")&&(u(\"title.position\"),n.coerceFont(u,\"title.font\",c.font)),u(\"aspectratio\"),u(\"baseratio\")}else e.visible=!1}},91132:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:r(86817),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:r(63447),layoutAttributes:r(10270),supplyDefaults:r(79824),supplyLayoutDefaults:r(69161),calc:r(2807).calc,crossTraceCalc:r(2807).crossTraceCalc,plot:r(96673),style:r(13757),styleOne:r(32891),meta:{}}},10270:function(t,e,r){\"use strict\";var n=r(4031).hiddenlabels;t.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},69161:function(t,e,r){\"use strict\";var n=r(34809),i=r(10270);t.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},96673:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(34809),o=a.strScale,s=a.strTranslate,l=r(30635),c=r(32995).toMoveInsideBar,u=r(84102),h=u.recordMinTextSize,f=u.clearMinTextSize,p=r(37252),d=r(35734),m=d.attachFxHandlers,g=d.determineInsideTextFont,y=d.layoutAreas,v=d.prerenderTitles,x=d.positionTitleOutside,_=d.formatSliceLabel;function b(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}t.exports=function(t,e){var r=t._context.staticPlot,u=t._fullLayout;f(\"funnelarea\",u),v(e,t),y(e,u._size),a.makeTraceGroups(u._funnelarealayer,e,\"trace\").each((function(e){var f=n.select(this),d=e[0],y=d.trace;!function(t){if(t.length){var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o,s,l=Math.pow(i,2),c=e.vTotal,u=c,h=c*l/(1-l)/c,f=[];for(f.push(E()),o=t.length-1;o>-1;o--)if(!(s=t[o]).hidden){var p=s.v/u;h+=p,f.push(E())}var d=1/0,m=-1/0;for(o=0;o<f.length;o++)a=f[o],d=Math.min(d,a[1]),m=Math.max(m,a[1]);for(o=0;o<f.length;o++)f[o][1]-=(m+d)/2;var g=f[f.length-1][0],y=e.r,v=(m-d)/2,x=y/g,_=y/v*n;for(e.r=_*v,o=0;o<f.length;o++)f[o][0]*=x,f[o][1]*=_;var b,w,T=[-(a=f[0])[0],a[1]],k=[a[0],a[1]],A=0;for(o=t.length-1;o>-1;o--)if(!(s=t[o]).hidden){var M=f[A+=1][0],S=f[A][1];s.TL=[-M,S],s.TR=[M,S],s.BL=T,s.BR=k,s.pxmid=(b=s.TR,w=s.BR,[.5*(b[0]+w[0]),.5*(b[1]+w[1])]),T=s.TL,k=s.TR}}function E(){var t,e={x:t=Math.sqrt(h),y:-t};return[e.x,e.y]}}(e),f.each((function(){var f=n.select(this).selectAll(\"g.slice\").data(e);f.enter().append(\"g\").classed(\"slice\",!0),f.exit().remove(),f.each((function(o,s){if(o.hidden)n.select(this).selectAll(\"path,g\").remove();else{o.pointNumber=o.i,o.curveNumber=y.index;var f=d.cx,v=d.cy,x=n.select(this),w=x.selectAll(\"path.surface\").data([o]);w.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":r?\"none\":\"all\"}),x.call(m,t,e);var T=\"M\"+(f+o.TR[0])+\",\"+(v+o.TR[1])+b(o.TR,o.BR)+b(o.BR,o.BL)+b(o.BL,o.TL)+\"Z\";w.attr(\"d\",T),_(t,o,d);var k=p.castOption(y.textposition,o.pts),A=x.selectAll(\"g.slicetext\").data(o.text&&\"none\"!==k?[0]:[]);A.enter().append(\"g\").classed(\"slicetext\",!0),A.exit().remove(),A.each((function(){var r=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),p=a.ensureUniformFontSize(t,g(y,o,u.font));r.text(o.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p).call(l.convertToTspans,t);var d,m,x,_=i.bBox(r.node()),b=Math.min(o.BL[1],o.BR[1])+v,w=Math.max(o.TL[1],o.TR[1])+v;m=Math.max(o.TL[0],o.BL[0])+f,x=Math.min(o.TR[0],o.BR[0])+f,(d=c(m,x,b,w,_,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})).fontSize=p.size,h(y.type,d,u),e[s].transform=d,a.setTransormAndDisplay(r,d)}))}}));var v=n.select(this).selectAll(\"g.titletext\").data(y.title.text?[0]:[]);v.enter().append(\"g\").classed(\"titletext\",!0),v.exit().remove(),v.each((function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),r=y.title.text;y._meta&&(r=a.templateString(r,y._meta)),e.text(r).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,y.title.font).call(l.convertToTspans,t);var c=x(d,u._size);e.attr(\"transform\",s(c.x,c.y)+o(Math.min(1,c.scale))+s(c.tx,c.ty))}))}))}))}},13757:function(t,e,r){\"use strict\";var n=r(45568),i=r(32891),a=r(84102).resizeText;t.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(\".trace\");a(t,e,\"funnelarea\"),e.each((function(e){var r=e[0].trace,a=n.select(this);a.style({opacity:r.opacity}),a.selectAll(\"path.surface\").each((function(e){n.select(this).call(i,e,r,t)}))}))}},81658:function(t,e,r){\"use strict\";var n=r(36640),i=r(9829),a=r(80337),o=r(80712).axisHoverFormat,s=r(3208).rb,l=r(3208).ay,c=r(87163),u=r(93049).extendFlat;t.exports=u({z:{valType:\"data_array\",editType:\"calc\"},x:u({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:u({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:u({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:u({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:u({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:u({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),xperiod:u({},n.xperiod,{impliedEdits:{xtype:\"scaled\"}}),yperiod:u({},n.yperiod,{impliedEdits:{ytype:\"scaled\"}}),xperiod0:u({},n.xperiod0,{impliedEdits:{xtype:\"scaled\"}}),yperiod0:u({},n.yperiod0,{impliedEdits:{ytype:\"scaled\"}}),xperiodalignment:u({},n.xperiodalignment,{impliedEdits:{xtype:\"scaled\"}}),yperiodalignment:u({},n.yperiodalignment,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},hoverongaps:{valType:\"boolean\",dflt:!0,editType:\"none\"},connectgaps:{valType:\"boolean\",editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),zhoverformat:o(\"z\",1),hovertemplate:s(),texttemplate:l({arrayOk:!1,editType:\"plot\"},{keys:[\"x\",\"y\",\"z\",\"text\"]}),textfont:a({editType:\"plot\",autoSize:!0,autoColor:!0,colorEditType:\"style\"}),showlegend:u({},i.showlegend,{dflt:!1}),zorder:n.zorder},{transforms:void 0},c(\"\",{cLetter:\"z\",autoColorDflt:!1}))},51670:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(29714),o=r(40528),s=r(19226),l=r(28379),c=r(87869),u=r(93877),h=r(69295),f=r(78106),p=r(80924),d=r(63821).BADNUM;function m(t){for(var e=[],r=t.length,n=0;n<r;n++){var i=t[n];i!==d&&e.push(i)}return e}t.exports=function(t,e){var r,g,y,v,x,_,b,w,T,k,A,M=a.getFromId(t,e.xaxis||\"x\"),S=a.getFromId(t,e.yaxis||\"y\"),E=n.traceIs(e,\"contour\"),C=n.traceIs(e,\"histogram\"),L=n.traceIs(e,\"gl2d\"),I=E?\"best\":e.zsmooth;if(M._minDtick=0,S._minDtick=0,C)v=(A=s(t,e)).orig_x,r=A.x,g=A.x0,y=A.dx,w=A.orig_y,x=A.y,_=A.y0,b=A.dy,T=A.z;else{var P=e.z;i.isArray1D(P)?(c(e,M,S,\"x\",\"y\",[\"z\"]),r=e._x,x=e._y,P=e._z):(v=e.x?M.makeCalcdata(e,\"x\"):[],w=e.y?S.makeCalcdata(e,\"y\"):[],r=o(e,M,\"x\",v).vals,x=o(e,S,\"y\",w).vals,e._x=r,e._y=x),g=e.x0,y=e.dx,_=e.y0,b=e.dy,T=u(P,e,M,S)}function z(t){I=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}function O(t){if(t.length>1){var e=(t[t.length-1]-t[0])/(t.length-1),r=Math.abs(e/100);for(k=0;k<t.length-1;k++)if(Math.abs(t[k+1]-t[k]-e)>r)return!1}return!0}(M.rangebreaks||S.rangebreaks)&&(T=function(t,e,r){for(var n=[],i=-1,a=0;a<r.length;a++)if(e[a]!==d){n[++i]=[];for(var o=0;o<r[a].length;o++)t[o]!==d&&n[i].push(r[a][o])}return n}(r,x,T),C||(r=m(r),x=m(x),e._x=r,e._y=x)),C||!E&&!e.connectgaps||(e._emptypoints=f(T),h(T,e._emptypoints)),e._islinear=!1,\"log\"===M.type||\"log\"===S.type?\"fast\"===I&&z(\"log axis found\"):O(r)?O(x)?e._islinear=!0:\"fast\"===I&&z(\"y scale is not linear\"):\"fast\"===I&&z(\"x scale is not linear\");var D=i.maxRowLength(T),R=\"scaled\"===e.xtype?\"\":r,F=p(e,R,g,y,D,M),B=\"scaled\"===e.ytype?\"\":x,N=p(e,B,_,b,T.length,S);L||(e._extremes[M._id]=a.findExtremes(M,F),e._extremes[S._id]=a.findExtremes(S,N));var j={x:F,y:N,z:T,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(e.xperiodalignment&&v&&(j.orig_x=v),e.yperiodalignment&&w&&(j.orig_y=w),R&&R.length===F.length-1&&(j.xCenter=R),B&&B.length===N.length-1&&(j.yCenter=B),C&&(j.xRanges=A.xRanges,j.yRanges=A.yRanges,j.pts=A.pts),E||l(t,e,{vals:T,cLetter:\"z\"}),E&&e.contours&&\"heatmap\"===e.contours.coloring){var U={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};j.xfill=p(U,R,g,y,D,M),j.yfill=p(U,B,_,b,T.length,S)}return[j]}},93877:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(63821).BADNUM;t.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function m(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var g=m(r),y=m(o);o&&\"category\"===o.type&&(s=o._categories.length);var v=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),v[h]=new Array(l),f=0;f<l;f++)v[h][f]=p(d(t,y(h),g(f)));return v}},12431:function(t){\"use strict\";t.exports={min:\"zmin\",max:\"zmax\"}},87869:function(t,e,r){\"use strict\";var n=r(34809),i=r(63821).BADNUM,a=r(40528);t.exports=function(t,e,r,o,s,l){var c=t._length,u=e.makeCalcdata(t,o),h=r.makeCalcdata(t,s);u=a(t,e,o,u).vals,h=a(t,r,s,h).vals;var f,p,d,m,g=t.text,y=void 0!==g&&n.isArray1D(g),v=t.hovertext,x=void 0!==v&&n.isArray1D(v),_=n.distinctVals(u),b=_.vals,w=n.distinctVals(h),T=w.vals,k=[],A=T.length,M=b.length;for(f=0;f<l.length;f++)k[f]=n.init2dArray(A,M);y&&(d=n.init2dArray(A,M)),x&&(m=n.init2dArray(A,M));var S=n.init2dArray(A,M);for(f=0;f<c;f++)if(u[f]!==i&&h[f]!==i){var E=n.findBin(u[f]+_.minDiff/2,b),C=n.findBin(h[f]+w.minDiff/2,T);for(p=0;p<l.length;p++){var L=t[l[p]];k[p][C][E]=L[f],S[C][E]=f}y&&(d[C][E]=g[f]),x&&(m[C][E]=v[f])}for(t[\"_\"+o]=b,t[\"_\"+s]=T,p=0;p<l.length;p++)t[\"_\"+l[p]]=k[p];y&&(t._text=d),x&&(t._hovertext=m),e&&\"category\"===e.type&&(t[\"_\"+o+\"CategoryMap\"]=b.map((function(t){return e._categories[t]}))),r&&\"category\"===r.type&&(t[\"_\"+s+\"CategoryMap\"]=T.map((function(t){return r._categories[t]}))),t._after2before=S}},52813:function(t,e,r){\"use strict\";var n=r(34809),i=r(86073),a=r(63814),o=r(99669),s=r(44143),l=r(39356),c=r(81658);t.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}i(t,e,h,u)?(o(t,e,u,h),h(\"xhoverformat\"),h(\"yhoverformat\"),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),a(h,u),s(t,e,h,u),h(\"hoverongaps\"),h(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),l(t,e,u,h,{prefix:\"\",cLetter:\"z\"}),h(\"zorder\")):e.visible=!1}},78106:function(t,e,r){\"use strict\";var n=r(34809).maxRowLength;t.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],m=[0,0,0],g=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<g;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||m)[2]+(h[[r+1,i]]||m)[2]+(h[[r,i-1]]||m)[2]+(h[[r,i+1]]||m)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort((function(t,e){return e[2]-t[2]}))}},93125:function(t,e,r){\"use strict\";var n=r(32141),i=r(34809),a=i.isArrayOrTypedArray,o=r(29714),s=r(88856).extractOpts;t.exports=function(t,e,r,l,c){c||(c={});var u,h,f,p,d=c.isContour,m=t.cd[0],g=m.trace,y=t.xa,v=t.ya,x=m.x,_=m.y,b=m.z,w=m.xCenter,T=m.yCenter,k=m.zmask,A=g.zhoverformat,M=x,S=_;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-x[0],e-x[x.length-1],0)>0||n.inbox(r-_[0],r-_[_.length-1],0)>0)return;if(d){var E;for(M=[2*x[0]-x[1]],E=1;E<x.length;E++)M.push((x[E]+x[E-1])/2);for(M.push([2*x[x.length-1]-x[x.length-2]]),S=[2*_[0]-_[1]],E=1;E<_.length;E++)S.push((_[E]+_[E-1])/2);S.push([2*_[_.length-1]-_[_.length-2]])}f=Math.max(0,Math.min(M.length-2,i.findBin(e,M))),p=Math.max(0,Math.min(S.length-2,i.findBin(r,S)))}var C,L,I=y.c2p(x[f]),P=y.c2p(x[f+1]),z=v.c2p(_[p]),O=v.c2p(_[p+1]);d?(C=m.orig_x||x,L=m.orig_y||_,P=I,u=C[f],O=z,h=L[p]):(C=m.orig_x||w||x,L=m.orig_y||T||_,u=w?C[f]:(C[f]+C[f+1])/2,h=T?L[p]:(L[p]+L[p+1])/2,y&&\"category\"===y.type&&(u=x[f]),v&&\"category\"===v.type&&(h=_[p]),g.zsmooth&&(I=P=y.c2p(u),z=O=v.c2p(h)));var D=b[p][f];if(k&&!k[p][f]&&(D=void 0),void 0!==D||g.hoverongaps){var R;a(m.hovertext)&&a(m.hovertext[p])?R=m.hovertext[p][f]:a(m.text)&&a(m.text[p])&&(R=m.text[p][f]);var F=s(g),B={type:\"linear\",range:[F.min,F.max],hoverformat:A,_separators:y._separators,_numFormat:y._numFormat},N=o.tickText(B,D,\"hover\").text;return[i.extendFlat(t,{index:g._after2before?g._after2before[p][f]:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:I,x1:P,y0:z,y1:O,xLabelVal:u,yLabelVal:h,zLabelVal:D,zLabel:N,text:R})]}}},29251:function(t,e,r){\"use strict\";t.exports={attributes:r(81658),supplyDefaults:r(52813),calc:r(51670),plot:r(19236),colorbar:r(12431),style:r(12774),hoverPoints:r(93125),moduleType:\"trace\",name:\"heatmap\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"2dMap\",\"showLegend\"],meta:{}}},69295:function(t,e,r){\"use strict\";var n=r(34809),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,m,g,y=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?m=g=h:(m=Math.min(m,h),g=Math.max(g,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(y=1):(t[a][o]=(1+r)*t[a][o]-r*d,g>m&&(y=Math.max(y,Math.abs(t[a][o]-d)/(g-m))))}return y}t.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},63814:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){t(\"texttemplate\");var r=n.extendFlat({},e.font,{color:\"auto\",size:\"auto\"});n.coerceFont(t,\"textfont\",r)}},80924:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809).isArrayOrTypedArray;t.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var m=e.length;if(!(m<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=Array.from(e).slice(0,o);else if(1===o)h=\"log\"===s.type?[.5*e[0],2*e[0]]:[e[0]-.5,e[0]+.5];else if(\"log\"===s.type){for(h=[Math.pow(e[0],1.5)/Math.pow(e[1],.5)],u=1;u<m;u++)h.push(Math.sqrt(e[u-1]*e[u]));h.push(Math.pow(e[m-1],1.5)/Math.pow(e[m-2],.5))}else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<m;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[m-1]-.5*e[m-2])}if(m<o){var g,y=h[h.length-1];if(\"log\"===s.type)for(g=y/h[h.length-2],u=m;u<o;u++)y*=g,h.push(y);else for(g=y-h[h.length-2],u=m;u<o;u++)y+=g,h.push(y)}}else{var v=t[s._id.charAt(0)+\"calendar\"];for(l=p?s.r2c(r,0,v):i(e)&&1===e.length?e[0]:void 0===r?0:(\"log\"===s.type?s.d2c:s.r2c)(r,0,v),c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},19236:function(t,e,r){\"use strict\";var n=r(45568),i=r(65657),a=r(33626),o=r(62203),s=r(29714),l=r(34809),c=r(30635),u=r(15294),h=r(78766),f=r(88856).extractOpts,p=r(88856).makeColorScaleFuncFromTrace,d=r(62972),m=r(4530).LINE_SPACING,g=r(95544),y=r(1837).STYLE,v=\"heatmap-label\";function x(t){return t.selectAll(\"g.\"+v)}function _(t){x(t).remove()}function b(t,e){var r=e.length-2,n=l.constrain(l.findBin(t,e),0,r),i=e[n],a=e[n+1],o=l.constrain(n+(t-i)/(a-i)-.5,0,r),s=Math.round(o),c=Math.abs(o-s);return o&&o!==r&&c?{bin0:s,frac:c,bin1:Math.round(s+c/(o-s))}:{bin0:s,bin1:s,frac:0}}function w(t,e){var r=e.length-1,n=l.constrain(l.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function T(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}t.exports=function(t,e,r,k){var A=e.xaxis,M=e.yaxis;l.makeTraceGroups(k,r,\"hm\").each((function(e){var r,k,S,E,C,L,I,P,z=n.select(this),O=e[0],D=O.trace,R=D.xgap||0,F=D.ygap||0,B=O.z,N=O.x,j=O.y,U=O.xCenter,V=O.yCenter,q=a.traceIs(D,\"contour\"),H=q?\"best\":D.zsmooth,G=B.length,Z=l.maxRowLength(B),W=!1,Y=!1;for(L=0;void 0===r&&L<N.length-1;)r=A.c2p(N[L]),L++;for(L=N.length-1;void 0===k&&L>0;)k=A.c2p(N[L]),L--;for(k<r&&(S=k,k=r,r=S,W=!0),L=0;void 0===E&&L<j.length-1;)E=M.c2p(j[L]),L++;for(L=j.length-1;void 0===C&&L>0;)C=M.c2p(j[L]),L--;C<E&&(S=E,E=C,C=S,Y=!0),q&&(U=N,V=j,N=O.xfill,j=O.yfill);var X=\"default\";if(H?X=\"best\"===H?\"smooth\":\"fast\":D._islinear&&0===R&&0===F&&g()&&(X=\"fast\"),\"fast\"!==X){var $=\"best\"===H?0:.5;r=Math.max(-$*A._length,r),k=Math.min((1+$)*A._length,k),E=Math.max(-$*M._length,E),C=Math.min((1+$)*M._length,C)}var J,K,Q=Math.round(k-r),tt=Math.round(C-E);if(r>=A._length||k<=0||E>=M._length||C<=0)return z.selectAll(\"image\").data([]).exit().remove(),void _(z);\"fast\"===X?(J=Z,K=G):(J=Q,K=tt);var et=document.createElement(\"canvas\");et.width=J,et.height=K;var rt,nt,it=et.getContext(\"2d\",{willReadFrequently:!0}),at=p(D,{noNumericCheck:!0,returnArray:!0});\"fast\"===X?(rt=W?function(t){return Z-1-t}:l.identity,nt=Y?function(t){return G-1-t}:l.identity):(rt=function(t){return l.constrain(Math.round(A.c2p(N[t])-r),0,Q)},nt=function(t){return l.constrain(Math.round(M.c2p(j[t])-E),0,tt)});var ot,st,lt,ct,ut=nt(0),ht=[ut,ut],ft=W?0:1,pt=Y?0:1,dt=0,mt=0,gt=0,yt=0;function vt(t,e){if(void 0!==t){var r=at(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),dt+=e,mt+=r[0]*e,gt+=r[1]*e,yt+=r[2]*e,r}return[0,0,0,0]}function xt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return vt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,vt(i+r.frac*c+n.frac*(u+r.frac*a))}if(\"default\"!==X){var _t,bt=0;try{_t=new Uint8Array(J*K*4)}catch(t){_t=new Array(J*K*4)}if(\"smooth\"===X){var wt,Tt,kt,At=U||N,Mt=V||j,St=new Array(At.length),Et=new Array(Mt.length),Ct=new Array(Q),Lt=U?w:b,It=V?w:b;for(L=0;L<At.length;L++)St[L]=Math.round(A.c2p(At[L])-r);for(L=0;L<Mt.length;L++)Et[L]=Math.round(M.c2p(Mt[L])-E);for(L=0;L<Q;L++)Ct[L]=Lt(L,St);for(I=0;I<tt;I++)for(Tt=B[(wt=It(I,Et)).bin0],kt=B[wt.bin1],L=0;L<Q;L++,bt+=4)T(_t,bt,ct=xt(Tt,kt,Ct[L],wt))}else for(I=0;I<G;I++)for(lt=B[I],ht=nt(I),L=0;L<Z;L++)ct=vt(lt[L],1),T(_t,bt=4*(ht*Z+rt(L)),ct);var Pt=it.createImageData(J,K);try{Pt.data.set(_t)}catch(t){var zt=Pt.data,Ot=zt.length;for(I=0;I<Ot;I++)zt[I]=_t[I]}it.putImageData(Pt,0,0)}else{var Dt=Math.floor(R/2),Rt=Math.floor(F/2);for(I=0;I<G;I++)if(lt=B[I],ht.reverse(),ht[pt]=nt(I+1),ht[0]!==ht[1]&&void 0!==ht[0]&&void 0!==ht[1])for(ot=[st=rt(0),st],L=0;L<Z;L++)ot.reverse(),ot[ft]=rt(L+1),ot[0]!==ot[1]&&void 0!==ot[0]&&void 0!==ot[1]&&(ct=vt(lt[L],(ot[1]-ot[0])*(ht[1]-ht[0])),it.fillStyle=\"rgba(\"+ct.join(\",\")+\")\",it.fillRect(ot[0]+Dt,ht[0]+Rt,ot[1]-ot[0]-R,ht[1]-ht[0]-F))}mt=Math.round(mt/dt),gt=Math.round(gt/dt),yt=Math.round(yt/dt);var Ft=i(\"rgb(\"+mt+\",\"+gt+\",\"+yt+\")\");t._hmpixcount=(t._hmpixcount||0)+dt,t._hmlumcount=(t._hmlumcount||0)+dt*Ft.getLuminance();var Bt=z.selectAll(\"image\").data(e);Bt.enter().append(\"svg:image\").attr({xmlns:d.svg,preserveAspectRatio:\"none\"}),Bt.attr({height:tt,width:Q,x:r,y:E,\"xlink:href\":et.toDataURL(\"image/png\")}),\"fast\"!==X||H||Bt.attr(\"style\",y),_(z);var Nt=D.texttemplate;if(Nt){var jt=f(D),Ut={type:\"linear\",range:[jt.min,jt.max],_separators:A._separators,_numFormat:A._numFormat},Vt=\"histogram2dcontour\"===D.type,qt=\"contour\"===D.type,Ht=qt?G-1:G,Gt=qt?1:0,Zt=qt?Z-1:Z,Wt=[];for(L=qt?1:0;L<Ht;L++){var Yt;if(qt)Yt=O.y[L];else if(Vt){if(0===L||L===G-1)continue;Yt=O.y[L]}else if(O.yCenter)Yt=O.yCenter[L];else{if(L+1===G&&void 0===O.y[L+1])continue;Yt=(O.y[L]+O.y[L+1])/2}var Xt=Math.round(M.c2p(Yt));if(!(0>Xt||Xt>M._length))for(I=Gt;I<Zt;I++){var $t;if(qt)$t=O.x[I];else if(Vt){if(0===I||I===Z-1)continue;$t=O.x[I]}else if(O.xCenter)$t=O.xCenter[I];else{if(I+1===Z&&void 0===O.x[I+1])continue;$t=(O.x[I]+O.x[I+1])/2}var Jt=Math.round(A.c2p($t));if(!(0>Jt||Jt>A._length)){var Kt=u({x:$t,y:Yt},D,t._fullLayout);Kt.x=$t,Kt.y=Yt;var Qt=O.z[L][I];void 0===Qt?(Kt.z=\"\",Kt.zLabel=\"\"):(Kt.z=Qt,Kt.zLabel=s.tickText(Ut,Qt,\"hover\").text);var te=O.text&&O.text[L]&&O.text[L][I];void 0!==te&&!1!==te||(te=\"\"),Kt.text=te;var ee=l.texttemplateString(Nt,Kt,t._fullLayout._d3locale,Kt,D._meta||{});if(ee){var re=ee.split(\"<br>\"),ne=re.length,ie=0;for(P=0;P<ne;P++)ie=Math.max(ie,re[P].length);Wt.push({l:ne,c:ie,t:ee,x:Jt,y:Xt,z:Qt})}}}}var ae=D.textfont,oe=ae.size,se=t._fullLayout.font.size;if(!oe||\"auto\"===oe){var le=1/0,ce=1/0,ue=0,he=0;for(P=0;P<Wt.length;P++){var fe=Wt[P];if(ue=Math.max(ue,fe.l),he=Math.max(he,fe.c),P<Wt.length-1){var pe=Wt[P+1],de=Math.abs(pe.x-fe.x),me=Math.abs(pe.y-fe.y);de&&(le=Math.min(le,de)),me&&(ce=Math.min(ce,me))}}isFinite(le)&&isFinite(ce)?(le-=R,ce-=F,le/=he,ce/=ue,le/=m/2,ce/=m,oe=Math.min(Math.floor(le),Math.floor(ce),se)):oe=se}if(oe<=0||!isFinite(oe))return;x(z).data(Wt).enter().append(\"g\").classed(v,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),i=ae.color;i&&\"auto\"!==i||(i=h.contrast(void 0===e.z?t._fullLayout.plot_bgcolor:\"rgba(\"+at(e.z).join()+\")\")),r.attr(\"data-notex\",1).call(c.positionText,function(t){return t.x}(e),function(t){return t.y-oe*(t.l*m/2-1)}(e)).call(o.font,{family:ae.family,size:oe,color:i,weight:ae.weight,style:ae.style,variant:ae.variant,textcase:ae.textcase,lineposition:ae.lineposition,shadow:ae.shadow}).text(e.t).call(c.convertToTspans,t)}))}}))}},12774:function(t,e,r){\"use strict\";var n=r(45568);t.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",(function(t){return t.trace.opacity}))}},44143:function(t){\"use strict\";t.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},86073:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(33626);function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}t.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(f)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return\"heatmapgl\"===t.type||a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},29751:function(t,e,r){\"use strict\";for(var n=r(81658),i=r(87163),a=r(93049).extendFlat,o=r(13582).overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}l.zsmooth={valType:\"enumerated\",values:[\"fast\",!1],dflt:\"fast\",editType:\"calc\"},a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),t.exports=o(l,\"calc\",\"nested\")},89987:function(t,e,r){\"use strict\";var n=r(99098).gl_heatmap2d,i=r(29714),a=r(55010);function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={zsmooth:\"fast\",z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y,this.options.zsmooth=t.zsmooth;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c,u,h=this.scene.xaxis,f=this.scene.yaxis;!1===t.zsmooth&&(c={ppad:r.x[1]-r.x[0]},u={ppad:r.y[1]-r.y[0]}),t._extremes[h._id]=i.findExtremes(h,r.x,c),t._extremes[f._id]=i.findExtremes(f,r.y,u)},s.dispose=function(){this.heatmap.dispose()},t.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},51312:function(t,e,r){\"use strict\";var n=r(34809),i=r(86073),a=r(39356),o=r(29751);t.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,l,s)?(l(\"text\"),l(\"zsmooth\"),a(t,e,s,l,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},72892:function(t,e,r){\"use strict\";[\"*heatmapgl* trace is deprecated!\",\"Please consider switching to the *heatmap* or *image* trace types.\",\"Alternatively you could contribute/sponsor rewriting this trace type\",\"based on cartesian features and using regl framework.\"].join(\" \"),t.exports={attributes:r(29751),supplyDefaults:r(51312),colorbar:r(12431),calc:r(51670),plot:r(89987),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:r(24585),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},16160:function(t,e,r){\"use strict\";var n=r(81481),i=r(80712).axisHoverFormat,a=r(3208).rb,o=r(3208).ay,s=r(80337),l=r(64766),c=r(39732),u=r(93049).extendFlat;t.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),text:u({},n.text,{}),hovertext:u({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:l(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:l(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:a({},{keys:c.eventDataKeys}),texttemplate:o({arrayOk:!1,editType:\"plot\"},{keys:[\"label\",\"value\"]}),textposition:u({},n.textposition,{arrayOk:!1}),textfont:s({arrayOk:!1,editType:\"plot\",colorEditType:\"style\"}),outsidetextfont:s({arrayOk:!1,editType:\"plot\",colorEditType:\"style\"}),insidetextfont:s({arrayOk:!1,editType:\"plot\",colorEditType:\"style\"}),insidetextanchor:n.insidetextanchor,textangle:n.textangle,cliponaxis:n.cliponaxis,constraintext:n.constraintext,marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir},zorder:n.zorder}},48198:function(t){\"use strict\";t.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},64766:function(t){\"use strict\";t.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},34870:function(t,e,r){\"use strict\";var n=r(10721);t.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},64852:function(t,e,r){\"use strict\";var n=r(63821),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=r(29714).tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}t.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],m=r[1],g=Math.min(h(d+f,d+p,n,a),h(m+f,m+p,n,a)),y=Math.min(h(d+c,d+f,n,a),h(m+c,m+f,n,a));if(g>y&&y<Math.abs(m-d)/4e3?(s=g,l=!1):(s=Math.min(g,y),l=!0),\"date\"===n.type&&s>o){var v=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",v);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},53616:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(33626),o=r(29714),s=r(35374),l=r(34870),c=r(58665),u=r(48198),h=r(64852);function f(t,e,r,s,l){var c,u,h,p,d,m,g,y=s+\"bins\",v=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],_=v._histogramBinOpts[x],b=\"overlay\"===v.barmode,w=function(t){return r.r2c(t,0,p)},T=function(t){return r.c2r(t,0,p)},k=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=k(e[t]),null===e[t]&&(e[t]=r[t])):(m[t]=e[t]=r[t],i.nestedProperty(u[0],y+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=_.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=_.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var I=o.autoBin(M,r,_.nbins,E,p,_.sizeFound&&_.size),P=u[0]._autoBin={};if(m=P[_.dirs[0]]={},C&&(_.size||(I.start=T(o.tickIncrement(w(I.start),I.size,!0,p))),void 0===_.end&&(I.end=T(o.tickIncrement(w(I.end),I.size,!1,p)))),b&&!a.traceIs(e,\"2dMap\")&&0===I._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type&&\"\"===e.bingroup&&void 0===e.xbins){if(l)return[I,d,!0];I=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var m=f(t,s,r,n,!0),g=m[0],y=m[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=m[1],y?d.push(s):p=Math.min(p,g.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var v=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],_=0;_<x.length;_++)if(void 0!==x[_]){v[o]=x[_];break}for(isFinite(p)||(p=i.distinctVals(v).minDiff),o=0;o<d.length;o++){var b=(s=d[o])[n+\"calendar\"],w={start:r.c2r(v[o]-p/2,0,b),end:r.c2r(v[o]+p/2,0,b),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,y)}(g=h.cumulative||{}).enabled&&\"include\"!==g.currentbin&&(\"decreasing\"===g.direction?I.start=T(o.tickIncrement(w(I.start),I.size,!0,p)):I.end=T(o.tickIncrement(w(I.end),I.size,!1,p))),_.size=I.size,_.sizeFound||(m.size=I.size,i.nestedProperty(u[0],y+\".size\").set(I.size)),A(\"start\",_,I),A(\"end\",_,I)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[y]||{},O=i.extendFlat({},_),D=_.start,R=r.r2l(z.start),F=void 0!==R;if((_.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:_.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,_.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,_.size,!0,p)),O.start=r.l2r(j),F||i.nestedProperty(e,y+\".start\").set(O.start)}var U=_.end,V=r.r2l(z.end),q=void 0!==V;if((_.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);O.end=r.l2r(H),q||i.nestedProperty(e,y+\".start\").set(O.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[y]=i.extendFlat({},e[y]||{}),delete e._input[G],delete e[G]),[O,d]}t.exports={calc:function(t,e){var r,a,p,d,m=[],g=[],y=\"h\"===e.orientation,v=o.getFromId(t,y?e.yaxis:e.xaxis),x=y?\"y\":\"x\",_={x:\"y\",y:\"x\"}[x],b=e[x+\"calendar\"],w=e.cumulative,T=f(t,e,v,x),k=T[0],A=T[1],M=\"string\"==typeof k.size,S=[],E=M?S:k,C=[],L=[],I=[],P=0,z=e.histnorm,O=e.histfunc,D=-1!==z.indexOf(\"density\");w.enabled&&D&&(z=z.replace(/ ?density$/,\"\"),D=!1);var R,F=\"max\"===O||\"min\"===O?null:0,B=l.count,N=c[z],j=!1,U=function(t){return v.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[_])&&\"count\"!==O&&(R=e[_],j=\"avg\"===O,B=l[O]),r=U(k.start),p=U(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&m.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),m.push((r+a)/2),g.push(F),I.push([]),S.push(r),D&&C.push(1/(a-r)),j&&L.push(0),!(a<=r));)r=a;S.push(r),M||\"date\"!==v.type||(E={start:U(E.start),end:U(E.end),size:E.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var V=e[\"_\"+x+\"bingroup\"],q={leftGap:1/0,rightGap:1/0};V&&(t._fullLayout._roundFnOpts[V]||(t._fullLayout._roundFnOpts[V]=q),q=t._fullLayout._roundFnOpts[V]);var H,G=g.length,Z=!0,W=q.leftGap,Y=q.rightGap,X={};for(r=0;r<A.length;r++){var $=A[r];(d=i.findBin($,E))>=0&&d<G&&(P+=B(d,r,g,R,L),Z&&I[d].length&&$!==A[I[d][0]]&&(Z=!1),I[d].push(r),X[r]=d,W=Math.min(W,$-S[d]),Y=Math.min(Y,S[d+1]-$))}q.leftGap=W,q.rightGap=Y,Z||(H=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[V];return h(n.leftGap,n.rightGap,S,v,b)(e,r)}}),j&&(P=u(g,L)),N&&N(g,P,C),w.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(g,w.direction,w.currentbin);var J=Math.min(m.length,g.length),K=[],Q=0,tt=J-1;for(r=0;r<J;r++)if(g[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(g[r]){tt=r;break}for(r=Q;r<=tt;r++)if(n(m[r])&&n(g[r])){var et={p:m[r],s:g[r],b:0};w.enabled||(et.pts=I[r],Z?et.ph0=et.ph1=I[r].length?A[I[r][0]]:m[r]:(e._computePh=!0,et.ph0=H(S[r]),et.ph1=H(S[r+1],!0))),K.push(et)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,k.size,!1,b)-K[0].p),s(K,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(K,e,X),K},calcAllAutoBins:f}},39732:function(t){\"use strict\";t.exports={eventDataKeys:[\"binNumber\"]}},83380:function(t,e,r){\"use strict\";var n=r(34809),i=r(5975),a=r(33626).traceIs,o=r(36301),s=r(17550).validateCornerradius,l=n.nestedProperty,c=r(84391).getAxisGroup,u=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],h=[\"x\",\"y\"];t.exports=function(t,e){var r,f,p,d,m,g,y,v=e._histogramBinOpts={},x=[],_={},b=[];function w(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function T(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"]||\"\",c=v[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(v[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(m=0;m<t.length;m++)if(r=t[m],a(r,\"histogram\")){if(x.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,\"histogram\"===r.type){var A=w(\"marker.cornerradius\",e.barcornerradius);r.marker&&(r.marker.cornerradius=s(A))}a(r,\"2dMap\")||o(r._input,r,e,w)}var M=e._alignmentOpts||{};for(m=0;m<x.length;m++){if(r=x[m],p=\"\",!a(r,\"2dMap\")){if(d=T(r),\"group\"===e.barmode&&r.alignmentgroup){var S=r[d+\"axis\"],E=c(e,S)+r.orientation;(M[E]||{})[r.alignmentgroup]&&(p=E)}p||\"overlay\"===e.barmode||(p=c(e,r.xaxis)+c(e,r.yaxis)+T(r))}p?(_[p]||(_[p]=[]),_[p].push(r)):b.push(r)}for(p in _)if(1!==(f=_[p]).length){var C=!1;for(f.length&&(r=f[0],C=w(\"bingroup\")),p=C||p,m=0;m<f.length;m++){var L=(r=f[m])._input.bingroup;L&&L!==p&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",p+\".\",\"Ignoring its bingroup:\",L,\"setting.\"].join(\" \")),r.bingroup=p,k(r,p,T(r))}}else b.push(f[0]);for(m=0;m<b.length;m++){r=b[m];var I=w(\"bingroup\");if(a(r,\"2dMap\"))for(y=0;y<2;y++){var P=w((d=h[y])+\"bingroup\",I?I+\"__\"+d:null);k(r,P,d)}else k(r,I,T(r))}for(p in v){var z=v[p];for(f=z.traces,g=0;g<u.length;g++){var O,D,R=u[g],F=R.name;if(\"nbins\"!==F||!z.sizeFound){for(m=0;m<f.length;m++){if(r=f[m],d=z.dirs[m],O=R.aStr[d],void 0!==l(r._input,O).get()){z[F]=w(O),z[F+\"Found\"]=!0;break}(D=(r._autoBin||{})[d]||{})[F]&&l(r,O).set(D[F])}if(\"start\"===F||\"end\"===F)for(;m<f.length;m++)(r=f[m])[\"_\"+d+\"bingroup\"]&&w(O,(D=(r._autoBin||{})[d]||{})[F]);\"nbins\"!==F||z.sizeFound||z.nbinsFound||(r=f[0],z[F]=w(O))}}}}},85079:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(78766),o=r(17550).handleText,s=r(59760),l=r(16160);t.exports=function(t,e,r,c){function u(r,n){return i.coerce(t,e,l,r,n)}var h=u(\"x\"),f=u(\"y\");u(\"cumulative.enabled\")&&(u(\"cumulative.direction\"),u(\"cumulative.currentbin\")),u(\"text\");var p=u(\"textposition\");o(t,e,c,u,p,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),u(\"hovertext\"),u(\"hovertemplate\"),u(\"xhoverformat\"),u(\"yhoverformat\");var d=u(\"orientation\",f&&!h?\"h\":\"v\"),m=\"v\"===d?\"x\":\"y\",g=\"v\"===d?\"y\":\"x\",y=h&&f?Math.min(i.minRowLength(h)&&i.minRowLength(f)):i.minRowLength(e[m]||[]);if(y){e._length=y,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],c),e[g]&&u(\"histfunc\"),u(\"histnorm\"),u(\"autobin\"+m),s(t,e,u,r,c),i.coerceSelectionMarkerOpacity(e,u);var v=(e.marker.line||{}).color,x=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");x(t,e,v||a.defaultLine,{axis:\"y\"}),x(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"}),u(\"zorder\")}else e.visible=!1}},82604:function(t){\"use strict\";t.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},20487:function(t,e,r){\"use strict\";var n=r(91664).hoverPoints,i=r(29714).hoverLabelText;t.exports=function(t,e,r,a,o){var s=n(t,e,r,a,o);if(s){var l=(t=s[0]).cd[t.index],c=t.cd[0].trace;if(!c.cumulative.enabled){var u=\"h\"===c.orientation?\"y\":\"x\";t[u+\"Label\"]=i(t[u+\"a\"],[l.ph0,l.ph1],c[u+\"hoverformat\"])}return s}}},74461:function(t,e,r){\"use strict\";t.exports={attributes:r(16160),layoutAttributes:r(25412),supplyDefaults:r(85079),crossTraceDefaults:r(83380),supplyLayoutDefaults:r(78931),calc:r(53616).calc,crossTraceCalc:r(24782).crossTraceCalc,plot:r(32995).plot,layerName:\"barlayer\",style:r(6851).style,styleOnSelect:r(6851).styleOnSelect,colorbar:r(21146),hoverPoints:r(20487),selectPoints:r(88384),eventData:r(82604),moduleType:\"trace\",name:\"histogram\",basePlotModule:r(37703),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},58665:function(t){\"use strict\";t.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},9310:function(t,e,r){\"use strict\";var n=r(16160),i=r(64766),a=r(81658),o=r(9829),s=r(80712).axisHoverFormat,l=r(3208).rb,c=r(3208).ay,u=r(87163),h=r(93049).extendFlat;t.exports=h({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:h({},n.bingroup,{}),xbingroup:h({},n.bingroup,{}),ybingroup:h({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,xhoverformat:s(\"x\"),yhoverformat:s(\"y\"),zhoverformat:s(\"z\",1),hovertemplate:l({},{keys:\"z\"}),texttemplate:c({arrayOk:!1,editType:\"plot\"},{keys:\"z\"}),textfont:a.textfont,showlegend:h({},o.showlegend,{dflt:!1})},u(\"\",{cLetter:\"z\",autoColorDflt:!1}))},19226:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(34870),o=r(58665),s=r(48198),l=r(64852),c=r(53616).calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}t.exports=function(t,e){var r,l,p,d,m=i.getFromId(t,e.xaxis),g=i.getFromId(t,e.yaxis),y=e.xcalendar,v=e.ycalendar,x=function(t){return m.r2c(t,0,y)},_=function(t){return g.r2c(t,0,v)},b=c(t,e,m,\"x\"),w=b[0],T=b[1],k=c(t,e,g,\"y\"),A=k[0],M=k[1],S=e._length;T.length>S&&T.splice(S,T.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],I=\"string\"==typeof w.size,P=\"string\"==typeof A.size,z=[],O=[],D=I?z:w,R=P?O:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Z=!1,W=[],Y=[],X=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";X&&\"count\"!==U&&(Z=\"avg\"===U,H=a[U]);var $=w.size,J=x(w.start),K=x(w.end)+(J-i.tickIncrement(J,$,!1,y))/1e6;for(r=J;r<K;r=i.tickIncrement(r,$,!1,y))C.push(q),z.push(r),Z&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-J)/tt,rt=(Q=J+et/2,m.c2r(Q,0,y)),nt=A.size,it=_(A.start),at=_(A.end)+(it-i.tickIncrement(it,nt,!1,v))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,v)){E.push(C.slice()),O.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Z&&B.push(L.slice())}O.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return g.c2r(t,0,v)}(it+lt/2);V&&(W=u(C.length,D,et,I),Y=u(E.length,R,lt,P)),I||\"date\"!==m.type||(D=h(x,D)),P||\"date\"!==g.type||(R=h(_,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,mt=1/0,gt=1/0,yt=1/0;for(r=0;r<S;r++){var vt=T[r],xt=M[r];p=n.findBin(vt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],X,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=vt:ft[p]!==vt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,vt-z[p]),mt=Math.min(mt,z[p+1]-vt),gt=Math.min(gt,xt-O[d]),yt=Math.min(yt,O[d+1]-xt))}if(Z)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,Y[d]);return{x:T,xRanges:f(z,ut&&ft,dt,mt,m,y),x0:rt,dx:et,y:M,yRanges:f(O,ht&&pt,gt,yt,g,v),y0:ct,dy:lt,z:E,pts:N}}},29097:function(t,e,r){\"use strict\";var n=r(34809),i=r(77134),a=r(44143),o=r(39356),s=r(63814),l=r(9310);t.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}i(t,e,u,c),!1!==e.visible&&(a(t,e,u,c),o(t,e,c,u,{prefix:\"\",cLetter:\"z\"}),u(\"hovertemplate\"),s(u,c),u(\"xhoverformat\"),u(\"yhoverformat\"))}},1873:function(t,e,r){\"use strict\";var n=r(93125),i=r(29714).hoverLabelText;t.exports=function(t,e,r,a,o){var s=n(t,e,r,a,o);if(s){var l=(t=s[0]).index,c=l[0],u=l[1],h=t.cd[0],f=h.trace,p=h.xRanges[u],d=h.yRanges[c];return t.xLabel=i(t.xa,[p[0],p[1]],f.xhoverformat),t.yLabel=i(t.ya,[d[0],d[1]],f.yhoverformat),s}}},66143:function(t,e,r){\"use strict\";t.exports={attributes:r(9310),supplyDefaults:r(29097),crossTraceDefaults:r(83380),calc:r(51670),plot:r(19236),layerName:\"heatmaplayer\",colorbar:r(12431),style:r(12774),hoverPoints:r(1873),eventData:r(82604),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\",\"showLegend\"],meta:{}}},77134:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809);t.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},85018:function(t,e,r){\"use strict\";var n=r(9310),i=r(52240),a=r(87163),o=r(80712).axisHoverFormat,s=r(93049).extendFlat;t.exports=s({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:{color:i.line.color,width:s({},i.line.width,{dflt:.5}),dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),zhoverformat:o(\"z\",1),hovertemplate:n.hovertemplate,texttemplate:i.texttemplate,textfont:i.textfont},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},49389:function(t,e,r){\"use strict\";var n=r(34809),i=r(77134),a=r(47495),o=r(39889),s=r(63814),l=r(85018);t.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}i(t,e,u,c),!1!==e.visible&&(a(t,e,u,(function(r){return n.coerce2(t,e,l,r)})),o(t,e,u,c),u(\"xhoverformat\"),u(\"yhoverformat\"),u(\"hovertemplate\"),e.contours&&\"heatmap\"===e.contours.coloring&&s(u,c))}},81955:function(t,e,r){\"use strict\";t.exports={attributes:r(85018),supplyDefaults:r(49389),crossTraceDefaults:r(83380),calc:r(40352),plot:r(8850).plot,layerName:\"contourlayer\",style:r(1328),colorbar:r(92697),hoverPoints:r(29815),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},12505:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(87163),o=r(13792).u,s=r(55412),l=r(56708),c=r(71856),u=r(43236),h=r(93049).extendFlat,f=r(94850).k;t.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"plot\"},flip:c.tiling.flip,pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},marker:h({colors:l.marker.colors,line:l.marker.line,pattern:f,editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:l.leaf,pathbar:c.pathbar,text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:u.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:u.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:c.outsidetextfont,textposition:c.textposition,sort:s.sort,root:l.root,domain:o({name:\"icicle\",trace:!0,editType:\"calc\"})}},63387:function(t,e,r){\"use strict\";var n=r(44122);e.name=\"icicle\",e.plot=function(t,r,i,a){n.plotBasePlot(e.name,t,r,i,a)},e.clean=function(t,r,i,a){n.cleanBasePlot(e.name,t,r,i,a)}},36349:function(t,e,r){\"use strict\";var n=r(14852);e._=function(t,e){return n.calc(t,e)},e.t=function(t){return n._runCrossTraceCalc(\"icicle\",t)}},17918:function(t,e,r){\"use strict\";var n=r(34809),i=r(12505),a=r(78766),o=r(13792).N,s=r(17550).handleText,l=r(56155).TEXTPAD,c=r(46979).handleMarkerDefaults,u=r(88856),h=u.hasColorscale,f=u.handleDefaults;t.exports=function(t,e,r,u){function p(r,a){return n.coerce(t,e,i,r,a)}var d=p(\"labels\"),m=p(\"parents\");if(d&&d.length&&m&&m.length){var g=p(\"values\");g&&g.length?p(\"branchvalues\"):p(\"count\"),p(\"level\"),p(\"maxdepth\"),p(\"tiling.orientation\"),p(\"tiling.flip\"),p(\"tiling.pad\");var y=p(\"text\");p(\"texttemplate\"),e.texttemplate||p(\"textinfo\",n.isArrayOrTypedArray(y)?\"text+label\":\"label\"),p(\"hovertext\"),p(\"hovertemplate\");var v=p(\"pathbar.visible\");s(t,e,u,p,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),p(\"textposition\"),c(t,e,u,p);var x=e._hasColorscale=h(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;x&&f(t,e,u,p,{prefix:\"marker.\",cLetter:\"c\"}),p(\"leaf.opacity\",x?1:.7),e._hovered={marker:{line:{width:2,color:a.contrast(u.paper_bgcolor)}}},v&&(p(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),p(\"pathbar.side\"),p(\"pathbar.edgeshape\")),p(\"sort\"),p(\"root.color\"),o(e,u,p),e._length=null}else e.visible=!1}},23593:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(30635),s=r(29316),l=r(50579).styleOne,c=r(43236),u=r(33108),h=r(44691),f=r(19718).formatSliceLabel,p=!1;t.exports=function(t,e,r,d,m){var g=m.width,y=m.height,v=m.viewX,x=m.viewY,_=m.pathSlice,b=m.toMoveInsideSlice,w=m.strTransform,T=m.hasTransition,k=m.handleSlicesExit,A=m.makeUpdateSliceInterpolator,M=m.makeUpdateTextInterpolator,S=m.prevEntry,E=t._context.staticPlot,C=t._fullLayout,L=e[0].trace,I=-1!==L.textposition.indexOf(\"left\"),P=-1!==L.textposition.indexOf(\"right\"),z=-1!==L.textposition.indexOf(\"bottom\"),O=s(r,[g,y],{flipX:L.tiling.flip.indexOf(\"x\")>-1,flipY:L.tiling.flip.indexOf(\"y\")>-1,orientation:L.tiling.orientation,pad:{inner:L.tiling.pad},maxDepth:L._maxDepth}).descendants(),D=1/0,R=-1/0;O.forEach((function(t){var e=t.depth;e>=L._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(D=Math.min(D,e),R=Math.max(R,e))})),d=d.data(O,u.getPtId),L._maxVisibleLayers=isFinite(R)?R-D+1:0,d.enter().append(\"g\").classed(\"slice\",!0),k(d,p,{},[g,y],_),d.order();var F=null;if(T&&S){var B=u.getPtId(S);d.each((function(t){null===F&&u.getPtId(t)===B&&(F={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var N=function(){return F||{x0:0,x1:g,y0:0,y1:y}},j=d;return T&&(j=j.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),j.each((function(s){s._x0=v(s.x0),s._x1=v(s.x1),s._y0=x(s.y0),s._y1=x(s.y1),s._hoverX=v(s.x1-L.tiling.pad),s._hoverY=x(z?s.y1-L.tiling.pad/2:s.y0+L.tiling.pad/2);var d=n.select(this),m=i.ensureSingle(d,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",E?\"none\":\"all\")}));T?m.transition().attrTween(\"d\",(function(t){var e=A(t,p,N(),[g,y],{orientation:L.tiling.orientation,flipX:L.tiling.flip.indexOf(\"x\")>-1,flipY:L.tiling.flip.indexOf(\"y\")>-1});return function(t){return _(e(t))}})):m.attr(\"d\",_),d.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),m.call(l,s,L,t,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=f(s,r,L,e,C)||\"\";var k=i.ensureSingle(d,\"g\",\"slicetext\"),S=i.ensureSingle(k,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),O=i.ensureUniformFontSize(t,u.determineTextFont(L,s,C.font));S.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",P?\"end\":I?\"start\":\"middle\").call(a.font,O).call(o.convertToTspans,t),s.textBB=a.bBox(S.node()),s.transform=b(s,{fontSize:O.size}),s.transform.fontSize=O.size,T?S.transition().attrTween(\"transform\",(function(t){var e=M(t,p,N(),[g,y]);return function(t){return w(e(t))}})):S.attr(\"transform\",w(s))})),F}},36858:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"icicle\",basePlotModule:r(63387),categories:[],animatable:!0,attributes:r(12505),layoutAttributes:r(60052),supplyDefaults:r(17918),supplyLayoutDefaults:r(11747),calc:r(36349)._,crossTraceCalc:r(36349).t,plot:r(1395),style:r(50579).style,colorbar:r(21146),meta:{}}},60052:function(t){\"use strict\";t.exports={iciclecolorway:{valType:\"colorlist\",editType:\"calc\"},extendiciclecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},11747:function(t,e,r){\"use strict\";var n=r(34809),i=r(60052);t.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"iciclecolorway\",e.colorway),r(\"extendiciclecolors\")}},29316:function(t,e,r){\"use strict\";var n=r(92264),i=r(36141);t.exports=function(t,e,r){var a=r.flipX,o=r.flipY,s=\"h\"===r.orientation,l=r.maxDepth,c=e[0],u=e[1];l&&(c=(t.height+1)*e[0]/Math.min(t.height+1,l),u=(t.height+1)*e[1]/Math.min(t.height+1,l));var h=n.partition().padding(r.pad.inner).size(s?[e[1],c]:[e[0],u])(t);return(s||a||o)&&i(h,e,{swapXY:s,flipX:a,flipY:o}),h}},1395:function(t,e,r){\"use strict\";var n=r(41567),i=r(23593);t.exports=function(t,e,r,a){return n(t,e,r,a,{type:\"icicle\",drawDescendants:i})}},50579:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(34809),o=r(84102).resizeText,s=r(72043);function l(t,e,r,n){var o=e.data.data,l=!e.children,c=o.i,u=a.castOption(r,c,\"marker.line.color\")||i.defaultLine,h=a.castOption(r,c,\"marker.line.width\")||0;t.call(s,e,r,n).style(\"stroke-width\",h).call(i.stroke,u).style(\"opacity\",l?r.leaf.opacity:null)}t.exports={style:function(t){var e=t._fullLayout._iciclelayer.selectAll(\".trace\");o(t,e,\"icicle\"),e.each((function(e){var r=n.select(this),i=e[0].trace;r.style(\"opacity\",i.opacity),r.selectAll(\"path.surface\").each((function(e){n.select(this).call(l,e,i,t)}))}))},styleOne:l}},22153:function(t,e,r){\"use strict\";for(var n=r(9829),i=r(36640).zorder,a=r(3208).rb,o=r(93049).extendFlat,s=r(42939).colormodel,l=[\"rgb\",\"rgba\",\"rgba256\",\"hsl\",\"hsla\"],c=[],u=[],h=0;h<l.length;h++){var f=s[l[h]];c.push(\"For the `\"+l[h]+\"` colormodel, it is [\"+(f.zminDflt||f.min).join(\", \")+\"].\"),u.push(\"For the `\"+l[h]+\"` colormodel, it is [\"+(f.zmaxDflt||f.max).join(\", \")+\"].\")}t.exports=o({source:{valType:\"string\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},colormodel:{valType:\"enumerated\",values:l,editType:\"calc\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",!1],dflt:!1,editType:\"plot\"},zmin:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},zmax:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",dflt:1,editType:\"calc\"},dy:{valType:\"number\",dflt:1,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"data_array\",editType:\"plot\"},hoverinfo:o({},n.hoverinfo,{flags:[\"x\",\"y\",\"z\",\"color\",\"name\",\"text\"],dflt:\"x+y+z+text+name\"}),hovertemplate:a({},{keys:[\"z\",\"color\",\"colormodel\"]}),zorder:i,transforms:void 0})},31181:function(t,e,r){\"use strict\";var n=r(34809),i=r(42939),a=r(10721),o=r(29714),s=r(34809).maxRowLength,l=r(96315).p;function c(t,e,r,i){return function(a){return n.constrain((a-t)*e,r,i)}}function u(t,e){return function(r){return n.constrain(r,t,e)}}t.exports=function(t,e){var r,n;if(e._hasZ)r=e.z.length,n=s(e.z);else if(e._hasSource){var h=l(e.source);r=h.height,n=h.width}var f,p=o.getFromId(t,e.xaxis||\"x\"),d=o.getFromId(t,e.yaxis||\"y\"),m=p.d2c(e.x0)-e.dx/2,g=d.d2c(e.y0)-e.dy/2,y=[m,m+n*e.dx],v=[g,g+r*e.dy];if(p&&\"log\"===p.type)for(f=0;f<n;f++)y.push(m+f*e.dx);if(d&&\"log\"===d.type)for(f=0;f<r;f++)v.push(g+f*e.dy);return e._extremes[p._id]=o.findExtremes(p,y),e._extremes[d._id]=o.findExtremes(d,v),e._scaler=function(t){var e=i.colormodel[t.colormodel],r=(e.colormodel||t.colormodel).length;t._sArray=[];for(var n=0;n<r;n++)e.min[n]!==t.zmin[n]||e.max[n]!==t.zmax[n]?t._sArray.push(c(t.zmin[n],(e.max[n]-e.min[n])/(t.zmax[n]-t.zmin[n]),e.min[n],e.max[n])):t._sArray.push(u(e.min[n],e.max[n]));return function(e){for(var n=e.slice(0,r),i=0;i<r;i++){var o=n[i];if(!a(o))return!1;n[i]=t._sArray[i](o)}return n}}(e),[{x0:m,y0:g,z:e.z,w:n,h:r}]}},42939:function(t){\"use strict\";t.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:[\"\",\"\",\"\"]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},rgba256:{colormodel:\"rgba\",zminDflt:[0,0,0,0],zmaxDflt:[255,255,255,255],min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\u00b0\",\"%\",\"%\"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\u00b0\",\"%\",\"%\",\"\"]}}}},82766:function(t,e,r){\"use strict\";var n=r(34809),i=r(22153),a=r(42939),o=r(84619).IMAGE_URL_PREFIX;t.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"source\"),e.source&&!e.source.match(o)&&delete e.source,e._hasSource=!!e.source;var s,l=r(\"z\");e._hasZ=!(void 0===l||!l.length||!l[0]||!l[0].length),e._hasZ||e._hasSource?(r(\"x0\"),r(\"y0\"),r(\"dx\"),r(\"dy\"),e._hasZ?(r(\"colormodel\",\"rgb\"),r(\"zmin\",(s=a.colormodel[e.colormodel]).zminDflt||s.min),r(\"zmax\",s.zmaxDflt||s.max)):e._hasSource&&(e.colormodel=\"rgba256\",s=a.colormodel[e.colormodel],e.zmin=s.zminDflt,e.zmax=s.zmaxDflt),r(\"zsmooth\"),r(\"text\"),r(\"hovertext\"),r(\"hovertemplate\"),e._length=null,r(\"zorder\")):e.visible=!1}},45461:function(t){\"use strict\";t.exports=function(t,e){return\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t.z||(t.z=e.color),t}},96315:function(t,e,r){\"use strict\";var n=r(19490),i=r(84619).IMAGE_URL_PREFIX,a=r(45708).Buffer;e.p=function(t){var e=t.replace(i,\"\"),r=new a(e,\"base64\");return n(r)}},57328:function(t,e,r){\"use strict\";var n=r(32141),i=r(34809),a=i.isArrayOrTypedArray,o=r(42939);t.exports=function(t,e,r){var s=t.cd[0],l=s.trace,c=t.xa,u=t.ya;if(!(n.inbox(e-s.x0,e-(s.x0+s.w*l.dx),0)>0||n.inbox(r-s.y0,r-(s.y0+s.h*l.dy),0)>0)){var h,f=Math.floor((e-s.x0)/l.dx),p=Math.floor(Math.abs(r-s.y0)/l.dy);if(l._hasZ?h=s.z[p][f]:l._hasSource&&(h=l._canvas.el.getContext(\"2d\",{willReadFrequently:!0}).getImageData(f,p,1,1).data),h){var d,m=s.hi||l.hoverinfo;if(m){var g=m.split(\"+\");-1!==g.indexOf(\"all\")&&(g=[\"color\"]),-1!==g.indexOf(\"color\")&&(d=!0)}var y,v=o.colormodel[l.colormodel],x=v.colormodel||l.colormodel,_=x.length,b=l._scaler(h),w=v.suffix,T=[];(l.hovertemplate||d)&&(T.push(\"[\"+[b[0]+w[0],b[1]+w[1],b[2]+w[2]].join(\", \")),4===_&&T.push(\", \"+b[3]+w[3]),T.push(\"]\"),T=T.join(\"\"),t.extraText=x.toUpperCase()+\": \"+T),a(l.hovertext)&&a(l.hovertext[p])?y=l.hovertext[p][f]:a(l.text)&&a(l.text[p])&&(y=l.text[p][f]);var k=u.c2p(s.y0+(p+.5)*l.dy),A=s.x0+(f+.5)*l.dx,M=s.y0+(p+.5)*l.dy,S=\"[\"+h.slice(0,l.colormodel.length).join(\", \")+\"]\";return[i.extendFlat(t,{index:[p,f],x0:c.c2p(s.x0+f*l.dx),x1:c.c2p(s.x0+(f+1)*l.dx),y0:k,y1:k,color:b,xVal:A,xLabelVal:A,yVal:M,yLabelVal:M,zLabelVal:S,text:y,hovertemplateLabels:{zLabel:S,colorLabel:T,\"color[0]Label\":b[0]+w[0],\"color[1]Label\":b[1]+w[1],\"color[2]Label\":b[2]+w[2],\"color[3]Label\":b[3]+w[3]}})]}}}},92106:function(t,e,r){\"use strict\";t.exports={attributes:r(22153),supplyDefaults:r(82766),calc:r(31181),plot:r(36899),style:r(67555),hoverPoints:r(57328),eventData:r(45461),moduleType:\"trace\",name:\"image\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"2dMap\",\"noSortingByValue\"],animatable:!1,meta:{}}},36899:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=i.strTranslate,o=r(62972),s=r(42939),l=r(95544),c=r(1837).STYLE;t.exports=function(t,e,r,u){var h=e.xaxis,f=e.yaxis,p=!t._context._exportedPlot&&l();i.makeTraceGroups(u,r,\"im\").each((function(e){var r=n.select(this),l=e[0],u=l.trace,d=(\"fast\"===u.zsmooth||!1===u.zsmooth&&p)&&!u._hasZ&&u._hasSource&&\"linear\"===h.type&&\"linear\"===f.type;u._realImage=d;var m,g,y,v,x,_,b=l.z,w=l.x0,T=l.y0,k=l.w,A=l.h,M=u.dx,S=u.dy;for(_=0;void 0===m&&_<k;)m=h.c2p(w+_*M),_++;for(_=k;void 0===g&&_>0;)g=h.c2p(w+_*M),_--;for(_=0;void 0===v&&_<A;)v=f.c2p(T+_*S),_++;for(_=A;void 0===x&&_>0;)x=f.c2p(T+_*S),_--;g<m&&(y=g,g=m,m=y),x<v&&(y=v,v=x,x=y),d||(m=Math.max(-.5*h._length,m),g=Math.min(1.5*h._length,g),v=Math.max(-.5*f._length,v),x=Math.min(1.5*f._length,x));var E=Math.round(g-m),C=Math.round(x-v);if(E<=0||C<=0)r.selectAll(\"image\").data([]).exit().remove();else{var L=r.selectAll(\"image\").data([e]);L.enter().append(\"svg:image\").attr({xmlns:o.svg,preserveAspectRatio:\"none\"}),L.exit().remove();var I=!1===u.zsmooth?c:\"\";if(d){var P=i.simpleMap(h.range,h.r2l),z=i.simpleMap(f.range,f.r2l),O=P[1]<P[0],D=z[1]>z[0];if(O||D){var R=m+E/2,F=v+C/2;I+=\"transform:\"+a(R+\"px\",F+\"px\")+\"scale(\"+(O?-1:1)+\",\"+(D?-1:1)+\")\"+a(-R+\"px\",-F+\"px\")+\";\"}}L.attr(\"style\",I);var B=new Promise((function(t){if(u._hasZ)t();else if(u._hasSource)if(u._canvas&&u._canvas.el.width===k&&u._canvas.el.height===A&&u._canvas.source===u.source)t();else{var e=document.createElement(\"canvas\");e.width=k,e.height=A;var r=e.getContext(\"2d\",{willReadFrequently:!0});u._image=u._image||new Image;var n=u._image;n.onload=function(){r.drawImage(n,0,0),u._canvas={el:e,source:u.source},t()},n.setAttribute(\"src\",u.source)}})).then((function(){var t,e;if(u._hasZ)e=N((function(t,e){var r=b[e][t];return i.isTypedArray(r)&&(r=Array.from(r)),r})),t=e.toDataURL(\"image/png\");else if(u._hasSource)if(d)t=u.source;else{var r=u._canvas.el.getContext(\"2d\",{willReadFrequently:!0}).getImageData(0,0,k,A).data;e=N((function(t,e){var n=4*(e*k+t);return[r[n],r[n+1],r[n+2],r[n+3]]})),t=e.toDataURL(\"image/png\")}L.attr({\"xlink:href\":t,height:C,width:E,x:m,y:v})}));t._promises.push(B)}function N(t){var e=document.createElement(\"canvas\");e.width=E,e.height=C;var r,n=e.getContext(\"2d\",{willReadFrequently:!0}),a=function(t){return i.constrain(Math.round(h.c2p(w+t*M)-m),0,E)},o=function(t){return i.constrain(Math.round(f.c2p(T+t*S)-v),0,C)},c=s.colormodel[u.colormodel],p=c.colormodel||u.colormodel,d=c.fmt;for(_=0;_<l.w;_++){var g=a(_),y=a(_+1);if(y!==g&&!isNaN(y)&&!isNaN(g))for(var x=0;x<l.h;x++){var b=o(x),k=o(x+1);k===b||isNaN(k)||isNaN(b)||!t(_,x)||(r=u._scaler(t(_,x)),n.fillStyle=r?p+\"(\"+d(r).join(\",\")+\")\":\"rgba(0,0,0,0)\",n.fillRect(g,b,y-g,k-b))}}return e}}))}},67555:function(t,e,r){\"use strict\";var n=r(45568);t.exports=function(t){n.select(t).selectAll(\".im image\").style(\"opacity\",(function(t){return t[0].trace.opacity}))}},95485:function(t,e,r){\"use strict\";var n=r(93049).extendFlat,i=r(93049).extendDeep,a=r(13582).overrideAll,o=r(80337),s=r(10229),l=r(13792).u,c=r(25829),u=r(78032).templatedArray,h=r(20909),f=r(80712).descriptionOnlyNumbers,p=o({editType:\"plot\",colorEditType:\"plot\"}),d={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},m={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"step\",i({},d,{range:m}));t.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},p,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\",description:f(\"value\")},font:n({},p,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\",description:f(\"value\")},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},p,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},d,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:m,visible:n({},c.visible,{dflt:!0}),tickmode:c.minor.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,ticklabelstep:c.ticklabelstep,showticklabels:c.showticklabels,labelalias:c.labelalias,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,minexponent:c.minexponent,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},d.line.color,{}),width:n({},d.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},d.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},47751:function(t,e,r){\"use strict\";var n=r(44122);e.name=\"indicator\",e.plot=function(t,r,i,a){n.plotBasePlot(e.name,t,r,i,a)},e.clean=function(t,r,i,a){n.cleanBasePlot(e.name,t,r,i,a)}},98385:function(t){\"use strict\";t.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},74807:function(t){\"use strict\";t.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},79306:function(t,e,r){\"use strict\";var n=r(34809),i=r(95485),a=r(13792).N,o=r(78032),s=r(59008),l=r(74807),c=r(22777),u=r(87433),h=r(12036),f=r(54616);function p(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}t.exports={supplyDefaults:function(t,e,r,d){function m(r,a){return n.coerce(t,e,i,r,a)}a(e,d,m),m(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=m(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var y,v,x=new Array(2);if(e._hasNumber){m(\"number.valueformat\");var _=n.extendFlat({},d.font);_.size=void 0,n.coerceFont(m,\"number.font\",_),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,x[0]=!0),m(\"number.prefix\"),m(\"number.suffix\"),y=e.number.font.size}if(e._hasDelta){var b=n.extendFlat({},d.font);b.size=void 0,n.coerceFont(m,\"delta.font\",b),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(y||l.defaultNumberFontSize),x[1]=!0),m(\"delta.reference\",e.value),m(\"delta.relative\"),m(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),m(\"delta.increasing.symbol\"),m(\"delta.increasing.color\"),m(\"delta.decreasing.symbol\"),m(\"delta.decreasing.color\"),m(\"delta.position\"),m(\"delta.prefix\"),m(\"delta.suffix\"),v=e.delta.font.size}e._scaleNumbers=(!e._hasNumber||x[0])&&(!e._hasDelta||x[1])||!1;var w,T,k,A,M=n.extendFlat({},d.font);function S(t,e){return n.coerce(w,T,i.gauge,t,e)}function E(t,e){return n.coerce(k,A,i.gauge.axis,t,e)}if(M.size=.25*(y||v||l.defaultNumberFontSize),n.coerceFont(m,\"title.font\",M),m(\"title.text\"),e._hasGauge){(w=t.gauge)||(w={}),T=o.newContainer(e,\"gauge\"),S(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||m(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||m(\"align\",\"center\"),S(\"bgcolor\",d.paper_bgcolor),S(\"borderwidth\"),S(\"bordercolor\"),S(\"bar.color\"),S(\"bar.line.color\"),S(\"bar.line.width\"),S(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(w,T,{name:\"steps\",handleItemDefaults:p}),S(\"threshold.value\"),S(\"threshold.thickness\"),S(\"threshold.line.width\"),S(\"threshold.line.color\"),k={},w&&(k=w.axis||{}),A=o.newContainer(T,\"axis\"),E(\"visible\"),e._range=E(\"range\",e._range);var C={font:d.font,noAutotickangles:!0,outerTicks:!0,noTicklabelshift:!0,noTicklabelstandoff:!0};c(k,A,E,\"linear\"),f(k,A,E,\"linear\",C),h(k,A,E,\"linear\",C),u(k,A,E,C)}else m(\"title.align\",\"center\"),m(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},25638:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:r(47751),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:r(95485),supplyDefaults:r(79306).supplyDefaults,calc:r(98385).calc,plot:r(37095),meta:{}}},37095:function(t,e,r){\"use strict\";var n=r(45568),i=r(88640).GW,a=r(88640).Dj,o=r(34809),s=o.strScale,l=o.strTranslate,c=o.rad2deg,u=r(4530).MID_SHIFT,h=r(62203),f=r(74807),p=r(30635),d=r(29714),m=r(97655),g=r(40957),y=r(25829),v=r(78766),x={left:\"start\",center:\"middle\",right:\"end\"},_={left:0,center:.5,right:1},b=/[yzafpn\u00b5mkMGTPEZY]/;function w(t){return t&&t.duration>0}function T(t){t.each((function(t){v.stroke(n.select(this),t.line.color)})).each((function(t){v.fill(n.select(this),t.color)})).style(\"stroke-width\",(function(t){return t.line.width}))}function k(t,e,r){var n=t._fullLayout,i=o.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),a={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noAutotickangles:!0,noHover:!0,noTickson:!0};function l(t,e){return o.coerce(i,a,y,t,e)}return m(i,a,l,s,n),g(i,a,l,s),a}function A(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function M(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(p.convertToTspans,i).call(h.font,e),h.bBox(o.node())}function S(t,e,r,n,i,a){var s=\"_cache\"+e;t[s]&&t[s].key===i||(t[s]={key:i,value:r});var l=o.aggNums(a,null,[t[s].value,n],2);return t[s].value=l,l}t.exports=function(t,e,r,m){var g,y=t._fullLayout;w(r)&&m&&(g=m()),o.makeTraceGroups(y._indicatorlayer,e,\"trace\").each((function(e){var m,E,C,L,I,P=e[0].trace,z=n.select(this),O=P._hasGauge,D=P._isAngular,R=P._isBullet,F=P.domain,B={w:y._size.w*(F.x[1]-F.x[0]),h:y._size.h*(F.y[1]-F.y[0]),l:y._size.l+y._size.w*F.x[0],r:y._size.r+y._size.w*(1-F.x[1]),t:y._size.t+y._size.h*(1-F.y[1]),b:y._size.b+y._size.h*F.y[0]},N=B.l+B.w/2,j=B.t+B.h/2,U=Math.min(B.w/2,B.h),V=f.innerRadius*U,q=P.align||\"center\";if(E=j,O){if(D&&(m=N,E=j+U/2,C=function(t){return function(t,e){return[e/Math.sqrt(t.width/2*(t.width/2)+t.height*t.height),t,e]}(t,.9*V)}),R){var H=f.bulletPadding,G=1-f.bulletNumberDomainSize+H;m=B.l+(G+(1-G)*_[q])*B.w,C=function(t){return A(t,(f.bulletNumberDomainSize-H)*B.w,B.h)}}}else m=B.l+_[q]*B.w,C=function(t){return A(t,B.w,B.h)};!function(t,e,r,i){var c,u,f,m=r[0].trace,g=i.numbersX,y=i.numbersY,T=m.align||\"center\",A=x[T],E=i.transitionOpts,C=i.onComplete,L=o.ensureSingle(e,\"g\",\"numbers\"),I=[];m._hasNumber&&I.push(\"number\"),m._hasDelta&&(I.push(\"delta\"),\"left\"===m.delta.position&&I.reverse());var P=L.selectAll(\"text\").data(I);function z(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(b)||r(i).slice(-1).match(b))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,(function(t){return parseInt(t)-1})),o=k(t,{tickformat:a});return function(t){return Math.abs(t)<1?d.tickText(o,t).text:r(t)}}P.enter().append(\"text\"),P.attr(\"text-anchor\",(function(){return A})).attr(\"class\",(function(t){return t})).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),P.exit().remove();var O,D=m.mode+m.align;if(m._hasDelta&&(O=function(){var e=k(t,{tickformat:m.delta.valueformat},m._range);e.setScale(),d.prepTicks(e);var i=function(t){return d.tickText(e,t).text},o=m.delta.suffix,s=m.delta.prefix,l=function(t){return m.delta.relative?t.relativeDelta:t.delta},c=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?m.delta.increasing.symbol:m.delta.decreasing.symbol)+s+e(t)+o},f=function(t){return t.delta>=0?m.delta.increasing.color:m.delta.decreasing.color};void 0===m._deltaLastValue&&(m._deltaLastValue=l(r[0]));var g=L.select(\"text.delta\");function y(){g.text(c(l(r[0]),i)).call(v.fill,f(r[0])).call(p.convertToTspans,t)}return g.call(h.font,m.delta.font).call(v.fill,f({delta:m._deltaLastValue})),w(E)?g.transition().duration(E.duration).ease(E.easing).tween(\"text\",(function(){var t=n.select(this),e=l(r[0]),o=m._deltaLastValue,s=z(m.delta.valueformat,i,o,e),u=a(o,e);return m._deltaLastValue=e,function(e){t.text(c(u(e),s)),t.call(v.fill,f({delta:u(e)}))}})).each(\"end\",(function(){y(),C&&C()})).each(\"interrupt\",(function(){y(),C&&C()})):y(),u=M(c(l(r[0]),i),m.delta.font,A,t),g}(),D+=m.delta.position+m.delta.font.size+m.delta.font.family+m.delta.valueformat,D+=m.delta.increasing.symbol+m.delta.decreasing.symbol,f=u),m._hasNumber&&(function(){var e=k(t,{tickformat:m.number.valueformat},m._range);e.setScale(),d.prepTicks(e);var i=function(t){return d.tickText(e,t).text},o=m.number.suffix,s=m.number.prefix,l=L.select(\"text.number\");function u(){var e=\"number\"==typeof r[0].y?s+i(r[0].y)+o:\"-\";l.text(e).call(h.font,m.number.font).call(p.convertToTspans,t)}w(E)?l.transition().duration(E.duration).ease(E.easing).each(\"end\",(function(){u(),C&&C()})).each(\"interrupt\",(function(){u(),C&&C()})).attrTween(\"text\",(function(){var t=n.select(this),e=a(r[0].lastY,r[0].y);m._lastValue=r[0].y;var l=z(m.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(s+l(e(r))+o)}})):u(),c=M(s+i(r[0].y)+o,m.number.font,A,t)}(),D+=m.number.font.size+m.number.font.family+m.number.valueformat+m.number.suffix+m.number.prefix,f=c),m._hasDelta&&m._hasNumber){var R,F,B=[(c.left+c.right)/2,(c.top+c.bottom)/2],N=[(u.left+u.right)/2,(u.top+u.bottom)/2],j=.75*m.delta.font.size;\"left\"===m.delta.position&&(R=S(m,\"deltaPos\",0,-1*(c.width*_[m.align]+u.width*(1-_[m.align])+j),D,Math.min),F=B[1]-N[1],f={width:c.width+u.width+j,height:Math.max(c.height,u.height),left:u.left+R,right:c.right,top:Math.min(c.top,u.top+F),bottom:Math.max(c.bottom,u.bottom+F)}),\"right\"===m.delta.position&&(R=S(m,\"deltaPos\",0,c.width*(1-_[m.align])+u.width*_[m.align]+j,D,Math.max),F=B[1]-N[1],f={width:c.width+u.width+j,height:Math.max(c.height,u.height),left:c.left,right:u.right+R,top:Math.min(c.top,u.top+F),bottom:Math.max(c.bottom,u.bottom+F)}),\"bottom\"===m.delta.position&&(R=null,F=u.height,f={width:Math.max(c.width,u.width),height:c.height+u.height,left:Math.min(c.left,u.left),right:Math.max(c.right,u.right),top:c.bottom-c.height,bottom:c.bottom+u.height}),\"top\"===m.delta.position&&(R=null,F=c.top,f={width:Math.max(c.width,u.width),height:c.height+u.height,left:Math.min(c.left,u.left),right:Math.max(c.right,u.right),top:c.bottom-c.height-u.height,bottom:c.bottom}),O.attr({dx:R,dy:F})}(m._hasNumber||m._hasDelta)&&L.attr(\"transform\",(function(){var t=i.numbersScaler(f);D+=t[2];var e,r=S(m,\"numbersScale\",1,t[0],D,Math.min);m._scaleNumbers||(r=1),e=m._isAngular?y-r*f.bottom:y-r*(f.top+f.bottom)/2,m._numbersTop=r*f.top+e;var n=f[T];\"center\"===T&&(n=(f.left+f.right)/2);var a=g-r*n;return a=S(m,\"numbersTranslate\",0,a,D,Math.max),l(a,e)+s(r)}))}(t,z,e,{numbersX:m,numbersY:E,numbersScaler:C,transitionOpts:r,onComplete:g}),O&&(L={range:P.gauge.axis.range,color:P.gauge.bgcolor,line:{color:P.gauge.bordercolor,width:0},thickness:1},I={range:P.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:P.gauge.bordercolor,width:P.gauge.borderwidth},thickness:1});var Z=z.selectAll(\"g.angular\").data(D?e:[]);Z.exit().remove();var W=z.selectAll(\"g.angularaxis\").data(D?e:[]);W.exit().remove(),D&&function(t,e,r,a){var o,s,h,f,p=r[0].trace,m=a.size,g=a.radius,y=a.innerRadius,v=a.gaugeBg,x=a.gaugeOutline,_=[m.l+m.w/2,m.t+m.h/2+g/2],b=a.gauge,A=a.layer,M=a.transitionOpts,S=a.onComplete,E=Math.PI/2;function C(t){var e=p.gauge.axis.range[0],r=(t-e)/(p.gauge.axis.range[1]-e)*Math.PI-E;return r<-E?-E:r>E?E:r}function L(t){return n.svg.arc().innerRadius((y+g)/2-t/2*(g-y)).outerRadius((y+g)/2+t/2*(g-y)).startAngle(-E)}function I(t){t.attr(\"d\",(function(t){return L(t.thickness).startAngle(C(t.range[0])).endAngle(C(t.range[1]))()}))}b.enter().append(\"g\").classed(\"angular\",!0),b.attr(\"transform\",l(_[0],_[1])),A.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),A.selectAll(\"g.xangularaxistick,path,text\").remove(),(o=k(t,p.gauge.axis)).type=\"linear\",o.range=p.gauge.axis.range,o._id=\"xangularaxis\",o.ticklabeloverflow=\"allow\",o.setScale();var P=function(t){return(o.range[0]-t.x)/(o.range[1]-o.range[0])*Math.PI+Math.PI},z={},O=d.makeLabelFns(o,0).labelStandoff;z.xFn=function(t){var e=P(t);return Math.cos(e)*O},z.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(O+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*u)},z.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},z.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var D=function(t){return l(_[0]+g*Math.cos(t),_[1]-g*Math.sin(t))};h=function(t){return D(P(t))};if(s=d.calcTicks(o),f=d.getTickSigns(o)[2],o.visible){f=\"inside\"===o.ticks?-1:1;var R=(o.linewidth||1)/2;d.drawTicks(t,o,{vals:s,layer:A,path:\"M\"+f*R+\",0h\"+f*o.ticklen,transFn:function(t){var e=P(t);return D(e)+\"rotate(\"+-c(e)+\")\"}}),d.drawLabels(t,o,{vals:s,layer:A,transFn:h,labelFns:z})}var F=[v].concat(p.gauge.steps),B=b.selectAll(\"g.bg-arc\").data(F);B.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),B.select(\"path\").call(I).call(T),B.exit().remove();var N=L(p.gauge.bar.thickness),j=b.selectAll(\"g.value-arc\").data([p.gauge.bar]);j.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var U,V,q,H=j.select(\"path\");w(M)?(H.transition().duration(M.duration).ease(M.easing).each(\"end\",(function(){S&&S()})).each(\"interrupt\",(function(){S&&S()})).attrTween(\"d\",(U=N,V=C(r[0].lastY),q=C(r[0].y),function(){var t=i(V,q);return function(e){return U.endAngle(t(e))()}})),p._lastValue=r[0].y):H.attr(\"d\",\"number\"==typeof r[0].y?N.endAngle(C(r[0].y)):\"M0,0Z\"),H.call(T),j.exit().remove(),F=[];var G=p.gauge.threshold.value;(G||0===G)&&F.push({range:[G,G],color:p.gauge.threshold.color,line:{color:p.gauge.threshold.line.color,width:p.gauge.threshold.line.width},thickness:p.gauge.threshold.thickness});var Z=b.selectAll(\"g.threshold-arc\").data(F);Z.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),Z.select(\"path\").call(I).call(T),Z.exit().remove();var W=b.selectAll(\"g.gauge-outline\").data([x]);W.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),W.select(\"path\").call(I).call(T),W.exit().remove()}(t,0,e,{radius:U,innerRadius:V,gauge:Z,layer:W,size:B,gaugeBg:L,gaugeOutline:I,transitionOpts:r,onComplete:g});var Y=z.selectAll(\"g.bullet\").data(R?e:[]);Y.exit().remove();var X=z.selectAll(\"g.bulletaxis\").data(R?e:[]);X.exit().remove(),R&&function(t,e,r,n){var i,a,o,s,c,u=r[0].trace,h=n.gauge,p=n.layer,m=n.gaugeBg,g=n.gaugeOutline,y=n.size,x=u.domain,_=n.transitionOpts,b=n.onComplete;h.enter().append(\"g\").classed(\"bullet\",!0),h.attr(\"transform\",l(y.l,y.t)),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var A=y.h,M=u.gauge.bar.thickness*A,S=x.x[0],E=x.x[0]+(x.x[1]-x.x[0])*(u._hasNumber||u._hasDelta?1-f.bulletNumberDomainSize:1);function C(t){t.attr(\"width\",(function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))})).attr(\"x\",(function(t){return i.c2p(t.range[0])})).attr(\"y\",(function(t){return.5*(1-t.thickness)*A})).attr(\"height\",(function(t){return t.thickness*A}))}(i=k(t,u.gauge.axis))._id=\"xbulletaxis\",i.domain=[S,E],i.setScale(),a=d.calcTicks(i),o=d.makeTransTickFn(i),s=d.getTickSigns(i)[2],c=y.t+y.h,i.visible&&(d.drawTicks(t,i,{vals:\"inside\"===i.ticks?d.clipEnds(i,a):a,layer:p,path:d.makeTickPath(i,c,s),transFn:o}),d.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:d.makeLabelFns(i,c)}));var L=[m].concat(u.gauge.steps),I=h.selectAll(\"g.bg-bullet\").data(L);I.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),I.select(\"rect\").call(C).call(T),I.exit().remove();var P=h.selectAll(\"g.value-bullet\").data([u.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",M).attr(\"y\",(A-M)/2).call(T),w(_)?P.select(\"rect\").transition().duration(_.duration).ease(_.easing).each(\"end\",(function(){b&&b()})).each(\"interrupt\",(function(){b&&b()})).attr(\"width\",Math.max(0,i.c2p(Math.min(u.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(u.gauge.axis.range[1],r[0].y))):0),P.exit().remove();var z=r.filter((function(){return u.gauge.threshold.value||0===u.gauge.threshold.value})),O=h.selectAll(\"g.threshold-bullet\").data(z);O.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),O.select(\"line\").attr(\"x1\",i.c2p(u.gauge.threshold.value)).attr(\"x2\",i.c2p(u.gauge.threshold.value)).attr(\"y1\",(1-u.gauge.threshold.thickness)/2*A).attr(\"y2\",(1-(1-u.gauge.threshold.thickness)/2)*A).call(v.stroke,u.gauge.threshold.line.color).style(\"stroke-width\",u.gauge.threshold.line.width),O.exit().remove();var D=h.selectAll(\"g.gauge-outline\").data([g]);D.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),D.select(\"rect\").call(C).call(T),D.exit().remove()}(t,0,e,{gauge:Y,layer:X,size:B,gaugeBg:L,gaugeOutline:I,transitionOpts:r,onComplete:g});var $=z.selectAll(\"text.title\").data(e);$.exit().remove(),$.enter().append(\"text\").classed(\"title\",!0),$.attr(\"text-anchor\",(function(){return R?x.right:x[P.title.align]})).text(P.title.text).call(h.font,P.title.font).call(p.convertToTspans,t),$.attr(\"transform\",(function(){var t,e=B.l+B.w*_[P.title.align],r=f.titlePadding,n=h.bBox($.node());return O?(D&&(t=P.gauge.axis.visible?h.bBox(W.node()).top-r-n.bottom:B.t+B.h/2-U/2-n.bottom-r),R&&(t=E-(n.top+n.bottom)/2,e=B.l-f.bulletPadding*B.w)):t=P._numbersTop-r-n.bottom,l(e,t)}))}))}},70252:function(t,e,r){\"use strict\";var n=r(87163),i=r(80712).axisHoverFormat,a=r(3208).rb,o=r(42450),s=r(9829),l=r(93049).extendFlat,c=r(13582).overrideAll,u=t.exports=c(l({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),valuehoverformat:i(\"value\",1),showlegend:l({},s.showlegend,{dflt:!1})},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:o.opacity,lightposition:o.lightposition,lighting:o.lighting,flatshading:o.flatshading,contour:o.contour,hoverinfo:l({},s.hoverinfo)}),\"calc\",\"nested\");u.flatshading.dflt=!0,u.lighting.facenormalsepsilon.dflt=0,u.x.editType=u.y.editType=u.z.editType=u.value.editType=\"calc+clearAxisTypes\",u.transforms=void 0},58988:function(t,e,r){\"use strict\";var n=r(28379),i=r(36402).processGrid,a=r(36402).filter;t.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=a(e.x,e._len),e._y=a(e.y,e._len),e._z=a(e.z,e._len),e._value=a(e.value,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomax?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},91370:function(t,e,r){\"use strict\";var n=r(99098).gl_mesh3d,i=r(46998).parseColorScale,a=r(34809).isArrayOrTypedArray,o=r(55010),s=r(88856).extractOpts,l=r(88239),c=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],o=this.data._Ys.length,s=this.data._Zs.length,l=c(r,this.data._Xs).id,u=c(n,this.data._Ys).id,h=c(i,this.data._Zs).id,f=t.index=h+s*u+s*o*l;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var p=this.data.hovertext||this.data.text;return a(p)&&void 0!==p[f]?t.textLabel=p[f]:p&&(t.textLabel=p),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=p(t);var a={positions:l(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:l(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);a.vertexIntensity=t._meshIntensity,a.vertexIntensityBounds=[c.min,c.max],a.colormap=i(t),this.mesh.update(a)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var f=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"];function p(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,i,a,o,s,l=t.surface.show,u=t.spaceframe.show,h=t.surface.fill,p=t.spaceframe.fill,d=!1,m=!1,g=0,y=t._Xs,v=t._Ys,x=t._Zs,_=y.length,b=v.length,w=x.length,T=f.indexOf(t._gridFill.replace(/-/g,\"\").replace(/\\+/g,\"\")),k=function(t,e,r){switch(T){case 5:return r+w*e+w*b*t;case 4:return r+w*t+w*_*e;case 3:return e+b*r+b*w*t;case 2:return e+b*t+b*_*r;case 1:return t+_*r+_*w*e;default:return t+_*e+_*b*r}},A=t._minValues,M=t._maxValues,S=t._vMin,E=t._vMax;function C(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===i[c]&&s===a[c])return c;return-1}function L(){r=e}function I(){n=[],i=[],a=[],o=[],e=0,L()}function P(t,r,s,l){return n.push(t),i.push(r),a.push(s),o.push(l),++e-1}function z(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function O(t){s=t}function D(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){L();var i,a,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-s),l=z(a,r,o),c=z(a,n,o),u=z(a,i,o),h=e[0],f=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,i,u],[u,c,n],[i,r,l],[l,u,i]],abc:[[h,f,-1],[-1,-1,h],[f,p,-1],[-1,-1,f],[p,h,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var h=0;h<l.length;h++){r=l[h],n=c[h];for(var f=[],p=0;p<3;p++){var d=r[p][0],m=r[p][1],y=r[p][2],v=r[p][3],x=n[p]>-1?n[p]:C(d,m,y);f[p]=x>-1?x:P(d,m,y,R(e,v))}i=f[0],a=f[1],o=f[2],t._meshI.push(i),t._meshJ.push(a),t._meshK.push(o),++g}}function B(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function U(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t._x[i],t._y[i],t._z[i],t._value[i]])}return r}var V=3;function q(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,i),N(e[1][3],n,i),N(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):a<V&&q(t,e,r,S,E,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach((function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=B(f,u,n,i),d=B(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}})),c||[[0,1,2],[1,2,0],[2,0,1]].forEach((function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=B(h,u,n,i),d=B(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}})),o}function H(t,e,r,n){var i=!1,a=U(e),o=[N(a[0][3],r,n),N(a[1][3],r,n),N(a[2][3],r,n),N(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return m&&(i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],h=a[l[2]],f=a[l[3]];if(m)i=F(t,[c,u,h],[e[l[0]],e[l[1]],e[l[2]]])||i;else{var p=B(f,c,r,n),d=B(f,u,r,n),g=B(f,h,r,n);i=F(null,[p,d,g],[-1,-1,-1])||i}s=!0}})),s||([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],h=a[l[2]],f=a[l[3]],p=B(h,c,r,n),d=B(h,u,r,n),g=B(f,u,r,n),y=B(f,c,r,n);m?(i=F(t,[c,y,p],[e[l[0]],-1,-1])||i,i=F(t,[u,d,g],[e[l[1]],-1,-1])||i):i=function(t,e,r){var n=function(t,n,i){F(null,[e[t],e[n],e[i]],[r[t],r[n],r[i]])};n(0,1,2),n(2,3,0)}(0,[p,d,g,y],[-1,-1,-1,-1])||i,s=!0}})),s||[[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach((function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],h=a[l[2]],f=a[l[3]],p=B(u,c,r,n),d=B(h,c,r,n),g=B(f,c,r,n);m?(i=F(t,[c,p,d],[e[l[0]],-1,-1])||i,i=F(t,[c,d,g],[e[l[0]],-1,-1])||i,i=F(t,[c,g,p],[e[l[0]],-1,-1])||i):i=F(null,[p,d,g],[-1,-1,-1])||i,s=!0}}))),i}function G(t,e,r,n,i,a,o,s,l,c,u){var h=!1;return d&&(D(t,\"A\")&&(h=H(null,[e,r,n,a],c,u)||h),D(t,\"B\")&&(h=H(null,[r,n,i,l],c,u)||h),D(t,\"C\")&&(h=H(null,[r,a,o,l],c,u)||h),D(t,\"D\")&&(h=H(null,[n,a,s,l],c,u)||h),D(t,\"E\")&&(h=H(null,[r,n,a,l],c,u)||h)),m&&(h=H(t,[r,n,a,l],c,u)||h),h}function Z(t,e,r,n,i,a,o,s){return[!0===s[0]||q(t,U([e,r,n]),[e,r,n],a,o),!0===s[1]||q(t,U([n,i,e]),[n,i,e],a,o)]}function W(t,e,r,n,i,a,o,s,l){return s?Z(t,e,r,i,n,a,o,l):Z(t,r,i,n,e,a,o,l)}function Y(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=q(t,[s,l,c],[-1,-1,-1],i,a)||h,h=q(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],m=o[2];return p&&(s=z(U([k(e,r-0,n-0)])[0],U([k(e-1,r-0,n-0)])[0],p),l=z(U([k(e,r-0,n-1)])[0],U([k(e-1,r-0,n-1)])[0],p),c=z(U([k(e,r-1,n-1)])[0],U([k(e-1,r-1,n-1)])[0],p),u=z(U([k(e,r-1,n-0)])[0],U([k(e-1,r-1,n-0)])[0],p),f()),d&&(s=z(U([k(e-0,r,n-0)])[0],U([k(e-0,r-1,n-0)])[0],d),l=z(U([k(e-0,r,n-1)])[0],U([k(e-0,r-1,n-1)])[0],d),c=z(U([k(e-1,r,n-1)])[0],U([k(e-1,r-1,n-1)])[0],d),u=z(U([k(e-1,r,n-0)])[0],U([k(e-1,r-1,n-0)])[0],d),f()),m&&(s=z(U([k(e-0,r-0,n)])[0],U([k(e-0,r-0,n-1)])[0],m),l=z(U([k(e-0,r-1,n)])[0],U([k(e-0,r-1,n-1)])[0],m),c=z(U([k(e-1,r-1,n)])[0],U([k(e-1,r-1,n-1)])[0],m),u=z(U([k(e-1,r-0,n)])[0],U([k(e-1,r-0,n-1)])[0],m),f()),h}function X(t,e,r,n,i,a,o,s,l,c,u,h){var f=t;return h?(d&&\"even\"===t&&(f=null),G(f,e,r,n,i,a,o,s,l,c,u)):(d&&\"odd\"===t&&(f=null),G(f,l,s,o,a,i,n,r,e,c,u))}function $(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<b;u++)a.push(W(t,k(l,u-1,c-1),k(l,u-1,c),k(l,u,c-1),k(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<w;u++)a.push(W(t,k(c-1,l,u-1),k(c,l,u-1),k(c-1,l,u),k(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<_;u++)a.push(W(t,k(u-1,c-1,l),k(u-1,c,l),k(u,c-1,l),k(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function Q(t,e,r){for(var n=1;n<w;n++)for(var i=1;i<b;i++)for(var a=1;a<_;a++)X(t,k(a-1,i-1,n-1),k(a-1,i-1,n),k(a-1,i,n-1),k(a-1,i,n),k(a,i-1,n-1),k(a,i-1,n),k(a,i,n-1),k(a,i,n),e,r,(a+i+n)%2)}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var h=1;h<b;h++)o.push(Y(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var h=1;h<w;h++)o.push(Y(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var h=1;h<_;h++)o.push(Y(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){I(),function(){for(var e=0;e<_;e++)for(var r=0;r<b;r++)for(var n=0;n<w;n++){var i=k(e,r,n);P(t._x[i],t._y[i],t._z[i],t._value[i])}}();var e=null;if(u&&p&&(O(p),m=!0,Q(e,S,E),m=!1),l&&h){O(h);for(var r=t.surface.pattern,s=t.surface.count,f=0;f<s;f++){var T=1===s?.5:f/(s-1),C=(1-T)*S+T*E,L=Math.abs(C-A)>Math.abs(C-M)?[A,C]:[C,M];d=!0,Q(r,L[0],L[1]),d=!1}}var z=[[Math.min(S,M),Math.max(S,M)],[Math.min(A,E),Math.max(A,E)]];[\"x\",\"y\",\"z\"].forEach((function(r){for(var n=[],i=0;i<z.length;i++){var a=0,o=z[i][0],s=z[i][1],l=t.slices[r];if(l.show&&l.fill){O(l.fill);var u=[],h=[],f=[];if(l.locations.length)for(var p=0;p<l.locations.length;p++){var d=c(l.locations[p],\"x\"===r?y:\"y\"===r?v:x);0===d.distRatio?u.push(d.id):d.id>0&&(h.push(d.id),\"x\"===r?f.push([d.distRatio,0,0]):\"y\"===r?f.push([0,d.distRatio,0]):f.push([0,0,d.distRatio]))}else u=nt(1,\"x\"===r?_-1:\"y\"===r?b-1:w-1);h.length>0&&(n[a]=\"x\"===r?tt(e,h,o,s,f,n[a]):\"y\"===r?et(e,h,o,s,f,n[a]):rt(e,h,o,s,f,n[a]),a++),u.length>0&&(n[a]=\"x\"===r?$(e,u,o,s,n[a]):\"y\"===r?J(e,u,o,s,n[a]):K(e,u,o,s,n[a]),a++)}var m=t.caps[r];m.show&&m.fill&&(O(m.fill),n[a]=\"x\"===r?$(e,[0,_-1],o,s,n[a]):\"y\"===r?J(e,[0,b-1],o,s,n[a]):K(e,[0,w-1],o,s,n[a]),a++)}})),0===g&&I(),t._meshX=n,t._meshY=i,t._meshZ=a,t._meshIntensity=o,t._Xs=y,t._Ys=v,t._Zs=x}(),t}t.exports={findNearestOnAxis:c,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},44731:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626),a=r(70252),o=r(39356);function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),a(\"valuehoverformat\"),[\"x\",\"y\",\"z\"].forEach((function(t){a(t+\"hoverformat\");var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))})),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach((function(t){a(t)})),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}t.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,(function(r,i){return n.coerce(t,e,a,r,i)}))},supplyIsoDefaults:s}},75297:function(t,e,r){\"use strict\";t.exports={attributes:r(70252),supplyDefaults:r(44731).supplyDefaults,calc:r(58988),colorbar:{min:\"cmin\",max:\"cmax\"},plot:r(91370).createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:r(2487),categories:[\"gl3d\",\"showLegend\"],meta:{}}},42450:function(t,e,r){\"use strict\";var n=r(87163),i=r(80712).axisHoverFormat,a=r(3208).rb,o=r(16131),s=r(9829),l=r(93049).extendFlat;t.exports=l({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:a({editType:\"calc\"}),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},intensitymode:{valType:\"enumerated\",values:[\"vertex\",\"cell\"],dflt:\"vertex\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:o.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:l({},o.contours.x.show,{}),color:o.contours.x.color,width:o.contours.x.width,editType:\"calc\"},lightposition:{x:l({},o.lightposition.x,{dflt:1e5}),y:l({},o.lightposition.y,{dflt:1e5}),z:l({},o.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:l({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},o.lighting),hoverinfo:l({},s.hoverinfo,{editType:\"calc\"}),showlegend:l({},s.showlegend,{dflt:!1})})},44878:function(t,e,r){\"use strict\";var n=r(28379);t.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},82836:function(t,e,r){\"use strict\";var n=r(99098).gl_mesh3d,i=r(99098).delaunay_triangulate,a=r(99098).alpha_shape,o=r(99098).convex_hull,s=r(46998).parseColorScale,l=r(34809).isArrayOrTypedArray,c=r(55010),u=r(88856).extractOpts,h=r(88239);function f(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var p=f.prototype;function d(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=c(t[n]);return e}function m(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function y(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}p.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return l(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},p.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,l=t.x.length,f=h(m(r.xaxis,t.x,e.dataScale[0],t.xcalendar),m(r.yaxis,t.y,e.dataScale[1],t.ycalendar),m(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!y(t.i,l)||!y(t.j,l)||!y(t.k,l))return;n=h(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var p={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:c(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var v=u(t);this.color=\"#fff\";var x=t.intensitymode;p[x+\"Intensity\"]=t.intensity,p[x+\"IntensityBounds\"]=[v.min,v.max],p.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],p.vertexColors=d(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],p.cellColors=d(t.facecolor)):(this.color=t.color,p.meshColor=c(t.color));this.mesh.update(p)},p.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},t.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new f(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},13573:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(39356),o=r(42450);t.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map((function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null}));return e.every((function(t){return t&&t.length===e[0].length}))&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach((function(t){l(t)})),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),\"intensity\"in t?(l(\"intensity\"),l(\"intensitymode\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),l(\"xhoverformat\"),l(\"yhoverformat\"),l(\"zhoverformat\"),e._length=null):e.visible=!1):e.visible=!1}},58859:function(t,e,r){\"use strict\";t.exports={attributes:r(42450),supplyDefaults:r(13573),calc:r(44878),colorbar:{min:\"cmin\",max:\"cmax\"},plot:r(82836),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:r(2487),categories:[\"gl3d\",\"showLegend\"],meta:{}}},86706:function(t,e,r){\"use strict\";var n=r(34809).extendFlat,i=r(36640),a=r(80712).axisHoverFormat,o=r(94850).T,s=r(70192),l=r(20909),c=l.INCREASING.COLOR,u=l.DECREASING.COLOR,h=i.line;function f(t){return{line:{color:n({},h.color,{dflt:t}),width:h.width,dash:o,editType:\"style\"},editType:\"style\"}}t.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},h.width,{}),dash:n({},o,{}),editType:\"style\"},increasing:f(c),decreasing:f(u),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},s.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}}),zorder:i.zorder}},95694:function(t,e,r){\"use strict\";var n=r(34809),i=n._,a=r(29714),o=r(40528),s=r(63821).BADNUM;function l(t,e,r,n){return{o:t,h:e,l:r,c:n}}function c(t,e,r,o,l,c){for(var u=l.makeCalcdata(e,\"open\"),h=l.makeCalcdata(e,\"high\"),f=l.makeCalcdata(e,\"low\"),p=l.makeCalcdata(e,\"close\"),d=n.isArrayOrTypedArray(e.text),m=n.isArrayOrTypedArray(e.hovertext),g=!0,y=null,v=!!e.xperiodalignment,x=[],_=0;_<o.length;_++){var b=o[_],w=u[_],T=h[_],k=f[_],A=p[_];if(b!==s&&w!==s&&T!==s&&k!==s&&A!==s){A===w?null!==y&&A!==y&&(g=A>y):g=A>w,y=A;var M=c(w,T,k,A);M.pos=b,M.yc=(w+A)/2,M.i=_,M.dir=g?\"increasing\":\"decreasing\",M.x=M.pos,M.y=[k,T],v&&(M.orig_p=r[_]),d&&(M.tx=e.text[_]),m&&(M.htx=e.hovertext[_]),x.push(M)}else x.push({pos:b,empty:!0})}return e._extremes[l._id]=a.findExtremes(l,n.concat(f,h),{padded:!0}),x.length&&(x[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),x}t.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),s=function(t,e,r){var i=r._minDiff;if(!i){var a,s=t._fullData,l=[];for(i=1/0,a=0;a<s.length;a++){var c=s[a];if(\"ohlc\"===c.type&&!0===c.visible&&c.xaxis===e._id){l.push(c);var u=e.makeCalcdata(c,\"x\");c._origX=u;var h=o(r,e,\"x\",u).vals;c._xcalc=h;var f=n.distinctVals(h).minDiff;f&&isFinite(f)&&(i=Math.min(i,f))}}for(i===1/0&&(i=1),a=0;a<l.length;a++)l[a]._minDiff=i}return i*r.tickwidth}(t,r,e),u=e._minDiff;e._minDiff=null;var h=e._origX;e._origX=null;var f=e._xcalc;e._xcalc=null;var p=c(t,e,h,f,i,l);return e._extremes[r._id]=a.findExtremes(r,f,{vpad:u/2}),p.length?(n.extendFlat(p[0].t,{wHover:u/2,tickLen:s}),p):[{t:{empty:!0}}]},calcCommon:c}},22629:function(t,e,r){\"use strict\";var n=r(34809),i=r(28270),a=r(99669),o=r(86706);function s(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}t.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}i(t,e,c,l)?(a(t,e,l,c,{x:!0}),c(\"xhoverformat\"),c(\"yhoverformat\"),c(\"line.width\"),c(\"line.dash\"),s(0,e,c,\"increasing\"),s(0,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"tickwidth\"),l._requestRangeslider[e.xaxis]=!0,c(\"zorder\")):e.visible=!1}},93245:function(t,e,r){\"use strict\";var n=r(29714),i=r(34809),a=r(32141),o=r(78766),s=r(34809).fillText,l=r(20909),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",m=h.bPos||0,g=function(t){return t.pos+m-e},y=h.bdPos||h.tickLen,v=h.wHover,x=Math.min(1,y/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function _(t){var e=g(t);return a.inbox(e-v,e+v,i)}function b(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(_(t)+b(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var T=a.getDistanceFunction(n,_,b,w);if(a.getClosest(l,T,t),!1===t.index)return null;var k=l[t.index];if(k.empty)return null;var A=u[k.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(k.pos+m-y,!0),t.x1=c.c2p(k.pos+m+y,!0),t.xLabelVal=void 0!==k.orig_p?k.orig_p:k.pos,t.spikeDistance=w(k)*s/i,t.xSpike=c.c2p(k.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(\"all\"!==p&&-1===d.indexOf(\"y\"))return[];for(var m=[\"high\",\"open\",\"close\",\"low\"],g={},y=0;y<m.length;y++){var v,x=m[y],_=l[x][f.index],b=s.c2p(_,!0);_ in g?(v=g[_]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,_,l.yhoverformat):((v=i.extendFlat({},f)).y0=v.y1=b,v.yLabelVal=_,v.yLabel=c.labels[x]+n.hoverLabelText(s,_,l.yhoverformat),v.name=\"\",h.push(v),g[_]=v)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,m=p.dir;function g(t){return h.labels[t]+n.hoverLabelText(o,l[t][d],l.yhoverformat)}var y=p.hi||l.hoverinfo,v=y.split(\"+\"),x=\"all\"===y,_=x||-1!==v.indexOf(\"y\"),b=x||-1!==v.indexOf(\"text\"),w=_?[g(\"open\"),g(\"high\"),g(\"low\"),g(\"close\")+\"  \"+c[m]]:[];return b&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}t.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},12683:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:r(86706),supplyDefaults:r(22629),calc:r(95694).calc,plot:r(38956),style:r(57406),hoverPoints:r(93245).hoverPoints,selectPoints:r(49343)}},28270:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809);t.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},38956:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809);t.exports=function(t,e,r,a){var o=e.yaxis,s=e.xaxis,l=!!s.rangebreaks;i.makeTraceGroups(a,r,\"trace ohlc\").each((function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var c=a.tickLen,u=e.selectAll(\"path\").data(i.identity);u.enter().append(\"path\"),u.exit().remove(),u.attr(\"d\",(function(t){if(t.empty)return\"M0,0Z\";var e=s.c2p(t.pos-c,!0),r=s.c2p(t.pos+c,!0),n=l?(e+r)/2:s.c2p(t.pos,!0);return\"M\"+e+\",\"+o.c2p(t.o,!0)+\"H\"+n+\"M\"+n+\",\"+o.c2p(t.h,!0)+\"V\"+o.c2p(t.l,!0)+\"M\"+r+\",\"+o.c2p(t.c,!0)+\"H\"+n}))}}))}},49343:function(t){\"use strict\";t.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},57406:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(78766);t.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each((function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}}))}))}},11660:function(t,e,r){\"use strict\";var n=r(93049).extendFlat,i=r(9829),a=r(80337),o=r(87163),s=r(3208).rb,l=r(13792).u,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});t.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({autoShadowDflt:!0,editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legend:void 0,legendgroup:void 0,legendrank:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},83260:function(t,e,r){\"use strict\";var n=r(4173).eV,i=r(37822),a=\"parcats\";e.name=a,e.plot=function(t,e,r,o){var s=n(t.calcdata,a);if(s.length){var l=s[0];i(t,l,r,o)}},e.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},95564:function(t,e,r){\"use strict\";var n=r(71293).wrap,i=r(65477).hasColorscale,a=r(28379),o=r(48965),s=r(62203),l=r(34809),c=r(10721);function u(t,e,r){t.valueInds.push(e),t.count+=r}function h(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function f(t,e,r){t.valueInds.push(e),t.count+=r}t.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var p,d,m,g=r.map((function(t){var e;if(\"trace\"===t.categoryorder)e=null;else if(\"array\"===t.categoryorder)e=t.categoryarray;else{e=o(t.values);for(var r=!0,n=0;n<e.length;n++)if(!c(e[n])){r=!1;break}e.sort(r?l.sorterAsc:void 0),\"category descending\"===t.categoryorder&&(e=e.reverse())}return function(t,e){e=null==e?[]:e.map((function(t){return t}));var r={},n={},i=[];e.forEach((function(t,e){r[t]=0,n[t]=e}));for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map((function(t){return r[t]}));return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)}));p=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e,r=t.map((function(t){return t.displayindex}));if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(r))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach((function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,g[e])}));var y,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),y=s.tryColorscale(v)):y=l.identity;var x,_,b,w,T,k=r[0].values.length,A={},M=g.map((function(t){return t.inds}));for(m=0,x=0;x<k;x++){var S=[];for(_=0;_<M.length;_++)S.push(M[_][x]);d=p[x%p.length],m+=d;var E=(b=x,w=void 0,T=void 0,l.isArrayOrTypedArray(v.color)?T=w=v.color[b%v.color.length]:w=v.color,{color:y(w),rawColor:T}),C=S+\"-\"+E.rawColor;void 0===A[C]&&(A[C]=h(S,E.color,E.rawColor)),f(A[C],x,d)}var L,I=r.map((function(t,e){return function(t,e,r,n,i){return{dimensionInd:t,containerInd:e,displayInd:r,dimensionLabel:n,count:i,categories:[],dragX:null}}(e,t._index,t._displayindex,t.label,m)}));for(x=0;x<k;x++)for(d=p[x%p.length],_=0;_<I.length;_++){var P=I[_].containerInd,z=g[_].inds[x],O=I[_].categories;if(void 0===O[z]){var D=e.dimensions[P]._categoryarray[z],R=e.dimensions[P]._ticktext[z];O[z]={dimensionInd:_,categoryInd:L=z,categoryValue:D,displayInd:L,categoryLabel:R,valueInds:[],count:0,dragY:null}}u(O[z],x,d)}return n(function(t,e,r){var n=t.map((function(t){return t.categories.length})).reduce((function(t,e){return Math.max(t,e)}));return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(I,A,m))}},62651:function(t,e,r){\"use strict\";var n=r(34809),i=r(65477).hasColorscale,a=r(39356),o=r(13792).N,s=r(59008),l=r(11660),c=r(63197),u=r(87800).isTypedArraySpec;function h(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=n.isArrayOrTypedArray(s)&&s.length>0||u(s);c&&(o=\"array\");var h=r(\"categoryorder\",o);\"array\"===h?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==h||(e.categoryorder=\"trace\")}}t.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:h}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,u,f);o(e,u,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var m=u.font;n.coerceFont(f,\"labelfont\",m,{overrideDflt:{size:Math.round(m.size)}}),n.coerceFont(f,\"tickfont\",m,{autoShadowDflt:!0,overrideDflt:{size:Math.round(m.size/1.2)}})}},6305:function(t,e,r){\"use strict\";t.exports={attributes:r(11660),supplyDefaults:r(62651),calc:r(95564),plot:r(37822),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:r(83260),categories:[\"noOpacity\"],meta:{}}},27219:function(t,e,r){\"use strict\";var n=r(45568),i=r(88640).Dj,a=r(31420),o=r(32141),s=r(34809),l=s.strTranslate,c=r(62203),u=r(65657),h=r(30635);function f(t,e,r,i){var a=e._context.staticPlot,o=t.map(F.bind(0,e,r)),u=i.selectAll(\"g.parcatslayer\").data([null]);u.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",a?\"none\":\"all\");var f=u.selectAll(\"g.trace.parcats\").data(o,p),v=f.enter().append(\"g\").attr(\"class\",\"trace parcats\");f.attr(\"transform\",(function(t){return l(t.x,t.y)})),v.append(\"g\").attr(\"class\",\"paths\");var x=f.select(\"g.paths\").selectAll(\"path.path\").data((function(t){return t.paths}),p);x.attr(\"fill\",(function(t){return t.model.color}));var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",0);b(w),x.attr(\"d\",(function(t){return t.svgD})),w.empty()||x.sort(m),x.exit().remove(),x.on(\"mouseover\",g).on(\"mouseout\",y).on(\"click\",_),v.append(\"g\").attr(\"class\",\"dimensions\");var A=f.select(\"g.dimensions\").selectAll(\"g.dimension\").data((function(t){return t.dimensions}),p);A.enter().append(\"g\").attr(\"class\",\"dimension\"),A.attr(\"transform\",(function(t){return l(t.x,0)})),A.exit().remove();var M=A.selectAll(\"g.category\").data((function(t){return t.categories}),p),S=M.enter().append(\"g\").attr(\"class\",\"category\");M.attr(\"transform\",(function(t){return l(0,t.y)})),S.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),M.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),T(S);var E=M.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),p);E.each((function(){s.raiseToTop(this)})),E.attr(\"fill\",(function(t){return t.color}));var O=E.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);E.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})).attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"})),k(O),E.exit().remove(),S.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\"),M.select(\"text.catlabel\").attr(\"text-anchor\",(function(t){return d(t)?\"start\":\"end\"})).attr(\"alignment-baseline\",\"middle\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",(function(t){return d(t)?t.width+5:-5})).attr(\"y\",(function(t){return t.height/2})).text((function(t){return t.model.categoryLabel})).each((function(t){c.font(n.select(this),t.parcatsViewModel.categorylabelfont),h.convertToTspans(n.select(this),e)})),S.append(\"text\").attr(\"class\",\"dimlabel\"),M.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"})).attr(\"x\",(function(t){return t.width/2})).attr(\"y\",-5).text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})).each((function(t){c.font(n.select(this),t.parcatsViewModel.labelfont)})),M.selectAll(\"rect.bandrect\").on(\"mouseover\",C).on(\"mouseout\",L),M.exit().remove(),A.call(n.behavior.drag().origin((function(t){return{x:t.x,y:0}})).on(\"dragstart\",I).on(\"drag\",P).on(\"dragend\",z)),f.each((function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")})),f.exit().remove()}function p(t){return t.key}function d(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function m(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function g(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){s.raiseToTop(this),w(n.select(this));var e=v(t),r=x(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var i,a,l,c=n.mouse(this)[0],h=t.parcatsViewModel.graphDiv,f=t.parcatsViewModel.trace,p=h._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),m=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(l=0;l<t.leftXs.length-1;l++)if(t.leftXs[l]+t.dimWidths[l]-2<=c&&c<=t.leftXs[l+1]+2){var g=t.parcatsViewModel.dimensions[l],y=t.parcatsViewModel.dimensions[l+1];i=(g.x+g.width+y.x)/2,a=(t.topYs[l]+t.topYs[l+1]+t.height)/2;break}var _=t.parcatsViewModel.x+i,b=t.parcatsViewModel.y+a,T=u.mostReadable(t.model.color,[\"black\",\"white\"]),k=t.model.count,A=k/t.parcatsViewModel.model.count,M={countLabel:k,probabilityLabel:A.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&S.push([\"Count:\",M.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&S.push([\"P:\",M.probabilityLabel].join(\" \"));var E=S.join(\"<br>\"),C=n.mouse(h)[0];o.loneHover({trace:f,x:_-d.left+m.left,y:b-d.top+m.top,text:E,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:T,idealAlign:C<_?\"right\":\"left\",hovertemplate:(f.line||{}).hovertemplate,hovertemplateLabels:M,eventData:[{data:f._input,fullData:f,count:k,probability:A}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:h})}}}function y(t){if(!t.parcatsViewModel.dragDimension&&(b(n.select(this)),o.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(m),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t),r=x(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=O(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function x(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var i=r[n],a=i.categories[t.model.categoryInds[n]];e[i.containerInd]=a.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function _(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t),r=x(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event,constraints:r})}}function b(t){t.attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function w(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",(function(t){return u.mostReadable(t.model.color,[\"black\",\"white\"])})).attr(\"stroke-width\",.3)}function T(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function k(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function A(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter((function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color}))}function M(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll(\"rect.bandrect\"),l=[];s.each((function(t){A(t).each((function(t){Array.prototype.push.apply(l,v(t))}))}));var c={};c[a.dimensionInd]=a.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function S(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=A(i),l=[];s.each((function(t){Array.prototype.push.apply(l,v(t))}));var c={};c[a.dimensionInd]=a.categoryValue,void 0!==i.rawColor&&(c.color=i.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function E(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=n.select(r.parentNode).select(\"rect.catrect\"),c=l.node().getBoundingClientRect(),u=l.datum(),h=u.parcatsViewModel,f=h.model.dimensions[u.model.dimensionInd],p=h.trace,d=c.top+c.height/2;h.dimensions.length>1&&f.displayInd===h.dimensions.length-1?(i=c.left,a=\"left\"):(i=c.left+c.width,a=\"right\");var m=u.model.count,g=u.model.categoryLabel,y=m/u.parcatsViewModel.model.count,v={countLabel:m,categoryLabel:g,probabilityLabel:y.toFixed(3)},x=[];-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&x.push([\"Count:\",v.countLabel].join(\" \")),-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&x.push([\"P(\"+v.categoryLabel+\"):\",v.probabilityLabel].join(\" \"));var _=x.join(\"<br>\");return{trace:p,x:o*(i-e.left),y:s*(d-e.top),text:_,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:a,hovertemplate:p.hovertemplate,hovertemplateLabels:v,eventData:[{data:p._input,fullData:p,count:m,category:g,probability:y}]}}function C(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,a=i._paperdiv.node().getBoundingClientRect(),l=t.parcatsViewModel.hoveron,c=this;\"color\"===l?(function(t){var e=n.select(t).datum(),r=A(e);w(r),r.each((function(){s.raiseToTop(this)})),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter((function(t){return t.color===e.color})).each((function(){s.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)}))}(c),S(c,\"plotly_hover\",n.event)):(function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each((function(t){var e=A(t);w(e),e.each((function(){s.raiseToTop(this)}))})),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(c),M(c,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")&&(\"category\"===l?e=E(r,a,c):\"color\"===l?e=function(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=r.getBoundingClientRect(),c=n.select(r).datum(),h=c.categoryViewModel,f=h.parcatsViewModel,p=f.model.dimensions[h.model.dimensionInd],d=f.trace,m=l.y+l.height/2;f.dimensions.length>1&&p.displayInd===f.dimensions.length-1?(i=l.left,a=\"left\"):(i=l.left+l.width,a=\"right\");var g=h.model.categoryLabel,y=c.parcatsViewModel.model.count,v=0;c.categoryViewModel.bands.forEach((function(t){t.color===c.color&&(v+=t.count)}));var x=h.model.count,_=0;f.pathSelection.each((function(t){t.model.color===c.color&&(_+=t.model.count)}));var b=v/y,w=v/_,T=v/x,k={countLabel:v,categoryLabel:g,probabilityLabel:b.toFixed(3)},A=[];-1!==h.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",k.countLabel].join(\" \")),-1!==h.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(A.push(\"P(color \u2229 \"+g+\"): \"+k.probabilityLabel),A.push(\"P(\"+g+\" | color): \"+w.toFixed(3)),A.push(\"P(color | \"+g+\"): \"+T.toFixed(3)));var M=A.join(\"<br>\"),S=u.mostReadable(c.color,[\"black\",\"white\"]);return{trace:d,x:o*(i-e.left),y:s*(m-e.top),text:M,color:c.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:S,fontSize:10,idealAlign:a,hovertemplate:d.hovertemplate,hovertemplateLabels:k,eventData:[{data:d._input,fullData:d,category:g,count:y,probability:b,categorycount:x,colorcount:_,bandcolorcount:v}]}}(r,a,c):\"dimension\"===l&&(e=function(t,e,r){var i=[];return n.select(r.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each((function(){i.push(E(t,e,this))})),i}(r,a,c)),e&&o.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r}))}}function L(t){var e=t.parcatsViewModel;e.dragDimension||(b(e.pathSelection),T(e.dimensionSelection.selectAll(\"g.category\")),k(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),o.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(m),-1!==e.hoverinfoItems.indexOf(\"skip\"))||(\"color\"===t.parcatsViewModel.hoveron?S(this,\"plotly_unhover\",n.event):M(this,\"plotly_unhover\",n.event))}function I(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each((function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map((function(t){return t.displayInd})),e.model.dragY=e.y,s.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each((function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)})))})),t.parcatsViewModel.dragDimension=t,o.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function P(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}j(t.parcatsViewModel),N(t.parcatsViewModel),R(t.parcatsViewModel),D(t.parcatsViewModel)}}function z(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=O(t.parcatsViewModel),i=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),o=t.initialDragDimensionDisplayInds.some((function(t,e){return t!==i[e]}));o&&i.forEach((function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r}));var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map((function(t){return t.displayInd}));if(s=t.initialDragCategoryDisplayInds.some((function(t,e){return t!==l[e]}))){var c=t.model.categories.slice().sort((function(t,e){return t.displayInd-e.displayInd})),u=c.map((function(t){return t.categoryValue})),h=c.map((function(t){return t.categoryLabel}));e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?S(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd&&(t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null),t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,j(t.parcatsViewModel),N(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each((function(){R(t.parcatsViewModel,!0),D(t.parcatsViewModel,!0)})).each(\"end\",(function(){(o||s)&&a.restyle(t.parcatsViewModel.graphDiv,e,[r])}))}}function O(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function D(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data((function(t){return t.paths}),p),(r=t.pathSelection,e?r.transition():r).attr(\"d\",(function(t){return t.svgD}))}function R(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data((function(t){return t.dimensions}),p);var i=t.dimensionSelection.selectAll(\"g.category\").data((function(t){return t.categories}),p);r(t.dimensionSelection).attr(\"transform\",(function(t){return l(t.x,0)})),r(i).attr(\"transform\",(function(t){return l(0,t.y)})),i.select(\".dimlabel\").text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})),i.select(\".catlabel\").attr(\"text-anchor\",(function(t){return d(t)?\"start\":\"end\"})).attr(\"x\",(function(t){return d(t)?t.width+5:-5})).each((function(t){var e,r;d(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)}));var a=i.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),p),o=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);a.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})),k(o),a.each((function(){s.raiseToTop(this)})),a.exit().remove()}function F(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var m={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};return i.dimensions&&(j(m),N(m)),m}function B(t,e,r,n,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=i(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+n+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+n)+\" \"+l[s]+\",\"+(e[s]+n)+\" \"+(t[s]+r[s])+\",\"+(e[s]+n),u+=\"l-\"+r[s]+\",0 \";return u+\"Z\"}function N(t){var e=t.dimensions,r=t.model,n=e.map((function(t){return t.categories.map((function(t){return t.y}))})),i=t.model.dimensions.map((function(t){return t.categories.map((function(t){return t.displayInd}))})),a=t.model.dimensions.map((function(t){return t.displayInd})),o=t.dimensions.map((function(t){return t.model.dimensionInd})),s=e.map((function(t){return t.x})),l=e.map((function(t){return t.width})),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map((function(t,e){return i[e][t]}));return o.map((function(t){return e[t]}))}c.sort((function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0}));for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map((function(t){return t.height})).reduce((function(t,e){return t+e})),m=0;m<c.length;m++){var g,y=c[m];g=p>0?d*(y.count/p):0;for(var v,x=new Array(n.length),_=0;_<y.categoryInds.length;_++){var b=y.categoryInds[_],w=i[_][b],T=a[_];x[T]=n[T][w],n[T][w]+=g;var k=t.dimensions[T].categories[w],A=k.bands.length,M=k.bands[A-1];if(void 0===M||y.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;k.bands.push({key:S,color:y.color,rawColor:y.rawColor,height:g,width:k.width,count:y.count,y:S,categoryViewModel:k,parcatsViewModel:t})}else{var E=k.bands[A-1];E.height+=g,E.count+=y.count}}v=\"hspline\"===t.pathShape?B(s,x,l,g,.5):B(s,x,l,g,0),f[m]={key:y.valueInds[0],model:y,height:g,leftXs:s,topYs:x,dimWidths:l,svgD:v,parcatsViewModel:t}}t.paths=f}function j(t){var e=t.model.dimensions.map((function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}}));e.sort((function(t,e){return t.displayInd-e.displayInd}));var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(U(t,a))}t.dimensions=r}function U(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),m=8*(h-f)/2,g=e.categories.map((function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}}));for(g.sort((function(t,e){return t.displayInd-e.displayInd})),c=0;c<f;c++)l=g[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:m,bands:[],parcatsViewModel:t},m=m+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}t.exports=function(t,e,r,n){f(r,t,n,e)}},37822:function(t,e,r){\"use strict\";var n=r(27219);t.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},59549:function(t,e,r){\"use strict\";var n=r(87163),i=r(25829),a=r(80337),o=r(13792).u,s=r(93049).extendFlat,l=r(78032).templatedArray;t.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({autoShadowDflt:!0,editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"})),unselected:{line:{color:{valType:\"color\",dflt:\"#7f7f7f\",editType:\"plot\"},opacity:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"plot\"},editType:\"plot\"},editType:\"plot\"}}},23245:function(t,e,r){\"use strict\";var n=r(77911),i=r(45568),a=r(71293).keyFun,o=r(71293).repeat,s=r(34809).sorterAsc,l=r(34809).strTranslate,c=n.bar.snapRatio;function u(t,e){return t*(1-c)+e*c}var h=n.bar.snapClose;function f(t,e){return t*(1-h)+e*h}function p(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],c=l,h=a;i*h<i*o;h+=i){var p=h+i,d=e[p];if(i*r<i*f(l,d))return u(l,c);if(i*r<i*d||p===o)return u(d,l);c=l,l=d}}function d(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function m(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=y(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function y(t,e){return t.map((function(t){return t.map((function(t){return Math.max(0,t*e)})).sort(s)}))}function v(){i.select(document.body).style(\"cursor\",null)}function x(t){t.attr(\"stroke-dasharray\",g)}function _(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");x(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=y(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],m=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);m&&(o.interval=l[a],o.intervalPix=d,o.region=m)}}if(t.ordinal&&!o.region){var g=t.unitTickvals,v=t.unitToPaddedPx.invert(e);for(r=0;r<g.length;r++){var x=[.25*g[Math.max(r-1,0)]+.75*g[r],.25*g[Math.min(r+1,g.length-1)]+.75*g[r]];if(v>=x[0]&&v<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function w(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),_(t.parentNode)}function T(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",(function(t){i.event.preventDefault(),t.parent.inBrushDrag||T(this,t)})).on(\"mouseleave\",(function(t){t.parent.inBrushDrag||v()})).call(i.behavior.drag().on(\"dragstart\",(function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter((function(t){return t[0]!==l[0]&&t[1]!==l[1]}))),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)})).on(\"drag\",(function(t){w(this,t)})).on(\"dragend\",(function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(T(t,e),w(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,v(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&M(r)):M(r),a.brushCallback(e),_(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[p(0,l,a.newExtent[0],a.stayingIntervals),p(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||M(r),a.brushCallback(e),c?_(t.parentNode,s):(s(),_(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)})))}function A(t,e){return t[0]-e[0]}function M(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function S(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return 1===n.length&&n[0][0]>n[0][1]&&(n=[]),n}t.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map((function(t){return t.slice().sort(s)})).sort(A)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=S(r),e=r.reduce((function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]}),[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map((function(t){return t.slice()}))}(e),n=r.slice();e.filter.set(n),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t,e,r){var i=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);i.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t,e,r){var i=r._context.staticPlot,a=t.selectAll(\".background\").data(o);a.enter().append(\"rect\").classed(\"background\",!0).call(d).call(m).style(\"pointer-events\",i?\"none\":\"auto\").attr(\"transform\",l(0,n.verticalPadding)),a.call(k).attr(\"height\",(function(t){return t.height-n.verticalPadding}));var s=t.selectAll(\".highlight-shadow\").data(o);s.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",e).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),s.attr(\"y1\",(function(t){return t.height})).call(x);var c=t.selectAll(\".highlight\").data(o);c.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),c.attr(\"y1\",(function(t){return t.height})).call(x)}(i,e,r)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map((function(t){return t.sort(s)})),t=e.multiselect?S(t.sort(A)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map((function(t){var e=[p(0,r,t[0],[]),p(1,r,t[1],[])];if(e[1]>e[0])return e})).filter((function(t){return t}))).length)return}return t.length>1?t:t[0]}}},79846:function(t,e,r){\"use strict\";t.exports={attributes:r(59549),supplyDefaults:r(12842),calc:r(20113),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:r(67207),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},67207:function(t,e,r){\"use strict\";var n=r(45568),i=r(4173).eV,a=r(58823),o=r(62972);e.name=\"parcoords\",e.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},e.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},e.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this,r=t.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":r,preserveAspectRatio:\"none\",x:0,y:0,width:t.style.width,height:t.style.height})})),window.setTimeout((function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")}),60)}},20113:function(t,e,r){\"use strict\";var n=r(34809).isArrayOrTypedArray,i=r(88856),a=r(71293).wrap;t.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},77911:function(t){\"use strict\";t.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},12842:function(t,e,r){\"use strict\";var n=r(34809),i=r(65477).hasColorscale,a=r(39356),o=r(13792).N,s=r(59008),l=r(29714),c=r(59549),u=r(23245),h=r(77911).maxDimensionCount,f=r(63197);function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}t.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var m=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),g=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(m)&&m.length||(e.visible=!1),f(e,m,\"values\",g);var y=n.extendFlat({},l.font,{size:Math.round(l.font.size/1.2)});n.coerceFont(u,\"labelfont\",y),n.coerceFont(u,\"tickfont\",y,{autoShadowDflt:!0}),n.coerceFont(u,\"rangefont\",y),u(\"labelangle\"),u(\"labelside\"),u(\"unselected.line.color\"),u(\"unselected.line.opacity\")}},62935:function(t,e,r){\"use strict\";var n=r(34809).isTypedArray;e.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},e.isOrdinal=function(t){return!!t.tickvals},e.isVisible=function(t){return t.visible||!(\"visible\"in t)}},83910:function(t,e,r){\"use strict\";var n=r(79846);n.plot=r(58823),t.exports=n},1293:function(t,e,r){\"use strict\";var n=[\"precision highp float;\",\"\",\"varying vec4 fragColor;\",\"\",\"attribute vec4 p01_04, p05_08, p09_12, p13_16,\",\"               p17_20, p21_24, p25_28, p29_32,\",\"               p33_36, p37_40, p41_44, p45_48,\",\"               p49_52, p53_56, p57_60, colors;\",\"\",\"uniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\",\"             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\",\"\",\"uniform vec2 resolution, viewBoxPos, viewBoxSize;\",\"uniform float maskHeight;\",\"uniform float drwLayer; // 0: context, 1: focus, 2: pick\",\"uniform vec4 contextColor;\",\"uniform sampler2D maskTexture, palette;\",\"\",\"bool isPick    = (drwLayer > 1.5);\",\"bool isContext = (drwLayer < 0.5);\",\"\",\"const vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\",\"const vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\",\"\",\"float val(mat4 p, mat4 v) {\",\"    return dot(matrixCompMult(p, v) * UNITS, UNITS);\",\"}\",\"\",\"float axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\",\"    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\",\"    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\",\"    return y1 * (1.0 - ratio) + y2 * ratio;\",\"}\",\"\",\"int iMod(int a, int b) {\",\"    return a - b * (a / b);\",\"}\",\"\",\"bool fOutside(float p, float lo, float hi) {\",\"    return (lo < hi) && (lo > p || p > hi);\",\"}\",\"\",\"bool vOutside(vec4 p, vec4 lo, vec4 hi) {\",\"    return (\",\"        fOutside(p[0], lo[0], hi[0]) ||\",\"        fOutside(p[1], lo[1], hi[1]) ||\",\"        fOutside(p[2], lo[2], hi[2]) ||\",\"        fOutside(p[3], lo[3], hi[3])\",\"    );\",\"}\",\"\",\"bool mOutside(mat4 p, mat4 lo, mat4 hi) {\",\"    return (\",\"        vOutside(p[0], lo[0], hi[0]) ||\",\"        vOutside(p[1], lo[1], hi[1]) ||\",\"        vOutside(p[2], lo[2], hi[2]) ||\",\"        vOutside(p[3], lo[3], hi[3])\",\"    );\",\"}\",\"\",\"bool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\",\"    return mOutside(A, loA, hiA) ||\",\"           mOutside(B, loB, hiB) ||\",\"           mOutside(C, loC, hiC) ||\",\"           mOutside(D, loD, hiD);\",\"}\",\"\",\"bool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\",\"    mat4 pnts[4];\",\"    pnts[0] = A;\",\"    pnts[1] = B;\",\"    pnts[2] = C;\",\"    pnts[3] = D;\",\"\",\"    for(int i = 0; i < 4; ++i) {\",\"        for(int j = 0; j < 4; ++j) {\",\"            for(int k = 0; k < 4; ++k) {\",\"                if(0 == iMod(\",\"                    int(255.0 * texture2D(maskTexture,\",\"                        vec2(\",\"                            (float(i * 2 + j / 2) + 0.5) / 8.0,\",\"                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\",\"                        ))[3]\",\"                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\",\"                    2\",\"                )) return true;\",\"            }\",\"        }\",\"    }\",\"    return false;\",\"}\",\"\",\"vec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\",\"    float x = 0.5 * sign(v) + 0.5;\",\"    float y = axisY(x, A, B, C, D);\",\"    float z = 1.0 - abs(v);\",\"\",\"    z += isContext ? 0.0 : 2.0 * float(\",\"        outsideBoundingBox(A, B, C, D) ||\",\"        outsideRasterMask(A, B, C, D)\",\"    );\",\"\",\"    return vec4(\",\"        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\",\"        z,\",\"        1.0\",\"    );\",\"}\",\"\",\"void main() {\",\"    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\",\"    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\",\"    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\",\"    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\",\"\",\"    float v = colors[3];\",\"\",\"    gl_Position = position(isContext, v, A, B, C, D);\",\"\",\"    fragColor =\",\"        isContext ? vec4(contextColor) :\",\"        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\",\"}\"].join(\"\\n\"),i=[\"precision highp float;\",\"\",\"varying vec4 fragColor;\",\"\",\"void main() {\",\"    gl_FragColor = fragColor;\",\"}\"].join(\"\\n\"),a=r(77911).maxDimensionCount,o=r(34809),s=1e-6,l=new Uint8Array(4),c=new Uint8Array(4),u={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function h(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function f(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(function(t){t.read({x:0,y:0,width:1,height:1,data:l})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],h(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame((function(){s(l+1)}))),r.drawCompleted=!1)}(0)}function p(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function d(t,e){return(t>>>8*e)%256/255}function m(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function g(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<a?\"p\"+g(t+1)+\"_\"+g(t+4):\"colors\"}function v(t,e,r,n,i,a,s,l,c,u,h,f,p,d){for(var m=[[],[]],g=0;g<64;g++)m[0][g]=g===i?1:0,m[1][g]=g===a?1:0;s*=d,l*=d,c*=d,u*=d;var y=t.lines.canvasOverdrag*d,v=t.domain,x=t.canvasWidth*d,_=t.canvasHeight*d,b=t.pad.l*d,w=t.pad.b*d,T=t.layoutHeight*d,k=t.layoutWidth*d,A=t.deselectedLines.color,M=t.deselectedLines.opacity;return o.extendFlat({key:h,resolution:[x,_],viewBoxPos:[s+y,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:m[0].slice(0,16),dim0B:m[0].slice(16,32),dim0C:m[0].slice(32,48),dim0D:m[0].slice(48,64),dim1A:m[1].slice(0,16),dim1B:m[1].slice(16,32),dim1C:m[1].slice(32,48),dim1D:m[1].slice(48,64),drwLayer:f,contextColor:[A[0]/255,A[1]/255,A[2]/255,\"auto\"!==M?A[3]*M:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:s+y)+(b-y)+k*v.x[0],scissorWidth:(n===r?x-s+y:c+.5)+(n===e?s+y:0),scissorY:l+w+T*v.y[0],scissorHeight:u,viewportX:b-y+k*v.x[0],viewportY:w+T*v.y[0],viewportWidth:x,viewportHeight:_},p)}function x(t){var e=2047,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}t.exports=function(t,e){var r,l,g,_,b,w=e.context,T=e.pick,k=e.regl,A=k._gl,M=A.getParameter(A.ALIASED_LINE_WIDTH_RANGE),S=Math.max(M[0],Math.min(M[1],e.viewModel.plotGlPixelRatio)),E={currentRafs:{},drawCompleted:!0,clearOnly:!1},C=function(t){for(var e={},r=0;r<=a;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(k),L=k.texture(u),I=[];z(e);var P=k({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:k.prop(\"scissorX\"),y:k.prop(\"scissorY\"),width:k.prop(\"scissorWidth\"),height:k.prop(\"scissorHeight\")}},viewport:{x:k.prop(\"viewportX\"),y:k.prop(\"viewportY\"),width:k.prop(\"viewportWidth\"),height:k.prop(\"viewportHeight\")},dither:!1,vert:n,frag:i,primitive:\"lines\",lineWidth:S,attributes:C,uniforms:{resolution:k.prop(\"resolution\"),viewBoxPos:k.prop(\"viewBoxPos\"),viewBoxSize:k.prop(\"viewBoxSize\"),dim0A:k.prop(\"dim0A\"),dim1A:k.prop(\"dim1A\"),dim0B:k.prop(\"dim0B\"),dim1B:k.prop(\"dim1B\"),dim0C:k.prop(\"dim0C\"),dim1C:k.prop(\"dim1C\"),dim0D:k.prop(\"dim0D\"),dim1D:k.prop(\"dim1D\"),loA:k.prop(\"loA\"),hiA:k.prop(\"hiA\"),loB:k.prop(\"loB\"),hiB:k.prop(\"hiB\"),loC:k.prop(\"loC\"),hiC:k.prop(\"hiC\"),loD:k.prop(\"loD\"),hiD:k.prop(\"hiD\"),palette:L,contextColor:k.prop(\"contextColor\"),maskTexture:k.prop(\"maskTexture\"),drwLayer:k.prop(\"drwLayer\"),maskHeight:k.prop(\"maskHeight\")},offset:k.prop(\"offset\"),count:k.prop(\"count\")});function z(t){r=t.model,l=t.viewModel,g=l.dimensions.slice(),_=g[0]?g[0].values.length:0;var e=r.lines,n=T?e.color.map((function(t,r){return r/e.color.length})):e.color,i=function(t,e,r){for(var n,i=new Array(t*(a+4)),o=0,l=0;l<t;l++){for(var c=0;c<a;c++)i[o++]=c<e.length?e[c].paddedUnitValues[l]:.5;i[o++]=d(l,2),i[o++]=d(l,1),i[o++]=d(l,0),i[o++]=(n=r[l],Math.max(s,Math.min(.999999,n)))}return i}(_,g,n);!function(t,e,r){for(var n=0;n<=a;n+=4)t[y(n)](m(n/4,e,r))}(C,_,i),w||T||(L=k.texture(o.extendFlat({data:p(r.unitToColor,255)},u)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,c=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>c&&(c=t[i].dim1.canvasX,o=i);0===s&&h(k,0,0,r.canvasWidth,r.canvasHeight);var u=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<g.length?g[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=new Array(16384);for(e=0;e<16384;e++)o[e]=255;if(!t)for(e=0;e<g.length;e++){var s=e%8,l=(e-s)/8,c=Math.pow(2,s),u=g[e].brush.filter.get();if(!(u.length<2)){var h=x(u[0])[1];for(r=1;r<u.length;r++){var f=x(u[r]);for(n=h+1;n<f[0];n++)o[8*n+l]&=~c;h=Math.max(h,f[1])}}}var p={shape:[8,2048],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:o};return b?b(p):b=k.texture(p),{maskTexture:b,maskHeight:2048,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var p=t[i],d=p.dim0.crossfilterDimensionIndex,m=p.dim1.crossfilterDimensionIndex,y=p.canvasX,A=p.canvasY,M=y+p.panelSizeX,S=p.plotGlPixelRatio;if(e||!I[d]||I[d][0]!==y||I[d][1]!==M){I[d]=[y,M];var C=v(r,a,o,i,d,m,y,A,p.panelSizeX,p.panelSizeY,p.dim0.crossfilterDimensionIndex,w?0:T?2:1,u,S);E.clearOnly=n;var L=e?r.lines.blockLineCount:_;f(k,P,E,L,_,C)}}},readPixel:function(t,e){return k.read({x:t,y:e,width:1,height:1,data:c}),c},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return k.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",L.destroy(),b&&b.destroy(),C)C[e].destroy()},update:z}}},63197:function(t){\"use strict\";t.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},16019:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=i.isArrayOrTypedArray,o=i.numberFormat,s=r(16401),l=r(29714),c=i.strRotate,u=i.strTranslate,h=r(30635),f=r(62203),p=r(88856),d=r(71293),m=d.keyFun,g=d.repeat,y=d.unwrap,v=r(62935),x=r(77911),_=r(23245),b=r(1293);function w(t,e,r){return i.aggNums(t,null,e,r)}function T(t,e){return A(w(Math.min,t,e),w(Math.max,t,e))}function k(t){var e=t.range;return e?A(e[0],e[1]):T(t.values,t._length)}function A(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function M(t,e,r,i,a){var s,l,c=k(r);return i?n.scale.ordinal().domain(i.map((s=o(r.tickformat),l=a,l?function(t,e){var r=l[e];return null==r?s(t):r}:s))).range(i.map((function(r){var n=(r-c[0])/(c[1]-c[0]);return t-e+n*(2*e-t)}))):n.scale.linear().domain(c).range([t-e,e])}function S(t){if(t.tickvals){var e=k(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map((function(t){return(t-e[0])/(e[1]-e[0])})))}}function E(t){var e=t.map((function(t){return t[0]})),r=t.map((function(t){var e=s(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")})),i=\"rgb\".split(\"\").map((function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i}));return function(t){return i.map((function(e){return e(t)}))}}function C(t){return t.dimensions.some((function(t){return t.brush.filterSpecified}))}function L(t,e,r){var a=y(e),o=a.trace,l=v.convertTypedArray(a.lineColor),c=o.line,u={color:s(o.unselected.line.color),opacity:o.unselected.line.opacity},h=p.extractOpts(c),f=h.reversescale?p.flipScale(a.cscale):a.cscale,d=o.domain,m=o.dimensions,g=t.width,_=o.labelangle,b=o.labelside,w=o.labelfont,T=o.tickfont,A=o.rangefont,M=i.extendDeepNoArrays({},c,{color:l.map(n.scale.linear().domain(k({values:l,range:[h.min,h.max],_length:o._length}))),blockLineCount:x.blockLineCount,canvasOverdrag:x.overdrag*x.canvasPixelRatio}),S=Math.floor(g*(d.x[1]-d.x[0])),C=Math.floor(t.height*(d.y[1]-d.y[0])),L=t.margin||{l:80,r:80,t:100,b:80},I=S,P=C;return{key:r,colCount:m.filter(v.isVisible).length,dimensions:m,tickDistance:x.tickDistance,unitToColor:E(f),lines:M,deselectedLines:u,labelAngle:_,labelSide:b,labelFont:w,tickFont:T,rangeFont:A,layoutWidth:g,layoutHeight:t.height,domain:d,translateX:d.x[0]*g,translateY:t.height-d.y[1]*t.height,pad:L,canvasWidth:I*x.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*x.canvasPixelRatio,width:I,height:P,canvasPixelRatio:x.canvasPixelRatio}}function I(t,e,r){var s=r.width,l=r.height,c=r.dimensions,u=r.canvasPixelRatio,h=function(t){return s*t/Math.max(1,r.colCount-1)},f=x.verticalPadding/l,p=function(t,e){return n.scale.linear().range([e,t-e])}(l,x.verticalPadding),d={key:r.key,xScale:h,model:r,inBrushDrag:!1},m={};return d.dimensions=c.filter(v.isVisible).map((function(s,c){var g=function(t,e){return n.scale.linear().domain(k(t)).range([e,1-e])}(s,f),y=m[s.label];m[s.label]=(y||0)+1;var b=s.label+(y?\"__\"+y:\"\"),w=s.constraintrange,T=w&&w.length;T&&!a(w[0])&&(w=[w]);var A=T?w.map((function(t){return t.map(g)})):[[-1/0,1/0]],E=s.values;E.length>s._length&&(E=E.slice(0,s._length));var L,I=s.tickvals;function P(t,e){return{val:t,text:L[e]}}function z(t,e){return t.val-e.val}if(a(I)&&I.length){i.isTypedArray(I)&&(I=Array.from(I)),L=s.ticktext,a(L)&&L.length?L.length>I.length?L=L.slice(0,I.length):I.length>L.length&&(I=I.slice(0,L.length)):L=I.map(o(s.tickformat));for(var O=1;O<I.length;O++)if(I[O]<I[O-1]){for(var D=I.map(P).sort(z),R=0;R<I.length;R++)I[R]=D[R].val,L[R]=D[R].text;break}}else I=void 0;return E=v.convertTypedArray(E),{key:b,label:s.label,tickFormat:s.tickformat,tickvals:I,ticktext:L,ordinal:v.isOrdinal(s),multiselect:s.multiselect,xIndex:c,crossfilterDimensionIndex:c,visibleIndex:s._index,height:l,values:E,paddedUnitValues:E.map(g),unitTickvals:I&&I.map(g),xScale:h,x:h(c),canvasX:h(c)*u,unitToPaddedPx:p,domainScale:M(l,x.verticalPadding,s,I,L),ordinalScale:S(s),parent:d,model:r,brush:_.makeBrush(t,T,A,(function(){t.linePickActive(!1)}),(function(){var e=d;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=C(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))}),(function(r){if(d.focusLayer.render(d.panels,!0),d.pickLayer&&d.pickLayer.render(d.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=g.invert,a=r.map((function(t){return t.map(n).sort(i.sorterAsc)})).sort((function(t,e){return t[0]-e[0]}));e.filterChanged(d.key,s._index,a)}}))}})),d}function P(t){t.classed(x.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\")}function z(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function O(t,e,r){for(var n=e.panels||(e.panels=[]),i=t.data(),a=0;a<i.length-1;a++){var o=n[a]||(n[a]={}),s=i[a],l=i[a+1];o.dim0=s,o.dim1=l,o.canvasX=s.canvasX,o.panelSizeX=l.canvasX-s.canvasX,o.panelSizeY=e.model.canvasHeight,o.y=0,o.canvasY=0,o.plotGlPixelRatio=r}}function D(t,e){return l.tickText(t._ax,e,!1).text}function R(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return D(t.model.dimensions[t.visibleIndex],n)}t.exports=function(t,e,r,a){var o=t._context.staticPlot,s=t._fullLayout,p=s._toppaper,d=s._glcontainer,w=t._context.plotGlPixelRatio,k=t._fullLayout.paper_bgcolor;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,a=0;a<i.length;a++){var o=i[a].values,s=i[a]._ax;s&&(s.range?s.range=A(s.range[0],s.range[1]):s.range=T(o,n._length),s.dtick||(s.dtick=.01*(Math.abs(s.range[1]-s.range[0])||1)),s.tickformat=i[a].tickformat,l.calcTicks(s),s.cleanRange())}}(e);var M,S,E=(M=!0,S=!1,{linePickActive:function(t){return arguments.length?M=!!t:M},contextShown:function(t){return arguments.length?S=!!t:S}}),F=e.filter((function(t){return y(t).trace.visible})).map(L.bind(0,r)).map(I.bind(0,E,a));d.each((function(t,e){return i.extendFlat(t,F[e])}));var B=d.selectAll(\".gl-canvas\").each((function(t){t.viewModel=F[0],t.viewModel.plotGlPixelRatio=w,t.viewModel.paperColor=k,t.model=t.viewModel?t.viewModel.model:null})),N=null;B.filter((function(t){return t.pick})).style(\"pointer-events\",o?\"none\":\"auto\").on(\"mousemove\",(function(t){if(E.linePickActive()&&t.lineLayer&&a&&a.hover){var e=n.event,r=this.width,i=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=i)return;var c=t.lineLayer.readPixel(s,i-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==N&&(u?a.hover(f):a.unhover&&a.unhover(f),N=h)}})),B.style(\"opacity\",(function(t){return t.pick?0:1})),p.style(\"background\",\"rgba(255, 255, 255, 0)\");var j=p.selectAll(\".\"+x.cn.parcoords).data(F,m);j.exit().remove(),j.enter().append(\"g\").classed(x.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),j.attr(\"transform\",(function(t){return u(t.model.translateX,t.model.translateY)}));var U=j.selectAll(\".\"+x.cn.parcoordsControlView).data(g,m);U.enter().append(\"g\").classed(x.cn.parcoordsControlView,!0),U.attr(\"transform\",(function(t){return u(t.model.pad.l,t.model.pad.t)}));var V=U.selectAll(\".\"+x.cn.yAxis).data((function(t){return t.dimensions}),m);V.enter().append(\"g\").classed(x.cn.yAxis,!0),U.each((function(t){O(V,t,w)})),B.each((function(t){if(t.viewModel){!t.lineLayer||a?t.lineLayer=b(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||a;t.lineLayer.render(t.viewModel.panels,e)}})),V.attr(\"transform\",(function(t){return u(t.xScale(t.xIndex),0)})),V.call(n.behavior.drag().origin((function(t){return t})).on(\"drag\",(function(t){var e=t.parent;E.linePickActive(!1),t.x=Math.max(-x.overdrag,Math.min(t.model.width+x.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,V.sort((function(t,e){return t.x-e.x})).each((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio})),O(V,e,w),V.filter((function(e){return 0!==Math.abs(t.xIndex-e.xIndex)})).attr(\"transform\",(function(t){return u(t.xScale(t.xIndex),0)})),n.select(this).attr(\"transform\",u(t.x,0)),V.each((function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!C(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)})).on(\"dragend\",(function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,O(V,e,w),n.select(this).attr(\"transform\",(function(t){return u(t.x,0)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!C(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),E.linePickActive(!0),a&&a.axesMoved&&a.axesMoved(e.key,e.dimensions.map((function(t){return t.crossfilterDimensionIndex})))}))),V.exit().remove();var q=V.selectAll(\".\"+x.cn.axisOverlays).data(g,m);q.enter().append(\"g\").classed(x.cn.axisOverlays,!0),q.selectAll(\".\"+x.cn.axis).remove();var H=q.selectAll(\".\"+x.cn.axis).data(g,m);H.enter().append(\"g\").classed(x.cn.axis,!0),H.each((function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat((function(e){return v.isOrdinal(t)?e:D(t.model.dimensions[t.visibleIndex],e)})).scale(r)),f.font(H.selectAll(\"text\"),t.model.tickFont)})),H.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),H.selectAll(\"text\").style(\"cursor\",\"default\");var G=q.selectAll(\".\"+x.cn.axisHeading).data(g,m);G.enter().append(\"g\").classed(x.cn.axisHeading,!0);var Z=G.selectAll(\".\"+x.cn.axisTitle).data(g,m);Z.enter().append(\"text\").classed(x.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"pointer-events\",o?\"none\":\"auto\"),Z.text((function(t){return t.label})).each((function(e){var r=n.select(this);f.font(r,e.model.labelFont),h.convertToTspans(r,t)})).attr(\"transform\",(function(t){var e=z(t.model.labelAngle,t.model.labelSide),r=x.axisTitleOffset;return(e.dir>0?\"\":u(0,2*r+t.model.height))+c(e.degrees)+u(-r*e.dx,-r*e.dy)})).attr(\"text-anchor\",(function(t){var e=z(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"}));var W=q.selectAll(\".\"+x.cn.axisExtent).data(g,m);W.enter().append(\"g\").classed(x.cn.axisExtent,!0);var Y=W.selectAll(\".\"+x.cn.axisExtentTop).data(g,m);Y.enter().append(\"g\").classed(x.cn.axisExtentTop,!0),Y.attr(\"transform\",u(0,-x.axisExtentOffset));var X=Y.selectAll(\".\"+x.cn.axisExtentTopText).data(g,m);X.enter().append(\"text\").classed(x.cn.axisExtentTopText,!0).call(P),X.text((function(t){return R(t,!0)})).each((function(t){f.font(n.select(this),t.model.rangeFont)}));var $=W.selectAll(\".\"+x.cn.axisExtentBottom).data(g,m);$.enter().append(\"g\").classed(x.cn.axisExtentBottom,!0),$.attr(\"transform\",(function(t){return u(0,t.model.height+x.axisExtentOffset)}));var J=$.selectAll(\".\"+x.cn.axisExtentBottomText).data(g,m);J.enter().append(\"text\").classed(x.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(P),J.text((function(t){return R(t,!1)})).each((function(t){f.font(n.select(this),t.model.rangeFont)})),_.ensureAxisBrush(q,k,t)}},58823:function(t,e,r){\"use strict\";var n=r(16019),i=r(22459),a=r(62935).isVisible,o={};function s(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}(t.exports=function(t,e){var r=t._fullLayout;if(i(t,[],o)){var l={},c={},u={},h={},f=r._size;e.forEach((function(e,r){var n=e[0].trace;u[r]=n.index;var i=h[r]=n._fullInput.index;l[r]=t.data[i].dimensions,c[r]=t.data[i].dimensions.slice()})),n(t,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{filterChanged:function(e,n,i){var a=c[e][n],o=i.map((function(t){return t.slice()})),s=\"dimensions[\"+n+\"].constraintrange\",l=r._tracePreGUI[t._fullData[u[e]]._fullInput.uid];if(void 0===l[s]){var f=a.constraintrange;l[s]=f||null}var p=t._fullData[u[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[h[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return s(t,e,r)-s(t,e,n)}}(r,c[e].filter(a));l[e].sort(n),c[e].filter((function(t){return!a(t)})).sort((function(t){return c[e].indexOf(t)})).forEach((function(t){l[e].splice(l[e].indexOf(t),1),l[e].splice(c[e].indexOf(t),0,t)})),t.emit(\"plotly_restyle\",[{dimensions:[l[e]]},[h[e]]])}})}}).reglPrecompiled=o},55412:function(t,e,r){\"use strict\";var n=r(9829),i=r(13792).u,a=r(80337),o=r(10229),s=r(3208).rb,l=r(3208).ay,c=r(93049).extendFlat,u=r(94850).k,h=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});t.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},pattern:u,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:c({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),texttemplate:l({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:c({},h,{}),insidetextorientation:{valType:\"enumerated\",values:[\"horizontal\",\"radial\",\"tangential\",\"auto\"],dflt:\"auto\",editType:\"plot\"},insidetextfont:c({},h,{}),outsidetextfont:c({},h,{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:c({},h,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:c({},h,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},96052:function(t,e,r){\"use strict\";var n=r(44122);e.name=\"pie\",e.plot=function(t,r,i,a){n.plotBasePlot(e.name,t,r,i,a)},e.clean=function(t,r,i,a){n.cleanBasePlot(e.name,t,r,i,a)}},44148:function(t,e,r){\"use strict\";var n=r(10721),i=r(65657),a=r(78766),o={};function s(t){return function(e,r){return!!e&&!!(e=i(e)).isValid()&&(e=a.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e)}}function l(t,e){var r,n=JSON.stringify(t),a=e[n];if(!a){for(a=t.slice(),r=0;r<t.length;r++)a.push(i(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)a.push(i(t[r]).darken(20).toHexString());e[n]=a}return a}t.exports={calc:function(t,e){var r,i,a=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],h=e.values,f=e._length,p=e._hasValues&&f;if(e.dlabel)for(c=new Array(f),r=0;r<f;r++)c[r]=String(e.label0+r*e.dlabel);var d={},m=s(o[\"_\"+e.type+\"colormap\"]),g=0,y=!1;for(r=0;r<f;r++){var v,x,_;if(p){if(v=h[r],!n(v))continue;v=+v}else v=1;void 0!==(x=c[r])&&\"\"!==x||(x=r);var b=d[x=String(x)];void 0===b?(d[x]=a.length,(_=-1!==l.indexOf(x))||(g+=v),a.push({v:v,label:x,color:m(u[r],x),i:r,pts:[r],hidden:_})):(y=!0,(i=a[b]).v+=v,i.pts.push(r),i.hidden||(g+=v),!1===i.color&&u[r]&&(i.color=m(u[r],x)))}return a=a.filter((function(t){return t.v>=0})),(\"funnelarea\"===e.type?y:e.sort)&&a.sort((function(t,e){return e.v-t.v})),a[0]&&(a[0].vTotal=g),a},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],s=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=l(a,o));for(var c=0,u=0;u<i.length;u++){var h=i[u];if(h[0].trace.type===r)for(var f=0;f<h.length;f++){var p=h[f];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=a[c%a.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},46979:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(55412),o=r(13792).N,s=r(17550).handleText,l=r(34809).coercePattern;function c(t,e){var r=i.isArrayOrTypedArray(t),a=i.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,a?e.length:1/0);if(isFinite(o)||(o=0),o&&a){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:a,len:o}}function u(t,e,r,n,i){n(\"marker.line.width\")&&n(\"marker.line.color\",i?void 0:r.paper_bgcolor);var a=n(\"marker.colors\");l(n,\"marker.pattern\",a),t.marker&&!e.marker.pattern.fgcolor&&(e.marker.pattern.fgcolor=t.marker.colors),e.marker.pattern.bgcolor||(e.marker.pattern.bgcolor=r.paper_bgcolor)}t.exports={handleLabelsAndValues:c,handleMarkerDefaults:u,supplyDefaults:function(t,e,r,n){function l(r,n){return i.coerce(t,e,a,r,n)}var h=c(l(\"labels\"),l(\"values\")),f=h.len;if(e._hasLabels=h.hasLabels,e._hasValues=h.hasValues,!e._hasLabels&&e._hasValues&&(l(\"label0\"),l(\"dlabel\")),f){e._length=f,u(t,e,n,l,!0),l(\"scalegroup\");var p,d=l(\"text\"),m=l(\"texttemplate\");if(m||(p=l(\"textinfo\",i.isArrayOrTypedArray(d)?\"text+percent\":\"percent\")),l(\"hovertext\"),l(\"hovertemplate\"),m||p&&\"none\"!==p){var g=l(\"textposition\");s(t,e,n,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(g)||\"auto\"===g||\"outside\"===g)&&l(\"automargin\"),(\"inside\"===g||\"auto\"===g||Array.isArray(g))&&l(\"insidetextorientation\")}else\"none\"===p&&l(\"textposition\",\"none\");o(e,n,l);var y=l(\"hole\");if(l(\"title.text\")){var v=l(\"title.position\",y?\"middle center\":\"top center\");y||\"middle center\"!==v||(e.title.position=\"top center\"),i.coerceFont(l,\"title.font\",n.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}}},50568:function(t,e,r){\"use strict\";var n=r(36040).appendArrayMultiPointValues;t.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,bbox:t.bbox,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},75067:function(t,e,r){\"use strict\";var n=r(62203),i=r(78766);t.exports=function(t,e,r,a){var o=r.marker.pattern;o&&o.shape?n.pointStyle(t,r,a,e):i.fill(t,e.color)}},37252:function(t,e,r){\"use strict\";var n=r(34809);function i(t){return-1!==t.indexOf(\"e\")?t.replace(/[.]?0+e/,\"e\"):-1!==t.indexOf(\".\")?t.replace(/[.]?0+$/,\"\"):t}e.formatPiePercent=function(t,e){var r=i((100*t).toPrecision(3));return n.numSeparate(r,e)+\"%\"},e.formatPieValue=function(t,e){var r=i(t.toPrecision(10));return n.numSeparate(r,e)},e.getFirstFilled=function(t,e){if(n.isArrayOrTypedArray(t))for(var r=0;r<e.length;r++){var i=t[e[r]];if(i||0===i||\"\"===i)return i}},e.castOption=function(t,r){return n.isArrayOrTypedArray(t)?e.getFirstFilled(t,r):t||void 0},e.getRotationAngle=function(t){return(\"auto\"===t?0:t)*Math.PI/180}},49913:function(t,e,r){\"use strict\";t.exports={attributes:r(55412),supplyDefaults:r(46979).supplyDefaults,supplyLayoutDefaults:r(13464),layoutAttributes:r(4031),calc:r(44148).calc,crossTraceCalc:r(44148).crossTraceCalc,plot:r(35734).plot,style:r(140),styleOne:r(32891),moduleType:\"trace\",name:\"pie\",basePlotModule:r(96052),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},4031:function(t){\"use strict\";t.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},13464:function(t,e,r){\"use strict\";var n=r(34809),i=r(4031);t.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},35734:function(t,e,r){\"use strict\";var n=r(45568),i=r(44122),a=r(32141),o=r(78766),s=r(62203),l=r(34809),c=l.strScale,u=l.strTranslate,h=r(30635),f=r(84102),p=f.recordMinTextSize,d=f.clearMinTextSize,m=r(56155).TEXTPAD,g=r(37252),y=r(50568),v=r(34809).isValidTextValue;function x(t,e,r){var i=r[0],o=i.cx,s=i.cy,c=i.trace,u=\"funnelarea\"===c.type;\"_hasHoverLabel\"in c||(c._hasHoverLabel=!1),\"_hasHoverEvent\"in c||(c._hasHoverEvent=!1),t.on(\"mouseover\",(function(t){var r=e._fullLayout,h=e._fullData[c.index];if(!e._dragging&&!1!==r.hovermode){var f=h.hoverinfo;if(Array.isArray(f)&&(f=a.castHoverinfo({hoverinfo:[g.castOption(f,t.pts)],_module:c._module},r,0)),\"all\"===f&&(f=\"label+text+value+percent+name\"),h.hovertemplate||\"none\"!==f&&\"skip\"!==f&&f){var p=t.rInscribed||0,d=o+t.pxmid[0]*(1-p),m=s+t.pxmid[1]*(1-p),v=r.separators,x=[];if(f&&-1!==f.indexOf(\"label\")&&x.push(t.label),t.text=g.castOption(h.hovertext||h.text,t.pts),f&&-1!==f.indexOf(\"text\")){var _=t.text;l.isValidTextValue(_)&&x.push(_)}t.value=t.v,t.valueLabel=g.formatPieValue(t.v,v),f&&-1!==f.indexOf(\"value\")&&x.push(t.valueLabel),t.percent=t.v/i.vTotal,t.percentLabel=g.formatPiePercent(t.percent,v),f&&-1!==f.indexOf(\"percent\")&&x.push(t.percentLabel);var b=h.hoverlabel,w=b.font,T=[];a.loneHover({trace:c,x0:d-p*i.r,x1:d+p*i.r,y:m,_x0:u?o+t.TL[0]:d-p*i.r,_x1:u?o+t.TR[0]:d+p*i.r,_y0:u?s+t.TL[1]:m-p*i.r,_y1:u?s+t.BL[1]:m+p*i.r,text:x.join(\"<br>\"),name:h.hovertemplate||-1!==f.indexOf(\"name\")?h.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:g.castOption(b.bgcolor,t.pts)||t.color,borderColor:g.castOption(b.bordercolor,t.pts),fontFamily:g.castOption(w.family,t.pts),fontSize:g.castOption(w.size,t.pts),fontColor:g.castOption(w.color,t.pts),nameLength:g.castOption(b.namelength,t.pts),textAlign:g.castOption(b.align,t.pts),hovertemplate:g.castOption(h.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[y(t,h)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e,inOut_bbox:T}),t.bbox=T[0],c._hasHoverLabel=!0}c._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[y(t,h)],event:n.event})}})),t.on(\"mouseout\",(function(t){var r=e._fullLayout,i=e._fullData[c.index],o=n.select(this).datum();c._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[y(o,i)],event:n.event}),c._hasHoverEvent=!1),c._hasHoverLabel&&(a.loneUnhover(r._hoverlayer.node()),c._hasHoverLabel=!1)})),t.on(\"click\",(function(t){var r=e._fullLayout,i=e._fullData[c.index];e._dragging||!1===r.hovermode||(e._hoverdata=[y(t,i)],a.click(e,n.event))}))}function _(t,e,r){var n=g.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=g.castOption(t._input.textfont.color,e.pts));var i=g.castOption(t.insidetextfont.family,e.pts)||g.castOption(t.textfont.family,e.pts)||r.family,a=g.castOption(t.insidetextfont.size,e.pts)||g.castOption(t.textfont.size,e.pts)||r.size,s=g.castOption(t.insidetextfont.weight,e.pts)||g.castOption(t.textfont.weight,e.pts)||r.weight,l=g.castOption(t.insidetextfont.style,e.pts)||g.castOption(t.textfont.style,e.pts)||r.style,c=g.castOption(t.insidetextfont.variant,e.pts)||g.castOption(t.textfont.variant,e.pts)||r.variant,u=g.castOption(t.insidetextfont.textcase,e.pts)||g.castOption(t.textfont.textcase,e.pts)||r.textcase,h=g.castOption(t.insidetextfont.lineposition,e.pts)||g.castOption(t.textfont.lineposition,e.pts)||r.lineposition,f=g.castOption(t.insidetextfont.shadow,e.pts)||g.castOption(t.textfont.shadow,e.pts)||r.shadow;return{color:n||o.contrast(e.color),family:i,size:a,weight:s,style:l,variant:c,textcase:u,lineposition:h,shadow:f}}function b(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=l.templateString(a,n._meta));var o=s.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(s.font,n.title.font).call(h.convertToTspans,e),c=s.bBox(o.node(),!0);r.titleBox={width:c.width,height:c.height},o.remove()}}function w(t,e,r){var n=r.r||e.rpx1,i=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-i,scale:0,rotate:0,textPosAngle:0};var a,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,h=\"horizontal\"===u,f=\"tangential\"===u,p=\"radial\"===u,d=\"auto\"===u,m=[];if(!d){var g,y=function(r,i){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(a=\"tan\"===i?k(t,n,o,c,0):T(t,n,o,c,Math.PI/2)).textPosAngle=r,m.push(a)}};if(h||f){for(g=4;g>=-4;g-=2)y(Math.PI*g,\"tan\");for(g=4;g>=-4;g-=2)y(Math.PI*(g+1),\"tan\")}if(h||p){for(g=4;g>=-4;g-=2)y(Math.PI*(g+1.5),\"rad\");for(g=4;g>=-4;g-=2)y(Math.PI*(g+.5),\"rad\")}}if(s||d||h){var v=Math.sqrt(t.width*t.width+t.height*t.height);if((a={scale:i*n*2/v,rCenter:1-i,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,a.scale>=1)return a;m.push(a)}(d||p)&&((a=T(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,m.push(a)),(d||f)&&((a=k(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,m.push(a));for(var x=0,_=0,b=0;b<m.length;b++){var w=m[b].scale;if(_<w&&(_=w,x=b),!d&&_>=1)break}return m[x]}function T(t,e,r,n,i){e=Math.max(0,e-2*m);var a=t.width/t.height,o=S(a,n,e,r);return{scale:2*o/t.height,rCenter:A(a,o/e),rotate:M(i)}}function k(t,e,r,n,i){e=Math.max(0,e-2*m);var a=t.height/t.width,o=S(a,n,e,r);return{scale:2*o/t.width,rCenter:A(a,o/e),rotate:M(i+Math.PI/2)}}function A(t,e){return Math.cos(e)-t*e}function M(t){return(180/Math.PI*t+720)%180-90}function S(t,e,r,n){var i=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(i*i+.5)+i),n/(Math.sqrt(t*t+n/2)+t))}function E(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function C(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function L(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=P(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c=t.r/(void 0===(l=t.trace.aspectratio)?1:l),u=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(u+=c,o.x-=(1+i)*c,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?u*=2:-1!==a.title.position.indexOf(\"right\")&&(u+=c,o.x+=(1+i)*c,s.tx-=t.titleBox.width/2),r=u/t.titleBox.width,n=I(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function I(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function P(t){var e,r=t.pull;if(!r)return 0;if(l.isArrayOrTypedArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function z(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=I(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+P(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=I(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if((i=(r=t[n][0]).trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?u=(c=r.r)/i.aspectratio:c=(u=r.r)*i.aspectratio,l=(c*=(1+i.baseratio)/2)*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if((i=(r=t[n][0]).trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}function O(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function D(t,e,r){var n=t._fullLayout,i=r.trace,a=i.texttemplate,o=i.textinfo;if(!a&&o&&\"none\"!==o){var s,c=o.split(\"+\"),u=function(t){return-1!==c.indexOf(t)},h=u(\"label\"),f=u(\"text\"),p=u(\"value\"),d=u(\"percent\"),m=n.separators;if(s=h?[e.label]:[],f){var y=g.getFirstFilled(i.text,e.pts);v(y)&&s.push(y)}p&&s.push(g.formatPieValue(e.v,m)),d&&s.push(g.formatPiePercent(e.v/r.vTotal,m)),e.text=s.join(\"<br>\")}if(a){var x=l.castOption(i,e.i,\"texttemplate\");if(x){var _=function(t){return{label:t.label,value:t.v,valueLabel:g.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:g.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(i,t.i,\"customdata\")}}(e),b=g.getFirstFilled(i.text,e.pts);(v(b)||\"\"===b)&&(_.text=b),e.text=l.texttemplateString(x,_,t._fullLayout._d3locale,_,i._meta||{})}else e.text=\"\"}}function R(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),i=Math.sin(r),a=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=a*n-o*i,t.textY=a*i+o*n,t.noCenter=!0}t.exports={plot:function(t,e){var r=t._context.staticPlot,a=t._fullLayout,f=a._size;d(\"pie\",a),b(e,t),z(e,f);var m=l.makeTraceGroups(a._pielayer,e,\"trace\").each((function(e){var d=n.select(this),m=e[0],y=m.trace;!function(t){var e,r,n,i=t[0],a=i.r,o=i.trace,s=g.getRotationAngle(o.rotation),l=2*Math.PI/i.vTotal,c=\"px0\",u=\"px1\";if(\"counterclockwise\"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c=\"px1\",u=\"px0\"}for(n=O(a,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=O(a,s),r.midangle=s,n=O(a,s+=l*r.v/2),r.stopangle=s,r[u]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-o.hole,r.rInscribed=E(r,i))}(e),d.attr(\"stroke-linejoin\",\"round\"),d.each((function(){var v=n.select(this).selectAll(\"g.slice\").data(e);v.enter().append(\"g\").classed(\"slice\",!0),v.exit().remove();var b=[[[],[]],[[],[]]],T=!1;v.each((function(i,o){if(i.hidden)n.select(this).selectAll(\"path,g\").remove();else{i.pointNumber=i.i,i.curveNumber=y.index,b[i.pxmid[1]<0?0:1][i.pxmid[0]<0?0:1].push(i);var c=m.cx,u=m.cy,f=n.select(this),d=f.selectAll(\"path.surface\").data([i]);if(d.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":r?\"none\":\"all\"}),f.call(x,t,e),y.pull){var v=+g.castOption(y.pull,i.pts)||0;v>0&&(c+=v*i.pxmid[0],u+=v*i.pxmid[1])}i.cxFinal=c,i.cyFinal=u;var k=y.hole;if(i.v===m.vTotal){var A=\"M\"+(c+i.px0[0])+\",\"+(u+i.px0[1])+I(i.px0,i.pxmid,!0,1)+I(i.pxmid,i.px0,!0,1)+\"Z\";k?d.attr(\"d\",\"M\"+(c+k*i.px0[0])+\",\"+(u+k*i.px0[1])+I(i.px0,i.pxmid,!1,k)+I(i.pxmid,i.px0,!1,k)+\"Z\"+A):d.attr(\"d\",A)}else{var M=I(i.px0,i.px1,!0,1);if(k){var S=1-k;d.attr(\"d\",\"M\"+(c+k*i.px1[0])+\",\"+(u+k*i.px1[1])+I(i.px1,i.px0,!1,k)+\"l\"+S*i.px0[0]+\",\"+S*i.px0[1]+M+\"Z\")}else d.attr(\"d\",\"M\"+c+\",\"+u+\"l\"+i.px0[0]+\",\"+i.px0[1]+M+\"Z\")}D(t,i,m);var E=g.castOption(y.textposition,i.pts),L=f.selectAll(\"g.slicetext\").data(i.text&&\"none\"!==E?[0]:[]);L.enter().append(\"g\").classed(\"slicetext\",!0),L.exit().remove(),L.each((function(){var r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),f=l.ensureUniformFontSize(t,\"outside\"===E?function(t,e,r){return{color:g.castOption(t.outsidetextfont.color,e.pts)||g.castOption(t.textfont.color,e.pts)||r.color,family:g.castOption(t.outsidetextfont.family,e.pts)||g.castOption(t.textfont.family,e.pts)||r.family,size:g.castOption(t.outsidetextfont.size,e.pts)||g.castOption(t.textfont.size,e.pts)||r.size,weight:g.castOption(t.outsidetextfont.weight,e.pts)||g.castOption(t.textfont.weight,e.pts)||r.weight,style:g.castOption(t.outsidetextfont.style,e.pts)||g.castOption(t.textfont.style,e.pts)||r.style,variant:g.castOption(t.outsidetextfont.variant,e.pts)||g.castOption(t.textfont.variant,e.pts)||r.variant,textcase:g.castOption(t.outsidetextfont.textcase,e.pts)||g.castOption(t.textfont.textcase,e.pts)||r.textcase,lineposition:g.castOption(t.outsidetextfont.lineposition,e.pts)||g.castOption(t.textfont.lineposition,e.pts)||r.lineposition,shadow:g.castOption(t.outsidetextfont.shadow,e.pts)||g.castOption(t.textfont.shadow,e.pts)||r.shadow}}(y,i,a.font):_(y,i,a.font));r.text(i.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,f).call(h.convertToTspans,t);var d,v=s.bBox(r.node());if(\"outside\"===E)d=C(v,i);else if(d=w(v,i,m),\"auto\"===E&&d.scale<1){var x=l.ensureUniformFontSize(t,y.outsidetextfont);r.call(s.font,x),d=C(v=s.bBox(r.node()),i)}var b=d.textPosAngle,k=void 0===b?i.pxmid:O(m.r,b);if(d.targetX=c+k[0]*d.rCenter+(d.x||0),d.targetY=u+k[1]*d.rCenter+(d.y||0),R(d,v),d.outside){var A=d.targetY;i.yLabelMin=A-v.height/2,i.yLabelMid=A,i.yLabelMax=A+v.height/2,i.labelExtraX=0,i.labelExtraY=0,T=!0}d.fontSize=f.size,p(y.type,d,a),e[o].transform=d,l.setTransormAndDisplay(r,d)}))}function I(t,e,r,n){var a=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return\"a\"+n*m.r+\",\"+n*m.r+\" 0 \"+i.largeArc+(r?\" 1 \":\" 0 \")+a+\",\"+o}}));var k=n.select(this).selectAll(\"g.titletext\").data(y.title.text?[0]:[]);if(k.enter().append(\"g\").classed(\"titletext\",!0),k.exit().remove(),k.each((function(){var e,r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),i=y.title.text;y._meta&&(i=l.templateString(i,y._meta)),r.text(i).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,y.title.font).call(h.convertToTspans,t),e=\"middle center\"===y.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(m):L(m,f),r.attr(\"transform\",u(e.x,e.y)+c(Math.min(1,e.scale))+u(e.tx,e.ty))})),T&&function(t,e){var r,n,i,a,o,s,c,u,h,f,p,d,m;function y(t,e){return t.pxmid[1]-e.pxmid[1]}function v(t,e){return e.pxmid[1]-t.pxmid[1]}function x(t,r){r||(r={});var i,u,h,p,d=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,v=t.cyFinal+o(t.px0[1],t.px1[1]),x=d-m;if(x*c>0&&(t.labelExtraY=x),l.isArrayOrTypedArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(g.castOption(e.pull,t.pts)||0)>=(g.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*c>0?(x=h.cyFinal+o(h.px0[1],h.px1[1])-m-t.labelExtraY)*c>0&&(t.labelExtraY+=x):(y+t.labelExtraY-v)*c>0&&(i=3*s*Math.abs(u-f.indexOf(t)),(p=h.cxFinal+a(h.px0[0],h.px1[0])+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=p)))}for(n=0;n<2;n++)for(i=n?y:v,o=n?Math.max:Math.min,c=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(m=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){m=h[p];break}for(p=0;p<d.length;p++){var _=p&&d[p-1];m&&!p&&(_=m),x(d[p],_)}}}(b,y),function(t,e){t.each((function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,l.setTransormAndDisplay(i,t.transform);var a=t.cxFinal+t.pxmid[0],s=\"M\"+a+\",\"+(t.cyFinal+t.pxmid[1]),c=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var u=t.labelExtraX*t.pxmid[1]/t.pxmid[0],h=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(u)>Math.abs(h)?s+=\"l\"+h*t.pxmid[0]/t.pxmid[1]+\",\"+h+\"H\"+(a+t.labelExtraX+c):s+=\"l\"+t.labelExtraX+\",\"+u+\"v\"+(h-u)+\"h\"+c}else s+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+c;l.ensureSingle(r,\"path\",\"textline\").call(o.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:s,fill:\"none\"})}else r.select(\"path.textline\").remove()}))}(v,y),T&&y.automargin){var A=s.bBox(d.node()),M=y.domain,S=f.w*(M.x[1]-M.x[0]),E=f.h*(M.y[1]-M.y[0]),I=(.5*S-m.r)/f.w,P=(.5*E-m.r)/f.h;i.autoMargin(t,\"pie.\"+y.uid+\".automargin\",{xl:M.x[0]-I,xr:M.x[1]+I,yb:M.y[0]-P,yt:M.y[1]+P,l:Math.max(m.cx-m.r-A.left,0),r:Math.max(A.right-(m.cx+m.r),0),b:Math.max(A.bottom-(m.cy+m.r),0),t:Math.max(m.cy-m.r-A.top,0),pad:5})}}))}));setTimeout((function(){m.selectAll(\"tspan\").each((function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))}))}),0)},formatSliceLabel:D,transformInsideText:w,determineInsideTextFont:_,positionTitleOutside:L,prerenderTitles:b,layoutAreas:z,attachFxHandlers:x,computeTransform:R}},140:function(t,e,r){\"use strict\";var n=r(45568),i=r(32891),a=r(84102).resizeText;t.exports=function(t){var e=t._fullLayout._pielayer.selectAll(\".trace\");a(t,e,\"pie\"),e.each((function(e){var r=e[0].trace,a=n.select(this);a.style({opacity:r.opacity}),a.selectAll(\"path.surface\").each((function(e){n.select(this).call(i,e,r,t)}))}))}},32891:function(t,e,r){\"use strict\";var n=r(78766),i=r(37252).castOption,a=r(75067);t.exports=function(t,e,r,o){var s=r.marker.line,l=i(s.color,e.pts)||n.defaultLine,c=i(s.width,e.pts)||0;t.call(a,e,r,o).style(\"stroke-width\",c).call(n.stroke,l)}},36961:function(t,e,r){\"use strict\";var n=r(36640);t.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},71593:function(t,e,r){\"use strict\";var n=r(99098).gl_pointcloud2d,i=r(34809).isArrayOrTypedArray,a=r(55010),o=r(32919).findExtremes,s=r(11539);function l(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var c=l.prototype;c.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:i(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},c.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=s(t,{})},c.updateFast=function(t){var e,r,n,i,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)i=n[2*l],s=n[2*l+1],i<d[0]&&(d[0]=i),i>d[2]&&(d[2]=i),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)i=c[l],s=u[l],r[l]=l,n[2*l]=i,n[2*l+1]=s,i<d[0]&&(d[0]=i),i>d[2]&&(d[2]=i),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var m=a(t.marker.color),g=a(t.marker.border.color),y=t.opacity*t.marker.opacity;m[3]*=y,this.pointcloudOptions.color=m;var v=t.marker.blend;null===v&&(v=c.length<100||u.length<100),this.pointcloudOptions.blend=v,g[3]*=y,this.pointcloudOptions.borderColor=g;var x=t.marker.sizemin,_=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=_,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var b=this.scene.xaxis,w=this.scene.yaxis,T=_/2||.5;t._extremes[b._id]=o(b,[d[0],d[2]],{ppad:T}),t._extremes[w._id]=o(w,[d[1],d[3]],{ppad:T})},c.dispose=function(){this.pointcloud.dispose()},t.exports=function(t,e){var r=new l(t,e.uid);return r.update(e),r}},75526:function(t,e,r){\"use strict\";var n=r(34809),i=r(36961);t.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},15186:function(t,e,r){\"use strict\";[\"*pointcloud* trace is deprecated!\",\"Please consider switching to the *scattergl* trace type.\"].join(\" \"),t.exports={attributes:r(36961),supplyDefaults:r(75526),calc:r(37593),plot:r(71593),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:r(24585),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},33795:function(t,e,r){\"use strict\";var n=r(80337),i=r(9829),a=r(10229),o=r(70192),s=r(13792).u,l=r(3208).rb,c=r(87163),u=r(78032).templatedArray,h=r(80712).descriptionOnlyNumbers,f=r(93049).extendFlat,p=r(13582).overrideAll;(t.exports=p({hoverinfo:f({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\",description:h(\"value\")},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({autoShadowDflt:!0}),customdata:void 0,node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),align:{valType:\"enumerated\",values:[\"justify\",\"left\",\"right\",\"center\"],dflt:\"justify\"}},link:{arrowlen:{valType:\"number\",min:0,dflt:0},label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},hovercolor:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:f(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},42229:function(t,e,r){\"use strict\";var n=r(13582).overrideAll,i=r(4173).eV,a=r(16506),o=r(6811),s=r(27983),l=r(14751),c=r(44844).prepSelect,u=r(34809),h=r(33626),f=\"sankey\";function p(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(o&&\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}e.name=f,e.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),e.plot=function(t){var r=i(t.calcdata,f)[0];a(t,r),e.updateFx(t)},e.clean=function(t,e,r,n){var i=n._has&&n._has(f),a=e._has&&e._has(f);i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},e.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)p(t,e)}},22915:function(t,e,r){\"use strict\";var n=r(26381),i=r(34809),a=r(71293).wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=r(88856);t.exports=function(t,e){var r=function(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h=o(a.hovercolor),f=o(a.customdata),p={},d={},m=a.colorscales.length;for(e=0;e<m;e++){var g=a.colorscales[e],y=l.extractScale(g,{cLetter:\"c\"}),v=l.makeColorScaleFunc(y);d[g.label]=v}var x=0;for(e=0;e<a.value.length;e++)a.source[e]>x&&(x=a.source[e]),a.target[e]>x&&(x=a.target[e]);var _,b=x+1;t.node._count=b;var w=t.node.groups,T={};for(e=0;e<w.length;e++){var k=w[e];for(_=0;_<k.length;_++){var A=k[_],M=b+e;T.hasOwnProperty(A)?i.warn(\"Node \"+A+\" is already part of a group.\"):T[A]=M}}var S={source:[],target:[]};for(e=0;e<a.value.length;e++){var E=a.value[e],C=a.source[e],L=a.target[e];if(E>0&&s(C,b)&&s(L,b)&&(!T.hasOwnProperty(C)||!T.hasOwnProperty(L)||T[C]!==T[L])){T.hasOwnProperty(L)&&(L=T[L]),T.hasOwnProperty(C)&&(C=T[C]),L=+L,p[C=+C]=p[L]=!0;var I=\"\";a.label&&a.label[e]&&(I=a.label[e]);var P=null;I&&d.hasOwnProperty(I)&&(P=d[I]),c.push({pointNumber:e,label:I,color:u?a.color[e]:a.color,hovercolor:h?a.hovercolor[e]:a.hovercolor,customdata:f?a.customdata[e]:a.customdata,concentrationscale:P,source:C,target:L,value:+E}),S.source.push(C),S.target.push(L)}}var z=b+w.length,O=o(r.color),D=o(r.customdata),R=[];for(e=0;e<z;e++)if(p[e]){var F=r.label[e];R.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:F,color:O?r.color[e]:r.color,customdata:D?r.customdata[e]:r.customdata})}var B=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some((function(t){return t.length>1}))}(z,S.source,S.target)&&(B=!0),{circular:B,links:c,nodes:R,groups:w,groupLookup:T}}(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},21541:function(t){\"use strict\";t.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeLabel:\"node-label\"}}},67940:function(t,e,r){\"use strict\";var n=r(34809),i=r(33795),a=r(78766),o=r(65657),s=r(13792).N,l=r(26430),c=r(78032),u=r(59008);function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}t.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),m=t.node,g=c.newContainer(e,\"node\");function y(t,e){return n.coerce(m,g,i.node,t,e)}y(\"label\"),y(\"groups\"),y(\"x\"),y(\"y\"),y(\"pad\"),y(\"thickness\"),y(\"line.color\"),y(\"line.width\"),y(\"hoverinfo\",t.hoverinfo),l(m,g,y,d),y(\"hovertemplate\"),y(\"align\");var v=f.colorway;y(\"color\",g.label.map((function(t,e){return a.addOpacity(function(t){return v[t%v.length]}(e),.8)}))),y(\"customdata\");var x=t.link||{},_=c.newContainer(e,\"link\");function b(t,e){return n.coerce(x,_,i.link,t,e)}b(\"label\"),b(\"arrowlen\"),b(\"source\"),b(\"target\"),b(\"value\"),b(\"line.color\"),b(\"line.width\"),b(\"hoverinfo\",t.hoverinfo),l(x,_,b,d),b(\"hovertemplate\");var w,T=o(f.paper_bgcolor).getLuminance()<.333,k=b(\"color\",T?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\");function A(t){var e=o(t);if(!e.isValid())return t;var r=e.getAlpha();return r<=.8?e.setAlpha(r+.2):e=T?e.brighten():e.darken(),e.toRgbString()}b(\"hovercolor\",Array.isArray(k)?k.map(A):A(k)),b(\"customdata\"),u(x,_,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),g.x.length&&g.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",f.font,{autoShadowDflt:!0}),e._length=null}},71760:function(t,e,r){\"use strict\";t.exports={attributes:r(33795),supplyDefaults:r(67940),calc:r(22915),plot:r(16506),moduleType:\"trace\",name:\"sankey\",basePlotModule:r(42229),selectPoints:r(74670),categories:[\"noOpacity\"],meta:{}}},16506:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=i.numberFormat,o=r(90958),s=r(32141),l=r(78766),c=r(21541).cn,u=i._;function h(t){return\"\"!==t}function f(t,e){return t.filter((function(t){return t.key===e.traceId}))}function p(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function d(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function m(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function y(t,e,r){e&&r&&f(r,e).selectAll(\".\"+c.sankeyLink).filter(m(e)).call(x.bind(0,e,r,!1))}function v(t,e,r){e&&r&&f(r,e).selectAll(\".\"+c.sankeyLink).filter(m(e)).call(_.bind(0,e,r,!1))}function x(t,e,r,n){n.style(\"fill\",(function(t){if(!t.link.concentrationscale)return t.tinyColorHoverHue})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return t.tinyColorHoverAlpha})),n.each((function(r){var n=r.link.label;\"\"!==n&&f(e,t).selectAll(\".\"+c.sankeyLink).filter((function(t){return t.link.label===n})).style(\"fill\",(function(t){if(!t.link.concentrationscale)return t.tinyColorHoverHue})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return t.tinyColorHoverAlpha}))})),r&&f(e,t).selectAll(\".\"+c.sankeyNode).filter(g(t)).call(y)}function _(t,e,r,n){n.style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),n.each((function(r){var n=r.link.label;\"\"!==n&&f(e,t).selectAll(\".\"+c.sankeyLink).filter((function(t){return t.link.label===n})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha}))})),r&&f(e,t).selectAll(c.sankeyNode).filter(g(t)).call(v)}function b(t,e){var r=t.hoverlabel||{},n=i.nestedProperty(r,e).get();return!Array.isArray(n)&&n}t.exports=function(t,e){for(var r=t._fullLayout,i=r._paper,f=r._size,m=0;m<t._fullData.length;m++)if(t._fullData[m].visible&&t._fullData[m].type===c.sankey&&!t._fullData[m]._viewInitial){var g=t._fullData[m].node;t._fullData[m]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var w=u(t,\"source:\")+\" \",T=u(t,\"target:\")+\" \",k=u(t,\"concentration:\")+\" \",A=u(t,\"incoming flow count:\")+\" \",M=u(t,\"outgoing flow count:\")+\" \";o(t,i,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.link.trace.link;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){for(var c=[],u=0,f=0;f<i.flow.links.length;f++){var m=i.flow.links[f];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===m.pointNumber){i.link.pointNumber===m.pointNumber&&(u=f),m.fullData=m.trace,o=i.link.trace.link;var g=v(m),y={valueLabel:a(i.valueFormat)(m.value)+i.valueSuffix};c.push({x:g[0],y:g[1],name:y.valueLabel,text:[m.label||\"\",w+m.source.label,T+m.target.label,m.concentrationscale?k+a(\"%0.2f\")(m.flow.labelConcentration):\"\"].filter(h).join(\"<br>\"),color:b(o,\"bgcolor\")||l.addOpacity(m.color,1),borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),fontWeight:b(o,\"font.weight\"),fontStyle:b(o,\"font.style\"),fontVariant:b(o,\"font.variant\"),fontTextcase:b(o,\"font.textcase\"),fontLineposition:b(o,\"font.lineposition\"),fontShadow:b(o,\"font.shadow\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:y,eventData:[m]})}}s.loneHover(c,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:u}).each((function(){i.link.concentrationscale||p(this,.65),d(this)}))}}function v(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return\"v\"===t.trace.orientation&&n.reverse(),n[0]+=i.parent.translateX,n[1]+=i.parent.translateY,n}},unhover:function(e,i,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(_.bind(0,i,a,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),s.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],s.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var l=n.select(e).select(\".\"+c.nodeRect),u=t._fullLayout._paperdiv.node().getBoundingClientRect(),f=l.node().getBoundingClientRect(),m=f.left-2-u.left,g=f.right+2-u.left,y=f.top+f.height/4-u.top,v={valueLabel:a(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace,t._fullLayout._calcInverseTransform(t);var x=t._fullLayout._invScaleX,_=t._fullLayout._invScaleY,w=s.loneHover({x0:x*m,x1:x*g,y:_*y,name:a(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,A+i.node.targetLinks.length,M+i.node.sourceLinks.length].filter(h).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),fontWeight:b(o,\"font.weight\"),fontStyle:b(o,\"font.style\"),fontVariant:b(o,\"font.variant\"),fontTextcase:b(o,\"font.textcase\"),fontLineposition:b(o,\"font.lineposition\"),fontShadow:b(o,\"font.shadow\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:v,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});p(w,.85),d(w)}}},unhover:function(e,i,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,i,a),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),s.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var a=r.node;a.originalEvent=n.event,t._hoverdata=[a],n.select(e).call(v,r,i),s.click(t,{target:!0})}}})}},90958:function(t,e,r){\"use strict\";var n=r(32702),i=r(88640).Dj,a=r(45568),o=r(62369),s=r(68735),l=r(21541),c=r(65657),u=r(78766),h=r(62203),f=r(34809),p=f.strTranslate,d=f.strRotate,m=r(71293),g=m.keyFun,y=m.repeat,v=m.unwrap,x=r(30635),_=r(33626),b=r(4530),w=b.CAP_SHIFT,T=b.LINE_SPACING;function k(t,e,r){var n,i=v(e),a=i.trace,u=a.domain,h=\"h\"===a.orientation,p=a.node.pad,d=a.node.thickness,m={justify:o.sankeyJustify,left:o.sankeyLeft,right:o.sankeyRight,center:o.sankeyCenter}[a.node.align],g=t.width*(u.x[1]-u.x[0]),y=t.height*(u.y[1]-u.y[0]),x=i._nodes,_=i._links,b=i.circular;(n=b?s.sankeyCircular().circularLinkGap(0):o.sankey()).iterations(l.sankeyIterations).size(h?[g,y]:[y,g]).nodeWidth(d).nodePadding(p).nodeId((function(t){return t.pointNumber})).nodeAlign(m).nodes(x).links(_);var w,T,k,A=n();for(var M in n.nodePadding()<p&&f.warn(\"node.pad was reduced to \",n.nodePadding(),\" to fit within the figure.\"),i._groupLookup){var S,E=parseInt(i._groupLookup[M]);for(w=0;w<A.nodes.length;w++)if(A.nodes[w].pointNumber===E){S=A.nodes[w];break}if(S){var C={pointNumber:parseInt(M),x0:S.x0,x1:S.x1,y0:S.y0,y1:S.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};A.nodes.unshift(C),S.childrenNodes.unshift(C)}}if(function(){for(w=0;w<A.nodes.length;w++){var t,e,r=A.nodes[w],n={};for(T=0;T<r.targetLinks.length;T++)t=(e=r.targetLinks[T]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(T=0;T<i.length;T++){var a=n[t=i[T]],o=0,s={};for(k=0;k<a.length;k++)s[(e=a[k]).label]||(s[e.label]=0),s[e.label]+=e.value,o+=e.value;for(k=0;k<a.length;k++)(e=a[k]).flow={value:o,labelConcentration:s[e.label]/o,concentration:e.value/o,links:a},e.concentrationscale&&(e.color=c(e.concentrationscale(e.flow.labelConcentration)))}var l=0;for(T=0;T<r.sourceLinks.length;T++)l+=r.sourceLinks[T].value;for(T=0;T<r.sourceLinks.length;T++)(e=r.sourceLinks[T]).concentrationOut=e.value/l;var u=0;for(T=0;T<r.targetLinks.length;T++)u+=r.targetLinks[T].value;for(T=0;T<r.targetLinks.length;T++)(e=r.targetLinks[T]).concenrationIn=e.value/u}}(),a.node.x.length&&a.node.y.length){for(w=0;w<Math.min(a.node.x.length,a.node.y.length,A.nodes.length);w++)if(a.node.x[w]&&a.node.y[w]){var L=[a.node.x[w]*g,a.node.y[w]*y];A.nodes[w].x0=L[0]-d/2,A.nodes[w].x1=L[0]+d/2;var I=A.nodes[w].y1-A.nodes[w].y0;A.nodes[w].y0=L[1]-I/2,A.nodes[w].y1=L[1]+I/2}\"snap\"===a.arrangement&&function(t){var e,r,n=t.map((function(t,e){return{x0:t.x0,index:e}})).sort((function(t,e){return t.x0-e.x0})),i=[],a=-1,o=-1/0;for(w=0;w<n.length;w++){var s=t[n[w].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(x=A.nodes).forEach((function(t){var e,r,n,i=0,a=t.length;for(t.sort((function(t,e){return t.y0-e.y0})),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})),n.update(A)}return{circular:b,key:r,trace:a,guid:f.randstr(),horizontal:h,width:g,height:y,nodePad:a.node.pad,nodeLineColor:a.node.line.color,nodeLineWidth:a.node.line.width,linkLineColor:a.link.line.color,linkLineWidth:a.link.line.width,linkArrowLength:a.link.arrowlen,valueFormat:a.valueformat,valueSuffix:a.valuesuffix,textFont:a.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:h?y:g,dragPerpendicular:h?g:y,arrangement:a.arrangement,sankey:n,graph:A,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}function A(t,e,r){var n=c(e.color),i=c(e.hovercolor),a=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:a,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:u.tinyRGB(n),tinyColorAlpha:n.getAlpha(),tinyColorHoverHue:u.tinyRGB(i),tinyColorHoverAlpha:i.getAlpha(),linkPath:M,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,linkArrowLength:t.linkArrowLength,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}function M(){return function(t){var e=t.linkArrowLength;if(t.link.circular)return function(t,e){var r=t.width/2,n=t.circularPathData;return\"top\"===t.circularLinkType?\"M \"+(n.targetX-e)+\" \"+(n.targetY+r)+\" L\"+(n.rightInnerExtent-e)+\" \"+(n.targetY+r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 1 \"+(n.rightFullExtent-r-e)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r-e)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 1 \"+(n.rightInnerExtent-e)+\" \"+(n.verticalFullExtent-r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 1 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 0 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+(n.rightInnerExtent-e)+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 0 \"+(n.rightFullExtent+r-e)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r-e)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 0 \"+(n.rightInnerExtent-e)+\" \"+(n.targetY-r)+\"L\"+(n.targetX-e)+\" \"+(n.targetY-r)+(e>0?\"L\"+n.targetX+\" \"+n.targetY:\"\")+\"Z\":\"M \"+(n.targetX-e)+\" \"+(n.targetY-r)+\" L\"+(n.rightInnerExtent-e)+\" \"+(n.targetY-r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 0 \"+(n.rightFullExtent-r-e)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r-e)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 0 \"+(n.rightInnerExtent-e)+\" \"+(n.verticalFullExtent+r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 0 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 1 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+(n.rightInnerExtent-e)+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 1 \"+(n.rightFullExtent+r-e)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r-e)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 1 \"+(n.rightInnerExtent-e)+\" \"+(n.targetY+r)+\"L\"+(n.targetX-e)+\" \"+(n.targetY+r)+(e>0?\"L\"+n.targetX+\" \"+n.targetY:\"\")+\"Z\"}(t.link,e);var r=Math.abs((t.link.target.x0-t.link.source.x1)/2);e>r&&(e=r);var n=t.link.source.x1,a=t.link.target.x0-e,o=i(n,a),s=o(.5),l=o(.5),c=t.link.y0-t.link.width/2,u=t.link.y0+t.link.width/2,h=t.link.y1-t.link.width/2,f=t.link.y1+t.link.width/2,p=\"M\"+n+\",\"+c,d=\"C\"+s+\",\"+c+\" \"+l+\",\"+h+\" \"+a+\",\"+h,m=\"C\"+l+\",\"+f+\" \"+s+\",\"+u+\" \"+n+\",\"+u,g=e>0?\"L\"+(a+e)+\",\"+(h+t.link.width/2):\"\";return p+d+(g+=\"L\"+a+\",\"+f)+m+\"Z\"}}function S(t,e){var r=c(e.color),n=l.nodePadAcross,i=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var a=e.dx,o=Math.max(.5,e.dy),s=\"node_\"+e.pointNumber;return e.group&&(s=f.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:s,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(a),visibleHeight:o,zoneX:-n,zoneY:-i,zoneWidth:a+2*n,zoneHeight:o+2*i,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:u.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,s].join(\"_\"),interactionState:t.interactionState,figure:t}}function E(t){t.attr(\"transform\",(function(t){return p(t.node.x0.toFixed(3),t.node.y0.toFixed(3))}))}function C(t){t.call(E)}function L(t,e){t.call(C),e.attr(\"d\",M())}function I(t){t.attr(\"width\",(function(t){return t.node.x1-t.node.x0})).attr(\"height\",(function(t){return t.visibleHeight}))}function P(t){return t.link.width>1||t.linkLineWidth>0}function z(t){return p(t.translateX,t.translateY)+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function O(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])})).on(\"mousemove.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])})).on(\"mouseout.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)})).on(\"click.basic\",(function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)}))}function D(t,e,r,i){var o=a.behavior.drag().origin((function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}})).on(\"dragstart\",(function(a){if(\"fixed\"!==a.arrangement&&(f.ensureSingle(i._fullLayout._infolayer,\"g\",\"dragcover\",(function(t){i._fullLayout._dragCover=t})),f.raiseToTop(this),a.interactionState.dragInProgress=a.node,F(a.node),a.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,a.interactionState.hovered),a.interactionState.hovered=!1),\"snap\"===a.arrangement)){var o=a.traceId+\"|\"+a.key;a.forceLayouts[o]?a.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter((function(t){return t.originalX===r.node.originalX})).filter((function(t){return!t.partOfGroup}));r.forceLayouts[e]=n.forceSimulation(a).alphaDecay(0).force(\"collide\",n.forceCollide().radius((function(t){return t.dy/2+r.nodePad/2})).strength(1).iterations(l.forceIterations)).force(\"constrain\",function(t,e,r,n){return function(){for(var t=0,i=0;i<r.length;i++){var a=r[i];a===n.interactionState.dragInProgress?(a.x=a.lastDraggedX,a.y=a.lastDraggedY):(a.vx=(a.originalX-a.x)/l.forceTicksPerFrame,a.y=Math.min(n.size-a.dy/2,Math.max(a.dy/2,a.y))),t=Math.max(t,Math.abs(a.vx),Math.abs(a.vy))}!n.interactionState.dragInProgress&&t<.1&&n.forceLayouts[e].alpha()>0&&n.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,a),function(t,e,r,n,i){window.requestAnimationFrame((function a(){var o;for(o=0;o<l.forceTicksPerFrame;o++)r.forceLayouts[n].tick();if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(r.graph.nodes),r.sankey.update(r.graph),L(t.filter(B(r)),e),r.forceLayouts[n].alpha()>0)window.requestAnimationFrame(a);else{var s=r.node.originalX;r.node.x0=s-r.visibleWidth/2,r.node.x1=s+r.visibleWidth/2,R(r,i)}}))}(t,e,a,o,i)}})).on(\"drag\",(function(r){if(\"fixed\"!==r.arrangement){var n=a.event.x,i=a.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),i=Math.max(0,Math.min(r.size-r.visibleHeight/2,i)),r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2),F(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),L(t.filter(B(r)),e))}})).on(\"dragend\",(function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&R(t,i)}}));t.on(\".drag\",null).call(o)}function R(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}_.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then((function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()}))}function F(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function B(t){return function(e){return e.node.originalX===t.node.originalX}}t.exports=function(t,e,r,n,i){var o=t._context.staticPlot,s=!1;f.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",(function(){s=!0}));var m=t._fullLayout._dragCover,_=r.filter((function(t){return v(t).trace.visible})).map(k.bind(null,n)),b=e.selectAll(\".\"+l.cn.sankey).data(_,g);b.exit().remove(),b.enter().append(\"g\").classed(l.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",o?\"none\":\"auto\").attr(\"transform\",z),b.each((function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;f.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=a.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",o?\"none\":\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})})),b.transition().ease(l.ease).duration(l.duration).attr(\"transform\",z);var C=b.selectAll(\".\"+l.cn.sankeyLinks).data(y,g);C.enter().append(\"g\").classed(l.cn.sankeyLinks,!0).style(\"fill\",\"none\");var L=C.selectAll(\".\"+l.cn.sankeyLink).data((function(t){return t.graph.links.filter((function(t){return t.value})).map(A.bind(null,t))}),g);L.enter().append(\"path\").classed(l.cn.sankeyLink,!0).call(O,b,i.linkEvents),L.style(\"stroke\",(function(t){return P(t)?u.tinyRGB(c(t.linkLineColor)):t.tinyColorHue})).style(\"stroke-opacity\",(function(t){return P(t)?u.opacity(t.linkLineColor):t.tinyColorAlpha})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})).style(\"stroke-width\",(function(t){return P(t)?t.linkLineWidth:1})).attr(\"d\",M()),L.style(\"opacity\",(function(){return t._context.staticPlot||s||m?1:0})).transition().ease(l.ease).duration(l.duration).style(\"opacity\",1),L.exit().transition().ease(l.ease).duration(l.duration).style(\"opacity\",0).remove();var R=b.selectAll(\".\"+l.cn.sankeyNodeSet).data(y,g);R.enter().append(\"g\").classed(l.cn.sankeyNodeSet,!0),R.style(\"cursor\",(function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}}));var F=R.selectAll(\".\"+l.cn.sankeyNode).data((function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort((function(t,e){return t-e})),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(S.bind(null,t))}),g);F.enter().append(\"g\").classed(l.cn.sankeyNode,!0).call(E).style(\"opacity\",(function(e){return!t._context.staticPlot&&!s||e.partOfGroup?0:1})),F.call(O,b,i.nodeEvents).call(D,L,i,t),F.transition().ease(l.ease).duration(l.duration).call(E).style(\"opacity\",(function(t){return t.partOfGroup?0:1})),F.exit().transition().ease(l.ease).duration(l.duration).style(\"opacity\",0).remove();var B=F.selectAll(\".\"+l.cn.nodeRect).data(y);B.enter().append(\"rect\").classed(l.cn.nodeRect,!0).call(I),B.style(\"stroke-width\",(function(t){return t.nodeLineWidth})).style(\"stroke\",(function(t){return u.tinyRGB(c(t.nodeLineColor))})).style(\"stroke-opacity\",(function(t){return u.opacity(t.nodeLineColor)})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),B.transition().ease(l.ease).duration(l.duration).call(I);var N=F.selectAll(\".\"+l.cn.nodeLabel).data(y);N.enter().append(\"text\").classed(l.cn.nodeLabel,!0).style(\"cursor\",\"default\"),N.attr(\"data-notex\",1).text((function(t){return t.node.label})).each((function(e){var r=a.select(this);h.font(r,e.textFont),x.convertToTspans(r,t)})).attr(\"text-anchor\",(function(t){return t.horizontal&&t.left?\"end\":\"start\"})).attr(\"transform\",(function(t){var e=a.select(this),r=x.lineCount(e),n=t.textFont.size*((r-1)*T-w),i=t.nodeLineWidth/2+3,o=((t.horizontal?t.visibleHeight:t.visibleWidth)-n)/2;t.horizontal&&(t.left?i=-i:i+=t.visibleWidth);var s=t.horizontal?\"\":\"scale(-1,1)\"+d(90);return p(t.horizontal?i:o,t.horizontal?o:i)+s})),N.transition().ease(l.ease).duration(l.duration)}},74670:function(t){\"use strict\";t.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},99203:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.texttemplate,t,\"txt\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"),n.mergeArray(e.textfont.weight,t,\"tw\"),n.mergeArray(e.textfont.style,t,\"ty\"),n.mergeArray(e.textfont.variant,t,\"tv\"),n.mergeArray(e.textfont.textcase,t,\"tC\"),n.mergeArray(e.textfont.lineposition,t,\"tE\"),n.mergeArray(e.textfont.shadow,t,\"tS\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.angle,t,\"ma\"),n.mergeArray(i.standoff,t,\"mf\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},36640:function(t,e,r){\"use strict\";var n=r(80712).axisHoverFormat,i=r(3208).ay,a=r(3208).rb,o=r(87163),s=r(80337),l=r(94850).T,c=r(94850).k,u=r(62203),h=r(32660),f=r(93049).extendFlat,p=r(19326);t.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},xperiod:{valType:\"any\",dflt:0,editType:\"calc\"},yperiod:{valType:\"any\",dflt:0,editType:\"calc\"},xperiod0:{valType:\"any\",editType:\"calc\"},yperiod0:{valType:\"any\",editType:\"calc\"},xperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},yperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},xhoverformat:n(\"x\"),yhoverformat:n(\"y\"),offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},texttemplate:i({},{}),hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:a({},{keys:h.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:f({},l,{editType:\"style\"}),backoff:{valType:\"number\",min:0,dflt:\"auto\",arrayOk:!0,editType:\"plot\"},simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:p(!0),fillgradient:f({type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],dflt:\"none\",editType:\"calc\"},start:{valType:\"number\",editType:\"calc\"},stop:{valType:\"number\",editType:\"calc\"},colorscale:{valType:\"colorscale\",editType:\"style\"},editType:\"calc\"}),fillpattern:c,marker:f({symbol:{valType:\"enumerated\",values:u.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},angle:{valType:\"angle\",dflt:0,arrayOk:!0,editType:\"plot\",anim:!1},angleref:{valType:\"enumerated\",values:[\"previous\",\"up\"],dflt:\"up\",editType:\"plot\",anim:!1},standoff:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"plot\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:f({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},o(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},o(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:s({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),zorder:{valType:\"integer\",dflt:0,editType:\"plot\"}}},26544:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(29714),o=r(40528),s=r(63821).BADNUM,l=r(64726),c=r(77272),u=r(99203),h=r(48861);function f(t,e,r,n,i,o,s){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[m(e)]===e.uid,d=(g(e,u,r,n)||{}).orientation,y=e.fill;r._minDtick=0,n._minDtick=0;var v={padded:!0},x={padded:!0};s&&(v.ppad=x.ppad=s);var _=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];_&&(\"tozerox\"===y||\"tonextx\"===y&&(p||\"h\"===d))?v.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==y&&\"tozeroy\"!==y&&(l.hasMarkers(e)||l.hasText(e))||(v.padded=!1,v.ppad=0),_&&(\"tozeroy\"===y||\"tonexty\"===y&&(p||\"v\"===d))?x.tozero=!0:\"tonextx\"!==y&&\"tozerox\"!==y||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,v)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function p(t,e){if(l.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var s={type:\"linear\"};a.setConvert(s);for(var c=s.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function d(t,e){var r=m(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function m(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}t.exports={calc:function(t,e){var r,l,m,y,v,x,_=t._fullLayout,b=e._xA=a.getFromId(t,e.xaxis||\"x\",\"x\"),w=e._yA=a.getFromId(t,e.yaxis||\"y\",\"y\"),T=b.makeCalcdata(e,\"x\"),k=w.makeCalcdata(e,\"y\"),A=o(e,b,\"x\",T),M=o(e,w,\"y\",k),S=A.vals,E=M.vals,C=e._length,L=new Array(C),I=e.ids,P=g(e,_,b,w),z=!1;d(_,e);var O,D=\"x\",R=\"y\";P?(i.pushUnique(P.traceIndices,e._expandedIndex),(r=\"v\"===P.orientation)?(R=\"s\",O=\"x\"):(D=\"s\",O=\"y\"),v=\"interpolate\"===P.stackgaps):f(t,e,b,w,S,E,p(e,C));var F=!!e.xperiodalignment,B=!!e.yperiodalignment;for(l=0;l<C;l++){var N=L[l]={},j=n(S[l]),U=n(E[l]);j&&U?(N[D]=S[l],N[R]=E[l],F&&(N.orig_x=T[l],N.xEnd=A.ends[l],N.xStart=A.starts[l]),B&&(N.orig_y=k[l],N.yEnd=M.ends[l],N.yStart=M.starts[l])):P&&(r?j:U)?(N[O]=r?S[l]:E[l],N.gap=!0,v?(N.s=s,z=!0):N.s=0):N[D]=N[R]=s,I&&(N.id=String(I[l]))}if(u(L,e),c(t,e),h(L,e),P){for(l=0;l<L.length;)L[l][O]===s?L.splice(l,1):l++;if(i.sort(L,(function(t,e){return t[O]-e[O]||t.i-e.i})),z){for(l=0;l<L.length-1&&L[l].gap;)l++;for((x=L[l].s)||(x=L[l].s=0),m=0;m<l;m++)L[m].s=x;for(y=L.length-1;y>l&&L[y].gap;)y--;for(x=L[y].s,m=L.length-1;m>y;m--)L[m].s=x;for(;l<y;)if(L[++l].gap){for(m=l+1;L[m].gap;)m++;for(var V=L[l-1][O],q=L[l-1].s,H=(L[m].s-q)/(L[m][O]-V);l<m;)L[l].s=q+(L[l][O]-V)*H,l++}}}return L},calcMarkerSize:p,calcAxisExpansion:f,setFirstScatter:d,getStackOpts:g}},48861:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},77272:function(t,e,r){\"use strict\";var n=r(65477).hasColorscale,i=r(28379),a=r(64726);t.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},32660:function(t){\"use strict\";t.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},75603:function(t,e,r){\"use strict\";var n=r(26544),i=r(24782).setGroupPositions;function a(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}t.exports=function(t,e){\"group\"===t._fullLayout.scattermode&&function(t,e){for(var r=e.xaxis,n=e.yaxis,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=[],c=[],u=0;u<o.length;u++){var h=o[u];!0===h.visible&&\"scatter\"===h.type&&h.xaxis===r._id&&h.yaxis===n._id&&(\"h\"===h.orientation?l.push(s[u]):\"v\"===h.orientation&&c.push(s[u]))}var f={mode:a.scattermode,gap:a.scattergap};i(t,r,n,c,f),i(t,n,r,l,f)}(t,e);var r=e.xaxis,o=e.yaxis,s=r._id+o._id,l=t._fullLayout._scatterStackOpts[s];if(l){var c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k=t.calcdata;for(var A in l){var M=(v=l[A]).traceIndices;if(M.length){for(x=\"interpolate\"===v.stackgaps,_=v.groupnorm,\"v\"===v.orientation?(b=\"x\",w=\"y\"):(b=\"y\",w=\"x\"),T=new Array(M.length),c=0;c<T.length;c++)T[c]=!1;d=k[M[0]];var S=new Array(d.length);for(c=0;c<d.length;c++)S[c]=d[c][b];for(c=1;c<M.length;c++){for(p=k[M[c]],u=h=0;u<p.length;u++){for(m=p[u][b];m>S[h]&&h<S.length;h++)a(p,u,S[h],c,T,x,b),u++;if(m!==S[h]){for(f=0;f<c;f++)a(k[M[f]],h,m,f,T,x,b);S.splice(h,0,m)}h++}for(;h<S.length;h++)a(p,u,S[h],c,T,x,b),u++}var E=S.length;for(u=0;u<d.length;u++){for(g=d[u][w]=d[u].s,c=1;c<M.length;c++)(p=k[M[c]])[0].trace._rawLength=p[0].trace._length,p[0].trace._length=E,g+=p[u].s,p[u][w]=g;if(_)for(y=(\"fraction\"===_?g:g/100)||1,c=0;c<M.length;c++){var C=k[M[c]][u];C[w]/=y,C.sNorm=C.s/y}}for(c=0;c<M.length;c++){var L=(p=k[M[c]])[0].trace,I=n.calcMarkerSize(L,L._rawLength),P=Array.isArray(I);if(I&&T[c]||P){var z=I;for(I=new Array(E),u=0;u<E;u++)I[u]=p[u].gap?0:P?z[p[u].i]:z}var O=new Array(E),D=new Array(E);for(u=0;u<E;u++)O[u]=p[u].x,D[u]=p[u].y;n.calcAxisExpansion(t,L,r,o,O,D,I),p[0].t.orientation=v.orientation}}}}}},53044:function(t,e,r){\"use strict\";var n=r(34809),i=r(36301),a=r(36640);t.exports=function(t,e){var r,o,s;function l(t){return n.coerce(o._input,o,a,t)}if(\"group\"===e.scattermode)for(s=0;s<t.length;s++)\"scatter\"===(o=t[s]).type&&(r=o._input,i(r,o,e,l));for(s=0;s<t.length;s++){var c=t[s];if(\"scatter\"===c.type){var u=c.fill;if(\"none\"!==u&&\"toself\"!==u&&(c.opacity=void 0,\"tonexty\"===u||\"tonextx\"===u))for(var h=s-1;h>=0;h--){var f=t[h];if(\"scatter\"===f.type&&f.xaxis===c.xaxis&&f.yaxis===c.yaxis){f.opacity=void 0;break}}}}}},40247:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626),a=r(36640),o=r(32660),s=r(64726),l=r(99867),c=r(99669),u=r(382),h=r(24272),f=r(98168),p=r(91602),d=r(663),m=r(54114),g=r(34809).coercePattern;t.exports=function(t,e,r,y){function v(r,i){return n.coerce(t,e,a,r,i)}var x=l(t,e,y,v);if(x||(e.visible=!1),e.visible){c(t,e,y,v),v(\"xhoverformat\"),v(\"yhoverformat\"),v(\"zorder\");var _=u(t,e,y,v);\"group\"===y.scattermode&&void 0===e.orientation&&v(\"orientation\",\"v\");var b=!_&&x<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",b),s.hasMarkers(e)&&h(t,e,r,y,v,{gradient:!0}),s.hasLines(e)&&(f(t,e,r,y,v,{backoff:!0}),p(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasText(e)&&(v(\"texttemplate\"),d(t,e,y,v));var w=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),w.push(\"points\")),v(\"fill\",_?_.fillDflt:\"none\"),\"none\"!==e.fill&&(m(t,e,r,v,{moduleHasFillgradient:!0}),s.hasLines(e)||p(t,e,v),g(v,\"fillpattern\",e.fillcolor,!1));var T=(e.line||{}).color,k=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||w.push(\"fills\"),v(\"hoveron\",w.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var A=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");A(t,e,T||k||r,{axis:\"y\"}),A(t,e,T||k||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},19326:function(t){\"use strict\";t.exports=function(t){return{valType:\"color\",editType:\"style\",anim:!0}}},54114:function(t,e,r){\"use strict\";var n=r(78766),i=r(34809).isArrayOrTypedArray;t.exports=function(t,e,r,a,o){o||(o={});var s,l=!1;if(e.marker){var c=e.marker.color,u=(e.marker.line||{}).color;c&&!i(c)?l=c:u&&!i(u)&&(l=u)}if(o.moduleHasFillgradient&&\"none\"!==a(\"fillgradient.type\")){a(\"fillgradient.start\"),a(\"fillgradient.stop\");var h=a(\"fillgradient.colorscale\");h&&(s=function(t){for(var e=n.interpolate(t[0][1],t[1][1],.5),r=2;r<t.length;r++){var i=n.interpolate(t[r-1][1],t[r][1],.5);e=n.interpolate(e,i,t[r-1][0]/t[r][0])}return e}(h))}a(\"fillcolor\",n.addOpacity((e.line||{}).color||l||s||r,.5))}},15294:function(t,e,r){\"use strict\";var n=r(29714);t.exports=function(t,e,r){var i={},a={_fullLayout:r},o=n.getFromTrace(a,e,\"x\"),s=n.getFromTrace(a,e,\"y\"),l=t.orig_x;void 0===l&&(l=t.x);var c=t.orig_y;return void 0===c&&(c=t.y),i.xLabel=n.tickText(o,o.c2l(l),!0).text,i.yLabel=n.tickText(s,s.c2l(c),!0).text,i}},11539:function(t,e,r){\"use strict\";var n=r(78766),i=r(64726);t.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},36301:function(t,e,r){\"use strict\";var n=r(84391).getAxisGroup;t.exports=function(t,e,r,i){var a=e.orientation,o=e[{v:\"x\",h:\"y\"}[a]+\"axis\"],s=n(r,o)+a,l=r._alignmentOpts||{},c=i(\"alignmentgroup\"),u=l[s];u||(u=l[s]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=i(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}},37255:function(t,e,r){\"use strict\";var n=r(34809),i=r(32141),a=r(33626),o=r(11539),s=r(78766),l=n.fillText;t.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),m=p.c2p(r),g=[d,m],y=h.hoveron||\"\",v=-1!==h.mode.indexOf(\"markers\")?3:.5,x=!!h.xperiodalignment,_=!!h.yperiodalignment;if(-1!==y.indexOf(\"points\")){var b=function(t){var e=Math.max(v,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-m;return Math.max(Math.sqrt(r*r+n*n)-e,1-v/e)},w=i.getDistanceFunction(c,(function(t){if(x){var e=f.c2p(t.xStart),r=f.c2p(t.xEnd);return d>=Math.min(e,r)&&d<=Math.max(e,r)?0:1/0}var n=Math.max(3,t.mrc||0),i=1-1/n,a=Math.abs(f.c2p(t.x)-d);return a<n?i*a/n:a-n+i}),(function(t){if(_){var e=p.c2p(t.yStart),r=p.c2p(t.yEnd);return m>=Math.min(e,r)&&m<=Math.max(e,r)?0:1/0}var n=Math.max(3,t.mrc||0),i=1-1/n,a=Math.abs(p.c2p(t.y)-m);return a<n?i*a/n:a-n+i}),b);if(i.getClosest(u,w,t),!1!==t.index){var T=u[t.index],k=f.c2p(T.x,!0),A=p.c2p(T.y,!0),M=T.mrc||1;t.index=T.i;var S=u[0].t.orientation,E=S&&(T.sNorm||T.s),C=\"h\"===S?E:void 0!==T.orig_x?T.orig_x:T.x,L=\"v\"===S?E:void 0!==T.orig_y?T.orig_y:T.y;return n.extendFlat(t,{color:o(h,T),x0:k-M,x1:k+M,xLabelVal:C,y0:A-M,y1:A+M,yLabelVal:L,spikeDistance:b(T),hovertemplate:h.hovertemplate}),l(T,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(T,h,t),[t]}}function I(t){if(!t)return!1;var e=t.node();try{var r=new DOMPoint(g[0],g[1]);return e.isPointInFill(r)}catch(t){var n=e.ownerSVGElement.createSVGPoint();return n.x=g[0],n.y=g[1],e.isPointInFill(n)}}if(-1!==y.indexOf(\"fills\")&&h._fillElement&&I(h._fillElement)&&!I(h._fillExclusionElement)){var P=function(t){var e,r,n,i,a,o,s,l,c,u=[],h=1/0,d=-1/0,m=1/0,y=-1/0;for(e=0;e<t.length;e++){var v=t[e];v.contains(g)&&(u.push(v),m=Math.min(m,v.ymin),y=Math.max(y,v.ymax))}if(0===u.length)return null;for(r=((m=Math.max(m,0))+(y=Math.min(y,p._length)))/2,e=0;e<u.length;e++)for(i=u[e].pts,n=1;n<i.length;n++)(l=i[n-1][1])>r!=(c=i[n][1])>=r&&(o=i[n-1][0],s=i[n][0],c-l&&(a=o+(s-o)*(r-l)/(c-l),h=Math.min(h,a),d=Math.max(d,a)));return{x0:h=Math.max(h,0),x1:d=Math.min(d,f._length),y0:r,y1:r}}(h._polygons);null===P&&(P={x0:g[0],x1:g[0],y0:g[1],y1:g[1]});var z=s.defaultLine;return s.opacity(h.fillcolor)?z=h.fillcolor:s.opacity((h.line||{}).color)&&(z=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:P.x0,x1:P.x1,y0:P.y0,y1:P.y1,color:z,hovertemplate:!1}),delete t.index,h.text&&!n.isArrayOrTypedArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}},69693:function(t,e,r){\"use strict\";var n=r(64726);t.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:r(36640),layoutAttributes:r(26667),supplyDefaults:r(40247),crossTraceDefaults:r(53044),supplyLayoutDefaults:r(12332),calc:r(26544).calc,crossTraceCalc:r(75603),arraysToCalcdata:r(99203),plot:r(36098),colorbar:r(21146),formatLabels:r(15294),style:r(9408).style,styleOnSelect:r(9408).styleOnSelect,hoverPoints:r(37255),selectPoints:r(32665),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},26667:function(t){\"use strict\";t.exports={scattermode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},scattergap:{valType:\"number\",min:0,max:1,editType:\"calc\"}}},12332:function(t,e,r){\"use strict\";var n=r(34809),i=r(26667);t.exports=function(t,e){var r,a=\"group\"===e.barmode;\"group\"===e.scattermode&&(\"scattergap\",r=a?e.bargap:.2,n.coerce(t,e,i,\"scattergap\",r))}},98168:function(t,e,r){\"use strict\";var n=r(34809).isArrayOrTypedArray,i=r(65477).hasColorscale,a=r(39356);t.exports=function(t,e,r,o,s,l){l||(l={});var c=(t.marker||{}).color;c&&c._inputArray&&(c=c._inputArray),s(\"line.color\",r),i(t,\"line\")?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r),s(\"line.width\"),l.noDash||s(\"line.dash\"),l.backoff&&s(\"line.backoff\")}},5525:function(t,e,r){\"use strict\";var n=r(62203),i=r(63821),a=i.BADNUM,o=i.LOG_CLIP,s=o+.5,l=o-.5,c=r(34809),u=c.segmentsIntersect,h=c.constrain,f=r(32660);t.exports=function(t,e){var r,i,o,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S,E=e.trace||{},C=e.xaxis,L=e.yaxis,I=\"log\"===C.type,P=\"log\"===L.type,z=C._length,O=L._length,D=e.backoff,R=E.marker,F=e.connectGaps,B=e.baseTolerance,N=e.shape,j=\"linear\"===N,U=E.fill&&\"none\"!==E.fill,V=[],q=f.minTolerance,H=t.length,G=new Array(H),Z=0;function W(r){var n=t[r];if(!n)return!1;var i=e.linearized?C.l2p(n.x):C.c2p(n.x),o=e.linearized?L.l2p(n.y):L.c2p(n.y);if(i===a){if(I&&(i=C.c2p(n.x,!0)),i===a)return!1;P&&o===a&&(i*=Math.abs(C._m*O*(C._m>0?s:l)/(L._m*z*(L._m>0?s:l)))),i*=1e3}if(o===a){if(P&&(o=L.c2p(n.y,!0)),o===a)return!1;o*=1e3}return[i,o]}function Y(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function X(t,e){var r=t[0]/z,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==M&&Y(r,n,M,S)&&(i=0),i&&e&&Y(r,n,e[0]/z,e[1]/O)&&(i=0),(1+f.toleranceGrowth*i)*B}function $(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var J,K,Q,tt,et,rt,nt,it=f.maxScreensAway,at=-z*it,ot=z*(1+it),st=-O*it,lt=O*(1+it),ct=[[at,st,ot,st],[ot,st,ot,lt],[ot,lt,at,lt],[at,lt,at,st]];function ut(t){if(t[0]<at||t[0]>ot||t[1]<st||t[1]>lt)return[h(t[0],at,ot),h(t[1],st,lt)]}function ht(t,e){return t[0]===e[0]&&(t[0]===at||t[0]===ot)||t[1]===e[1]&&(t[1]===st||t[1]===lt)||void 0}function ft(t,e,r){return function(n,i){var a=ut(n),o=ut(i),s=[];if(a&&o&&ht(a,o))return s;a&&s.push(a),o&&s.push(o);var l=2*c.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);return l&&((a&&o?l>0==a[t]>o[t]?a:o:a||o)[t]+=l),s}}function pt(t){var e=t[0],r=t[1],n=e===G[Z-1][0],i=r===G[Z-1][1];if(!n||!i)if(Z>1){var a=e===G[Z-2][0],o=r===G[Z-2][1];n&&(e===at||e===ot)&&a?o?Z--:G[Z-1]=t:i&&(r===st||r===lt)&&o?a?Z--:G[Z-1]=t:G[Z++]=t}else G[Z++]=t}function dt(t){G[Z-1][0]!==t[0]&&G[Z-1][1]!==t[1]&&pt([Q,tt]),pt(t),et=null,Q=tt=0}\"linear\"===N||\"spline\"===N?nt=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=ct[i],o=u(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&$(o,t)<$(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===N||\"vh\"===N?nt=function(t,e){var r=[],n=ut(t),i=ut(e);return n&&i&&ht(n,i)||(n&&r.push(n),i&&r.push(i)),r}:\"hvh\"===N?nt=ft(0,at,ot):\"vhv\"===N&&(nt=ft(1,st,lt));var mt=c.isArrayOrTypedArray(R);function gt(e){if(e&&D&&(e.i=r,e.d=t,e.trace=E,e.marker=mt?R[e.i]:R,e.backoff=D),M=e[0]/z,S=e[1]/O,J=e[0]<at?at:e[0]>ot?ot:0,K=e[1]<st?st:e[1]>lt?lt:0,J||K){if(Z)if(et){var n=nt(et,e);n.length>1&&(dt(n[0]),G[Z++]=n[1])}else rt=nt(G[Z-1],e)[0],G[Z++]=rt;else G[Z++]=[J||e[0],K||e[1]];var i=G[Z-1];J&&K&&(i[0]!==J||i[1]!==K)?(et&&(Q!==J&&tt!==K?pt(Q&&tt?(a=et,s=(o=e)[0]-a[0],l=(o[1]-a[1])/s,(a[1]*o[0]-o[1]*a[0])/s>0?[l>0?at:ot,lt]:[l>0?ot:at,st]):[Q||J,tt||K]):Q&&tt&&pt([Q,tt])),pt([J,K])):Q-J&&tt-K&&pt([J||Q,K||tt]),et=e,Q=J,tt=K}else et&&dt(nt(et,e)[0]),G[Z++]=e;var a,o,s,l}for(r=0;r<H;r++)if(i=W(r)){for(Z=0,et=null,gt(i),r++;r<H;r++){if(!(p=W(r))){if(F)continue;break}if(j&&e.simplify){var yt=W(r+1);if(x=$(p,i),U&&(0===Z||Z===H-1)||!(x<X(p,yt)*q)){for(y=[(p[0]-i[0])/x,(p[1]-i[1])/x],d=i,_=x,b=T=k=0,g=!1,o=p,r++;r<t.length;r++){if(m=yt,yt=W(r+1),!m){if(F)continue;break}if(A=(v=[m[0]-i[0],m[1]-i[1]])[0]*y[1]-v[1]*y[0],T=Math.min(T,A),(k=Math.max(k,A))-T>X(m,yt))break;o=m,(w=v[0]*y[0]+v[1]*y[1])>_?(_=w,p=m,g=!1):w<b&&(b=w,d=m,g=!0)}if(g?(gt(p),o!==d&&gt(d)):(d!==i&&gt(d),o!==p&&gt(p)),gt(o),r>=t.length||!m)break;gt(m),i=m}}else gt(p)}et&&pt([Q||et[0],tt||et[1]]),V.push(G.slice(0,Z))}var vt=N.slice(N.length-1);if(D&&\"h\"!==vt&&\"v\"!==vt){for(var xt=!1,_t=-1,bt=[],wt=0;wt<V.length;wt++)for(var Tt=0;Tt<V[wt].length-1;Tt++){var kt=V[wt][Tt],At=V[wt][Tt+1],Mt=n.applyBackoff(At,kt);Mt[0]===At[0]&&Mt[1]===At[1]||(xt=!0),bt[_t+1]||(bt[++_t]=[kt,[Mt[0],Mt[1]]])}return xt?bt:V}return V}},91602:function(t){\"use strict\";t.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},17210:function(t){\"use strict\";var e={tonextx:1,tonexty:1,tonext:1};t.exports=function(t,r,n){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<n.length;a++)(o=(i=n[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in e&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=n.slice();u&&d.sort((function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index}));var m={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in e&&(s=m[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),m[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},92527:function(t,e,r){\"use strict\";var n=r(10721);t.exports=function(t,e){e||(e=2);var r=t.marker,i=r.sizeref||1,a=r.sizemin||0,o=\"area\"===r.sizemode?function(t){return Math.sqrt(t/i)}:function(t){return t/i};return function(t){var r=o(t/e);return n(r)&&r>0?Math.max(r,a):0}}},21146:function(t){\"use strict\";t.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},24272:function(t,e,r){\"use strict\";var n=r(78766),i=r(65477).hasColorscale,a=r(39356),o=r(64726);t.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),c.noAngle||(l(\"marker.angle\"),c.noAngleRef||l(\"marker.angleref\"),c.noStandOff||l(\"marker.standoff\")),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient&&\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\")}},99669:function(t,e,r){\"use strict\";var n=r(34809).dateTick0,i=r(63821).ONEWEEK;function a(t,e){return n(e,t%i==0?1:0)}t.exports=function(t,e,r,n,i){if(i||(i={x:!0,y:!0}),i.x){var o=n(\"xperiod\");o&&(n(\"xperiod0\",a(o,e.xcalendar)),n(\"xperiodalignment\"))}if(i.y){var s=n(\"yperiod\");s&&(n(\"yperiod0\",a(s,e.ycalendar)),n(\"yperiodalignment\"))}}},36098:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(34809),o=a.ensureSingle,s=a.identity,l=r(62203),c=r(64726),u=r(5525),h=r(17210),f=r(80899).tester;function p(t,e,r,h,p,d,m){var g,y=t._context.staticPlot;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(c.hasMarkers(f)){var p=f.marker.maxdisplayed;if(0!==p){var d=i.filter((function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]})),m=Math.ceil(d.length/p),g=0;o.forEach((function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&g++}));var y=Math.round(g*m/3+Math.floor(g/3)*m/7.1);i.forEach((function(t){delete t.vis})),d.forEach((function(t,e){0===Math.round((e+y)%m)&&(t.vis=!0)}))}}}(0,e,r,h,p);var v=!!m&&m.duration>0;function x(t){return v?t.transition():t}var _=r.xaxis,b=r.yaxis,w=h[0].trace,T=w.line,k=n.select(d),A=o(k,\"g\",\"errorbars\"),M=o(k,\"g\",\"lines\"),S=o(k,\"g\",\"points\"),E=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,A,r,m),!0===w.visible){var C,L;x(k).style(\"opacity\",w.opacity);var I,P,z=w.fill.charAt(w.fill.length-1);\"x\"!==z&&\"y\"!==z&&(z=\"\"),\"y\"===z?(I=1,P=b.c2p(0,!0)):\"x\"===z&&(I=0,P=_.c2p(0,!0)),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var O,D,R=\"\",F=[],B=w._prevtrace,N=null,j=null;B&&(R=B._prevRevpath||\"\",L=B._nextFill,F=B._ownPolygons,N=B._fillsegments,j=B._fillElement);var U,V,q,H,G,Z,W=\"\",Y=\"\",X=[];w._polygons=[];var $=[],J=[],K=a.noop;if(C=w._ownFill,c.hasLines(w)||\"none\"!==w.fill){L&&L.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(T.shape)?(U=l.steps(T.shape),V=l.steps(T.shape.split(\"\").reverse().join(\"\"))):U=V=\"spline\"===T.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),T.smoothing):l.smoothopen(t,T.smoothing)}:function(t){return\"M\"+t.join(\"L\")},q=function(t){return V(t.reverse())},J=u(h,{xaxis:_,yaxis:b,trace:w,connectGaps:w.connectgaps,baseTolerance:Math.max(T.width||1,3)/4,shape:T.shape,backoff:T.backoff,simplify:T.simplify,fill:w.fill}),$=new Array(J.length);var Q=0;for(g=0;g<J.length;g++){var tt,et=J[g];tt&&z?tt.push.apply(tt,et):(tt=et.slice(),$[Q]=tt,Q++)}w._fillElement=null,w._fillExclusionElement=j,w._fillsegments=$.slice(0,Q),$=w._fillsegments,J.length&&(H=J[0][0].slice(),Z=(G=J[J.length-1])[G.length-1].slice()),K=function(t){return function(e){if(O=U(e),D=q(e),W?z?(W+=\"L\"+O.substr(1),Y=D+\"L\"+Y.substr(1)):(W+=\"Z\"+O,Y=D+\"Z\"+Y):(W=O,Y=D),c.hasLines(w)){var r=n.select(this);if(r.datum(h),t)x(r.style(\"opacity\",0).attr(\"d\",O).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=x(r);i.attr(\"d\",O),l.singleLineStyle(h,i)}}}}}var rt=M.selectAll(\".js-line\").data(J);x(rt.exit()).style(\"opacity\",0).remove(),rt.each(K(!1)),rt.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",y?\"none\":\"non-scaling-stroke\").call(l.lineGroupStyle).each(K(!0)),l.setClipUrl(rt,r.layerClipId,t);var nt=function(){var t=new Array($.length);for(g=0;g<$.length;g++)t[g]=f($[g]);return t},it=function(t){var e,r;if(t&&0!==t.length){for(e=new Array(t.length-1+$.length),r=0;r<t.length-1;r++)e[r]=f(t[r]);var n=t[t.length-1].slice();for(n.reverse(),r=0;r<$.length;r++)e[t.length-1+r]=f($[r].concat(n))}else for(e=new Array($.length),r=0;r<$.length;r++){var i=$[r][0].slice(),a=$[r][$[r].length-1].slice();i[I]=a[I]=P;var o=[a,i].concat($[r]);e[r]=f(o)}return e};J.length?(C?(C.datum(h),H&&Z&&(z?(H[I]=Z[I]=P,x(C).attr(\"d\",\"M\"+Z+\"L\"+H+\"L\"+W.substr(1)).call(l.singleFillStyle,t),X=it(null)):(x(C).attr(\"d\",W+\"Z\").call(l.singleFillStyle,t),X=nt())),w._polygons=X,w._fillElement=C):L&&(\"tonext\"===w.fill.substr(0,6)&&W&&R?(\"tonext\"===w.fill?(x(L).attr(\"d\",W+\"Z\"+R+\"Z\").call(l.singleFillStyle,t),X=nt(),w._polygons=X.concat(F)):(x(L).attr(\"d\",W+\"L\"+R.substr(1)+\"Z\").call(l.singleFillStyle,t),X=it(N),w._polygons=X),w._fillElement=L):ot(L)),w._prevRevpath=Y):(C?ot(C):L&&ot(L),w._prevRevpath=null),w._ownPolygons=X,S.datum(h),E.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=ht(u),d=ft,m=ft;if(h||f){var g=s,y=u.stackgroup,w=y&&\"infer zero\"===t._fullLayout._scatterStackOpts[_._id+b._id][y].stackgaps;u.marker.maxdisplayed||u._needsCull?g=w?lt:st:y&&!w&&(g=ct),h&&(d=g),f&&(m=g)}var T,k=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);v&&k.call(l.pointStyle,u,t).call(l.translatePoints,_,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(T=l.makePointStyleFns(u)),o.each((function(e){var i=n.select(this),a=x(i);l.translatePoint(e,a,_,b)?(l.singlePointStyle(e,a,u,T,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,_,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()})),v?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(m,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each((function(t){var e=n.select(this),i=x(e.select(\"text\"));l.translatePoint(t,i,_,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,_,b,u.xcalendar,u.ycalendar):e.remove()})),o.selectAll(\"text\").call(l.textPointStyle,u,t).each((function(t){var e=_.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each((function(){x(n.select(this)).attr({x:e,y:r})}))})),o.exit().remove()}(S,E,h);var at=!1===w.cliponaxis?null:r.layerClipId;l.setClipUrl(S,at,t),l.setClipUrl(E,at,t)}function ot(t){x(t).attr(\"d\",\"M0,0Z\")}function st(t){return t.filter((function(t){return!t.gap&&t.vis}))}function lt(t){return t.filter((function(t){return t.vis}))}function ct(t){return t.filter((function(t){return!t.gap}))}function ut(t){return t.id}function ht(t){if(t.ids)return ut}function ft(){return!1}}t.exports=function(t,e,r,i,a,c){var u,f,d=!a,m=!!a&&a.duration>0,g=h(t,e,r);(u=i.selectAll(\"g.trace\").data(g,(function(t){return t[0].trace.uid}))).enter().append(\"g\").attr(\"class\",(function(t){return\"trace scatter trace\"+t[0].trace.uid})).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each((function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each((function(t){a[t]=null})).remove(),u.order().each((function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")}))}))}(t,u,e),m?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",(function(){f&&f()})).each(\"interrupt\",(function(){f&&f()})).each((function(){i.selectAll(\"g.trace\").each((function(r,n){p(t,n,e,r,g,this,a)}))}))):u.each((function(r,n){p(t,n,e,r,g,this,a)})),d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},32665:function(t,e,r){\"use strict\";var n=r(64726);t.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},382:function(t){\"use strict\";var e=[\"orientation\",\"groupnorm\",\"stackgaps\"];t.exports=function(t,r,n,i){var a=n._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=r.xaxis+r.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(r):(c=l[o]={traceIndices:[],traces:[r]},u=!0);for(var h={orientation:r.x&&!r.y?\"h\":\"v\"},f=0;f<e.length;f++){var p=e[f],d=p+\"Found\";if(!c[d]){var m=void 0!==t[p],g=\"orientation\"===p;if((m||u)&&(c[p]=i(p,h[p]),g&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),m&&(c[d]=!0,!u&&(delete c.traces[0][p],g))))for(var y=0;y<c.traces.length-1;y++){var v=c.traces[y];v._input.fill!==v.fill&&(v.fill=c.fillDflt)}}}return c}}},9408:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(33626);function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}t.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.selectAll(\"g.points\").each((function(e){o(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.text\").each((function(e){s(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle,t,!1),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},64726:function(t,e,r){\"use strict\";var n=r(34809),i=r(87800).isTypedArraySpec;t.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){var e=t.marker;return n.isPlainObject(e)&&(n.isArrayOrTypedArray(e.size)||i(e.size))}}},663:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",a.font||r.font,a),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},99867:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626);t.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},14117:function(t,e,r){\"use strict\";var n=r(36640),i=r(80337),a=r(87163),o=r(80712).axisHoverFormat,s=r(3208).rb,l=r(3208).ay,c=r(9829),u=r(84770),h=r(49467),f=r(93049).extendFlat,p=r(13582).overrideAll,d=r(62994),m=n.line,g=n.marker,y=g.line,v=f({width:m.width,dash:{valType:\"enumerated\",values:d(u),dflt:\"solid\"}},a(\"line\")),x=t.exports=p({x:n.x,y:n.y,z:{valType:\"data_array\"},text:f({},n.text,{}),texttemplate:l({},{}),hovertext:f({},n.hovertext,{}),hovertemplate:s(),xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),zhoverformat:o(\"z\"),mode:f({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:v,marker:f({symbol:{valType:\"enumerated\",values:d(h),dflt:\"circle\",arrayOk:!0},size:f({},g.size,{dflt:8}),sizeref:g.sizeref,sizemin:g.sizemin,sizemode:g.sizemode,opacity:f({},g.opacity,{arrayOk:!1}),colorbar:g.colorbar,line:f({width:f({},y.width,{arrayOk:!1})},a(\"marker.line\"))},a(\"marker\")),textposition:f({},n.textposition,{dflt:\"top center\"}),textfont:i({noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0,editType:\"calc\",colorEditType:\"style\",arrayOk:!0,variantValues:[\"normal\",\"small-caps\"]}),opacity:c.opacity,hoverinfo:f({},c.hoverinfo)},\"calc\",\"nested\");x.x.editType=x.y.editType=x.z.editType=\"calc+clearAxisTypes\"},37593:function(t,e,r){\"use strict\";var n=r(99203),i=r(77272);t.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},95447:function(t,e,r){\"use strict\";var n=r(33626);function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}t.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},16533:function(t,e,r){\"use strict\";var n=r(99098).gl_line3d,i=r(99098).gl_scatter3d,a=r(99098).gl_error3d,o=r(99098).gl_mesh3d,s=r(99098).delaunay_triangulate,l=r(34809),c=r(55010),u=r(46998).formatColor,h=r(92527),f=r(84770),p=r(49467),d=r(29714),m=r(36040).appendArrayPointValue,g=r(95447);function y(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=y.prototype;function x(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function _(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function b(t,e){return e(4*t)}function w(t){return p[t]}function T(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function k(t){if(l.isArrayOrTypedArray(t)){var e=t[0];return l.isArrayOrTypedArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map((function(t){return Math.round(255*t)}))+\")\"}return null}function A(t){return l.isArrayOrTypedArray(t)?4===t.length&&\"number\"==typeof t[0]?k(t):t.map(k):null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(l.isArrayOrTypedArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,p,y,v=this.scene.glplot.gl,k=f.solid;this.data=t;var M=function(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,y=t.dataScale,v=p.xaxis,k=p.yaxis,A=p.zaxis,M=e.marker,S=e.line,E=e.x||[],C=e.y||[],L=e.z||[],I=E.length,P=e.xcalendar,z=e.ycalendar,O=e.zcalendar;for(o=0;o<I;o++)r=v.d2l(E[o],0,P)*y[0],n=k.d2l(C[o],0,z)*y[1],i=A.d2l(L[o],0,O)*y[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(l.isTypedArray(e.text))s=Array.from(e.text);else if(void 0!==e.text)for(s=new Array(I),o=0;o<I;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,I):I,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var U={x:E[o],y:C[o],z:L[o]},V={xLabel:D(\"xaxis\",E[o]),yLabel:D(\"yaxis\",C[o]),zLabel:D(\"zaxis\",L[o])},q={};m(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),V,F,q,U,H)}}if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(S,1,I),a.lineWidth=S.width,a.lineDashes=S.dash),\"marker\"in e){var G=h(e);a.scatterColor=u(M,1,I),a.scatterSize=T(M.size,I,b,20,G),a.scatterMarker=T(M.symbol,I,w,\"\u25cf\"),a.scatterLineWidth=M.line.width,a.scatterLineColor=u(M.line,1,I),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=_(t[r]));else e[0]=x(t),e[1]=_(t);return e}(e.textposition),a.textColor=u(e.textfont,1,I),a.textSize=T(e.textfont.size,I,l.identity,12),a.textFontFamily=e.textfont.family,a.textFontWeight=e.textfont.weight,a.textFontStyle=e.textfont.style,a.textFontVariant=e.textfont.variant,a.textAngle=0);var Z=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Z[o]];(a.project[o]=W.show)&&(a.projectOpacity[o]=W.opacity,a.projectScale[o]=W.scale)}a.errorBounds=g(e,y,p);var Y=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=Y.color,a.errorLineWidth=Y.lineWidth,a.errorCapSize=Y.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}(this.scene,t);\"mode\"in M&&(this.mode=M.mode),\"lineDashes\"in M&&M.lineDashes in f&&(k=f[M.lineDashes]),this.color=A(M.scatterColor)||A(M.lineColor),this.dataPoints=M.position,e={gl:this.scene.glplot.gl,position:M.position,color:M.lineColor,lineWidth:M.lineWidth||1,dashes:k[0],dashScale:k[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var S=t.opacity;if(t.marker&&void 0!==t.marker.opacity&&(S*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:M.position,color:M.scatterColor,size:M.scatterSize,glyph:M.scatterMarker,opacity:S,orthographic:!0,lineWidth:M.scatterLineWidth,lineColor:M.scatterLineColor,project:M.project,projectScale:M.projectScale,projectOpacity:M.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),y={gl:this.scene.glplot.gl,position:M.position,glyph:M.text,color:M.textColor,size:M.textSize,angle:M.textAngle,alignment:M.textOffset,font:M.textFontFamily,fontWeight:M.textFontWeight,fontStyle:M.textFontStyle,fontVariant:M.textFontVariant,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(y):(this.textMarkers=i(y),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),p={gl:this.scene.glplot.gl,position:M.position,color:M.errorColor,error:M.errorBounds,lineWidth:M.errorLineWidth,capSize:M.errorCapSize,opacity:t.opacity},this.errorBars?M.errorBounds?this.errorBars.update(p):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):M.errorBounds&&(this.errorBars=a(p),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),M.delaunayAxis>=0){var E=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(M.position,M.delaunayColor,M.delaunayAxis);E.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(E):(E.gl=v,this.delaunayMesh=o(E),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},t.exports=function(t,e){var r=new y(t,e.uid);return r.update(e),r}},82418:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(64726),o=r(24272),s=r(98168),l=r(663),c=r(14117);t.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}var f=function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");return n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a),a}(t,e,h,u);if(f){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"xhoverformat\"),h(\"yhoverformat\"),h(\"zhoverformat\"),h(\"mode\"),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0,noAngle:!0}),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasText(e)&&(h(\"texttemplate\"),l(t,e,u,h,{noSelect:!0,noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0}));var p=(e.line||{}).color,d=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",p||d);for(var m=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var y=\"projection.\"+m[g];h(y+\".show\")&&(h(y+\".opacity\"),h(y+\".scale\"))}var v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,p||d||r,{axis:\"z\"}),v(t,e,p||d||r,{axis:\"y\",inherit:\"z\"}),v(t,e,p||d||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},17822:function(t,e,r){\"use strict\";t.exports={plot:r(16533),attributes:r(14117),markerSymbols:r(49467),supplyDefaults:r(82418),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:r(37593),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:r(2487),categories:[\"gl3d\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},54637:function(t,e,r){\"use strict\";var n=r(19326),i=r(36640),a=r(9829),o=r(3208).rb,s=r(3208).ay,l=r(87163),c=r(93049).extendFlat,u=i.marker,h=i.line,f=u.line;t.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:c({},i.mode,{dflt:\"markers\"}),text:c({},i.text,{}),texttemplate:s({editType:\"plot\"},{keys:[\"a\",\"b\",\"text\"]}),hovertext:c({},i.hovertext,{}),line:{color:h.color,width:h.width,dash:h.dash,backoff:h.backoff,shape:c({},h.shape,{values:[\"linear\",\"spline\"]}),smoothing:h.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,fill:c({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n(),marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,angle:u.angle,angleref:u.angleref,standoff:u.standoff,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:f.width,editType:\"calc\"},l(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},l(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:c({},a.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:o(),zorder:i.zorder}},68001:function(t,e,r){\"use strict\";var n=r(10721),i=r(77272),a=r(99203),o=r(48861),s=r(26544).calcMarkerSize,l=r(26571);t.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var m=r.ab2xy(+u,+h,!0),g=r.isVisible(+u,+h);g||(d=!0),p[c]={x:m[0],y:m[1],a:u,b:h,vis:g}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},16986:function(t,e,r){\"use strict\";var n=r(34809),i=r(32660),a=r(64726),o=r(24272),s=r(98168),l=r(91602),c=r(663),u=r(54114),h=r(54637);t.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),m=p(\"b\"),g=Math.min(d.length,m.length);if(g){e._length=g,p(\"text\"),p(\"texttemplate\"),p(\"hovertext\"),p(\"mode\",g<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasLines(e)&&(s(t,e,r,f,p,{backoff:!0}),l(t,e,p),p(\"connectgaps\")),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),\"fills\"!==p(\"hoveron\",y.join(\"+\")||\"points\")&&p(\"hovertemplate\"),p(\"zorder\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},68289:function(t){\"use strict\";t.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},32709:function(t){\"use strict\";t.exports=function(t,e){var r={},n=e._carpet,i=n.ab2ij([t.a,t.b]),a=Math.floor(i[0]),o=i[0]-a,s=Math.floor(i[1]),l=i[1]-s,c=n.evalxy([],a,s,o,l);return r.yLabel=c[1].toFixed(3),r}},59420:function(t,e,r){\"use strict\";var n=r(37255),i=r(34809).fillText;t.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,m=p._module.formatLabels(f,p);s.yLabel=m.yLabel,delete s.text;var g=[];if(!p.hovertemplate){var y=(f.hi||p.hoverinfo).split(\"+\");-1!==y.indexOf(\"all\")&&(y=[\"a\",\"b\",\"text\"]),-1!==y.indexOf(\"a\")&&v(d.aaxis,f.a),-1!==y.indexOf(\"b\")&&v(d.baxis,f.b),g.push(\"y: \"+s.yLabel),-1!==y.indexOf(\"text\")&&i(f,p,g),s.extraText=g.join(\"<br>\")}return o}function v(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,g.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},56534:function(t,e,r){\"use strict\";t.exports={attributes:r(54637),supplyDefaults:r(16986),colorbar:r(21146),formatLabels:r(32709),calc:r(68001),plot:r(64535),style:r(9408).style,styleOnSelect:r(9408).styleOnSelect,hoverPoints:r(59420),selectPoints:r(32665),eventData:r(68289),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:r(37703),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},64535:function(t,e,r){\"use strict\";var n=r(36098),i=r(29714),a=r(62203);t.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h=i.getFromId(t,u.xaxis||\"x\"),f=i.getFromId(t,u.yaxis||\"y\"),p={xaxis:h,yaxis:f,plot:e.plot};for(s=0;s<r.length;s++)(l=r[s][0].trace)._xA=h,l._yA=f;for(n(t,p,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},6893:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(19326),o=r(36640),s=r(9829),l=r(87163),c=r(94850).T,u=r(93049).extendFlat,h=r(13582).overrideAll,f=o.marker,p=o.line,d=f.line;t.exports=h({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\",\"geojson-id\"],dflt:\"ISO-3\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:{valType:\"string\",editType:\"calc\",dflt:\"id\"},mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"location\",\"text\"]}),hovertext:u({},o.hovertext,{}),textfont:o.textfont,textposition:o.textposition,line:{color:p.color,width:p.width,dash:c},connectgaps:o.connectgaps,marker:u({symbol:f.symbol,opacity:f.opacity,angle:f.angle,angleref:u({},f.angleref,{values:[\"previous\",\"up\",\"north\"]}),standoff:f.standoff,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,colorbar:f.colorbar,line:u({width:d.width},l(\"marker.line\")),gradient:f.gradient},l(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:a(),selected:o.selected,unselected:o.unselected,hoverinfo:u({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},75649:function(t,e,r){\"use strict\";var n=r(10721),i=r(63821).BADNUM,a=r(77272),o=r(99203),s=r(48861),l=r(34809).isArrayOrTypedArray,c=r(34809)._;function u(t){return t&&\"string\"==typeof t}t.exports=function(t,e){var r,h=l(e.locations),f=h?e.locations.length:e._length,p=new Array(f);r=e.geojson?function(t){return u(t)||n(t)}:u;for(var d=0;d<f;d++){var m=p[d]={};if(h){var g=e.locations[d];m.loc=r(g)?g:null}else{var y=e.lon[d],v=e.lat[d];n(y)&&n(v)?m.lonlat=[+y,+v]:m.lonlat=[i,i]}}return o(p,e),a(t,e),s(p,e),f&&(p[0].t={labels:{lat:c(t,\"lat:\")+\" \",lon:c(t,\"lon:\")+\" \"}}),p}},27386:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(24272),o=r(98168),s=r(663),l=r(54114),c=r(6893);t.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}var f,p=h(\"locations\");if(p&&p.length){var d,m=h(\"geojson\");(\"string\"==typeof m&&\"\"!==m||n.isPlainObject(m))&&(d=\"geojson-id\"),\"geojson-id\"===h(\"locationmode\",d)&&h(\"featureidkey\"),f=p.length}else{var g=h(\"lon\")||[],y=h(\"lat\")||[];f=Math.min(g.length,y.length)}f?(e._length=f,h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasText(e)&&(h(\"texttemplate\"),s(t,e,u,h)),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)):e.visible=!1}},71873:function(t){\"use strict\";t.exports=function(t,e,r,n,i){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t}},57413:function(t,e,r){\"use strict\";var n=r(29714);t.exports=function(t,e,r){var i={},a=r[e.geo]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},40636:function(t,e,r){\"use strict\";var n=r(32141),i=r(63821).BADNUM,a=r(11539),o=r(34809).fillText,s=r(6893);t.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=f.projection.isLonLatOverEdges,d=f.project;if(n.getClosest(l,(function(t){var n=t.lonlat;if(n[0]===i)return 1/0;if(p(n))return 1/0;var a=d(n),o=d([e,r]),s=Math.abs(a[0]-o[0]),l=Math.abs(a[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)}),t),!1!==t.index){var m=l[t.index],g=m.lonlat,y=[u.c2p(g),h.c2p(g)],v=m.mrc||1;t.x0=y[0]-v,t.x1=y[0]+v,t.y0=y[1]-v,t.y1=y[1]+v,t.loc=m.loc,t.lon=g[0],t.lat=g[1];var x={};x[c.geo]={_subplot:f};var _=c._module.formatLabels(m,c,x);return t.lonLabel=_.lonLabel,t.latLabel=_.latLabel,t.color=a(c,m),t.extraText=function(t,e,r,n){if(!t.hovertemplate){var i=e.hi||t.hoverinfo,a=\"all\"===i?s.hoverinfo.flags:i.split(\"+\"),l=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];return l?f.push(e.loc):c&&u?f.push(\"(\"+p(r.latLabel)+\", \"+p(r.lonLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel)),h&&o(e,t,f),f.join(\"<br>\")}function p(t){return t+\"\u00b0\"}}(c,m,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},18070:function(t,e,r){\"use strict\";t.exports={attributes:r(6893),supplyDefaults:r(27386),colorbar:r(21146),formatLabels:r(57413),calc:r(75649),calcGeoJSON:r(48887).calcGeoJSON,plot:r(48887).plot,style:r(60367),styleOnSelect:r(9408).styleOnSelect,hoverPoints:r(40636),eventData:r(71873),selectPoints:r(45852),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:r(47544),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},48887:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(11577).getTopojsonFeatures,o=r(39532),s=r(3994),l=r(32919).findExtremes,c=r(63821).BADNUM,u=r(26544).calcMarkerSize,h=r(64726),f=r(60367);t.exports={calcGeoJSON:function(t,e){var r,n,o=t[0].trace,h=e[o.geo],f=h._subplot,p=o._length;if(i.isArrayOrTypedArray(o.locations)){var d=o.locationmode,m=\"geojson-id\"===d?s.extractTraceFeature(t):a(o,f.topojson);for(r=0;r<p;r++){n=t[r];var g=\"geojson-id\"===d?n.fOut:s.locationToFeature(d,n.loc,m);n.lonlat=g?g.properties.ct:[c,c]}}var y,v,x={padded:!0};if(\"geojson\"===h.fitbounds&&\"geojson-id\"===o.locationmode){var _=s.computeBbox(s.getTraceGeojson(o));y=[_[0],_[2]],v=[_[1],_[3]]}else{for(y=new Array(p),v=new Array(p),r=0;r<p;r++)n=t[r],y[r]=n.lonlat[0],v[r]=n.lonlat[1];x.ppad=u(o,p)}o._extremes.lon=l(h.lonaxis._ax,y,x),o._extremes.lat=l(h.lataxis._ax,v,x)},plot:function(t,e,r){var a=e.layers.frontplot.select(\".scatterlayer\"),s=i.makeTraceGroups(a,r,\"trace scattergeo\");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll(\"*\").remove(),s.each((function(e){var r=n.select(this),a=e[0].trace;if(h.hasLines(a)||\"none\"!==a.fill){var s=o.calcTraceToLineCoords(e),c=\"none\"!==a.fill?o.makePolygon(s):o.makeLine(s);r.selectAll(\"path.js-line\").data([{geojson:c,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}h.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each((function(t){l(t,this)})),h.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each((function(t){l(t,this)})),f(t,e)}))}}},45852:function(t,e,r){\"use strict\";var n=r(64726),i=r(63821).BADNUM;t.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},60367:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(78766),o=r(9408),s=o.stylePoints,l=o.styleText;t.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each((function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)}))}(t,e)}},92089:function(t,e,r){\"use strict\";var n=r(9829),i=r(80337),a=r(19326),o=r(36640),s=r(80712).axisHoverFormat,l=r(87163),c=r(62994),u=r(93049).extendFlat,h=r(13582).overrideAll,f=r(29483).DASHES,p=o.line,d=o.marker,m=d.line,g=t.exports=h({x:o.x,x0:o.x0,dx:o.dx,y:o.y,y0:o.y0,dy:o.dy,xperiod:o.xperiod,yperiod:o.yperiod,xperiod0:o.xperiod0,yperiod0:o.yperiod0,xperiodalignment:o.xperiodalignment,yperiodalignment:o.yperiodalignment,xhoverformat:s(\"x\"),yhoverformat:s(\"y\"),text:o.text,hovertext:o.hovertext,textposition:o.textposition,textfont:i({noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0,editType:\"calc\",colorEditType:\"style\",arrayOk:!0,noNumericWeightValues:!0,variantValues:[\"normal\",\"small-caps\"]}),mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:p.color,width:p.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:c(f),dflt:\"solid\"}},marker:u({},l(\"marker\"),{symbol:d.symbol,angle:d.angle,size:d.size,sizeref:d.sizeref,sizemin:d.sizemin,sizemode:d.sizemode,opacity:d.opacity,colorbar:d.colorbar,line:u({},l(\"marker.line\"),{width:m.width})}),connectgaps:o.connectgaps,fill:u({},o.fill,{dflt:\"none\"}),fillcolor:a(),selected:{marker:o.selected.marker,textfont:o.selected.textfont},unselected:{marker:o.unselected.marker,textfont:o.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");g.x.editType=g.y.editType=g.x0.editType=g.y0.editType=\"calc+clearAxisTypes\",g.hovertemplate=o.hovertemplate,g.texttemplate=o.texttemplate},68258:function(t,e,r){\"use strict\";var n=r(36544);t.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:r(37703),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:r(92089),supplyDefaults:r(86590),crossTraceDefaults:r(53044),colorbar:r(21146),formatLabels:r(99185),calc:r(15293),hoverPoints:n.hoverPoints,selectPoints:r(17168),meta:{}}},15293:function(t,e,r){\"use strict\";var n=r(27549),i=r(34809),a=r(5975),o=r(32919).findExtremes,s=r(40528),l=r(26544),c=l.calcMarkerSize,u=l.calcAxisExpansion,h=l.setFirstScatter,f=r(77272),p=r(19937),d=r(62336),m=r(63821).BADNUM,g=r(29483).TOO_MANY_POINTS;function y(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}t.exports=function(t,e){var r,o=t._fullLayout,l=e._xA=a.getFromId(t,e.xaxis,\"x\"),v=e._yA=a.getFromId(t,e.yaxis,\"y\"),x=o._plots[e.xaxis+e.yaxis],_=e._length,b=_>=g,w=2*_,T={},k=l.makeCalcdata(e,\"x\"),A=v.makeCalcdata(e,\"y\"),M=s(e,l,\"x\",k),S=s(e,v,\"y\",A),E=M.vals,C=S.vals;e._x=E,e._y=C,e.xperiodalignment&&(e._origX=k,e._xStarts=M.starts,e._xEnds=M.ends),e.yperiodalignment&&(e._origY=A,e._yStarts=S.starts,e._yEnds=S.ends);var L=new Array(w),I=new Array(_);for(r=0;r<_;r++)L[2*r]=E[r]===m?NaN:E[r],L[2*r+1]=C[r]===m?NaN:C[r],I[r]=r;if(\"log\"===l.type)for(r=0;r<w;r+=2)L[r]=l.c2l(L[r]);if(\"log\"===v.type)for(r=1;r<w;r+=2)L[r]=v.c2l(L[r]);b&&\"log\"!==l.type&&\"log\"!==v.type?T.tree=n(L):T.ids=I,f(t,e);var P,z=function(t,e,r,n,a,o){var s=p.style(t,r);if(s.marker&&(s.marker.positions=n),s.line&&n.length>1&&i.extendFlat(s.line,p.linePositions(t,r,n)),s.errorX||s.errorY){var l=p.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}return s.text&&(i.extendFlat(s.text,{positions:n},p.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},p.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},p.textPosition(t,r,s.text,s.markerUnsel))),s}(t,0,e,L,E,C),O=d(t,x);return h(o,e),b?z.marker&&(P=z.marker.sizeAvg||Math.max(z.marker.size,3)):P=c(e,_),u(t,e,l,v,E,C,P),z.errorX&&y(e,l,z.errorX),z.errorY&&y(e,v,z.errorY),z.fill&&!O.fill2d&&(O.fill2d=!0),z.marker&&!O.scatter2d&&(O.scatter2d=!0),z.line&&!O.line2d&&(O.line2d=!0),!z.errorX&&!z.errorY||O.error2d||(O.error2d=!0),z.text&&!O.glText&&(O.glText=!0),z.marker&&(z.marker.snap=_),O.lineOptions.push(z.line),O.errorXOptions.push(z.errorX),O.errorYOptions.push(z.errorY),O.fillOptions.push(z.fill),O.markerOptions.push(z.marker),O.markerSelectedOptions.push(z.markerSel),O.markerUnselectedOptions.push(z.markerUnsel),O.textOptions.push(z.text),O.textSelectedOptions.push(z.textSel),O.textUnselectedOptions.push(z.textUnsel),O.selectBatch.push([]),O.unselectBatch.push([]),T._scene=O,T.index=O.count,T.x=E,T.y=C,T.positions=L,O.count++,[{x:!1,y:!1,t:T,trace:e}]}},29483:function(t){\"use strict\";t.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},19937:function(t,e,r){\"use strict\";var n=r(10721),i=r(96021),a=r(162),o=r(33626),s=r(34809),l=s.isArrayOrTypedArray,c=r(62203),u=r(5975),h=r(46998).formatColor,f=r(64726),p=r(92527),d=r(4075),m=r(29483),g=r(20438).DESELECTDIM,y={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=r(36040).appendArrayPointValue;function x(t,e){var r,i=t._fullLayout,a=e._length,o=e.textfont,c=e.textposition,u=l(c)?c:[c],h=o.color,f=o.size,p=o.family,d=o.weight,m=o.style,g=o.variant,y={},x=t._context.plotGlPixelRatio,b=e.texttemplate;if(b){y.text=[];var w=i._d3locale,T=Array.isArray(b),k=T?Math.min(b.length,a):a,A=T?function(t){return b[t]}:function(){return b};for(r=0;r<k;r++){var M={i:r},S=e._module.formatLabels(M,e,i),E={};v(E,e,r);var C=e._meta||{};y.text.push(s.texttemplateString(A(r),S,w,E,M,C))}}else l(e.text)&&e.text.length<a?y.text=e.text.slice():y.text=e.text;if(l(y.text))for(r=y.text.length;r<a;r++)y.text[r]=\"\";for(y.opacity=e.opacity,y.font={},y.align=[],y.baseline=[],r=0;r<u.length;r++){var L=u[r].split(/\\s+/);switch(L[1]){case\"left\":y.align.push(\"right\");break;case\"right\":y.align.push(\"left\");break;default:y.align.push(L[1])}switch(L[0]){case\"top\":y.baseline.push(\"bottom\");break;case\"bottom\":y.baseline.push(\"top\");break;default:y.baseline.push(L[0])}}if(l(h))for(y.color=new Array(a),r=0;r<a;r++)y.color[r]=h[r];else y.color=h;if(l(f)||Array.isArray(p)||l(d)||Array.isArray(m)||Array.isArray(g))for(y.font=new Array(a),r=0;r<a;r++){var I=y.font[r]={};I.size=(s.isTypedArray(f)?f[r]:l(f)?n(f[r])?f[r]:0:f)*x,I.family=Array.isArray(p)?p[r]:p,I.weight=_(l(d)?d[r]:d),I.style=Array.isArray(m)?m[r]:m,I.variant=Array.isArray(g)?g[r]:g}else y.font={size:f*x,family:p,weight:_(d),style:m,variant:g};return y}function _(t){return t<=1e3?t>500?\"bold\":\"normal\":t}function b(t,e){var r,n,i=e._length,o=e.marker,s={},c=l(o.symbol),u=l(o.angle),f=l(o.color),m=l(o.line.color),g=l(o.opacity),y=l(o.size),v=l(o.line.width);if(c||(n=d.isOpenSymbol(o.symbol)),c||f||m||g||u){s.symbols=new Array(i),s.angles=new Array(i),s.colors=new Array(i),s.borderColors=new Array(i);var x=o.symbol,_=o.angle,b=h(o,o.opacity,i),w=h(o.line,o.opacity,i);if(!l(w[0])){var T=w;for(w=Array(i),r=0;r<i;r++)w[r]=T}if(!l(b[0])){var k=b;for(b=Array(i),r=0;r<i;r++)b[r]=k}if(!l(x)){var A=x;for(x=Array(i),r=0;r<i;r++)x[r]=A}if(!l(_)){var M=_;for(_=Array(i),r=0;r<i;r++)_[r]=M}for(s.symbols=x,s.angles=_,s.colors=b,s.borderColors=w,r=0;r<i;r++)c&&(n=d.isOpenSymbol(o.symbol[r])),n&&(w[r]=b[r].slice(),b[r]=b[r].slice(),b[r][3]=0);for(s.opacity=e.opacity,s.markers=new Array(i),r=0;r<i;r++)s.markers[r]=L({mx:s.symbols[r],ma:s.angles[r]},e)}else n?(s.color=a(o.color,\"uint8\"),s.color[3]=0,s.borderColor=a(o.color,\"uint8\")):(s.color=a(o.color,\"uint8\"),s.borderColor=a(o.line.color,\"uint8\")),s.opacity=e.opacity*o.opacity,s.marker=L({mx:o.symbol,ma:o.angle},e);var S,E=p(e,1);if(y||v){var C,I=s.sizes=new Array(i),P=s.borderSizes=new Array(i),z=0;if(y){for(r=0;r<i;r++)I[r]=E(o.size[r]),z+=I[r];C=z/i}else for(S=E(o.size),r=0;r<i;r++)I[r]=S;if(v)for(r=0;r<i;r++)P[r]=o.line.width[r];else for(S=o.line.width,r=0;r<i;r++)P[r]=S;s.sizeAvg=C}else s.size=E(o&&o.size||10),s.borderSizes=E(o.line.width);return s}function w(t,e,r){var n=e.marker,i={};return r?(r.marker&&r.marker.symbol?i=b(0,s.extendFlat({},n,r.marker)):r.marker&&(r.marker.size&&(i.size=r.marker.size),r.marker.color&&(i.colors=r.marker.color),void 0!==r.marker.opacity&&(i.opacity=r.marker.opacity)),i):i}function T(t,e,r){var n={};if(!r)return n;if(r.textfont){var i={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(i.textfont,r.textfont),n=x(t,i)}return n}function k(t,e,r){var n={capSize:2*e.width*r,lineWidth:e.thickness*r,color:e.color};return e.copy_ystyle&&(n=t.error_y),n}var A=m.SYMBOL_SDF_SIZE,M=m.SYMBOL_SIZE,S=m.SYMBOL_STROKE,E={},C=c.symbolFuncs[0](.05*M);function L(t,e){var r,n,a=t.mx;if(\"circle\"===a)return null;var o=c.symbolNumber(a),s=c.symbolFuncs[o%100],l=!!c.symbolNoDot[o%100],u=!!c.symbolNoFill[o%100],h=d.isDotSymbol(a);if(t.ma&&(a+=\"_\"+t.ma),E[a])return E[a];var f=c.getMarkerAngle(t,e);return r=h&&!l?s(1.1*M,f)+C:s(M,f),n=i(r,{w:A,h:A,viewBox:[-M,-M,M,M],stroke:u?S:-S}),E[a]=n,n||null}t.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0},i=t._context.plotGlPixelRatio;if(!0!==e.visible)return n;if(f.hasText(e)&&(n.text=x(t,e),n.textSel=T(t,e,e.selected),n.textUnsel=T(t,e,e.unselected)),f.hasMarkers(e)&&(n.marker=b(0,e),n.markerSel=w(0,e,e.selected),n.markerUnsel=w(0,e,e.unselected),!e.unselected&&l(e.marker.opacity))){var a=e.marker.opacity;for(n.markerUnsel.opacity=new Array(a.length),r=0;r<a.length;r++)n.markerUnsel.opacity[r]=g*a[r]}if(f.hasLines(e)){n.line={overlay:!0,thickness:e.line.width*i,color:e.line.color,opacity:e.opacity};var o=(m.DASHES[e.line.dash]||[1]).slice();for(r=0;r<o.length;++r)o[r]*=e.line.width*i;n.line.dashes=o}return e.error_x&&e.error_x.visible&&(n.errorX=k(e,e.error_x,i)),e.error_y&&e.error_y.visible&&(n.errorY=k(e,e.error_y,i)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:b,markerSelection:w,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(f.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>m.TOO_MANY_POINTS||f.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var h=n[0],p=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=h,n[i+1]=p):(h=n[i],p=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=u.getFromId(t,e.xaxis,\"x\"),c=u.getFromId(t,e.yaxis,\"y\"),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,m=-1/0,g=0,y=0;g<h;g++,y+=4){var v=t[g];if(n(v)){var x=r[2*g+c],_=l(v,g),b=_[0],w=_[1];if(n(b)&&n(w)){var T=v-b,k=v+w;p[y+u[0]]=x-i.c2l(T),p[y+u[1]]=i.c2l(k)-x,p[y+u[2]]=0,p[y+u[3]]=0,d=Math.min(d,v-b),m=Math.max(m,v+w)}}}f[a]={positions:r,errors:p,_bnds:[d,m]}}}return p(i,l),p(a,c),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(f.hasMarkers(e)){var s=r.font,c=r.align,u=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var h=n.sizes?n.sizes[i]:n.size,p=l(s)?s[i].size:s.size,d=l(c)?c.length>1?c[i]:c[0]:c,m=l(u)?u.length>1?u[i]:u[0]:u,g=y[d],v=y[m],x=h?h/.8+1:0,_=-v*x-.5*v;o.offset[i]=[g*x/p,_/p]}}return o}}},86590:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626),a=r(4075),o=r(92089),s=r(32660),l=r(64726),c=r(99867),u=r(99669),h=r(24272),f=r(98168),p=r(54114),d=r(663);t.exports=function(t,e,r,m){function g(r,i){return n.coerce(t,e,o,r,i)}var y=!!t.marker&&a.isOpenSymbol(t.marker.symbol),v=l.isBubble(t),x=c(t,e,m,g);if(x){u(t,e,m,g),g(\"xhoverformat\"),g(\"yhoverformat\");var _=x<s.PTS_LINESONLY?\"lines+markers\":\"lines\";g(\"text\"),g(\"hovertext\"),g(\"hovertemplate\"),g(\"mode\",_),l.hasMarkers(e)&&(h(t,e,r,m,g,{noAngleRef:!0,noStandOff:!0}),g(\"marker.line.width\",y||v?1:0)),l.hasLines(e)&&(g(\"connectgaps\"),f(t,e,r,m,g),g(\"line.shape\")),l.hasText(e)&&(g(\"texttemplate\"),d(t,e,m,g,{noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0}));var b=(e.line||{}).color,w=(e.marker||{}).color;g(\"fill\"),\"none\"!==e.fill&&p(t,e,r,g);var T=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");T(t,e,b||w||r,{axis:\"y\"}),T(t,e,b||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,g)}else e.visible=!1}},85686:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(20438).DESELECTDIM;t.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},m=c.textUnselectedOptions[u]||{},g=n.extendFlat({},p);if(h.length||f.length){var y=d.color,v=m.color,x=p.color,_=n.isArrayOrTypedArray(x);for(g.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],g.color[r]=y||(_?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var b=_?x[r]:x;g.color[r]=v||(y?b:i.addOpacity(b,a))}}c.glText[u].update(g)}}},99185:function(t,e,r){\"use strict\";var n=r(15294);t.exports=function(t,e,r){var i=t.i;return\"x\"in t||(t.x=e._x[i]),\"y\"in t||(t.y=e._y[i]),n(t,e,r)}},4075:function(t,e,r){\"use strict\";var n=r(29483);e.isOpenSymbol=function(t){return\"string\"==typeof t?n.OPEN_RE.test(t):t%200>100},e.isDotSymbol=function(t){return\"string\"==typeof t?n.DOT_RE.test(t):t>200}},36544:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(11539);function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=i.isArrayOrTypedArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=i.isArrayOrTypedArray(p.size)?p.size[h]:p.size,f.tc=i.isArrayOrTypedArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family,f.tw=Array.isArray(p.weight)?p.weight[h]:p.weight,f.ty=Array.isArray(p.style)?p.style[h]:p.style,f.tv=Array.isArray(p.variant)?p.variant[h]:p.variant);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=i.isArrayOrTypedArray(d.symbol)?d.symbol[h]:d.symbol,f.ma=i.isArrayOrTypedArray(d.angle)?d.angle[h]:d.angle,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var m=d&&d.line;m&&(f.mlc=Array.isArray(m.color)?m.color[h]:m.color,f.mlw=i.isArrayOrTypedArray(m.width)?m.width[h]:m.width);var g=d&&d.gradient;g&&\"none\"!==g.type&&(f.mgt=Array.isArray(g.type)?g.type[h]:g.type,f.mgc=Array.isArray(g.color)?g.color[h]:g.color);var y=s.c2p(f.x,!0),v=l.c2p(f.y,!0),x=f.mrc||1,_=o.hoverlabel;_&&(f.hbg=Array.isArray(_.bgcolor)?_.bgcolor[h]:_.bgcolor,f.hbc=Array.isArray(_.bordercolor)?_.bordercolor[h]:_.bordercolor,f.hts=i.isArrayOrTypedArray(_.font.size)?_.font.size[h]:_.font.size,f.htc=Array.isArray(_.font.color)?_.font.color[h]:_.font.color,f.htf=Array.isArray(_.font.family)?_.font.family[h]:_.font.family,f.hnl=i.isArrayOrTypedArray(_.namelength)?_.namelength[h]:_.namelength);var b=o.hoverinfo;b&&(f.hi=Array.isArray(b)?b[h]:b);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var T={};T[t.index]=f;var k=o._origX,A=o._origY,M=i.extendFlat({},t,{color:a(o,f),x0:y-x,x1:y+x,xLabelVal:k?k[h]:f.x,y0:v-x,y1:v+x,yLabelVal:A?A[h]:f.y,cd:T,distance:c,spikeDistance:u,hovertemplate:f.ht});return f.htx?M.text=f.htx:f.tx?M.text=f.tx:o.text&&(M.text=o.text),i.fillText(f,o,M),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,M),M}t.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d,m=t.cd,g=m[0].t,y=m[0].trace,v=t.xa,x=t.ya,_=g.x,b=g.y,w=v.c2p(e),T=x.c2p(r),k=t.distance;if(g.tree){var A=v.p2c(w-k),M=v.p2c(w+k),S=x.p2c(T-k),E=x.p2c(T+k);i=\"x\"===n?g.tree.range(Math.min(A,M),Math.min(x._rl[0],x._rl[1]),Math.max(A,M),Math.max(x._rl[0],x._rl[1])):g.tree.range(Math.min(A,M),Math.min(S,E),Math.max(A,M),Math.max(S,E))}else i=g.ids;var C=k;if(\"x\"===n){var L=!!y.xperiodalignment,I=!!y.yperiodalignment;for(u=0;u<i.length;u++){if(l=_[a=i[u]],h=Math.abs(v.c2p(l)-w),L){var P=v.c2p(y._xStarts[a]),z=v.c2p(y._xEnds[a]);h=w>=Math.min(P,z)&&w<=Math.max(P,z)?0:1/0}if(h<C){if(C=h,c=b[a],f=x.c2p(c)-T,I){var O=x.c2p(y._yStarts[a]),D=x.c2p(y._yEnds[a]);f=T>=Math.min(O,D)&&T<=Math.max(O,D)?0:1/0}d=Math.sqrt(h*h+f*f),s=i[u]}}}else for(u=i.length-1;u>-1;u--)l=_[a=i[u]],c=b[a],h=v.c2p(l)-w,f=x.c2p(c)-T,(p=Math.sqrt(h*h+f*f))<C&&(C=d=p,s=a);return t.index=s,t.distance=C,t.dxy=d,void 0===s?[t]:[o(t,_,b,y)]},calcHover:o}},52378:function(t,e,r){\"use strict\";var n=r(68258);n.plot=r(47731),t.exports=n},47731:function(t,e,r){\"use strict\";var n=r(62172),i=r(49478),a=r(29978),o=r(74024),s=r(34809),l=r(70414).selectMode,c=r(22459),u=r(64726),h=r(17210),f=r(85686).styleTextSelection,p={};function d(t,e,r,n){var i=t._size,a=t.width*n,o=t.height*n,s=i.l*n,l=i.b*n,c=i.r*n,u=i.t*n,h=i.w*n,f=i.h*n;return[s+e.domain[0]*h,l+r.domain[0]*f,a-c-(1-e.domain[1])*h,o-u-(1-r.domain[1])*f]}(t.exports=function(t,e,r){if(r.length){var m,g,y=t._fullLayout,v=e._scene,x=e.xaxis,_=e.yaxis;if(v)if(c(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"],p)){var b=v.count,w=y._glcanvas.data()[0].regl;if(h(t,e,r),v.dirty){if(!v.line2d&&!v.error2d||v.scatter2d||v.fill2d||v.glText||w.clear({}),!0===v.error2d&&(v.error2d=a(w)),!0===v.line2d&&(v.line2d=i(w)),!0===v.scatter2d&&(v.scatter2d=n(w)),!0===v.fill2d&&(v.fill2d=i(w)),!0===v.glText)for(v.glText=new Array(b),m=0;m<b;m++)v.glText[m]=new o(w);if(v.glText){if(b>v.glText.length){var T=b-v.glText.length;for(m=0;m<T;m++)v.glText.push(new o(w))}else if(b<v.glText.length){var k=v.glText.length-b;v.glText.splice(b,k).forEach((function(t){t.destroy()}))}for(m=0;m<b;m++)v.glText[m].update(v.textOptions[m])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map((function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t})),v.line2d.update(v.lineOptions)),v.error2d){var A=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(A)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,b),v.fill2d&&(v.fillOptions=v.fillOptions.map((function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,t.splitNull=!0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),p.push(null,null),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var m=s._nexttrace;if(m){var g=v.lineOptions[e+1];if(g){var y=g.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],_=y[2*e+1];isNaN(x)||isNaN(_)||p.push(x,_)}t.fill=m.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var b=v.lineOptions[e-1].positions,w=p.length/2,T=[i=w];for(a=0;a<b.length;a+=2)(isNaN(b[a])||isNaN(b[a+1]))&&(T.push(a/2+w+1),i=a+2);p=p.concat(b),t.hole=T}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}})),v.fill2d.update(v.fillOptions))}var M=y.dragmode,S=l(M),E=y.clickmode.indexOf(\"select\")>-1;for(m=0;m<b;m++){var C=r[m][0],L=C.trace,I=C.t,P=I.index,z=L._length,O=I.x,D=I.y;if(L.selectedpoints||S||E){if(S||(S=!0),L.selectedpoints){var R=v.selectBatch[P]=s.selIndices2selPoints(L),F={};for(g=0;g<R.length;g++)F[R[g]]=1;var B=[];for(g=0;g<z;g++)F[g]||B.push(g);v.unselectBatch[P]=B}var N=I.xpx=new Array(z),j=I.ypx=new Array(z);for(g=0;g<z;g++)N[g]=x.c2p(O[g]),j[g]=_.c2p(D[g])}else I.xpx=I.ypx=null}if(S){if(v.select2d||(v.select2d=n(y._glcanvas.data()[1].regl)),v.scatter2d){var U=new Array(b);for(m=0;m<b;m++)U[m]=v.selectBatch[m].length||v.unselectBatch[m].length?v.markerUnselectedOptions[m]:{};v.scatter2d.update(U)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach((function(t){var e=((t||[])[0]||{}).trace||{};u.hasText(e)&&f(t)}))}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var V={viewport:d(y,x,_,t._context.plotGlPixelRatio),range:[(x._rl||x.range)[0],(_._rl||_.range)[0],(x._rl||x.range)[1],(_._rl||_.range)[1]]},q=s.repeat(V,v.count);v.fill2d&&v.fill2d.update(q),v.line2d&&v.line2d.update(q),v.error2d&&v.error2d.update(q.concat(q)),v.scatter2d&&v.scatter2d.update(q),v.select2d&&v.select2d.update(q),v.glText&&v.glText.forEach((function(t){t.update(V)}))}else v.init()}}).reglPrecompiled=p},62336:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach((function(t){t.destroy&&t.destroy()})),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},17168:function(t,e,r){\"use strict\";var n=r(64726),i=r(85686).styleTextSelection;t.exports=function(t,e){var r=t.cd,a=t.xaxis,o=t.yaxis,s=[],l=r[0].trace,c=r[0].t,u=l._length,h=c.x,f=c.y,p=c._scene,d=c.index;if(!p)return s;var m=n.hasText(l),g=n.hasMarkers(l),y=!g&&!m;if(!0!==l.visible||y)return s;var v=[],x=[];if(!1!==e&&!e.degenerate)for(var _=0;_<u;_++)e.contains([c.xpx[_],c.ypx[_]],!1,_,t)?(v.push(_),s.push({pointNumber:_,x:a.c2d(h[_]),y:o.c2d(f[_])})):x.push(_);if(g){var b=p.scatter2d;if(v.length||x.length){if(!p.selectBatch[d].length&&!p.unselectBatch[d].length){var w=new Array(p.count);w[d]=p.markerUnselectedOptions[d],b.update.apply(b,w)}}else{var T=new Array(p.count);T[d]=p.markerOptions[d],b.update.apply(b,T)}}return p.selectBatch[d]=v,p.unselectBatch[d]=x,m&&i(r),s}},71388:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(19326),o=r(6893),s=r(36640),l=r(8257),c=r(9829),u=r(87163),h=r(93049).extendFlat,f=r(13582).overrideAll,p=r(8257),d=o.line,m=o.marker;t.exports=f({lon:o.lon,lat:o.lat,cluster:{enabled:{valType:\"boolean\"},maxzoom:h({},p.layers.maxzoom,{}),step:{valType:\"number\",arrayOk:!0,dflt:-1,min:-1},size:{valType:\"number\",arrayOk:!0,dflt:20,min:0},color:{valType:\"color\",arrayOk:!0},opacity:h({},m.opacity,{dflt:1})},mode:h({},s.mode,{dflt:\"markers\"}),text:h({},s.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:h({},s.hovertext,{}),line:{color:d.color,width:d.width},connectgaps:s.connectgaps,marker:h({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:m.opacity,size:m.size,sizeref:m.sizeref,sizemin:m.sizemin,sizemode:m.sizemode},u(\"marker\")),fill:o.fill,fillcolor:a(),textfont:l.layers.symbol.textfont,textposition:l.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:s.selected.marker},unselected:{marker:s.unselected.marker},hoverinfo:h({},c.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},13624:function(t){\"use strict\";var e=[\"Metropolis Black Italic\",\"Metropolis Black\",\"Metropolis Bold Italic\",\"Metropolis Bold\",\"Metropolis Extra Bold Italic\",\"Metropolis Extra Bold\",\"Metropolis Extra Light Italic\",\"Metropolis Extra Light\",\"Metropolis Light Italic\",\"Metropolis Light\",\"Metropolis Medium Italic\",\"Metropolis Medium\",\"Metropolis Regular Italic\",\"Metropolis Regular\",\"Metropolis Semi Bold Italic\",\"Metropolis Semi Bold\",\"Metropolis Thin Italic\",\"Metropolis Thin\",\"Open Sans Bold Italic\",\"Open Sans Bold\",\"Open Sans Extrabold Italic\",\"Open Sans Extrabold\",\"Open Sans Italic\",\"Open Sans Light Italic\",\"Open Sans Light\",\"Open Sans Regular\",\"Open Sans Semibold Italic\",\"Open Sans Semibold\",\"Klokantech Noto Sans Bold\",\"Klokantech Noto Sans CJK Bold\",\"Klokantech Noto Sans CJK Regular\",\"Klokantech Noto Sans Italic\",\"Klokantech Noto Sans Regular\"];t.exports={isSupportedFont:function(t){return-1!==e.indexOf(t)}}},76717:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(63821).BADNUM,o=r(39532),s=r(88856),l=r(62203),c=r(92527),u=r(64726),h=r(13624).isSupportedFont,f=r(4657),p=r(36040).appendArrayPointValue,d=r(30635).NEWLINES,m=r(30635).BR_TAG_ALL;function g(t){return{type:t,geojson:o.makeBlank(),layout:{visibility:\"none\"},filter:null,paint:{}}}function y(t,e){return i.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function x(t){return t[0]===a}function _(t,e){var r;if(i.isArrayOrTypedArray(t)&&i.isArrayOrTypedArray(e)){r=[\"step\",[\"get\",\"point_count\"],t[0]];for(var n=1;n<t.length;n++)r.push(e[n-1],t[n])}else r=t;return r}function b(t){var e=t.textfont,r=e.family,n=e.style,i=e.weight,a=r.split(\" \"),o=\"Italic\"===a[a.length-1];o&&a.pop(),o=o||\"italic\"===n;var s=a.join(\" \");return\"bold\"===i&&-1===a.indexOf(\"Bold\")?s+=\" Bold\":i<=1e3&&(\"Metropolis\"===a[0]?(s=\"Metropolis\",s+=i>850?\" Black\":i>750?\" Extra Bold\":i>650?\" Bold\":i>550?\" Semi Bold\":i>450?\" Medium\":i>350?\" Regular\":i>250?\" Light\":i>150?\" Extra Light\":\" Thin\"):\"Open Sans\"===a.slice(0,2).join(\" \")?(s=\"Open Sans\",s+=i>750?\" Extrabold\":i>650?\" Bold\":i>550?\" Semibold\":i>350?\" Regular\":\" Light\"):\"Klokantech Noto Sans\"===a.slice(0,3).join(\" \")&&(s=\"Klokantech Noto Sans\",\"CJK\"===a[3]&&(s+=\" CJK\"),s+=i>500?\" Bold\":\" Regular\")),o&&(s+=\" Italic\"),\"Open Sans Regular Italic\"===s?s=\"Open Sans Italic\":\"Open Sans Regular Bold\"===s?s=\"Open Sans Bold\":\"Open Sans Regular Bold Italic\"===s?s=\"Open Sans Bold Italic\":\"Klokantech Noto Sans Regular Italic\"===s&&(s=\"Klokantech Noto Sans Italic\"),h(s)||(s=r),s.split(\", \")}t.exports=function(t,e){var r,a=e[0].trace,h=!0===a.visible&&0!==a._length,w=\"none\"!==a.fill,T=u.hasLines(a),k=u.hasMarkers(a),A=u.hasText(a),M=k&&\"circle\"===a.marker.symbol,S=k&&\"circle\"!==a.marker.symbol,E=a.cluster&&a.cluster.enabled,C=g(\"fill\"),L=g(\"line\"),I=g(\"circle\"),P=g(\"symbol\"),z={fill:C,line:L,circle:I,symbol:P};if(!h)return z;if((w||T)&&(r=o.calcTraceToLineCoords(e)),w&&(C.geojson=o.makePolygon(r),C.layout.visibility=\"visible\",i.extendFlat(C.paint,{\"fill-color\":a.fillcolor})),T&&(L.geojson=o.makeLine(r),L.layout.visibility=\"visible\",i.extendFlat(L.paint,{\"line-width\":a.line.width,\"line-color\":a.line.color,\"line-opacity\":a.opacity})),M){var O=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),m=i.isArrayOrTypedArray(h.opacity);function g(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity),d&&(a=c(u)),m&&(o=function(t){return g(n(t)?+i.constrain(t,0,1):0)});var y,v,_=[];for(e=0;e<t.length;e++){var b=t[e],w=b.lonlat;if(!x(w)){var T={};r&&(T.mcc=b.mcc=r(b.mc)),a&&(T.mrc=b.mrc=a(b.ms)),o&&(T.mo=o(b.mo)),f&&(T.selected=b.selected||0),_.push({type:\"Feature\",id:e+1,geometry:{type:\"Point\",coordinates:w},properties:T})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<_.length;e++){var k=_[e].properties;y.selectedOpacityFn&&(k.mo=g(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:_},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(v=h.size,v/2),mo:m||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:g(h.opacity)}}(e);I.geojson=O.geojson,I.layout.visibility=\"visible\",E&&(I.filter=[\"!\",[\"has\",\"point_count\"]],z.cluster={type:\"circle\",filter:[\"has\",\"point_count\"],layout:{visibility:\"visible\"},paint:{\"circle-color\":_(a.cluster.color,a.cluster.step),\"circle-radius\":_(a.cluster.size,a.cluster.step),\"circle-opacity\":_(a.cluster.opacity,a.cluster.step)}},z.clusterCount={type:\"symbol\",filter:[\"has\",\"point_count\"],paint:{},layout:{\"text-field\":\"{point_count_abbreviated}\",\"text-font\":b(a),\"text-size\":12}}),i.extendFlat(I.paint,{\"circle-color\":O.mcc,\"circle-radius\":O.mrc,\"circle-opacity\":O.mo})}if(M&&E&&(I.filter=[\"!\",[\"has\",\"point_count\"]]),(S||A)&&(P.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,a=n.marker||{},o=a.symbol,s=a.angle,l=\"circle\"!==o?y(o):v,c=\"auto\"!==s?y(s,!0):v,h=u.hasText(n)?y(n.text):v,f=[],g=0;g<t.length;g++){var _=t[g];if(!x(_.lonlat)){var b,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[g]||\"\":w,k=n._module.formatLabels(_,n,r),A={};p(A,n,_.i);var M=n._meta||{};b=i.texttemplateString(T,k,r._d3locale,A,_,M)}else b=h(g);b&&(b=b.replace(d,\"\").replace(m,\"\\n\")),f.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_.lonlat},properties:{symbol:l(g),angle:c(g),text:b}})}}return{type:\"FeatureCollection\",features:f}}(e,t),i.extendFlat(P.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),S&&(i.extendFlat(P.layout,{\"icon-size\":a.marker.size/10}),\"angle\"in a.marker&&\"auto\"!==a.marker.angle&&i.extendFlat(P.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),P.layout[\"icon-allow-overlap\"]=a.marker.allowoverlap,i.extendFlat(P.paint,{\"icon-opacity\":a.opacity*a.marker.opacity,\"icon-color\":a.marker.color})),A)){var D=(a.marker||{}).size,R=f(a.textposition,D);i.extendFlat(P.layout,{\"text-size\":a.textfont.size,\"text-anchor\":R.anchor,\"text-offset\":R.offset,\"text-font\":b(a)}),i.extendFlat(P.paint,{\"text-color\":a.textfont.color,\"text-opacity\":a.opacity})}return z}},57387:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(24272),o=r(98168),s=r(663),l=r(54114),c=r(71388),u=r(13624).isSupportedFont;t.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,c,r,i)}function p(r,i){return n.coerce2(t,e,c,r,i)}var d=function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f);if(d){if(f(\"text\"),f(\"texttemplate\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),f(\"below\"),i.hasMarkers(e)){a(t,e,r,h,f,{noLine:!0,noAngle:!0}),f(\"marker.allowoverlap\"),f(\"marker.angle\");var m=e.marker;\"circle\"!==m.symbol&&(n.isArrayOrTypedArray(m.size)&&(m.size=m.size[0]),n.isArrayOrTypedArray(m.color)&&(m.color=m.color[0]))}i.hasLines(e)&&(o(t,e,r,h,f,{noDash:!0}),f(\"connectgaps\"));var g=p(\"cluster.maxzoom\"),y=p(\"cluster.step\"),v=p(\"cluster.color\",e.marker&&e.marker.color||r),x=p(\"cluster.size\"),_=p(\"cluster.opacity\");if(f(\"cluster.enabled\",!1!==g||!1!==y||!1!==v||!1!==x||!1!==_)||i.hasText(e)){var b=h.font.family;s(t,e,h,f,{noSelect:!0,noFontVariant:!0,noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0,font:{family:u(b)?b:\"Open Sans Regular\",weight:h.font.weight,style:h.font.style,size:h.font.size,color:h.font.color}})}f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},58240:function(t){\"use strict\";t.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},66762:function(t,e,r){\"use strict\";var n=r(29714);t.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},67275:function(t,e,r){\"use strict\";var n=r(32141),i=r(34809),a=r(11539),o=i.fillText,s=r(63821).BADNUM,l=r(8814).traceLayerPrefix;function c(t,e,r){if(!t.hovertemplate){var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];return i||a&&s?c.push(\"(\"+u(l[1])+\", \"+u(l[0])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1])),(i||-1!==n.indexOf(\"text\"))&&o(e,t,c),c.join(\"<br>\")}function u(t){return t+\"\u00b0\"}}t.exports={hoverPoints:function(t,e,r){var o=t.cd,u=o[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=[],m=l+u.uid+\"-circle\",g=u.cluster&&u.cluster.enabled;if(g){var y=p.map.queryRenderedFeatures(null,{layers:[m]});d=y.map((function(t){return t.id}))}var v=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),x=e-v;if(n.getClosest(o,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;if(g&&-1===d.indexOf(t.i+1))return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=p.project([n,a]),l=o.x-h.c2p([x,a]),c=o.y-f.c2p([n,r]),u=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-u,1-3/u)}),t),!1!==t.index){var _=o[t.index],b=_.lonlat,w=[i.modHalf(b[0],360)+v,b[1]],T=h.c2p(w),k=f.c2p(w),A=_.mrc||1;t.x0=T-A,t.x1=T+A,t.y0=k-A,t.y1=k+A;var M={};M[u.subplot]={_subplot:p};var S=u._module.formatLabels(_,u,M);return t.lonLabel=S.lonLabel,t.latLabel=S.latLabel,t.color=a(u,_),t.extraText=c(u,_,o[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}},getExtraText:c}},30929:function(t,e,r){\"use strict\";t.exports={attributes:r(71388),supplyDefaults:r(57387),colorbar:r(21146),formatLabels:r(66762),calc:r(75649),plot:r(26126),hoverPoints:r(67275).hoverPoints,eventData:r(58240),selectPoints:r(21501),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermap\",basePlotModule:r(34091),categories:[\"map\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},26126:function(t,e,r){\"use strict\";var n=r(34809),i=r(76717),a=r(8814).traceLayerPrefix,o={cluster:[\"cluster\",\"clusterCount\",\"circle\"],nonCluster:[\"fill\",\"line\",\"circle\",\"symbol\"]};function s(t,e,r,n){this.type=\"scattermap\",this.subplot=t,this.uid=e,this.clusterEnabled=r,this.isHidden=n,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\",cluster:\"source-\"+e+\"-circle\",clusterCount:\"source-\"+e+\"-circle\"},this.layerIds={fill:a+e+\"-fill\",line:a+e+\"-line\",circle:a+e+\"-circle\",symbol:a+e+\"-symbol\",cluster:a+e+\"-cluster\",clusterCount:a+e+\"-cluster-count\"},this.below=null}var l=s.prototype;l.addSource=function(t,e,r){var i={type:\"geojson\",data:e.geojson};r&&r.enabled&&n.extendFlat(i,{cluster:!0,clusterMaxZoom:r.maxzoom});var a=this.subplot.map.getSource(this.sourceIds[t]);a?a.setData(e.geojson):this.subplot.map.addSource(this.sourceIds[t],i)},l.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},l.addLayer=function(t,e,r){var n={type:e.type,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint};e.filter&&(n.filter=e.filter);for(var i,a=this.layerIds[t],o=this.subplot.getMapLayers(),s=0;s<o.length;s++)if(o[s].id===a){i=!0;break}i?(this.subplot.setOptions(a,\"setLayoutProperty\",n.layout),\"visible\"===n.layout.visibility&&this.subplot.setOptions(a,\"setPaintProperty\",n.paint)):this.subplot.addLayer(n,r)},l.update=function(t){var e=t[0].trace,r=this.subplot,n=r.map,a=i(r.gd,t),s=r.belowLookup[\"trace-\"+this.uid],l=!(!e.cluster||!e.cluster.enabled),c=!!this.clusterEnabled,u=this;function h(t){c?function(t){for(var e=o.cluster,r=e.length-1;r>=0;r--){var i=e[r];n.removeLayer(u.layerIds[i])}t||n.removeSource(u.sourceIds.circle)}(t):function(t){for(var e=o.nonCluster,r=e.length-1;r>=0;r--){var i=e[r];n.removeLayer(u.layerIds[i]),t||n.removeSource(u.sourceIds[i])}}(t)}function f(t){l?function(t){t||u.addSource(\"circle\",a.circle,e.cluster);for(var r=o.cluster,n=0;n<r.length;n++){var i=r[n],l=a[i];u.addLayer(i,l,s)}}(t):function(t){for(var e=o.nonCluster,r=0;r<e.length;r++){var n=e[r],i=a[n];t||u.addSource(n,i),u.addLayer(n,i,s)}}(t)}function p(){for(var t=l?o.cluster:o.nonCluster,e=0;e<t.length;e++){var n=t[e],i=a[n];i&&(r.setOptions(u.layerIds[n],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(\"cluster\"!==n&&u.setSourceData(n,i),r.setOptions(u.layerIds[n],\"setPaintProperty\",i.paint)))}}var d=this.isHidden,m=!0!==e.visible;m?d||h():d?m||f():c!==l?(h(),f()):this.below!==s?(h(!0),f(!0),p()):p(),this.clusterEnabled=l,this.isHidden=m,this.below=s,t[0].trace._glTrace=this},l.dispose=function(){for(var t=this.subplot.map,e=this.clusterEnabled?o.cluster:o.nonCluster,r=e.length-1;r>=0;r--){var n=e[r];t.removeLayer(this.layerIds[n]),t.removeSource(this.sourceIds[n])}},t.exports=function(t,e){var r,n,a,l=e[0].trace,c=l.cluster&&l.cluster.enabled,u=!0!==l.visible,h=new s(t,l.uid,c,u),f=i(t.gd,e),p=h.below=t.belowLookup[\"trace-\"+l.uid];if(c)for(h.addSource(\"circle\",f.circle,l.cluster),r=0;r<o.cluster.length;r++)a=f[n=o.cluster[r]],h.addLayer(n,a,p);else for(r=0;r<o.nonCluster.length;r++)a=f[n=o.nonCluster[r]],h.addSource(n,a,l.cluster),h.addLayer(n,a,p);return e[0].trace._glTrace=h,h}},21501:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(63821).BADNUM;t.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},95833:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(19326),o=r(6893),s=r(36640),l=r(67514),c=r(9829),u=r(87163),h=r(93049).extendFlat,f=r(13582).overrideAll,p=r(67514),d=o.line,m=o.marker;t.exports=f({lon:o.lon,lat:o.lat,cluster:{enabled:{valType:\"boolean\"},maxzoom:h({},p.layers.maxzoom,{}),step:{valType:\"number\",arrayOk:!0,dflt:-1,min:-1},size:{valType:\"number\",arrayOk:!0,dflt:20,min:0},color:{valType:\"color\",arrayOk:!0},opacity:h({},m.opacity,{dflt:1})},mode:h({},s.mode,{dflt:\"markers\"}),text:h({},s.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:h({},s.hovertext,{}),line:{color:d.color,width:d.width},connectgaps:s.connectgaps,marker:h({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:m.opacity,size:m.size,sizeref:m.sizeref,sizemin:m.sizemin,sizemode:m.sizemode},u(\"marker\")),fill:o.fill,fillcolor:a(),textfont:l.layers.symbol.textfont,textposition:l.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:s.selected.marker},unselected:{marker:s.unselected.marker},hoverinfo:h({},c.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},2795:function(t){\"use strict\";var e=[\"Metropolis Black Italic\",\"Metropolis Black\",\"Metropolis Bold Italic\",\"Metropolis Bold\",\"Metropolis Extra Bold Italic\",\"Metropolis Extra Bold\",\"Metropolis Extra Light Italic\",\"Metropolis Extra Light\",\"Metropolis Light Italic\",\"Metropolis Light\",\"Metropolis Medium Italic\",\"Metropolis Medium\",\"Metropolis Regular Italic\",\"Metropolis Regular\",\"Metropolis Semi Bold Italic\",\"Metropolis Semi Bold\",\"Metropolis Thin Italic\",\"Metropolis Thin\",\"Open Sans Bold Italic\",\"Open Sans Bold\",\"Open Sans Extrabold Italic\",\"Open Sans Extrabold\",\"Open Sans Italic\",\"Open Sans Light Italic\",\"Open Sans Light\",\"Open Sans Regular\",\"Open Sans Semibold Italic\",\"Open Sans Semibold\",\"Klokantech Noto Sans Bold\",\"Klokantech Noto Sans CJK Bold\",\"Klokantech Noto Sans CJK Regular\",\"Klokantech Noto Sans Italic\",\"Klokantech Noto Sans Regular\"];t.exports={isSupportedFont:function(t){return-1!==e.indexOf(t)}}},27009:function(t,e,r){\"use strict\";var n=r(10721),i=r(34809),a=r(63821).BADNUM,o=r(39532),s=r(88856),l=r(62203),c=r(92527),u=r(64726),h=r(2795).isSupportedFont,f=r(2178),p=r(36040).appendArrayPointValue,d=r(30635).NEWLINES,m=r(30635).BR_TAG_ALL;function g(t){return{type:t,geojson:o.makeBlank(),layout:{visibility:\"none\"},filter:null,paint:{}}}function y(t,e){return i.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function x(t){return t[0]===a}function _(t,e){var r;if(i.isArrayOrTypedArray(t)&&i.isArrayOrTypedArray(e)){r=[\"step\",[\"get\",\"point_count\"],t[0]];for(var n=1;n<t.length;n++)r.push(e[n-1],t[n])}else r=t;return r}function b(t){var e=t.textfont,r=e.family,n=e.style,i=e.weight,a=r.split(\" \"),o=\"Italic\"===a[a.length-1];o&&a.pop(),o=o||\"italic\"===n;var s=a.join(\" \");return\"bold\"===i&&-1===a.indexOf(\"Bold\")?s+=\" Bold\":i<=1e3&&(\"Metropolis\"===a[0]?(s=\"Metropolis\",s+=i>850?\" Black\":i>750?\" Extra Bold\":i>650?\" Bold\":i>550?\" Semi Bold\":i>450?\" Medium\":i>350?\" Regular\":i>250?\" Light\":i>150?\" Extra Light\":\" Thin\"):\"Open Sans\"===a.slice(0,2).join(\" \")?(s=\"Open Sans\",s+=i>750?\" Extrabold\":i>650?\" Bold\":i>550?\" Semibold\":i>350?\" Regular\":\" Light\"):\"Klokantech Noto Sans\"===a.slice(0,3).join(\" \")&&(s=\"Klokantech Noto Sans\",\"CJK\"===a[3]&&(s+=\" CJK\"),s+=i>500?\" Bold\":\" Regular\")),o&&(s+=\" Italic\"),\"Open Sans Regular Italic\"===s?s=\"Open Sans Italic\":\"Open Sans Regular Bold\"===s?s=\"Open Sans Bold\":\"Open Sans Regular Bold Italic\"===s?s=\"Open Sans Bold Italic\":\"Klokantech Noto Sans Regular Italic\"===s&&(s=\"Klokantech Noto Sans Italic\"),h(s)||(s=r),s.split(\", \")}t.exports=function(t,e){var r,a=e[0].trace,h=!0===a.visible&&0!==a._length,w=\"none\"!==a.fill,T=u.hasLines(a),k=u.hasMarkers(a),A=u.hasText(a),M=k&&\"circle\"===a.marker.symbol,S=k&&\"circle\"!==a.marker.symbol,E=a.cluster&&a.cluster.enabled,C=g(\"fill\"),L=g(\"line\"),I=g(\"circle\"),P=g(\"symbol\"),z={fill:C,line:L,circle:I,symbol:P};if(!h)return z;if((w||T)&&(r=o.calcTraceToLineCoords(e)),w&&(C.geojson=o.makePolygon(r),C.layout.visibility=\"visible\",i.extendFlat(C.paint,{\"fill-color\":a.fillcolor})),T&&(L.geojson=o.makeLine(r),L.layout.visibility=\"visible\",i.extendFlat(L.paint,{\"line-width\":a.line.width,\"line-color\":a.line.color,\"line-opacity\":a.opacity})),M){var O=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),m=i.isArrayOrTypedArray(h.opacity);function g(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity),d&&(a=c(u)),m&&(o=function(t){return g(n(t)?+i.constrain(t,0,1):0)});var y,v,_=[];for(e=0;e<t.length;e++){var b=t[e],w=b.lonlat;if(!x(w)){var T={};r&&(T.mcc=b.mcc=r(b.mc)),a&&(T.mrc=b.mrc=a(b.ms)),o&&(T.mo=o(b.mo)),f&&(T.selected=b.selected||0),_.push({type:\"Feature\",id:e+1,geometry:{type:\"Point\",coordinates:w},properties:T})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<_.length;e++){var k=_[e].properties;y.selectedOpacityFn&&(k.mo=g(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:_},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(v=h.size,v/2),mo:m||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:g(h.opacity)}}(e);I.geojson=O.geojson,I.layout.visibility=\"visible\",E&&(I.filter=[\"!\",[\"has\",\"point_count\"]],z.cluster={type:\"circle\",filter:[\"has\",\"point_count\"],layout:{visibility:\"visible\"},paint:{\"circle-color\":_(a.cluster.color,a.cluster.step),\"circle-radius\":_(a.cluster.size,a.cluster.step),\"circle-opacity\":_(a.cluster.opacity,a.cluster.step)}},z.clusterCount={type:\"symbol\",filter:[\"has\",\"point_count\"],paint:{},layout:{\"text-field\":\"{point_count_abbreviated}\",\"text-font\":b(a),\"text-size\":12}}),i.extendFlat(I.paint,{\"circle-color\":O.mcc,\"circle-radius\":O.mrc,\"circle-opacity\":O.mo})}if(M&&E&&(I.filter=[\"!\",[\"has\",\"point_count\"]]),(S||A)&&(P.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,a=n.marker||{},o=a.symbol,s=a.angle,l=\"circle\"!==o?y(o):v,c=\"auto\"!==s?y(s,!0):v,h=u.hasText(n)?y(n.text):v,f=[],g=0;g<t.length;g++){var _=t[g];if(!x(_.lonlat)){var b,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[g]||\"\":w,k=n._module.formatLabels(_,n,r),A={};p(A,n,_.i);var M=n._meta||{};b=i.texttemplateString(T,k,r._d3locale,A,_,M)}else b=h(g);b&&(b=b.replace(d,\"\").replace(m,\"\\n\")),f.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_.lonlat},properties:{symbol:l(g),angle:c(g),text:b}})}}return{type:\"FeatureCollection\",features:f}}(e,t),i.extendFlat(P.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),S&&(i.extendFlat(P.layout,{\"icon-size\":a.marker.size/10}),\"angle\"in a.marker&&\"auto\"!==a.marker.angle&&i.extendFlat(P.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),P.layout[\"icon-allow-overlap\"]=a.marker.allowoverlap,i.extendFlat(P.paint,{\"icon-opacity\":a.opacity*a.marker.opacity,\"icon-color\":a.marker.color})),A)){var D=(a.marker||{}).size,R=f(a.textposition,D);i.extendFlat(P.layout,{\"text-size\":a.textfont.size,\"text-anchor\":R.anchor,\"text-offset\":R.offset,\"text-font\":b(a)}),i.extendFlat(P.paint,{\"text-color\":a.textfont.color,\"text-opacity\":a.opacity})}return z}},38302:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(24272),o=r(98168),s=r(663),l=r(54114),c=r(95833),u=r(2795).isSupportedFont;t.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,c,r,i)}function p(r,i){return n.coerce2(t,e,c,r,i)}var d=function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f);if(d){if(f(\"text\"),f(\"texttemplate\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),f(\"below\"),i.hasMarkers(e)){a(t,e,r,h,f,{noLine:!0,noAngle:!0}),f(\"marker.allowoverlap\"),f(\"marker.angle\");var m=e.marker;\"circle\"!==m.symbol&&(n.isArrayOrTypedArray(m.size)&&(m.size=m.size[0]),n.isArrayOrTypedArray(m.color)&&(m.color=m.color[0]))}i.hasLines(e)&&(o(t,e,r,h,f,{noDash:!0}),f(\"connectgaps\"));var g=p(\"cluster.maxzoom\"),y=p(\"cluster.step\"),v=p(\"cluster.color\",e.marker&&e.marker.color||r),x=p(\"cluster.size\"),_=p(\"cluster.opacity\");if(f(\"cluster.enabled\",!1!==g||!1!==y||!1!==v||!1!==x||!1!==_)||i.hasText(e)){var b=h.font.family;s(t,e,h,f,{noSelect:!0,noFontVariant:!0,noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0,font:{family:u(b)?b:\"Open Sans Regular\",weight:h.font.weight,style:h.font.style,size:h.font.size,color:h.font.color}})}f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},68197:function(t){\"use strict\";t.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},69009:function(t,e,r){\"use strict\";var n=r(29714);t.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},18016:function(t,e,r){\"use strict\";var n=r(32141),i=r(34809),a=r(11539),o=i.fillText,s=r(63821).BADNUM,l=r(44245).traceLayerPrefix;function c(t,e,r){if(!t.hovertemplate){var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];return i||a&&s?c.push(\"(\"+u(l[1])+\", \"+u(l[0])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1])),(i||-1!==n.indexOf(\"text\"))&&o(e,t,c),c.join(\"<br>\")}function u(t){return t+\"\u00b0\"}}t.exports={hoverPoints:function(t,e,r){var o=t.cd,u=o[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=[],m=l+u.uid+\"-circle\",g=u.cluster&&u.cluster.enabled;if(g){var y=p.map.queryRenderedFeatures(null,{layers:[m]});d=y.map((function(t){return t.id}))}var v=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),x=e-v;if(n.getClosest(o,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;if(g&&-1===d.indexOf(t.i+1))return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=p.project([n,a]),l=o.x-h.c2p([x,a]),c=o.y-f.c2p([n,r]),u=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-u,1-3/u)}),t),!1!==t.index){var _=o[t.index],b=_.lonlat,w=[i.modHalf(b[0],360)+v,b[1]],T=h.c2p(w),k=f.c2p(w),A=_.mrc||1;t.x0=T-A,t.x1=T+A,t.y0=k-A,t.y1=k+A;var M={};M[u.subplot]={_subplot:p};var S=u._module.formatLabels(_,u,M);return t.lonLabel=S.lonLabel,t.latLabel=S.latLabel,t.color=a(u,_),t.extraText=c(u,_,o[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}},getExtraText:c}},83866:function(t,e,r){\"use strict\";[\"*scattermapbox* trace is deprecated!\",\"Please consider switching to the *scattermap* trace type and `map` subplots.\",\"Learn more at: https://plotly.com/javascript/maplibre-migration/\"].join(\" \"),t.exports={attributes:r(95833),supplyDefaults:r(38302),colorbar:r(21146),formatLabels:r(69009),calc:r(75649),plot:r(20691),hoverPoints:r(18016).hoverPoints,eventData:r(68197),selectPoints:r(60784),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:r(68192),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},20691:function(t,e,r){\"use strict\";var n=r(34809),i=r(27009),a=r(44245).traceLayerPrefix,o={cluster:[\"cluster\",\"clusterCount\",\"circle\"],nonCluster:[\"fill\",\"line\",\"circle\",\"symbol\"]};function s(t,e,r,n){this.type=\"scattermapbox\",this.subplot=t,this.uid=e,this.clusterEnabled=r,this.isHidden=n,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\",cluster:\"source-\"+e+\"-circle\",clusterCount:\"source-\"+e+\"-circle\"},this.layerIds={fill:a+e+\"-fill\",line:a+e+\"-line\",circle:a+e+\"-circle\",symbol:a+e+\"-symbol\",cluster:a+e+\"-cluster\",clusterCount:a+e+\"-cluster-count\"},this.below=null}var l=s.prototype;l.addSource=function(t,e,r){var i={type:\"geojson\",data:e.geojson};r&&r.enabled&&n.extendFlat(i,{cluster:!0,clusterMaxZoom:r.maxzoom});var a=this.subplot.map.getSource(this.sourceIds[t]);a?a.setData(e.geojson):this.subplot.map.addSource(this.sourceIds[t],i)},l.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},l.addLayer=function(t,e,r){var n={type:e.type,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint};e.filter&&(n.filter=e.filter);for(var i,a=this.layerIds[t],o=this.subplot.getMapLayers(),s=0;s<o.length;s++)if(o[s].id===a){i=!0;break}i?(this.subplot.setOptions(a,\"setLayoutProperty\",n.layout),\"visible\"===n.layout.visibility&&this.subplot.setOptions(a,\"setPaintProperty\",n.paint)):this.subplot.addLayer(n,r)},l.update=function(t){var e=t[0].trace,r=this.subplot,n=r.map,a=i(r.gd,t),s=r.belowLookup[\"trace-\"+this.uid],l=!(!e.cluster||!e.cluster.enabled),c=!!this.clusterEnabled,u=this;function h(t){c?function(t){for(var e=o.cluster,r=e.length-1;r>=0;r--){var i=e[r];n.removeLayer(u.layerIds[i])}t||n.removeSource(u.sourceIds.circle)}(t):function(t){for(var e=o.nonCluster,r=e.length-1;r>=0;r--){var i=e[r];n.removeLayer(u.layerIds[i]),t||n.removeSource(u.sourceIds[i])}}(t)}function f(t){l?function(t){t||u.addSource(\"circle\",a.circle,e.cluster);for(var r=o.cluster,n=0;n<r.length;n++){var i=r[n],l=a[i];u.addLayer(i,l,s)}}(t):function(t){for(var e=o.nonCluster,r=0;r<e.length;r++){var n=e[r],i=a[n];t||u.addSource(n,i),u.addLayer(n,i,s)}}(t)}function p(){for(var t=l?o.cluster:o.nonCluster,e=0;e<t.length;e++){var n=t[e],i=a[n];i&&(r.setOptions(u.layerIds[n],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(\"cluster\"!==n&&u.setSourceData(n,i),r.setOptions(u.layerIds[n],\"setPaintProperty\",i.paint)))}}var d=this.isHidden,m=!0!==e.visible;m?d||h():d?m||f():c!==l?(h(),f()):this.below!==s?(h(!0),f(!0),p()):p(),this.clusterEnabled=l,this.isHidden=m,this.below=s,t[0].trace._glTrace=this},l.dispose=function(){for(var t=this.subplot.map,e=this.clusterEnabled?o.cluster:o.nonCluster,r=e.length-1;r>=0;r--){var n=e[r];t.removeLayer(this.layerIds[n]),t.removeSource(this.sourceIds[n])}},t.exports=function(t,e){var r,n,a,l=e[0].trace,c=l.cluster&&l.cluster.enabled,u=!0!==l.visible,h=new s(t,l.uid,c,u),f=i(t.gd,e),p=h.below=t.belowLookup[\"trace-\"+l.uid];if(c)for(h.addSource(\"circle\",f.circle,l.cluster),r=0;r<o.cluster.length;r++)a=f[n=o.cluster[r]],h.addLayer(n,a,p);else for(r=0;r<o.nonCluster.length;r++)a=f[n=o.nonCluster[r]],h.addSource(n,a,l.cluster),h.addLayer(n,a,p);return e[0].trace._glTrace=h,h}},60784:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(63821).BADNUM;t.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},8738:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(93049).extendFlat,o=r(19326),s=r(36640),l=r(9829),c=s.line;t.exports={mode:s.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:s.text,texttemplate:i({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:s.hovertext,line:{color:c.color,width:c.width,dash:c.dash,backoff:c.backoff,shape:a({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:s.connectgaps,marker:s.marker,cliponaxis:a({},s.cliponaxis,{dflt:!1}),textposition:s.textposition,textfont:s.textfont,fill:a({},s.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o(),hoverinfo:a({},l.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:s.hoveron,hovertemplate:n(),selected:s.selected,unselected:s.unselected}},13246:function(t,e,r){\"use strict\";var n=r(10721),i=r(63821).BADNUM,a=r(29714),o=r(77272),s=r(99203),l=r(48861),c=r(26544).calcMarkerSize;t.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),m=e._length,g=new Array(m),y=0;y<m;y++){var v=p[y],x=d[y],_=g[y]={};n(v)&&n(x)?(_.r=v,_.theta=x):_.r=i}var b=c(e,m);return e._extremes.x=a.findExtremes(h,p,{ppad:b}),o(t,e),s(g,e),l(g,e),g}},73749:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(24272),o=r(98168),s=r(91602),l=r(663),c=r(54114),u=r(32660).PTS_LINESONLY,h=r(8738);function f(t,e,r,i){var a,o=i(\"r\"),s=i(\"theta\");if(n.isTypedArray(o)&&(e.r=o=Array.from(o)),n.isTypedArray(s)&&(e.theta=s=Array.from(s)),o)s?a=Math.min(o.length,s.length):(a=o.length,i(\"theta0\"),i(\"dtheta\"));else{if(!s)return 0;a=e.theta.length,i(\"r0\"),i(\"dr\")}return e._length=a,a}t.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var m=f(0,e,0,d);if(m){d(\"thetaunit\"),d(\"mode\",m<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasLines(e)&&(o(t,e,r,p,d,{backoff:!0}),s(t,e,d),d(\"connectgaps\")),i.hasText(e)&&(d(\"texttemplate\"),l(t,e,p,d));var g=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),g.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||g.push(\"fills\"),d(\"hoveron\",g.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},33368:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714);t.exports=function(t,e,r){var a,o,s={},l=r[e.subplot]._subplot;l?(a=l.radialAxis,o=l.angularAxis):(a=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=a.c2l(t.r);s.rLabel=i.tickText(a,c,!0).text;var u=\"degrees\"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=i.tickText(o,u,!0).text,s}},29709:function(t,e,r){\"use strict\";var n=r(37255);function i(t,e,r,n){var i=r.radialAxis,a=r.angularAxis;i._hovertitle=\"r\",a._hovertitle=\"\u03b8\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var h=l.split(\"+\");-1!==h.indexOf(\"all\")&&(h=[\"r\",\"theta\",\"text\"]),-1!==h.indexOf(\"r\")&&u(i,n.rLabel),-1!==h.indexOf(\"theta\")&&u(a,n.thetaLabel),-1!==h.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}t.exports={hoverPoints:function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,i(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:i}},66939:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:r(31645),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:r(8738),supplyDefaults:r(73749).supplyDefaults,colorbar:r(21146),formatLabels:r(33368),calc:r(13246),plot:r(43836),style:r(9408).style,styleOnSelect:r(9408).styleOnSelect,hoverPoints:r(29709).hoverPoints,selectPoints:r(32665),meta:{}}},43836:function(t,e,r){\"use strict\";var n=r(36098),i=r(63821).BADNUM;t.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o=e.xaxis,s=e.yaxis,l={xaxis:o,yaxis:s,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},c=e.radialAxis,u=e.angularAxis,h=0;h<r.length;h++)for(var f=r[h],p=0;p<f.length;p++){0===p&&(f[0].trace._xA=o,f[0].trace._yA=s);var d=f[p],m=d.r;if(m===i)d.x=d.y=i;else{var g=c.c2g(m),y=u.c2g(d.theta);d.x=g*Math.cos(y),d.y=g*Math.sin(y)}}n(t,l,r,a)}},58319:function(t,e,r){\"use strict\";var n=r(8738),i=r(92089),a=r(3208).ay;t.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:a({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:{color:i.line.color,width:i.line.width,dash:i.line.dash,editType:\"calc\"},connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},25796:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:r(31645),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:r(58319),supplyDefaults:r(14952),colorbar:r(21146),formatLabels:r(94015),calc:r(71535),hoverPoints:r(47522).hoverPoints,selectPoints:r(17168),meta:{}}},71535:function(t,e,r){\"use strict\";var n=r(77272),i=r(26544).calcMarkerSize,a=r(19937),o=r(29714),s=r(29483).TOO_MANY_POINTS;t.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=e._r=c.makeCalcdata(e,\"r\"),f=e._theta=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var m,g=d.opts=a.style(t,e);return p<s?m=i(e,p):g.marker&&(m=2*(g.marker.sizeAvg||Math.max(g.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:m}),[{x:!1,y:!1,t:d,trace:e}]}},14952:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(73749).handleRThetaDefaults,o=r(24272),s=r(98168),l=r(663),c=r(54114),u=r(32660).PTS_LINESONLY,h=r(58319);t.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasMarkers(e)&&o(t,e,r,f,p,{noAngleRef:!0,noStandOff:!0}),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasText(e)&&(p(\"texttemplate\"),l(t,e,f,p,{noFontShadow:!0,noFontLineposition:!0,noFontTextcase:!0})),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},94015:function(t,e,r){\"use strict\";var n=r(33368);t.exports=function(t,e,r){var i=t.i;return\"r\"in t||(t.r=e._r[i]),\"theta\"in t||(t.theta=e._theta[i]),n(t,e,r)}},47522:function(t,e,r){\"use strict\";var n=r(36544),i=r(29709).makeHoverPointText;t.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},23748:function(t,e,r){\"use strict\";var n=r(25796);n.plot=r(54121),t.exports=n},54121:function(t,e,r){\"use strict\";var n=r(27549),i=r(10721),a=r(47731),o=r(62336),s=r(19937),l=r(34809),c=r(29483).TOO_MANY_POINTS;t.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach((function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,m=p._length,g=d.r,y=d.theta,v=d.opts,x=g.slice(),_=y.slice();for(a=0;a<g.length;a++)e.isPtInside({r:g[a],theta:y[a]})||(x[a]=NaN,_[a]=NaN);var b=new Array(2*m),w=Array(m),T=Array(m);for(a=0;a<m;a++){var k,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(_[a],p.thetaunit);k=S*Math.cos(E),A=S*Math.sin(E)}else k=A=NaN;w[a]=b[2*a]=k,T[a]=b[2*a+1]=A}d.tree=n(b),v.marker&&m>=c&&(v.marker.cluster=d.tree),v.marker&&(v.markerSel.positions=v.markerUnsel.positions=v.marker.positions=b),v.line&&b.length>1&&l.extendFlat(v.line,s.linePositions(t,p,b)),v.text&&(l.extendFlat(v.text,{positions:b},s.textPosition(t,p,v.text,v.marker)),l.extendFlat(v.textSel,{positions:b},s.textPosition(t,p,v.text,v.markerSel)),l.extendFlat(v.textUnsel,{positions:b},s.textPosition(t,p,v.text,v.markerUnsel))),v.fill&&!f.fill2d&&(f.fill2d=!0),v.marker&&!f.scatter2d&&(f.scatter2d=!0),v.line&&!f.line2d&&(f.line2d=!0),v.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(v.line),f.fillOptions.push(v.fill),f.markerOptions.push(v.marker),f.markerSelectedOptions.push(v.markerSel),f.markerUnselectedOptions.push(v.markerUnsel),f.textOptions.push(v.text),f.textSelectedOptions.push(v.textSel),f.textUnselectedOptions.push(v.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=T,d.rawx=w,d.rawy=T,d.r=g,d.theta=y,d.positions=b,d._scene=f,d.index=f.count,f.count++}})),a(t,e,r)}},t.exports.reglPrecompiled={}},69595:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(93049).extendFlat,o=r(19326),s=r(36640),l=r(9829),c=s.line;t.exports={mode:s.mode,real:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},imag:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s.text,texttemplate:i({editType:\"plot\"},{keys:[\"real\",\"imag\",\"text\"]}),hovertext:s.hovertext,line:{color:c.color,width:c.width,dash:c.dash,backoff:c.backoff,shape:a({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:s.connectgaps,marker:s.marker,cliponaxis:a({},s.cliponaxis,{dflt:!1}),textposition:s.textposition,textfont:s.textfont,fill:a({},s.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o(),hoverinfo:a({},l.hoverinfo,{flags:[\"real\",\"imag\",\"text\",\"name\"]}),hoveron:s.hoveron,hovertemplate:n(),selected:s.selected,unselected:s.unselected}},44315:function(t,e,r){\"use strict\";var n=r(10721),i=r(63821).BADNUM,a=r(77272),o=r(99203),s=r(48861),l=r(26544).calcMarkerSize;t.exports=function(t,e){for(var r=t._fullLayout,c=e.subplot,u=r[c].realaxis,h=r[c].imaginaryaxis,f=u.makeCalcdata(e,\"real\"),p=h.makeCalcdata(e,\"imag\"),d=e._length,m=new Array(d),g=0;g<d;g++){var y=f[g],v=p[g],x=m[g]={};n(y)&&n(v)?(x.real=y,x.imag=v):x.real=i}return l(e,d),a(t,e),o(m,e),s(m,e),m}},93788:function(t,e,r){\"use strict\";var n=r(34809),i=r(64726),a=r(24272),o=r(98168),s=r(91602),l=r(663),c=r(54114),u=r(32660).PTS_LINESONLY,h=r(69595);t.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=function(t,e,r,i){var a,o=i(\"real\"),s=i(\"imag\");return o&&s&&(a=Math.min(o.length,s.length)),n.isTypedArray(o)&&(e.real=o=Array.from(o)),n.isTypedArray(s)&&(e.imag=s=Array.from(s)),e._length=a,a}(0,e,0,p);if(d){p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasMarkers(e)&&a(t,e,r,f,p,{gradient:!0}),i.hasLines(e)&&(o(t,e,r,f,p,{backoff:!0}),s(t,e,p),p(\"connectgaps\")),i.hasText(e)&&(p(\"texttemplate\"),l(t,e,f,p));var m=[];(i.hasMarkers(e)||i.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,p),i.hasLines(e)||s(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),p(\"hoveron\",m.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},89419:function(t,e,r){\"use strict\";var n=r(29714);t.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot;return i.realLabel=n.tickText(a.radialAxis,t.real,!0).text,i.imagLabel=n.tickText(a.angularAxis,t.imag,!0).text,i}},64422:function(t,e,r){\"use strict\";var n=r(37255);function i(t,e,r,n){var i=r.radialAxis,a=r.angularAxis;i._hovertitle=\"real\",a._hovertitle=\"imag\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.realLabel=s.realLabel,n.imagLabel=s.imagLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var h=l.split(\"+\");-1!==h.indexOf(\"all\")&&(h=[\"real\",\"imag\",\"text\"]),-1!==h.indexOf(\"real\")&&u(i,n.realLabel),-1!==h.indexOf(\"imag\")&&u(a,n.imagLabel),-1!==h.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}t.exports={hoverPoints:function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,i(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:i}},73304:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"scattersmith\",basePlotModule:r(50358),categories:[\"smith\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:r(69595),supplyDefaults:r(93788),colorbar:r(21146),formatLabels:r(89419),calc:r(44315),plot:r(6229),style:r(9408).style,styleOnSelect:r(9408).styleOnSelect,hoverPoints:r(64422).hoverPoints,selectPoints:r(32665),meta:{}}},6229:function(t,e,r){\"use strict\";var n=r(36098),i=r(63821).BADNUM,a=r(52007).smith;t.exports=function(t,e,r){for(var o=e.layers.frontplot.select(\"g.scatterlayer\"),s=e.xaxis,l=e.yaxis,c={xaxis:s,yaxis:l,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},u=0;u<r.length;u++)for(var h=r[u],f=0;f<h.length;f++){0===f&&(h[0].trace._xA=s,h[0].trace._yA=l);var p=h[f],d=p.real;if(d===i)p.x=p.y=i;else{var m=a([d,p.imag]);p.x=m[0],p.y=m[1]}}n(t,c,r,o)}},18483:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(19326),o=r(36640),s=r(9829),l=r(87163),c=r(94850).T,u=r(93049).extendFlat,h=o.marker,f=o.line,p=h.line;t.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"a\",\"b\",\"c\",\"text\"]}),hovertext:u({},o.hovertext,{}),line:{color:f.color,width:f.width,dash:c,backoff:f.backoff,shape:u({},f.shape,{values:[\"linear\",\"spline\"]}),smoothing:f.smoothing,editType:\"calc\"},connectgaps:o.connectgaps,cliponaxis:o.cliponaxis,fill:u({},o.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a(),marker:u({symbol:h.symbol,opacity:h.opacity,angle:h.angle,angleref:h.angleref,standoff:h.standoff,maxdisplayed:h.maxdisplayed,size:h.size,sizeref:h.sizeref,sizemin:h.sizemin,sizemode:h.sizemode,line:u({width:p.width,editType:\"calc\"},l(\"marker.line\")),gradient:h.gradient,editType:\"calc\"},l(\"marker\")),textfont:o.textfont,textposition:o.textposition,selected:o.selected,unselected:o.unselected,hoverinfo:u({},s.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:o.hoveron,hovertemplate:n()}},67091:function(t,e,r){\"use strict\";var n=r(10721),i=r(77272),a=r(99203),o=r(48861),s=r(26544).calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};t.exports=function(t,e){var r,u,h,f,p,d,m=t._fullLayout[e.subplot].sum,g=e.sum||m,y={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!y[h=l[r]]){for(p=y[c[h][0]],d=y[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=g-p[u]-d[u];y[h]=f}var v,x,_,b,w,T,k=e._length,A=new Array(k);for(r=0;r<k;r++)v=y.a[r],x=y.b[r],_=y.c[r],n(v)&&n(x)&&n(_)?(1!=(b=m/((v=+v)+(x=+x)+(_=+_)))&&(v*=b,x*=b,_*=b),T=v,w=_-x,A[r]={x:w,y:T,a:v,b:x,c:_}):A[r]={x:!1,y:!1};return s(e,k),i(t,e),a(A,e),o(A,e),A}},79028:function(t,e,r){\"use strict\";var n=r(34809),i=r(32660),a=r(64726),o=r(24272),s=r(98168),l=r(91602),c=r(663),u=r(54114),h=r(18483);t.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,m=p(\"a\"),g=p(\"b\"),y=p(\"c\");if(m?(d=m.length,g?(d=Math.min(d,g.length),y&&(d=Math.min(d,y.length))):d=y?Math.min(d,y.length):0):g&&y&&(d=Math.min(g.length,y.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasLines(e)&&(s(t,e,r,f,p,{backoff:!0}),l(t,e,p),p(\"connectgaps\")),a.hasText(e)&&(p(\"texttemplate\"),c(t,e,f,p));var v=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),v.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),p(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},94343:function(t){\"use strict\";t.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},78995:function(t,e,r){\"use strict\";var n=r(29714);t.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot;return i.aLabel=n.tickText(a.aaxis,t.a,!0).text,i.bLabel=n.tickText(a.baxis,t.b,!0).text,i.cLabel=n.tickText(a.caxis,t.c,!0).text,i}},26558:function(t,e,r){\"use strict\";var n=r(37255);t.exports=function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var o=a[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),a}var h=o.cd[o.index],f=o.trace,p=o.subplot;o.a=h.a,o.b=h.b,o.c=h.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[f.subplot]={_subplot:p};var m=f._module.formatLabels(h,f,d);o.aLabel=m.aLabel,o.bLabel=m.bLabel,o.cLabel=m.cLabel;var g=h.hi||f.hoverinfo,y=[];if(!f.hovertemplate){var v=g.split(\"+\");-1!==v.indexOf(\"all\")&&(v=[\"a\",\"b\",\"c\"]),-1!==v.indexOf(\"a\")&&x(p.aaxis,o.aLabel),-1!==v.indexOf(\"b\")&&x(p.baxis,o.bLabel),-1!==v.indexOf(\"c\")&&x(p.caxis,o.cLabel)}return o.extraText=y.join(\"<br>\"),o.hovertemplate=f.hovertemplate,a}function x(t,e){y.push(t._hovertitle+\": \"+e)}}},12864:function(t,e,r){\"use strict\";t.exports={attributes:r(18483),supplyDefaults:r(79028),colorbar:r(21146),formatLabels:r(78995),calc:r(67091),plot:r(79005),style:r(9408).style,styleOnSelect:r(9408).styleOnSelect,hoverPoints:r(26558),selectPoints:r(32665),eventData:r(94343),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:r(7638),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},79005:function(t,e,r){\"use strict\";var n=r(36098);t.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();for(var a=e.xaxis,o=e.yaxis,s={xaxis:a,yaxis:o,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},l=e.layers.frontplot.select(\"g.scatterlayer\"),c=0;c<r.length;c++){var u=r[c];u.length&&(u[0].trace._xA=a,u[0].trace._yA=o)}n(t,s,r,l)}},68697:function(t,e,r){\"use strict\";var n=r(36640),i=r(87163),a=r(80712).axisHoverFormat,o=r(3208).rb,s=r(92089),l=r(54826).idRegex,c=r(78032).templatedArray,u=r(93049).extendFlat,h=n.marker,f=h.line,p=u(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:u({},f.width,{editType:\"calc\"}),editType:\"calc\"}),d=u(i(\"marker\"),{symbol:h.symbol,angle:h.angle,size:u({},h.size,{editType:\"markerSize\"}),sizeref:h.sizeref,sizemin:h.sizemin,sizemode:h.sizemode,opacity:h.opacity,colorbar:h.colorbar,line:p,editType:\"calc\"});function m(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:l[t],editType:\"plot\"}}}d.color.editType=d.cmin.editType=d.cmax.editType=\"style\",t.exports={dimensions:c(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:u({},s.text,{}),hovertext:u({},s.hovertext,{}),hovertemplate:o(),xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),marker:d,xaxes:m(\"x\"),yaxes:m(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:s.selected.marker,editType:\"calc\"},unselected:{marker:s.unselected.marker,editType:\"calc\"},opacity:s.opacity}},86690:function(t,e,r){\"use strict\";var n=r(33626),i=r(83595);t.exports={moduleType:\"trace\",name:\"splom\",categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:r(68697),supplyDefaults:r(52542),colorbar:r(21146),calc:r(55325),plot:r(83027),hoverPoints:r(25600).hoverPoints,selectPoints:r(13392),editStyle:r(27926),meta:{}},n.register(i)},571:function(t,e,r){\"use strict\";var n=r(49478),i=r(33626),a=r(22459),o=r(4173).eV,s=r(37703),l=r(5975).getFromId,c=r(29714).shouldShowZeroLine,u=\"splom\",h={};function f(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function p(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._context.plotGlPixelRatio,n=t._fullLayout,i=n._size,a=[0,0,n.width*r,n.height*r],o={};function s(t,e,n,i,s,l){n*=r,i*=r,s*=r,l*=r;var c=e[t+\"color\"],u=e[t+\"width\"],h=String(c+u);h in o?o[h].data.push(NaN,NaN,n,i,s,l):o[h]={data:[n,i,s,l],join:\"rect\",thickness:u*r,color:c,viewport:a,range:a,overlay:!1}}for(e in n._splomSubplots){var l,u,h=n._plots[e],f=h.xaxis,p=h.yaxis,d=f._gridVals,m=p._gridVals,g=f._offset,y=f._length,v=p._length,x=i.b+p.domain[0]*i.h,_=-p._m,b=-_*p.r2l(p.range[0],p.calendar);if(f.showgrid)for(e=0;e<d.length;e++)l=g+f.l2p(d[e].x),s(\"grid\",f,l,x,l,x+v);if(p.showgrid)for(e=0;e<m.length;e++)s(\"grid\",p,g,u=x+b+_*m[e].x,g+y,u);c(t,f,p)&&(l=g+f.l2p(0),s(\"zeroline\",f,l,x,l,x+v)),c(t,p,f)&&s(\"zeroline\",p,g,u=x+b+0,g+y,u)}var w=[];for(e in o)w.push(o[e]);return w}(t))}t.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"],h)&&(e._hasOnlyLargeSploms&&p(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&p(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&f(t,i,a)}},updateGrid:p,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG,reglPrecompiled:h}},55325:function(t,e,r){\"use strict\";var n=r(34809),i=r(5975),a=r(26544).calcMarkerSize,o=r(26544).calcAxisExpansion,s=r(77272),l=r(19937).markerSelection,c=r(19937).markerStyle,u=r(78880),h=r(63821).BADNUM,f=r(29483).TOO_MANY_POINTS;t.exports=function(t,e){var r,p,d,m,g,y,v=e.dimensions,x=e._length,_={},b=_.cdata=[],w=_.data=[],T=e._visibleDims=[];function k(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];b.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<v.length;r++)if((d=v[r]).visible){if(m=i.getFromId(t,e._diag[r][0]),g=i.getFromId(t,e._diag[r][1]),m&&g&&m.type!==g.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}m?(k(m,d),g&&\"category\"===g.type&&(g._categories=m._categories.slice())):k(g,d),T.push(r)}for(s(t,e),n.extendFlat(_,c(t,e)),y=b.length*x>f?_.sizeAvg||Math.max(_.size,3):a(e,x),p=0;p<T.length;p++)d=v[r=T[p]],m=i.getFromId(t,e._diag[r][0])||{},g=i.getFromId(t,e._diag[r][1])||{},o(t,e,m,g,b[p],b[p],y);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=_,A.selectedOptions=l(t,e,e.selected),A.unselectedOptions=l(t,e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},52542:function(t,e,r){\"use strict\";var n=r(34809),i=r(59008),a=r(68697),o=r(64726),s=r(24272),l=r(63197),c=r(4075).isOpenSymbol;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}t.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),m=f(\"showupperhalf\"),g=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||m||g)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"xhoverformat\"),f(\"yhoverformat\"),s(t,e,r,h,f,{noAngleRef:!0,noStandOff:!0});var y=c(e.marker.symbol),v=o.isBubble(e);f(\"marker.line.width\",y||v?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),m=n(\"yaxes\",f),g=e._diag=new Array(s);e._xaxes={},e._yaxes={};var y=[],v=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var _=!u&&!c,b=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],T=0===i,k=i===s-1,A=T&&_||k&&b?void 0:d[i],M=T&&b||k&&_?void 0:m[i];x(A,M,w,y),x(M,A,w,v),g[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<y.length;i++)for(a=0;a<v.length;a++){var S=y[i]+v[a];i>a&&l||i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},27926:function(t,e,r){\"use strict\";var n=r(34809),i=r(77272),a=r(19937).markerStyle;t.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(t,r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},52875:function(t,e){\"use strict\";e.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},25600:function(t,e,r){\"use strict\";var n=r(52875),i=r(36544).calcHover,a=r(29714).getFromId,o=r(93049).extendFlat;function s(t,e,r,a){var o=t.cd[0].trace,s=t.scene.matrixOptions.cdata,l=t.xa,c=t.ya,u=l.c2p(e),h=c.c2p(r),f=t.distance,p=n.getDimIndex(o,l),d=n.getDimIndex(o,c);if(!1===p||!1===d)return[t];for(var m,g,y=s[p],v=s[d],x=f,_=0;_<y.length;_++)if(!a||_===t.index){var b=y[_],w=v[_],T=l.c2p(b)-u,k=c.c2p(w)-h,A=Math.sqrt(T*T+k*k);(a||A<x)&&(x=g=A,m=_)}return t.index=m,t.distance=x,t.dxy=g,void 0===m?[t]:[i(t,y,v,o)]}t.exports={hoverPoints:function(t,e,r,n,i){i||(i={});var l=\"x\"===(n||\"\").charAt(0),c=\"y\"===(n||\"\").charAt(0),u=s(t,e,r);if((l||c)&&\"axis\"===i.hoversubplots&&u[0])for(var h=(l?t.xa:t.ya)._subplotsWith,f=i.gd,p=o({},t),d=0;d<h.length;d++){var m=h[d];if(m!==t.xa._id+t.ya._id){c?p.xa=a(f,m,\"x\"):p.ya=a(f,m,\"y\");var g=s(p,e,r,l||c);u=u.concat(g)}}return u}}},91450:function(t,e,r){\"use strict\";var n=r(86690);n.basePlotModule=r(571),t.exports=n},83027:function(t,e,r){\"use strict\";var n=r(31239),i=r(34809),a=r(5975),o=r(70414).selectMode;function s(t,e){var r,s,l,c,u,h=t._fullLayout,f=h._size,p=e.trace,d=e.t,m=h._splomScenes[p.uid],g=m.matrixOptions,y=g.cdata,v=h._glcanvas.data()[0].regl,x=h.dragmode;if(0!==y.length){g.lower=p.showupperhalf,g.upper=p.showlowerhalf,g.diagonal=p.diagonal.visible;var _=p._visibleDims,b=y.length,w=m.viewOpts={};for(w.ranges=new Array(b),w.domains=new Array(b),u=0;u<_.length;u++){l=_[u];var T=w.ranges[u]=new Array(4),k=w.domains[u]=new Array(4);(r=a.getFromId(t,p._diag[l][0]))&&(T[0]=r._rl[0],T[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(s=a.getFromId(t,p._diag[l][1]))&&(T[1]=s._rl[0],T[3]=s._rl[1],k[1]=s.domain[0],k[3]=s.domain[1])}var A=t._context.plotGlPixelRatio,M=f.l*A,S=f.b*A,E=f.w*A,C=f.h*A;w.viewport=[M,S,E+M,C+S],!0===m.matrix&&(m.matrix=n(v));var L=h.clickmode.indexOf(\"select\")>-1,I=!0;if(o(x)||p.selectedpoints||L){var P=p._length;if(p.selectedpoints){m.selectBatch=p.selectedpoints;var z=p.selectedpoints,O={};for(l=0;l<z.length;l++)O[z[l]]=!0;var D=[];for(l=0;l<P;l++)O[l]||D.push(l);m.unselectBatch=D}var R=d.xpx=new Array(b),F=d.ypx=new Array(b);for(u=0;u<_.length;u++){if(l=_[u],r=a.getFromId(t,p._diag[l][0]))for(R[u]=new Array(P),c=0;c<P;c++)R[u][c]=r.c2p(y[u][c]);if(s=a.getFromId(t,p._diag[l][1]))for(F[u]=new Array(P),c=0;c<P;c++)F[u][c]=s.c2p(y[u][c])}if(m.selectBatch.length||m.unselectBatch.length){var B=i.extendFlat({},g,m.unselectedOptions,w),N=i.extendFlat({},g,m.selectedOptions,w);m.matrix.update(B,N),I=!1}}else d.xpx=d.ypx=null;if(I){var j=i.extendFlat({},g,w);m.matrix.update(j,null)}}}t.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)s(t,r[n][0])}},78880:function(t,e,r){\"use strict\";var n=r(34809);t.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},13392:function(t,e,r){\"use strict\";var n=r(34809),i=n.pushUnique,a=r(64726),o=r(52875);t.exports=function(t,e){var r=t.cd,s=r[0].trace,l=r[0].t,c=t.scene,u=c.matrixOptions.cdata,h=t.xaxis,f=t.yaxis,p=[];if(!c)return p;var d=!a.hasMarkers(s)&&!a.hasText(s);if(!0!==s.visible||d)return p;var m=o.getDimIndex(s,h),g=o.getDimIndex(s,f);if(!1===m||!1===g)return p;var y=l.xpx[m],v=l.ypx[g],x=u[m],_=u[g],b=(t.scene.selectBatch||[]).slice(),w=[];if(!1!==e&&!e.degenerate)for(var T=0;T<x.length;T++)e.contains([y[T],v[T]],null,T,t)?(p.push({pointNumber:T,x:x[T],y:_[T]}),i(b,T)):-1!==b.indexOf(T)?i(b,T):w.push(T);var k=c.matrixOptions;return b.length||w.length?c.selectBatch.length||c.unselectBatch.length||c.matrix.update(c.unselectedOptions,n.extendFlat({},k,c.selectedOptions,c.viewOpts)):c.matrix.update(k,null),c.selectBatch=b,c.unselectBatch=w,p}},14774:function(t,e,r){\"use strict\";var n=r(87163),i=r(80712).axisHoverFormat,a=r(3208).rb,o=r(42450),s=r(9829),l=r(93049).extendFlat,c={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:a({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]}),uhoverformat:i(\"u\",1),vhoverformat:i(\"v\",1),whoverformat:i(\"w\",1),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),showlegend:l({},s.showlegend,{dflt:!1})};l(c,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"})),[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){c[t]=o[t]})),c.hoverinfo=l({},s.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),c.transforms=void 0,t.exports=c},36402:function(t,e,r){\"use strict\";var n=r(34809),i=r(28379);function a(t){var e,r,i,a,s,l,c,u,h,f,p,d,m=t._x,g=t._y,y=t._z,v=t._len,x=-1/0,_=1/0,b=-1/0,w=1/0,T=-1/0,k=1/0,A=\"\";for(v&&(c=m[0],h=g[0],p=y[0]),v>1&&(u=m[v-1],f=g[v-1],d=y[v-1]),e=0;e<v;e++)x=Math.max(x,m[e]),_=Math.min(_,m[e]),b=Math.max(b,g[e]),w=Math.min(w,g[e]),T=Math.max(T,y[e]),k=Math.min(k,y[e]),a||m[e]===c||(a=!0,A+=\"x\"),s||g[e]===h||(s=!0,A+=\"y\"),l||y[e]===p||(l=!0,A+=\"z\");a||(A+=\"x\"),s||(A+=\"y\"),l||(A+=\"z\");var M=o(t._x),S=o(t._y),E=o(t._z);A=(A=(A=A.replace(\"x\",(c>u?\"-\":\"+\")+\"x\")).replace(\"y\",(h>f?\"-\":\"+\")+\"y\")).replace(\"z\",(p>d?\"-\":\"+\")+\"z\");var C=function(){v=0,M=[],S=[],E=[]};(!v||v<M.length*S.length*E.length)&&C();var L=function(t){return\"x\"===t?m:\"y\"===t?g:y},I=function(t){return\"x\"===t?M:\"y\"===t?S:E},P=function(t){return t[v-1]<t[0]?-1:1},z=L(A[1]),O=L(A[3]),D=L(A[5]),R=I(A[1]).length,F=I(A[3]).length,B=I(A[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},U=P(L(A[1])),V=P(L(A[3])),q=P(L(A[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(i=0;i<R-1;i++){var H=j(e,r,i),G=j(e,r,i+1),Z=j(e,r+1,i),W=j(e+1,r,i);if(z[H]*U<z[G]*U&&O[H]*V<O[Z]*V&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn(\"Encountered arbitrary coordinates! Unable to input data grid.\"),C()),{xMin:_,yMin:w,zMin:k,xMax:x,yMax:b,zMax:T,Xs:M,Ys:S,Zs:E,len:v,fill:A}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],i=0;i<e;i++)r[i]=+t[i];return r}t.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,h=0,f=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],m=e._w[u],g=Math.sqrt(p*p+d*d+m*m);h=Math.max(h,g),f=Math.min(f,g)}for(i(t,e,{vals:[f,h],containerStr:\"\",cLetter:\"c\"}),u=0;u<c;u++){var y=n[u];r.xMax=Math.max(r.xMax,y),r.xMin=Math.min(r.xMin,y);var v=o[u];r.yMax=Math.max(r.yMax,v),r.yMin=Math.min(r.yMin,v);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=h,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:a}},49280:function(t,e,r){\"use strict\";var n=r(99098).gl_streamtube3d,i=n.createTubeMesh,a=r(34809),o=r(46998).parseColorScale,s=r(88856).extractOpts,l=r(88239),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function d(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,(function(t){return n.d2l(t)*o}))}if(h.vectors=l(d(e._u,\"xaxis\"),d(e._v,\"yaxis\"),d(e._w,\"zaxis\"),u),!u)return{positions:[],cells:[]};var m=d(e._Xs,\"xaxis\"),g=d(e._Ys,\"yaxis\"),y=d(e._Zs,\"zaxis\");if(h.meshgrid=[m,g,y],h.gridFill=e._gridFill,e._slen)h.startingPositions=l(d(e._startsX,\"xaxis\"),d(e._startsY,\"yaxis\"),d(e._startsZ,\"zaxis\"));else{for(var v=g[0],x=f(m),_=f(y),b=new Array(x.length*_.length),w=0,T=0;T<x.length;T++)for(var k=0;k<_.length;k++)b[w++]=[x[T],v,_[k]];h.startingPositions=b}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var A=d(e._xbnds,\"xaxis\"),M=d(e._ybnds,\"yaxis\"),S=d(e._zbnds,\"zaxis\"),E=p(m),C=p(g),L=p(y),I=[[A[0]-E[0],M[0]-C[0],S[0]-L[0]],[A[1]+E[1],M[1]+C[1],S[1]+L[1]]],P=n(h,I),z=s(e);P.vertexIntensityBounds=[z.min/e._normMax,z.max/e._normMax];var O=e.lightposition;return P.lightPosition=[O.x,O.y,O.z],P.ambient=e.lighting.ambient,P.diffuse=e.lighting.diffuse,P.specular=e.lighting.specular,P.roughness=e.lighting.roughness,P.fresnel=e.lighting.fresnel,P.opacity=e.opacity,e._pad=P.tubeScale*e.sizeref*2,P}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},t.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},52737:function(t,e,r){\"use strict\";var n=r(34809),i=r(39356),a=r(14774);t.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"uhoverformat\"),s(\"vhoverformat\"),s(\"whoverformat\"),s(\"xhoverformat\"),s(\"yhoverformat\"),s(\"zhoverformat\"),e._length=null):e.visible=!1}},51943:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:r(2487),categories:[\"gl3d\",\"showLegend\"],attributes:r(14774),supplyDefaults:r(52737),colorbar:{min:\"cmin\",max:\"cmax\"},calc:r(36402).calc,plot:r(49280),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},56708:function(t,e,r){\"use strict\";var n=r(9829),i=r(3208).rb,a=r(3208).ay,o=r(87163),s=r(13792).u,l=r(55412),c=r(2032),u=r(93049).extendFlat,h=r(94850).k;t.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},count:{valType:\"flaglist\",flags:[\"branches\",\"leaves\"],dflt:\"leaves\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:u({colors:{valType:\"data_array\",editType:\"calc\"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:\"calc\"},pattern:h,editType:\"calc\"},o(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1},editType:\"plot\"},text:l.text,textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],extras:[\"none\"],editType:\"plot\"},texttemplate:a({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],dflt:\"label+text+value+name\"}),hovertemplate:i({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),rotation:{valType:\"angle\",dflt:0,editType:\"plot\"},sort:l.sort,root:{color:{valType:\"color\",editType:\"calc\",dflt:\"rgba(0,0,0,0)\"},editType:\"calc\"},domain:s({name:\"sunburst\",trace:!0,editType:\"calc\"})}},14724:function(t,e,r){\"use strict\";var n=r(44122);e.name=\"sunburst\",e.plot=function(t,r,i,a){n.plotBasePlot(e.name,t,r,i,a)},e.clean=function(t,r,i,a){n.cleanBasePlot(e.name,t,r,i,a)}},14852:function(t,e,r){\"use strict\";var n=r(92264),i=r(10721),a=r(34809),o=r(88856).makeColorScaleFuncFromTrace,s=r(44148).makePullColorFn,l=r(44148).generateExtendedColors,c=r(88856).calc,u=r(63821).ALMOST_EQUAL,h={},f={},p={};function d(t,e,r){var n=0,i=t.children;if(i){for(var a=i.length,o=0;o<a;o++)n+=d(i[o],e,r);r.branches&&n++}else r.leaves&&n++;return t.value=t.data.data.value=n,e._values||(e._values=[]),e._values[t.data.data.i]=n,n}e.calc=function(t,e){var r,l,h,f,p,m,g=t._fullLayout,y=e.ids,v=a.isArrayOrTypedArray(y),x=e.labels,_=e.parents,b=e.values,w=a.isArrayOrTypedArray(b),T=[],k={},A={},M=function(t){return t||\"number\"==typeof t},S=function(t){return!w||i(b[t])&&b[t]>=0};v?(r=Math.min(y.length,_.length),l=function(t){return M(y[t])&&S(t)},h=function(t){return String(y[t])}):(r=Math.min(x.length,_.length),l=function(t){return M(x[t])&&S(t)},h=function(t){return String(x[t])}),w&&(r=Math.min(r,b.length));for(var E=0;E<r;E++)if(l(E)){var C=h(E),L=M(_[E])?String(_[E]):\"\",I={i:E,id:C,pid:L,label:M(x[E])?String(x[E]):\"\"};w&&(I.v=+b[E]),T.push(I),p=C,k[f=L]?k[f].push(p):k[f]=[p],A[p]=1}if(k[\"\"]){if(k[\"\"].length>1){for(var P=a.randstr(),z=0;z<T.length;z++)\"\"===T[z].pid&&(T[z].pid=P);T.unshift({hasMultipleRoots:!0,id:P,pid:\"\",label:\"\"})}}else{var O,D=[];for(O in k)A[O]||D.push(O);if(1!==D.length)return a.warn([\"Multiple implied roots, cannot build\",e.type,\"hierarchy of\",e.name+\".\",\"These roots include:\",D.join(\", \")].join(\" \"));O=D[0],T.unshift({hasImpliedRoot:!0,id:O,pid:\"\",label:O})}try{m=n.stratify().id((function(t){return t.id})).parentId((function(t){return t.pid}))(T)}catch(t){return a.warn([\"Failed to build\",e.type,\"hierarchy of\",e.name+\".\",\"Error:\",t.message].join(\" \"))}var R=n.hierarchy(m),F=!1;if(w)switch(e.branchvalues){case\"remainder\":R.sum((function(t){return t.data.v}));break;case\"total\":R.each((function(t){var r=t.data.data,n=r.v;if(t.children){var i=t.children.reduce((function(t,e){return t+e.data.data.v}),0);if((r.hasImpliedRoot||r.hasMultipleRoots)&&(n=i),n<i*u)return F=!0,a.warn([\"Total value for node\",t.data.data.id,\"of\",e.name,\"is smaller than the sum of its children.\",\"\\nparent value =\",n,\"\\nchildren sum =\",i].join(\" \"))}t.value=n}))}else d(R,e,{branches:-1!==e.count.indexOf(\"branches\"),leaves:-1!==e.count.indexOf(\"leaves\")});if(!F){var B,N;e.sort&&R.sort((function(t,e){return e.value-t.value}));var j=e.marker.colors||[],U=!!j.length;return e._hasColorscale?(U||(j=w?e.values:e._values),c(t,e,{vals:j,containerStr:\"marker\",cLetter:\"c\"}),N=o(e.marker)):B=s(g[\"_\"+e.type+\"colormap\"]),R.each((function(t){var r=t.data.data;r.color=e._hasColorscale?N(j[r.i]):B(j[r.i],r.id)})),T[0].hierarchy=R,T}},e._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,i=r[t+\"colorway\"],a=r[\"_\"+t+\"colormap\"];r[\"extend\"+t+\"colors\"]&&(i=l(i,\"icicle\"===t?p:\"treemap\"===t?f:h));var o,s=0;function c(t){var e=t.data.data,r=e.id;!1===e.color&&(a[r]?e.color=a[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(a[r]=e.color=i[s%i.length],s++):e.color=o)}for(var u=0;u<n.length;u++){var d=n[u][0];d.trace.type===t&&d.hierarchy&&(o=d.trace.root.color,d.hierarchy.each(c))}},e.crossTraceCalc=function(t){return e._runCrossTraceCalc(\"sunburst\",t)}},2032:function(t){\"use strict\";t.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"]}},33459:function(t,e,r){\"use strict\";var n=r(34809),i=r(56708),a=r(13792).N,o=r(17550).handleText,s=r(46979).handleMarkerDefaults,l=r(88856),c=l.hasColorscale,u=l.handleDefaults;t.exports=function(t,e,r,l){function h(r,a){return n.coerce(t,e,i,r,a)}var f=h(\"labels\"),p=h(\"parents\");if(f&&f.length&&p&&p.length){var d=h(\"values\");d&&d.length?h(\"branchvalues\"):h(\"count\"),h(\"level\"),h(\"maxdepth\"),s(t,e,l,h);var m=e._hasColorscale=c(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;m&&u(t,e,l,h,{prefix:\"marker.\",cLetter:\"c\"}),h(\"leaf.opacity\",m?1:.7);var g=h(\"text\");h(\"texttemplate\"),e.texttemplate||h(\"textinfo\",n.isArrayOrTypedArray(g)?\"text+label\":\"label\"),h(\"hovertext\"),h(\"hovertemplate\"),o(t,e,l,h,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),h(\"insidetextorientation\"),h(\"sort\"),h(\"rotation\"),h(\"root.color\"),a(e,l,h),e._length=null}else e.visible=!1}},72043:function(t,e,r){\"use strict\";var n=r(62203),i=r(78766);t.exports=function(t,e,r,a,o){var s=e.data.data,l=s.i,c=o||s.color;if(l>=0){e.i=s.i;var u=r.marker;u.pattern&&u.colors&&u.pattern.shape||(u.color=c,e.color=c),n.pointStyle(t,r,a,e)}else i.fill(t,c)}},44691:function(t,e,r){\"use strict\";var n=r(45568),i=r(33626),a=r(36040).appendArrayPointValue,o=r(32141),s=r(34809),l=r(68596),c=r(33108),u=r(37252).formatPieValue;function h(t,e,r){for(var n=t.data.data,i={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(i[s]=t[s])}return\"parentString\"in t&&!c.isHierarchyRoot(t)&&(i.parent=t.parentString),a(i,e,n.i),i}t.exports=function(t,e,r,a,f){var p=a[0],d=p.trace,m=p.hierarchy,g=\"sunburst\"===d.type,y=\"treemap\"===d.type||\"icicle\"===d.type;\"_hasHoverLabel\"in d||(d._hasHoverLabel=!1),\"_hasHoverEvent\"in d||(d._hasHoverEvent=!1),t.on(\"mouseover\",(function(i){var a=r._fullLayout;if(!r._dragging&&!1!==a.hovermode){var l,v=r._fullData[d.index],x=i.data.data,_=x.i,b=c.isHierarchyRoot(i),w=c.getParent(m,i),T=c.getValue(i),k=function(t){return s.castOption(v,_,t)},A=k(\"hovertemplate\"),M=o.castHoverinfo(v,a,_),S=a.separators;if(A||M&&\"none\"!==M&&\"skip\"!==M){var E,C;g&&(E=p.cx+i.pxmid[0]*(1-i.rInscribed),C=p.cy+i.pxmid[1]*(1-i.rInscribed)),y&&(E=i._hoverX,C=i._hoverY);var L,I={},P=[],z=[],O=function(t){return-1!==P.indexOf(t)};M&&(P=\"all\"===M?v._module.attributes.hoverinfo.flags:M.split(\"+\")),I.label=x.label,O(\"label\")&&I.label&&z.push(I.label),x.hasOwnProperty(\"v\")&&(I.value=x.v,I.valueLabel=u(I.value,S),O(\"value\")&&z.push(I.valueLabel)),I.currentPath=i.currentPath=c.getPath(i.data),O(\"current path\")&&!b&&z.push(I.currentPath);var D=[],R=function(){-1===D.indexOf(L)&&(z.push(L),D.push(L))};I.percentParent=i.percentParent=T/c.getValue(w),I.parent=i.parentString=c.getPtLabel(w),O(\"percent parent\")&&(L=c.formatPercent(I.percentParent,S)+\" of \"+I.parent,R()),I.percentEntry=i.percentEntry=T/c.getValue(e),I.entry=i.entry=c.getPtLabel(e),!O(\"percent entry\")||b||i.onPathbar||(L=c.formatPercent(I.percentEntry,S)+\" of \"+I.entry,R()),I.percentRoot=i.percentRoot=T/c.getValue(m),I.root=i.root=c.getPtLabel(m),O(\"percent root\")&&!b&&(L=c.formatPercent(I.percentRoot,S)+\" of \"+I.root,R()),I.text=k(\"hovertext\")||k(\"text\"),O(\"text\")&&(L=I.text,s.isValidTextValue(L)&&z.push(L)),l=[h(i,v,f.eventDataKeys)];var F={trace:v,y:C,_x0:i._x0,_x1:i._x1,_y0:i._y0,_y1:i._y1,text:z.join(\"<br>\"),name:A||O(\"name\")?v.name:void 0,color:k(\"hoverlabel.bgcolor\")||x.color,borderColor:k(\"hoverlabel.bordercolor\"),fontFamily:k(\"hoverlabel.font.family\"),fontSize:k(\"hoverlabel.font.size\"),fontColor:k(\"hoverlabel.font.color\"),fontWeight:k(\"hoverlabel.font.weight\"),fontStyle:k(\"hoverlabel.font.style\"),fontVariant:k(\"hoverlabel.font.variant\"),nameLength:k(\"hoverlabel.namelength\"),textAlign:k(\"hoverlabel.align\"),hovertemplate:A,hovertemplateLabels:I,eventData:l};g&&(F.x0=E-i.rInscribed*i.rpx1,F.x1=E+i.rInscribed*i.rpx1,F.idealAlign=i.pxmid[0]<0?\"left\":\"right\"),y&&(F.x=E,F.idealAlign=E<0?\"left\":\"right\");var B=[];o.loneHover(F,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r,inOut_bbox:B}),l[0].bbox=B[0],d._hasHoverLabel=!0}if(y){var N=t.select(\"path.surface\");f.styleOne(N,i,v,r,{hovered:!0})}d._hasHoverEvent=!0,r.emit(\"plotly_hover\",{points:l||[h(i,v,f.eventDataKeys)],event:n.event})}})),t.on(\"mouseout\",(function(e){var i=r._fullLayout,a=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit(\"plotly_unhover\",{points:[h(s,a,f.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(i._hoverlayer.node()),d._hasHoverLabel=!1),y){var l=t.select(\"path.surface\");f.styleOne(l,s,a,r,{hovered:!1})}})),t.on(\"click\",(function(t){var e=r._fullLayout,a=r._fullData[d.index],s=g&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(m,u):c.findEntryWithLevel(m,u),y=c.getPtId(p),v={points:[h(t,a,f.eventDataKeys)],event:n.event};s||(v.nextLevel=y);var x=l.triggerHandler(r,\"plotly_\"+d.type+\"click\",v);if(!1!==x&&e.hovermode&&(r._hoverdata=[h(t,a,f.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){i.call(\"_storeDirectGUIEdit\",a,e._tracePreGUI[a.uid],{level:a.level});var _={data:[{level:y}],traces:[d.index]},b={frame:{redraw:!1,duration:f.transitionTime},transition:{duration:f.transitionTime,easing:f.transitionEasing},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),i.call(\"animate\",r,_,b)}}))}},33108:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(27983),o=r(37252);function s(t){return t.data.data.pid}e.findEntryWithLevel=function(t,r){var n;return r&&t.eachAfter((function(t){if(e.getPtId(t)===r)return n=t.copy()})),n||t},e.findEntryWithChild=function(t,r){var n;return t.eachAfter((function(t){for(var i=t.children||[],a=0;a<i.length;a++){var o=i[a];if(e.getPtId(o)===r)return n=t.copy()}})),n||t},e.isEntry=function(t){return!t.parent},e.isLeaf=function(t){return!t.children},e.getPtId=function(t){return t.data.data.id},e.getPtLabel=function(t){return t.data.data.label},e.getValue=function(t){return t.value},e.isHierarchyRoot=function(t){return\"\"===s(t)},e.setSliceCursor=function(t,r,n){var i=n.isTransitioning;if(!i){var o=t.datum();i=n.hideOnRoot&&e.isHierarchyRoot(o)||n.hideOnLeaves&&e.isLeaf(o)}a(t,i?null:\"pointer\")},e.getInsideTextFontKey=function(t,e,r,i,a){var o=(a||{}).onPathbar?\"pathbar.textfont\":\"insidetextfont\",s=r.data.data.i;return n.castOption(e,s,o+\".\"+t)||n.castOption(e,s,\"textfont.\"+t)||i.size},e.getOutsideTextFontKey=function(t,e,r,i){var a=r.data.data.i;return n.castOption(e,a,\"outsidetextfont.\"+t)||n.castOption(e,a,\"textfont.\"+t)||i.size},e.isOutsideText=function(t,r){return!t._hasColorscale&&e.isHierarchyRoot(r)},e.determineTextFont=function(t,r,a,o){return e.isOutsideText(t,r)?function(t,r,n){return{color:e.getOutsideTextFontKey(\"color\",t,r,n),family:e.getOutsideTextFontKey(\"family\",t,r,n),size:e.getOutsideTextFontKey(\"size\",t,r,n),weight:e.getOutsideTextFontKey(\"weight\",t,r,n),style:e.getOutsideTextFontKey(\"style\",t,r,n),variant:e.getOutsideTextFontKey(\"variant\",t,r,n),textcase:e.getOutsideTextFontKey(\"textcase\",t,r,n),lineposition:e.getOutsideTextFontKey(\"lineposition\",t,r,n),shadow:e.getOutsideTextFontKey(\"shadow\",t,r,n)}}(t,r,a):function(t,r,a,o){var s=(o||{}).onPathbar,l=r.data.data,c=l.i,u=n.castOption(t,c,(s?\"pathbar.textfont\":\"insidetextfont\")+\".color\");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,\"textfont.color\")),{color:u||i.contrast(l.color),family:e.getInsideTextFontKey(\"family\",t,r,a,o),size:e.getInsideTextFontKey(\"size\",t,r,a,o),weight:e.getInsideTextFontKey(\"weight\",t,r,a,o),style:e.getInsideTextFontKey(\"style\",t,r,a,o),variant:e.getInsideTextFontKey(\"variant\",t,r,a,o),textcase:e.getInsideTextFontKey(\"textcase\",t,r,a,o),lineposition:e.getInsideTextFontKey(\"lineposition\",t,r,a,o),shadow:e.getInsideTextFontKey(\"shadow\",t,r,a,o)}}(t,r,a,o)},e.hasTransition=function(t){return!!(t&&t.duration>0)},e.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},e.isHeader=function(t,r){return!(e.isLeaf(t)||t.depth===r._maxDepth-1)},e.getParent=function(t,r){return e.findEntryWithLevel(t,s(r))},e.listPath=function(t,r){var n=t.parent;if(!n)return[];var i=r?[n.data[r]]:[n];return e.listPath(n,r).concat(i)},e.getPath=function(t){return e.listPath(t,\"label\").join(\"/\")+\"/\"},e.formatValue=o.formatPieValue,e.formatPercent=function(t,e){var r=n.formatPercent(t,0);return\"0%\"===r&&(r=o.formatPiePercent(t,e)),r}},80809:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:r(14724),categories:[],animatable:!0,attributes:r(56708),layoutAttributes:r(98959),supplyDefaults:r(33459),supplyLayoutDefaults:r(75816),calc:r(14852).calc,crossTraceCalc:r(14852).crossTraceCalc,plot:r(19718).plot,style:r(98972).style,colorbar:r(21146),meta:{}}},98959:function(t){\"use strict\";t.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},75816:function(t,e,r){\"use strict\";var n=r(34809),i=r(98959);t.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},19718:function(t,e,r){\"use strict\";var n=r(45568),i=r(92264),a=r(88640).GW,o=r(62203),s=r(34809),l=r(30635),c=r(84102),u=c.recordMinTextSize,h=c.clearMinTextSize,f=r(35734),p=r(37252).getRotationAngle,d=f.computeTransform,m=f.transformInsideText,g=r(98972).styleOne,y=r(6851).resizeText,v=r(44691),x=r(2032),_=r(33108);function b(t,r,c,h){var f=t._context.staticPlot,y=t._fullLayout,b=!y.uniformtext.mode&&_.hasTransition(h),T=n.select(c).selectAll(\"g.slice\"),k=r[0],A=k.trace,M=k.hierarchy,S=_.findEntryWithLevel(M,A.level),E=_.getMaxDepth(A),C=y._size,L=A.domain,I=C.w*(L.x[1]-L.x[0]),P=C.h*(L.y[1]-L.y[0]),z=.5*Math.min(I,P),O=k.cx=C.l+C.w*(L.x[1]+L.x[0])/2,D=k.cy=C.t+C.h*(1-L.y[0])-P/2;if(!S)return T.remove();var R=null,F={};b&&T.each((function(t){F[_.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!R&&_.isEntry(t)&&(R=t)}));var B=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(S).descendants(),N=S.height+1,j=0,U=E;k.hasMultipleRoots&&_.isHierarchyRoot(S)&&(B=B.slice(1),N-=1,j=1,U+=1),B=B.filter((function(t){return t.y1<=U}));var V=p(A.rotation);V&&B.forEach((function(t){t.x0+=V,t.x1+=V}));var q=Math.min(N,E),H=function(t){return(t-j)/q*z},G=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},Z=function(t){return s.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,O,D)},W=function(t){return O+w(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},Y=function(t){return D+w(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(T=T.data(B,_.getPtId)).enter().append(\"g\").classed(\"slice\",!0),b?T.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=_.getPtId(t),n=F[r],i=F[_.getPtId(S)];if(i){var o=(t.x1>i.x1?2*Math.PI:0)+V;e=t.rpx1<i.rpx1?{x0:t.x0,x1:t.x1,rpx0:0,rpx1:0}:{x0:o,x1:o,rpx0:t.rpx0,rpx1:t.rpx1}}else{var s,l=_.getPtId(t.parent);T.each((function(t){if(_.getPtId(t)===l)return s=t}));var c,u=s.children;u.forEach((function(t,e){if(_.getPtId(t)===r)return c=e}));var h=u.length,f=a(s.x0,s.x1);e={rpx0:z,rpx1:z,x0:f(c/h),x1:f((c+1)/h)}}return a(n,e)}(t);return function(t){return Z(e(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():T.exit().remove(),T.order();var X=null;if(b&&R){var $=_.getPtId(R);T.each((function(t){null===X&&_.getPtId(t)===$&&(X=t.x1)}))}var J=T;function K(t){var e=t.parent,r=F[_.getPtId(e)],n={};if(r){var i=e.children,o=i.indexOf(t),s=i.length,l=a(r.x0,r.x1);n.x0=l(o/s),n.x1=l(o/s)}else n.x0=n.x1=0;return n}b&&(J=J.transition().each(\"end\",(function(){var e=n.select(this);_.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})}))),J.each((function(i){var c=n.select(this),h=s.ensureSingle(c,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",f?\"none\":\"all\")}));i.rpx0=H(i.y0),i.rpx1=H(i.y1),i.xmid=(i.x0+i.x1)/2,i.pxmid=G(i.rpx1,i.xmid),i.midangle=-(i.xmid-Math.PI/2),i.startangle=-(i.x0-Math.PI/2),i.stopangle=-(i.x1-Math.PI/2),i.halfangle=.5*Math.min(s.angleDelta(i.x0,i.x1)||Math.PI,Math.PI),i.ring=1-i.rpx0/i.rpx1,i.rInscribed=function(t){return 0===t.rpx0&&s.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(i),b?h.transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=F[_.getPtId(t)],n={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(R)if(t.parent)if(X){var i=(t.x1>X?2*Math.PI:0)+V;e={x0:i,x1:i}}else e={rpx0:z,rpx1:z},s.extendFlat(e,K(t));else e={rpx0:0,rpx1:0};else e={x0:V,x1:V};return a(e,n)}(t);return function(t){return Z(e(t))}})):h.attr(\"d\",Z),c.call(v,S,t,r,{eventDataKeys:x.eventDataKeys,transitionTime:x.CLICK_TRANSITION_TIME,transitionEasing:x.CLICK_TRANSITION_EASING}).call(_.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),h.call(g,i,A,t);var p=s.ensureSingle(c,\"g\",\"slicetext\"),w=s.ensureSingle(p,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),T=s.ensureUniformFontSize(t,_.determineTextFont(A,i,y.font));w.text(e.formatSliceLabel(i,S,A,r,y)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(o.font,T).call(l.convertToTspans,t);var M=o.bBox(w.node());i.transform=m(M,i,k),i.transform.targetX=W(i),i.transform.targetY=Y(i);var E=function(t,e){var r=t.transform;return d(r,e),r.fontSize=T.size,u(A.type,r,y),s.getTextTransform(r)};b?w.transition().attrTween(\"transform\",(function(t){var e=function(t){var e,r=F[_.getPtId(t)],n=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:n.textPosAngle,scale:0,rotate:n.rotate,rCenter:n.rCenter,x:n.x,y:n.y}},R)if(t.parent)if(X){var i=t.x1>X?2*Math.PI:0;e.x0=e.x1=i}else s.extendFlat(e,K(t));else e.x0=e.x1=V;else e.x0=e.x1=V;var o=a(e.transform.textPosAngle,t.transform.textPosAngle),l=a(e.rpx1,t.rpx1),c=a(e.x0,t.x0),h=a(e.x1,t.x1),f=a(e.transform.scale,n.scale),p=a(e.transform.rotate,n.rotate),d=0===n.rCenter?3:0===e.transform.rCenter?1/3:1,m=a(e.transform.rCenter,n.rCenter);return function(t){var e=l(t),r=c(t),i=h(t),a=function(t){return m(Math.pow(t,d))}(t),s={pxmid:G(e,(r+i)/2),rpx1:e,transform:{textPosAngle:o(t),rCenter:a,x:n.x,y:n.y}};return u(A.type,n,y),{transform:{targetX:W(s),targetY:Y(s),scale:f(t),rotate:p(t),rCenter:a}}}}(t);return function(t){return E(e(t),M)}})):w.attr(\"transform\",E(i,M))}))}function w(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}e.plot=function(t,e,r,i){var a,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,u=!s.uniformtext.mode&&_.hasTransition(r);h(\"sunburst\",s),(a=l.selectAll(\"g.trace.sunburst\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),u?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){o&&o()})).each(\"interrupt\",(function(){o&&o()})).each((function(){l.selectAll(\"g.trace\").each((function(e){b(t,e,this,r)}))}))):(a.each((function(e){b(t,e,this,r)})),s.uniformtext.mode&&y(t,s._sunburstlayer.selectAll(\".trace\"),\"sunburst\")),c&&a.exit().remove()},e.formatSliceLabel=function(t,e,r,n,i){var a=r.texttemplate,o=r.textinfo;if(!(a||o&&\"none\"!==o))return\"\";var l=i.separators,c=n[0],u=t.data.data,h=c.hierarchy,f=_.isHierarchyRoot(t),p=_.getParent(h,t),d=_.getValue(t);if(!a){var m,g=o.split(\"+\"),y=function(t){return-1!==g.indexOf(t)},v=[];if(y(\"label\")&&u.label&&v.push(u.label),u.hasOwnProperty(\"v\")&&y(\"value\")&&v.push(_.formatValue(u.v,l)),!f){y(\"current path\")&&v.push(_.getPath(t.data));var x=0;y(\"percent parent\")&&x++,y(\"percent entry\")&&x++,y(\"percent root\")&&x++;var b=x>1;if(x){var w,T=function(t){m=_.formatPercent(w,l),b&&(m+=\" of \"+t),v.push(m)};y(\"percent parent\")&&!f&&(w=d/_.getValue(p),T(\"parent\")),y(\"percent entry\")&&(w=d/_.getValue(e),T(\"entry\")),y(\"percent root\")&&(w=d/_.getValue(h),T(\"root\"))}}return y(\"text\")&&(m=s.castOption(r,u.i,\"text\"),s.isValidTextValue(m)&&v.push(m)),v.join(\"<br>\")}var k=s.castOption(r,u.i,\"texttemplate\");if(!k)return\"\";var A={};u.label&&(A.label=u.label),u.hasOwnProperty(\"v\")&&(A.value=u.v,A.valueLabel=_.formatValue(u.v,l)),A.currentPath=_.getPath(t.data),f||(A.percentParent=d/_.getValue(p),A.percentParentLabel=_.formatPercent(A.percentParent,l),A.parent=_.getPtLabel(p)),A.percentEntry=d/_.getValue(e),A.percentEntryLabel=_.formatPercent(A.percentEntry,l),A.entry=_.getPtLabel(e),A.percentRoot=d/_.getValue(h),A.percentRootLabel=_.formatPercent(A.percentRoot,l),A.root=_.getPtLabel(h),u.hasOwnProperty(\"color\")&&(A.color=u.color);var M=s.castOption(r,u.i,\"text\");return(s.isValidTextValue(M)||\"\"===M)&&(A.text=M),A.customdata=s.castOption(r,u.i,\"customdata\"),s.texttemplateString(k,A,i._d3locale,A,r._meta||{})}},98972:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(34809),o=r(84102).resizeText,s=r(72043);function l(t,e,r,n){var o=e.data.data,l=!e.children,c=o.i,u=a.castOption(r,c,\"marker.line.color\")||i.defaultLine,h=a.castOption(r,c,\"marker.line.width\")||0;t.call(s,e,r,n).style(\"stroke-width\",h).call(i.stroke,u).style(\"opacity\",l?r.leaf.opacity:null)}t.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(\".trace\");o(t,e,\"sunburst\"),e.each((function(e){var r=n.select(this),i=e[0].trace;r.style(\"opacity\",i.opacity),r.selectAll(\"path.surface\").each((function(e){n.select(this).call(l,e,i,t)}))}))},styleOne:l}},16131:function(t,e,r){\"use strict\";var n=r(78766),i=r(87163),a=r(80712).axisHoverFormat,o=r(3208).rb,s=r(9829),l=r(93049).extendFlat,c=r(13582).overrideAll;function u(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var h=t.exports=c(l({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:o(),xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),zhoverformat:a(\"z\"),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:u(),y:u(),z:u()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},opacityscale:{valType:\"any\",editType:\"calc\"},_deprecated:{zauto:l({},i.zauto,{}),zmin:l({},i.zmin,{}),zmax:l({},i.zmax,{})},hoverinfo:l({},s.hoverinfo),showlegend:l({},s.showlegend,{dflt:!1})}),\"calc\",\"nested\");h.x.editType=h.y.editType=h.z.editType=\"calc+clearAxisTypes\",h.transforms=void 0},53027:function(t,e,r){\"use strict\";var n=r(28379);t.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},27159:function(t,e,r){\"use strict\";var n=r(99098).gl_surface3d,i=r(99098).ndarray,a=r(99098).ndarray_linear_interpolate.d2,o=r(69295),s=r(78106),l=r(34809).isArrayOrTypedArray,c=r(46998).parseColorScale,u=r(55010),h=r(88856).extractOpts;function f(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var p=f.prototype;p.getXat=function(t,e,r,n){var i=l(this.data.x)?l(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},p.getYat=function(t,e,r,n){var i=l(this.data.y)?l(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},p.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},p.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){null!=t.dataCoordinate[a]&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var o=this.data.hovertext||this.data.text;return l(o)&&o[i]&&void 0!==o[i][n]?t.textLabel=o[i][n]:t.textLabel=o||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var d=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function m(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function g(t){for(var e=[],r=0;r<d.length;r++){var n=d[r];e.push(m(t,n))}return e}function y(t){for(var e=g(t),r=t,n=0;n<d.length;n++)if(e[n]>0){r=d[n];break}return r}function v(t,e){if(!(t<1||e<1)){for(var r=g(t),n=g(e),i=1,a=0;a<d.length;a++)i*=Math.pow(d[a],Math.max(r[a],n[a]));return i}}p.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},p.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var x=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=x[9],b=x[13];function w(t,e,r){var n=r[8]+r[2]*e[0]+r[5]*e[1];return t[0]=(r[6]+r[0]*e[0]+r[3]*e[1])/n,t[1]=(r[7]+r[1]*e[0]+r[4]*e[1])/n,t}function T(t,e,r){return function(t,e,r,n){for(var i=[0,0],o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++)r(i,[l,c],n),t.set(l,c,a(e,i[0],i[1]))}(t,e,w,r),t}function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}p.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=v(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>b;)r--,r/=y(r),++r<_&&(r=b);var n=Math.round(r/t);return n>1?n:1},p.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],a=t[0].shape[1],o=0|Math.floor(t[0].shape[0]*e+1),s=0|Math.floor(t[0].shape[1]*r+1),l=1+n+1,c=1+a+1,u=i(new Float32Array(l*c),[l,c]),h=[1/e,0,0,0,1/r,0,0,0,1],f=0;f<t.length;++f){this.surface.padField(u,t[f]);var p=i(new Float32Array(o*s),[o,s]);T(p,u,h),t[f]=p}},p.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},p.update=function(t){var e,r,n,a,l=this.scene,f=l.fullSceneLayout,p=this.surface,d=c(t),m=l.dataScale,g=t.z[0].length,y=t._ylength,v=l.contourLevels;this.data=t;var x=[];for(e=0;e<3;e++)for(x[e]=[],r=0;r<g;r++)x[e][r]=[];for(r=0;r<g;r++)for(n=0;n<y;n++)x[0][r][n]=this.getXat(r,n,t.xcalendar,f.xaxis),x[1][r][n]=this.getYat(r,n,t.ycalendar,f.yaxis),x[2][r][n]=this.getZat(r,n,t.zcalendar,f.zaxis);if(t.connectgaps)for(t._emptypoints=s(x[2]),o(x[2],t._emptypoints),t._interpolatedZ=[],r=0;r<g;r++)for(t._interpolatedZ[r]=[],n=0;n<y;n++)t._interpolatedZ[r][n]=x[2][r][n];for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<y;n++)null==(a=x[e][r][n])?x[e][r][n]=NaN:a=x[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<y;n++)null!=(a=x[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<y;n++)null!=(a=x[e][r][n])&&(x[e][r][n]-=this.objectOffset[e]);var _=[i(new Float32Array(g*y),[g,y]),i(new Float32Array(g*y),[g,y]),i(new Float32Array(g*y),[g,y])];for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<y;n++)_[e].set(r,n,x[e][r][n]);x=[];var w={colormap:d,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},T=h(t);if(w.intensityBounds=[T.min,T.max],t.surfacecolor){var k=i(new Float32Array(g*y),[g,y]);for(r=0;r<g;r++)for(n=0;n<y;n++)k.set(r,n,t.surfacecolor[n][r]);_.push(k)}else w.intensityBounds[0]*=m[2],w.intensityBounds[1]*=m[2];(b<_[0].shape[0]||b<_[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(_[0].shape[0],0),this.dataScaleY=this.estimateScale(_[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(_)),t.surfacecolor&&(w.intensity=_.pop());var A=[!0,!0,!0],M=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var S=t.contours[M[e]];A[e]=S.highlight,w.showContour[e]=S.show||S.highlight,w.showContour[e]&&(w.contourProject[e]=[S.project.x,S.project.y,S.project.z],S.show?(this.showContour[e]=!0,w.levels[e]=v[e],p.highlightColor[e]=w.contourColor[e]=u(S.color),S.usecolormap?p.highlightTint[e]=w.contourTint[e]=0:p.highlightTint[e]=w.contourTint[e]=1,w.contourWidth[e]=S.width,this.contourStart[e]=S.start,this.contourEnd[e]=S.end,this.contourSize[e]=S.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),S.highlight&&(w.dynamicColor[e]=u(S.highlightcolor),w.dynamicWidth[e]=S.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(d)&&(w.vertexColor=!0),w.objectOffset=this.objectOffset,w.coords=_,p.update(w),p.visible=t.visible,p.enableDynamic=A,p.enableHighlight=A,p.snapToData=!0,\"lighting\"in t&&(p.ambientLight=t.lighting.ambient,p.diffuseLight=t.lighting.diffuse,p.specularLight=t.lighting.specular,p.roughness=t.lighting.roughness,p.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(p.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z])},p.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},t.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new f(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},65444:function(t,e,r){\"use strict\";var n=r(33626),i=r(34809),a=r(39356),o=r(16131);function s(t,e,r,n){var i=n(\"opacityscale\");\"max\"===i?e.opacityscale=[[0,.1],[1,1]]:\"min\"===i?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===i?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=.1+.9*(1-Math.pow(Math.sin(1*i*Math.PI),2));r.push([i,Math.max(0,Math.min(1,a))])}return r}():function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(i)||(e.opacityscale=void 0)}function l(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}t.exports={supplyDefaults:function(t,e,r,c){var u,h;function f(r,n){return i.coerce(t,e,o,r,n)}var p=f(\"x\"),d=f(\"y\"),m=f(\"z\");if(!m||!m.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&i.isArrayOrTypedArray(p[0])?m.length:m[0].length,e._ylength=m.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],c),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"xhoverformat\"),f(\"yhoverformat\"),f(\"zhoverformat\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach((function(t){f(t)}));var g=f(\"surfacecolor\"),y=[\"x\",\"y\",\"z\"];for(u=0;u<3;++u){var v=\"contours.\"+y[u],x=f(v+\".show\"),_=f(v+\".highlight\");if(x||_)for(h=0;h<3;++h)f(v+\".project.\"+y[h]);x&&(f(v+\".color\"),f(v+\".width\"),f(v+\".usecolormap\")),_&&(f(v+\".highlightcolor\"),f(v+\".highlightwidth\")),f(v+\".start\"),f(v+\".end\"),f(v+\".size\")}g||(l(t,\"zmin\",\"cmin\"),l(t,\"zmax\",\"cmax\"),l(t,\"zauto\",\"cauto\")),a(t,e,c,f,{prefix:\"\",cLetter:\"c\"}),s(0,e,0,f),e._length=null}},opacityscaleDefaults:s}},95984:function(t,e,r){\"use strict\";t.exports={attributes:r(16131),supplyDefaults:r(65444).supplyDefaults,colorbar:{min:\"cmin\",max:\"cmax\"},calc:r(53027),plot:r(27159),moduleType:\"trace\",name:\"surface\",basePlotModule:r(2487),categories:[\"gl3d\",\"2dMap\",\"showLegend\"],meta:{}}},92294:function(t,e,r){\"use strict\";var n=r(50222),i=r(93049).extendFlat,a=r(13582).overrideAll,o=r(80337),s=r(13792).u,l=r(80712).descriptionOnlyNumbers;(t.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[],description:l(\"cell value\")},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[],description:l(\"cell value\")},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},82662:function(t,e,r){\"use strict\";var n=r(4173).eV,i=r(84576),a=\"table\";e.name=a,e.plot=function(t){var e=n(t.calcdata,a)[0];e.length&&i(t,e)},e.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._paperdiv.selectAll(\".table\").remove()}},87522:function(t,e,r){\"use strict\";var n=r(71293).wrap;t.exports=function(){return n({})}},18426:function(t){\"use strict\";t.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},21908:function(t,e,r){\"use strict\";var n=r(18426),i=r(93049).extendFlat,a=r(10721),o=r(87800).isTypedArray,s=r(87800).isArrayOrTypedArray;function l(t){if(s(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,l(t[r]));return e}return t}function c(t,e){return t+e}function u(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)o(r[e])?r[e]=Array.from(r[e]):s(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(h(a)))}return r}function h(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function f(t){return t.calcdata.columns.reduce((function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e}),0)}function p(t,e){return Object.keys(t).map((function(r){return i({},t[r],{auxiliaryBlocks:e})}))}function d(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}t.exports=function(t,e){var r=u(e.cells.values),o=function(t){return t.slice(e.header.values.length,t.length)},m=u(e.header.values);m.length&&!m[0].length&&(m[0]=[\"\"],m=u(m));var g=m.concat(o(r).map((function(){return h((m[0]||[\"\"]).length)}))),y=e.domain,v=Math.floor(t._fullLayout._size.w*(y.x[1]-y.x[0])),x=Math.floor(t._fullLayout._size.h*(y.y[1]-y.y[0])),_=e.header.values.length?g[0].map((function(){return e.header.height})):[n.emptyHeaderHeight],b=r.length?r[0].map((function(){return e.cells.height})):[],w=_.reduce(c,0),T=d(b,x-w+n.uplift),k=p(d(_,w),[]),A=p(T,k),M={},S=e._fullInput.columnorder;s(S)&&(S=Array.from(S)),S=S.concat(o(r.map((function(t,e){return e}))));var E=g.map((function(t,r){var n=s(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1})),C=E.reduce(c,0);E=E.map((function(t){return t/C*v}));var L=Math.max(l(e.header.line.width),l(e.cells.line.width)),I={key:e.uid+t._context.staticPlot,translateX:y.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-y.y[1]),size:t._fullLayout._size,width:v,maxLineWidth:L,height:x,columnOrder:S,groupHeight:x,rowBlocks:A,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map((function(t){return t[0]})),gdColumnsOriginalOrder:g.map((function(t){return t[0]})),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map((function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+\"__\"+M[t],label:t,specIndex:e,xIndex:S[e],xScale:f,x:void 0,calcdata:void 0,columnWidth:E[e]}}))};return I.columns.forEach((function(t){t.calcdata=I,t.x=f(t)})),I}},49618:function(t,e,r){\"use strict\";var n=r(93049).extendFlat;e.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},e.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0;return[r,e?r+e.rows.length:0]}(t);return(t.values||[]).slice(e[0],e[1]).map((function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}}))}},23281:function(t,e,r){\"use strict\";var n=r(34809),i=r(92294),a=r(13792).N;t.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",o.font),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort((function(t,e){return t-e})),o=i.map((function(t){return a.indexOf(t)})),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",o.font),e._length=null}},51671:function(t,e,r){\"use strict\";t.exports={attributes:r(92294),supplyDefaults:r(23281),calc:r(87522),plot:r(84576),moduleType:\"trace\",name:\"table\",basePlotModule:r(82662),categories:[\"noOpacity\"],meta:{}}},84576:function(t,e,r){\"use strict\";var n=r(18426),i=r(45568),a=r(34809),o=a.numberFormat,s=r(71293),l=r(62203),c=r(30635),u=r(34809).raiseToTop,h=r(34809).strTranslate,f=r(34809).cancelTransition,p=r(21908),d=r(49618),m=r(78766);function g(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function y(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function v(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function x(t){return[].concat.apply([],t.map((function(t){return t}))).map((function(t){return t.__data__}))}function _(t,e,r){var a=t.selectAll(\".\"+n.cn.scrollbarKit).data(s.repeat,s.keyFun);a.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),a.each((function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return R(e,e.length-1)+(e.length?F(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-E(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom})).attr(\"transform\",(function(t){var e=t.width+n.scrollbarWidth/2+n.scrollbarOffset;return h(e,E(t))}));var o=a.selectAll(\".\"+n.cn.scrollbar).data(s.repeat,s.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=o.selectAll(\".\"+n.cn.scrollbarSlider).data(s.repeat,s.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",(function(t){return h(0,t.scrollbarState.topY||0)}));var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(s.repeat,s.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",(function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2})).attr(\"stroke-opacity\",(function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4})),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=o.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(s.repeat,s.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",(function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||L(e,t,null,l(s-o.barLength/2))(r)})).call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t})).on(\"drag\",L(e,t)).on(\"dragend\",(function(){}))),u.attr(\"y2\",(function(t){return t.scrollbarState.scrollableAreaHeight})),e._context.staticPlot&&(c.remove(),u.remove())}function b(t,e,r,a){var o=function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(s.repeat,s.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r),c=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(d.splitToCells,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(o);!function(t){t.each((function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:k(r.size,n,e),color:k(r.color,n,e),family:k(r.family,n,e),weight:k(r.weight,n,e),style:k(r.style,n,e),variant:k(r.variant,n,e),textcase:k(r.textcase,n,e),lineposition:k(r.lineposition,n,e),shadow:k(r.shadow,n,e)};t.rowNumber=t.key,t.align=k(t.calcdata.cells.align,n,e),t.cellBorderWidth=k(t.calcdata.cells.line.width,n,e),t.font=i}))}(c);var u=function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(s.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(c);!function(t){t.attr(\"width\",(function(t){return t.column.columnWidth})).attr(\"stroke-width\",(function(t){return t.cellBorderWidth})).each((function(t){var e=i.select(this);m.stroke(e,k(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),m.fill(e,k(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))}))}(u);var h=function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(s.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(c),f=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(s.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",(function(){return\"auto\"})).on(\"mousedown\",(function(){i.event.stopPropagation()})),e}(h);!function(t){t.each((function(t){l.font(i.select(this),t.font)}))}(f),w(f,e,a,t),D(c)}function w(t,e,r,a){t.text((function(t){var e=t.column.specIndex,r=t.rowNumber,i=t.value,a=\"string\"==typeof i,s=a&&i.match(/<br>/i),l=!a||s;t.mayHaveMarkup=a&&i.match(/[<&>]/);var c,u=\"string\"==typeof(c=i)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":k(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":k(t.calcdata.cells.suffix,e,r)||\"\",m=u?null:k(t.calcdata.cells.format,e,r)||null,g=p+(m?o(m)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=T(g)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?T(g):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var y=(\" \"===n.wrapSplitCharacter?g.replace(/<a href=/gi,\"<a_href=\"):g).split(n.wrapSplitCharacter),v=\" \"===n.wrapSplitCharacter?y.map((function(t){return t.replace(/<a_href=/gi,\"<a href=\")})):y;t.fragments=v.map((function(t){return{text:t,width:null}})),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=v.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=g;return f})).attr(\"dy\",(function(t){return t.needsConvertToTspans?0:\"0.75em\"})).each((function(t){var o=this,s=i.select(o),l=t.wrappingNeeded?P:z;t.needsConvertToTspans?c.convertToTspans(s,a,l(r,o,e,a,t)):i.select(o.parentNode).attr(\"transform\",(function(t){return h(O(t),n.cellPad)})).attr(\"text-anchor\",(function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]}))}))}function T(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function k(t,e,r){if(a.isArrayOrTypedArray(t)){var n=t[Math.min(e,t.length-1)];return a.isArrayOrTypedArray(n)?n[Math.min(r,n.length-1)]:n}return t}function A(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",h(e.x,r))}function M(t){return\"cells\"===t.type}function S(t){return\"header\"===t.type}function E(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce((function(t,e){return t+F(e,1/0)}),0)}function C(t,e,r){var n=x(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=R(i,i.length),s=n.calcdata.groupHeight-E(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each((function(t,e){t.page=c[e],t.scrollY=l})),e.attr(\"transform\",(function(t){var e=R(t.rowBlocks,t.page)-t.scrollY;return h(0,e)})),t&&(I(t,r,e,c,n.prevPages,n,0),I(t,r,e,c,n.prevPages,n,1),_(r,t))}}function L(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter((function(t){return s.key===t.key})),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(M);return C(t,h,l),s.scrollY===u}}function I(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout((function(){var a=r.filter((function(t,e){return e===o&&n[e]!==i[e]}));b(t,e,a,r),i[o]=n[o]})))}function P(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each((function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each((function(t,r){e[r].width=this.getComputedTextLength()}));var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0})),o.selectAll(\"tspan.line\").remove(),w(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(D)}}function z(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=N(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,f=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,p=Math.max(f,u);p-l.rows[c].rowHeight&&(l.rows[c].rowHeight=p,t.selectAll(\".\"+n.cn.columnCell).call(D),C(null,t.filter(M),0),_(r,a,!0)),s.attr(\"transform\",(function(){var t=this,e=t.parentNode.getBoundingClientRect(),r=i.select(t.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),a=t.transform.baseVal.consolidate(),s=r.top-e.top+(a?a.matrix.f:n.cellPad);return h(O(o,i.select(t.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width),s)})),o.settledY=!0}}}function O(t,e){switch(t.align){case\"left\":default:return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2}}function D(t){t.attr(\"transform\",(function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce((function(t,e){return t+F(e,1/0)}),0),r=F(N(t),t.key);return h(0,r+e)})).selectAll(\".\"+n.cn.cellRect).attr(\"height\",(function(t){return(e=N(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r}))}function R(t,e){for(var r=0,n=e-1;n>=0;n--)r+=B(t[n]);return r}function F(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function B(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function N(t){return t.rowBlocks[t.page]}t.exports=function(t,e){var r=!t._context.staticPlot,a=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map((function(e){var r=s.unwrap(e).trace;return p(t,r)})),s.keyFun);a.exit().remove(),a.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),a.attr(\"width\",(function(t){return t.width+t.size.l+t.size.r})).attr(\"height\",(function(t){return t.height+t.size.t+t.size.b})).attr(\"transform\",(function(t){return h(t.translateX,t.translateY)}));var o=a.selectAll(\".\"+n.cn.tableControlView).data(s.repeat,s.keyFun),c=o.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");if(r){var m=\"onwheel\"in document?\"wheel\":\"mousewheel\";c.on(\"mousemove\",(function(e){o.filter((function(t){return e===t})).call(_,t)})).on(m,(function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;L(t,o,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}})).call(_,t,!0)}o.attr(\"transform\",(function(t){return h(t.size.l,t.size.t)}));var w=o.selectAll(\".\"+n.cn.scrollBackground).data(s.repeat,s.keyFun);w.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),w.attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),o.each((function(e){l.setClipUrl(i.select(this),y(t,e),t)}));var T=o.selectAll(\".\"+n.cn.yColumn).data((function(t){return t.columns}),s.keyFun);T.enter().append(\"g\").classed(n.cn.yColumn,!0),T.exit().remove(),T.attr(\"transform\",(function(t){return h(t.x,0)})),r&&T.call(i.behavior.drag().origin((function(e){return A(i.select(this),e,-n.uplift),u(this),e.calcdata.columnDragInProgress=!0,_(o.filter((function(t){return e.calcdata.key===t.key})),t),e})).on(\"drag\",(function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),x(T).filter((function(e){return e.calcdata.key===t.calcdata.key})).sort((function(t,e){return r(t)-r(e)})).forEach((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)})),T.filter((function(e){return t!==e})).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",(function(t){return h(t.x,0)})),e.call(f).attr(\"transform\",h(t.x,-n.uplift))})).on(\"dragend\",(function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,A(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort((function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]})),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map((function(t){return t.xIndex})))}))),T.each((function(e){l.setClipUrl(i.select(this),v(t,e),t)}));var k=T.selectAll(\".\"+n.cn.columnBlock).data(d.splitToPanels,s.keyFun);k.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",(function(t){return t.key})),k.style(\"cursor\",(function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"}));var E=k.filter(S),I=k.filter(M);r&&I.call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t})).on(\"drag\",L(t,o,-1)).on(\"dragend\",(function(){}))),b(t,o,E,k),b(t,o,I,k);var P=o.selectAll(\".\"+n.cn.scrollAreaClip).data(s.repeat,s.keyFun);P.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",(function(e){return y(t,e)}));var z=P.selectAll(\".\"+n.cn.scrollAreaClipRect).data(s.repeat,s.keyFun);z.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),z.attr(\"width\",(function(t){return t.width+2*n.overdrag})).attr(\"height\",(function(t){return t.height+n.uplift})),T.selectAll(\".\"+n.cn.columnBoundary).data(s.repeat,s.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=T.selectAll(\".\"+n.cn.columnBoundaryClippath).data(s.repeat,s.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",(function(e){return v(t,e)}));var D=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(s.repeat,s.keyFun);D.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),D.attr(\"width\",(function(t){return t.columnWidth+2*g(t)})).attr(\"height\",(function(t){return t.calcdata.height+2*g(t)+n.uplift})).attr(\"x\",(function(t){return-g(t)})).attr(\"y\",(function(t){return-g(t)})),C(null,I,o)}},71856:function(t,e,r){\"use strict\";var n=r(3208).rb,i=r(3208).ay,a=r(87163),o=r(13792).u,s=r(55412),l=r(56708),c=r(43236),u=r(93049).extendFlat,h=r(94850).k;t.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:\"enumerated\",values:[\"squarify\",\"binary\",\"dice\",\"slice\",\"slice-dice\",\"dice-slice\"],dflt:\"squarify\",editType:\"plot\"},squarifyratio:{valType:\"number\",min:1,dflt:1,editType:\"plot\"},flip:{valType:\"flaglist\",flags:[\"x\",\"y\"],dflt:\"\",editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:3,editType:\"plot\"},editType:\"calc\"},marker:u({pad:{t:{valType:\"number\",min:0,editType:\"plot\"},l:{valType:\"number\",min:0,editType:\"plot\"},r:{valType:\"number\",min:0,editType:\"plot\"},b:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\"},colors:l.marker.colors,pattern:h,depthfade:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],editType:\"style\"},line:l.marker.line,cornerradius:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),pathbar:{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},edgeshape:{valType:\"enumerated\",values:[\">\",\"<\",\"|\",\"/\",\"\\\\\"],dflt:\">\",editType:\"plot\"},thickness:{valType:\"number\",min:12,editType:\"plot\"},textfont:u({},s.textfont,{}),editType:\"calc\"},text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"top left\",editType:\"plot\"},sort:s.sort,root:l.root,domain:o({name:\"treemap\",trace:!0,editType:\"calc\"})}},69784:function(t,e,r){\"use strict\";var n=r(44122);e.name=\"treemap\",e.plot=function(t,r,i,a){n.plotBasePlot(e.name,t,r,i,a)},e.clean=function(t,r,i,a){n.cleanBasePlot(e.name,t,r,i,a)}},38848:function(t,e,r){\"use strict\";var n=r(14852);e._=function(t,e){return n.calc(t,e)},e.t=function(t){return n._runCrossTraceCalc(\"treemap\",t)}},43236:function(t){\"use strict\";t.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"poly\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"],gapWithPathbar:1}},95719:function(t,e,r){\"use strict\";var n=r(34809),i=r(71856),a=r(78766),o=r(13792).N,s=r(17550).handleText,l=r(56155).TEXTPAD,c=r(46979).handleMarkerDefaults,u=r(88856),h=u.hasColorscale,f=u.handleDefaults;t.exports=function(t,e,r,u){function p(r,a){return n.coerce(t,e,i,r,a)}var d=p(\"labels\"),m=p(\"parents\");if(d&&d.length&&m&&m.length){var g=p(\"values\");g&&g.length?p(\"branchvalues\"):p(\"count\"),p(\"level\"),p(\"maxdepth\"),\"squarify\"===p(\"tiling.packing\")&&p(\"tiling.squarifyratio\"),p(\"tiling.flip\"),p(\"tiling.pad\");var y=p(\"text\");p(\"texttemplate\"),e.texttemplate||p(\"textinfo\",n.isArrayOrTypedArray(y)?\"text+label\":\"label\"),p(\"hovertext\"),p(\"hovertemplate\");var v=p(\"pathbar.visible\");s(t,e,u,p,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),p(\"textposition\");var x=-1!==e.textposition.indexOf(\"bottom\");c(t,e,u,p),(e._hasColorscale=h(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis)?f(t,e,u,p,{prefix:\"marker.\",cLetter:\"c\"}):p(\"marker.depthfade\",!(e.marker.colors||[]).length);var _=2*e.textfont.size;p(\"marker.pad.t\",x?_/4:_),p(\"marker.pad.l\",_/4),p(\"marker.pad.r\",_/4),p(\"marker.pad.b\",x?_:_/4),p(\"marker.cornerradius\"),e._hovered={marker:{line:{width:2,color:a.contrast(u.paper_bgcolor)}}},v&&(p(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),p(\"pathbar.side\"),p(\"pathbar.edgeshape\")),p(\"sort\"),p(\"root.color\"),o(e,u,p),e._length=null}else e.visible=!1}},41567:function(t,e,r){\"use strict\";var n=r(45568),i=r(33108),a=r(84102).clearMinTextSize,o=r(6851).resizeText,s=r(95709);t.exports=function(t,e,r,l,c){var u,h,f=c.type,p=c.drawDescendants,d=t._fullLayout,m=d[\"_\"+f+\"layer\"],g=!r;a(f,d),(u=m.selectAll(\"g.trace.\"+f).data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(f,!0),u.order(),!d.uniformtext.mode&&i.hasTransition(r)?(l&&(h=l()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){h&&h()})).each(\"interrupt\",(function(){h&&h()})).each((function(){m.selectAll(\"g.trace\").each((function(e){s(t,e,this,r,p)}))}))):(u.each((function(e){s(t,e,this,r,p)})),d.uniformtext.mode&&o(t,m.selectAll(\".trace\"),f)),g&&u.exit().remove()}},17010:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(30635),s=r(11995),l=r(92080).styleOne,c=r(43236),u=r(33108),h=r(44691),f=!0;t.exports=function(t,e,r,p,d){var m=d.barDifY,g=d.width,y=d.height,v=d.viewX,x=d.viewY,_=d.pathSlice,b=d.toMoveInsideSlice,w=d.strTransform,T=d.hasTransition,k=d.handleSlicesExit,A=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,S={},E=t._context.staticPlot,C=t._fullLayout,L=e[0],I=L.trace,P=L.hierarchy,z=g/I._entryDepth,O=u.listPath(r.data,\"id\"),D=s(P.copy(),[g,y],{packing:\"dice\",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(D=D.filter((function(t){var e=O.indexOf(t.data.id);return-1!==e&&(t.x0=z*e,t.x1=z*(e+1),t.y0=m,t.y1=m+y,t.onPathbar=!0,!0)}))).reverse(),(p=p.data(D,u.getPtId)).enter().append(\"g\").classed(\"pathbar\",!0),k(p,f,S,[g,y],_),p.order();var R=p;T&&(R=R.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})}))),R.each((function(s){s._x0=v(s.x0),s._x1=v(s.x1),s._y0=x(s.y0),s._y1=x(s.y1),s._hoverX=v(s.x1-Math.min(g,y)/2),s._hoverY=x(s.y1-y/2);var p=n.select(this),d=i.ensureSingle(p,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",E?\"none\":\"all\")}));T?d.transition().attrTween(\"d\",(function(t){var e=A(t,f,S,[g,y]);return function(t){return _(e(t))}})):d.attr(\"d\",_),p.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),d.call(l,s,I,t,{hovered:!1}),s._text=(u.getPtLabel(s)||\"\").split(\"<br>\").join(\" \")||\"\";var m=i.ensureSingle(p,\"g\",\"slicetext\"),k=i.ensureSingle(m,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),L=i.ensureUniformFontSize(t,u.determineTextFont(I,s,C.font,{onPathbar:!0}));k.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",\"start\").call(a.font,L).call(o.convertToTspans,t),s.textBB=a.bBox(k.node()),s.transform=b(s,{fontSize:L.size,onPathbar:!0}),s.transform.fontSize=L.size,T?k.transition().attrTween(\"transform\",(function(t){var e=M(t,f,S,[g,y]);return function(t){return w(e(t))}})):k.attr(\"transform\",w(s))}))}},50916:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(30635),s=r(11995),l=r(92080).styleOne,c=r(43236),u=r(33108),h=r(44691),f=r(19718).formatSliceLabel,p=!1;t.exports=function(t,e,r,d,m){var g=m.width,y=m.height,v=m.viewX,x=m.viewY,_=m.pathSlice,b=m.toMoveInsideSlice,w=m.strTransform,T=m.hasTransition,k=m.handleSlicesExit,A=m.makeUpdateSliceInterpolator,M=m.makeUpdateTextInterpolator,S=m.prevEntry,E=t._context.staticPlot,C=t._fullLayout,L=e[0].trace,I=-1!==L.textposition.indexOf(\"left\"),P=-1!==L.textposition.indexOf(\"right\"),z=-1!==L.textposition.indexOf(\"bottom\"),O=!z&&!L.marker.pad.t||z&&!L.marker.pad.b,D=s(r,[g,y],{packing:L.tiling.packing,squarifyratio:L.tiling.squarifyratio,flipX:L.tiling.flip.indexOf(\"x\")>-1,flipY:L.tiling.flip.indexOf(\"y\")>-1,pad:{inner:L.tiling.pad,top:L.marker.pad.t,left:L.marker.pad.l,right:L.marker.pad.r,bottom:L.marker.pad.b}}).descendants(),R=1/0,F=-1/0;D.forEach((function(t){var e=t.depth;e>=L._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(R=Math.min(R,e),F=Math.max(F,e))})),d=d.data(D,u.getPtId),L._maxVisibleLayers=isFinite(F)?F-R+1:0,d.enter().append(\"g\").classed(\"slice\",!0),k(d,p,{},[g,y],_),d.order();var B=null;if(T&&S){var N=u.getPtId(S);d.each((function(t){null===B&&u.getPtId(t)===N&&(B={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var j=function(){return B||{x0:0,x1:g,y0:0,y1:y}},U=d;return T&&(U=U.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),U.each((function(s){var d=u.isHeader(s,L);s._x0=v(s.x0),s._x1=v(s.x1),s._y0=x(s.y0),s._y1=x(s.y1),s._hoverX=v(s.x1-L.marker.pad.r),s._hoverY=x(z?s.y1-L.marker.pad.b/2:s.y0+L.marker.pad.t/2);var m=n.select(this),k=i.ensureSingle(m,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",E?\"none\":\"all\")}));T?k.transition().attrTween(\"d\",(function(t){var e=A(t,p,j(),[g,y]);return function(t){return _(e(t))}})):k.attr(\"d\",_),m.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),k.call(l,s,L,t,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=d?O?\"\":u.getPtLabel(s)||\"\":f(s,r,L,e,C)||\"\";var S=i.ensureSingle(m,\"g\",\"slicetext\"),D=i.ensureSingle(S,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),R=i.ensureUniformFontSize(t,u.determineTextFont(L,s,C.font)),F=s._text||\" \",B=d&&-1===F.indexOf(\"<br>\");D.text(F).classed(\"slicetext\",!0).attr(\"text-anchor\",P?\"end\":I||B?\"start\":\"middle\").call(a.font,R).call(o.convertToTspans,t),s.textBB=a.bBox(D.node()),s.transform=b(s,{fontSize:R.size,isHeader:d}),s.transform.fontSize=R.size,T?D.transition().attrTween(\"transform\",(function(t){var e=M(t,p,j(),[g,y]);return function(t){return w(e(t))}})):D.attr(\"transform\",w(s))})),B}},36141:function(t){\"use strict\";t.exports=function t(e,r,n){var i;n.swapXY&&(i=e.x0,e.x0=e.y0,e.y0=i,i=e.x1,e.x1=e.y1,e.y1=i),n.flipX&&(i=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-i),n.flipY&&(i=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-i);var a=e.children;if(a)for(var o=0;o<a.length;o++)t(a[o],r,n)}},47181:function(t,e,r){\"use strict\";t.exports={moduleType:\"trace\",name:\"treemap\",basePlotModule:r(69784),categories:[],animatable:!0,attributes:r(71856),layoutAttributes:r(4219),supplyDefaults:r(95719),supplyLayoutDefaults:r(49852),calc:r(38848)._,crossTraceCalc:r(38848).t,plot:r(64274),style:r(92080).style,colorbar:r(21146),meta:{}}},4219:function(t){\"use strict\";t.exports={treemapcolorway:{valType:\"colorlist\",editType:\"calc\"},extendtreemapcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},49852:function(t,e,r){\"use strict\";var n=r(34809),i=r(4219);t.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"treemapcolorway\",e.colorway),r(\"extendtreemapcolors\")}},11995:function(t,e,r){\"use strict\";var n=r(92264),i=r(36141);t.exports=function(t,e,r){var a,o=r.flipX,s=r.flipY,l=\"dice-slice\"===r.packing,c=r.pad[s?\"bottom\":\"top\"],u=r.pad[o?\"right\":\"left\"],h=r.pad[o?\"left\":\"right\"],f=r.pad[s?\"top\":\"bottom\"];l&&(a=u,u=c,c=a,a=h,h=f,f=a);var p=n.treemap().tile(function(t,e){switch(t){case\"squarify\":return n.treemapSquarify.ratio(e);case\"binary\":return n.treemapBinary;case\"dice\":return n.treemapDice;case\"slice\":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(u).paddingRight(h).paddingTop(c).paddingBottom(f).size(l?[e[1],e[0]]:e)(t);return(l||o||s)&&i(p,e,{swapXY:l,flipX:o,flipY:s}),p}},64274:function(t,e,r){\"use strict\";var n=r(41567),i=r(50916);t.exports=function(t,e,r,a){return n(t,e,r,a,{type:\"treemap\",drawDescendants:i})}},95709:function(t,e,r){\"use strict\";var n=r(45568),i=r(88640).GW,a=r(33108),o=r(34809),s=r(56155).TEXTPAD,l=r(32995).toMoveInsideBar,c=r(84102).recordMinTextSize,u=r(43236),h=r(17010);function f(t){return a.isHierarchyRoot(t)?\"\":a.getPtId(t)}t.exports=function(t,e,r,p,d){var m=t._fullLayout,g=e[0],y=g.trace,v=\"icicle\"===y.type,x=g.hierarchy,_=a.findEntryWithLevel(x,y.level),b=n.select(r),w=b.selectAll(\"g.pathbar\"),T=b.selectAll(\"g.slice\");if(!_)return w.remove(),void T.remove();var k=a.isHierarchyRoot(_),A=!m.uniformtext.mode&&a.hasTransition(p),M=a.getMaxDepth(y),S=m._size,E=y.domain,C=S.w*(E.x[1]-E.x[0]),L=S.h*(E.y[1]-E.y[0]),I=C,P=y.pathbar.thickness,z=y.marker.line.width+u.gapWithPathbar,O=y.pathbar.visible?y.pathbar.side.indexOf(\"bottom\")>-1?L+z:-(P+z):0,D={x0:I,x1:I,y0:O,y1:O+P},R=function(t,e,r){var n=y.tiling.pad,i=function(t){return t-n<=e.x0},a=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return t.x0===e.x0&&t.x1===e.x1&&t.y0===e.y0&&t.y1===e.y1?{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1}:{x0:i(t.x0-n)?0:a(t.x0-n)?r[0]:t.x0,x1:i(t.x1+n)?0:a(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},F=null,B={},N={},j=null,U=function(t,e){return e?B[f(t)]:N[f(t)]};g.hasMultipleRoots&&k&&M++,y._maxDepth=M,y._backgroundColor=m.paper_bgcolor,y._entryDepth=_.data.depth,y._atRootLevel=k;var V=-C/2+S.l+S.w*(E.x[1]+E.x[0])/2,q=-L/2+S.t+S.h*(1-(E.y[1]+E.y[0])/2),H=function(t){return V+t},G=function(t){return q+t},Z=G(0),W=H(0),Y=function(t){return W+t},X=function(t){return Z+t};function $(t,e){return t+\",\"+e}var J=Y(0),K=function(t){t.x=Math.max(J,t.x)},Q=y.pathbar.edgeshape,tt=y[v?\"tiling\":\"marker\"].pad,et=function(t){return-1!==y.textposition.indexOf(t)},rt=et(\"top\"),nt=et(\"left\"),it=et(\"right\"),at=et(\"bottom\"),ot=function(t,e){var r=t.x0,n=t.x1,i=t.y0,a=t.y1,o=t.textBB,u=rt||e.isHeader&&!at?\"start\":at?\"end\":\"middle\",h=et(\"right\"),f=et(\"left\")||e.onPathbar?-1:h?1:0;if(e.isHeader){if((r+=(v?tt:tt.l)-s)>=(n-=(v?tt:tt.r)-s)){var p=(r+n)/2;r=p,n=p}var d;at?i<(d=a-(v?tt:tt.b))&&d<a&&(i=d):i<(d=i+(v?tt:tt.t))&&d<a&&(a=d)}var g=l(r,n,i,a,o,{isHorizontal:!1,constrained:!0,angle:0,anchor:u,leftToRight:f});return g.fontSize=e.fontSize,g.targetX=H(g.targetX),g.targetY=G(g.targetY),isNaN(g.targetX)||isNaN(g.targetY)?{}:(r!==n&&i!==a&&c(y.type,g,m),{scale:g.scale,rotate:g.rotate,textX:g.textX,textY:g.textY,anchorX:g.anchorX,anchorY:g.anchorY,targetX:g.targetX,targetY:g.targetY})},st=function(t,e){for(var r,n=0,i=t;!r&&n<M;)n++,(i=i.parent)?r=U(i,e):n=M;return r||{}},lt=function(t,e,r,n,a){var s,l=U(t,e);if(l)s=l;else if(e)s=D;else if(F)if(t.parent){var c=j||r;c&&!e?s=R(t,c,n):(s={},o.extendFlat(s,st(t,e)))}else s=o.extendFlat({},t),v&&(\"h\"===a.orientation?a.flipX?s.x0=t.x1:s.x1=0:a.flipY?s.y0=t.y1:s.y1=0);else s={};return i(s,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},ct=function(t,e,r,n){var s=U(t,e),l={},u=function(t,e,r,n){if(e)return B[f(x)]||D;var i=N[y.level]||r;return function(t){return t.data.depth-_.data.depth<M}(t)?R(t,i,n):{}}(t,e,r,n);o.extendFlat(l,{transform:ot({x0:u.x0,x1:u.x1,y0:u.y0,y1:u.y1,textBB:t.textBB,_text:t._text},{isHeader:a.isHeader(t,y)})}),s?l=s:t.parent&&o.extendFlat(l,st(t,e));var h=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(y.type,h,m),i(l,{transform:{scale:h.scale,rotate:h.rotate,textX:h.textX,textY:h.textY,anchorX:h.anchorX,anchorY:h.anchorY,targetX:h.targetX,targetY:h.targetY}})},ut=function(t,e,r,a,o){var s=a[0],l=a[1];A?t.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var r=function(t,e,r,n){var a,o=U(t,e);if(e)a=D;else{var s=U(_,e);a=s?R(t,s,n):{}}return i(o,a)}(t,e,0,[s,l]);return function(t){return o(r(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():t.exit().remove()},ht=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(y.type,e,m),o.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};A&&(w.each((function(t){B[f(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(B[f(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})})),T.each((function(t){N[f(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(N[f(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!F&&a.isEntry(t)&&(F=t)}))),j=d(t,e,_,T,{width:C,height:L,viewX:H,viewY:G,pathSlice:function(t){var e=H(t.x0),r=H(t.x1),n=G(t.y0),i=G(t.y1),a=r-e,o=i-n;if(!a||!o)return\"\";var s=y.marker.cornerradius||0,l=Math.min(s,a/2,o/2);l&&t.data&&t.data.data&&t.data.data.label&&(rt&&(l=Math.min(l,tt.t)),nt&&(l=Math.min(l,tt.l)),it&&(l=Math.min(l,tt.r)),at&&(l=Math.min(l,tt.b)));var c=function(t,e){return l?\"a\"+$(l,l)+\" 0 0 1 \"+$(t,e):\"\"};return\"M\"+$(e,n+l)+c(l,-l)+\"L\"+$(r-l,n)+c(l,l)+\"L\"+$(r,i-l)+c(-l,l)+\"L\"+$(e+l,i)+c(-l,-l)+\"Z\"},toMoveInsideSlice:ot,prevEntry:F,makeUpdateSliceInterpolator:lt,makeUpdateTextInterpolator:ct,handleSlicesExit:ut,hasTransition:A,strTransform:ht}),y.pathbar.visible?h(t,e,_,w,{barDifY:O,width:I,height:P,viewX:Y,viewY:X,pathSlice:function(t){var e=Y(Math.max(Math.min(t.x0,t.x0),0)),r=Y(Math.min(Math.max(t.x1,t.x1),I)),n=X(t.y0),i=X(t.y1),a=P/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+i)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:i},h={x:e,y:i};return\">\"===Q?(l.x-=a,c.x-=a,u.x-=a,h.x-=a):\"/\"===Q?(u.x-=a,h.x-=a,o.x-=a/2,s.x-=a/2):\"\\\\\"===Q?(l.x-=a,c.x-=a,o.x-=a/2,s.x-=a/2):\"<\"===Q&&(o.x-=a,s.x-=a),K(l),K(h),K(o),K(c),K(u),K(s),\"M\"+$(l.x,l.y)+\"L\"+$(c.x,c.y)+\"L\"+$(s.x,s.y)+\"L\"+$(u.x,u.y)+\"L\"+$(h.x,h.y)+\"L\"+$(o.x,o.y)+\"Z\"},toMoveInsideSlice:ot,makeUpdateSliceInterpolator:lt,makeUpdateTextInterpolator:ct,handleSlicesExit:ut,hasTransition:A,strTransform:ht}):w.remove()}},92080:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(34809),o=r(33108),s=r(84102).resizeText,l=r(72043);function c(t,e,r,n,s){var c,u,h=(s||{}).hovered,f=e.data.data,p=f.i,d=f.color,m=o.isHierarchyRoot(e),g=1;if(h)c=r._hovered.marker.line.color,u=r._hovered.marker.line.width;else if(m&&d===r.root.color)g=100,c=\"rgba(0,0,0,0)\",u=0;else if(c=a.castOption(r,p,\"marker.line.color\")||i.defaultLine,u=a.castOption(r,p,\"marker.line.width\")||0,!r._hasColorscale&&!e.onPathbar){var y=r.marker.depthfade;if(y){var v,x=i.combine(i.addOpacity(r._backgroundColor,.75),d);if(!0===y){var _=o.getMaxDepth(r);v=isFinite(_)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else v=e.data.depth-r._entryDepth,r._atRootLevel||v++;if(v>0)for(var b=0;b<v;b++){var w=.5*b/v;d=i.combine(i.addOpacity(x,w),d)}}}t.call(l,e,r,n,d).style(\"stroke-width\",u).call(i.stroke,c).style(\"opacity\",g)}t.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(\".trace\");s(t,e,\"treemap\"),e.each((function(e){var r=n.select(this),i=e[0].trace;r.style(\"opacity\",i.opacity),r.selectAll(\"path.surface\").each((function(e){n.select(this).call(c,e,i,t,{hovered:!1})}))}))},styleOne:c}},14711:function(t,e,r){\"use strict\";var n=r(64625),i=r(93049).extendFlat,a=r(80712).axisHoverFormat;t.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,quartilemethod:n.quartilemethod,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"},zorder:n.zorder}},88759:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(89429),o=r(37881),s=r(63821).BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}t.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,m=0;m<r.length;m++){var g=r[m],y=g.pts.map(o.extractVal),v=g.bandwidth=l(e,g,y),x=g.span=c(e,g,u,v);if(g.min===g.max&&0===v)x=g.span=[g.min,g.max],g.density=[{v:1,t:x[0]}],g.bandwidth=v,p=Math.max(p,1);else{var _=x[1]-x[0],b=Math.ceil(_/(v/3)),w=_/b;if(!isFinite(w)||!isFinite(b))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var T=o.makeKDE(g,e,y);g.density=new Array(b);for(var k=0,A=x[0];A<x[1]+w/2;k++,A+=w){var M=T(A);g.density[k]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,y.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},67316:function(t,e,r){\"use strict\";var n=r(81606).setPositionOffset,i=[\"v\",\"h\"];t.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},10864:function(t,e,r){\"use strict\";var n=r(34809),i=r(78766),a=r(62294),o=r(14711);t.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var m=c(\"box.width\"),g=c(\"box.fillcolor\",d),y=c(\"box.line.color\",f),v=c(\"box.line.width\",p);l(\"box.visible\",Boolean(m||g||y||v))||(e.box={visible:!1});var x=c(\"meanline.color\",f),_=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||_))||(e.meanline={visible:!1}),l(\"quartilemethod\"),l(\"zorder\")}}},37881:function(t,e,r){\"use strict\";var n=r(34809),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};e.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},e.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},e.getKdeValue=function(t,r,n){var i=t.pts.map(e.extractVal);return e.makeKDE(t,r,i)(n)/t.posDensityScale},e.extractVal=function(t){return t.v}},16842:function(t,e,r){\"use strict\";var n=r(78766),i=r(34809),a=r(29714),o=r(11448),s=r(37881);t.exports=function(t,e,r,l,c){c||(c={});var u,h,f=c.hoverLayer,p=t.cd,d=p[0].trace,m=d.hoveron,g=-1!==m.indexOf(\"violins\"),y=-1!==m.indexOf(\"kde\"),v=[];if(g||y){var x=o.hoverOnBoxes(t,e,r,l);if(y&&x.length>0){var _,b,w,T,k,A=t.xa,M=t.ya;\"h\"===d.orientation?(k=e,_=\"y\",w=M,b=\"x\",T=A):(k=r,_=\"x\",w=A,b=\"y\",T=M);var S=p[t.index];if(k>=S.span[0]&&k<=S.span[1]){var E=i.extendFlat({},t),C=T.c2p(k,!0),L=s.getKdeValue(S,d,k),I=s.getPositionOnKdePath(S,d,C),P=w._offset,z=w._length;E[_+\"0\"]=I[0],E[_+\"1\"]=I[1],E[b+\"0\"]=E[b+\"1\"]=C,E[b+\"Label\"]=b+\": \"+a.hoverLabelText(T,k,d[b+\"hoverformat\"])+\", \"+p[0].t.labels.kde+\" \"+L.toFixed(3);for(var O=0,D=0;D<x.length;D++)if(\"med\"===x[D].attr){O=D;break}E.spikeDistance=x[O].spikeDistance;var R=_+\"Spike\";E[R]=x[O][R],x[O].spikeDistance=void 0,x[O][R]=void 0,E.hovertemplate=!1,v.push(E),(h={})[_+\"1\"]=i.constrain(P+I[0],P,P+z),h[_+\"2\"]=i.constrain(P+I[1],P,P+z),h[b+\"1\"]=h[b+\"2\"]=T._offset+C}}g&&(v=v.concat(x))}-1!==m.indexOf(\"points\")&&(u=o.hoverOnPoints(t,e,r));var F=f.selectAll(\".violinline-\"+d.uid).data(h?[0]:[]);return F.enter().append(\"line\").classed(\"violinline-\"+d.uid,!0).attr(\"stroke-width\",1.5),F.exit().remove(),F.attr(h).call(n.stroke,t.color),\"closest\"===l?u?[u]:v:u?(v.push(u),v):v}},37276:function(t,e,r){\"use strict\";t.exports={attributes:r(14711),layoutAttributes:r(84734),supplyDefaults:r(10864),crossTraceDefaults:r(62294).crossTraceDefaults,supplyLayoutDefaults:r(55145),calc:r(88759),crossTraceCalc:r(67316),plot:r(36769),style:r(25117),styleOnSelect:r(9408).styleOnSelect,hoverPoints:r(16842),selectPoints:r(72488),moduleType:\"trace\",name:\"violin\",basePlotModule:r(37703),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},84734:function(t,e,r){\"use strict\";var n=r(64636),i=r(34809).extendFlat;t.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},55145:function(t,e,r){\"use strict\";var n=r(34809),i=r(84734),a=r(65067);t.exports=function(t,e,r){a._supply(t,e,r,(function(r,a){return n.coerce(t,e,i,r,a)}),\"violin\")}},36769:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(95419),s=r(5525),l=r(37881);t.exports=function(t,e,r,c){var u=t._context.staticPlot,h=t._fullLayout,f=e.xaxis,p=e.yaxis;function d(t,e){var r=s(t,{xaxis:f,yaxis:p,trace:e,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0,linearized:!0});return a.smoothopen(r[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each((function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var m=s.bPos,g=s.bdPos,y=e[s.valLetter+\"axis\"],v=e[s.posLetter+\"axis\"],x=\"both\"===c.side,_=x||\"positive\"===c.side,b=x||\"negative\"===c.side,w=r.selectAll(\"path.violin\").data(i.identity);w.enter().append(\"path\").style(\"vector-effect\",u?\"none\":\"non-scaling-stroke\").attr(\"class\",\"violin\"),w.exit().remove(),w.each((function(t){var e,r,i,a,o,l,u,f,p=n.select(this),w=t.density,T=w.length,k=v.c2l(t.pos+m,!0),A=v.l2p(k);if(c.width)e=s.maxKDE/g;else{var M=h._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(_){for(u=new Array(T),o=0;o<T;o++)(f=u[o]={})[s.posLetter]=k+w[o].v/e,f[s.valLetter]=y.c2l(w[o].t,!0);r=d(u,c)}if(b){for(u=new Array(T),l=0,o=T-1;l<T;l++,o--)(f=u[l]={})[s.posLetter]=k-w[o].v/e,f[s.valLetter]=y.c2l(w[o].t,!0);i=d(u,c)}if(x)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,y.c2p(w[0].t)],E=[A,y.c2p(w[T-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=_?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}p.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=p.node(),t.pathLength=t.path.getTotalLength()/(x?2:1)}));var T,k,A,M=c.box,S=M.width,E=(M.line||{}).width;x?(T=g*S,k=0):_?(T=[0,g*S/2],k=E*{x:1,y:-1}[s.posLetter]):(T=[g*S/2,0],k=E*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:v,val:y},c,{bPos:m,bdPos:T,bPosPxOffset:k}),o.plotBoxMean(r,{pos:v,val:y},c,{bPos:m,bdPos:T,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(A=i.identity);var C=r.selectAll(\"path.meanline\").data(A||[]);C.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",u?\"none\":\"non-scaling-stroke\"),C.exit().remove(),C.each((function(t){var e=y.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])})),o.plotPoints(r,{x:f,y:p},c,s)}}))}},25117:function(t,e,r){\"use strict\";var n=r(45568),i=r(78766),a=r(9408).stylePoints;t.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)}))}},51526:function(t,e,r){\"use strict\";var n=r(87163),i=r(70252),a=r(16131),o=r(9829),s=r(93049).extendFlat,l=r(13582).overrideAll,c=t.exports=l(s({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,xhoverformat:i.xhoverformat,yhoverformat:i.yhoverformat,zhoverformat:i.zhoverformat,valuehoverformat:i.valuehoverformat,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:a.opacityscale,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},96496:function(t,e,r){\"use strict\";var n=r(99098).gl_mesh3d,i=r(46998).parseColorScale,a=r(34809).isArrayOrTypedArray,o=r(55010),s=r(88856).extractOpts,l=r(88239),c=r(91370).findNearestOnAxis,u=r(91370).generateIsoMeshes;function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],o=this.data._Ys.length,s=this.data._Zs.length,l=c(r,this.data._Xs).id,u=c(n,this.data._Ys).id,h=c(i,this.data._Zs).id,f=t.index=h+s*u+s*o*l;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var p=this.data.hovertext||this.data.text;return a(p)&&void 0!==p[f]?t.textLabel=p[f]:p&&(t.textLabel=p),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=u(t);var a={positions:l(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:l(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);a.vertexIntensity=t._meshIntensity,a.vertexIntensityBounds=[c.min,c.max],a.colormap=i(t),this.mesh.update(a)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},t.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},22385:function(t,e,r){\"use strict\";var n=r(34809),i=r(51526),a=r(44731).supplyIsoDefaults,o=r(65444).opacityscaleDefaults;t.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,s,l),o(t,e,s,l)}},75703:function(t,e,r){\"use strict\";t.exports={attributes:r(51526),supplyDefaults:r(22385),calc:r(58988),colorbar:{min:\"cmin\",max:\"cmax\"},plot:r(96496),moduleType:\"trace\",name:\"volume\",basePlotModule:r(2487),categories:[\"gl3d\",\"showLegend\"],meta:{}}},37832:function(t,e,r){\"use strict\";var n=r(81481),i=r(36640).line,a=r(9829),o=r(80712).axisHoverFormat,s=r(3208).rb,l=r(3208).ay,c=r(82508),u=r(93049).extendFlat,h=r(78766);function f(t){return{marker:{color:u({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:u({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:u({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}t.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),hovertext:n.hovertext,hovertemplate:s({},{keys:c.eventDataKeys}),hoverinfo:u({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:l({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:f(),decreasing:f(),totals:f(),connector:{line:{color:u({},i.color,{dflt:h.defaultLine}),width:u({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,zorder:n.zorder}},15e3:function(t,e,r){\"use strict\";var n=r(29714),i=r(40528),a=r(34809).mergeArray,o=r(48861),s=r(63821).BADNUM;function l(t){return\"a\"===t||\"absolute\"===t}function c(t){return\"t\"===t||\"total\"===t}t.exports=function(t,e){var r,u,h,f,p,d,m=n.getFromId(t,e.xaxis||\"x\"),g=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=m.makeCalcdata(e,\"x\"),h=g.makeCalcdata(e,\"y\"),f=i(e,g,\"y\",h),p=!!e.yperiodalignment,d=\"y\"):(r=g.makeCalcdata(e,\"y\"),h=m.makeCalcdata(e,\"x\"),f=i(e,m,\"x\",h),p=!!e.xperiodalignment,d=\"x\"),u=f.vals;for(var y,v=Math.min(u.length,r.length),x=new Array(v),_=0,b=!1,w=0;w<v;w++){var T=r[w]||0,k=!1;(r[w]!==s||c(e.measure[w])||l(e.measure[w]))&&w+1<v&&(r[w+1]!==s||c(e.measure[w+1])||l(e.measure[w+1]))&&(k=!0);var A=x[w]={i:w,p:u[w],s:T,rawS:T,cNext:k};l(e.measure[w])?(_=A.s,A.isSum=!0,A.dir=\"totals\",A.s=_):c(e.measure[w])?(A.isSum=!0,A.dir=\"totals\",A.s=_):(A.isSum=!1,A.dir=A.rawS<0?\"decreasing\":\"increasing\",y=A.s,A.s=_+y,_+=y),\"totals\"===A.dir&&(b=!0),p&&(x[w].orig_p=h[w],x[w][d+\"End\"]=f.ends[w],x[w][d+\"Start\"]=f.starts[w]),e.ids&&(A.id=String(e.ids[w])),A.v=(e.base||0)+_}return x.length&&(x[0].hasTotals=b),a(e.text,x,\"tx\"),a(e.hovertext,x,\"htx\"),o(x,e),x}},82508:function(t){\"use strict\";t.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},9963:function(t,e,r){\"use strict\";var n=r(24782).setGroupPositions;t.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var m=0;m<r.length;m++){var g=r[m];!1===g.isSum&&(g.s0+=0===m?0:r[m-1].s),m+1<r.length&&(r[m].nextP0=r[m+1].p0,r[m].nextS0=r[m+1].s0)}}}},67199:function(t,e,r){\"use strict\";var n=r(34809),i=r(36301),a=r(17550).handleText,o=r(99867),s=r(99669),l=r(37832),c=r(78766),u=r(20909),h=u.INCREASING.COLOR,f=u.DECREASING.COLOR;function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",c.defaultLine),t(e+\".marker.line.width\")}t.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,c)){s(t,e,i,c),c(\"xhoverformat\"),c(\"yhoverformat\"),c(\"measure\"),c(\"orientation\",e.x&&!e.y?\"h\":\"v\"),c(\"base\"),c(\"offset\"),c(\"width\"),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var u=c(\"textposition\");a(t,e,i,c,u,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&(c(\"texttemplate\"),e.texttemplate||c(\"textinfo\")),p(c,\"increasing\",h),p(c,\"decreasing\",f),p(c,\"totals\",\"#4499FF\"),c(\"connector.visible\")&&(c(\"connector.mode\"),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\"))),c(\"zorder\")}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.waterfallmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},64932:function(t){\"use strict\";t.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},40943:function(t,e,r){\"use strict\";var n=r(29714).hoverLabelText,i=r(78766).opacity,a=r(91664).hoverOnBars,o=r(20909),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;t.exports=function(t,e,r,o,c){var u=a(t,e,r,o,c);if(u){var h=u.cd,f=h[0].trace,p=\"h\"===f.orientation,d=p?\"x\":\"y\",m=p?t.xa:t.ya,g=h[u.index],y=g.isSum?g.b+g.s:g.rawS;u.initial=g.b+g.s-y,u.delta=y,u.final=u.initial+u.delta;var v=k(Math.abs(u.delta));u.deltaLabel=y<0?\"(\"+v+\")\":v,u.finalLabel=k(u.final),u.initialLabel=k(u.initial);var x=g.hi||f.hoverinfo,_=[];if(x&&\"none\"!==x&&\"skip\"!==x){var b=\"all\"===x,w=x.split(\"+\"),T=function(t){return b||-1!==w.indexOf(t)};g.isSum||(!T(\"final\")||T(p?\"x\":\"y\")||_.push(u.finalLabel),T(\"delta\")&&(y<0?_.push(u.deltaLabel+\" \"+l):_.push(u.deltaLabel+\" \"+s)),T(\"initial\")&&_.push(\"Initial: \"+u.initialLabel))}return _.length&&(u.extraText=_.join(\"<br>\")),u.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;return i(n)?n:i(a)&&o?a:void 0}(f,g),[u]}function k(t){return n(m,t,f[d+\"hoverformat\"])}}},38261:function(t,e,r){\"use strict\";t.exports={attributes:r(37832),layoutAttributes:r(579),supplyDefaults:r(67199).supplyDefaults,crossTraceDefaults:r(67199).crossTraceDefaults,supplyLayoutDefaults:r(71492),calc:r(15e3),crossTraceCalc:r(9963),plot:r(71130),style:r(57256).style,hoverPoints:r(40943),eventData:r(64932),selectPoints:r(88384),moduleType:\"trace\",name:\"waterfall\",basePlotModule:r(37703),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},579:function(t){\"use strict\";t.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},71492:function(t,e,r){\"use strict\";var n=r(34809),i=r(579);t.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},71130:function(t,e,r){\"use strict\";var n=r(45568),i=r(34809),a=r(62203),o=r(63821).BADNUM,s=r(32995),l=r(84102).clearMinTextSize;t.exports=function(t,e,r,c){var u=t._fullLayout;l(\"waterfall\",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),u=r[0].trace,h=i.ensureSingle(s,\"g\",\"lines\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=u.connector.mode,d=h.selectAll(\"g.line\").data(i.identity);d.enter().append(\"g\").classed(\"line\",!0),d.exit().remove();var m=d.size();d.each((function(r,s){if(s===m-1||r.cNext){var u=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,l,c,f),h=u[0],d=u[1],g=\"\";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&(\"spanning\"===p&&!r.isSum&&s>0&&(g+=f?\"M\"+h[0]+\",\"+d[1]+\"V\"+d[0]:\"M\"+h[1]+\",\"+d[0]+\"H\"+h[0]),\"between\"!==p&&(r.isSum||s<m-1)&&(g+=f?\"M\"+h[1]+\",\"+d[0]+\"V\"+d[1]:\"M\"+h[0]+\",\"+d[1]+\"H\"+h[1]),h[2]!==o&&d[2]!==o&&(g+=f?\"M\"+h[1]+\",\"+d[1]+\"V\"+d[2]:\"M\"+h[1]+\",\"+d[1]+\"H\"+h[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,c)}},57256:function(t,e,r){\"use strict\";var n=r(45568),i=r(62203),a=r(78766),o=r(20438).DESELECTDIM,s=r(6851),l=r(84102).resizeText,c=s.styleTextPoints;t.exports={style:function(t,e,r){var s=r||n.select(t).selectAll('g[class^=\"waterfalllayer\"]').selectAll(\"g.trace\");l(t,s,\"waterfall\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},47908:function(t,e,r){\"use strict\";var n=r(29714),i=r(34809),a=r(57297),o=r(5086).z,s=r(63821).BADNUM;e.moduleType=\"transform\",e.name=\"aggregate\";var l=e.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case\"avg\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case\"min\":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case\"max\":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case\"range\":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case\"median\":return function(t,e){for(var r=[],o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&r.push(l)}if(!r.length)return s;r.sort(i.sorterAsc);var c=(r.length-1)/2;return a((r[Math.floor(c)]+r[Math.ceil(c)])/2)};case\"mode\":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case\"rms\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),m=0;m<r.length;m++)d[m]=u(c,r[m]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}e.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function m(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var g=m(\"target\"),y=m(\"func\");m(\"enabled\")&&g&&(u[g]||\"count\"===y&&void 0===u[g])?(\"stddev\"===y&&m(\"funcmode\"),u[g]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},e.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],m=o(e.transforms,r),g=a.length;for(e._length&&(g=Math.min(g,e._length)),s=0;s<g;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=m(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(m(s)));r._indexToPoints=p;var y=r.aggregations;for(s=0;s<y.length;s++)u(t,e,d,y[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},42849:function(t,e,r){\"use strict\";var n=r(34809),i=r(33626),a=r(29714),o=r(5086).z,s=r(20726),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;e.moduleType=\"transform\",e.name=\"filter\",e.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},e.supplyDefaults=function(t){var r={};function a(i,a){return n.coerce(t,r,e.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return r.enabled=!1,r;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,r,\"valuecalendar\",null),s(t,r,\"targetcalendar\",null)}return r},e.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var m=n.nestedProperty(e,s+\"calendar\").get();m&&(f=m)}var g,y,v=function(t,e,r){var i=t.operation,a=t.value,o=n.isArrayOrTypedArray(a);function s(t){return-1!==t.indexOf(i)}var h,f=function(r){return e(r,0,t.valuecalendar)},p=function(t){return e(t,0,r)};switch(s(l)?h=f(o?a[0]:a):s(c)?h=o?[f(a[0]),f(a[1])]:[f(a),f(a)]:s(u)&&(h=o?a.map(f):[f(a)]),i){case\"=\":return function(t){return p(t)===h};case\"!=\":return function(t){return p(t)!==h};case\"<\":return function(t){return p(t)<h};case\"<=\":return function(t){return p(t)<=h};case\">\":return function(t){return p(t)>h};case\">=\":return function(t){return p(t)>=h};case\"[]\":return function(t){var e=p(t);return e>=h[0]&&e<=h[1]};case\"()\":return function(t){var e=p(t);return e>h[0]&&e<h[1]};case\"[)\":return function(t){var e=p(t);return e>=h[0]&&e<h[1]};case\"(]\":return function(t){var e=p(t);return e>h[0]&&e<=h[1]};case\"][\":return function(t){var e=p(t);return e<=h[0]||e>=h[1]};case\")(\":return function(t){var e=p(t);return e<h[0]||e>h[1]};case\"](\":return function(t){var e=p(t);return e<=h[0]||e>h[1]};case\")[\":return function(t){var e=p(t);return e<h[0]||e>=h[1]};case\"{}\":return function(t){return-1!==h.indexOf(p(t))};case\"}{\":return function(t){return-1===h.indexOf(p(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},_={},b=0;d?(g=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},y=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(g=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},y=function(t,e){var r=x[t.astr][e];t.get().push(r)}),k(g);for(var w=o(e.transforms,r),T=0;T<h;T++)v(i[T])?(k(y,T),_[b++]=w(T)):d&&b++;r._indexToPoints=_,e._length=b}}function k(t,r){for(var i=0;i<p.length;i++)t(n.nestedProperty(e,p[i]),r)}}},50453:function(t,e,r){\"use strict\";var n=r(34809),i=r(57297),a=r(44122),o=r(5086).z;function s(t,e){var r,s,l,c,u,h,f,p,d,m,g=e.transform,y=e.transformIndex,v=t.transforms[y].groups,x=o(t.transforms,g);if(!n.isArrayOrTypedArray(v)||0===v.length)return[t];var _=n.filterUnique(v),b=new Array(_.length),w=v.length,T=i.findArrayAttributes(t),k=g.styles||[],A={};for(r=0;r<k.length;r++)A[k[r].target]=k[r].value;g.styles&&(m=n.keyedContainer(g,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<_.length;r++){M[h=_[r]]=r,S[h]=0,(f=b[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[y]._indexToPoints={};var E=null;for(m&&(E=m.get(h)),f.name=E||\"\"===E?E:n.templateString(g.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<T.length;s++)n.nestedProperty(f,T[s]).set([])}for(l=0;l<T.length;l++){for(c=T[l],s=0,d=[];s<_.length;s++)d[s]=n.nestedProperty(b[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[v[s]]].push(u[s])}for(s=0;s<w;s++)(f=b[M[v[s]]]).transforms[y]._indexToPoints[S[v[s]]]=x(s),S[v[s]]++;for(r=0;r<_.length;r++)h=_[r],f=b[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return b}e.moduleType=\"transform\",e.name=\"groupby\",e.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},e.supplyDefaults=function(t,r,i){var a,o={};function s(r,i){return n.coerce(t,o,e.attributes,r,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],e.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],e.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},e.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},5086:function(t,e){\"use strict\";e.z=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);var a=n?function(t){return n[t]}:function(t){return[t]};return a}},99855:function(t,e,r){\"use strict\";var n=r(34809),i=r(29714),a=r(5086).z,o=r(63821).BADNUM;e.moduleType=\"transform\",e.name=\"sort\",e.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},e.supplyDefaults=function(t){var r={};function i(i,a){return n.coerce(t,r,e.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),r},e.calcTransform=function(t,e,r){if(r.enabled){var s=n.getTargetArray(e,r);if(s){var l=r.target,c=s.length;e._length&&(c=Math.min(c,e._length));var u,h,f=e._arrayAttrs,p=function(t,e,r,n){var i,a=new Array(n),s=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:n-i};case\"descending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:i-n}}}(t,r)),i=0;i<n;i++)s[i]=a[i].i;return s}(r,s,i.getDataToCoordFunc(t,e,l,s),c),d=a(e.transforms,r),m={};for(u=0;u<f.length;u++){var g=n.nestedProperty(e,f[u]),y=g.get(),v=new Array(c);for(h=0;h<c;h++)v[h]=y[p[h]];g.set(v)}for(h=0;h<c;h++)m[h]=d(p[h]);r._indexToPoints=m,e._length=c}}}},29697:function(t,e){\"use strict\";e.version=\"2.35.2\"},99098:function(t,e,r){var n=r(45708).Buffer,i=r(33282);!function(){var e={1964:function(t,e,r){t.exports={alpha_shape:r(3502),convex_hull:r(7352),delaunay_triangulate:r(7642),gl_cone3d:r(6405),gl_error3d:r(9165),gl_heatmap2d:r(2510),gl_line3d:r(5714),gl_mesh3d:r(7201),gl_plot2d:r(1850),gl_plot3d:r(4100),gl_pointcloud2d:r(4696),gl_scatter3d:r(8418),gl_select_box:r(3161),gl_spikes2d:r(4098),gl_streamtube3d:r(7815),gl_surface3d:r(9499),ndarray:r(9618),ndarray_linear_interpolate:r(4317)}},4793:function(t,e,r){\"use strict\";function n(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(t,i(n.key),n)}}function i(t){var e=function(t,e){if(\"object\"!=l(t)||!t)return t;var r=t[Symbol.toPrimitive];if(void 0!==r){var n=r.call(t,\"string\");if(\"object\"!=l(n))return n;throw new TypeError(\"@@toPrimitive must return a primitive value.\")}return String(t)}(t);return\"symbol\"==l(e)?e:e+\"\"}function a(){try{var t=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){})))}catch(t){}return(a=function(){return!!t})()}function o(t){return o=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},o(t)}function s(t,e){return s=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(t,e){return t.__proto__=e,t},s(t,e)}function l(t){return l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},l(t)}var c=r(7507),u=r(3778),h=\"function\"==typeof Symbol&&\"function\"==typeof Symbol.for?Symbol.for(\"nodejs.util.inspect.custom\"):null;e.hp=d,e.IS=50;var f=2147483647;function p(t){if(t>f)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return Object.setPrototypeOf(e,d.prototype),e}function d(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return y(t)}return m(t,e,r)}function m(t,e,r){if(\"string\"==typeof t)return function(t,e){if(\"string\"==typeof e&&\"\"!==e||(e=\"utf8\"),!d.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|b(t,e),n=p(r),i=n.write(t,e);return i!==r&&(n=n.slice(0,i)),n}(t,e);if(ArrayBuffer.isView(t))return function(t){if(et(t,Uint8Array)){var e=new Uint8Array(t);return x(e.buffer,e.byteOffset,e.byteLength)}return v(t)}(t);if(null==t)throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+l(t));if(et(t,ArrayBuffer)||t&&et(t.buffer,ArrayBuffer))return x(t,e,r);if(\"undefined\"!=typeof SharedArrayBuffer&&(et(t,SharedArrayBuffer)||t&&et(t.buffer,SharedArrayBuffer)))return x(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return d.from(n,e,r);var i=function(t){if(d.isBuffer(t)){var e=0|_(t.length),r=p(e);return 0===r.length||t.copy(r,0,0,e),r}return void 0!==t.length?\"number\"!=typeof t.length||rt(t.length)?p(0):v(t):\"Buffer\"===t.type&&Array.isArray(t.data)?v(t.data):void 0}(t);if(i)return i;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return d.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+l(t))}function g(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function y(t){return g(t),p(t<0?0:0|_(t))}function v(t){for(var e=t.length<0?0:0|_(t.length),r=p(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function x(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;return n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r),Object.setPrototypeOf(n,d.prototype),n}function _(t){if(t>=f)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+f.toString(16)+\" bytes\");return 0|t}function b(t,e){if(d.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||et(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+l(t));var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return K(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return Q(t).length;default:if(i)return n?-1:K(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function w(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return R(this,e,r);case\"utf8\":case\"utf-8\":return P(this,e,r);case\"ascii\":return O(this,e,r);case\"latin1\":case\"binary\":return D(this,e,r);case\"base64\":return I(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return F(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function T(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function k(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),rt(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=d.from(e,n)),d.isBuffer(e))return 0===e.length?-1:A(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):A(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function A(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function M(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a,o=e.length;for(n>o/2&&(n=o/2),a=0;a<n;++a){var s=parseInt(e.substr(2*a,2),16);if(rt(s))return a;t[r+a]=s}return a}function S(t,e,r,n){return tt(K(e,t.length-r),t,r,n)}function E(t,e,r,n){return tt(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function C(t,e,r,n){return tt(Q(e),t,r,n)}function L(t,e,r,n){return tt(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)n=(r=t.charCodeAt(o))>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function I(t,e,r){return 0===e&&r===t.length?c.fromByteArray(t):c.fromByteArray(t.slice(e,r))}function P(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a=t[i],o=null,s=a>239?4:a>223?3:a>191?2:1;if(i+s<=r){var l=void 0,c=void 0,u=void 0,h=void 0;switch(s){case 1:a<128&&(o=a);break;case 2:128==(192&(l=t[i+1]))&&(h=(31&a)<<6|63&l)>127&&(o=h);break;case 3:l=t[i+1],c=t[i+2],128==(192&l)&&128==(192&c)&&(h=(15&a)<<12|(63&l)<<6|63&c)>2047&&(h<55296||h>57343)&&(o=h);break;case 4:l=t[i+1],c=t[i+2],u=t[i+3],128==(192&l)&&128==(192&c)&&128==(192&u)&&(h=(15&a)<<18|(63&l)<<12|(63&c)<<6|63&u)>65535&&h<1114112&&(o=h)}}null===o?(o=65533,s=1):o>65535&&(o-=65536,n.push(o>>>10&1023|55296),o=56320|1023&o),n.push(o),i+=s}return function(t){var e=t.length;if(e<=z)return String.fromCharCode.apply(String,t);for(var r=\"\",n=0;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=z));return r}(n)}d.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1),e={foo:function(){return 42}};return Object.setPrototypeOf(e,Uint8Array.prototype),Object.setPrototypeOf(t,e),42===t.foo()}catch(t){return!1}}(),d.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(d.prototype,\"parent\",{enumerable:!0,get:function(){if(d.isBuffer(this))return this.buffer}}),Object.defineProperty(d.prototype,\"offset\",{enumerable:!0,get:function(){if(d.isBuffer(this))return this.byteOffset}}),d.poolSize=8192,d.from=function(t,e,r){return m(t,e,r)},Object.setPrototypeOf(d.prototype,Uint8Array.prototype),Object.setPrototypeOf(d,Uint8Array),d.alloc=function(t,e,r){return function(t,e,r){return g(t),t<=0?p(t):void 0!==e?\"string\"==typeof r?p(t).fill(e,r):p(t).fill(e):p(t)}(t,e,r)},d.allocUnsafe=function(t){return y(t)},d.allocUnsafeSlow=function(t){return y(t)},d.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==d.prototype},d.compare=function(t,e){if(et(t,Uint8Array)&&(t=d.from(t,t.offset,t.byteLength)),et(e,Uint8Array)&&(e=d.from(e,e.offset,e.byteLength)),!d.isBuffer(t)||!d.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},d.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},d.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return d.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=d.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var a=t[r];if(et(a,Uint8Array))i+a.length>n.length?(d.isBuffer(a)||(a=d.from(a)),a.copy(n,i)):Uint8Array.prototype.set.call(n,a,i);else{if(!d.isBuffer(a))throw new TypeError('\"list\" argument must be an Array of Buffers');a.copy(n,i)}i+=a.length}return n},d.byteLength=b,d.prototype._isBuffer=!0,d.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)T(this,e,e+1);return this},d.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)T(this,e,e+3),T(this,e+1,e+2);return this},d.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)T(this,e,e+7),T(this,e+1,e+6),T(this,e+2,e+5),T(this,e+3,e+4);return this},d.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?P(this,0,t):w.apply(this,arguments)},d.prototype.toLocaleString=d.prototype.toString,d.prototype.equals=function(t){if(!d.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===d.compare(this,t)},d.prototype.inspect=function(){var t=\"\",r=e.IS;return t=this.toString(\"hex\",0,r).replace(/(.{2})/g,\"$1 \").trim(),this.length>r&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},h&&(d.prototype[h]=d.prototype.inspect),d.prototype.compare=function(t,e,r,n,i){if(et(t,Uint8Array)&&(t=d.from(t,t.offset,t.byteLength)),!d.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+l(t));if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var a=(i>>>=0)-(n>>>=0),o=(r>>>=0)-(e>>>=0),s=Math.min(a,o),c=this.slice(n,i),u=t.slice(e,r),h=0;h<s;++h)if(c[h]!==u[h]){a=c[h],o=u[h];break}return a<o?-1:o<a?1:0},d.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},d.prototype.indexOf=function(t,e,r){return k(this,t,e,r,!0)},d.prototype.lastIndexOf=function(t,e,r){return k(this,t,e,r,!1)},d.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return M(this,t,e,r);case\"utf8\":case\"utf-8\":return S(this,t,e,r);case\"ascii\":case\"latin1\":case\"binary\":return E(this,t,e,r);case\"base64\":return C(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return L(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},d.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var z=4096;function O(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function D(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function R(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=nt[t[a]];return i}function F(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length-1;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function B(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function N(t,e,r,n,i,a){if(!d.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<a)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function j(t,e,r,n,i){Y(e,n,i,t,r,7);var a=Number(e&BigInt(4294967295));t[r++]=a,a>>=8,t[r++]=a,a>>=8,t[r++]=a,a>>=8,t[r++]=a;var o=Number(e>>BigInt(32)&BigInt(4294967295));return t[r++]=o,o>>=8,t[r++]=o,o>>=8,t[r++]=o,o>>=8,t[r++]=o,r}function U(t,e,r,n,i){Y(e,n,i,t,r,7);var a=Number(e&BigInt(4294967295));t[r+7]=a,a>>=8,t[r+6]=a,a>>=8,t[r+5]=a,a>>=8,t[r+4]=a;var o=Number(e>>BigInt(32)&BigInt(4294967295));return t[r+3]=o,o>>=8,t[r+2]=o,o>>=8,t[r+1]=o,o>>=8,t[r]=o,r+8}function V(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function q(t,e,r,n,i){return e=+e,r>>>=0,i||V(t,0,r,4),u.write(t,e,r,n,23,4),r+4}function H(t,e,r,n,i){return e=+e,r>>>=0,i||V(t,0,r,8),u.write(t,e,r,n,52,8),r+8}d.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return Object.setPrototypeOf(n,d.prototype),n},d.prototype.readUintLE=d.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||B(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},d.prototype.readUintBE=d.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||B(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},d.prototype.readUint8=d.prototype.readUInt8=function(t,e){return t>>>=0,e||B(t,1,this.length),this[t]},d.prototype.readUint16LE=d.prototype.readUInt16LE=function(t,e){return t>>>=0,e||B(t,2,this.length),this[t]|this[t+1]<<8},d.prototype.readUint16BE=d.prototype.readUInt16BE=function(t,e){return t>>>=0,e||B(t,2,this.length),this[t]<<8|this[t+1]},d.prototype.readUint32LE=d.prototype.readUInt32LE=function(t,e){return t>>>=0,e||B(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},d.prototype.readUint32BE=d.prototype.readUInt32BE=function(t,e){return t>>>=0,e||B(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},d.prototype.readBigUInt64LE=it((function(t){X(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||$(t,this.length-8);var n=e+this[++t]*Math.pow(2,8)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,24),i=this[++t]+this[++t]*Math.pow(2,8)+this[++t]*Math.pow(2,16)+r*Math.pow(2,24);return BigInt(n)+(BigInt(i)<<BigInt(32))})),d.prototype.readBigUInt64BE=it((function(t){X(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||$(t,this.length-8);var n=e*Math.pow(2,24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+this[++t],i=this[++t]*Math.pow(2,24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+r;return(BigInt(n)<<BigInt(32))+BigInt(i)})),d.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||B(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},d.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||B(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},d.prototype.readInt8=function(t,e){return t>>>=0,e||B(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},d.prototype.readInt16LE=function(t,e){t>>>=0,e||B(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},d.prototype.readInt16BE=function(t,e){t>>>=0,e||B(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},d.prototype.readInt32LE=function(t,e){return t>>>=0,e||B(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},d.prototype.readInt32BE=function(t,e){return t>>>=0,e||B(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},d.prototype.readBigInt64LE=it((function(t){X(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||$(t,this.length-8);var n=this[t+4]+this[t+5]*Math.pow(2,8)+this[t+6]*Math.pow(2,16)+(r<<24);return(BigInt(n)<<BigInt(32))+BigInt(e+this[++t]*Math.pow(2,8)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,24))})),d.prototype.readBigInt64BE=it((function(t){X(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||$(t,this.length-8);var n=(e<<24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+this[++t];return(BigInt(n)<<BigInt(32))+BigInt(this[++t]*Math.pow(2,24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+r)})),d.prototype.readFloatLE=function(t,e){return t>>>=0,e||B(t,4,this.length),u.read(this,t,!0,23,4)},d.prototype.readFloatBE=function(t,e){return t>>>=0,e||B(t,4,this.length),u.read(this,t,!1,23,4)},d.prototype.readDoubleLE=function(t,e){return t>>>=0,e||B(t,8,this.length),u.read(this,t,!0,52,8)},d.prototype.readDoubleBE=function(t,e){return t>>>=0,e||B(t,8,this.length),u.read(this,t,!1,52,8)},d.prototype.writeUintLE=d.prototype.writeUIntLE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||N(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},d.prototype.writeUintBE=d.prototype.writeUIntBE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||N(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},d.prototype.writeUint8=d.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,1,255,0),this[e]=255&t,e+1},d.prototype.writeUint16LE=d.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},d.prototype.writeUint16BE=d.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},d.prototype.writeUint32LE=d.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},d.prototype.writeUint32BE=d.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},d.prototype.writeBigUInt64LE=it((function(t){return j(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,BigInt(0),BigInt(\"0xffffffffffffffff\"))})),d.prototype.writeBigUInt64BE=it((function(t){return U(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,BigInt(0),BigInt(\"0xffffffffffffffff\"))})),d.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);N(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},d.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);N(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},d.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},d.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},d.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},d.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},d.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||N(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},d.prototype.writeBigInt64LE=it((function(t){return j(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,-BigInt(\"0x8000000000000000\"),BigInt(\"0x7fffffffffffffff\"))})),d.prototype.writeBigInt64BE=it((function(t){return U(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,-BigInt(\"0x8000000000000000\"),BigInt(\"0x7fffffffffffffff\"))})),d.prototype.writeFloatLE=function(t,e,r){return q(this,t,e,!0,r)},d.prototype.writeFloatBE=function(t,e,r){return q(this,t,e,!1,r)},d.prototype.writeDoubleLE=function(t,e,r){return H(this,t,e,!0,r)},d.prototype.writeDoubleBE=function(t,e,r){return H(this,t,e,!1,r)},d.prototype.copy=function(t,e,r,n){if(!d.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;return this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin?this.copyWithin(e,r,n):Uint8Array.prototype.set.call(t,this.subarray(r,n),e),i},d.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!d.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t?t&=255:\"boolean\"==typeof t&&(t=Number(t));if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var a;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(a=e;a<r;++a)this[a]=t;else{var o=d.isBuffer(t)?t:d.from(t,n),s=o.length;if(0===s)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(a=0;a<r-e;++a)this[a+e]=o[a%s]}return this};var G={};function Z(t,e,r){G[t]=function(r){function i(){var r;return function(t,e){if(!(t instanceof e))throw new TypeError(\"Cannot call a class as a function\")}(this,i),r=function(t,e,r){return e=o(e),function(t,e){if(e&&(\"object\"==l(e)||\"function\"==typeof e))return e;if(void 0!==e)throw new TypeError(\"Derived constructors may only return object or undefined\");return function(t){if(void 0===t)throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\");return t}(t)}(t,a()?Reflect.construct(e,r||[],o(t).constructor):e.apply(t,r))}(this,i),Object.defineProperty(r,\"message\",{value:e.apply(r,arguments),writable:!0,configurable:!0}),r.name=\"\".concat(r.name,\" [\").concat(t,\"]\"),r.stack,delete r.name,r}return function(t,e){if(\"function\"!=typeof e&&null!==e)throw new TypeError(\"Super expression must either be null or a function\");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Object.defineProperty(t,\"prototype\",{writable:!1}),e&&s(t,e)}(i,r),c=i,(u=[{key:\"code\",get:function(){return t},set:function(t){Object.defineProperty(this,\"code\",{configurable:!0,enumerable:!0,value:t,writable:!0})}},{key:\"toString\",value:function(){return\"\".concat(this.name,\" [\").concat(t,\"]: \").concat(this.message)}}])&&n(c.prototype,u),Object.defineProperty(c,\"prototype\",{writable:!1}),c;var c,u}(r)}function W(t){for(var e=\"\",r=t.length,n=\"-\"===t[0]?1:0;r>=n+4;r-=3)e=\"_\".concat(t.slice(r-3,r)).concat(e);return\"\".concat(t.slice(0,r)).concat(e)}function Y(t,e,r,n,i,a){if(t>r||t<e){var o,s=\"bigint\"==typeof e?\"n\":\"\";throw o=a>3?0===e||e===BigInt(0)?\">= 0\".concat(s,\" and < 2\").concat(s,\" ** \").concat(8*(a+1)).concat(s):\">= -(2\".concat(s,\" ** \").concat(8*(a+1)-1).concat(s,\") and < 2 ** \")+\"\".concat(8*(a+1)-1).concat(s):\">= \".concat(e).concat(s,\" and <= \").concat(r).concat(s),new G.ERR_OUT_OF_RANGE(\"value\",o,t)}!function(t,e,r){X(e,\"offset\"),void 0!==t[e]&&void 0!==t[e+r]||$(e,t.length-(r+1))}(n,i,a)}function X(t,e){if(\"number\"!=typeof t)throw new G.ERR_INVALID_ARG_TYPE(e,\"number\",t)}function $(t,e,r){if(Math.floor(t)!==t)throw X(t,r),new G.ERR_OUT_OF_RANGE(r||\"offset\",\"an integer\",t);if(e<0)throw new G.ERR_BUFFER_OUT_OF_BOUNDS;throw new G.ERR_OUT_OF_RANGE(r||\"offset\",\">= \".concat(r?1:0,\" and <= \").concat(e),t)}Z(\"ERR_BUFFER_OUT_OF_BOUNDS\",(function(t){return t?\"\".concat(t,\" is outside of buffer bounds\"):\"Attempt to access memory outside buffer bounds\"}),RangeError),Z(\"ERR_INVALID_ARG_TYPE\",(function(t,e){return'The \"'.concat(t,'\" argument must be of type number. Received type ').concat(l(e))}),TypeError),Z(\"ERR_OUT_OF_RANGE\",(function(t,e,r){var n='The value of \"'.concat(t,'\" is out of range.'),i=r;return Number.isInteger(r)&&Math.abs(r)>Math.pow(2,32)?i=W(String(r)):\"bigint\"==typeof r&&(i=String(r),(r>Math.pow(BigInt(2),BigInt(32))||r<-Math.pow(BigInt(2),BigInt(32)))&&(i=W(i)),i+=\"n\"),n+\" It must be \".concat(e,\". Received \").concat(i)}),RangeError);var J=/[^+/0-9A-Za-z-_]/g;function K(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function Q(t){return c.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(J,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function tt(t,e,r,n){var i;for(i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function et(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function rt(t){return t!=t}var nt=function(){for(var t=\"0123456789abcdef\",e=new Array(256),r=0;r<16;++r)for(var n=16*r,i=0;i<16;++i)e[n+i]=t[r]+t[i];return e}();function it(t){return\"undefined\"==typeof BigInt?at:t}function at(){throw new Error(\"BigInt not supported\")}},9216:function(t){\"use strict\";t.exports=i,t.exports.isMobile=i,t.exports.default=i;var e=/(android|bb\\d+|meego).+mobile|armv7l|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|samsungbrowser.*mobile|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,r=/CrOS/,n=/android|ipad|playbook|silk/i;function i(t){t||(t={});var i=t.ua;if(i||\"undefined\"==typeof navigator||(i=navigator.userAgent),i&&i.headers&&\"string\"==typeof i.headers[\"user-agent\"]&&(i=i.headers[\"user-agent\"]),\"string\"!=typeof i)return!1;var a=e.test(i)&&!r.test(i)||!!t.tablet&&n.test(i);return!a&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==i.indexOf(\"Macintosh\")&&-1!==i.indexOf(\"Safari\")&&(a=!0),a}},6296:function(t,e,r){\"use strict\";t.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=r(7261),i=r(9977),a=r(4192);function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map((function(e){return t[e]})),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;s.flush=function(t){for(var e=this._controllerList,r=0;r<e.length;++r)e[r].flush(t)},s.idle=function(t){for(var e=this._controllerList,r=0;r<e.length;++r)e[r].idle(t)},s.lookAt=function(t,e,r,n){for(var i=this._controllerList,a=0;a<i.length;++a)i[a].lookAt(t,e,r,n)},s.rotate=function(t,e,r,n){for(var i=this._controllerList,a=0;a<i.length;++a)i[a].rotate(t,e,r,n)},s.pan=function(t,e,r,n){for(var i=this._controllerList,a=0;a<i.length;++a)i[a].pan(t,e,r,n)},s.translate=function(t,e,r,n){for(var i=this._controllerList,a=0;a<i.length;++a)i[a].translate(t,e,r,n)},s.setMatrix=function(t,e){for(var r=this._controllerList,n=0;n<r.length;++n)r[n].setMatrix(t,e)},s.setDistanceLimits=function(t,e){for(var r=this._controllerList,n=0;n<r.length;++n)r[n].setDistanceLimits(t,e)},s.setDistance=function(t,e){for(var r=this._controllerList,n=0;n<r.length;++n)r[n].setDistance(t,e)},s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},7169:function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?r(1538):WeakMap,i=r(2762),a=r(8116),o=new n;t.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},1085:function(t,e,r){var n=r(1371);t.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map((function(t,i){var o=i+e,s=String(o).length;return n(o,a-s)+r+t})).join(\"\\n\")}},3952:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=r(3250);function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},5995:function(t,e,r){\"use strict\";t.exports=function(t,e){return n(e).filter((function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1}))};var n=r(7642),i=r(6037)},3502:function(t,e,r){t.exports=function(t,e){return i(n(t,e))};var n=r(5995),i=r(9127)},6468:function(t){t.exports=function(t){return atob(t)}},2642:function(t,e,r){\"use strict\";t.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}for(a[r]=new Array(r+1),o=0;o<=r;++o)a[r][o]=1;var c=new Array(r+1);for(o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);var f=new Array(r+1);for(o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=r(727);function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},7507:function(t,e){\"use strict\";e.byteLength=function(t){var e=s(t),r=e[0],n=e[1];return 3*(r+n)/4-n},e.toByteArray=function(t){var e,r,a=s(t),o=a[0],l=a[1],c=new i(function(t,e,r){return 3*(e+r)/4-r}(0,o,l)),u=0,h=l>0?o-4:o;for(r=0;r<h;r+=4)e=n[t.charCodeAt(r)]<<18|n[t.charCodeAt(r+1)]<<12|n[t.charCodeAt(r+2)]<<6|n[t.charCodeAt(r+3)],c[u++]=e>>16&255,c[u++]=e>>8&255,c[u++]=255&e;return 2===l&&(e=n[t.charCodeAt(r)]<<2|n[t.charCodeAt(r+1)]>>4,c[u++]=255&e),1===l&&(e=n[t.charCodeAt(r)]<<10|n[t.charCodeAt(r+1)]<<4|n[t.charCodeAt(r+2)]>>2,c[u++]=e>>8&255,c[u++]=255&e),c},e.fromByteArray=function(t){for(var e,n=t.length,i=n%3,a=[],o=16383,s=0,c=n-i;s<c;s+=o)a.push(l(t,s,s+o>c?c:s+o));return 1===i?(e=t[n-1],a.push(r[e>>2]+r[e<<4&63]+\"==\")):2===i&&(e=(t[n-2]<<8)+t[n-1],a.push(r[e>>10]+r[e>>4&63]+r[e<<2&63]+\"=\")),a.join(\"\")};for(var r=[],n=[],i=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,a=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",o=0;o<64;++o)r[o]=a[o],n[a.charCodeAt(o)]=o;function s(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function l(t,e,n){for(var i,a,o=[],s=e;s<n;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(r[(a=i)>>18&63]+r[a>>12&63]+r[a>>6&63]+r[63&a]);return o.join(\"\")}n[\"-\".charCodeAt(0)]=62,n[\"_\".charCodeAt(0)]=63},3865:function(t,e,r){\"use strict\";var n=r(869);t.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},1318:function(t){\"use strict\";t.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},8697:function(t,e,r){\"use strict\";var n=r(869);t.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},7842:function(t,e,r){\"use strict\";var n=r(6330),i=r(1533),a=r(2651),o=r(4387),s=r(869),l=r(8697);t.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c,u,h=0;if(i(e))c=e.clone();else if(\"string\"==typeof e)c=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))c=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),h-=256;c=a(e)}}if(n(r))c.mul(r[1]),u=r[0].clone();else if(i(r))u=r.clone();else if(\"string\"==typeof r)u=o(r);else if(r)if(r===Math.floor(r))u=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),h+=256;u=a(r)}else u=a(1);return h>0?c=c.ushln(h):h<0&&(u=u.ushln(-h)),s(c,u)}},6330:function(t,e,r){\"use strict\";var n=r(1533);t.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},5716:function(t,e,r){\"use strict\";var n=r(6859);t.exports=function(t){return t.cmp(new n(0))}},1369:function(t,e,r){\"use strict\";var n=r(5716);t.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++)i+=r[a]*Math.pow(67108864,a);return n(t)*i}},4025:function(t,e,r){\"use strict\";var n=r(2361),i=r(8828).countTrailingZeros;t.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));return r>20?52:r+32}},1533:function(t,e,r){\"use strict\";r(6859),t.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},2651:function(t,e,r){\"use strict\";var n=r(6859),i=r(2361);t.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},869:function(t,e,r){\"use strict\";var n=r(2651),i=r(5716);t.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);return o.cmpn(1)?[t.div(o),e.div(o)]:[t,e]}},4387:function(t,e,r){\"use strict\";var n=r(6859);t.exports=function(t){return new n(t)}},6504:function(t,e,r){\"use strict\";var n=r(869);t.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},7721:function(t,e,r){\"use strict\";var n=r(5716);t.exports=function(t){return n(t[0])*n(t[1])}},5572:function(t,e,r){\"use strict\";var n=r(869);t.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},946:function(t,e,r){\"use strict\";var n=r(1369),i=r(4025);t.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4;return c*(s+(f=n(l.ushln(u).divRound(r)))*Math.pow(2,-u))}var h=r.bitLength()-l.bitLength()+53,f=n(l.ushln(h).divRound(r));return h<1023?c*f*Math.pow(2,-h):c*(f*=Math.pow(2,-1023))*Math.pow(2,1023-h)}},2478:function(t){\"use strict\";function e(t,e,r,n,i){for(var a=i+1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)>=0?(a=o,i=o-1):n=o+1}return a}function r(t,e,r,n,i){for(var a=i+1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)>0?(a=o,i=o-1):n=o+1}return a}function n(t,e,r,n,i){for(var a=n-1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)<0?(a=o,n=o+1):i=o-1}return a}function i(t,e,r,n,i){for(var a=n-1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)<=0?(a=o,n=o+1):i=o-1}return a}function a(t,e,r,n,i){for(;n<=i;){var a=n+i>>>1,o=t[a],s=void 0!==r?r(o,e):o-e;if(0===s)return a;s<=0?n=a+1:i=a-1}return-1}function o(t,e,r,n,i,a){return\"function\"==typeof r?a(t,e,r,void 0===n?0:0|n,void 0===i?t.length-1:0|i):a(t,e,void 0,void 0===r?0:0|r,void 0===n?t.length-1:0|n)}t.exports={ge:function(t,r,n,i,a){return o(t,r,n,i,a,e)},gt:function(t,e,n,i,a){return o(t,e,n,i,a,r)},lt:function(t,e,r,i,a){return o(t,e,r,i,a,n)},le:function(t,e,r,n,a){return o(t,e,r,n,a,i)},eq:function(t,e,r,n,i){return o(t,e,r,n,i,a)}}},8828:function(t,e){\"use strict\";function r(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}e.INT_BITS=32,e.INT_MAX=2147483647,e.INT_MIN=-1<<31,e.sign=function(t){return(t>0)-(t<0)},e.abs=function(t){var e=t>>31;return(t^e)-e},e.min=function(t,e){return e^(t^e)&-(t<e)},e.max=function(t,e){return t^(t^e)&-(t<e)},e.isPow2=function(t){return!(t&t-1||!t)},e.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},e.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},e.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},e.countTrailingZeros=r,e.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,1+(t|=t>>>16)},e.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},e.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var n=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(n),e.reverse=function(t){return n[255&t]<<24|n[t>>>8&255]<<16|n[t>>>16&255]<<8|n[t>>>24&255]},e.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},e.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},e.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},e.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},e.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>r(t)+1}},6859:function(t,e,r){!function(t,e){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof t?t.exports=a:e.BN=a,a.BN=a,a.wordSize=26;try{o=\"undefined\"!=typeof window&&void 0!==window.Buffer?window.Buffer:r(7790).Buffer}catch(t){}function s(t,e){var r=t.charCodeAt(e);return r>=65&&r<=70?r-55:r>=97&&r<=102?r-87:r-48&15}function l(t,e,r){var n=s(t,r);return r-1>=e&&(n|=s(t,r-1)<<4),n}function c(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&(i++,this.negative=1),i<t.length&&(16===e?this._parseHex(t,i,r):(this._parseBase(t,e,i),\"le\"===r&&this._initArray(this.toArray(),e,r)))},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e,r){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var n=0;n<this.length;n++)this.words[n]=0;var i,a=0,o=0;if(\"be\"===r)for(n=t.length-1;n>=e;n-=2)i=l(t,e,n)<<a,this.words[o]|=67108863&i,a>=18?(a-=18,o+=1,this.words[o]|=i>>>26):a+=8;else for(n=(t.length-e)%2==0?e+1:e;n<t.length;n+=2)i=l(t,e,n)<<a,this.words[o]|=67108863&i,a>=18?(a-=18,o+=1,this.words[o]|=i>>>26):a+=8;this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,l=0,u=r;u<s;u+=n)l=c(t,u,u+n,e),this.imuln(i),this.words[0]+l<67108864?this.words[0]+=l:this._iaddn(l);if(0!==o){var h=1;for(l=c(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+l<67108864?this.words[0]+=l:this._iaddn(l)}this.strip()},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var u=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],h=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],f=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function p(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!=(a=s>>>24-i&16777215)||o!==this.length-1?u[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var c=h[t],p=f[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var m=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?m+r:u[c-m.length]+m+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(void 0!==o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var d=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,m=p>>>13,g=0|o[2],y=8191&g,v=g>>>13,x=0|o[3],_=8191&x,b=x>>>13,w=0|o[4],T=8191&w,k=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,I=0|o[7],P=8191&I,z=I>>>13,O=0|o[8],D=8191&O,R=O>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Z=0|s[2],W=8191&Z,Y=Z>>>13,X=0|s[3],$=8191&X,J=X>>>13,K=0|s[4],Q=8191&K,tt=K>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,mt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var gt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(gt>>>26)|0,gt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(m,U)|0,a=Math.imul(m,V);var yt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(y,U),i=(i=Math.imul(y,V))+Math.imul(v,U)|0,a=Math.imul(v,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(m,H)|0,a=a+Math.imul(m,G)|0;var vt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,Y)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,Y)|0)+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(_,U),i=(i=Math.imul(_,V))+Math.imul(b,U)|0,a=Math.imul(b,V),n=n+Math.imul(y,H)|0,i=(i=i+Math.imul(y,G)|0)+Math.imul(v,H)|0,a=a+Math.imul(v,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,Y)|0)+Math.imul(m,W)|0,a=a+Math.imul(m,Y)|0;var xt=(c+(n=n+Math.imul(h,$)|0)|0)+((8191&(i=(i=i+Math.imul(h,J)|0)+Math.imul(f,$)|0))<<13)|0;c=((a=a+Math.imul(f,J)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(T,U),i=(i=Math.imul(T,V))+Math.imul(k,U)|0,a=Math.imul(k,V),n=n+Math.imul(_,H)|0,i=(i=i+Math.imul(_,G)|0)+Math.imul(b,H)|0,a=a+Math.imul(b,G)|0,n=n+Math.imul(y,W)|0,i=(i=i+Math.imul(y,Y)|0)+Math.imul(v,W)|0,a=a+Math.imul(v,Y)|0,n=n+Math.imul(d,$)|0,i=(i=i+Math.imul(d,J)|0)+Math.imul(m,$)|0,a=a+Math.imul(m,J)|0;var _t=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(T,H)|0,i=(i=i+Math.imul(T,G)|0)+Math.imul(k,H)|0,a=a+Math.imul(k,G)|0,n=n+Math.imul(_,W)|0,i=(i=i+Math.imul(_,Y)|0)+Math.imul(b,W)|0,a=a+Math.imul(b,Y)|0,n=n+Math.imul(y,$)|0,i=(i=i+Math.imul(y,J)|0)+Math.imul(v,$)|0,a=a+Math.imul(v,J)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(m,Q)|0,a=a+Math.imul(m,tt)|0;var bt=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(T,W)|0,i=(i=i+Math.imul(T,Y)|0)+Math.imul(k,W)|0,a=a+Math.imul(k,Y)|0,n=n+Math.imul(_,$)|0,i=(i=i+Math.imul(_,J)|0)+Math.imul(b,$)|0,a=a+Math.imul(b,J)|0,n=n+Math.imul(y,Q)|0,i=(i=i+Math.imul(y,tt)|0)+Math.imul(v,Q)|0,a=a+Math.imul(v,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(m,rt)|0,a=a+Math.imul(m,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(P,U),i=(i=Math.imul(P,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,Y)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,Y)|0,n=n+Math.imul(T,$)|0,i=(i=i+Math.imul(T,J)|0)+Math.imul(k,$)|0,a=a+Math.imul(k,J)|0,n=n+Math.imul(_,Q)|0,i=(i=i+Math.imul(_,tt)|0)+Math.imul(b,Q)|0,a=a+Math.imul(b,tt)|0,n=n+Math.imul(y,rt)|0,i=(i=i+Math.imul(y,nt)|0)+Math.imul(v,rt)|0,a=a+Math.imul(v,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(m,at)|0,a=a+Math.imul(m,ot)|0;var Tt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(P,H)|0,i=(i=i+Math.imul(P,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,Y)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,Y)|0,n=n+Math.imul(M,$)|0,i=(i=i+Math.imul(M,J)|0)+Math.imul(S,$)|0,a=a+Math.imul(S,J)|0,n=n+Math.imul(T,Q)|0,i=(i=i+Math.imul(T,tt)|0)+Math.imul(k,Q)|0,a=a+Math.imul(k,tt)|0,n=n+Math.imul(_,rt)|0,i=(i=i+Math.imul(_,nt)|0)+Math.imul(b,rt)|0,a=a+Math.imul(b,nt)|0,n=n+Math.imul(y,at)|0,i=(i=i+Math.imul(y,ot)|0)+Math.imul(v,at)|0,a=a+Math.imul(v,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(m,lt)|0,a=a+Math.imul(m,ct)|0;var kt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(P,W)|0,i=(i=i+Math.imul(P,Y)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,Y)|0,n=n+Math.imul(C,$)|0,i=(i=i+Math.imul(C,J)|0)+Math.imul(L,$)|0,a=a+Math.imul(L,J)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(T,rt)|0,i=(i=i+Math.imul(T,nt)|0)+Math.imul(k,rt)|0,a=a+Math.imul(k,nt)|0,n=n+Math.imul(_,at)|0,i=(i=i+Math.imul(_,ot)|0)+Math.imul(b,at)|0,a=a+Math.imul(b,ot)|0,n=n+Math.imul(y,lt)|0,i=(i=i+Math.imul(y,ct)|0)+Math.imul(v,lt)|0,a=a+Math.imul(v,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(m,ht)|0,a=a+Math.imul(m,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,mt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,mt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,Y)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,Y)|0,n=n+Math.imul(P,$)|0,i=(i=i+Math.imul(P,J)|0)+Math.imul(z,$)|0,a=a+Math.imul(z,J)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(T,at)|0,i=(i=i+Math.imul(T,ot)|0)+Math.imul(k,at)|0,a=a+Math.imul(k,ot)|0,n=n+Math.imul(_,lt)|0,i=(i=i+Math.imul(_,ct)|0)+Math.imul(b,lt)|0,a=a+Math.imul(b,ct)|0,n=n+Math.imul(y,ht)|0,i=(i=i+Math.imul(y,ft)|0)+Math.imul(v,ht)|0,a=a+Math.imul(v,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,mt)|0)+Math.imul(m,dt)|0))<<13)|0;c=((a=a+Math.imul(m,mt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,Y))+Math.imul(N,W)|0,a=Math.imul(N,Y),n=n+Math.imul(D,$)|0,i=(i=i+Math.imul(D,J)|0)+Math.imul(R,$)|0,a=a+Math.imul(R,J)|0,n=n+Math.imul(P,Q)|0,i=(i=i+Math.imul(P,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(T,lt)|0,i=(i=i+Math.imul(T,ct)|0)+Math.imul(k,lt)|0,a=a+Math.imul(k,ct)|0,n=n+Math.imul(_,ht)|0,i=(i=i+Math.imul(_,ft)|0)+Math.imul(b,ht)|0,a=a+Math.imul(b,ft)|0;var St=(c+(n=n+Math.imul(y,dt)|0)|0)+((8191&(i=(i=i+Math.imul(y,mt)|0)+Math.imul(v,dt)|0))<<13)|0;c=((a=a+Math.imul(v,mt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,$),i=(i=Math.imul(B,J))+Math.imul(N,$)|0,a=Math.imul(N,J),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(P,rt)|0,i=(i=i+Math.imul(P,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(T,ht)|0,i=(i=i+Math.imul(T,ft)|0)+Math.imul(k,ht)|0,a=a+Math.imul(k,ft)|0;var Et=(c+(n=n+Math.imul(_,dt)|0)|0)+((8191&(i=(i=i+Math.imul(_,mt)|0)+Math.imul(b,dt)|0))<<13)|0;c=((a=a+Math.imul(b,mt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(P,at)|0,i=(i=i+Math.imul(P,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(i=(i=i+Math.imul(T,mt)|0)+Math.imul(k,dt)|0))<<13)|0;c=((a=a+Math.imul(k,mt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(P,lt)|0,i=(i=i+Math.imul(P,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,mt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,mt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(P,ht)|0,i=(i=i+Math.imul(P,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var It=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,mt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,mt)|0)+(i>>>13)|0)+(It>>>26)|0,It&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Pt=(c+(n=n+Math.imul(P,dt)|0)|0)+((8191&(i=(i=i+Math.imul(P,mt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,mt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,mt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,mt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var Ot=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,mt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,mt))+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,l[0]=gt,l[1]=yt,l[2]=vt,l[3]=xt,l[4]=_t,l[5]=bt,l[6]=wt,l[7]=Tt,l[8]=kt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=It,l[16]=Pt,l[17]=zt,l[18]=Ot,0!==c&&(l[19]=c,r.length++),r};function m(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(d=p),a.prototype.mulTo=function(t,e){var r,n=this.length+t.length;return r=10===this.length&&10===t.length?d(this,t,e):n<63?p(this,t,e):n<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):m(this,t,e),r},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],m=n[u+p],g=r[u+p+o],y=n[u+p+o],v=h*g-f*y;y=h*y+f*g,g=v,r[u+p]=d+g,n[u+p]=m+y,r[u+p+o]=d-g,n[u+p+o]=m-y,p!==s&&(v=l*h-c*f,f=l*f+c*h,h=v)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),m(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r||!(this.words[r]&i))},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!=(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,m=1;0==(r.words[0]&m)&&d<26;++d,m<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new T(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var y={k256:null,p224:null,p192:null,p25519:null};function v(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function x(){v.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function _(){v.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){v.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function w(){v.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function T(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){T.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}v.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},v.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):void 0!==r.strip?r.strip():r._strip(),r},v.prototype.split=function(t,e){t.iushrn(this.n,0,e)},v.prototype.imulK=function(t){return t.imul(this.k)},i(x,v),x.prototype.split=function(t,e){for(var r=4194303,n=Math.min(t.length,9),i=0;i<n;i++)e.words[i]=t.words[i];if(e.length=n,t.length<=9)return t.words[0]=0,void(t.length=1);var a=t.words[9];for(e.words[e.length++]=a&r,i=10;i<t.length;i++){var o=0|t.words[i];t.words[i-10]=(o&r)<<4|a>>>22,a=o}a>>>=22,t.words[i-10]=a,0===a&&t.length>10?t.length-=10:t.length-=9},x.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(_,v),i(b,v),i(w,v),w.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(y[t])return y[t];var e;if(\"k256\"===t)e=new x;else if(\"p224\"===t)e=new _;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new w}return y[t]=e,e},T.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},T.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},T.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},T.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},T.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},T.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},T.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},T.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},T.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},T.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},T.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},T.prototype.isqr=function(t){return this.imul(t,t.clone())},T.prototype.sqr=function(t){return this.mul(t,t)},T.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var m=p,g=0;0!==m.cmp(s);g++)m=m.redSqr();n(g<d);var y=this.pow(h,new a(1).iushln(d-g-1));f=f.redMul(y),h=y.redSqr(),p=p.redMul(h),d=g}return f},T.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},T.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4==++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},T.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},T.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,T),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(t=r.nmd(t),this)},6204:function(t){\"use strict\";t.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},6867:function(t,e,r){\"use strict\";t.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=r(1888),a=r(855),o=r(7150);function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),m=i.mallocInt32(c);(c=l(e,u,d,m))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,m):o(u,r,n,s,f,p,c,d,m),i.free(d),i.free(m))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},2455:function(t,e){\"use strict\";function r(t){return t?function(t,e,r,n,i,a,o,s,l,c,u){return i-n>l-s?function(t,e,r,n,i,a,o,s,l,c,u){for(var h=2*t,f=n,p=h*n;f<i;++f,p+=h){var d=a[e+p],m=a[e+p+t],g=o[f];t:for(var y=s,v=h*s;y<l;++y,v+=h){var x=c[e+v],_=c[e+v+t],b=u[y];if(!(_<d||m<x)){for(var w=e+1;w<t;++w){var T=a[w+p],k=a[w+t+p],A=c[w+v],M=c[w+t+v];if(k<A||M<T)continue t}var S=r(g,b);if(void 0!==S)return S}}}}(t,e,r,n,i,a,o,s,l,c,u):function(t,e,r,n,i,a,o,s,l,c,u){for(var h=2*t,f=s,p=h*s;f<l;++f,p+=h){var d=c[e+p],m=c[e+p+t],g=u[f];t:for(var y=n,v=h*n;y<i;++y,v+=h){var x=a[e+v],_=a[e+v+t],b=o[y];if(!(m<x||_<d)){for(var w=e+1;w<t;++w){var T=a[w+v],k=a[w+t+v],A=c[w+p],M=c[w+t+p];if(k<A||M<T)continue t}var S=r(b,g);if(void 0!==S)return S}}}}(t,e,r,n,i,a,o,s,l,c,u)}:function(t,e,r,n,i,a,o,s,l,c,u,h){return a-i>c-l?n?function(t,e,r,n,i,a,o,s,l,c,u){for(var h=2*t,f=n,p=h*n;f<i;++f,p+=h){var d=a[e+p],m=a[e+p+t],g=o[f];t:for(var y=s,v=h*s;y<l;++y,v+=h){var x=c[e+v],_=u[y];if(!(x<=d||m<x)){for(var b=e+1;b<t;++b){var w=a[b+p],T=a[b+t+p],k=c[b+v],A=c[b+t+v];if(T<k||A<w)continue t}var M=r(_,g);if(void 0!==M)return M}}}}(t,e,r,i,a,o,s,l,c,u,h):function(t,e,r,n,i,a,o,s,l,c,u){for(var h=2*t,f=n,p=h*n;f<i;++f,p+=h){var d=a[e+p],m=a[e+p+t],g=o[f];t:for(var y=s,v=h*s;y<l;++y,v+=h){var x=c[e+v],_=u[y];if(!(x<d||m<x)){for(var b=e+1;b<t;++b){var w=a[b+p],T=a[b+t+p],k=c[b+v],A=c[b+t+v];if(T<k||A<w)continue t}var M=r(g,_);if(void 0!==M)return M}}}}(t,e,r,i,a,o,s,l,c,u,h):n?function(t,e,r,n,i,a,o,s,l,c,u){for(var h=2*t,f=s,p=h*s;f<l;++f,p+=h){var d=c[e+p],m=u[f];t:for(var g=n,y=h*n;g<i;++g,y+=h){var v=a[e+y],x=a[e+y+t],_=o[g];if(!(d<=v||x<d)){for(var b=e+1;b<t;++b){var w=a[b+y],T=a[b+t+y],k=c[b+p],A=c[b+t+p];if(T<k||A<w)continue t}var M=r(m,_);if(void 0!==M)return M}}}}(t,e,r,i,a,o,s,l,c,u,h):function(t,e,r,n,i,a,o,s,l,c,u){for(var h=2*t,f=s,p=h*s;f<l;++f,p+=h){var d=c[e+p],m=u[f];t:for(var g=n,y=h*n;g<i;++g,y+=h){var v=a[e+y],x=a[e+y+t],_=o[g];if(!(d<v||x<d)){for(var b=e+1;b<t;++b){var w=a[b+y],T=a[b+t+y],k=c[b+p],A=c[b+t+p];if(T<k||A<w)continue t}var M=r(_,m);if(void 0!==M)return M}}}}(t,e,r,i,a,o,s,l,c,u,h)}}e.partial=r(!1),e.full=r(!0)},7150:function(t,e,r){\"use strict\";t.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(_*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(b*r);T.length<o&&(n.free(T),T=n.mallocDouble(o))}(t,a+E);var I,P=0,z=2*t;for(k(P++,0,0,a,0,E,r?16:0,-1/0,1/0),r||k(P++,0,0,E,0,a,1,-1/0,1/0);P>0;){var O=(P-=1)*_,D=w[O],R=w[O+1],F=w[O+2],B=w[O+3],N=w[O+4],j=w[O+5],U=P*b,V=T[U],q=T[U+1],H=1&j,G=!!(16&j),Z=u,W=S,Y=C,X=L;if(H&&(Z=C,W=L,Y=u,X=S),!(2&j&&R>=(F=g(t,D,R,F,Z,W,q))||4&j&&(R=y(t,D,R,F,Z,W,V))>=F)){var $=F-R,J=N-B;if(G){if(t*$*($+J)<p){if(void 0!==(I=l.scanComplete(t,D,e,R,F,Z,W,B,N,Y,X)))return I;continue}}else{if(t*Math.min($,J)<h){if(void 0!==(I=o(t,D,e,H,R,F,Z,W,B,N,Y,X)))return I;continue}if(t*$*J<f){if(void 0!==(I=l.scanBipartite(t,D,e,H,R,F,Z,W,B,N,Y,X)))return I;continue}}var K=d(t,D,R,F,Z,W,V,q);if(R<K)if(t*(K-R)<h){if(void 0!==(I=s(t,D+1,e,R,K,Z,W,B,N,Y,X)))return I}else if(D===t-2){if(void 0!==(I=H?l.sweepBipartite(t,e,B,N,Y,X,R,K,Z,W):l.sweepBipartite(t,e,R,K,Z,W,B,N,Y,X)))return I}else k(P++,D+1,R,K,B,N,H,-1/0,1/0),k(P++,D+1,B,N,R,K,1^H,-1/0,1/0);if(K<F){var Q=c(t,D,B,N,Y,X),tt=Y[z*Q+D],et=m(t,D,Q,N,Y,X,tt);if(et<N&&k(P++,D,K,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&k(P++,D,K,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(I=G?M(t,D,e,K,F,Z,W,Q,Y,X[Q]):A(t,D,e,H,K,F,Z,W,Q,Y,X[Q])))return I}else if(Q<et){var rt;if(G){if(K<(rt=v(t,D,K,F,Z,W,tt))){var nt=m(t,D,K,rt,Z,W,tt);if(D===t-2){if(K<nt&&void 0!==(I=l.sweepComplete(t,e,K,nt,Z,W,Q,et,Y,X)))return I;if(nt<rt&&void 0!==(I=l.sweepBipartite(t,e,nt,rt,Z,W,Q,et,Y,X)))return I}else K<nt&&k(P++,D+1,K,nt,Q,et,16,-1/0,1/0),nt<rt&&(k(P++,D+1,nt,rt,Q,et,0,-1/0,1/0),k(P++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else K<(rt=H?x(t,D,K,F,Z,W,tt):v(t,D,K,F,Z,W,tt))&&(D===t-2?I=H?l.sweepBipartite(t,e,Q,et,Y,X,K,rt,Z,W):l.sweepBipartite(t,e,K,rt,Z,W,Q,et,Y,X):(k(P++,D+1,K,rt,Q,et,H,-1/0,1/0),k(P++,D+1,Q,et,K,rt,1^H,-1/0,1/0)))}}}}};var n=r(1888),i=r(8828),a=r(2455),o=a.partial,s=a.full,l=r(855),c=r(3545),u=r(8105),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\"),m=u(\"lo===p0\"),g=u(\"lo<p0\"),y=u(\"hi<=p0\"),v=u(\"lo<=p0&&p0<=hi\"),x=u(\"lo<p0&&p0<=hi\"),_=6,b=2,w=n.mallocInt32(1024),T=n.mallocDouble(1024);function k(t,e,r,n,i,a,o,s,l){var c=_*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=b*t;T[u]=s,T[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,m=i*h;d<a;++d,m+=h){var g=o[m+e],y=o[m+e+t];if(!(p<g||y<p||n&&p===g)){for(var v,x=s[d],_=e+1;_<t;++_){g=o[m+_],y=o[m+_+t];var b=c[f+_],w=c[f+_+t];if(y<b||w<g)continue t}if(void 0!==(v=n?r(u,x):r(x,u)))return v}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var m=o[p];if(m!==c){var g=a[d+e],y=a[d+e+t];if(!(f<g||y<f)){for(var v=e+1;v<t;++v){g=a[d+v],y=a[d+v+t];var x=l[h+v],_=l[h+v+t];if(y<x||_<g)continue t}var b=r(m,c);if(void 0!==b)return b}}}}},3545:function(t,e,r){\"use strict\";t.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;for(var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var m=u-c,g=Math.random()*m+c|0,y=s[f*g+e],v=Math.random()*m+c|0,x=s[f*v+e],_=Math.random()*m+c|0,b=s[f*_+e];y<=x?b>=x?(p=v,d=x):y>=b?(p=g,d=y):(p=_,d=b):x>=b?(p=v,d=x):b>=y?(p=g,d=y):(p=_,d=b);for(var w=f*(u-1),T=f*p,k=0;k<f;++k,++w,++T){var A=s[w];s[w]=s[T],s[T]=A}var M=l[u-1];for(l[u-1]=l[p],l[p]=M,w=f*(u-1),T=f*(p=n(t,e,c,u-1,s,l,d)),k=0;k<f;++k,++w,++T)A=s[w],s[w]=s[T],s[T]=A;if(M=l[u-1],l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=r(8105)(\"lo<p0\"),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var m=i[f];i[f]=i[p],i[p]=m}var g=a[u];a[u]=a[u-1],a[u-1]=g}}},8105:function(t){\"use strict\";t.exports=function(t){return e[t]};var e={\"lo===p0\":function(t,e,r,n,i,a,o){for(var s=2*t,l=s*r,c=l,u=r,h=e,f=r;n>f;++f,l+=s)if(i[l+h]===o)if(u===f)u+=1,c+=s;else{for(var p=0;s>p;++p){var d=i[l+p];i[l+p]=i[c],i[c++]=d}var m=a[f];a[f]=a[u],a[u++]=m}return u},\"lo<p0\":function(t,e,r,n,i,a,o){for(var s=2*t,l=s*r,c=l,u=r,h=e,f=r;n>f;++f,l+=s)if(i[l+h]<o)if(u===f)u+=1,c+=s;else{for(var p=0;s>p;++p){var d=i[l+p];i[l+p]=i[c],i[c++]=d}var m=a[f];a[f]=a[u],a[u++]=m}return u},\"lo<=p0\":function(t,e,r,n,i,a,o){for(var s=2*t,l=s*r,c=l,u=r,h=t+e,f=r;n>f;++f,l+=s)if(i[l+h]<=o)if(u===f)u+=1,c+=s;else{for(var p=0;s>p;++p){var d=i[l+p];i[l+p]=i[c],i[c++]=d}var m=a[f];a[f]=a[u],a[u++]=m}return u},\"hi<=p0\":function(t,e,r,n,i,a,o){for(var s=2*t,l=s*r,c=l,u=r,h=t+e,f=r;n>f;++f,l+=s)if(i[l+h]<=o)if(u===f)u+=1,c+=s;else{for(var p=0;s>p;++p){var d=i[l+p];i[l+p]=i[c],i[c++]=d}var m=a[f];a[f]=a[u],a[u++]=m}return u},\"lo<p0&&p0<=hi\":function(t,e,r,n,i,a,o){for(var s=2*t,l=s*r,c=l,u=r,h=e,f=t+e,p=r;n>p;++p,l+=s){var d=i[l+h],m=i[l+f];if(d<o&&o<=m)if(u===p)u+=1,c+=s;else{for(var g=0;s>g;++g){var y=i[l+g];i[l+g]=i[c],i[c++]=y}var v=a[p];a[p]=a[u],a[u++]=v}}return u},\"lo<=p0&&p0<=hi\":function(t,e,r,n,i,a,o){for(var s=2*t,l=s*r,c=l,u=r,h=e,f=t+e,p=r;n>p;++p,l+=s){var d=i[l+h],m=i[l+f];if(d<=o&&o<=m)if(u===p)u+=1,c+=s;else{for(var g=0;s>g;++g){var y=i[l+g];i[l+g]=i[c],i[c++]=y}var v=a[p];a[p]=a[u],a[u++]=v}}return u},\"!(lo>=p0)&&!(p1>=hi)\":function(t,e,r,n,i,a,o,s){for(var l=2*t,c=l*r,u=c,h=r,f=e,p=t+e,d=r;n>d;++d,c+=l){var m=i[c+f],g=i[c+p];if(!(m>=o||s>=g))if(h===d)h+=1,u+=l;else{for(var y=0;l>y;++y){var v=i[c+y];i[c+y]=i[u],i[u++]=v}var x=a[d];a[d]=a[h],a[h++]=x}}return h}}},1811:function(t){\"use strict\";t.exports=function(t,n){n<=4*e?r(0,n-1,t):c(0,n-1,t)};var e=32;function r(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function n(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function i(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function a(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function o(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function s(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function l(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}function c(t,u,h){var f=(u-t+1)/6|0,p=t+f,d=u-f,m=t+u>>1,g=m-f,y=m+f,v=p,x=g,_=m,b=y,w=d,T=t+1,k=u-1,A=0;s(v,x,h)&&(A=v,v=x,x=A),s(b,w,h)&&(A=b,b=w,w=A),s(v,_,h)&&(A=v,v=_,_=A),s(x,_,h)&&(A=x,x=_,_=A),s(v,b,h)&&(A=v,v=b,b=A),s(_,b,h)&&(A=_,_=b,b=A),s(x,w,h)&&(A=x,x=w,w=A),s(x,_,h)&&(A=x,x=_,_=A),s(b,w,h)&&(A=b,b=w,w=A);for(var M=h[2*x],S=h[2*x+1],E=h[2*b],C=h[2*b+1],L=2*v,I=2*_,P=2*w,z=2*p,O=2*m,D=2*d,R=0;R<2;++R){var F=h[L+R],B=h[I+R],N=h[P+R];h[z+R]=F,h[O+R]=B,h[D+R]=N}i(g,t,h),i(y,u,h);for(var j=T;j<=k;++j)if(l(j,M,S,h))j!==T&&n(j,T,h),++T;else if(!l(j,E,C,h))for(;;){if(l(k,E,C,h)){l(k,M,S,h)?(a(j,T,k,h),++T,--k):(n(j,k,h),--k);break}if(--k<j)break}o(t,T-1,M,S,h),o(u,k+1,E,C,h),T-2-t<=e?r(t,T-2,h):c(t,T-2,h),u-(k+2)<=e?r(k+2,u,h):c(k+2,u,h),k-T<=e?r(T,k,h):c(T,k,h)}},855:function(t,e,r){\"use strict\";t.exports={init:function(t){var e=i.nextPow2(t);l.length<e&&(n.free(l),l=n.mallocInt32(e)),c.length<e&&(n.free(c),c=n.mallocInt32(e)),u.length<e&&(n.free(u),u=n.mallocInt32(e)),h.length<e&&(n.free(h),h=n.mallocInt32(e)),f.length<e&&(n.free(f),f=n.mallocInt32(e)),p.length<e&&(n.free(p),p=n.mallocInt32(e));var r=8*e;d.length<r&&(n.free(d),d=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,s,f,p,y,v){for(var x=0,_=2*t,b=t-1,w=_-1,T=r;T<n;++T){var k=s[T],A=_*T;d[x++]=i[A+b],d[x++]=-(k+1),d[x++]=i[A+w],d[x++]=k}for(T=f;T<p;++T){k=v[T]+o;var M=_*T;d[x++]=y[M+b],d[x++]=-k,d[x++]=y[M+w],d[x++]=k}var S=x>>>1;a(d,S);var E=0,C=0;for(T=0;T<S;++T){var L=0|d[2*T+1];if(L>=o)m(u,h,C--,L=L-o|0);else if(L>=0)m(l,c,E--,L);else if(L<=-o){L=-L-o|0;for(var I=0;I<E;++I)if(void 0!==(P=e(l[I],L)))return P;g(u,h,C++,L)}else{for(L=-L-1|0,I=0;I<C;++I){var P;if(void 0!==(P=e(L,u[I])))return P}g(l,c,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,s,y,v,x){for(var _=0,b=2*t,w=t-1,T=b-1,k=r;k<n;++k){var A=o[k]+1<<1,M=b*k;d[_++]=i[M+w],d[_++]=-A,d[_++]=i[M+T],d[_++]=A}for(k=s;k<y;++k){A=x[k]+1<<1;var S=b*k;d[_++]=v[S+w],d[_++]=1|-A,d[_++]=v[S+T],d[_++]=1|A}var E=_>>>1;a(d,E);var C=0,L=0,I=0;for(k=0;k<E;++k){var P=0|d[2*k+1],z=1&P;if(k<E-1&&P>>1==d[2*k+3]>>1&&(z=2,k+=1),P<0){for(var O=-(P>>1)-1,D=0;D<I;++D)if(void 0!==(R=e(f[D],O)))return R;if(0!==z)for(D=0;D<C;++D)if(void 0!==(R=e(l[D],O)))return R;if(1!==z)for(D=0;D<L;++D){var R;if(void 0!==(R=e(u[D],O)))return R}0===z?g(l,c,C++,O):1===z?g(u,h,L++,O):2===z&&g(f,p,I++,O)}else O=(P>>1)-1,0===z?m(l,c,C--,O):1===z?m(u,h,L--,O):2===z&&m(f,p,I--,O)}},scanBipartite:function(t,e,r,n,i,s,u,h,f,p,y,v){var x=0,_=2*t,b=e,w=e+t,T=1,k=1;n?k=o:T=o;for(var A=i;A<s;++A){var M=A+T,S=_*A;d[x++]=u[S+b],d[x++]=-M,d[x++]=u[S+w],d[x++]=M}for(A=f;A<p;++A){M=A+k;var E=_*A;d[x++]=y[E+b],d[x++]=-M}var C=x>>>1;a(d,C);var L=0;for(A=0;A<C;++A){var I=0|d[2*A+1];if(I<0){var P=!1;if((M=-I)>=o?(P=!n,M-=o):(P=!!n,M-=1),P)g(l,c,L++,M);else{var z=v[M],O=_*M,D=y[O+e+1],R=y[O+e+1+t];t:for(var F=0;F<L;++F){var B=l[F],N=_*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(y[O+j+t]<u[N+j]||u[N+j+t]<y[O+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else m(l,c,L--,I-T)}},scanComplete:function(t,e,r,n,i,s,c,u,h,f,p){for(var m=0,g=2*t,y=e,v=e+t,x=n;x<i;++x){var _=x+o,b=g*x;d[m++]=s[b+y],d[m++]=-_,d[m++]=s[b+v],d[m++]=_}for(x=u;x<h;++x){_=x+1;var w=g*x;d[m++]=f[w+y],d[m++]=-_}var T=m>>>1;a(d,T);var k=0;for(x=0;x<T;++x){var A=0|d[2*x+1];if(A<0)if((_=-A)>=o)l[k++]=_-o;else{var M=p[_-=1],S=g*_,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<k;++L){var I=l[L],P=c[I];if(P===M)break;var z=g*I;if(!(C<s[z+e+1]||s[z+e+1+t]<E)){for(var O=e+2;O<t;++O)if(f[S+O+t]<s[z+O]||s[z+O+t]<f[S+O])continue t;var D=r(P,M);if(void 0!==D)return D}}}else{for(_=A-o,L=k-1;L>=0;--L)if(l[L]===_){for(O=L+1;O<k;++O)l[O-1]=l[O];break}--k}}}};var n=r(1888),i=r(8828),a=r(1811),o=1<<28,s=1024,l=n.mallocInt32(s),c=n.mallocInt32(s),u=n.mallocInt32(s),h=n.mallocInt32(s),f=n.mallocInt32(s),p=n.mallocInt32(s),d=n.mallocDouble(8192);function m(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},2538:function(t,e,r){\"use strict\";var n=r(8902),i=r(5542),a=r(2272),o=r(5023);function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}t.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var m=i(t.length,function(t){return t.map(s).sort(l)}(e)),g=0;g<d.length;++g){var y=d[g];m.addTriangle(y[0],y[1],y[2])}return u&&a(t,m),f?h?p?o(m,0,p):m.cells():o(m,1,p):o(m,-1)}return d}},2272:function(t,e,r){\"use strict\";var n=r(2646)[4];function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}r(2478),t.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2)if(!((p=l[c])<s||e.isConstraint(s,p))){for(var u=l[c-1],h=-1,f=1;f<l.length;f+=2)if(l[f-1]===p){h=l[f];break}h<0||n(t[s],t[p],t[u],t[h])<0&&r.push(s,p)}for(;r.length>0;){for(var p=r.pop(),d=(u=-1,h=-1,l=o[s=r.pop()],1);d<l.length;d+=2){var m=l[d-1],g=l[d];m===p?h=g:g===p&&(u=m)}u<0||h<0||n(t[s],t[p],t[u],t[h])>=0||(e.flip(s,p),i(t,e,r,u,s,h),i(t,e,r,s,h,u),i(t,e,r,h,p,u),i(t,e,r,p,u,h))}}},5023:function(t,e,r){\"use strict\";var n,i=r(2478);function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}t.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=(y=r[i])[0],l=y[1],c=y[2];l<c?l<s&&(y[0]=l,y[1]=c,y[2]=s):c<s&&(y[0]=c,y[1]=s,y[2]=l)}r.sort(o);var u=new Array(n);for(i=0;i<u.length;++i)u[i]=0;var h=[],f=[],p=new Array(3*n),d=new Array(3*n),m=null;e&&(m=[]);var g=new a(r,p,d,u,h,f,m);for(i=0;i<n;++i)for(var y=r[i],v=0;v<3;++v){s=y[v],l=y[(v+1)%3];var x=p[3*i+v]=g.locate(l,s,t.opposite(l,s)),_=d[3*i+v]=t.isConstraint(s,l);x<0&&(_?f.push(i):(h.push(i),u[i]=1),e&&m.push([l,s,-1]))}return g}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;for(var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i,u[p];for(var d=0;d<3;++d){var m=f[3*p+d];m>=0&&0===c[m]&&(h[3*p+d]?l.push(m):(s.push(m),c[m]=i))}}}var g=l;l=s,s=g,l.length=0,i=-i}var y=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);return r?y.concat(n.boundary):y},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},8902:function(t,e,r){\"use strict\";var n=r(2478),i=r(3250)[3];function a(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function o(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function s(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(0!==t.type&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function l(t,e){return i(t.a,t.b,e)}function c(t,e,r,a,o){for(var s=n.lt(e,a,l),c=n.gt(e,a,l),u=s;u<c;++u){for(var h=e[u],f=h.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=h.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function u(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function h(t,e,r){var i=n.le(t,r,u),o=t[i],s=o.upperIds,l=s[s.length-1];o.upperIds=[l],t.splice(i+1,0,new a(r.a,r.b,r.idx,[l],s))}function f(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,u),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}t.exports=function(t,e){for(var r=t.length,n=e.length,i=[],l=0;l<r;++l)i.push(new o(t[l],null,0,l));for(l=0;l<n;++l){var u=e[l],p=t[u[0]],d=t[u[1]];p[0]<d[0]?i.push(new o(p,d,2,l),new o(d,p,1,l)):p[0]>d[0]&&i.push(new o(d,p,2,l),new o(p,d,1,l))}i.sort(s);for(var m=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),g=[new a([m,1],[m,0],-1,[],[],[],[])],y=[],v=(l=0,i.length);l<v;++l){var x=i[l],_=x.type;0===_?c(y,g,t,x.a,x.idx):2===_?h(g,0,x):f(g,0,x)}return y}},5542:function(t,e,r){\"use strict\";var n=r(2478);function i(t,e){this.stars=t,this.edges=e}t.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},2419:function(t){\"use strict\";t.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},3628:function(t,e,r){\"use strict\";var n=r(1338),i=r(727);function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,t.exports=s},6037:function(t,e,r){t.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=r(3628)},332:function(t,e,r){\"use strict\";t.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}for(var s=function(t,e,r){var n=d(t,[],p(t));return y(e,n,r),!!n}(t,e,!!r);v(t,e,!!r);)s=!0;if(r&&s)for(n.length=0,r.length=0,a=0;a<e.length;++a)o=e[a],n.push([o[0],o[1]]),r.push(o[2]);return s};var n=r(1755),i=r(6867),a=r(1125),o=r(7842),s=r(1318),l=r(946),c=r(5838),u=r(1278),h=r(3637);function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,(function(t,e){o.link(t,e)}));var d=!0,m=new Array(a);for(l=0;l<a;++l)(y=o.find(l))!==l&&(d=!1,t[y]=[Math.min(t[l][0],t[y][0]),Math.min(t[l][1],t[y][1])]);if(d)return null;var g=0;for(l=0;l<a;++l){var y;(y=o.find(l))===l?(m[l]=g,t[g++]=t[l]):m[l]=-1}for(t.length=g,l=0;l<a;++l)m[l]<0&&(m[l]=m[o.find(l)]);return m}function m(t,e){return t[0]-e[0]||t[1]-e[1]}function g(t,e){return t[0]-e[0]||t[1]-e[1]||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function y(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1],o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(g):t.sort(m);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function v(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,(function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}})),n}(t,e,n),m=function(t,e,r,n){var o=[];return i(r,n,(function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}})),o}(t,e,n,p(t)),g=function(t,e,r,n,i){var a,u,f=t.map((function(t){return[o(t[0]),o(t[1])]}));for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],m=e[u],g=e[d],y=h(c(t[m[0]]),c(t[m[1]]),c(t[g[0]]),c(t[g[1]]));if(y){var v=t.length;t.push([l(y[0]),l(y[1])]),f.push(y),n.push([u,v],[d,v])}}for(n.sort((function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])})),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],_=x[0],b=x[1],w=t[_],T=t[b];if((w[0]-T[0]||w[1]-T[1])<0){var k=_;_=b,b=k}x[0]=_;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,b,A]):e.push([M,b])}return f}(t,e,f,m,r),v=d(t,g);return y(e,v,r),!!v||f.length>0||m.length>0}},3637:function(t,e,r){\"use strict\";t.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=u(h,s(t,r)),d=i(p,f),m=c(a,d);return l(t,m)};var n=r(6504),i=r(8697),a=r(5572),o=r(7721),s=r(544),l=r(2653),c=r(8987);function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},3642:function(t){t.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},6729:function(t,e,r){\"use strict\";var n=r(3642),i=r(395);function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}t.exports=function(t){var e,r,l,c,u,h,f,p,d,m;if(t||(t={}),p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\"),\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1],e=u.map((function(t){return Math.round(t.index*p)})),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var g=u.map((function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1||(n[3]=d[0]+(d[1]-d[0])*r),n})),y=[];for(m=0;m<e.length-1;++m){c=e[m+1]-e[m],r=g[m],l=g[m+1];for(var v=0;v<c;v++){var x=v/c;y.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}return y.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?y=y.map(o):\"rgbaString\"===f?y=y.map(s):\"float\"===f&&(y=y.map(a)),y}},3140:function(t,e,r){\"use strict\";t.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r);return u===l(t,e,a)?0:u?1:-1}return 0}return 0===c?s>0||l(t,e,a)?-1:1:0===s?c>0||l(t,e,r)?1:-1:i(c-s)}var h=n(t,e,r);return h>0?o>0&&n(t,e,a)>0?1:-1:h<0?o>0||n(t,e,a)>0?1:-1:n(t,e,a)>0||l(t,e,r)?1:-1};var n=r(3250),i=r(8572),a=r(9362),o=r(5382),s=r(8210);function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},8572:function(t){\"use strict\";t.exports=function(t){return t<0?-1:t>0?1:0}},8507:function(t){t.exports=function(t,n){var i=t.length,a=t.length-n.length;if(a)return a;switch(i){case 0:return 0;case 1:return t[0]-n[0];case 2:return t[0]+t[1]-n[0]-n[1]||e(t[0],t[1])-e(n[0],n[1]);case 3:var o=t[0]+t[1],s=n[0]+n[1];if(a=o+t[2]-(s+n[2]))return a;var l=e(t[0],t[1]),c=e(n[0],n[1]);return e(l,t[2])-e(c,n[2])||e(l+t[2],o)-e(c+n[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=n[0],m=n[1],g=n[2],y=n[3];return u+h+f+p-(d+m+g+y)||e(u,h,f,p)-e(d,m,g,y,d)||e(u+h,u+f,u+p,h+f,h+p,f+p)-e(d+m,d+g,d+y,m+g,m+y,g+y)||e(u+h+f,u+h+p,u+f+p,h+f+p)-e(d+m+g,d+m+y,d+g+y,m+g+y);default:for(var v=t.slice().sort(r),x=n.slice().sort(r),_=0;_<i;++_)if(a=v[_]-x[_])return a;return 0}};var e=Math.min;function r(t,e){return t-e}},3788:function(t,e,r){\"use strict\";var n=r(8507),i=r(2419);t.exports=function(t,e){return n(t,e)||i(t)-i(e)}},7352:function(t,e,r){\"use strict\";var n=r(5721),i=r(4750),a=r(2690);t.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;return 0===r?[]:1===r?n(t):2===r?i(t):a(t,r)}},5721:function(t){\"use strict\";t.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},4750:function(t,e,r){\"use strict\";t.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=r(3090)},2690:function(t,e,r){\"use strict\";t.exports=function(t,e){try{return n(t,!0)}catch(o){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];var a=e.length;for(i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(n(a,!0),r)}};var n=r(8954),i=r(3952)},4769:function(t){\"use strict\";t.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},t.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},7642:function(t,e,r){\"use strict\";var n=r(8954),i=r(1682);function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}t.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map((function(t,e){return[t[0],e]}));n.sort((function(t,e){return t[0]-e[0]}));for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}return r&&i.push([-1,i[0][1]],[i[t-1][1],-1]),i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var m=h[d];f[d]=m,p+=m*m}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;var g=new Array(r+s+1),y=new Array(r+s+1),v=(s+1)*(s+1)*c,x=new Array(s+1);for(u=0;u<=s;++u)x[u]=0;for(x[s]=v,g[0]=x.slice(),y[0]=-1,u=0;u<=s;++u)(f=x.slice())[u]=1,g[u+1]=f,y[u+1]=-1;for(u=0;u<r;++u){var _=l[u];g[u+s+1]=_.point,y[u+s+1]=_.index}var b=n(g,!1);if(b=e?b.filter((function(t){for(var e=0,r=0;r<=s;++r){var n=y[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0})):b.filter((function(t){for(var e=0;e<=s;++e){var r=y[t[e]];if(r<0)return!1;t[e]=r}return!0})),1&s)for(u=0;u<b.length;++u)f=(_=b[u])[0],_[0]=_[1],_[1]=f;return b}},2361:function(t){var e=!1;if(\"undefined\"!=typeof Float64Array){var r=new Float64Array(1),i=new Uint32Array(r.buffer);r[0]=1,e=!0,1072693248===i[1]?(t.exports=function(t){return r[0]=t,[i[0],i[1]]},t.exports.pack=function(t,e){return i[0]=t,i[1]=e,r[0]},t.exports.lo=function(t){return r[0]=t,i[0]},t.exports.hi=function(t){return r[0]=t,i[1]}):1072693248===i[0]?(t.exports=function(t){return r[0]=t,[i[1],i[0]]},t.exports.pack=function(t,e){return i[1]=t,i[0]=e,r[0]},t.exports.lo=function(t){return r[0]=t,i[1]},t.exports.hi=function(t){return r[0]=t,i[0]}):e=!1}if(!e){var a=new n(8);t.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},t.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},t.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},t.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}t.exports.sign=function(e){return t.exports.hi(e)>>>31},t.exports.exponent=function(e){return(t.exports.hi(e)<<1>>>21)-1023},t.exports.fraction=function(e){var r=t.exports.lo(e),n=t.exports.hi(e),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},t.exports.denormalized=function(e){return!(2146435072&t.exports.hi(e))}},1338:function(t){\"use strict\";function e(t,r,n){var i=0|t[n];if(i<=0)return[];var a,o=new Array(i);if(n===t.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=e(t,r,n+1);return o}t.exports=function(t,r){switch(void 0===r&&(r=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,r);break;case\"object\":if(\"number\"==typeof t.length)return e(t,r,0)}return[]}},3134:function(t,e,r){\"use strict\";t.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;var o=new Array(e);for(i=0;i<e;++i)o[i]=[];for(i=0;i<r;++i)o[(a=t[i])[0]].push(a[1]),o[a[1]].push(a[0]);for(var s=0;s<e;++s)n(o[s],(function(t,e){return t-e}));return o};var n=r(1682)},5033:function(t){\"use strict\";t.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},9215:function(t,e,r){\"use strict\";t.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:return\"number\"==typeof t?new o(n=l(t),n,0):new o(t,l(t.length),0);case 2:var n;if(\"number\"==typeof e)return new o(t,n=l(t.length),+e);r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=r(4769),i=r(2478);function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var m=e[o],g=e[o+1]-m||1,y=this._scratch[1],v=this._scratch[2],x=this._scratch[3],_=this._scratch[4],b=!0;for(p=0;p<u;++p,--f)y[p]=l[f],x[p]=c[f]*g,v[p]=l[f+u],_[p]=c[f+u]*g,b=b&&y[p]===v[p]&&x[p]===_[p]&&0===x[p];if(b)for(p=0;p<u;++p)s[p]=y[p];else n(y,x,v,_,(t-m)/g,s)}var w=h[0],T=h[1];for(p=0;p<u;++p)s[p]=a(w[p],T[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],m=this._scratch[2],g=this._scratch[3],y=this._scratch[4],v=!0;for(h=0;h<c;++h,--u)d[h]=s[u],g[h]=l[u]*p,m[h]=s[u+c],y[h]=l[u+c]*p,v=v&&d[h]===m[h]&&g[h]===y[h]&&0===g[h];if(v)for(h=0;h<c;++h)o[h]=0;else for(n.derivative(d,g,m,y,(t-f)/p,o),h=0;h<c;++h)o[h]/=p}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);for(this._time.push(t),h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},3840:function(t){\"use strict\";function e(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function r(t){return new e(t._color,t.key,t.value,t.left,t.right,t._count)}function n(t,r){return new e(t,r.key,r.value,r.left,r.right,r._count)}function i(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function a(t,e){this._compare=t,this.root=e}t.exports=function(t){return new a(t||p,null)};var o=a.prototype;function s(t,e){var r;return e.left&&(r=s(t,e.left))?r:(r=t(e.key,e.value))||(e.right?s(t,e.right):void 0)}function l(t,e,r,n){if(e(t,n.key)<=0){var i;if(n.left&&(i=l(t,e,r,n.left)))return i;if(i=r(n.key,n.value))return i}if(n.right)return l(t,e,r,n.right)}function c(t,e,r,n,i){var a,o=r(t,i.key),s=r(e,i.key);if(o<=0){if(i.left&&(a=c(t,e,r,n,i.left)))return a;if(s>0&&(a=n(i.key,i.value)))return a}if(s>0&&i.right)return c(t,e,r,n,i.right)}function u(t,e){this.tree=t,this._stack=e}Object.defineProperty(o,\"keys\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(e)})),t}}),Object.defineProperty(o,\"values\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(r)})),t}}),Object.defineProperty(o,\"length\",{get:function(){return this.root?this.root._count:0}}),o.insert=function(t,r){for(var o=this._compare,s=this.root,l=[],c=[];s;){var u=o(t,s.key);l.push(s),c.push(u),s=u<=0?s.left:s.right}l.push(new e(0,t,r,null,null,1));for(var h=l.length-2;h>=0;--h)s=l[h],c[h]<=0?l[h]=new e(s._color,s.key,s.value,l[h+1],s.right,s._count+1):l[h]=new e(s._color,s.key,s.value,s.left,l[h+1],s._count+1);for(h=l.length-1;h>1;--h){var f=l[h-1];if(s=l[h],1===f._color||1===s._color)break;var p=l[h-2];if(p.left===f)if(f.left===s){if(!(d=p.right)||0!==d._color){p._color=0,p.left=f.right,f._color=1,f.right=p,l[h-2]=f,l[h-1]=s,i(p),i(f),h>=3&&((m=l[h-3]).left===p?m.left=f:m.right=f);break}f._color=1,p.right=n(1,d),p._color=0,h-=1}else{if(!(d=p.right)||0!==d._color){f.right=s.left,p._color=0,p.left=s.right,s._color=1,s.left=f,s.right=p,l[h-2]=s,l[h-1]=f,i(p),i(f),i(s),h>=3&&((m=l[h-3]).left===p?m.left=s:m.right=s);break}f._color=1,p.right=n(1,d),p._color=0,h-=1}else if(f.right===s){if(!(d=p.left)||0!==d._color){p._color=0,p.right=f.left,f._color=1,f.left=p,l[h-2]=f,l[h-1]=s,i(p),i(f),h>=3&&((m=l[h-3]).right===p?m.right=f:m.left=f);break}f._color=1,p.left=n(1,d),p._color=0,h-=1}else{var d;if(!(d=p.left)||0!==d._color){var m;f.left=s.right,p._color=0,p.right=s.left,s._color=1,s.right=f,s.left=p,l[h-2]=s,l[h-1]=f,i(p),i(f),i(s),h>=3&&((m=l[h-3]).right===p?m.right=s:m.left=s);break}f._color=1,p.left=n(1,d),p._color=0,h-=1}}return l[0]._color=1,new a(o,l[0])},o.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return s(t,this.root);case 2:return l(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return c(e,r,this._compare,t,this.root)}},Object.defineProperty(o,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new u(this,t)}}),Object.defineProperty(o,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new u(this,t)}}),o.at=function(t){if(t<0)return new u(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new u(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new u(this,[])},o.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new u(this,n)},o.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new u(this,n)},o.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new u(this,n)},o.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new u(this,n)},o.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new u(this,n);r=i<=0?r.left:r.right}return new u(this,[])},o.remove=function(t){var e=this.find(t);return e?e.remove():this},o.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var h=u.prototype;function f(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function p(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(h,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(h,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),h.clone=function(){return new u(this.tree,this._stack.slice())},h.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var o=new Array(t.length),s=t[t.length-1];o[o.length-1]=new e(s._color,s.key,s.value,s.left,s.right,s._count);for(var l=t.length-2;l>=0;--l)(s=t[l]).left===t[l+1]?o[l]=new e(s._color,s.key,s.value,o[l+1],s.right,s._count):o[l]=new e(s._color,s.key,s.value,s.left,o[l+1],s._count);if((s=o[o.length-1]).left&&s.right){var c=o.length;for(s=s.left;s.right;)o.push(s),s=s.right;var u=o[c-1];for(o.push(new e(s._color,u.key,u.value,s.left,s.right,s._count)),o[c-1].key=s.key,o[c-1].value=s.value,l=o.length-2;l>=c;--l)s=o[l],o[l]=new e(s._color,s.key,s.value,s.left,o[l+1],s._count);o[c-1].left=o[c]}if(0===(s=o[o.length-1])._color){var h=o[o.length-2];for(h.left===s?h.left=null:h.right===s&&(h.right=null),o.pop(),l=0;l<o.length;++l)o[l]._count--;return new a(this.tree._compare,o[0])}if(s.left||s.right){for(s.left?f(s,s.left):s.right&&f(s,s.right),s._color=1,l=0;l<o.length-1;++l)o[l]._count--;return new a(this.tree._compare,o[0])}if(1===o.length)return new a(this.tree._compare,null);for(l=0;l<o.length;++l)o[l]._count--;var p=o[o.length-2];return function(t){for(var e,a,o,s,l=t.length-1;l>=0;--l){if(e=t[l],0===l)return void(e._color=1);if((a=t[l-1]).left===e){if((o=a.right).right&&0===o.right._color)return s=(o=a.right=r(o)).right=r(o.right),a.right=o.left,o.left=a,o.right=s,o._color=a._color,e._color=1,a._color=1,s._color=1,i(a),i(o),l>1&&((c=t[l-2]).left===a?c.left=o:c.right=o),void(t[l-1]=o);if(o.left&&0===o.left._color)return s=(o=a.right=r(o)).left=r(o.left),a.right=s.left,o.left=s.right,s.left=a,s.right=o,s._color=a._color,a._color=1,o._color=1,e._color=1,i(a),i(o),i(s),l>1&&((c=t[l-2]).left===a?c.left=s:c.right=s),void(t[l-1]=s);if(1===o._color){if(0===a._color)return a._color=1,void(a.right=n(0,o));a.right=n(0,o);continue}o=r(o),a.right=o.left,o.left=a,o._color=a._color,a._color=0,i(a),i(o),l>1&&((c=t[l-2]).left===a?c.left=o:c.right=o),t[l-1]=o,t[l]=a,l+1<t.length?t[l+1]=e:t.push(e),l+=2}else{if((o=a.left).left&&0===o.left._color)return s=(o=a.left=r(o)).left=r(o.left),a.left=o.right,o.right=a,o.left=s,o._color=a._color,e._color=1,a._color=1,s._color=1,i(a),i(o),l>1&&((c=t[l-2]).right===a?c.right=o:c.left=o),void(t[l-1]=o);if(o.right&&0===o.right._color)return s=(o=a.left=r(o)).right=r(o.right),a.left=s.right,o.right=s.left,s.right=a,s.left=o,s._color=a._color,a._color=1,o._color=1,e._color=1,i(a),i(o),i(s),l>1&&((c=t[l-2]).right===a?c.right=s:c.left=s),void(t[l-1]=s);if(1===o._color){if(0===a._color)return a._color=1,void(a.left=n(0,o));a.left=n(0,o);continue}var c;o=r(o),a.left=o.right,o.right=a,o._color=a._color,a._color=0,i(a),i(o),l>1&&((c=t[l-2]).right===a?c.right=o:c.left=o),t[l-1]=o,t[l]=a,l+1<t.length?t[l+1]=e:t.push(e),l+=2}}}(o),p.left===s?p.left=null:p.right=null,new a(this.tree._compare,o[0])},Object.defineProperty(h,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(h,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(h,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),h.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(h,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),h.update=function(t){var r=this._stack;if(0===r.length)throw new Error(\"Can't update empty node!\");var n=new Array(r.length),i=r[r.length-1];n[n.length-1]=new e(i._color,i.key,t,i.left,i.right,i._count);for(var o=r.length-2;o>=0;--o)(i=r[o]).left===r[o+1]?n[o]=new e(i._color,i.key,i.value,n[o+1],i.right,i._count):n[o]=new e(i._color,i.key,i.value,i.left,n[o+1],i._count);return new a(this.tree._compare,n[0])},h.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(h,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},3837:function(t,e,r){\"use strict\";t.exports=function(t,e){var r=new p(t);return r.update(e),r};var n=r(4935),i=r(501),a=r(5304),o=r(6429),s=r(6444),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),c=ArrayBuffer,u=DataView;function h(t){return Array.isArray(t)||function(t){return c.isView(t)&&!(t instanceof u)}(t)}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickFontStyle=[\"normal\",\"normal\",\"normal\"],this.tickFontWeight=[\"normal\",\"normal\",\"normal\"],this.tickFontVariant=[\"normal\",\"normal\",\"normal\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.labelFontStyle=[\"normal\",\"normal\",\"normal\"],this.labelFontWeight=[\"normal\",\"normal\",\"normal\"],this.labelFontVariant=[\"normal\",\"normal\",\"normal\"],this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var d=p.prototype;function m(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}d.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?h(a)&&h(a[0]):h(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,(function(t){if(h(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]})),u=!1,f=!1;if(\"bounds\"in t)for(var p=t.bounds,d=0;d<2;++d)for(var m=0;m<3;++m)p[d][m]!==this.bounds[d][m]&&(f=!0),this.bounds[d][m]=p[d][m];if(\"ticks\"in t)for(r=t.ticks,u=!0,this.autoTicks=!1,d=0;d<3;++d)this.tickSpacing[d]=0;else a(\"tickSpacing\")&&(this.autoTicks=!0,f=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),f=!0,u=!0,this._firstInit=!1),f&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(d=0;d<3;++d)r[d].sort((function(t,e){return t.x-e.x}));s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),l(\"tickFontStyle\")&&(u=!0),l(\"tickFontWeight\")&&(u=!0),l(\"tickFontVariant\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),l(\"labelFontStyle\")&&(g=!0),l(\"labelFontWeight\")&&(g=!0),l(\"labelFontVariant\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\");var y=[{family:this.labelFont[0],style:this.labelFontStyle[0],weight:this.labelFontWeight[0],variant:this.labelFontVariant[0]},{family:this.labelFont[1],style:this.labelFontStyle[1],weight:this.labelFontWeight[1],variant:this.labelFontVariant[1]},{family:this.labelFont[2],style:this.labelFontStyle[2],weight:this.labelFontWeight[2],variant:this.labelFontVariant[2]}],v=[{family:this.tickFont[0],style:this.tickFontStyle[0],weight:this.tickFontWeight[0],variant:this.tickFontVariant[0]},{family:this.tickFont[1],style:this.tickFontStyle[1],weight:this.tickFontWeight[1],variant:this.tickFontVariant[1]},{family:this.tickFont[2],style:this.tickFontStyle[2],weight:this.tickFontWeight[2],variant:this.tickFontVariant[2]}];this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,y,this.ticks,v):this._text=n(this.gl,this.bounds,this.labels,y,this.ticks,v),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var g=[new m,new m,new m];function y(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var v=[0,0,0],x={model:l,view:l,projection:l,_ortho:!1};d.isOpaque=function(){return!0},d.isTransparent=function(){return!1},d.drawTransparent=function(t){};var _=[0,0,0],b=[0,0,0],w=[0,0,0];d.draw=function(t){t=t||x;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,c=o(r,n,i,a,s),u=c.cubeEdges,h=c.axis,p=n[12],d=n[13],m=n[14],T=n[15],k=(s?2:1)*this.pixelRatio*(i[3]*p+i[7]*d+i[11]*m+i[15]*T)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=u[A],this.lastCubeProps.axis[A]=h[A];var M=g;for(A=0;A<3;++A)y(g[A],A,this.bounds,u,h);e=this.gl;var S,E,C,L=v;for(A=0;A<3;++A)this.backgroundEnable[A]?L[A]=h[A]:L[A]=0;for(this._background.draw(r,n,i,a,L,this.backgroundColor),this._lines.bind(r,n,i,this),A=0;A<3;++A){var I=[0,0,0];h[A]>0?I[A]=a[1][A]:I[A]=a[0][A];for(var P=0;P<2;++P){var z=(A+1+P)%3,O=(A+1+(1^P))%3;this.gridEnable[z]&&this._lines.drawGrid(z,O,this.bounds,I,this.gridColor[z],this.gridWidth[z]*this.pixelRatio)}for(P=0;P<2;++P)z=(A+1+P)%3,O=(A+1+(1^P))%3,this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(z,O,this.bounds,I,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var D=f(_,M[A].primalMinor),R=f(b,M[A].mirrorMinor),F=this.lineTickLength;for(P=0;P<3;++P){var B=k/r[5*P];D[P]*=F[P]*B,R[P]*=F[P]*B}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,D,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,R,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}function N(t){(C=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0||a>0&&l<0||a<0&&l>0||a<0&&l<0?N(n):(o>0&&s>0||o>0&&s<0||o<0&&s>0||o<0&&s<0)&&N(i)}for(this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio),A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=f(w,M[A].primalOffset);for(P=0;P<3;++P)this.lineTickEnable[A]&&(q[P]+=k*U[P]*Math.max(this.lineTickLength[P],0)/r[5*P]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){for(-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,E=1,\"auto\"===(S=[this.tickAlign[A],.5,E])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),C=[0,0,0],j(A,U,V),P=0;P<3;++P)q[P]+=k*U[P]*this.tickPad[P]/r[5*P];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,C,S)}if(this.labelEnable[A]){for(E=0,C=[0,0,0],this.labels[A].length>4&&(N(A),E=1),\"auto\"===(S=[this.labelAlign[A],.5,E])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),P=0;P<3;++P)q[P]+=k*U[P]*this.labelPad[P]/r[5*P];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],C,S)}}this._text.unbind()},d.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},5304:function(t,e,r){\"use strict\";t.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var m=-1;m<=1;m+=2)h[u]=m,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var g=c;c=u,u=g}var y=n(t,new Float32Array(e)),v=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:y,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:y,type:t.FLOAT,size:3,offset:12,stride:24}],v),_=a(t);return _.attributes.position.location=0,_.attributes.normal.location=1,new o(t,y,x,_)};var n=r(2762),i=r(8116),a=r(1879).bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},6429:function(t,e,r){\"use strict\";t.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var v=0,x=0;x<2;++x){u[2]=a[x][2];for(var _=0;_<2;++_){u[1]=a[_][1];for(var b=0;b<2;++b)u[0]=a[b][0],f(l[v],u,s),v+=1}}var w=-1;for(x=0;x<8;++x){for(var T=l[x][3],k=0;k<3;++k)c[x][k]=l[x][k]/T;p&&(c[x][2]*=-1),T<0&&(w<0||c[x][2]<c[w][2])&&(w=x)}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var I=(z=L<<A)+(L<<M)+(1-L<<S),P=z+(1-L<<M)+(L<<S);o(c[z],c[I],c[P],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(L=0;L<2;++L){I=(z=L<<A)+(L<<M)+(1-L<<S),P=z+(1-L<<M)+(L<<S);var z,O=d([l[z],l[I],l[P],l[z+(1<<M)+(1<<S)]]);L?E=O:C=O}C>E&&(w|=1<<A)}}}var D=7^w,R=-1;for(x=0;x<8;++x)x!==w&&x!==D&&(R<0||c[R][1]>c[x][1])&&(R=x);var F=-1;for(x=0;x<3;++x)(N=R^1<<x)!==w&&N!==D&&(F<0&&(F=N),(S=c[N])[0]<c[F][0]&&(F=N));var B=-1;for(x=0;x<3;++x){var N;(N=R^1<<x)!==w&&N!==D&&N!==F&&(B<0&&(B=N),(S=c[N])[0]>c[B][0]&&(B=N))}var j=m;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^B)]=R&B;var U=7^B;U===w||U===D?(U=7^F,j[n.log2(B^U)]=U&B):j[n.log2(F^U)]=U&F;var V=g,q=w;for(A=0;A<3;++A)V[A]=q&1<<A?-1:1;return y};var n=r(8828),i=r(6760),a=r(5202),o=r(3250),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var m=[1,1,1],g=[0,0,0],y={cubeEdges:m,axis:g}},501:function(t,e,r){\"use strict\";t.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var m=+r[h][d].x;o.push(m,0,1,m,1,1,m,0,-1,m,0,-1,m,1,1,m,1,-1)}var g=o.length/3|0;s[h]=f,l[h]=g-f,f=o.length/3|0;for(var y=0;y<r[h].length;++y)m=+r[h][y].x,o.push(m,0,1,m,1,1,m,0,-1,m,0,-1,m,1,1,m,1,-1);g=o.length/3|0,c[h]=f,u[h]=g-f}var v=n(t,new Float32Array(o)),x=i(t,[{buffer:v,type:t.FLOAT,size:3,stride:0,offset:0}]),_=a(t);return _.attributes.position.location=0,new p(t,v,x,_,l,s,u,c)};var n=r(2762),i=r(8116),a=r(1879).n,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var m=h(l);m[t]=1,this.shader.uniforms.screenAxis=m,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},1879:function(t,e,r){\"use strict\";var n=r(3236),i=r(9405),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * (view * (model * vec4(p, 1.0)));\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);e.n=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * (view * (model * vec4(p, 1.0)));\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\\n\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);e.Q=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * (view * (model * vec4(nPosition, 1.0)));\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\\n\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);e.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},4935:function(t,e,r){\"use strict\";t.exports=function(t,e,r,i,o,l){var c=n(t),h=a(t,[{buffer:c,size:3}]),f=s(t);f.attributes.position.location=0;var p=new u(t,f,c,h);return p.update(e,r,i,o,l),p};var n=r(2762),a=r(8116),o=r(4359),s=r(1879).Q,l=window||i.global||{},c=l.__TEXT_CACHE||{};function u(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}l.__TEXT_CACHE={};var h=u.prototype,f=[0,0];h.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,f[0]=this.gl.drawingBufferWidth,f[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=f},h.unbind=function(){this.vao.unbind()},h.update=function(t,e,r,n,i){var a=[];function s(t,e,r,n,i,s){var l=[r.style,r.weight,r.variant,r.family].join(\"_\"),u=c[l];u||(u=c[l]={});var h=u[e];h||(h=u[e]=function(t,e){try{return o(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r.family,fontStyle:r.style,fontWeight:r.weight,fontVariant:r.variant,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var f=(n||12)/12,p=h.positions,d=h.cells,m=0,g=d.length;m<g;++m)for(var y=d[m],v=2;v>=0;--v){var x=p[y[v]];a.push(f*x[0],-f*x[1],t)}}for(var l=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=a.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(a.length/3|0)-h[d],l[d]=a.length/3|0;for(var m=0;m<n[d].length;++m)if(n[d][m].text){var g={family:n[d][m].font||i[d].family,style:i[d].fontStyle||i[d].style,weight:i[d].fontWeight||i[d].weight,variant:i[d].fontVariant||i[d].variant};s(n[d][m].x,n[d][m].text,g,n[d][m].fontSize||12,1.25,p)}u[d]=(a.length/3|0)-l[d]}this.buffer.update(a),this.tickOffset=l,this.tickCount=u,this.labelOffset=h,this.labelCount=f},h.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},h.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},h.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}},6444:function(t,e){\"use strict\";function r(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}e.create=function(t,e){for(var n=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:r(e[i],o)});for(o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:r(e[i],o)});n.push(a)}return n},e.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},5445:function(t,e,r){\"use strict\";t.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,y=e.projection||c,v=e._ortho||!1,x=t.bounds,_=(h=h||a(f,p,y,x,v)).axis;o(u,p,f),o(u,y,u);for(var b=m,w=0;w<3;++w)b[w].lo=1/0,b[w].hi=-1/0,b[w].pixelsPerDataUnit=1/0;var T=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var A=(k+1)%3,M=(k+2)%3,S=g;t:for(w=0;w<2;++w){var E=[];if(_[k]<0!=!!w){S[k]=x[w][k];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}var I=v?5:4;for(C=I;C===I;++C){if(0===E.length)continue t;E=i.positive(E,T[C])}for(C=0;C<E.length;++C){M=E[C];var P=d(g,u,M,r,l);for(L=0;L<3;++L)b[L].lo=Math.min(b[L].lo,M[L]),b[L].hi=Math.max(b[L].hi,M[L]),L!==k&&(b[L].pixelsPerDataUnit=Math.min(b[L].pixelsPerDataUnit,Math.abs(P[L])))}}}}return b};var n=r(5033),i=r(5202),a=r(6429),o=r(6760),s=r(5665),l=r(5352),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var m=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],g=[0,0,0]},2762:function(t,e,r){\"use strict\";var n=r(1888),i=r(5298),a=r(9618),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&void 0!==t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER&&(r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\"),r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},t.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},6405:function(t,e,r){\"use strict\";var n=r(2931);t.exports=function(t,e){var r=t.positions,i=t.vectors,a={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),a;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=null,d=null,m=[],g=1/0,y=!1,v=\"raw\"===t.coneSizemode,x=0;x<r.length;x++){var _=r[x];s=Math.min(_[0],s),l=Math.max(_[0],l),c=Math.min(_[1],c),u=Math.max(_[1],u),h=Math.min(_[2],h),f=Math.max(_[2],f);var b=i[x];if(n.length(b)>o&&(o=n.length(b)),x&&!v){var w=2*n.distance(p,_)/(n.length(d)+n.length(b));w?(g=Math.min(g,w),y=!1):y=!0}y||(p=_,d=b),m.push(b)}var T=[s,c,h],k=[l,u,f];e&&(e[0]=T,e[1]=k),0===o&&(o=1);var A=1/o;isFinite(g)||(g=1),a.vectorScale=g;var M=t.coneSize||(v?1:.5);t.absoluteConeSize&&(M=t.absoluteConeSize*A),a.coneScale=M,x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],I=m[x],P=n.length(I)*A,z=0;z<8;z++){a.positions.push([E,C,L,S++]),a.positions.push([E,C,L,S++]),a.positions.push([E,C,L,S++]),a.positions.push([E,C,L,S++]),a.positions.push([E,C,L,S++]),a.positions.push([E,C,L,S++]),a.vectors.push(I),a.vectors.push(I),a.vectors.push(I),a.vectors.push(I),a.vectors.push(I),a.vectors.push(I),a.vertexIntensity.push(P,P,P),a.vertexIntensity.push(P,P,P);var O=a.positions.length;a.cells.push([O-6,O-5,O-4],[O-3,O-2,O-1])}return a};var i=r(614);t.exports.createMesh=r(9060),t.exports.createConeMesh=function(e,r){return t.exports.createMesh(e,r,{shaders:i,traceType:\"cone\"})}},9060:function(t,e,r){\"use strict\";var n=r(9405),i=r(2762),a=r(8116),o=r(7766),s=r(6760),l=r(7608),c=r(9618),u=r(6729),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e,r,n,i,a,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=h,this._view=h,this._projection=h,this._resolution=[1,1]}var p=f.prototype;p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],o=[],s=[],l=[],h=[];this.cells=r,this.positions=n,this.vectors=i;var f=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,m=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],m=+t.vertexIntensityBounds[1];else for(var g=0;g<p.length;++g){var y=p[g];d=Math.min(d,y),m=Math.max(m,y)}else for(g=0;g<n.length;++g)y=n[g][2],d=Math.min(d,y),m=Math.max(m,y);for(this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],g=0;g<n.length;++g)for(var v=n[g],x=0;x<3;++x)!isNaN(v[x])&&isFinite(v[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],v[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],v[x]));var _=0;t:for(g=0;g<r.length;++g){var b=r[g];if(3===b.length){for(x=0;x<3;++x){v=n[T=b[x]];for(var w=0;w<3;++w)if(isNaN(v[w])||!isFinite(v[w]))continue t}for(x=0;x<3;++x){var T;v=n[T=b[2-x]],a.push(v[0],v[1],v[2],v[3]);var k=i[T];o.push(k[0],k[1],k[2],k[3]||0);var A,M=f;3===M.length?s.push(M[0],M[1],M[2],1):s.push(M[0],M[1],M[2],M[3]),A=p?[(p[T]-d)/(m-d),0]:[(v[2]-d)/(m-d),0],l.push(A[0],A[1]),h.push(g)}_+=1}}this.triangleCount=_,this.trianglePositions.update(a),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(h))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,i=t.projection||h,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:i,inverseModel:h.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);for(s(u,c.view,c.model),s(u,c.projection,u),l(u,u),o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/f}if(this.triangleCount>0){var m=this.triShader;m.bind(),m.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,i=t.projection||h,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),i={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return\"cone\"===this.traceType?i.index=Math.floor(r[1]/48):\"streamtube\"===this.traceType&&(i.intensity=this.intensity[r[1]],i.velocity=this.vectors[r[1]].slice(0,3),i.divergence=this.vectors[r[1]][3],i.index=e),i},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},t.exports=function(t,e,r){var s=r.shaders;1===arguments.length&&(t=(e=t).gl);var l=function(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}(t,s),u=function(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}(t,s),h=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));h.generateMipmap(),h.minFilter=t.LINEAR_MIPMAP_LINEAR,h.magFilter=t.LINEAR;var p=i(t),d=i(t),m=i(t),g=i(t),y=i(t),v=new f(t,h,l,u,p,d,y,m,g,a(t,[{buffer:p,type:t.FLOAT,size:4},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:g,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:4}]),r.traceType||\"cone\");return v.update(e),v}},614:function(t,e,r){var n=r(3236),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, coneScale, coneOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float vectorScale, coneScale, coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * (view * conePosition);\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);e.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},e.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},737:function(t){t.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34e3:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},5171:function(t,e,r){var n=r(737);t.exports=function(t){return n[t]}},9165:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=r(2762),i=r(8116),a=r(3436),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p,d=n[l],m=e[s];if(Array.isArray(m[0])&&(m=e[l]),3===m.length?m=[m[0],m[1],m[2],1]:4===m.length&&(m=[m[0],m[1],m[2],m[3]],!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0)),!isNaN(d[0][s])&&!isNaN(d[1][s]))d[0][s]<0&&((p=u.slice())[s]+=d[0][s],i.push(u[0],u[1],u[2],m[0],m[1],m[2],m[3],0,0,0,p[0],p[1],p[2],m[0],m[1],m[2],m[3],0,0,0),c(this.bounds,p),o+=2+h(i,p,m,s)),d[1][s]>0&&((p=u.slice())[s]+=d[1][s],i.push(u[0],u[1],u[2],m[0],m[1],m[2],m[3],0,0,0,p[0],p[1],p[2],m[0],m[1],m[2],m[3],0,0,0),c(this.bounds,p),o+=2+h(i,p,m,s))}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},3436:function(t,e,r){\"use strict\";var n=r(3236),i=r(9405),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * (view * worldPosition);\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);t.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},2260:function(t,e,r){\"use strict\";var n=r(7766);t.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");if(!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c),Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]),\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var m=!0;\"depth\"in n&&(m=!!n.depth);var g=!1;return\"stencil\"in n&&(g=!!n.stencil),new d(t,e,r,f,h,m,g,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var m=this,g=[0|e,0|r];Object.defineProperties(g,{0:{get:function(){return m._shape[0]},set:function(t){return m.width=t}},1:{get:function(){return m._shape[1]},set:function(t){return m.height=t}}}),this._shapeVector=g,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,m=t._useDepth,g=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var y=0;y<o;++y)t.color[y]=f(r,i,a,g,r.RGBA,r.COLOR_ATTACHMENT0+y);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var v=r.getExtension(\"WEBGL_depth_texture\");v?d?t.depth=f(r,i,a,v.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):m&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):m&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):m?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),y=0;y<t.color.length;++y)t.color[y].dispose(),t.color[y]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var m=d.prototype;function g(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(m,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return g(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return g(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,g(this,this._shape[0],t),t},enumerable:!1}}),m.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},m.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},2992:function(t,e,r){var n=r(3387).sprintf,i=r(5171),a=r(1848),o=r(1085);t.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var m=parseInt(d.split(\":\")[2]);if(isNaN(m))throw new Error(n(\"Could not parse error: %s\",d));f[m]=d}}var g=o(e).split(\"\\n\");for(p=0;p<g.length;p++)if((f[p+3]||f[p+2]||f[p+1])&&(c+=g[p]+\"\\n\",f[p+1])){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}return{long:c.trim(),short:u.trim()}}},2510:function(t,e,r){\"use strict\";t.exports=function(t,e){var r=t.gl,n=new c(t,o(r,l.vertex,l.fragment),o(r,l.pickVertex,l.pickFragment),s(r),s(r),s(r),s(r));return n.update(e),t.addObject(n),n};var n=r(2478),i=r(7762),a=r(1888),o=r(9405),s=r(2762),l=r(6768);function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var m=i.attributes;return this.positionBuffer.bind(),m.position.pointer(),this.weightBuffer.bind(),m.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),m.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]),l=!1!==t.zsmooth;this.xData=r,this.yData=o;var c,u,h,p,d=t.colorLevels||[0],m=t.colorValues||[0,0,0,1],g=d.length,y=this.bounds;l?(c=y[0]=r[0],u=y[1]=o[0],h=y[2]=r[r.length-1],p=y[3]=o[o.length-1]):(c=y[0]=r[0]+(r[1]-r[0])/2,u=y[1]=o[0]+(o[1]-o[0])/2,h=y[2]=r[r.length-1]+(r[r.length-1]-r[r.length-2])/2,p=y[3]=o[o.length-1]+(o[o.length-1]-o[o.length-2])/2);var v=1/(h-c),x=1/(p-u),_=e[0],b=e[1];this.shape=[_,b];var w=(l?(_-1)*(b-1):_*b)*(f.length>>>1);this.numVertices=w;for(var T=a.mallocUint8(4*w),k=a.mallocFloat32(2*w),A=a.mallocUint8(2*w),M=a.mallocUint32(w),S=0,E=l?_-1:_,C=l?b-1:b,L=0;L<C;++L){var I,P;l?(I=x*(o[L]-u),P=x*(o[L+1]-u)):(I=L<b-1?x*(o[L]-(o[L+1]-o[L])/2-u):x*(o[L]-(o[L]-o[L-1])/2-u),P=L<b-1?x*(o[L]+(o[L+1]-o[L])/2-u):x*(o[L]+(o[L]-o[L-1])/2-u));for(var z=0;z<E;++z){var O,D;l?(O=v*(r[z]-c),D=v*(r[z+1]-c)):(O=z<_-1?v*(r[z]-(r[z+1]-r[z])/2-c):v*(r[z]-(r[z]-r[z-1])/2-c),D=z<_-1?v*(r[z]+(r[z+1]-r[z])/2-c):v*(r[z]+(r[z]-r[z-1])/2-c));for(var R=0;R<f.length;R+=2){var F,B,N,j,U=f[R],V=f[R+1],q=s[l?(L+V)*_+(z+U):L*_+z],H=n.le(d,q);if(H<0)F=m[0],B=m[1],N=m[2],j=m[3];else if(H===g-1)F=m[4*g-4],B=m[4*g-3],N=m[4*g-2],j=m[4*g-1];else{var G=(q-d[H])/(d[H+1]-d[H]),Z=1-G,W=4*H,Y=4*(H+1);F=Z*m[W]+G*m[Y],B=Z*m[W+1]+G*m[Y+1],N=Z*m[W+2]+G*m[Y+2],j=Z*m[W+3]+G*m[Y+3]}T[4*S]=255*F,T[4*S+1]=255*B,T[4*S+2]=255*N,T[4*S+3]=255*j,k[2*S]=.5*O+.5*D,k[2*S+1]=.5*I+.5*P,A[2*S]=U,A[2*S+1]=V,M[S]=L*_+z,S+=1}}}this.positionBuffer.update(k),this.weightBuffer.update(A),this.colorBuffer.update(T),this.idBuffer.update(M),a.free(k),a.free(T),a.free(A),a.free(M)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},6768:function(t,e,r){\"use strict\";var n=r(3236);t.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},7319:function(t,e,r){var n=r(3236),i=r(9405),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * (view * (model * vec4(p, 1.0)));\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\\nvec4 packFloat(float v) {\\n  float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  float e = floor(log2(av));\\n  float m = av * pow(2.0, -e) - 1.0;\\n\\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n\\n  //Unpack exponent\\n  float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0;\\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];e.createShader=function(t){return i(t,a,o,null,l)},e.createPickShader=function(t){return i(t,a,s,null,l)}},5714:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=h(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=f(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=a(e,u);d.wrap=e.REPEAT;var m=new y(e,r,o,s,l,d);return m.update(t),m};var n=r(2762),i=r(8116),a=r(7766),o=new Uint8Array(4),s=new Float32Array(o.buffer),l=r(2478),c=r(9618),u=r(7319),h=u.createShader,f=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function m(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function y(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var v=y.prototype;v.isTransparent=function(){return this.hasAlpha},v.isOpaque=function(){return!this.hasAlpha},v.pickSlots=1,v.setPickBase=function(t){this.pickId=t},v.drawTransparent=v.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:m(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},v.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:m(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},v.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],s=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var p=t.color||t.colors||[0,0,0,1],m=t.lineWidth||1,g=!1;t:for(e=1;e<f.length;++e){var y,v,x,_=f[e-1],b=f[e];for(a.push(s),o.push(_.slice()),r=0;r<3;++r){if(isNaN(_[r])||isNaN(b[r])||!isFinite(_[r])||!isFinite(b[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,g=!0}continue t}h[0][r]=Math.min(h[0][r],_[r],b[r]),h[1][r]=Math.max(h[1][r],_[r],b[r])}Array.isArray(p[0])?(y=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],v=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):y=v=p,3===y.length&&(y=[y[0],y[1],y[2],1]),3===v.length&&(v=[v[0],v[1],v[2],1]),!this.hasAlpha&&y[3]<1&&(this.hasAlpha=!0),x=Array.isArray(m)?m.length>e-1?m[e-1]:m.length>0?m[m.length-1]:[0,0,0,1]:m;var T=s;if(s+=d(_,b),g){for(r=0;r<2;++r)i.push(_[0],_[1],_[2],b[0],b[1],b[2],T,x,y[0],y[1],y[2],y[3]);u+=2,g=!1}i.push(_[0],_[1],_[2],b[0],b[1],b[2],T,x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],T,-x,y[0],y[1],y[2],y[3],b[0],b[1],b[2],_[0],_[1],_[2],s,-x,v[0],v[1],v[2],v[3],b[0],b[1],b[2],_[0],_[1],_[2],s,x,v[0],v[1],v[2],v[3]),u+=4}}if(this.buffer.update(i),a.push(s),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var k=t.dashes.slice();for(k.unshift(0),e=1;e<k.length;++e)k[e]=k[e-1]+k[e];var A=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&l.le(k,k[k.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},v.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},v.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=0,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2]),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-a,u=[0,0,0],h=0;h<3;++h)u[h]=c*n[h]+a*i[h];var f=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,u,f,this.points[f])}},1903:function(t){t.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},6864:function(t){t.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},9921:function(t){t.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],m=t[14],g=t[15];return(e*o-r*a)*(h*g-f*m)-(e*s-n*a)*(u*g-f*d)+(e*l-i*a)*(u*m-h*d)+(r*s-n*o)*(c*g-f*p)-(r*l-i*o)*(c*m-h*p)+(n*l-i*s)*(c*d-u*p)}},7399:function(t){t.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,m=a*o,g=a*s,y=a*l;return t[0]=1-h-d,t[1]=u+y,t[2]=f-g,t[3]=0,t[4]=u-y,t[5]=1-c-d,t[6]=p+m,t[7]=0,t[8]=f+g,t[9]=p-m,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},6743:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,m=a*c,g=o*s,y=o*l,v=o*c;return t[0]=1-(p+m),t[1]=h+v,t[2]=f-y,t[3]=0,t[4]=h-v,t[5]=1-(u+m),t[6]=d+g,t[7]=0,t[8]=f+y,t[9]=d-g,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},7894:function(t){t.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},7608:function(t){t.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],m=e[13],g=e[14],y=e[15],v=r*s-n*o,x=r*l-i*o,_=r*c-a*o,b=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*m-h*d,A=u*g-f*d,M=u*y-p*d,S=h*g-f*m,E=h*y-p*m,C=f*y-p*g,L=v*C-x*E+_*S+b*M-w*A+T*k;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(m*T-g*w+y*b)*L,t[3]=(f*w-h*T-p*b)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(g*_-d*T-y*x)*L,t[7]=(u*T-f*_+p*x)*L,t[8]=(o*E-s*M+c*k)*L,t[9]=(n*M-r*E-a*k)*L,t[10]=(d*w-m*_+y*v)*L,t[11]=(h*_-u*w-p*v)*L,t[12]=(s*A-o*S-l*k)*L,t[13]=(r*S-n*A+i*k)*L,t[14]=(m*x-d*b-g*v)*L,t[15]=(u*b-h*x+f*v)*L,t):null}},6582:function(t,e,r){var n=r(7894);t.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,m=e[0],g=e[1],y=e[2],v=i[0],x=i[1],_=i[2],b=r[0],w=r[1],T=r[2];return Math.abs(m-b)<1e-6&&Math.abs(g-w)<1e-6&&Math.abs(y-T)<1e-6?n(t):(h=m-b,f=g-w,p=y-T,a=x*(p*=d=1/Math.sqrt(h*h+f*f+p*p))-_*(f*=d),o=_*(h*=d)-v*p,s=v*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0),l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0),t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*m+o*g+s*y),t[13]=-(l*m+c*g+u*y),t[14]=-(h*m+f*g+p*y),t[15]=1,t)}},6760:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],m=e[12],g=e[13],y=e[14],v=e[15],x=r[0],_=r[1],b=r[2],w=r[3];return t[0]=x*n+_*s+b*h+w*m,t[1]=x*i+_*l+b*f+w*g,t[2]=x*a+_*c+b*p+w*y,t[3]=x*o+_*u+b*d+w*v,x=r[4],_=r[5],b=r[6],w=r[7],t[4]=x*n+_*s+b*h+w*m,t[5]=x*i+_*l+b*f+w*g,t[6]=x*a+_*c+b*p+w*y,t[7]=x*o+_*u+b*d+w*v,x=r[8],_=r[9],b=r[10],w=r[11],t[8]=x*n+_*s+b*h+w*m,t[9]=x*i+_*l+b*f+w*g,t[10]=x*a+_*c+b*p+w*y,t[11]=x*o+_*u+b*d+w*v,x=r[12],_=r[13],b=r[14],w=r[15],t[12]=x*n+_*s+b*h+w*m,t[13]=x*i+_*l+b*f+w*g,t[14]=x*a+_*c+b*p+w*y,t[15]=x*o+_*u+b*d+w*v,t}},4040:function(t){t.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},4772:function(t){t.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},6079:function(t){t.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S,E=n[0],C=n[1],L=n[2],I=Math.sqrt(E*E+C*C+L*L);return Math.abs(I)<1e-6?null:(E*=I=1/I,C*=I,L*=I,i=Math.sin(r),o=1-(a=Math.cos(r)),s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],m=e[8],g=e[9],y=e[10],v=e[11],x=E*E*o+a,_=C*E*o+L*i,b=L*E*o-C*i,w=E*C*o-L*i,T=C*C*o+a,k=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*_+m*b,t[1]=l*x+f*_+g*b,t[2]=c*x+p*_+y*b,t[3]=u*x+d*_+v*b,t[4]=s*w+h*T+m*k,t[5]=l*w+f*T+g*k,t[6]=c*w+p*T+y*k,t[7]=u*w+d*T+v*k,t[8]=s*A+h*M+m*S,t[9]=l*A+f*M+g*S,t[10]=c*A+p*M+y*S,t[11]=u*A+d*M+v*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t)}},5567:function(t){t.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},2408:function(t){t.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},7089:function(t){t.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},2504:function(t){t.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},7656:function(t){t.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,m=r[0],g=r[1],y=r[2];return e===t?(t[12]=e[0]*m+e[4]*g+e[8]*y+e[12],t[13]=e[1]*m+e[5]*g+e[9]*y+e[13],t[14]=e[2]*m+e[6]*g+e[10]*y+e[14],t[15]=e[3]*m+e[7]*g+e[11]*y+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*m+s*g+h*y+e[12],t[13]=i*m+l*g+f*y+e[13],t[14]=a*m+c*g+p*y+e[14],t[15]=o*m+u*g+d*y+e[15]),t}},5665:function(t){t.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},7626:function(t,e,r){\"use strict\";var n=r(2642),i=r(9346);function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}t.exports=function(t,e,r,a,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),h=0;h<t.length;++h)u[h]=o(t[h],r,a,l,c);var f=0,p=1/0;for(h=0;h<u.length;++h){for(var d=0,m=0;m<2;++m)d+=Math.pow(u[h][m]-e[m],2);d<p&&(p=d,f=h)}var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return(r=Math.sqrt(r))+(a=Math.sqrt(a))<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),y=0;for(h=0;h<3;++h){if(g[h]<-.001||g[h]>1.0001)return null;y+=g[h]}return Math.abs(y-1)>.001?null:[f,s(t,g),g]}},840:function(t,e,r){var n=r(3236),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * (view * (model * vec4(p, 1.0)));\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * (view * (model * vec4(position, 1.0)));\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * (view * (model * vec4(position, 1.0)));\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * (view * (model * vec4(position, 1.0)));\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * (view * (model * vec4(position, 1.0)));\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * (view * (model * vec4(position, 1.0)));\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);e.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},e.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},e.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},e.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},e.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},e.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},7201:function(t,e,r){\"use strict\";var n=r(9405),i=r(2762),a=r(8116),o=r(7766),s=r(8406),l=r(6760),c=r(7608),u=r(9618),h=r(6729),f=r(7765),p=r(1888),d=r(840),m=r(7626),g=d.meshShader,y=d.wireShader,v=d.pointShader,x=d.pickShader,_=d.pointPickShader,b=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function T(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,T,k,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=g,this.edgeUVs=y,this.edgeIds=m,this.edgeVAO=v,this.edgeCount=0,this.pointPositions=x,this.pointColors=b,this.pointUVs=T,this.pointSizes=k,this.pointIds=_,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var k=T.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e}k.isOpaque=function(){return!this.hasAlpha},k.isTransparent=function(){return this.hasAlpha},k.pickSlots=1,k.setPickBase=function(t){this.pickId=t},k.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],m=n[h][1],g=i[h],y=1-g,v=this.positions[d],x=this.positions[m],_=0;_<3;++_)o[s++]=g*v[_]+y*x[_]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},k.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],m=[],g=[],y=[],v=[],x=[],_=[],b=[];this.cells=r,this.positions=n;var w=t.vertexNormals,T=t.cellNormals,k=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!T&&(T=s.faceNormals(r,n,M)),T||w||(w=s.vertexNormals(r,n,k));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,I=t.vertexIntensity,P=t.cellUVs,z=t.cellIntensity,O=1/0,D=-1/0;if(!L&&!P)if(I)if(t.vertexIntensityBounds)O=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<I.length;++R){var F=I[R];O=Math.min(O,F),D=Math.max(D,F)}else if(z)if(t.cellIntensityBounds)O=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<z.length;++R)F=z[R],O=Math.min(O,F),D=Math.max(D,F);else for(R=0;R<n.length;++R)F=n[R][2],O=Math.min(O,F),D=Math.max(D,F);this.intensity=I||z||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.pickVertex=!(z||E);var B=t.pointSizes,N=t.pointSize||1;for(this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;y.push(j[0],j[1],j[2]),Y=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(Y[0],Y[1],Y[2],this.opacity*A((I[W]-O)/(D-O),this.opacityscale)):3===Y.length?v.push(Y[0],Y[1],Y[2],this.opacity):(v.push(Y[0],Y[1],Y[2],Y[3]*this.opacity),Y[3]<1&&(this.hasAlpha=!0)),X=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],x.push(X[0],X[1]),B?_.push(B[W]):_.push(N),b.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Z=0;Z<3;++Z)if(isNaN(j[Z])||!isFinite(j[Z]))continue t}for(U=0;U<2;++U)j=n[W=G[U]],p.push(j[0],j[1],j[2]),Y=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(Y[0],Y[1],Y[2],this.opacity*A((I[W]-O)/(D-O),this.opacityscale)):3===Y.length?d.push(Y[0],Y[1],Y[2],this.opacity):(d.push(Y[0],Y[1],Y[2],Y[3]*this.opacity),Y[3]<1&&(this.hasAlpha=!0)),X=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],m.push(X[0],X[1]),g.push(R);q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Z=0;Z<3;++Z)if(isNaN(j[Z])||!isFinite(j[Z]))continue t;for(U=0;U<3;++U){var W,Y,X,$;j=n[W=G[2-U]],i.push(j[0],j[1],j[2]),(Y=S?S[W]:E?E[R]:C)?this.opacityscale&&I?a.push(Y[0],Y[1],Y[2],this.opacity*A((I[W]-O)/(D-O),this.opacityscale)):3===Y.length?a.push(Y[0],Y[1],Y[2],this.opacity):(a.push(Y[0],Y[1],Y[2],Y[3]*this.opacity),Y[3]<1&&(this.hasAlpha=!0)):a.push(.5,.5,.5,1),X=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],c.push(X[0],X[1]),$=w?w[W]:T[R],l.push($[0],$[1],$[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(y),this.pointColors.update(v),this.pointUVs.update(x),this.pointSizes.update(_),this.pointIds.update(new Uint32Array(b)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(g)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},k.drawTransparent=k.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);for(l(u,s.view,s.model),l(u,s.projection,u),c(u,u),o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind()),this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},k.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};(s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},k.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],h=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:h}}var f=m(i,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!f)return null;var p=f[2],d=0;for(a=0;a<r.length;++a)d+=p[a]*this.intensity[r[a]];return{position:f[1],index:r[f[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[f[0]]]}},k.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},t.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,g.vertex,g.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),m=i(t),v=i(t),x=i(t),_=i(t),b=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:_,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),k=i(t),A=i(t),L=i(t),I=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:k,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),P=i(t),z=i(t),O=i(t),D=i(t),R=i(t),F=a(t,[{buffer:P,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:O,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new T(t,p,r,s,l,c,h,f,d,_,m,v,x,b,w,L,k,A,I,P,R,z,O,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},8120:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl;return new o(t,n(e,[0,0,0,1,1,0,1,1]),i(e,a.boxVert,a.lineFrag))};var n=r(2762),i=r(9405),a=r(3603);function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},1913:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl;return new s(t,n(e),i(e,o.gridVert,o.gridFrag),i(e,o.tickVert,o.gridFrag))};var n=r(2762),i=r(9405),a=r(2478),o=r(3603);function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,m=0;m<2;++m){var g=a[m],y=a[m+2]-g,v=.5*(o[m+2]+o[m]),x=o[m+2]-o[m];u[m]=2*y/x,c[m]=2*(g-v)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var _=0;for(m=0;m<2;++m){h[0]=h[1]=0,h[m]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[m]/(s[m+2]-s[m])*d,r.uniforms.color=f[m];var b=6*n[m].length;p[m]&&b&&i.drawArrays(i.TRIANGLES,_,b),_+=b}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,m=s.viewBox,g=s.pixelRatio,y=s.screenBox,v=y[2]-y[0],x=y[3]-y[1],_=m[2]-m[0],b=m[3]-m[1],w=0;w<2;++w){var T=p[w],k=p[w+2]-T,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*k/M,t[w]=2*(T-A)/M}e[0]*=_/v,t[0]*=_/v,e[1]*=b/x,t[1]*=b/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,I=6*h[0].length,P=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),O=0+6*P,D=6*Math.max(0,z-P),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=I+6*R,N=6*Math.max(0,F-R);i[0]=2*(m[0]-E[1])/v-1,i[1]=(m[3]+m[1])/x-1,o[0]=E[1]*g/v,o[1]=C[1]*g/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(m[2]+m[0])/v-1,i[1]=2*(m[1]-E[0])/x-1,o[0]=C[0]*g/v,o[1]=E[0]*g/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,O,D)),i[0]=2*(m[2]+E[3])/v-1,i[1]=(m[3]+m[1])/x-1,o[0]=E[3]*g/v,o[1]=C[3]*g/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(m[2]+m[0])/v-1,i[1]=2*(m[3]+E[2])/x-1,o[0]=C[2]*g/v,o[1]=E[2]*g/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,O,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var m=0;m<6;++m)n[i++]=d,n[i++]=f[m],n[i++]=p[m]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},4747:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl;return new o(t,n(e,[-1,-1,-1,1,1,-1,1,1]),i(e,a.lineVert,a.lineFrag))};var n=r(2762),i=r(9405),a=r(3603);function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},3603:function(t,e,r){\"use strict\";var n=r(3236),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);t.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},2142:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl;return new l(t,n(e),i(e,s.textVert,s.textFrag))};var n=r(2762),i=r(9405),a=r(529),o=r(2478),s=r(3603);function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,m=l.prototype;m.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,m=e.tickPad,g=e.tickColor,y=e.tickAngle,v=e.labelEnable,x=e.labelPad,_=e.labelColor,b=e.labelAngle,w=this.labelOffset[t],T=this.labelCount[t],k=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*m[t],k<A&&i[A]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=g[t],r.uniforms.angle=y[t],a.drawArrays(a.TRIANGLES,i[k],i[A]-i[k]))),v[t]&&T&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=_[t],r.uniforms.angle=b[t],a.drawArrays(a.TRIANGLES,w,T)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*m[t+2],k<A&&i[A]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=g[t+2],r.uniforms.angle=y[t+2],a.drawArrays(a.TRIANGLES,i[k],i[A]-i[k]))),v[t+2]&&T&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=_[t+2],r.uniforms.angle=b[t+2],a.drawArrays(a.TRIANGLES,w,T))}),m.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),m.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],m=a[o+2]-h,g=i[o],y=i[o+2]-g;p[o]=2*l/u*m/y,f[o]=2*(s-c)/u*m/y}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),m.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,m=p.text,g=p.font||\"sans-serif\",y=p.fontStyle||\"normal\",v=p.fontWeight||\"normal\",x=p.fontVariant||\"normal\";i=p.fontSize||12;for(var _=1/(c[o+2]-c[o]),b=c[o],w=m.split(\"\\n\"),T=0;T<w.length;T++)for(n=a(g,w[T],{fontStyle:y,fontWeight:v,fontVariant:x}).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-T*i*1.2,(d-b)*_);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{fontStyle:t.labelFontStyle[o],fontWeight:t.labelFontWeight[o],fontVariant:t.labelFontVariant[o],textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title,{fontStyle:t.titleFontStyle,fontWeight:t.titleFontWeight,fontVariant:t.titleFontVariant}).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},m.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},1850:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl,r=new l(e,n(e,[e.drawingBufferWidth,e.drawingBufferHeight]));return r.grid=i(r),r.text=a(r),r.line=o(r),r.box=s(r),r.update(t),r};var n=r(3589),i=r(1913),a=r(2142),o=r(4747),s=r(8120);function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var m=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(m,e[1],m,e[3],p[d],f[d]):o.drawLine(e[0],m,e[2],m,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var g=this.borderLineEnable,y=this.borderLineWidth,v=this.borderLineColor;for(g[1]&&o.drawLine(r[0],r[1]-.5*y[1]*i,r[0],r[3]+.5*y[3]*i,y[1],v[1]),g[0]&&o.drawLine(r[0]-.5*y[0]*i,r[1],r[2]+.5*y[2]*i,r[1],y[0],v[0]),g[3]&&o.drawLine(r[2],r[1]-.5*y[1]*i,r[2],r[3]+.5*y[3]*i,y[3],v[3]),g[2]&&o.drawLine(r[0]-.5*y[0]*i,r[3],r[2]+.5*y[2]*i,r[3],y[2],v[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]),this.screenBox,this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t)||!!t.titleEnable,this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],labelFontStyle:t.labelFontStyle||[\"normal\",\"normal\"],labelFontWeight:t.labelFontWeight||[\"normal\",\"normal\"],labelFontVariant:t.labelFontVariant||[\"normal\",\"normal\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\",titleFontStyle:t.titleFontStyle||\"normal\",titleFontWeight:t.titleFontWeight||\"normal\",titleFontVariant:t.titleFontVariant||\"normal\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();for(this.objects.length=0,t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},4437:function(t,e,r){\"use strict\";t.exports=function(t,e){t=t||document.body;var r=[.01,1/0];\"distanceLimits\"in(e=e||{})&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]),\"zoomMin\"in e&&(r[0]=e.zoomMin),\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",(function(t){return t.preventDefault(),!1})),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,m=!!a.shift,g=!!(1&e),y=!!(2&e),v=!!(4&e),x=1/t.clientHeight,_=x*(r-d._lastX),b=x*(i-d._lastY),w=d.flipX?1:-1,T=d.flipY?1:-1,k=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&g&&!f&&!p&&!m||g&&!f&&!p&&m)&&c.rotate(A,w*k*_,-T*k*b,0),(l&&g&&!f&&!p&&!m||y||g&&f&&!p&&!m)&&c.pan(A,-d.translateSpeed*_*h,d.translateSpeed*b*h,0),u&&g&&!f&&!p&&!m||v||g&&!f&&p&&!m)){var M=-d.zoomSpeed*b/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",(function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods)}),!!l&&{passive:!0}),t.addEventListener(\"touchmove\",(function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchend\",(function(t){e(0,d._lastX,d._lastY,d._lastMods)}),!!l&&{passive:!0}),d.wheelListener=o(t,(function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}}),!0)},d.enableMouseListeners(),d};var n=r(3025),i=r(6296),a=r(351),o=r(8512),s=r(24),l=r(7520)},799:function(t,e,r){var n=r(3236),i=r(9405),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);t.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},4100:function(t,e,r){\"use strict\";var n=r(4437),i=r(3837),a=r(5445),o=r(4449),s=r(3589),l=r(2260),c=r(7169),u=r(351),h=r(4772),f=r(4040),p=r(799),d=r(9216)({tablet:!0,featureDetect:!0});function m(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function g(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}return e>0?(r=Math.round(Math.pow(10,e)),Math.ceil(t/r)*r):Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}t.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;e||(e=document.createElement(\"canvas\"),t.container?t.container.appendChild(e):document.body.appendChild(e));var r=t.gl;if(r||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),r=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d})),!r)throw new Error(\"webgl not supported\");var v=t.bounds||[[-10,-10,-10],[10,10,10]],x=new m,_=l(r,r.drawingBufferWidth,r.drawingBufferHeight,{preferFloat:!d}),b=p(r),w=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:w},k=t.axes||{},A=i(r,k);A.enable=!k.disable;var M=t.spikes||{},S=o(r,M),E=[],C=[],L=[],I=[],P=!0,z=!0,O={view:null,projection:new Array(16),model:new Array(16),_ortho:!1},D=(z=!0,[r.drawingBufferWidth,r.drawingBufferHeight]),R=t.cameraObject||n(e,T),F={gl:r,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:x,camera:R,axes:A,axesPixels:null,spikes:S,bounds:v,objects:E,shape:D,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:O,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,z=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},B=[r.drawingBufferWidth/F.pixelRatio|0,r.drawingBufferHeight/F.pixelRatio|0];function N(){if(!F._stopped&&F.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*F.pixelRatio),a=0|Math.ceil(n*F.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",P=!0}}}function j(){for(var t=E.length,e=I.length,n=0;n<e;++n)L[n]=0;t:for(n=0;n<t;++n){var i=E[n],a=i.pickSlots;if(a){for(var o=0;o<e;++o)if(L[o]+a<255){C[n]=o,i.setPickBase(L[o]+1),L[o]+=a;continue t}var l=s(r,D);C[n]=e,I.push(l),L.push(a),i.setPickBase(1),e+=1}else C[n]=-1}for(;e>0&&0===L[e-1];)L.pop(),I.pop().dispose()}function U(){if(F.contextLost)return!0;r.isContextLost()&&(F.contextLost=!0,F.mouseListener.enabled=!1,F.selection.object=null,F.oncontextloss&&F.oncontextloss())}F.autoResize&&N(),window.addEventListener(\"resize\",N),F.update=function(t){F._stopped||(t=t||{},P=!0,z=!0)},F.add=function(t){F._stopped||(t.axes=A,E.push(t),C.push(-1),P=!0,z=!0,j())},F.remove=function(t){if(!F._stopped){var e=E.indexOf(t);e<0||(E.splice(e,1),C.pop(),P=!0,z=!0,j())}},F.dispose=function(){if(!F._stopped&&(F._stopped=!0,window.removeEventListener(\"resize\",N),e.removeEventListener(\"webglcontextlost\",U),F.mouseListener.enabled=!1,!F.contextLost)){A.dispose(),S.dispose();for(var t=0;t<E.length;++t)E[t].dispose();for(_.dispose(),t=0;t<I.length;++t)I[t].dispose();b.dispose(),r=null,A=null,S=null,E=[]}},F._mouseRotating=!1,F._prevButtons=0,F.enableMouseListeners=function(){F.mouseListener=u(e,(function(t,e,r){if(!F._stopped){var n=I.length,i=E.length,a=x.object;x.distance=1/0,x.mouse[0]=e,x.mouse[1]=r,x.object=null,x.screen=null,x.dataCoordinate=x.dataPosition=null;var o=!1;if(t&&F._prevButtons)F._mouseRotating=!0;else{F._mouseRotating&&(z=!0),F._mouseRotating=!1;for(var s=0;s<n;++s){var l=I[s].query(e,B[1]-r-1,F.pickRadius);if(l){if(l.distance>x.distance)continue;for(var c=0;c<i;++c){var u=E[c];if(C[c]===s){var h=u.pick(l);h&&(x.buttons=t,x.screen=l.coord,x.distance=l.distance,x.object=u,x.index=h.distance,x.dataPosition=h.position,x.dataCoordinate=h.dataCoordinate,x.data=h,o=!0)}}}}}a&&a!==x.object&&(a.highlight&&a.highlight(null),P=!0),x.object&&(x.object.highlight&&x.object.highlight(x.data),P=!0),(o=o||x.object!==a)&&F.onselect&&F.onselect(x),1&t&&!(1&F._prevButtons)&&F.onclick&&F.onclick(x),F._prevButtons=t}}))},e.addEventListener(\"webglcontextlost\",U);var V=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],q=[V[0].slice(),V[1].slice()];function H(){if(!U()){N();var t=F.camera.tick();O.view=F.camera.matrix,P=P||t,z=z||t,A.pixelRatio=F.pixelRatio,S.pixelRatio=F.pixelRatio;var e=E.length,n=V[0],i=V[1];n[0]=n[1]=n[2]=1/0,i[0]=i[1]=i[2]=-1/0;for(var o=0;o<e;++o){(L=E[o]).pixelRatio=F.pixelRatio,L.axes=F.axes,P=P||!!L.dirty,z=z||!!L.dirty;var s=L.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)n[p]=Math.min(n[p],l[p]),i[p]=Math.max(i[p],u[p])}var d=F.bounds;if(F.autoBounds)for(p=0;p<3;++p){if(i[p]<n[p])n[p]=-1,i[p]=1;else{n[p]===i[p]&&(n[p]-=1,i[p]+=1);var m=.05*(i[p]-n[p]);n[p]=n[p]-m,i[p]=i[p]+m}d[0][p]=n[p],d[1][p]=i[p]}var y=!1;for(p=0;p<3;++p)y=y||q[0][p]!==d[0][p]||q[1][p]!==d[1][p],q[0][p]=d[0][p],q[1][p]=d[1][p];if(z=z||y,P=P||y){if(y){var v=[0,0,0];for(o=0;o<3;++o)v[o]=g((d[1][o]-d[0][o])/10);A.autoTicks?A.update({bounds:d,tickSpacing:v}):A.update({bounds:d})}var T=r.drawingBufferWidth,k=r.drawingBufferHeight;for(D[0]=T,D[1]=k,B[0]=0|Math.max(T/F.pixelRatio,1),B[1]=0|Math.max(k/F.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,i=n.projection,a=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(f(i,-p,p,-1,1,l,c),n._ortho=!0):(h(i,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)a[d]=0;a[15]=1;var m=0;for(d=0;d<3;++d)m=Math.max(m,r[1][d]-r[0][d]);for(d=0;d<3;++d)t.autoScale?a[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):a[5*d]=1/m,t.autoCenter&&(a[12+d]=.5*-a[5*d]*(r[0][d]+r[1][d]))}(F,w),o=0;o<e;++o)(L=E[o]).axesBounds=d,F.clipToBounds&&(L.clipBounds=d);x.object&&(F.snapToData?S.position=x.dataCoordinate:S.position=x.dataPosition,S.bounds=d),z&&(z=!1,function(){if(!U()){r.colorMask(!0,!0,!0,!0),r.depthMask(!0),r.disable(r.BLEND),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL);for(var t=E.length,e=I.length,n=0;n<e;++n){var i=I[n];i.shape=B,i.begin();for(var a=0;a<t;++a)if(C[a]===n){var o=E[a];o.drawPick&&(o.pixelRatio=1,o.drawPick(O))}i.end()}}}()),F.axesPixels=a(F.axes,O,T,k),F.onrender&&F.onrender(),r.bindFramebuffer(r.FRAMEBUFFER,null),r.viewport(0,0,T,k),F.clearRGBA(),r.depthMask(!0),r.colorMask(!0,!0,!0,!0),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL),r.disable(r.BLEND),r.disable(r.CULL_FACE);var M=!1;for(A.enable&&(M=M||A.isTransparent(),A.draw(O)),S.axes=A,x.object&&S.draw(O),r.disable(r.CULL_FACE),o=0;o<e;++o)(L=E[o]).axes=A,L.pixelRatio=F.pixelRatio,L.isOpaque&&L.isOpaque()&&L.draw(O),L.isTransparent&&L.isTransparent()&&(M=!0);if(M){for(_.shape=D,_.bind(),r.clear(r.DEPTH_BUFFER_BIT),r.colorMask(!1,!1,!1,!1),r.depthMask(!0),r.depthFunc(r.LESS),A.enable&&A.isTransparent()&&A.drawTransparent(O),o=0;o<e;++o)(L=E[o]).isOpaque&&L.isOpaque()&&L.draw(O);for(r.enable(r.BLEND),r.blendEquation(r.FUNC_ADD),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.colorMask(!0,!0,!0,!0),r.depthMask(!1),r.clearColor(0,0,0,0),r.clear(r.COLOR_BUFFER_BIT),A.isTransparent()&&A.drawTransparent(O),o=0;o<e;++o){var L;(L=E[o]).isTransparent&&L.isTransparent()&&L.drawTransparent(O)}r.bindFramebuffer(r.FRAMEBUFFER,null),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.disable(r.DEPTH_TEST),b.bind(),_.color[0].bind(0),b.uniforms.accumBuffer=0,c(r),r.disable(r.BLEND)}for(P=!1,o=0;o<e;++o)E[o].dirty=!1}}}return F.enableMouseListeners(),function t(){F._stopped||F.contextLost||(H(),requestAnimationFrame(t))}(),F.redraw=function(){F._stopped||(P=!0,H())},F},createCamera:n}},6640:function(t,e,r){var n=r(3236);e.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),e.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),e.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),e.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},4696:function(t,e,r){\"use strict\";var n=r(9405),i=r(2762),a=r(1888),o=r(6640);function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}t.exports=function(t,e){var r=t.gl,a=new s(t,i(r),i(r),n(r,o.pointVertex,o.pointFragment),n(r,o.pickVertex,o.pickFragment));return a.update(e),t.addObject(a),a};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},783:function(t){t.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],m=r[2],g=r[3];return(a=c*p+u*d+h*m+f*g)<0&&(a=-a,p=-p,d=-d,m=-m,g=-g),1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n),t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*m,t[3]=s*f+l*g,t}},5964:function(t){\"use strict\";t.exports=function(t){return t||0===t?t.toString():\"\"}},9366:function(t,e,r){\"use strict\";var n=r(4359);t.exports=function(t,e,r){var a=[e.style,e.weight,e.variant,e.family].join(\"_\"),o=i[a];if(o||(o=i[a]={}),t in o)return o[t];var s={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e.family,fontStyle:e.style,fontWeight:e.weight,fontVariant:e.variant,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},l=n(t,s);s.triangles=!1;var c,u,h=n(t,s);if(r&&1!==r){for(c=0;c<l.positions.length;++c)for(u=0;u<l.positions[c].length;++u)l.positions[c][u]/=r;for(c=0;c<h.positions.length;++c)for(u=0;u<h.positions[c].length;++u)h.positions[c][u]/=r}var f=[[1/0,1/0],[-1/0,-1/0]],p=h.positions.length;for(c=0;c<p;++c){var d=h.positions[c];for(u=0;u<2;++u)f[0][u]=Math.min(f[0][u],d[u]),f[1][u]=Math.max(f[1][u],d[u])}return o[t]=[l,h,f]};var i={}},1283:function(t,e,r){var n=r(9405),i=r(3236),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * (view * (model * vec4(position, 1)));\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * (view * (model * vec4(dataPosition, 1)));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},m={vertex:o,fragment:c,attributes:u},g={vertex:s,fragment:c,attributes:u};function y(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}e.createPerspective=function(t){return y(t,h)},e.createOrtho=function(t){return y(t,f)},e.createProject=function(t){return y(t,p)},e.createPickPerspective=function(t){return y(t,d)},e.createPickOrtho=function(t){return y(t,m)},e.createPickProject=function(t){return y(t,g)}},8418:function(t,e,r){\"use strict\";var n=r(5219),i=r(2762),a=r(8116),o=r(1888),s=r(6760),l=r(1283),c=r(9366),u=r(5964),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],f=ArrayBuffer,p=DataView;function d(t){return Array.isArray(t)||function(t){return f.isView(t)&&!(t instanceof p)}(t)}function m(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function g(t,e,r,n){return m(n,n),m(n,n),m(n,n)}function y(t,e){this.index=t,this.dataCoordinate=this.position=e}function v(t){return!0===t||t>1?1:t}function x(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new y(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}t.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),m=new x(e,r,n,o,h,f,p,d,a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),s,c,u);return m.update(t),m};var _=x.prototype;_.pickSlots=1,_.setPickBase=function(t){this.pickId=t},_.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},_.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var b=[0,0],w=[0,0,0],T=[0,0,0],k=[0,0,0,1],A=[0,0,0,1],M=h.slice(),S=[0,0,0],E=[[0,0,0],[0,0,0]];function C(t){return t[0]=t[1]=t[2]=0,t}function L(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function I(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}var P=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function z(t,e,r,n,i,a,o){var l=r.gl;if((a===r.projectHasAlpha||o)&&function(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,p=e.axesBounds,d=function(t){for(var e=E,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],b[0]=2/o.drawingBufferWidth,b[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=b,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=d,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var m=0;m<3;++m)if(a[m]){l.scale=e.projectScale[m],l.opacity=e.projectOpacity[m];for(var y=M,v=0;v<16;++v)y[v]=0;for(v=0;v<4;++v)y[5*v]=1;y[5*m]=0,i[m]<0?y[12+m]=p[0][m]:y[12+m]=p[1][m],s(y,c,y),l.model=y;var x=(m+1)%3,_=(m+2)%3,P=C(w),z=C(T);P[x]=1,z[_]=1;var O=g(0,0,0,L(k,P)),D=g(0,0,0,L(A,z));if(Math.abs(O[1])>Math.abs(D[1])){var R=O;O=D,D=R,R=P,P=z,z=R;var F=x;x=_,_=F}O[0]<0&&(P[x]=-1),D[1]>0&&(z[_]=-1);var B=0,N=0;for(v=0;v<4;++v)B+=Math.pow(c[4*x+v],2),N+=Math.pow(c[4*_+v],2);P[x]/=Math.sqrt(B),z[_]/=Math.sqrt(N),l.axes[0]=P,l.axes[1]=z,l.fragClipBounds[0]=I(S,d[0],m,-1e8),l.fragClipBounds[1]=I(S,d[1],m,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}(e,r,n,i),a===r.hasAlpha||o){t.bind();var c=t.uniforms;c.model=n.model||h,c.view=n.view||h,c.projection=n.projection||h,b[0]=2/l.drawingBufferWidth,b[1]=2/l.drawingBufferHeight,c.screenSize=b,c.highlightId=r.highlightId,c.highlightScale=r.highlightScale,c.fragClipBounds=P,c.clipBounds=r.axes.bounds,c.opacity=r.opacity,c.pickGroup=r.pickId/255,c.pixelRatio=i,r.vao.bind(),r.vao.draw(l.TRIANGLES,r.vertexCount),r.lineWidth>0&&(l.lineWidth(r.lineWidth*i),r.vao.draw(l.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=d(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\u25bc\",o=!1),r||(r={});var s=r.family;d(s)&&(s=s[e]),s||(s=\"normal\");var l=r.weight;d(l)&&(l=l[e]),l||(l=\"normal\");var h=r.style;d(h)&&(h=h[e]),h||(h=\"normal\");var f=r.variant;d(f)&&(f=f[e]),f||(f=\"normal\");var p=c(a,{family:s,weight:l,style:h,variant:f},i);return{mesh:(p=c(a,r,i))[0],lines:p[1],bounds:p[2],visible:o}}_.draw=function(t){z(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},_.drawTransparent=function(t){z(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},_.drawPick=function(t){z(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},_.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},_.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},_.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(d(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(d(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){d(t.projectOpacity)?this.projectOpacity=t.projectOpacity.slice():(r=+t.projectOpacity,this.projectOpacity=[r,r,r]);for(var n=0;n<3;++n)this.projectOpacity[n]=v(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=v(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l={family:t.font||\"normal\",style:t.fontStyle||\"normal\",weight:t.fontWeight||\"normal\",variant:t.fontVariant||\"normal\"},c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else for(i=[],a=[],n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1];var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,m=t.size,g=t.angle,y=t.lineColor,x=-1,_=0,b=0,w=0;if(s.length){w=s.length;t:for(n=0;n<w;++n){for(var T=s[n],k=0;k<3;++k)if(isNaN(T[k])||!isFinite(T[k]))continue t;var A=(j=O(f,n,l,this.pixelRatio)).mesh,M=j.lines,S=j.bounds;_+=3*A.cells.length,b+=2*M.edges.length}}var E=_+b,C=o.mallocFloat(3*E),L=o.mallocFloat(4*E),I=o.mallocFloat(2*E),P=o.mallocUint32(E);if(E>0){var z=0,D=_,R=[0,0,0,1],F=[0,0,0,1],B=d(p)&&d(p[0]),N=d(y)&&d(y[0]);t:for(n=0;n<w;++n){for(x+=1,T=s[n],k=0;k<3;++k){if(isNaN(T[k])||!isFinite(T[k]))continue t;h[k]=Math.max(h[k],T[k]),u[k]=Math.min(u[k],T[k])}A=(j=O(f,n,l,this.pixelRatio)).mesh,M=j.lines,S=j.bounds;var j,U=j.visible;if(U)if(d(p)){if(3===(V=B?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)R[k]=V[k];R[3]=1}else if(4===V.length){for(k=0;k<4;++k)R[k]=V[k];!this.hasAlpha&&V[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];if(U)if(d(y)){var V;if(3===(V=N?n<y.length?y[n]:[0,0,0,0]:y).length){for(k=0;k<3;++k)F[k]=V[k];F[k]=1}else if(4===V.length){for(k=0;k<4;++k)F[k]=V[k];!this.hasAlpha&&V[3]<1&&(this.hasAlpha=!0)}}else F[0]=F[1]=F[2]=0,F[3]=1;else F=[1,1,1,0];var q=.5;U?d(m)?q=n<m.length?+m[n]:12:m?q=+m:this.useOrtho&&(q=12):q=0;var H=0;d(g)?H=n<g.length?+g[n]:0:g&&(H=+g);var G=Math.cos(H),Z=Math.sin(H);for(T=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],T[k]),u[k]=Math.min(u[k],T[k]);var W=i,Y=a;W=0,d(i)?W=n<i.length?i[n]:0:i&&(W=i),Y=0,d(a)?Y=n<a.length?a[n]:0:a&&(Y=a);var X=[W*=W>0?1-S[0][0]:W<0?1+S[1][0]:1,Y*=Y>0?1-S[0][1]:Y<0?1+S[1][1]:1],$=A.cells||[],J=A.positions||[];for(k=0;k<$.length;++k)for(var K=$[k],Q=0;Q<3;++Q){for(var tt=0;tt<3;++tt)C[3*z+tt]=T[tt];for(tt=0;tt<4;++tt)L[4*z+tt]=R[tt];P[z]=x;var et=J[K[Q]];I[2*z]=q*(G*et[0]-Z*et[1]+X[0]),I[2*z+1]=q*(Z*et[0]+G*et[1]+X[1]),z+=1}for($=M.edges,J=M.positions,k=0;k<$.length;++k)for(K=$[k],Q=0;Q<2;++Q){for(tt=0;tt<3;++tt)C[3*D+tt]=T[tt];for(tt=0;tt<4;++tt)L[4*D+tt]=F[tt];P[D]=x,et=J[K[Q]],I[2*D]=q*(G*et[0]-Z*et[1]+X[0]),I[2*D+1]=q*(Z*et[0]+G*et[1]+X[1]),D+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=_,this.lineVertexCount=b,this.pointBuffer.update(C),this.colorBuffer.update(L),this.glyphBuffer.update(I),this.idBuffer.update(P),o.free(C),o.free(L),o.free(I),o.free(P)},_.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},4298:function(t,e,r){\"use strict\";var n=r(3236);e.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),e.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},3161:function(t,e,r){\"use strict\";var n=r(9405),i=r(2762),a=r(4298);function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}t.exports=function(t,e){var r=t.gl,s=new o(t,i(r,[0,0,0,1,1,0,1,1]),n(r,a.boxVertex,a.boxFragment));return s.update(e),t.addOverlay(s),s};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var m=s[2]-s[0],g=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,m,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,m,g,i),o.drawBox(p,f,m,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var y=r*u;o.drawBox(h-y,f-y,p+y,f+y,a),o.drawBox(h-y,d-y,p+y,d+y,a),o.drawBox(h-y,f-y,h+y,d+y,a),o.drawBox(p-y,f-y,p+y,d+y,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},3589:function(t,e,r){\"use strict\";t.exports=function(t,e){var r=e[0],a=e[1];return new l(t,n(t,r,a,{}),i.mallocUint8(r*a*4))};var n=r(2260),i=r(1888),a=r(9618),o=r(8828).nextPow2;function s(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function l(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var c=l.prototype;Object.defineProperty(c,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),c.begin=function(){var t=this.gl;this.shape,t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},c.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},c.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),l=0|Math.min(Math.max(e-r,0),n[1]),c=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||c<=l)return null;var u=[o-i,c-l],h=a(this.buffer,[u[0],u[1],4],[4,4*n[0],1],4*(i+n[0]*l)),f=function(t,e,r){for(var n=1e8,i=-1,a=-1,o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++){var u=t.get(l,c,0),h=t.get(l,c,1),f=t.get(l,c,2),p=t.get(l,c,3);if(u<255||h<255||f<255||p<255){var d=e-l,m=r-c,g=d*d+m*m;g<n&&(n=g,i=l,a=c)}}return[i,a,n]}(h.hi(u[0],u[1],1),r,r),p=f[0],d=f[1];return p<0||Math.pow(this.radius,2)<f[2]?null:new s(p+i|0,d+l|0,h.get(p,d,0),[h.get(p,d,1),h.get(p,d,2),h.get(p,d,3)],Math.sqrt(f[2]))},c.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},9405:function(t,e,r){\"use strict\";var n=r(3327),i=r(8731),a=r(216),o=r(5091),s=r(2145),l=r(8866);function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var m=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),m&&m.dispose(),f.fragShader=f._fref.shader,!r||!c){var g=p.createProgram();if(p.attachShader(g,f.fragShader),p.attachShader(g,f.vertShader),p.linkProgram(g),!p.getProgramParameter(g,p.LINK_STATUS)){var y=p.getProgramInfoLog(g);throw new l(y,\"Error linking program:\"+y)}r=r||s.uniforms(p,g),c=c||s.attributes(p,g),p.deleteProgram(g)}(c=c.slice()).sort(h);var v,x=[],_=[],b=[];for(v=0;v<c.length;++v){var w=c[v];if(w.type.indexOf(\"mat\")>=0){for(var T=0|w.type.charAt(w.type.length-1),k=new Array(T),A=0;A<T;++A)k[A]=b.length,_.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?b.push(w.location+A):Array.isArray(w.location)&&w.location.length===T&&\"number\"==typeof w.location[A]?b.push(0|w.location[A]):b.push(-1);x.push({name:w.name,type:w.type,locations:k})}else x.push({name:w.name,type:w.type,locations:[b.length]}),_.push(w.name),\"number\"==typeof w.location?b.push(0|w.location):b.push(-1)}var M=0;for(v=0;v<b.length;++v)if(b[v]<0){for(;b.indexOf(M)>=0;)M+=1;b[v]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,_,b);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,b),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},t.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},8866:function(t){function e(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}e.prototype=new Error,e.prototype.name=\"GLError\",e.prototype.constructor=e,t.exports=e},8731:function(t,e,r){\"use strict\";t.exports=function(t,e,r,i){for(var a={},o=0,c=r.length;o<c;++o){var u=r[o],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":s(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){if((d=f.charCodeAt(f.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d;if((d=f.charCodeAt(f.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);l(t,e,p,i,d,a,h)}}}return a};var n=r(8866);function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;a.pointer=function(t,e,r,n){var i=this,a=i._gl,o=i._locations[i._index];a.vertexAttribPointer(o,i._dimension,t||a.FLOAT,!!e,r||0,n||0),a.enableVertexAttribArray(o)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}});var o=[function(t,e,r){return void 0===r.length?t.vertexAttrib1f(e,r):t.vertexAttrib1fv(e,r)},function(t,e,r,n){return void 0===r.length?t.vertexAttrib2f(e,r,n):t.vertexAttrib2fv(e,r)},function(t,e,r,n,i){return void 0===r.length?t.vertexAttrib3f(e,r,n,i):t.vertexAttrib3fv(e,r)},function(t,e,r,n,i,a){return void 0===r.length?t.vertexAttrib4f(e,r,n,i,a):t.vertexAttrib4fv(e,r)}];function s(t,e,r,n,a,s,l){var c=o[a],u=new i(t,e,r,n,a,c);Object.defineProperty(s,l,{set:function(e){return t.disableVertexAttribArray(n[r]),c(t,n[r],e),e},get:function(){return u},enumerable:!0})}function l(t,e,r,n,i,a,o){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)s(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,o,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}},3327:function(t,e,r){\"use strict\";var n=r(216),i=r(8866);function a(t){return function(){return t}}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}t.exports=function(t,e,r,s){function l(e){return function(n){for(var a=c(\"\",e),o=0;o<a.length;++o){var l=a[o],u=l[0],h=l[1];if(s[h]){var f=n;if(\"string\"==typeof u&&(0===u.indexOf(\".\")||0===u.indexOf(\"[\"))){var p=u;if(0===u.indexOf(\".\")&&(p=u.slice(1)),p.indexOf(\"]\")===p.length-1){var d=p.indexOf(\"[\"),m=p.slice(0,d),g=p.slice(d+1,p.length-1);f=m?n[m][g]:n[g]}else f=n[p]}var y,v=r[h].type;switch(v){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":t.uniform1i(s[h],f);break;case\"float\":t.uniform1f(s[h],f);break;default:var x=v.indexOf(\"vec\");if(!(0<=x&&x<=1&&v.length===4+x)){if(0===v.indexOf(\"mat\")&&4===v.length){if((y=v.charCodeAt(v.length-1)-48)<2||y>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+v);t[\"uniformMatrix\"+y+\"fv\"](s[h],!1,f);break}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+v)}if((y=v.charCodeAt(v.length-1)-48)<2||y>4)throw new i(\"\",\"Invalid data type\");switch(v.charAt(0)){case\"b\":case\"i\":t[\"uniform\"+y+\"iv\"](s[h],f);break;case\"v\":t[\"uniform\"+y+\"fv\"](s[h],f);break;default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+v)}}}}}}function c(t,e){if(\"object\"!=typeof e)return[[t,e]];var r=[];for(var n in e){var i=e[n],a=t;parseInt(n)+\"\"===n?a+=\"[\"+n+\"]\":a+=\".\"+n,\"object\"==typeof i?r.push.apply(r,c(a,i)):r.push([a,i])}return r}function u(t,e,n){if(\"object\"==typeof n){var c=h(n);Object.defineProperty(t,e,{get:a(c),set:l(n),enumerable:!0,configurable:!1})}else s[n]?Object.defineProperty(t,e,{get:(u=n,function(t,e,r){return t.getUniform(e.program,r[u])}),set:l(n),enumerable:!0,configurable:!1}):t[e]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r;if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[n].type);var u}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:l(f),enumerable:!0,configurable:!0}}},216:function(t){\"use strict\";t.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name.split(\".\"),a=r,o=0;o<i.length;++o){var s=i[o].split(\"[\");if(s.length>1){s[0]in a||(a[s[0]]=[]),a=a[s[0]];for(var l=1;l<s.length;++l){var c=parseInt(s[l]);l<s.length-1||o<i.length-1?(c in a||(l<s.length-1?a[c]=[]:a[c]={}),a=a[c]):a[c]=e?n:t[n].type}}else o<i.length-1?(s[0]in a||(a[s[0]]={}),a=a[s[0]]):a[s[0]]=e?n:t[n].type}return r}},2145:function(t,e){\"use strict\";e.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],a=0;a<r;++a){var o=t.getActiveUniform(e,a);if(o){var s=i(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},e.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],a=0;a<r;++a){var o=t.getActiveAttrib(e,a);o&&n.push({name:o.name,type:i(t,o.type)})}return n};var r={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},n=null;function i(t,e){if(!n){var i=Object.keys(r);n={};for(var a=0;a<i.length;++a){var o=i[a];n[t[o]]=r[o]}}return n[e]}},5091:function(t,e,r){\"use strict\";e.shader=function(t,e,r){return u(t).getShaderReference(e,r)},e.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=r(8866),i=r(2992),a=new(\"undefined\"==typeof WeakMap?r(606):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},4098:function(t){\"use strict\";function e(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}t.exports=function(t,r){var n=new e(t);return n.update(r),t.addOverlay(n),n};var r=e.prototype;r.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map((function(t){return t.slice()})),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},r.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},r.dispose=function(){this.plot.removeOverlay(this)}},1493:function(t,e,r){\"use strict\";var n=r(3236),i=r(9405),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * (view * (model * vec4(vertexPosition, 1.0)));\\n  vec2 clipOffset = (projection * (view * (model * vec4(color, 0.0)))).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);t.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},4449:function(t,e,r){\"use strict\";var n=r(2762),i=r(8116),a=r(1493);t.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);for(h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h,d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},6740:function(t,e,r){var n=r(3236),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, tubeScale;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * (view * tubePosition);\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);e.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},e.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},7815:function(t,e,r){\"use strict\";var n=r(2931),i=r(9970),a=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"],o=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var i=t[r];if(i===e)return r;if(i>e)return r-1}return r},s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t){var e=1/0;t.sort((function(t,e){return t-e}));for(var r=t.length,n=1;n<r;n++){var i=Math.abs(t[n]-t[n-1]);i<e&&(e=i)}return e};t.exports=function(t,e){var r=t.startingPositions,c=t.maxLength||1e3,u=t.tubeSize||1,h=t.absoluteTubeSize,f=t.gridFill||\"+x+y+z\",p={};-1!==f.indexOf(\"-x\")&&(p.reversedX=!0),-1!==f.indexOf(\"-y\")&&(p.reversedY=!0),-1!==f.indexOf(\"-z\")&&(p.reversedZ=!0),p.filled=a.indexOf(f.replace(/-/g,\"\").replace(/\\+/g,\"\"));var d=t.getVelocity||function(e){return function(t,e,r){var i=e.vectors,a=e.meshgrid,l=t[0],c=t[1],u=t[2],h=a[0].length,f=a[1].length,p=a[2].length,d=o(a[0],l),m=o(a[1],c),g=o(a[2],u),y=d+1,v=m+1,x=g+1;if(d=s(d,0,h-1),y=s(y,0,h-1),m=s(m,0,f-1),v=s(v,0,f-1),g=s(g,0,p-1),x=s(x,0,p-1),d<0||m<0||g<0||y>h-1||v>f-1||x>p-1)return n.create();var _,b,w,T,k,A,M=a[0][d],S=a[0][y],E=a[1][m],C=a[1][v],L=a[2][g],I=(l-M)/(S-M),P=(c-E)/(C-E),z=(u-L)/(a[2][x]-L);switch(isFinite(I)||(I=.5),isFinite(P)||(P=.5),isFinite(z)||(z=.5),r.reversedX&&(d=h-1-d,y=h-1-y),r.reversedY&&(m=f-1-m,v=f-1-v),r.reversedZ&&(g=p-1-g,x=p-1-x),r.filled){case 5:k=g,A=x,w=m*p,T=v*p,_=d*p*f,b=y*p*f;break;case 4:k=g,A=x,_=d*p,b=y*p,w=m*p*h,T=v*p*h;break;case 3:w=m,T=v,k=g*f,A=x*f,_=d*f*p,b=y*f*p;break;case 2:w=m,T=v,_=d*f,b=y*f,k=g*f*h,A=x*f*h;break;case 1:_=d,b=y,k=g*h,A=x*h,w=m*h*p,T=v*h*p;break;default:_=d,b=y,w=m*h,T=v*h,k=g*h*f,A=x*h*f}var O=i[_+w+k],D=i[_+w+A],R=i[_+T+k],F=i[_+T+A],B=i[b+w+k],N=i[b+w+A],j=i[b+T+k],U=i[b+T+A],V=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(V,O,B,I),n.lerp(q,D,N,I),n.lerp(H,R,j,I),n.lerp(G,F,U,I);var Z=n.create(),W=n.create();n.lerp(Z,V,H,P),n.lerp(W,q,G,P);var Y=n.create();return n.lerp(Y,Z,W,z),Y}(e,t,p)},m=t.getDivergence||function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=d(r);n.subtract(a,a,e),n.scale(a,a,1/i),n.add(r,t,[0,i,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1/i),n.add(r,t,[0,0,i]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1/i),n.add(r,a,o),n.add(r,r,s),r},g=[],y=e[0][0],v=e[0][1],x=e[0][2],_=e[1][0],b=e[1][1],w=e[1][2],T=function(t){var e=t[0],r=t[1],n=t[2];return!(e<y||e>_||r<v||r>b||n<x||n>w)},k=10*n.distance(e[0],e[1])/c,A=k*k,M=1,S=0,E=r.length;E>1&&(M=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=t.length,c=0;c<s;c++){var u=t[c],h=u[0],f=u[1],p=u[2];i[h]||(e.push(h),i[h]=!0),a[f]||(r.push(f),a[f]=!0),o[p]||(n.push(p),o[p]=!0)}var d=l(e),m=l(r),g=l(n),y=Math.min(d,m,g);return isFinite(y)?y:1}(r));for(var C=0;C<E;C++){var L=n.create();n.copy(L,r[C]);var I=[L],P=[],z=d(L),O=L;P.push(z);var D=[],R=m(L,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),g.push({points:I,velocities:P,divergences:D});for(var B=0;B<100*c&&I.length<c&&T(L);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;j>A&&n.scale(N,N,k/Math.sqrt(j)),n.add(N,N,L),z=d(N),n.squaredDistance(O,N)-A>-1e-4*A&&(I.push(N),O=N,P.push(z),R=m(N,z),F=n.length(R),isFinite(F)&&F>S&&(S=F),D.push(F)),L=N}}var U=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map((function(t){return function(t,e,r,a){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],h=[],f=[],p=[],d=[],m=0,g=0,y=i.create(),v=i.create(),x=0;x<o.length;x++){var _=o[x],b=s[x],w=l[x];0===e&&(w=.05*r),g=n.length(b)/a,y=i.create(),n.copy(y,b),y[3]=w;for(var T=0;T<8;T++)p[T]=[_[0],_[1],_[2],T];if(f.length>0)for(T=0;T<8;T++){var k=(T+1)%8;c.push(f[T],p[T],p[k],p[k],f[k],f[T]),h.push(v,y,y,y,v,v),d.push(m,g,g,g,m,m);var A=c.length;u.push([A-6,A-5,A-4],[A-3,A-2,A-1])}var M=f;f=p,p=M;var S=v;v=y,y=S;var E=m;m=g,g=E}return{positions:c,cells:u,vectors:h,vertexIntensity:d}}(t,r,a,o)})),h=[],f=[],p=[],d=[];for(s=0;s<u.length;s++){var m=u[s],g=h.length;for(h=h.concat(m.positions),p=p.concat(m.vectors),d=d.concat(m.vertexIntensity),c=0;c<m.cells.length;c++){var y=m.cells[c],v=[];f.push(v);for(var x=0;x<y.length;x++)v.push(y[x]+g)}}return{positions:h,cells:f,vectors:p,vertexIntensity:d,colormap:e}}(g,t.colormap,S,M);return h?U.tubeScale=h:(0===S&&(S=1),U.tubeScale=.5*u*M/S),U};var c=r(6740),u=r(6405).createMesh;t.exports.createTubeMesh=function(t,e){return u(t,e,{shaders:c,traceType:\"streamtube\"})}},990:function(t,e,r){var n=r(9405),i=r(3236),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  mat4 objectOffsetTranslation = mat4(1.0) + mat4(vec4(0), vec4(0), vec4(0), vec4(objectOffset, 0));\\n  vec4 worldPosition = (model * objectOffsetTranslation) * vec4(localCoordinate, 1.0);\\n  vec4 clipPosition = projection * (view * worldPosition);\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if (\\n    kill > 0.0 ||\\n    vColor.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\\n  ) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  mat4 objectOffsetTranslation = mat4(1.0) + mat4(vec4(0), vec4(0), vec4(0), vec4(objectOffset, 0));\\n  vec4 worldPosition = (model * objectOffsetTranslation) * vec4(dataCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * (view * worldPosition);\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);e.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},e.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},e.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},e.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},9499:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.gl,r=v(e),n=_(e),s=x(e),l=b(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),m=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);m.minFilter=e.LINEAR,m.magFilter=e.LINEAR;var g=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,m,s,l,h,f,p,d,[0,0,0]),y={levels:[[],[],[]]};for(var T in t)y[T]=t[T];return y.colormap=y.colormap||\"jet\",g.update(y),g};var n=r(8828),i=r(2762),a=r(8116),o=r(7766),s=r(1888),l=r(6729),c=r(5298),u=r(9994),h=r(9618),f=r(3711),p=r(6760),d=r(7608),m=r(2478),g=r(6199),y=r(990),v=y.createShader,x=y.createContourShader,_=y.createPickShader,b=y.createPickContourShader,w=40,T=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],k=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,m,g){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=g,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=m,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.genColormap=function(t,e){var r=!1,n=u([l({colormap:t,nshades:S,format:\"rgba\"}).map((function(t,n){var i=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(n/255,e):t[3];return i<1&&(r=!0),[t[0],t[1],t[2],255*i]}))]);return c.divseq(n,255),this.hasAlphaScale=r,n},C.isTransparent=function(){return this.opacity<1||this.hasAlphaScale},C.isOpaque=function(){return!this.isTransparent()},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],I={showSurface:!1,showContour:!1,projections:[T.slice(),T.slice(),T.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function P(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=I.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=I.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return I.showSurface=o,I.showContour=s,I}var z={model:T,view:T,projection:T,inverseModel:T.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},O=T.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||T,n.view=t.view||T,n.projection=t.projection||T,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=O;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=P(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var m=0;m<this.contourLevels[o].length;++m)m===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==m&&m-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][m]&&(h.uniforms.height=this.contourLevels[o][m],f.draw(r.LINES,this._contourCounts[o][m],this._contourOffsets[o][m]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:T,view:T,projection:T,inverseModel:T,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||T,r.view=t.view||T,r.projection=t.projection||T,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=P(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,g=h*(f?l:1-l),y=0;y<3;++y)c[y]+=this._field[y].get(p,d)*g;for(var v=this._pickResult.level,x=0;x<3;++x)if(v[x]=m.le(this.contourLevels[x],c[x]),v[x]<0)this.contourLevels[x].length>0&&(v[x]=0);else if(v[x]<this.contourLevels[x].length-1){var _=this.contourLevels[x][v[x]],b=this.contourLevels[x][v[x]+1];Math.abs(_-c[x])>Math.abs(b-c[x])&&(v[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],y=0;y<3;++y)r.dataCoordinate[y]=this._field[y].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,(function(t){return B(t,Boolean)}))),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0),\"colormap\"in t&&this._colorMap.setPixels(this.genColormap(t.colormap,this.opacityscale));var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var l=t.coords;if(!Array.isArray(l)||3!==l.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var c=l[o];for(y=0;y<2;++y)if(c.shape[y]!==a[y])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],c)}}else if(t.ticks){var u=t.ticks;if(!Array.isArray(u)||2!==u.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var p=u[o];if((Array.isArray(p)||p.length)&&(p=h(p)),p.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var d=h(p.data,a);d.stride[o]=p.stride[0],d.stride[1^o]=0,this.padField(this._field[o],d)}}else{for(o=0;o<2;++o){var m=[0,0];m[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],m,0)}this._field[0].set(0,0,0);for(var y=0;y<a[0];++y)this._field[0].set(y+1,0,y);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),y=0;y<a[1];++y)this._field[1].set(0,y+1,y);this._field[1].set(0,a[1]+1,a[1]-1)}var v=this._field,x=h(s.mallocFloat(3*v[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)g(x.pick(o),v[o],\"mirror\");var _=h(s.mallocFloat(3*v[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(y=0;y<a[1]+2;++y){var b=x.get(0,o,y,0),w=x.get(0,o,y,1),T=x.get(1,o,y,0),A=x.get(1,o,y,1),M=x.get(2,o,y,0),S=x.get(2,o,y,1),E=T*S-A*M,C=M*w-S*b,L=b*A-w*T,I=Math.sqrt(E*E+C*C+L*L);I<1e-8?(I=Math.max(Math.abs(E),Math.abs(C),Math.abs(L)))<1e-8?(L=1,C=E=0,I=1):I=1/I:I=1/Math.sqrt(I),_.set(o,y,0,E*I),_.set(o,y,1,C*I),_.set(o,y,2,L*I)}s.free(x.data);var P=[1/0,1/0,1/0],z=[-1/0,-1/0,-1/0],O=1/0,D=-1/0,R=(a[0]-1)*(a[1]-1)*6,F=s.mallocFloat(n.nextPow2(10*R)),N=0,U=0;for(o=0;o<a[0]-1;++o)t:for(y=0;y<a[1]-1;++y){for(var V=0;V<2;++V)for(var q=0;q<2;++q)for(var H=0;H<3;++H){var G=this._field[H].get(1+o+V,1+y+q);if(isNaN(G)||!isFinite(G))continue t}for(H=0;H<6;++H){var Z=o+k[H][0],W=y+k[H][1],Y=this._field[0].get(Z+1,W+1),X=this._field[1].get(Z+1,W+1);G=this._field[2].get(Z+1,W+1),E=_.get(Z+1,W+1,0),C=_.get(Z+1,W+1,1),L=_.get(Z+1,W+1,2),t.intensity&&($=t.intensity.get(Z,W));var $=t.intensity?t.intensity.get(Z,W):G+this.objectOffset[2];F[N++]=Z,F[N++]=W,F[N++]=Y,F[N++]=X,F[N++]=G,F[N++]=0,F[N++]=$,F[N++]=E,F[N++]=C,F[N++]=L,P[0]=Math.min(P[0],Y+this.objectOffset[0]),P[1]=Math.min(P[1],X+this.objectOffset[1]),P[2]=Math.min(P[2],G+this.objectOffset[2]),O=Math.min(O,$),z[0]=Math.max(z[0],Y+this.objectOffset[0]),z[1]=Math.max(z[1],X+this.objectOffset[1]),z[2]=Math.max(z[2],G+this.objectOffset[2]),D=Math.max(D,$),U+=1}}for(t.intensityBounds&&(O=+t.intensityBounds[0],D=+t.intensityBounds[1]),o=6;o<N;o+=10)F[o]=(F[o]-O)/(D-O);this._vertexCount=U,this._coordinateBuffer.update(F.subarray(0,N)),s.freeFloat(F),s.free(_.data),this.bounds=[P,z],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===O&&this.intensityBounds[1]===D||(r=!0),this.intensityBounds=[O,D]}if(\"levels\"in t){var J=t.levels;for(J=Array.isArray(J[0])?J.slice():[[],[],J],o=0;o<3;++o)J[o]=J[o].slice(),J[o].sort((function(t,e){return t-e}));for(o=0;o<3;++o)for(y=0;y<J[o].length;++y)J[o][y]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(J[o].length!==this.contourLevels[o].length){r=!0;break}for(y=0;y<J[o].length;++y)if(J[o][y]!==this.contourLevels[o][y]){r=!0;break t}}this.contourLevels=J}if(r){v=this._field,a=this.shape;for(var K=[],Q=0;Q<3;++Q){var tt=this.contourLevels[Q],et=[],rt=[],nt=[0,0,0];for(o=0;o<tt.length;++o){var it=f(this._field[Q],tt[o]);et.push(K.length/5|0),U=0;t:for(y=0;y<it.cells.length;++y){var at=it.cells[y];for(H=0;H<2;++H){var ot=it.positions[at[H]],st=ot[0],lt=0|Math.floor(st),ct=st-lt,ut=ot[1],ht=0|Math.floor(ut),ft=ut-ht,pt=!1;e:for(var dt=0;dt<3;++dt){nt[dt]=0;var mt=(Q+dt+1)%3;for(V=0;V<2;++V){var gt=V?ct:1-ct;for(Z=0|Math.min(Math.max(lt+V,0),a[0]),q=0;q<2;++q){var yt=q?ft:1-ft;if(W=0|Math.min(Math.max(ht+q,0),a[1]),G=dt<2?this._field[mt].get(Z,W):(this.intensity.get(Z,W)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(G)||isNaN(G)){pt=!0;break e}var vt=gt*yt;nt[dt]+=vt*G}}}if(pt){if(H>0){for(var xt=0;xt<5;++xt)K.pop();U-=1}continue t}K.push(nt[0],nt[1],ot[0],ot[1],nt[2]),U+=1}}rt.push(U)}this._contourOffsets[Q]=et,this._contourCounts[Q]=rt}var _t=s.mallocFloat(K.length);for(o=0;o<K.length;++o)_t[o]=K[o];this._contourBuffer.update(_t),s.freeFloat(_t)}},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),m=d.cells,g=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<m.length;++e)for(var y=m[e],v=0;v<2;++v){var x=g[y[v]],_=+x[0],b=0|_,w=0|Math.min(b+1,i[0]),T=_-b,k=1-T,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=k*C,I=k*E,P=T*C,z=T*E,O=L*h.get(b,M)+I*h.get(b,S)+P*h.get(w,M)+z*h.get(w,S),D=L*p.get(b,M)+I*p.get(b,S)+P*p.get(w,M)+z*p.get(w,S);if(isNaN(O)||isNaN(D)){v&&(n-=1);break}a[2*n+0]=O,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},7766:function(t,e,r){\"use strict\";var n=r(9618),i=r(5298),a=r(1888);t.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");if(o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t),\"number\"==typeof arguments[1])return g(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return g(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,g=0;if(2===o.length)g=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])g=t.ALPHA;else if(2===o[2])g=t.LUMINANCE_ALPHA;else if(3===o[2])g=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");g=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var y=e.size;if(l)h=0===e.offset&&e.data.length===y?e.data:e.data.subarray(e.offset,e.offset+y);else{var v=[o[2],o[2]*o[0],1];p=a.malloc(y,r);var x=n(p,o,v,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,y)}var _=m(t);return t.texImage2D(t.TEXTURE_2D,0,g,o[0],o[1],0,g,c,h),l||a.free(p),new f(t,_,o[0],o[1],g,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function m(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function g(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l)this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l);else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var m=0,g=0,y=d(p,h.stride.slice());if(\"float32\"===f?m=t.FLOAT:\"float64\"===f?(m=t.FLOAT,y=!1,f=\"float32\"):\"uint8\"===f?m=t.UNSIGNED_BYTE:(m=t.UNSIGNED_BYTE,y=!1,f=\"uint8\"),2===p.length)g=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])g=t.ALPHA;else if(2===p[2])g=t.LUMINANCE_ALPHA;else if(3===p[2])g=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");g=t.RGBA}p[2]}if(g!==t.LUMINANCE&&g!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(g=s),g!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var v=h.size,x=c.indexOf(o)<0;if(x&&c.push(o),m===l&&y)0===h.offset&&h.data.length===v?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+v)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+v));else{var _;_=l===t.FLOAT?a.mallocFloat32(v):a.mallocUint8(v);var b=n(_,p,[p[2],p[2]*p[0],1]);m===t.FLOAT&&l===t.UNSIGNED_BYTE?u(b,h):i.assign(b,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,_.subarray(0,v)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,_.subarray(0,v)),l===t.FLOAT?a.freeFloat32(_):a.freeUint8(_)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},1433:function(t){\"use strict\";t.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},870:function(t,e,r){\"use strict\";var n=r(1433);function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},t.exports=function(t){return new i(t)}},7518:function(t,e,r){\"use strict\";var n=r(1433);function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},t.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},8116:function(t,e,r){\"use strict\";var n=r(7518),i=r(870);function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}t.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},5632:function(t){t.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},8192:function(t,e,r){t.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=r(2825),i=r(3536),a=r(244)},9226:function(t){t.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},3126:function(t){t.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},3990:function(t){t.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},1091:function(t){t.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},5911:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},5455:function(t,e,r){t.exports=r(7056)},7056:function(t){t.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},4008:function(t,e,r){t.exports=r(6690)},6690:function(t){t.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},244:function(t){t.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},2613:function(t){t.exports=1e-6},9922:function(t,e,r){t.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=r(2613)},9265:function(t){t.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},2681:function(t){t.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},5137:function(t,e,r){t.exports=function(t,e,r,i,a,o){var s,l;for(e||(e=3),r||(r=0),l=i?Math.min(i*e+r,t.length):t.length,s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=r(1091)()},2825:function(t){t.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},2931:function(t,e,r){t.exports={EPSILON:r(2613),create:r(1091),clone:r(3126),angle:r(8192),fromValues:r(2825),copy:r(3990),set:r(1463),equals:r(9922),exactEquals:r(9265),add:r(5632),subtract:r(6843),sub:r(2229),multiply:r(5847),mul:r(4505),divide:r(6690),div:r(4008),min:r(8107),max:r(7417),floor:r(2681),ceil:r(9226),round:r(2447),scale:r(6621),scaleAndAdd:r(8489),distance:r(7056),dist:r(5455),squaredDistance:r(2953),sqrDist:r(6141),length:r(1387),len:r(868),squaredLength:r(3066),sqrLen:r(5486),negate:r(5093),inverse:r(811),normalize:r(3536),dot:r(244),cross:r(5911),lerp:r(6658),random:r(7636),transformMat4:r(5673),transformMat3:r(492),transformQuat:r(264),rotateX:r(6894),rotateY:r(109),rotateZ:r(8692),forEach:r(5137)}},811:function(t){t.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},868:function(t,e,r){t.exports=r(1387)},1387:function(t){t.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},6658:function(t){t.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},7417:function(t){t.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},8107:function(t){t.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},4505:function(t,e,r){t.exports=r(5847)},5847:function(t){t.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},5093:function(t){t.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},3536:function(t){t.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a),t}},7636:function(t){t.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},6894:function(t){t.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},109:function(t){t.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},8692:function(t){t.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},2447:function(t){t.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},6621:function(t){t.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},8489:function(t){t.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},1463:function(t){t.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},6141:function(t,e,r){t.exports=r(2953)},5486:function(t,e,r){t.exports=r(3066)},2953:function(t){t.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},3066:function(t){t.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},2229:function(t,e,r){t.exports=r(6843)},6843:function(t){t.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},492:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},5673:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},264:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},4361:function(t){t.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},2335:function(t){t.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},2933:function(t){t.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},7536:function(t){t.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},4691:function(t){t.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},1373:function(t){t.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},3750:function(t){t.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},3390:function(t){t.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},9970:function(t,e,r){t.exports={create:r(7536),clone:r(2335),fromValues:r(3390),copy:r(2933),set:r(4578),add:r(4361),subtract:r(6860),multiply:r(3576),divide:r(1373),min:r(2334),max:r(160),scale:r(9288),scaleAndAdd:r(4844),distance:r(4691),squaredDistance:r(7960),length:r(6808),squaredLength:r(483),negate:r(1498),inverse:r(4494),normalize:r(5177),dot:r(3750),lerp:r(2573),random:r(9131),transformMat4:r(5352),transformQuat:r(4041)}},4494:function(t){t.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},6808:function(t){t.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},2573:function(t){t.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},160:function(t){t.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},2334:function(t){t.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},3576:function(t){t.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},1498:function(t){t.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},5177:function(t){t.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;return o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o),t}},9131:function(t,e,r){var n=r(5177),i=r(9288);t.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},9288:function(t){t.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},4844:function(t){t.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},4578:function(t){t.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},7960:function(t){t.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},483:function(t){t.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},6860:function(t){t.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},5352:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},4041:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},1848:function(t,e,r){var n=r(4905),i=r(6468);t.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},5874:function(t,e,r){t.exports=function(t){var e,r,T,k=0,A=0,M=l,S=[],E=[],C=1,L=0,I=0,P=!1,z=!1,O=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);var F={},B={};for(k=0;k<D.length;k++)F[D[k]]=!0;for(k=0;k<R.length;k++)B[R[k]]=!0;return function(t){return E=[],null!==t?function(t){var r;for(k=0,t.toString&&(t=t.toString()),O+=t.replace(/\\r\\n/g,\"\\n\"),T=O.length;e=O[k],k<T;){switch(r=k,M){case u:k=q();break;case h:case f:k=V();break;case p:k=H();break;case d:k=W();break;case b:k=Z();break;case m:k=Y();break;case c:k=X();break;case x:k=U();break;case l:k=j()}r!==k&&(\"\\n\"===O[r]?(L=0,++C):++L)}return A+=k,O=O.slice(k),E}(t):(S.length&&N(S.join(\"\")),M=_,N(\"(eof)\"),E)};function N(t){t.length&&E.push({type:w[M],data:t,position:I,line:C,column:L})}function j(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(I=A+k-1,M=u,r=e,k+1):\"/\"===r&&\"/\"===e?(I=A+k-1,M=h,r=e,k+1):\"#\"===e?(M=f,I=A+k,k):/\\s/.test(e)?(M=x,I=A+k,k):(P=/\\d/.test(e),z=/[^\\w_]/.test(e),I=A+k,M=P?d:z?p:c,k)}function U(){return/[^\\s]/g.test(e)?(N(S.join(\"\")),M=l,k):(S.push(e),r=e,k+1)}function V(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,k+1):(N(S.join(\"\")),M=l,k)}function q(){return\"/\"===e&&\"*\"===r?(S.push(e),N(S.join(\"\")),M=l,k+1):(S.push(e),r=e,k+1)}function H(){if(\".\"===r&&/\\d/.test(e))return M=m,k;if(\"/\"===r&&\"*\"===e)return M=u,k;if(\"/\"===r&&\"/\"===e)return M=h,k;if(\".\"===e&&S.length){for(;G(S););return M=m,k}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;G(S););return N(e),M=l,k+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;G(S););return M=l,k}return S.push(e),r=e,k+1}function G(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return N(r),I+=r.length,(S=S.slice(r.length)).length}}function Z(){return/[^a-fA-F0-9]/.test(e)?(N(S.join(\"\")),M=l,k):(S.push(e),r=e,k+1)}function W(){return\".\"===e||/[eE]/.test(e)?(S.push(e),M=m,r=e,k+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=b,S.push(e),r=e,k+1):/[^\\d]/.test(e)?(N(S.join(\"\")),M=l,k):(S.push(e),r=e,k+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,k+=1),/[eE]/.test(e)?(S.push(e),r=e,k+1):(\"-\"!==e&&\"+\"!==e||!/[eE]/.test(r))&&/[^\\d]/.test(e)?(N(S.join(\"\")),M=l,k):(S.push(e),r=e,k+1)}function X(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=B[t]?v:F[t]?y:g,N(S.join(\"\")),M=l,k}return S.push(e),r=e,k+1}};var n=r(620),i=r(7827),a=r(6852),o=r(7932),s=r(3508),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,m=5,g=6,y=7,v=8,x=9,_=10,b=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},3508:function(t,e,r){var n=r(6852);n=n.slice().filter((function(t){return!/^(gl\\_|texture)/.test(t)})),t.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},6852:function(t){t.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},7932:function(t,e,r){var n=r(620);t.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},620:function(t){t.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"uint\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},7827:function(t){t.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},4905:function(t,e,r){var n=r(5874);t.exports=function(t,e){var r=n(e),i=[];return(i=i.concat(r(t))).concat(r(null))}},3236:function(t){t.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},7520:function(t,e,r){\"use strict\";var n=r(9507);t.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},3778:function(t,e){e.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},e.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,m=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*m}},8954:function(t,e,r){\"use strict\";t.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2);for(u=0;u<=i;++u){for(var d=l.slice(),m=0;m<=i;++m)m===u&&(d[m]=-1);var g=d[0];d[0]=d[1],d[1]=g;var y=new a(d,new Array(i+1),!0);f[u]=y,p[u]=y}for(p[i+1]=h,u=0;u<=i;++u){d=f[u].vertices;var v=f[u].adjacent;for(m=0;m<=i;++m){var x=d[m];if(x<0)v[m]=h;else for(var _=0;_<=i;++_)f[_].vertices.indexOf(x)<0&&(v[m]=f[_])}}var b=new c(i,o,p),w=!!e;for(u=i+1;u<r;++u)b.insert(t[u],w);return b.boundary()};var n=r(3250),i=r(6803).Fw;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter((function(t){return!t.boundary})),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a,o=l[t];o||(o=l[t]=((a=n[t+1])||(a=n),function(t){return function(){var e=this.tuple;return t.apply(this,e)}}(a))),this.orient=o}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;)for(var s=(t=o.pop()).adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];for(s.lastVisited=r,u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,m=p.indexOf(r);if(!(m<0))for(var g=0;g<=n;++g)if(g!==m){var y=d[g];if(y.boundary&&!(y.lastVisited>=r)){var v=y.vertices;if(y.lastVisited!==-r){for(var x=0,_=0;_<=n;++_)v[_]<0?(x=_,l[_]=t):l[_]=i[v[_]];if(this.orient()>0){v[x]=r,y.boundary=!1,c.push(y),h.push(y),y.lastVisited=r;continue}y.lastVisited=-r}var b=y.adjacent,w=p.slice(),T=d.slice(),k=new a(w,T,!0);u.push(k);var A=b.indexOf(e);if(!(A<0))for(b[A]=k,T[m]=y,w[g]=-1,T[g]=e,d[g]=k,k.flip(),_=0;_<=n;++_){var M=w[_];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===_||(S[E++]=L)}f.push(new o(S,k,_))}}}}}for(f.sort(s),g=0;g+1<f.length;g+=2){var I=f[g],P=f[g+1],z=I.index,O=P.index;z<0||O<0||(I.cell.adjacent[I.index]=P.cell,P.cell.adjacent[P.index]=I.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},3352:function(t,e,r){\"use strict\";var n=r(2478);function i(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}t.exports=function(t){return t&&0!==t.length?new y(g(t)):new y(null)};var a=i.prototype;function o(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function s(t,e){var r=g(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function l(t,e){var r=t.intervals([]);r.push(e),s(t,r)}function c(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?0:(r.splice(n,1),s(t,r),1)}function u(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function h(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function f(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function p(t,e){return t-e}function d(t,e){return t[0]-e[0]||t[1]-e[1]}function m(t,e){return t[1]-e[1]||t[0]-e[0]}function g(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(p);var n=e[e.length>>1],a=[],o=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?o.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(d),u.sort(m),new i(n,g(a),g(o),c,u)}function y(t){this.root=t}a.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},a.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?l(this,t):this.left.insert(t):this.left=g([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?l(this,t):this.right.insert(t):this.right=g([t]);else{var r=n.ge(this.leftPoints,t,d),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},a.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?c(this,t):2===(s=this.left.remove(t))?(this.left=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?c(this,t):2===(s=this.right.remove(t))?(this.right=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(1===this.count)return this.leftPoints[0]===t?2:0;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,i=this.left;i.right;)r=i,i=i.right;if(r===this)i.right=this.right;else{var a=this.left,s=this.right;r.count-=i.count,r.right=i.left,i.left=a,i.right=s}o(this,i),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?o(this,this.left):o(this,this.right);return 1}for(a=n.ge(this.leftPoints,t,d);a<this.leftPoints.length&&this.leftPoints[a][0]===t[0];++a)if(this.leftPoints[a]===t)for(this.count-=1,this.leftPoints.splice(a,1),s=n.ge(this.rightPoints,t,m);s<this.rightPoints.length&&this.rightPoints[s][1]===t[1];++s)if(this.rightPoints[s]===t)return this.rightPoints.splice(s,1),1;return 0},a.queryPoint=function(t,e){return t<this.mid?this.left&&(r=this.left.queryPoint(t,e))?r:u(this.leftPoints,t,e):t>this.mid?this.right&&(r=this.right.queryPoint(t,e))?r:h(this.rightPoints,t,e):f(this.leftPoints,e);var r},a.queryInterval=function(t,e,r){var n;return t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r))||e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r))?n:e<this.mid?u(this.leftPoints,e,r):t>this.mid?h(this.rightPoints,t,r):f(this.leftPoints,r)};var v=y.prototype;v.insert=function(t){this.root?this.root.insert(t):this.root=new i(t[0],null,null,[t],[t])},v.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),0!==e}return!1},v.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},v.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(v,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(v,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},7762:function(t){\"use strict\";t.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},9507:function(t){t.exports=!0},7163:function(t){function e(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}t.exports=function(t){return null!=t&&(e(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&e(t.slice(0,0))}(t)||!!t._isBuffer)}},5219:function(t){\"use strict\";t.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},395:function(t){t.exports=function(t,e,r){return t*(1-r)+e*r}},2652:function(t,e,r){var n=r(4335),i=r(6864),a=r(1903),o=r(9921),s=r(7608),l=r(5665),c={length:r(1387),normalize:r(3536),dot:r(244),cross:r(5911)},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function m(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}t.exports=function(t,e,r,i,g,y){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),g||(g=[0,0,0,1]),y||(y=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var v,x,_,b,w,T,k,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],I=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=I,!s(h,h))return!1;l(h,h),v=g,_=h,b=(x=f)[0],w=x[1],T=x[2],k=x[3],v[0]=_[0]*b+_[4]*w+_[8]*T+_[12]*k,v[1]=_[1]*b+_[5]*w+_[9]*T+_[13]*k,v[2]=_[2]*b+_[6]*w+_[10]*T+_[14]*k,v[3]=_[3]*b+_[7]*w+_[11]*T+_[15]*k}else g[0]=g[1]=g[2]=0,g[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),m(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),m(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),m(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var P=0;P<3;P++)r[P]*=-1,p[P][0]*=-1,p[P][1]*=-1,p[P][2]*=-1;return y[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),y[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),y[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),y[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(y[0]=-y[0]),p[0][2]>p[2][0]&&(y[1]=-y[1]),p[1][0]>p[0][1]&&(y[2]=-y[2]),!0}},4335:function(t){t.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},7442:function(t,e,r){var n=r(6658),i=r(7182),a=r(2652),o=r(9921),s=r(8648),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}t.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},7182:function(t,e,r){var n={identity:r(7894),translate:r(7656),multiply:r(6760),create:r(6864),scale:r(2504),fromRotationTranslation:r(6743)},i=(n.create(),n.create());t.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},4192:function(t,e,r){\"use strict\";var n=r(2478),i=r(7442),a=r(7608),o=r(5567),s=r(2408),l=r(7089),c=r(6582),u=r(7656),h=(r(2504),r(3536)),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}t.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var m=this.computedUp;m[0]=o[1],m[1]=o[5],m[2]=o[9],h(m,m);var g=this.computedInverse;a(g,o);var y=this.computedEye,v=g[15];y[0]=g[12]/v,y[1]=g[13]/v,y[2]=g[14]/v;var x=this.computedCenter,_=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=y[c]-o[2+4*c]*_}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var m=[0,0,0];d.pan=function(t,e,r,n){m[0]=-(e||0),m[1]=-(r||0),m[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,m),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){m[0]=e||0,m[1]=r||0,m[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,m),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},3090:function(t,e,r){\"use strict\";t.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}var a=new Array(e);for(i=0;i<e;++i)a[i]=i;a.sort((function(e,r){return t[e][0]-t[r][0]||t[e][1]-t[r][1]}));var o=[a[0],a[1]],s=[a[0],a[1]];for(i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}r=new Array(s.length+o.length-2);for(var h=0,f=(i=0,o.length);i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=r(3250)[3]},351:function(t,e,r){\"use strict\";t.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function m(t){c(r&~n.buttons(t),t)}function g(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",m),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}g();var y={element:t};return Object.defineProperties(y,{enabled:{get:function(){return s},set:function(e){e?g():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",m),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),y};var n=r(4687)},24:function(t){var e={left:0,top:0};t.exports=function(t,r,n){r=r||t.currentTarget||t.srcElement,Array.isArray(n)||(n=[0,0]);var i,a=t.clientX||0,o=t.clientY||0,s=(i=r)===window||i===document||i===document.body?e:i.getBoundingClientRect();return n[0]=a-s.left,n[1]=o-s.top,n}},4687:function(t,e){\"use strict\";function r(t){return t.target||t.srcElement||window}e.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},e.element=r,e.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=r(t).getBoundingClientRect();return t.clientX-e.left}return 0},e.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=r(t).getBoundingClientRect();return t.clientY-e.top}return 0}},8512:function(t,e,r){\"use strict\";var n=r(665);t.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=i;break;case 2:s=window.innerHeight}if(a*=s,o*=s,(n*=s)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},2640:function(t,e,r){\"use strict\";var n=r(1888);t.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var a=t.arrayArguments||1;a<1&&e(\"Must have at least one array argument\"),(t.scalarArguments||0)<0&&e(\"Scalar arg count must be > 0\"),\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\"),\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\"),\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var o=t.getters||[],s=new Array(a),l=0;l<a;++l)o.indexOf(l)>=0?s[l]=!0:s[l]=!1;return function(t,e,r,a,o,s){var l=[s,o].join(\",\");return(0,i[l])(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,0,r,s)};var i={\"false,0,1\":function(t,e,r,n,i){return function(a,o,s,l){var c,u=0|a.shape[0],h=0|a.shape[1],f=a.data,p=0|a.offset,d=0|a.stride[0],m=0|a.stride[1],g=p,y=0|-d,v=0,x=0|-m,_=0,b=-d-m|0,w=0,T=0|d,k=m-d*u|0,A=0,M=0,S=0,E=2*u|0,C=n(E),L=n(E),I=0,P=0,z=-1,O=-1,D=0,R=0|-u,F=0|u,B=0,N=-u-1|0,j=u-1|0,U=0,V=0,q=0;for(A=0;A<u;++A)C[I++]=r(f[g],o,s,l),g+=T;if(g+=k,h>0){if(M=1,C[I++]=r(f[g],o,s,l),g+=T,u>0)for(A=1,c=f[g],P=C[I]=r(c,o,s,l),D=C[I+z],B=C[I+R],U=C[I+N],P===D&&P===B&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,D,B,U,o,s,l),V=L[I]=S++),I+=1,g+=T,A=2;A<u;++A)c=f[g],P=C[I]=r(c,o,s,l),D=C[I+z],B=C[I+R],U=C[I+N],P===D&&P===B&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,D,B,U,o,s,l),V=L[I]=S++,U!==D&&e(L[I+z],V,w,v,U,D,o,s,l)),I+=1,g+=T;for(g+=k,I=0,q=z,z=O,O=q,q=R,R=F,F=q,q=N,N=j,j=q,M=2;M<h;++M){if(C[I++]=r(f[g],o,s,l),g+=T,u>0)for(A=1,c=f[g],P=C[I]=r(c,o,s,l),D=C[I+z],B=C[I+R],U=C[I+N],P===D&&P===B&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,D,B,U,o,s,l),V=L[I]=S++,U!==B&&e(L[I+R],V,_,w,B,U,o,s,l)),I+=1,g+=T,A=2;A<u;++A)c=f[g],P=C[I]=r(c,o,s,l),D=C[I+z],B=C[I+R],U=C[I+N],P===D&&P===B&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,D,B,U,o,s,l),V=L[I]=S++,U!==B&&e(L[I+R],V,_,w,B,U,o,s,l),U!==D&&e(L[I+z],V,w,v,U,D,o,s,l)),I+=1,g+=T;1&M&&(I=0),q=z,z=O,O=q,q=R,R=F,F=q,q=N,N=j,j=q,g+=k}}i(L),i(C)}},\"false,1,0\":function(t,e,r,n,i){return function(a,o,s,l){var c,u=0|a.shape[0],h=0|a.shape[1],f=a.data,p=0|a.offset,d=0|a.stride[0],m=0|a.stride[1],g=p,y=0|-d,v=0,x=0|-m,_=0,b=-d-m|0,w=0,T=0|m,k=d-m*h|0,A=0,M=0,S=0,E=2*h|0,C=n(E),L=n(E),I=0,P=0,z=-1,O=-1,D=0,R=0|-h,F=0|h,B=0,N=-h-1|0,j=h-1|0,U=0,V=0,q=0;for(M=0;M<h;++M)C[I++]=r(f[g],o,s,l),g+=T;if(g+=k,u>0){if(A=1,C[I++]=r(f[g],o,s,l),g+=T,h>0)for(M=1,c=f[g],P=C[I]=r(c,o,s,l),B=C[I+R],D=C[I+z],U=C[I+N],P===B&&P===D&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,B,D,U,o,s,l),V=L[I]=S++),I+=1,g+=T,M=2;M<h;++M)c=f[g],P=C[I]=r(c,o,s,l),B=C[I+R],D=C[I+z],U=C[I+N],P===B&&P===D&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,B,D,U,o,s,l),V=L[I]=S++,U!==D&&e(L[I+z],V,_,w,D,U,o,s,l)),I+=1,g+=T;for(g+=k,I=0,q=R,R=F,F=q,q=z,z=O,O=q,q=N,N=j,j=q,A=2;A<u;++A){if(C[I++]=r(f[g],o,s,l),g+=T,h>0)for(M=1,c=f[g],P=C[I]=r(c,o,s,l),B=C[I+R],D=C[I+z],U=C[I+N],P===B&&P===D&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,B,D,U,o,s,l),V=L[I]=S++,U!==B&&e(L[I+R],V,w,v,U,B,o,s,l)),I+=1,g+=T,M=2;M<h;++M)c=f[g],P=C[I]=r(c,o,s,l),B=C[I+R],D=C[I+z],U=C[I+N],P===B&&P===D&&P===U||(v=f[g+y],_=f[g+x],w=f[g+b],t(A,M,c,v,_,w,P,B,D,U,o,s,l),V=L[I]=S++,U!==D&&e(L[I+z],V,_,w,D,U,o,s,l),U!==B&&e(L[I+R],V,w,v,U,B,o,s,l)),I+=1,g+=T;1&A&&(I=0),q=R,R=F,F=q,q=z,z=O,O=q,q=N,N=j,j=q,g+=k}}i(L),i(C)}}}},6199:function(t,e,r){\"use strict\";var n=r(1338),i={zero:function(t,e,r,n){var i=t[0];n|=0;var a=0,o=r[0];for(a=0;a<i;++a)e[n]=0,n+=o},fdTemplate1:function(t,e,r,n,i,a,o){var s=t[0],l=r[0],c=-1*l,u=l;n|=0,o|=0;var h=0,f=l,p=a[0];for(h=0;h<s;++h)i[o]=.5*(e[n+c]-e[n+u]),n+=f,o+=p},fdTemplate2:function(t,e,r,n,i,a,o,s,l,c){var u=t[0],h=t[1],f=r[0],p=r[1],d=a[0],m=a[1],g=l[0],y=l[1],v=-1*f,x=f,_=-1*p,b=p;n|=0,o|=0,c|=0;var w=0,T=0,k=p,A=f-h*p,M=m,S=d-h*m,E=y,C=g-h*y;for(T=0;T<u;++T){for(w=0;w<h;++w)i[o]=.5*(e[n+v]-e[n+x]),s[c]=.5*(e[n+_]-e[n+b]),n+=k,o+=M,c+=E;n+=A,o+=S,c+=C}}},a={cdiff:function(t){var e={};return function(r,n,i){var a=r.dtype,o=r.order,s=n.dtype,l=n.order,c=i.dtype,u=i.order,h=[a,o.join(),s,l.join(),c,u.join()].join(),f=e[h];return f||(e[h]=f=t([a,o,s,l,c,u])),f(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset,i.data,i.stride,0|i.offset)}},zero:function(t){var e={};return function(r){var n=r.dtype,i=r.order,a=[n,i.join()].join(),o=e[a];return o||(e[a]=o=t([n,i])),o(r.shape.slice(0),r.data,r.stride,0|r.offset)}},fdTemplate1:function(t){var e={};return function(r,n){var i=r.dtype,a=r.order,o=n.dtype,s=n.order,l=[i,a.join(),o,s.join()].join(),c=e[l];return c||(e[l]=c=t([i,a,o,s])),c(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset)}},fdTemplate2:function(t){var e={};return function(r,n,i){var a=r.dtype,o=r.order,s=n.dtype,l=n.order,c=i.dtype,u=i.order,h=[a,o.join(),s,l.join(),c,u.join()].join(),f=e[h];return f||(e[h]=f=t([a,o,s,l,c,u])),f(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset,i.data,i.stride,0|i.offset)}}};function o(t){return(0,a[t.funcName])(s.bind(void 0,t))}function s(t){return i[t.funcName]}function l(t){return o({funcName:t.funcName})}var c={},u={},h=l({funcName:\"cdiff\"}),f=l({funcName:\"zero\"});function p(t){return t in c?c[t]:c[t]=l({funcName:\"fdTemplate\"+t})}function d(t,e,r,n){return function(t,i){var a=i.shape.slice();return a[0]>2&&a[1]>2&&n(i.pick(-1,-1).lo(1,1).hi(a[0]-2,a[1]-2),t.pick(-1,-1,0).lo(1,1).hi(a[0]-2,a[1]-2),t.pick(-1,-1,1).lo(1,1).hi(a[0]-2,a[1]-2)),a[1]>2&&(r(i.pick(0,-1).lo(1).hi(a[1]-2),t.pick(0,-1,1).lo(1).hi(a[1]-2)),e(t.pick(0,-1,0).lo(1).hi(a[1]-2))),a[1]>2&&(r(i.pick(a[0]-1,-1).lo(1).hi(a[1]-2),t.pick(a[0]-1,-1,1).lo(1).hi(a[1]-2)),e(t.pick(a[0]-1,-1,0).lo(1).hi(a[1]-2))),a[0]>2&&(r(i.pick(-1,0).lo(1).hi(a[0]-2),t.pick(-1,0,0).lo(1).hi(a[0]-2)),e(t.pick(-1,0,1).lo(1).hi(a[0]-2))),a[0]>2&&(r(i.pick(-1,a[1]-1).lo(1).hi(a[0]-2),t.pick(-1,a[1]-1,0).lo(1).hi(a[0]-2)),e(t.pick(-1,a[1]-1,1).lo(1).hi(a[0]-2))),t.set(0,0,0,0),t.set(0,0,1,0),t.set(a[0]-1,0,0,0),t.set(a[0]-1,0,1,0),t.set(0,a[1]-1,0,0),t.set(0,a[1]-1,1,0),t.set(a[0]-1,a[1]-1,0,0),t.set(a[0]-1,a[1]-1,1,0),t}}t.exports=function(t,e,r){return Array.isArray(r)||(r=n(e.dimension,\"string\"==typeof r?r:\"clamp\")),0===e.size?t:0===e.dimension?(t.set(0),t):function(t){var e=t.join();if(a=u[e])return a;for(var r=t.length,n=[h,f],i=1;i<=r;++i)n.push(p(i));var a=d.apply(void 0,n);return u[e]=a,a}(r)(t,e)}},4317:function(t){\"use strict\";function e(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function r(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function n(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],m=0<=f+1&&f+1<t.shape[2],g=o&&u&&d?t.get(i,l,f):0,y=o&&h&&d?t.get(i,l+1,f):0,v=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,_=o&&u&&m?t.get(i,l,f+1):0,b=o&&h&&m?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*g+a*v)+c*((1-a)*y+a*x))+p*((1-c)*((1-a)*_+a*(s&&u&&m?t.get(i+1,l,f+1):0))+c*((1-a)*b+a*(s&&h&&m?t.get(i+1,l+1,f+1):0)))}function i(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}t.exports=function(t,a,o,s){switch(t.shape.length){case 0:return 0;case 1:return e(t,a);case 2:return r(t,a,o);case 3:return n(t,a,o,s);default:return i.apply(void 0,arguments)}},t.exports.d1=e,t.exports.d2=r,t.exports.d3=n},5298:function(t,e){\"use strict\";var r={\"float64,2,1,0\":function(){return function(t,e,r,n,i){var a=t[0],o=t[1],s=t[2],l=r[0],c=r[1],u=r[2];n|=0;var h=0,f=0,p=0,d=u,m=c-s*u,g=l-o*c;for(p=0;p<a;++p){for(f=0;f<o;++f){for(h=0;h<s;++h)e[n]/=i,n+=d;n+=m}n+=g}}},\"uint8,2,0,1,float64,2,1,0\":function(){return function(t,e,r,n,i,a,o,s){for(var l=t[0],c=t[1],u=t[2],h=r[0],f=r[1],p=r[2],d=a[0],m=a[1],g=a[2],y=n|=0,v=o|=0,x=0|t[0];x>0;){x<64?(l=x,x=0):(l=64,x-=64);for(var _=0|t[1];_>0;){_<64?(c=_,_=0):(c=64,_-=64),n=y+x*h+_*f,o=v+x*d+_*m;var b=0,w=0,T=0,k=p,A=h-u*p,M=f-l*h,S=g,E=d-u*g,C=m-l*d;for(T=0;T<c;++T){for(w=0;w<l;++w){for(b=0;b<u;++b)e[n]=i[o]*s,n+=k,o+=S;n+=A,o+=E}n+=M,o+=C}}}}},\"float32,1,0,float32,1,0\":function(){return function(t,e,r,n,i,a,o){var s=t[0],l=t[1],c=r[0],u=r[1],h=a[0],f=a[1];n|=0,o|=0;var p=0,d=0,m=u,g=c-l*u,y=f,v=h-l*f;for(d=0;d<s;++d){for(p=0;p<l;++p)e[n]=i[o],n+=m,o+=y;n+=g,o+=v}}},\"float32,1,0,float32,0,1\":function(){return function(t,e,r,n,i,a,o){for(var s=t[0],l=t[1],c=r[0],u=r[1],h=a[0],f=a[1],p=n|=0,d=o|=0,m=0|t[1];m>0;){m<64?(l=m,m=0):(l=64,m-=64);for(var g=0|t[0];g>0;){g<64?(s=g,g=0):(s=64,g-=64),n=p+m*u+g*c,o=d+m*f+g*h;var y=0,v=0,x=u,_=c-l*u,b=f,w=h-l*f;for(v=0;v<s;++v){for(y=0;y<l;++y)e[n]=i[o],n+=x,o+=b;n+=_,o+=w}}}}},\"uint8,2,0,1,uint8,1,2,0\":function(){return function(t,e,r,n,i,a,o){for(var s=t[0],l=t[1],c=t[2],u=r[0],h=r[1],f=r[2],p=a[0],d=a[1],m=a[2],g=n|=0,y=o|=0,v=0|t[2];v>0;){v<64?(c=v,v=0):(c=64,v-=64);for(var x=0|t[0];x>0;){x<64?(s=x,x=0):(s=64,x-=64);for(var _=0|t[1];_>0;){_<64?(l=_,_=0):(l=64,_-=64),n=g+v*f+x*u+_*h,o=y+v*m+x*p+_*d;var b=0,w=0,T=0,k=f,A=u-c*f,M=h-s*u,S=m,E=p-c*m,C=d-s*p;for(T=0;T<l;++T){for(w=0;w<s;++w){for(b=0;b<c;++b)e[n]=i[o],n+=k,o+=S;n+=A,o+=E}n+=M,o+=C}}}}}},\"uint8,2,0,1,array,2,0,1\":function(){return function(t,e,r,n,i,a,o){var s=t[0],l=t[1],c=t[2],u=r[0],h=r[1],f=r[2],p=a[0],d=a[1],m=a[2];n|=0,o|=0;var g=0,y=0,v=0,x=f,_=u-c*f,b=h-s*u,w=m,T=p-c*m,k=d-s*p;for(v=0;v<l;++v){for(y=0;y<s;++y){for(g=0;g<c;++g)e[n]=i[o],n+=x,o+=w;n+=_,o+=T}n+=b,o+=k}}}},n=function(t,e){var n=e.join(\",\");return(0,r[n])()},i={mul:function(t){var e={};return function(r,n,i){var a=r.dtype,o=r.order,s=n.dtype,l=n.order,c=i.dtype,u=i.order,h=[a,o.join(),s,l.join(),c,u.join()].join(),f=e[h];return f||(e[h]=f=t([a,o,s,l,c,u])),f(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset,i.data,i.stride,0|i.offset)}},muls:function(t){var e={};return function(r,n,i){var a=r.dtype,o=r.order,s=n.dtype,l=n.order,c=[a,o.join(),s,l.join()].join(),u=e[c];return u||(e[c]=u=t([a,o,s,l])),u(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset,i)}},mulseq:function(t){var e={};return function(r,n){var i=r.dtype,a=r.order,o=[i,a.join()].join(),s=e[o];return s||(e[o]=s=t([i,a])),s(r.shape.slice(0),r.data,r.stride,0|r.offset,n)}},div:function(t){var e={};return function(r,n,i){var a=r.dtype,o=r.order,s=n.dtype,l=n.order,c=i.dtype,u=i.order,h=[a,o.join(),s,l.join(),c,u.join()].join(),f=e[h];return f||(e[h]=f=t([a,o,s,l,c,u])),f(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset,i.data,i.stride,0|i.offset)}},divs:function(t){var e={};return function(r,n,i){var a=r.dtype,o=r.order,s=n.dtype,l=n.order,c=[a,o.join(),s,l.join()].join(),u=e[c];return u||(e[c]=u=t([a,o,s,l])),u(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset,i)}},divseq:function(t){var e={};return function(r,n){var i=r.dtype,a=r.order,o=[i,a.join()].join(),s=e[o];return s||(e[o]=s=t([i,a])),s(r.shape.slice(0),r.data,r.stride,0|r.offset,n)}},assign:function(t){var e={};return function(r,n){var i=r.dtype,a=r.order,o=n.dtype,s=n.order,l=[i,a.join(),o,s.join()].join(),c=e[l];return c||(e[l]=c=t([i,a,o,s])),c(r.shape.slice(0),r.data,r.stride,0|r.offset,n.data,n.stride,0|n.offset)}}};function a(t){return e={funcName:t.funcName},(0,i[e.funcName])(n.bind(void 0,e));var e}var o={mul:\"*\",div:\"/\"};!function(){for(var t in o)e[t]=a({funcName:t}),e[t+\"s\"]=a({funcName:t+\"s\"}),e[t+\"seq\"]=a({funcName:t+\"seq\"})}(),e.assign=a({funcName:\"assign\"})},9994:function(t,e,r){\"use strict\";var n=r(9618),i=r(8277);t.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},8277:function(t){\"use strict\";t.exports=function(t){var e={};return function(r,n){var i=r.dtype,a=r.order,o=[i,a.join()].join(),s=e[o];return s||(e[o]=s=t([i,a])),s(r.shape.slice(0),r.data,r.stride,0|r.offset,n)}}(function(){return function(t,e,r,n,i){var a=t[0],o=t[1],s=t[2],l=r[0],c=r[1],u=r[2],h=[0,0,0];n|=0;var f=0,p=0,d=0,m=u,g=c-s*u,y=l-o*c;for(d=0;d<a;++d){for(p=0;p<o;++p){for(f=0;f<s;++f){var v,x=i;for(v=0;v<h.length-1;++v)x=x[h[v]];e[n]=x[h[h.length-1]],n+=m,++h[2]}n+=g,h[2]-=s,++h[1]}n+=y,h[1]-=o,++h[0]}}}.bind(void 0,{funcName:\"convert\"}))},7640:function(t,e,r){\"use strict\";var n=r(1888);function i(t){return\"uint32\"===t?[n.mallocUint32,n.freeUint32]:null}var a={\"uint32,1,0\":function(t,e){return function(r,n,i,a,o,s,l,c,u,h,f){var p,d,m,g,y,v,x,_,b=r*o+a,w=t(c);for(p=r+1;p<=n;++p){for(d=p,m=b+=o,y=0,v=b,g=0;g<c;++g)w[y++]=i[v],v+=u;t:for(;d-- >r;){y=0,v=m-o;e:for(g=0;g<c;++g){if((x=i[v])<(_=w[y]))break t;if(x>_)break e;v+=h,y+=f}for(y=m,v=m-o,g=0;g<c;++g)i[y]=i[v],y+=u,v+=u;m-=o}for(y=m,v=0,g=0;g<c;++g)i[y]=w[v++],y+=u}e(w)}}},o={\"uint32,1,0\":function(t,e,r){return function n(i,a,o,s,l,c,u,h,f,p,d){var m,g,y,v,x,_,b,w,T,k,A,M,S,E,C,L,I,P,z,O,D,R,F,B,N,j=(a-i+1)/6|0,U=i+j,V=a-j,q=i+a>>1,H=q-j,G=q+j,Z=U,W=H,Y=q,X=G,$=V,J=i+1,K=a-1,Q=!0,tt=0,et=0,rt=0,nt=h,it=e(nt),at=e(nt);A=l*Z,M=l*W,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=Z,Z=W,W=g;break t}if(rt<0)break t;N+=p}A=l*X,M=l*$,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=X,X=$,$=g;break t}if(rt<0)break t;N+=p}A=l*Z,M=l*Y,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=Z,Z=Y,Y=g;break t}if(rt<0)break t;N+=p}A=l*W,M=l*Y,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=W,W=Y,Y=g;break t}if(rt<0)break t;N+=p}A=l*Z,M=l*X,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=Z,Z=X,X=g;break t}if(rt<0)break t;N+=p}A=l*Y,M=l*X,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=Y,Y=X,X=g;break t}if(rt<0)break t;N+=p}A=l*W,M=l*$,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=W,W=$,$=g;break t}if(rt<0)break t;N+=p}A=l*W,M=l*Y,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=W,W=Y,Y=g;break t}if(rt<0)break t;N+=p}A=l*X,M=l*$,N=s;t:for(k=0;k<h;++k){if(w=M+N,(rt=o[b=A+N]-o[w])>0){g=X,X=$,$=g;break t}if(rt<0)break t;N+=p}for(A=l*Z,M=l*W,S=l*Y,E=l*X,C=l*$,L=l*U,I=l*q,P=l*V,B=0,N=s,k=0;k<h;++k)b=A+N,w=M+N,T=S+N,z=E+N,O=C+N,D=L+N,R=I+N,F=P+N,it[B]=o[w],at[B]=o[z],Q=Q&&it[B]===at[B],y=o[b],v=o[T],x=o[O],o[D]=y,o[R]=v,o[F]=x,++B,N+=f;for(A=l*H,M=l*i,N=s,k=0;k<h;++k)w=M+N,o[b=A+N]=o[w],N+=f;for(A=l*G,M=l*a,N=s,k=0;k<h;++k)w=M+N,o[b=A+N]=o[w],N+=f;if(Q)for(_=J;_<=K;++_){for(b=s+_*l,B=0,k=0;k<h&&0==(rt=o[b]-it[B]);++k)B+=d,b+=p;if(0!==rt)if(rt<0){if(_!==J)for(A=l*_,M=l*J,N=s,k=0;k<h;++k)w=M+N,m=o[b=A+N],o[b]=o[w],o[w]=m,N+=f;++J}else for(;;){for(b=s+K*l,B=0,k=0;k<h&&0==(rt=o[b]-it[B]);++k)B+=d,b+=p;if(!(rt>0)){if(rt<0){for(A=l*_,M=l*J,S=l*K,N=s,k=0;k<h;++k)w=M+N,T=S+N,m=o[b=A+N],o[b]=o[w],o[w]=o[T],o[T]=m,N+=f;++J,--K;break}for(A=l*_,M=l*K,N=s,k=0;k<h;++k)w=M+N,m=o[b=A+N],o[b]=o[w],o[w]=m,N+=f;--K;break}K--}}else for(_=J;_<=K;++_){for(b=s+_*l,B=0,k=0;k<h&&0==(tt=o[b]-it[B]);++k)B+=d,b+=p;if(tt<0){if(_!==J)for(A=l*_,M=l*J,N=s,k=0;k<h;++k)w=M+N,m=o[b=A+N],o[b]=o[w],o[w]=m,N+=f;++J}else{for(b=s+_*l,B=0,k=0;k<h&&0==(et=o[b]-at[B]);++k)B+=d,b+=p;if(et>0)for(;;){for(b=s+K*l,B=0,k=0;k<h&&0==(rt=o[b]-at[B]);++k)B+=d,b+=p;if(!(rt>0)){for(b=s+K*l,B=0,k=0;k<h&&0==(rt=o[b]-it[B]);++k)B+=d,b+=p;if(rt<0){for(A=l*_,M=l*J,S=l*K,N=s,k=0;k<h;++k)w=M+N,T=S+N,m=o[b=A+N],o[b]=o[w],o[w]=o[T],o[T]=m,N+=f;++J,--K}else{for(A=l*_,M=l*K,N=s,k=0;k<h;++k)w=M+N,m=o[b=A+N],o[b]=o[w],o[w]=m,N+=f;--K}break}if(--K<_)break}}}for(A=l*i,M=l*(J-1),B=0,N=s,k=0;k<h;++k)w=M+N,o[b=A+N]=o[w],o[w]=it[B],++B,N+=f;for(A=l*a,M=l*(K+1),B=0,N=s,k=0;k<h;++k)w=M+N,o[b=A+N]=o[w],o[w]=at[B],++B,N+=f;if(J-2-i<=32?t(i,J-2,o,s,l,c,u,h,f,p,d):n(i,J-2,o,s,l,c,u,h,f,p,d),a-(K+2)<=32?t(K+2,a,o,s,l,c,u,h,f,p,d):n(K+2,a,o,s,l,c,u,h,f,p,d),Q)return r(it),void r(at);if(J<U&&K>V){t:for(;;){for(b=s+J*l,B=0,N=s,k=0;k<h;++k){if(o[b]!==it[B])break t;++B,b+=f}++J}t:for(;;){for(b=s+K*l,B=0,N=s,k=0;k<h;++k){if(o[b]!==at[B])break t;++B,b+=f}--K}for(_=J;_<=K;++_){for(b=s+_*l,B=0,k=0;k<h&&0==(tt=o[b]-it[B]);++k)B+=d,b+=p;if(0===tt){if(_!==J)for(A=l*_,M=l*J,N=s,k=0;k<h;++k)w=M+N,m=o[b=A+N],o[b]=o[w],o[w]=m,N+=f;++J}else{for(b=s+_*l,B=0,k=0;k<h&&0==(et=o[b]-at[B]);++k)B+=d,b+=p;if(0===et)for(;;){for(b=s+K*l,B=0,k=0;k<h&&0==(rt=o[b]-at[B]);++k)B+=d,b+=p;if(0!==rt){for(b=s+K*l,B=0,k=0;k<h&&0==(rt=o[b]-it[B]);++k)B+=d,b+=p;if(rt<0){for(A=l*_,M=l*J,S=l*K,N=s,k=0;k<h;++k)w=M+N,T=S+N,m=o[b=A+N],o[b]=o[w],o[w]=o[T],o[T]=m,N+=f;++J,--K}else{for(A=l*_,M=l*K,N=s,k=0;k<h;++k)w=M+N,m=o[b=A+N],o[b]=o[w],o[w]=m,N+=f;--K}break}if(--K<_)break}}}}r(it),r(at),K-J<=32?t(J,K,o,s,l,c,u,h,f,p,d):n(J,K,o,s,l,c,u,h,f,p,d)}}},s={\"uint32,1,0\":function(t,e){return function(r){var n=r.data,i=0|r.offset,a=r.shape,o=r.stride,s=0|o[0],l=0|a[0],c=0|o[1],u=0|a[1],h=c,f=c;l<=32?t(0,l-1,n,i,s,c,l,u,h,f,1):e(0,l-1,n,i,s,c,l,u,h,f,1)}}};t.exports=function(t,e){var r=[e,t].join(\",\"),n=s[r],l=function(t,e){var r=i(e),n=[e,t].join(\",\"),o=a[n];return r?o(r[0],r[1]):o()}(t,e),c=function(t,e,r){var n=i(e),a=[e,t].join(\",\"),s=o[a];return t.length>1&&n?s(r,n[0],n[1]):s(r)}(t,e,l);return n(l,c)}},446:function(t,e,r){\"use strict\";var n=r(7640),i={};t.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},9618:function(t,e,r){var n=r(7163),i=\"undefined\"!=typeof Float64Array;function a(t,e){return t[0]-e[0]}function o(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(a);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}var s={T:function(t){function e(t){this.data=t}var r=e.prototype;return r.dtype=t,r.index=function(){return-1},r.size=0,r.dimension=-1,r.shape=r.stride=r.order=[],r.lo=r.hi=r.transpose=r.step=function(){return new e(this.data)},r.get=r.set=function(){},r.pick=function(){return null},function(t){return new e(t)}},0:function(t,e){function r(t,e){this.data=t,this.offset=e}var n=r.prototype;return n.dtype=t,n.index=function(){return this.offset},n.dimension=0,n.size=1,n.shape=n.stride=n.order=[],n.lo=n.hi=n.transpose=n.step=function(){return new r(this.data,this.offset)},n.pick=function(){return e(this.data)},n.valueOf=n.get=function(){return\"generic\"===t?this.data.get(this.offset):this.data[this.offset]},n.set=function(e){return\"generic\"===t?this.data.set(this.offset,e):this.data[this.offset]=e},function(t,e,n,i){return new r(t,i)}},1:function(t,e,r){function n(t,e,r,n){this.data=t,this.shape=[e],this.stride=[r],this.offset=0|n}var i=n.prototype;return i.dtype=t,i.dimension=1,Object.defineProperty(i,\"size\",{get:function(){return this.shape[0]}}),i.order=[0],i.set=function(e,r){return\"generic\"===t?this.data.set(this.offset+this.stride[0]*e,r):this.data[this.offset+this.stride[0]*e]=r},i.get=function(e){return\"generic\"===t?this.data.get(this.offset+this.stride[0]*e):this.data[this.offset+this.stride[0]*e]},i.index=function(t){return this.offset+this.stride[0]*t},i.hi=function(t){return new n(this.data,\"number\"!=typeof t||t<0?this.shape[0]:0|t,this.stride[0],this.offset)},i.lo=function(t){var e=this.offset,r=0,i=this.shape[0],a=this.stride[0];return\"number\"==typeof t&&t>=0&&(e+=a*(r=0|t),i-=r),new n(this.data,i,a,e)},i.step=function(t){var e=this.shape[0],r=this.stride[0],i=this.offset,a=0,o=Math.ceil;return\"number\"==typeof t&&((a=0|t)<0?(i+=r*(e-1),e=o(-e/a)):e=o(e/a),r*=a),new n(this.data,e,r,i)},i.transpose=function(t){t=void 0===t?0:0|t;var e=this.shape,r=this.stride;return new n(this.data,e[t],r[t],this.offset)},i.pick=function(t){var r=[],n=[],i=this.offset;return\"number\"==typeof t&&t>=0?i=i+this.stride[0]*t|0:(r.push(this.shape[0]),n.push(this.stride[0])),(0,e[r.length+1])(this.data,r,n,i)},function(t,e,r,i){return new n(t,e[0],r[0],i)}},2:function(t,e,r){function n(t,e,r,n,i,a){this.data=t,this.shape=[e,r],this.stride=[n,i],this.offset=0|a}var i=n.prototype;return i.dtype=t,i.dimension=2,Object.defineProperty(i,\"size\",{get:function(){return this.shape[0]*this.shape[1]}}),Object.defineProperty(i,\"order\",{get:function(){return Math.abs(this.stride[0])>Math.abs(this.stride[1])?[1,0]:[0,1]}}),i.set=function(e,r,n){return\"generic\"===t?this.data.set(this.offset+this.stride[0]*e+this.stride[1]*r,n):this.data[this.offset+this.stride[0]*e+this.stride[1]*r]=n},i.get=function(e,r){return\"generic\"===t?this.data.get(this.offset+this.stride[0]*e+this.stride[1]*r):this.data[this.offset+this.stride[0]*e+this.stride[1]*r]},i.index=function(t,e){return this.offset+this.stride[0]*t+this.stride[1]*e},i.hi=function(t,e){return new n(this.data,\"number\"!=typeof t||t<0?this.shape[0]:0|t,\"number\"!=typeof e||e<0?this.shape[1]:0|e,this.stride[0],this.stride[1],this.offset)},i.lo=function(t,e){var r=this.offset,i=0,a=this.shape[0],o=this.shape[1],s=this.stride[0],l=this.stride[1];return\"number\"==typeof t&&t>=0&&(r+=s*(i=0|t),a-=i),\"number\"==typeof e&&e>=0&&(r+=l*(i=0|e),o-=i),new n(this.data,a,o,s,l,r)},i.step=function(t,e){var r=this.shape[0],i=this.shape[1],a=this.stride[0],o=this.stride[1],s=this.offset,l=0,c=Math.ceil;return\"number\"==typeof t&&((l=0|t)<0?(s+=a*(r-1),r=c(-r/l)):r=c(r/l),a*=l),\"number\"==typeof e&&((l=0|e)<0?(s+=o*(i-1),i=c(-i/l)):i=c(i/l),o*=l),new n(this.data,r,i,a,o,s)},i.transpose=function(t,e){t=void 0===t?0:0|t,e=void 0===e?1:0|e;var r=this.shape,i=this.stride;return new n(this.data,r[t],r[e],i[t],i[e],this.offset)},i.pick=function(t,r){var n=[],i=[],a=this.offset;return\"number\"==typeof t&&t>=0?a=a+this.stride[0]*t|0:(n.push(this.shape[0]),i.push(this.stride[0])),\"number\"==typeof r&&r>=0?a=a+this.stride[1]*r|0:(n.push(this.shape[1]),i.push(this.stride[1])),(0,e[n.length+1])(this.data,n,i,a)},function(t,e,r,i){return new n(t,e[0],e[1],r[0],r[1],i)}},3:function(t,e,r){function n(t,e,r,n,i,a,o,s){this.data=t,this.shape=[e,r,n],this.stride=[i,a,o],this.offset=0|s}var i=n.prototype;return i.dtype=t,i.dimension=3,Object.defineProperty(i,\"size\",{get:function(){return this.shape[0]*this.shape[1]*this.shape[2]}}),Object.defineProperty(i,\"order\",{get:function(){var t=Math.abs(this.stride[0]),e=Math.abs(this.stride[1]),r=Math.abs(this.stride[2]);return t>e?e>r?[2,1,0]:t>r?[1,2,0]:[1,0,2]:t>r?[2,0,1]:r>e?[0,1,2]:[0,2,1]}}),i.set=function(e,r,n,i){return\"generic\"===t?this.data.set(this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n,i):this.data[this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n]=i},i.get=function(e,r,n){return\"generic\"===t?this.data.get(this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n):this.data[this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n]},i.index=function(t,e,r){return this.offset+this.stride[0]*t+this.stride[1]*e+this.stride[2]*r},i.hi=function(t,e,r){return new n(this.data,\"number\"!=typeof t||t<0?this.shape[0]:0|t,\"number\"!=typeof e||e<0?this.shape[1]:0|e,\"number\"!=typeof r||r<0?this.shape[2]:0|r,this.stride[0],this.stride[1],this.stride[2],this.offset)},i.lo=function(t,e,r){var i=this.offset,a=0,o=this.shape[0],s=this.shape[1],l=this.shape[2],c=this.stride[0],u=this.stride[1],h=this.stride[2];return\"number\"==typeof t&&t>=0&&(i+=c*(a=0|t),o-=a),\"number\"==typeof e&&e>=0&&(i+=u*(a=0|e),s-=a),\"number\"==typeof r&&r>=0&&(i+=h*(a=0|r),l-=a),new n(this.data,o,s,l,c,u,h,i)},i.step=function(t,e,r){var i=this.shape[0],a=this.shape[1],o=this.shape[2],s=this.stride[0],l=this.stride[1],c=this.stride[2],u=this.offset,h=0,f=Math.ceil;return\"number\"==typeof t&&((h=0|t)<0?(u+=s*(i-1),i=f(-i/h)):i=f(i/h),s*=h),\"number\"==typeof e&&((h=0|e)<0?(u+=l*(a-1),a=f(-a/h)):a=f(a/h),l*=h),\"number\"==typeof r&&((h=0|r)<0?(u+=c*(o-1),o=f(-o/h)):o=f(o/h),c*=h),new n(this.data,i,a,o,s,l,c,u)},i.transpose=function(t,e,r){t=void 0===t?0:0|t,e=void 0===e?1:0|e,r=void 0===r?2:0|r;var i=this.shape,a=this.stride;return new n(this.data,i[t],i[e],i[r],a[t],a[e],a[r],this.offset)},i.pick=function(t,r,n){var i=[],a=[],o=this.offset;return\"number\"==typeof t&&t>=0?o=o+this.stride[0]*t|0:(i.push(this.shape[0]),a.push(this.stride[0])),\"number\"==typeof r&&r>=0?o=o+this.stride[1]*r|0:(i.push(this.shape[1]),a.push(this.stride[1])),\"number\"==typeof n&&n>=0?o=o+this.stride[2]*n|0:(i.push(this.shape[2]),a.push(this.stride[2])),(0,e[i.length+1])(this.data,i,a,o)},function(t,e,r,i){return new n(t,e[0],e[1],e[2],r[0],r[1],r[2],i)}},4:function(t,e,r){function n(t,e,r,n,i,a,o,s,l,c){this.data=t,this.shape=[e,r,n,i],this.stride=[a,o,s,l],this.offset=0|c}var i=n.prototype;return i.dtype=t,i.dimension=4,Object.defineProperty(i,\"size\",{get:function(){return this.shape[0]*this.shape[1]*this.shape[2]*this.shape[3]}}),Object.defineProperty(i,\"order\",{get:r}),i.set=function(e,r,n,i,a){return\"generic\"===t?this.data.set(this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i,a):this.data[this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i]=a},i.get=function(e,r,n,i){return\"generic\"===t?this.data.get(this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i):this.data[this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i]},i.index=function(t,e,r,n){return this.offset+this.stride[0]*t+this.stride[1]*e+this.stride[2]*r+this.stride[3]*n},i.hi=function(t,e,r,i){return new n(this.data,\"number\"!=typeof t||t<0?this.shape[0]:0|t,\"number\"!=typeof e||e<0?this.shape[1]:0|e,\"number\"!=typeof r||r<0?this.shape[2]:0|r,\"number\"!=typeof i||i<0?this.shape[3]:0|i,this.stride[0],this.stride[1],this.stride[2],this.stride[3],this.offset)},i.lo=function(t,e,r,i){var a=this.offset,o=0,s=this.shape[0],l=this.shape[1],c=this.shape[2],u=this.shape[3],h=this.stride[0],f=this.stride[1],p=this.stride[2],d=this.stride[3];return\"number\"==typeof t&&t>=0&&(a+=h*(o=0|t),s-=o),\"number\"==typeof e&&e>=0&&(a+=f*(o=0|e),l-=o),\"number\"==typeof r&&r>=0&&(a+=p*(o=0|r),c-=o),\"number\"==typeof i&&i>=0&&(a+=d*(o=0|i),u-=o),new n(this.data,s,l,c,u,h,f,p,d,a)},i.step=function(t,e,r,i){var a=this.shape[0],o=this.shape[1],s=this.shape[2],l=this.shape[3],c=this.stride[0],u=this.stride[1],h=this.stride[2],f=this.stride[3],p=this.offset,d=0,m=Math.ceil;return\"number\"==typeof t&&((d=0|t)<0?(p+=c*(a-1),a=m(-a/d)):a=m(a/d),c*=d),\"number\"==typeof e&&((d=0|e)<0?(p+=u*(o-1),o=m(-o/d)):o=m(o/d),u*=d),\"number\"==typeof r&&((d=0|r)<0?(p+=h*(s-1),s=m(-s/d)):s=m(s/d),h*=d),\"number\"==typeof i&&((d=0|i)<0?(p+=f*(l-1),l=m(-l/d)):l=m(l/d),f*=d),new n(this.data,a,o,s,l,c,u,h,f,p)},i.transpose=function(t,e,r,i){t=void 0===t?0:0|t,e=void 0===e?1:0|e,r=void 0===r?2:0|r,i=void 0===i?3:0|i;var a=this.shape,o=this.stride;return new n(this.data,a[t],a[e],a[r],a[i],o[t],o[e],o[r],o[i],this.offset)},i.pick=function(t,r,n,i){var a=[],o=[],s=this.offset;return\"number\"==typeof t&&t>=0?s=s+this.stride[0]*t|0:(a.push(this.shape[0]),o.push(this.stride[0])),\"number\"==typeof r&&r>=0?s=s+this.stride[1]*r|0:(a.push(this.shape[1]),o.push(this.stride[1])),\"number\"==typeof n&&n>=0?s=s+this.stride[2]*n|0:(a.push(this.shape[2]),o.push(this.stride[2])),\"number\"==typeof i&&i>=0?s=s+this.stride[3]*i|0:(a.push(this.shape[3]),o.push(this.stride[3])),(0,e[a.length+1])(this.data,a,o,s)},function(t,e,r,i){return new n(t,e[0],e[1],e[2],e[3],r[0],r[1],r[2],r[3],i)}},5:function(t,e,r){function n(t,e,r,n,i,a,o,s,l,c,u,h){this.data=t,this.shape=[e,r,n,i,a],this.stride=[o,s,l,c,u],this.offset=0|h}var i=n.prototype;return i.dtype=t,i.dimension=5,Object.defineProperty(i,\"size\",{get:function(){return this.shape[0]*this.shape[1]*this.shape[2]*this.shape[3]*this.shape[4]}}),Object.defineProperty(i,\"order\",{get:r}),i.set=function(e,r,n,i,a,o){return\"generic\"===t?this.data.set(this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i+this.stride[4]*a,o):this.data[this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i+this.stride[4]*a]=o},i.get=function(e,r,n,i,a){return\"generic\"===t?this.data.get(this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i+this.stride[4]*a):this.data[this.offset+this.stride[0]*e+this.stride[1]*r+this.stride[2]*n+this.stride[3]*i+this.stride[4]*a]},i.index=function(t,e,r,n,i){return this.offset+this.stride[0]*t+this.stride[1]*e+this.stride[2]*r+this.stride[3]*n+this.stride[4]*i},i.hi=function(t,e,r,i,a){return new n(this.data,\"number\"!=typeof t||t<0?this.shape[0]:0|t,\"number\"!=typeof e||e<0?this.shape[1]:0|e,\"number\"!=typeof r||r<0?this.shape[2]:0|r,\"number\"!=typeof i||i<0?this.shape[3]:0|i,\"number\"!=typeof a||a<0?this.shape[4]:0|a,this.stride[0],this.stride[1],this.stride[2],this.stride[3],this.stride[4],this.offset)},i.lo=function(t,e,r,i,a){var o=this.offset,s=0,l=this.shape[0],c=this.shape[1],u=this.shape[2],h=this.shape[3],f=this.shape[4],p=this.stride[0],d=this.stride[1],m=this.stride[2],g=this.stride[3],y=this.stride[4];return\"number\"==typeof t&&t>=0&&(o+=p*(s=0|t),l-=s),\"number\"==typeof e&&e>=0&&(o+=d*(s=0|e),c-=s),\"number\"==typeof r&&r>=0&&(o+=m*(s=0|r),u-=s),\"number\"==typeof i&&i>=0&&(o+=g*(s=0|i),h-=s),\"number\"==typeof a&&a>=0&&(o+=y*(s=0|a),f-=s),new n(this.data,l,c,u,h,f,p,d,m,g,y,o)},i.step=function(t,e,r,i,a){var o=this.shape[0],s=this.shape[1],l=this.shape[2],c=this.shape[3],u=this.shape[4],h=this.stride[0],f=this.stride[1],p=this.stride[2],d=this.stride[3],m=this.stride[4],g=this.offset,y=0,v=Math.ceil;return\"number\"==typeof t&&((y=0|t)<0?(g+=h*(o-1),o=v(-o/y)):o=v(o/y),h*=y),\"number\"==typeof e&&((y=0|e)<0?(g+=f*(s-1),s=v(-s/y)):s=v(s/y),f*=y),\"number\"==typeof r&&((y=0|r)<0?(g+=p*(l-1),l=v(-l/y)):l=v(l/y),p*=y),\"number\"==typeof i&&((y=0|i)<0?(g+=d*(c-1),c=v(-c/y)):c=v(c/y),d*=y),\"number\"==typeof a&&((y=0|a)<0?(g+=m*(u-1),u=v(-u/y)):u=v(u/y),m*=y),new n(this.data,o,s,l,c,u,h,f,p,d,m,g)},i.transpose=function(t,e,r,i,a){t=void 0===t?0:0|t,e=void 0===e?1:0|e,r=void 0===r?2:0|r,i=void 0===i?3:0|i,a=void 0===a?4:0|a;var o=this.shape,s=this.stride;return new n(this.data,o[t],o[e],o[r],o[i],o[a],s[t],s[e],s[r],s[i],s[a],this.offset)},i.pick=function(t,r,n,i,a){var o=[],s=[],l=this.offset;return\"number\"==typeof t&&t>=0?l=l+this.stride[0]*t|0:(o.push(this.shape[0]),s.push(this.stride[0])),\"number\"==typeof r&&r>=0?l=l+this.stride[1]*r|0:(o.push(this.shape[1]),s.push(this.stride[1])),\"number\"==typeof n&&n>=0?l=l+this.stride[2]*n|0:(o.push(this.shape[2]),s.push(this.stride[2])),\"number\"==typeof i&&i>=0?l=l+this.stride[3]*i|0:(o.push(this.shape[3]),s.push(this.stride[3])),\"number\"==typeof a&&a>=0?l=l+this.stride[4]*a|0:(o.push(this.shape[4]),s.push(this.stride[4])),(0,e[o.length+1])(this.data,o,s,l)},function(t,e,r,i){return new n(t,e[0],e[1],e[2],e[3],e[4],r[0],r[1],r[2],r[3],r[4],i)}}};function l(t,e){var r=-1===e?\"T\":String(e),n=s[r];return-1===e?n(t):0===e?n(t,c[t][0]):n(t,c[t],o)}var c={generic:[],buffer:[],array:[],float32:[],float64:[],int8:[],int16:[],int32:[],uint8_clamped:[],uint8:[],uint16:[],uint32:[],bigint64:[],biguint64:[]};t.exports=function(t,e,r,a){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===a)for(a=0,s=0;s<o;++s)r[s]<0&&(a-=(e[s]-1)*r[s]);for(var h=function(t){if(n(t))return\"buffer\";if(i)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object BigInt64Array]\":return\"bigint64\";case\"[object BigUint64Array]\":return\"biguint64\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,a)}},1278:function(t,e,r){\"use strict\";var n=r(2361),i=Math.pow(2,-1074),a=-1>>>0;t.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);return e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1,n.pack(o,r)}},8406:function(t,e){e.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],m=new Array(3),g=0,y=new Array(3),v=0,x=0;x<3;++x)m[x]=f[x]-p[x],g+=m[x]*m[x],y[x]=d[x]-p[x],v+=y[x]*y[x];if(g*v>a){var _=i[c],b=1/Math.sqrt(g*v);for(x=0;x<3;++x){var w=(x+1)%3,T=(x+2)%3;_[x]+=b*(y[w]*m[T]-y[T]*m[w])}}}for(o=0;o<n;++o){_=i[o];var k=0;for(x=0;x<3;++x)k+=_[x]*_[x];if(k>a)for(b=1/Math.sqrt(k),x=0;x<3;++x)_[x]*=b;else for(x=0;x<3;++x)_[x]=0}return i},e.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,m=(c+2)%3;f[c]=u[d]*h[m]-u[m]*h[d],p+=f[c]*f[c]}for(p=p>a?1/Math.sqrt(p):0,c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},4081:function(t){\"use strict\";t.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c);h=Math.sqrt(2*f-u+1),e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},9977:function(t,e,r){\"use strict\";t.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));return i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up),i};var n=r(9215),i=r(6582),a=r(7399),o=r(7608),s=r(4081);function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var m=i[2],g=i[6],y=i[10],v=m*a+g*o+y*s,x=m*u+g*h+y*f,_=l(m-=v*a+x*u,g-=v*o+x*h,y-=v*s+x*f);m/=_,g/=_,y/=_;var b=u*e+a*r,w=h*e+o*r,T=f*e+s*r;this.center.move(t,b,w,T);var k=Math.exp(this.computedRadius[0]);k=Math.max(1e-4,k+n),this.radius.set(t,Math.log(k))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],m=i[10],g=e*a+r*u,y=e*o+r*h,v=e*s+r*f,x=-(d*v-m*y),_=-(m*g-p*v),b=-(p*y-d*g),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(_,2)-Math.pow(b,2))),T=c(x,_,b,w);T>1e-6?(x/=T,_/=T,b/=T,w/=T):(x=_=b=0,w=1);var k=this.computedRotation,A=k[0],M=k[1],S=k[2],E=k[3],C=A*w+E*x+M*b-S*_,L=M*w+E*_+S*x-A*b,I=S*w+E*b+A*_-M*x,P=E*w-A*x-M*_-S*b;if(n){x=p,_=d,b=m;var z=Math.sin(n)/l(x,_,b);x*=z,_*=z,b*=z,P=P*(w=Math.cos(e))-(C=C*w+P*x+L*b-I*_)*x-(L=L*w+P*_+I*x-C*b)*_-(I=I*w+P*b+C*_-L*x)*b}var O=c(C,L,I,P);O>1e-6?(C/=O,L/=O,I/=O,P/=O):(C=L=I=0,P=1),this.rotation.set(t,C,L,I,P)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},1371:function(t,e,r){\"use strict\";var n=r(3233);t.exports=function(t,e,r){return n(r=void 0!==r?r+\"\":\" \",e)+t}},3202:function(t){t.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},3088:function(t,e,r){\"use strict\";t.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}var l=[];for(o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],m=d[1^h];n(e[t],e[r],e[s],e[m])>0&&(o=d,s=m,l=h)}return i||o&&c(o,l),s}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var m=h(o,p);f(0,m)?d.push.apply(d,m):(d.length>0&&l.push(d),d=m)}d.length>0&&l.push(d)}return l};var n=r(3140)},5609:function(t,e,r){\"use strict\";t.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){i[p=o.pop()]=!1;var c=r[p];for(s=0;s<c.length;++s){var u=c[s];0==--a[u]&&o.push(u)}}var h=new Array(e.length),f=[];for(s=0;s<e.length;++s)if(i[s]){var p=f.length;h[s]=p,f.push(e[s])}else h[s]=-1;var d=[];for(s=0;s<t.length;++s){var m=t[s];i[m[0]]&&i[m[1]]&&d.push([h[m[0]],h[m[1]]])}return[d,f]};var n=r(3134)},2095:function(t,e,r){\"use strict\";t.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e),m=(d=d.filter((function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0}))).length,g=new Array(m),y=new Array(m);for(p=0;p<m;++p){g[p]=p;var v=new Array(m),x=d[p].map((function(t){return e[t]})),_=a([x]),b=0;t:for(var w=0;w<m;++w)if(v[w]=0,p!==w){for(var T=(q=d[w]).length,k=0;k<T;++k){var A=_(e[q[k]]);if(0!==A){A<0&&(v[w]=1,b+=1);continue t}}v[w]=1,b+=1}y[p]=[b,p,v]}for(y.sort((function(t,e){return e[0]-t[0]})),p=0;p<m;++p){var M=(v=y[p])[1],S=v[2];for(w=0;w<m;++w)S[w]&&(g[w]=M)}var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(m);for(p=0;p<m;++p)E[p].push(g[p]),E[g[p]].push(p);var C={},L=u(h,!1);for(p=0;p<m;++p)for(T=(q=d[p]).length,w=0;w<T;++w){var I=q[w],P=q[(w+1)%T],z=Math.min(I,P)+\":\"+Math.max(I,P);if(z in C){var O=C[z];E[O].push(p),E[p].push(O),L[I]=L[P]=!0}else C[z]=p}function D(t){for(var e=t.length,r=0;r<e;++r)if(!L[t[r]])return!1;return!0}var R=[],F=u(m,-1);for(p=0;p<m;++p)g[p]!==p||D(d[p])?F[p]=-1:(R.push(p),F[p]=0);for(r=[];R.length>0;){var B=R.pop(),N=E[B];l(N,(function(t,e){return t-e}));var j,U=N.length,V=F[B];for(0===V&&(j=[q=d[B]]),p=0;p<U;++p){var q,H=N[p];F[H]>=0||(F[H]=1^V,R.push(H),0===V&&(D(q=d[H])||(q.reverse(),j.push(q))))}0===V&&r.push(j)}return r};var n=r(3134),i=r(3088),a=r(5085),o=r(5250),s=r(8210),l=r(1682),c=r(5609);function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},5085:function(t,e,r){t.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],m=u[p];d[0]===m[0]?a.push([d,m]):r.push([d,m])}if(0===r.length)return 0===a.length?c:(g=l(a),function(t){return g(t[0],t[1])?0:1});var g,y=i(r),v=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(y.slabs,y.coordinates);return 0===a.length?v:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),v)};var n=r(3250)[3],i=r(4209),a=r(3352),o=r(2478);function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},9346:function(t){\"use strict\";var e=new Float64Array(4),r=new Float64Array(4),n=new Float64Array(4);t.exports=function(t,i,a,o,s){e.length<o.length&&(e=new Float64Array(o.length),r=new Float64Array(o.length),n=new Float64Array(o.length));for(var l=0;l<o.length;++l)e[l]=t[l]-o[l],r[l]=i[l]-t[l],n[l]=a[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var m=r[l],g=n[l],y=e[l];c+=m*m,u+=m*g,h+=g*g,f+=y*m,p+=y*g,d+=y*y}var v,x,_,b,w,T=Math.abs(c*h-u*u),k=u*p-h*f,A=u*f-c*p;if(k+A<=T)if(k<0)A<0&&f<0?(A=0,-f>=c?(k=1,v=c+2*f+d):v=f*(k=-f/c)+d):(k=0,p>=0?(A=0,v=d):-p>=h?(A=1,v=h+2*p+d):v=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(k=0,v=d):-f>=c?(k=1,v=c+2*f+d):v=f*(k=-f/c)+d;else{var M=1/T;v=(k*=M)*(c*k+u*(A*=M)+2*f)+A*(u*k+h*A+2*p)+d}else k<0?(_=h+p)>(x=u+f)?(b=_-x)>=(w=c-2*u+h)?(k=1,A=0,v=c+2*f+d):v=(k=b/w)*(c*k+u*(A=1-k)+2*f)+A*(u*k+h*A+2*p)+d:(k=0,_<=0?(A=1,v=h+2*p+d):p>=0?(A=0,v=d):v=p*(A=-p/h)+d):A<0?(_=c+f)>(x=u+p)?(b=_-x)>=(w=c-2*u+h)?(A=1,k=0,v=h+2*p+d):v=(k=1-(A=b/w))*(c*k+u*A+2*f)+A*(u*k+h*A+2*p)+d:(A=0,_<=0?(k=1,v=c+2*f+d):f>=0?(k=0,v=d):v=f*(k=-f/c)+d):(b=h+p-u-f)<=0?(k=0,A=1,v=h+2*p+d):b>=(w=c-2*u+h)?(k=1,A=0,v=c+2*f+d):v=(k=b/w)*(c*k+u*(A=1-k)+2*f)+A*(u*k+h*A+2*p)+d;var S=1-k-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+k*i[l]+A*a[l];return v<0?0:v}},8648:function(t,e,r){t.exports=r(783)},2653:function(t,e,r){\"use strict\";var n=r(3865);t.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},5838:function(t,e,r){\"use strict\";t.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=r(7842)},8987:function(t,e,r){\"use strict\";var n=r(7842),i=r(6504);t.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},544:function(t,e,r){\"use strict\";var n=r(5572);t.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},5771:function(t,e,r){\"use strict\";var n=r(8507),i=r(3788),a=r(2419);t.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},3233:function(t){\"use strict\";var e,r=\"\";t.exports=function(t,n){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===n)return t;if(2===n)return t+t;var i=t.length*n;if(e!==t||void 0===e)e=t,r=\"\";else if(r.length>=i)return r.substr(0,i);for(;i>r.length&&n>1;)1&n&&(r+=t),n>>=1,t+=t;return r=(r+=t).substr(0,i)}},3025:function(t,e,r){t.exports=r.g.performance&&r.g.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}},7004:function(t){\"use strict\";t.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r;(l=(s=t[i])-((r=a+s)-a))&&(t[--n]=r,r=l)}var o=0;for(i=n;i<e;++i){var s,l;(l=(s=r)-((r=(a=t[i])+s)-a))&&(t[o++]=l)}return t[o++]=r,t.length=o,t}},2962:function(t,e,r){\"use strict\";var n=r(5250),i=r(8210),a=r(3012),o=r(7004);function s(t,e,r,n){return function(e){return n(t(r(e[0][0],e[1][1]),r(-e[0][1],e[1][0])))}}function l(t,e,r,n){return function(i){return n(t(e(t(r(i[1][1],i[2][2]),r(-i[1][2],i[2][1])),i[0][0]),t(e(t(r(i[1][0],i[2][2]),r(-i[1][2],i[2][0])),-i[0][1]),e(t(r(i[1][0],i[2][1]),r(-i[1][1],i[2][0])),i[0][2]))))}}function c(t,e,r,n){return function(i){return n(t(t(e(t(e(t(r(i[2][2],i[3][3]),r(-i[2][3],i[3][2])),i[1][1]),t(e(t(r(i[2][1],i[3][3]),r(-i[2][3],i[3][1])),-i[1][2]),e(t(r(i[2][1],i[3][2]),r(-i[2][2],i[3][1])),i[1][3]))),i[0][0]),e(t(e(t(r(i[2][2],i[3][3]),r(-i[2][3],i[3][2])),i[1][0]),t(e(t(r(i[2][0],i[3][3]),r(-i[2][3],i[3][0])),-i[1][2]),e(t(r(i[2][0],i[3][2]),r(-i[2][2],i[3][0])),i[1][3]))),-i[0][1])),t(e(t(e(t(r(i[2][1],i[3][3]),r(-i[2][3],i[3][1])),i[1][0]),t(e(t(r(i[2][0],i[3][3]),r(-i[2][3],i[3][0])),-i[1][1]),e(t(r(i[2][0],i[3][1]),r(-i[2][1],i[3][0])),i[1][3]))),i[0][2]),e(t(e(t(r(i[2][1],i[3][2]),r(-i[2][2],i[3][1])),i[1][0]),t(e(t(r(i[2][0],i[3][2]),r(-i[2][2],i[3][0])),-i[1][1]),e(t(r(i[2][0],i[3][1]),r(-i[2][1],i[3][0])),i[1][2]))),-i[0][3]))))}}function u(t,e,r,n){return function(i){return n(t(t(e(t(t(e(t(e(t(r(i[3][3],i[4][4]),r(-i[3][4],i[4][3])),i[2][2]),t(e(t(r(i[3][2],i[4][4]),r(-i[3][4],i[4][2])),-i[2][3]),e(t(r(i[3][2],i[4][3]),r(-i[3][3],i[4][2])),i[2][4]))),i[1][1]),e(t(e(t(r(i[3][3],i[4][4]),r(-i[3][4],i[4][3])),i[2][1]),t(e(t(r(i[3][1],i[4][4]),r(-i[3][4],i[4][1])),-i[2][3]),e(t(r(i[3][1],i[4][3]),r(-i[3][3],i[4][1])),i[2][4]))),-i[1][2])),t(e(t(e(t(r(i[3][2],i[4][4]),r(-i[3][4],i[4][2])),i[2][1]),t(e(t(r(i[3][1],i[4][4]),r(-i[3][4],i[4][1])),-i[2][2]),e(t(r(i[3][1],i[4][2]),r(-i[3][2],i[4][1])),i[2][4]))),i[1][3]),e(t(e(t(r(i[3][2],i[4][3]),r(-i[3][3],i[4][2])),i[2][1]),t(e(t(r(i[3][1],i[4][3]),r(-i[3][3],i[4][1])),-i[2][2]),e(t(r(i[3][1],i[4][2]),r(-i[3][2],i[4][1])),i[2][3]))),-i[1][4]))),i[0][0]),e(t(t(e(t(e(t(r(i[3][3],i[4][4]),r(-i[3][4],i[4][3])),i[2][2]),t(e(t(r(i[3][2],i[4][4]),r(-i[3][4],i[4][2])),-i[2][3]),e(t(r(i[3][2],i[4][3]),r(-i[3][3],i[4][2])),i[2][4]))),i[1][0]),e(t(e(t(r(i[3][3],i[4][4]),r(-i[3][4],i[4][3])),i[2][0]),t(e(t(r(i[3][0],i[4][4]),r(-i[3][4],i[4][0])),-i[2][3]),e(t(r(i[3][0],i[4][3]),r(-i[3][3],i[4][0])),i[2][4]))),-i[1][2])),t(e(t(e(t(r(i[3][2],i[4][4]),r(-i[3][4],i[4][2])),i[2][0]),t(e(t(r(i[3][0],i[4][4]),r(-i[3][4],i[4][0])),-i[2][2]),e(t(r(i[3][0],i[4][2]),r(-i[3][2],i[4][0])),i[2][4]))),i[1][3]),e(t(e(t(r(i[3][2],i[4][3]),r(-i[3][3],i[4][2])),i[2][0]),t(e(t(r(i[3][0],i[4][3]),r(-i[3][3],i[4][0])),-i[2][2]),e(t(r(i[3][0],i[4][2]),r(-i[3][2],i[4][0])),i[2][3]))),-i[1][4]))),-i[0][1])),t(e(t(t(e(t(e(t(r(i[3][3],i[4][4]),r(-i[3][4],i[4][3])),i[2][1]),t(e(t(r(i[3][1],i[4][4]),r(-i[3][4],i[4][1])),-i[2][3]),e(t(r(i[3][1],i[4][3]),r(-i[3][3],i[4][1])),i[2][4]))),i[1][0]),e(t(e(t(r(i[3][3],i[4][4]),r(-i[3][4],i[4][3])),i[2][0]),t(e(t(r(i[3][0],i[4][4]),r(-i[3][4],i[4][0])),-i[2][3]),e(t(r(i[3][0],i[4][3]),r(-i[3][3],i[4][0])),i[2][4]))),-i[1][1])),t(e(t(e(t(r(i[3][1],i[4][4]),r(-i[3][4],i[4][1])),i[2][0]),t(e(t(r(i[3][0],i[4][4]),r(-i[3][4],i[4][0])),-i[2][1]),e(t(r(i[3][0],i[4][1]),r(-i[3][1],i[4][0])),i[2][4]))),i[1][3]),e(t(e(t(r(i[3][1],i[4][3]),r(-i[3][3],i[4][1])),i[2][0]),t(e(t(r(i[3][0],i[4][3]),r(-i[3][3],i[4][0])),-i[2][1]),e(t(r(i[3][0],i[4][1]),r(-i[3][1],i[4][0])),i[2][3]))),-i[1][4]))),i[0][2]),t(e(t(t(e(t(e(t(r(i[3][2],i[4][4]),r(-i[3][4],i[4][2])),i[2][1]),t(e(t(r(i[3][1],i[4][4]),r(-i[3][4],i[4][1])),-i[2][2]),e(t(r(i[3][1],i[4][2]),r(-i[3][2],i[4][1])),i[2][4]))),i[1][0]),e(t(e(t(r(i[3][2],i[4][4]),r(-i[3][4],i[4][2])),i[2][0]),t(e(t(r(i[3][0],i[4][4]),r(-i[3][4],i[4][0])),-i[2][2]),e(t(r(i[3][0],i[4][2]),r(-i[3][2],i[4][0])),i[2][4]))),-i[1][1])),t(e(t(e(t(r(i[3][1],i[4][4]),r(-i[3][4],i[4][1])),i[2][0]),t(e(t(r(i[3][0],i[4][4]),r(-i[3][4],i[4][0])),-i[2][1]),e(t(r(i[3][0],i[4][1]),r(-i[3][1],i[4][0])),i[2][4]))),i[1][2]),e(t(e(t(r(i[3][1],i[4][2]),r(-i[3][2],i[4][1])),i[2][0]),t(e(t(r(i[3][0],i[4][2]),r(-i[3][2],i[4][0])),-i[2][1]),e(t(r(i[3][0],i[4][1]),r(-i[3][1],i[4][0])),i[2][2]))),-i[1][4]))),-i[0][3]),e(t(t(e(t(e(t(r(i[3][2],i[4][3]),r(-i[3][3],i[4][2])),i[2][1]),t(e(t(r(i[3][1],i[4][3]),r(-i[3][3],i[4][1])),-i[2][2]),e(t(r(i[3][1],i[4][2]),r(-i[3][2],i[4][1])),i[2][3]))),i[1][0]),e(t(e(t(r(i[3][2],i[4][3]),r(-i[3][3],i[4][2])),i[2][0]),t(e(t(r(i[3][0],i[4][3]),r(-i[3][3],i[4][0])),-i[2][2]),e(t(r(i[3][0],i[4][2]),r(-i[3][2],i[4][0])),i[2][3]))),-i[1][1])),t(e(t(e(t(r(i[3][1],i[4][3]),r(-i[3][3],i[4][1])),i[2][0]),t(e(t(r(i[3][0],i[4][3]),r(-i[3][3],i[4][0])),-i[2][1]),e(t(r(i[3][0],i[4][1]),r(-i[3][1],i[4][0])),i[2][3]))),i[1][2]),e(t(e(t(r(i[3][1],i[4][2]),r(-i[3][2],i[4][1])),i[2][0]),t(e(t(r(i[3][0],i[4][2]),r(-i[3][2],i[4][0])),-i[2][1]),e(t(r(i[3][0],i[4][1]),r(-i[3][1],i[4][0])),i[2][2]))),-i[1][3]))),i[0][4])))))}}function h(t){return(2===t?s:3===t?l:4===t?c:5===t?u:void 0)(i,a,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];function p(t,e,r,n,i,a,o,s){return function(l){switch(l.length){case 0:return t(l);case 1:return e(l);case 2:return r(l);case 3:return n(l);case 4:return i(l);case 5:return a(l)}var c=o[l.length];return c||(c=o[l.length]=s(l.length)),c(l)}}!function(){for(;f.length<6;)f.push(h(f.length));t.exports=p.apply(void 0,f.concat([f,h]));for(var e=0;e<f.length;++e)t.exports[e]=f[e]}()},1944:function(t,e,r){\"use strict\";var n=r(5250),i=r(8210);t.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},2646:function(t,e,r){\"use strict\";var n=r(5250),i=r(8210),a=r(8545),o=r(3012);function s(t){return(3===t?l:4===t?c:5===t?u:h)(i,a,n,o)}function l(t,e,r,n){return function(i,a,o){var s=r(i[0],i[0]),l=n(s,a[0]),c=n(s,o[0]),u=r(a[0],a[0]),h=n(u,i[0]),f=n(u,o[0]),p=r(o[0],o[0]),d=n(p,i[0]),m=n(p,a[0]),g=t(e(m,f),e(h,l)),y=e(d,c),v=e(g,y);return v[v.length-1]}}function c(t,e,r,n){return function(i,a,o,s){var l=t(r(i[0],i[0]),r(i[1],i[1])),c=n(l,a[0]),u=n(l,o[0]),h=n(l,s[0]),f=t(r(a[0],a[0]),r(a[1],a[1])),p=n(f,i[0]),d=n(f,o[0]),m=n(f,s[0]),g=t(r(o[0],o[0]),r(o[1],o[1])),y=n(g,i[0]),v=n(g,a[0]),x=n(g,s[0]),_=t(r(s[0],s[0]),r(s[1],s[1])),b=n(_,i[0]),w=n(_,a[0]),T=n(_,o[0]),k=t(t(n(e(T,x),a[1]),t(n(e(w,m),-o[1]),n(e(v,d),s[1]))),t(n(e(w,m),i[1]),t(n(e(b,h),-a[1]),n(e(p,c),s[1])))),A=t(t(n(e(T,x),i[1]),t(n(e(b,h),-o[1]),n(e(y,u),s[1]))),t(n(e(v,d),i[1]),t(n(e(y,u),-a[1]),n(e(p,c),o[1])))),M=e(k,A);return M[M.length-1]}}function u(t,e,r,n){return function(i,a,o,s,l){var c=t(r(i[0],i[0]),t(r(i[1],i[1]),r(i[2],i[2]))),u=n(c,a[0]),h=n(c,o[0]),f=n(c,s[0]),p=n(c,l[0]),d=t(r(a[0],a[0]),t(r(a[1],a[1]),r(a[2],a[2]))),m=n(d,i[0]),g=n(d,o[0]),y=n(d,s[0]),v=n(d,l[0]),x=t(r(o[0],o[0]),t(r(o[1],o[1]),r(o[2],o[2]))),_=n(x,i[0]),b=n(x,a[0]),w=n(x,s[0]),T=n(x,l[0]),k=t(r(s[0],s[0]),t(r(s[1],s[1]),r(s[2],s[2]))),A=n(k,i[0]),M=n(k,a[0]),S=n(k,o[0]),E=n(k,l[0]),C=t(r(l[0],l[0]),t(r(l[1],l[1]),r(l[2],l[2]))),L=n(C,i[0]),I=n(C,a[0]),P=n(C,o[0]),z=n(C,s[0]),O=t(t(t(n(t(n(e(z,E),o[1]),t(n(e(P,T),-s[1]),n(e(S,w),l[1]))),a[2]),t(n(t(n(e(z,E),a[1]),t(n(e(I,v),-s[1]),n(e(M,y),l[1]))),-o[2]),n(t(n(e(P,T),a[1]),t(n(e(I,v),-o[1]),n(e(b,g),l[1]))),s[2]))),t(n(t(n(e(S,w),a[1]),t(n(e(M,y),-o[1]),n(e(b,g),s[1]))),-l[2]),t(n(t(n(e(z,E),a[1]),t(n(e(I,v),-s[1]),n(e(M,y),l[1]))),i[2]),n(t(n(e(z,E),i[1]),t(n(e(L,p),-s[1]),n(e(A,f),l[1]))),-a[2])))),t(t(n(t(n(e(I,v),i[1]),t(n(e(L,p),-a[1]),n(e(m,u),l[1]))),s[2]),t(n(t(n(e(M,y),i[1]),t(n(e(A,f),-a[1]),n(e(m,u),s[1]))),-l[2]),n(t(n(e(S,w),a[1]),t(n(e(M,y),-o[1]),n(e(b,g),s[1]))),i[2]))),t(n(t(n(e(S,w),i[1]),t(n(e(A,f),-o[1]),n(e(_,h),s[1]))),-a[2]),t(n(t(n(e(M,y),i[1]),t(n(e(A,f),-a[1]),n(e(m,u),s[1]))),o[2]),n(t(n(e(b,g),i[1]),t(n(e(_,h),-a[1]),n(e(m,u),o[1]))),-s[2]))))),D=t(t(t(n(t(n(e(z,E),o[1]),t(n(e(P,T),-s[1]),n(e(S,w),l[1]))),i[2]),n(t(n(e(z,E),i[1]),t(n(e(L,p),-s[1]),n(e(A,f),l[1]))),-o[2])),t(n(t(n(e(P,T),i[1]),t(n(e(L,p),-o[1]),n(e(_,h),l[1]))),s[2]),n(t(n(e(S,w),i[1]),t(n(e(A,f),-o[1]),n(e(_,h),s[1]))),-l[2]))),t(t(n(t(n(e(P,T),a[1]),t(n(e(I,v),-o[1]),n(e(b,g),l[1]))),i[2]),n(t(n(e(P,T),i[1]),t(n(e(L,p),-o[1]),n(e(_,h),l[1]))),-a[2])),t(n(t(n(e(I,v),i[1]),t(n(e(L,p),-a[1]),n(e(m,u),l[1]))),o[2]),n(t(n(e(b,g),i[1]),t(n(e(_,h),-a[1]),n(e(m,u),o[1]))),-l[2])))),R=e(O,D);return R[R.length-1]}}function h(t,e,r,n){return function(i,a,o,s,l,c){var u=t(t(r(i[0],i[0]),r(i[1],i[1])),t(r(i[2],i[2]),r(i[3],i[3]))),h=n(u,a[0]),f=n(u,o[0]),p=n(u,s[0]),d=n(u,l[0]),m=n(u,c[0]),g=t(t(r(a[0],a[0]),r(a[1],a[1])),t(r(a[2],a[2]),r(a[3],a[3]))),y=n(g,i[0]),v=n(g,o[0]),x=n(g,s[0]),_=n(g,l[0]),b=n(g,c[0]),w=t(t(r(o[0],o[0]),r(o[1],o[1])),t(r(o[2],o[2]),r(o[3],o[3]))),T=n(w,i[0]),k=n(w,a[0]),A=n(w,s[0]),M=n(w,l[0]),S=n(w,c[0]),E=t(t(r(s[0],s[0]),r(s[1],s[1])),t(r(s[2],s[2]),r(s[3],s[3]))),C=n(E,i[0]),L=n(E,a[0]),I=n(E,o[0]),P=n(E,l[0]),z=n(E,c[0]),O=t(t(r(l[0],l[0]),r(l[1],l[1])),t(r(l[2],l[2]),r(l[3],l[3]))),D=n(O,i[0]),R=n(O,a[0]),F=n(O,o[0]),B=n(O,s[0]),N=n(O,c[0]),j=t(t(r(c[0],c[0]),r(c[1],c[1])),t(r(c[2],c[2]),r(c[3],c[3]))),U=n(j,i[0]),V=n(j,a[0]),q=n(j,o[0]),H=n(j,s[0]),G=n(j,l[0]),Z=t(t(t(n(t(t(n(t(n(e(G,N),s[1]),t(n(e(H,z),-l[1]),n(e(B,P),c[1]))),o[2]),n(t(n(e(G,N),o[1]),t(n(e(q,S),-l[1]),n(e(F,M),c[1]))),-s[2])),t(n(t(n(e(H,z),o[1]),t(n(e(q,S),-s[1]),n(e(I,A),c[1]))),l[2]),n(t(n(e(B,P),o[1]),t(n(e(F,M),-s[1]),n(e(I,A),l[1]))),-c[2]))),a[3]),t(n(t(t(n(t(n(e(G,N),s[1]),t(n(e(H,z),-l[1]),n(e(B,P),c[1]))),a[2]),n(t(n(e(G,N),a[1]),t(n(e(V,b),-l[1]),n(e(R,_),c[1]))),-s[2])),t(n(t(n(e(H,z),a[1]),t(n(e(V,b),-s[1]),n(e(L,x),c[1]))),l[2]),n(t(n(e(B,P),a[1]),t(n(e(R,_),-s[1]),n(e(L,x),l[1]))),-c[2]))),-o[3]),n(t(t(n(t(n(e(G,N),o[1]),t(n(e(q,S),-l[1]),n(e(F,M),c[1]))),a[2]),n(t(n(e(G,N),a[1]),t(n(e(V,b),-l[1]),n(e(R,_),c[1]))),-o[2])),t(n(t(n(e(q,S),a[1]),t(n(e(V,b),-o[1]),n(e(k,v),c[1]))),l[2]),n(t(n(e(F,M),a[1]),t(n(e(R,_),-o[1]),n(e(k,v),l[1]))),-c[2]))),s[3]))),t(t(n(t(t(n(t(n(e(H,z),o[1]),t(n(e(q,S),-s[1]),n(e(I,A),c[1]))),a[2]),n(t(n(e(H,z),a[1]),t(n(e(V,b),-s[1]),n(e(L,x),c[1]))),-o[2])),t(n(t(n(e(q,S),a[1]),t(n(e(V,b),-o[1]),n(e(k,v),c[1]))),s[2]),n(t(n(e(I,A),a[1]),t(n(e(L,x),-o[1]),n(e(k,v),s[1]))),-c[2]))),-l[3]),n(t(t(n(t(n(e(B,P),o[1]),t(n(e(F,M),-s[1]),n(e(I,A),l[1]))),a[2]),n(t(n(e(B,P),a[1]),t(n(e(R,_),-s[1]),n(e(L,x),l[1]))),-o[2])),t(n(t(n(e(F,M),a[1]),t(n(e(R,_),-o[1]),n(e(k,v),l[1]))),s[2]),n(t(n(e(I,A),a[1]),t(n(e(L,x),-o[1]),n(e(k,v),s[1]))),-l[2]))),c[3])),t(n(t(t(n(t(n(e(G,N),s[1]),t(n(e(H,z),-l[1]),n(e(B,P),c[1]))),a[2]),n(t(n(e(G,N),a[1]),t(n(e(V,b),-l[1]),n(e(R,_),c[1]))),-s[2])),t(n(t(n(e(H,z),a[1]),t(n(e(V,b),-s[1]),n(e(L,x),c[1]))),l[2]),n(t(n(e(B,P),a[1]),t(n(e(R,_),-s[1]),n(e(L,x),l[1]))),-c[2]))),i[3]),n(t(t(n(t(n(e(G,N),s[1]),t(n(e(H,z),-l[1]),n(e(B,P),c[1]))),i[2]),n(t(n(e(G,N),i[1]),t(n(e(U,m),-l[1]),n(e(D,d),c[1]))),-s[2])),t(n(t(n(e(H,z),i[1]),t(n(e(U,m),-s[1]),n(e(C,p),c[1]))),l[2]),n(t(n(e(B,P),i[1]),t(n(e(D,d),-s[1]),n(e(C,p),l[1]))),-c[2]))),-a[3])))),t(t(t(n(t(t(n(t(n(e(G,N),a[1]),t(n(e(V,b),-l[1]),n(e(R,_),c[1]))),i[2]),n(t(n(e(G,N),i[1]),t(n(e(U,m),-l[1]),n(e(D,d),c[1]))),-a[2])),t(n(t(n(e(V,b),i[1]),t(n(e(U,m),-a[1]),n(e(y,h),c[1]))),l[2]),n(t(n(e(R,_),i[1]),t(n(e(D,d),-a[1]),n(e(y,h),l[1]))),-c[2]))),s[3]),n(t(t(n(t(n(e(H,z),a[1]),t(n(e(V,b),-s[1]),n(e(L,x),c[1]))),i[2]),n(t(n(e(H,z),i[1]),t(n(e(U,m),-s[1]),n(e(C,p),c[1]))),-a[2])),t(n(t(n(e(V,b),i[1]),t(n(e(U,m),-a[1]),n(e(y,h),c[1]))),s[2]),n(t(n(e(L,x),i[1]),t(n(e(C,p),-a[1]),n(e(y,h),s[1]))),-c[2]))),-l[3])),t(n(t(t(n(t(n(e(B,P),a[1]),t(n(e(R,_),-s[1]),n(e(L,x),l[1]))),i[2]),n(t(n(e(B,P),i[1]),t(n(e(D,d),-s[1]),n(e(C,p),l[1]))),-a[2])),t(n(t(n(e(R,_),i[1]),t(n(e(D,d),-a[1]),n(e(y,h),l[1]))),s[2]),n(t(n(e(L,x),i[1]),t(n(e(C,p),-a[1]),n(e(y,h),s[1]))),-l[2]))),c[3]),n(t(t(n(t(n(e(H,z),o[1]),t(n(e(q,S),-s[1]),n(e(I,A),c[1]))),a[2]),n(t(n(e(H,z),a[1]),t(n(e(V,b),-s[1]),n(e(L,x),c[1]))),-o[2])),t(n(t(n(e(q,S),a[1]),t(n(e(V,b),-o[1]),n(e(k,v),c[1]))),s[2]),n(t(n(e(I,A),a[1]),t(n(e(L,x),-o[1]),n(e(k,v),s[1]))),-c[2]))),i[3]))),t(t(n(t(t(n(t(n(e(H,z),o[1]),t(n(e(q,S),-s[1]),n(e(I,A),c[1]))),i[2]),n(t(n(e(H,z),i[1]),t(n(e(U,m),-s[1]),n(e(C,p),c[1]))),-o[2])),t(n(t(n(e(q,S),i[1]),t(n(e(U,m),-o[1]),n(e(T,f),c[1]))),s[2]),n(t(n(e(I,A),i[1]),t(n(e(C,p),-o[1]),n(e(T,f),s[1]))),-c[2]))),-a[3]),n(t(t(n(t(n(e(H,z),a[1]),t(n(e(V,b),-s[1]),n(e(L,x),c[1]))),i[2]),n(t(n(e(H,z),i[1]),t(n(e(U,m),-s[1]),n(e(C,p),c[1]))),-a[2])),t(n(t(n(e(V,b),i[1]),t(n(e(U,m),-a[1]),n(e(y,h),c[1]))),s[2]),n(t(n(e(L,x),i[1]),t(n(e(C,p),-a[1]),n(e(y,h),s[1]))),-c[2]))),o[3])),t(n(t(t(n(t(n(e(q,S),a[1]),t(n(e(V,b),-o[1]),n(e(k,v),c[1]))),i[2]),n(t(n(e(q,S),i[1]),t(n(e(U,m),-o[1]),n(e(T,f),c[1]))),-a[2])),t(n(t(n(e(V,b),i[1]),t(n(e(U,m),-a[1]),n(e(y,h),c[1]))),o[2]),n(t(n(e(k,v),i[1]),t(n(e(T,f),-a[1]),n(e(y,h),o[1]))),-c[2]))),-s[3]),n(t(t(n(t(n(e(I,A),a[1]),t(n(e(L,x),-o[1]),n(e(k,v),s[1]))),i[2]),n(t(n(e(I,A),i[1]),t(n(e(C,p),-o[1]),n(e(T,f),s[1]))),-a[2])),t(n(t(n(e(L,x),i[1]),t(n(e(C,p),-a[1]),n(e(y,h),s[1]))),o[2]),n(t(n(e(k,v),i[1]),t(n(e(T,f),-a[1]),n(e(y,h),o[1]))),-s[2]))),c[3]))))),W=t(t(t(n(t(t(n(t(n(e(G,N),s[1]),t(n(e(H,z),-l[1]),n(e(B,P),c[1]))),o[2]),n(t(n(e(G,N),o[1]),t(n(e(q,S),-l[1]),n(e(F,M),c[1]))),-s[2])),t(n(t(n(e(H,z),o[1]),t(n(e(q,S),-s[1]),n(e(I,A),c[1]))),l[2]),n(t(n(e(B,P),o[1]),t(n(e(F,M),-s[1]),n(e(I,A),l[1]))),-c[2]))),i[3]),t(n(t(t(n(t(n(e(G,N),s[1]),t(n(e(H,z),-l[1]),n(e(B,P),c[1]))),i[2]),n(t(n(e(G,N),i[1]),t(n(e(U,m),-l[1]),n(e(D,d),c[1]))),-s[2])),t(n(t(n(e(H,z),i[1]),t(n(e(U,m),-s[1]),n(e(C,p),c[1]))),l[2]),n(t(n(e(B,P),i[1]),t(n(e(D,d),-s[1]),n(e(C,p),l[1]))),-c[2]))),-o[3]),n(t(t(n(t(n(e(G,N),o[1]),t(n(e(q,S),-l[1]),n(e(F,M),c[1]))),i[2]),n(t(n(e(G,N),i[1]),t(n(e(U,m),-l[1]),n(e(D,d),c[1]))),-o[2])),t(n(t(n(e(q,S),i[1]),t(n(e(U,m),-o[1]),n(e(T,f),c[1]))),l[2]),n(t(n(e(F,M),i[1]),t(n(e(D,d),-o[1]),n(e(T,f),l[1]))),-c[2]))),s[3]))),t(t(n(t(t(n(t(n(e(H,z),o[1]),t(n(e(q,S),-s[1]),n(e(I,A),c[1]))),i[2]),n(t(n(e(H,z),i[1]),t(n(e(U,m),-s[1]),n(e(C,p),c[1]))),-o[2])),t(n(t(n(e(q,S),i[1]),t(n(e(U,m),-o[1]),n(e(T,f),c[1]))),s[2]),n(t(n(e(I,A),i[1]),t(n(e(C,p),-o[1]),n(e(T,f),s[1]))),-c[2]))),-l[3]),n(t(t(n(t(n(e(B,P),o[1]),t(n(e(F,M),-s[1]),n(e(I,A),l[1]))),i[2]),n(t(n(e(B,P),i[1]),t(n(e(D,d),-s[1]),n(e(C,p),l[1]))),-o[2])),t(n(t(n(e(F,M),i[1]),t(n(e(D,d),-o[1]),n(e(T,f),l[1]))),s[2]),n(t(n(e(I,A),i[1]),t(n(e(C,p),-o[1]),n(e(T,f),s[1]))),-l[2]))),c[3])),t(n(t(t(n(t(n(e(G,N),o[1]),t(n(e(q,S),-l[1]),n(e(F,M),c[1]))),a[2]),n(t(n(e(G,N),a[1]),t(n(e(V,b),-l[1]),n(e(R,_),c[1]))),-o[2])),t(n(t(n(e(q,S),a[1]),t(n(e(V,b),-o[1]),n(e(k,v),c[1]))),l[2]),n(t(n(e(F,M),a[1]),t(n(e(R,_),-o[1]),n(e(k,v),l[1]))),-c[2]))),i[3]),n(t(t(n(t(n(e(G,N),o[1]),t(n(e(q,S),-l[1]),n(e(F,M),c[1]))),i[2]),n(t(n(e(G,N),i[1]),t(n(e(U,m),-l[1]),n(e(D,d),c[1]))),-o[2])),t(n(t(n(e(q,S),i[1]),t(n(e(U,m),-o[1]),n(e(T,f),c[1]))),l[2]),n(t(n(e(F,M),i[1]),t(n(e(D,d),-o[1]),n(e(T,f),l[1]))),-c[2]))),-a[3])))),t(t(t(n(t(t(n(t(n(e(G,N),a[1]),t(n(e(V,b),-l[1]),n(e(R,_),c[1]))),i[2]),n(t(n(e(G,N),i[1]),t(n(e(U,m),-l[1]),n(e(D,d),c[1]))),-a[2])),t(n(t(n(e(V,b),i[1]),t(n(e(U,m),-a[1]),n(e(y,h),c[1]))),l[2]),n(t(n(e(R,_),i[1]),t(n(e(D,d),-a[1]),n(e(y,h),l[1]))),-c[2]))),o[3]),n(t(t(n(t(n(e(q,S),a[1]),t(n(e(V,b),-o[1]),n(e(k,v),c[1]))),i[2]),n(t(n(e(q,S),i[1]),t(n(e(U,m),-o[1]),n(e(T,f),c[1]))),-a[2])),t(n(t(n(e(V,b),i[1]),t(n(e(U,m),-a[1]),n(e(y,h),c[1]))),o[2]),n(t(n(e(k,v),i[1]),t(n(e(T,f),-a[1]),n(e(y,h),o[1]))),-c[2]))),-l[3])),t(n(t(t(n(t(n(e(F,M),a[1]),t(n(e(R,_),-o[1]),n(e(k,v),l[1]))),i[2]),n(t(n(e(F,M),i[1]),t(n(e(D,d),-o[1]),n(e(T,f),l[1]))),-a[2])),t(n(t(n(e(R,_),i[1]),t(n(e(D,d),-a[1]),n(e(y,h),l[1]))),o[2]),n(t(n(e(k,v),i[1]),t(n(e(T,f),-a[1]),n(e(y,h),o[1]))),-l[2]))),c[3]),n(t(t(n(t(n(e(B,P),o[1]),t(n(e(F,M),-s[1]),n(e(I,A),l[1]))),a[2]),n(t(n(e(B,P),a[1]),t(n(e(R,_),-s[1]),n(e(L,x),l[1]))),-o[2])),t(n(t(n(e(F,M),a[1]),t(n(e(R,_),-o[1]),n(e(k,v),l[1]))),s[2]),n(t(n(e(I,A),a[1]),t(n(e(L,x),-o[1]),n(e(k,v),s[1]))),-l[2]))),i[3]))),t(t(n(t(t(n(t(n(e(B,P),o[1]),t(n(e(F,M),-s[1]),n(e(I,A),l[1]))),i[2]),n(t(n(e(B,P),i[1]),t(n(e(D,d),-s[1]),n(e(C,p),l[1]))),-o[2])),t(n(t(n(e(F,M),i[1]),t(n(e(D,d),-o[1]),n(e(T,f),l[1]))),s[2]),n(t(n(e(I,A),i[1]),t(n(e(C,p),-o[1]),n(e(T,f),s[1]))),-l[2]))),-a[3]),n(t(t(n(t(n(e(B,P),a[1]),t(n(e(R,_),-s[1]),n(e(L,x),l[1]))),i[2]),n(t(n(e(B,P),i[1]),t(n(e(D,d),-s[1]),n(e(C,p),l[1]))),-a[2])),t(n(t(n(e(R,_),i[1]),t(n(e(D,d),-a[1]),n(e(y,h),l[1]))),s[2]),n(t(n(e(L,x),i[1]),t(n(e(C,p),-a[1]),n(e(y,h),s[1]))),-l[2]))),o[3])),t(n(t(t(n(t(n(e(F,M),a[1]),t(n(e(R,_),-o[1]),n(e(k,v),l[1]))),i[2]),n(t(n(e(F,M),i[1]),t(n(e(D,d),-o[1]),n(e(T,f),l[1]))),-a[2])),t(n(t(n(e(R,_),i[1]),t(n(e(D,d),-a[1]),n(e(y,h),l[1]))),o[2]),n(t(n(e(k,v),i[1]),t(n(e(T,f),-a[1]),n(e(y,h),o[1]))),-l[2]))),-s[3]),n(t(t(n(t(n(e(I,A),a[1]),t(n(e(L,x),-o[1]),n(e(k,v),s[1]))),i[2]),n(t(n(e(I,A),i[1]),t(n(e(C,p),-o[1]),n(e(T,f),s[1]))),-a[2])),t(n(t(n(e(L,x),i[1]),t(n(e(C,p),-a[1]),n(e(y,h),s[1]))),o[2]),n(t(n(e(k,v),i[1]),t(n(e(T,f),-a[1]),n(e(y,h),o[1]))),-s[2]))),l[3]))))),Y=e(Z,W);return Y[Y.length-1]}}var f=[function(){return 0},function(){return 0},function(){return 0}];function p(t){var e=f[t.length];return e||(e=f[t.length]=s(t.length)),e.apply(void 0,t)}function d(t,e,r,n,i,a,o,s){return function(e,r,l,c,u,h){switch(arguments.length){case 0:case 1:return 0;case 2:return n(e,r);case 3:return i(e,r,l);case 4:return a(e,r,l,c);case 5:return o(e,r,l,c,u);case 6:return s(e,r,l,c,u,h)}for(var f=new Array(arguments.length),p=0;p<arguments.length;++p)f[p]=arguments[p];return t(f)}}!function(){for(;f.length<=6;)f.push(s(f.length));t.exports=d.apply(void 0,[p].concat(f));for(var e=0;e<=6;++e)t.exports[e]=f[e]}()},727:function(t,e,r){\"use strict\";var n=r(2962);function i(t){return(2===t?a:3===t?o:4===t?s:5===t?l:c)(t<6?n[t]:n)}function a(t){return function(e,r){return[t([[+r[0],+e[0][1]],[+r[1],+e[1][1]]]),t([[+e[0][0],+r[0]],[+e[1][0],+r[1]]]),t(e)]}}function o(t){return function(e,r){return[t([[+r[0],+e[0][1],+e[0][2]],[+r[1],+e[1][1],+e[1][2]],[+r[2],+e[2][1],+e[2][2]]]),t([[+e[0][0],+r[0],+e[0][2]],[+e[1][0],+r[1],+e[1][2]],[+e[2][0],+r[2],+e[2][2]]]),t([[+e[0][0],+e[0][1],+r[0]],[+e[1][0],+e[1][1],+r[1]],[+e[2][0],+e[2][1],+r[2]]]),t(e)]}}function s(t){return function(e,r){return[t([[+r[0],+e[0][1],+e[0][2],+e[0][3]],[+r[1],+e[1][1],+e[1][2],+e[1][3]],[+r[2],+e[2][1],+e[2][2],+e[2][3]],[+r[3],+e[3][1],+e[3][2],+e[3][3]]]),t([[+e[0][0],+r[0],+e[0][2],+e[0][3]],[+e[1][0],+r[1],+e[1][2],+e[1][3]],[+e[2][0],+r[2],+e[2][2],+e[2][3]],[+e[3][0],+r[3],+e[3][2],+e[3][3]]]),t([[+e[0][0],+e[0][1],+r[0],+e[0][3]],[+e[1][0],+e[1][1],+r[1],+e[1][3]],[+e[2][0],+e[2][1],+r[2],+e[2][3]],[+e[3][0],+e[3][1],+r[3],+e[3][3]]]),t([[+e[0][0],+e[0][1],+e[0][2],+r[0]],[+e[1][0],+e[1][1],+e[1][2],+r[1]],[+e[2][0],+e[2][1],+e[2][2],+r[2]],[+e[3][0],+e[3][1],+e[3][2],+r[3]]]),t(e)]}}function l(t){return function(e,r){return[t([[+r[0],+e[0][1],+e[0][2],+e[0][3],+e[0][4]],[+r[1],+e[1][1],+e[1][2],+e[1][3],+e[1][4]],[+r[2],+e[2][1],+e[2][2],+e[2][3],+e[2][4]],[+r[3],+e[3][1],+e[3][2],+e[3][3],+e[3][4]],[+r[4],+e[4][1],+e[4][2],+e[4][3],+e[4][4]]]),t([[+e[0][0],+r[0],+e[0][2],+e[0][3],+e[0][4]],[+e[1][0],+r[1],+e[1][2],+e[1][3],+e[1][4]],[+e[2][0],+r[2],+e[2][2],+e[2][3],+e[2][4]],[+e[3][0],+r[3],+e[3][2],+e[3][3],+e[3][4]],[+e[4][0],+r[4],+e[4][2],+e[4][3],+e[4][4]]]),t([[+e[0][0],+e[0][1],+r[0],+e[0][3],+e[0][4]],[+e[1][0],+e[1][1],+r[1],+e[1][3],+e[1][4]],[+e[2][0],+e[2][1],+r[2],+e[2][3],+e[2][4]],[+e[3][0],+e[3][1],+r[3],+e[3][3],+e[3][4]],[+e[4][0],+e[4][1],+r[4],+e[4][3],+e[4][4]]]),t([[+e[0][0],+e[0][1],+e[0][2],+r[0],+e[0][4]],[+e[1][0],+e[1][1],+e[1][2],+r[1],+e[1][4]],[+e[2][0],+e[2][1],+e[2][2],+r[2],+e[2][4]],[+e[3][0],+e[3][1],+e[3][2],+r[3],+e[3][4]],[+e[4][0],+e[4][1],+e[4][2],+r[4],+e[4][4]]]),t([[+e[0][0],+e[0][1],+e[0][2],+e[0][3],+r[0]],[+e[1][0],+e[1][1],+e[1][2],+e[1][3],+r[1]],[+e[2][0],+e[2][1],+e[2][2],+e[2][3],+r[2]],[+e[3][0],+e[3][1],+e[3][2],+e[3][3],+r[3]],[+e[4][0],+e[4][1],+e[4][2],+e[4][3],+r[4]]]),t(e)]}}function c(t){return function(e,r){return[t([[+r[0],+e[0][1],+e[0][2],+e[0][3],+e[0][4],+e[0][5]],[+r[1],+e[1][1],+e[1][2],+e[1][3],+e[1][4],+e[1][5]],[+r[2],+e[2][1],+e[2][2],+e[2][3],+e[2][4],+e[2][5]],[+r[3],+e[3][1],+e[3][2],+e[3][3],+e[3][4],+e[3][5]],[+r[4],+e[4][1],+e[4][2],+e[4][3],+e[4][4],+e[4][5]],[+r[5],+e[5][1],+e[5][2],+e[5][3],+e[5][4],+e[5][5]]]),t([[+e[0][0],+r[0],+e[0][2],+e[0][3],+e[0][4],+e[0][5]],[+e[1][0],+r[1],+e[1][2],+e[1][3],+e[1][4],+e[1][5]],[+e[2][0],+r[2],+e[2][2],+e[2][3],+e[2][4],+e[2][5]],[+e[3][0],+r[3],+e[3][2],+e[3][3],+e[3][4],+e[3][5]],[+e[4][0],+r[4],+e[4][2],+e[4][3],+e[4][4],+e[4][5]],[+e[5][0],+r[5],+e[5][2],+e[5][3],+e[5][4],+e[5][5]]]),t([[+e[0][0],+e[0][1],+r[0],+e[0][3],+e[0][4],+e[0][5]],[+e[1][0],+e[1][1],+r[1],+e[1][3],+e[1][4],+e[1][5]],[+e[2][0],+e[2][1],+r[2],+e[2][3],+e[2][4],+e[2][5]],[+e[3][0],+e[3][1],+r[3],+e[3][3],+e[3][4],+e[3][5]],[+e[4][0],+e[4][1],+r[4],+e[4][3],+e[4][4],+e[4][5]],[+e[5][0],+e[5][1],+r[5],+e[5][3],+e[5][4],+e[5][5]]]),t([[+e[0][0],+e[0][1],+e[0][2],+r[0],+e[0][4],+e[0][5]],[+e[1][0],+e[1][1],+e[1][2],+r[1],+e[1][4],+e[1][5]],[+e[2][0],+e[2][1],+e[2][2],+r[2],+e[2][4],+e[2][5]],[+e[3][0],+e[3][1],+e[3][2],+r[3],+e[3][4],+e[3][5]],[+e[4][0],+e[4][1],+e[4][2],+r[4],+e[4][4],+e[4][5]],[+e[5][0],+e[5][1],+e[5][2],+r[5],+e[5][4],+e[5][5]]]),t([[+e[0][0],+e[0][1],+e[0][2],+e[0][3],+r[0],+e[0][5]],[+e[1][0],+e[1][1],+e[1][2],+e[1][3],+r[1],+e[1][5]],[+e[2][0],+e[2][1],+e[2][2],+e[2][3],+r[2],+e[2][5]],[+e[3][0],+e[3][1],+e[3][2],+e[3][3],+r[3],+e[3][5]],[+e[4][0],+e[4][1],+e[4][2],+e[4][3],+r[4],+e[4][5]],[+e[5][0],+e[5][1],+e[5][2],+e[5][3],+r[5],+e[5][5]]]),t([[+e[0][0],+e[0][1],+e[0][2],+e[0][3],+e[0][4],+r[0]],[+e[1][0],+e[1][1],+e[1][2],+e[1][3],+e[1][4],+r[1]],[+e[2][0],+e[2][1],+e[2][2],+e[2][3],+e[2][4],+r[2]],[+e[3][0],+e[3][1],+e[3][2],+e[3][3],+e[3][4],+r[3]],[+e[4][0],+e[4][1],+e[4][2],+e[4][3],+e[4][4],+r[4]],[+e[5][0],+e[5][1],+e[5][2],+e[5][3],+e[5][4],+r[5]]]),t(e)]}}var u=[function(){return[[0]]},function(t,e){return[[e[0]],[t[0][0]]]}];function h(t,e,r,n,i,a,o,s){return function(l,c){switch(l.length){case 0:return t(l,c);case 1:return e(l,c);case 2:return r(l,c);case 3:return n(l,c);case 4:return i(l,c);case 5:return a(l,c)}var u=o[l.length];return u||(u=o[l.length]=s(l.length)),u(l,c)}}!function(){for(;u.length<6;)u.push(i(u.length));t.exports=h.apply(void 0,u.concat([u,i]));for(var e=0;e<6;++e)t.exports[e]=u[e]}()},3250:function(t,e,r){\"use strict\";var n=r(5250),i=r(8210),a=r(3012),o=r(8545);function s(t,e,r,n){return function(r,i,a){var o=t(t(e(i[1],a[0]),e(-a[1],i[0])),t(e(r[1],i[0]),e(-i[1],r[0]))),s=t(e(r[1],a[0]),e(-a[1],r[0])),l=n(o,s);return l[l.length-1]}}function l(t,e,r,n){return function(i,a,o,s){var l=t(t(r(t(e(o[1],s[0]),e(-s[1],o[0])),a[2]),t(r(t(e(a[1],s[0]),e(-s[1],a[0])),-o[2]),r(t(e(a[1],o[0]),e(-o[1],a[0])),s[2]))),t(r(t(e(a[1],s[0]),e(-s[1],a[0])),i[2]),t(r(t(e(i[1],s[0]),e(-s[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),s[2])))),c=t(t(r(t(e(o[1],s[0]),e(-s[1],o[0])),i[2]),t(r(t(e(i[1],s[0]),e(-s[1],i[0])),-o[2]),r(t(e(i[1],o[0]),e(-o[1],i[0])),s[2]))),t(r(t(e(a[1],o[0]),e(-o[1],a[0])),i[2]),t(r(t(e(i[1],o[0]),e(-o[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),o[2])))),u=n(l,c);return u[u.length-1]}}function c(t,e,r,n){return function(i,a,o,s,l){var c=t(t(t(r(t(r(t(e(s[1],l[0]),e(-l[1],s[0])),o[2]),t(r(t(e(o[1],l[0]),e(-l[1],o[0])),-s[2]),r(t(e(o[1],s[0]),e(-s[1],o[0])),l[2]))),a[3]),t(r(t(r(t(e(s[1],l[0]),e(-l[1],s[0])),a[2]),t(r(t(e(a[1],l[0]),e(-l[1],a[0])),-s[2]),r(t(e(a[1],s[0]),e(-s[1],a[0])),l[2]))),-o[3]),r(t(r(t(e(o[1],l[0]),e(-l[1],o[0])),a[2]),t(r(t(e(a[1],l[0]),e(-l[1],a[0])),-o[2]),r(t(e(a[1],o[0]),e(-o[1],a[0])),l[2]))),s[3]))),t(r(t(r(t(e(o[1],s[0]),e(-s[1],o[0])),a[2]),t(r(t(e(a[1],s[0]),e(-s[1],a[0])),-o[2]),r(t(e(a[1],o[0]),e(-o[1],a[0])),s[2]))),-l[3]),t(r(t(r(t(e(s[1],l[0]),e(-l[1],s[0])),a[2]),t(r(t(e(a[1],l[0]),e(-l[1],a[0])),-s[2]),r(t(e(a[1],s[0]),e(-s[1],a[0])),l[2]))),i[3]),r(t(r(t(e(s[1],l[0]),e(-l[1],s[0])),i[2]),t(r(t(e(i[1],l[0]),e(-l[1],i[0])),-s[2]),r(t(e(i[1],s[0]),e(-s[1],i[0])),l[2]))),-a[3])))),t(t(r(t(r(t(e(a[1],l[0]),e(-l[1],a[0])),i[2]),t(r(t(e(i[1],l[0]),e(-l[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),l[2]))),s[3]),t(r(t(r(t(e(a[1],s[0]),e(-s[1],a[0])),i[2]),t(r(t(e(i[1],s[0]),e(-s[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),s[2]))),-l[3]),r(t(r(t(e(o[1],s[0]),e(-s[1],o[0])),a[2]),t(r(t(e(a[1],s[0]),e(-s[1],a[0])),-o[2]),r(t(e(a[1],o[0]),e(-o[1],a[0])),s[2]))),i[3]))),t(r(t(r(t(e(o[1],s[0]),e(-s[1],o[0])),i[2]),t(r(t(e(i[1],s[0]),e(-s[1],i[0])),-o[2]),r(t(e(i[1],o[0]),e(-o[1],i[0])),s[2]))),-a[3]),t(r(t(r(t(e(a[1],s[0]),e(-s[1],a[0])),i[2]),t(r(t(e(i[1],s[0]),e(-s[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),s[2]))),o[3]),r(t(r(t(e(a[1],o[0]),e(-o[1],a[0])),i[2]),t(r(t(e(i[1],o[0]),e(-o[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),o[2]))),-s[3]))))),u=t(t(t(r(t(r(t(e(s[1],l[0]),e(-l[1],s[0])),o[2]),t(r(t(e(o[1],l[0]),e(-l[1],o[0])),-s[2]),r(t(e(o[1],s[0]),e(-s[1],o[0])),l[2]))),i[3]),r(t(r(t(e(s[1],l[0]),e(-l[1],s[0])),i[2]),t(r(t(e(i[1],l[0]),e(-l[1],i[0])),-s[2]),r(t(e(i[1],s[0]),e(-s[1],i[0])),l[2]))),-o[3])),t(r(t(r(t(e(o[1],l[0]),e(-l[1],o[0])),i[2]),t(r(t(e(i[1],l[0]),e(-l[1],i[0])),-o[2]),r(t(e(i[1],o[0]),e(-o[1],i[0])),l[2]))),s[3]),r(t(r(t(e(o[1],s[0]),e(-s[1],o[0])),i[2]),t(r(t(e(i[1],s[0]),e(-s[1],i[0])),-o[2]),r(t(e(i[1],o[0]),e(-o[1],i[0])),s[2]))),-l[3]))),t(t(r(t(r(t(e(o[1],l[0]),e(-l[1],o[0])),a[2]),t(r(t(e(a[1],l[0]),e(-l[1],a[0])),-o[2]),r(t(e(a[1],o[0]),e(-o[1],a[0])),l[2]))),i[3]),r(t(r(t(e(o[1],l[0]),e(-l[1],o[0])),i[2]),t(r(t(e(i[1],l[0]),e(-l[1],i[0])),-o[2]),r(t(e(i[1],o[0]),e(-o[1],i[0])),l[2]))),-a[3])),t(r(t(r(t(e(a[1],l[0]),e(-l[1],a[0])),i[2]),t(r(t(e(i[1],l[0]),e(-l[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),l[2]))),o[3]),r(t(r(t(e(a[1],o[0]),e(-o[1],a[0])),i[2]),t(r(t(e(i[1],o[0]),e(-o[1],i[0])),-a[2]),r(t(e(i[1],a[0]),e(-a[1],i[0])),o[2]))),-l[3])))),h=n(c,u);return h[h.length-1]}}function u(t){return(3===t?s:4===t?l:c)(i,n,a,o)}var h=u(3),f=u(4),p=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=33306690738754716e-32*n;return o>=s||o<=-s?o:h(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],p=r[2]-n[2],d=a*c,m=o*l,g=o*s,y=i*c,v=i*l,x=a*s,_=u*(d-m)+h*(g-y)+p*(v-x),b=7771561172376103e-31*((Math.abs(d)+Math.abs(m))*Math.abs(u)+(Math.abs(g)+Math.abs(y))*Math.abs(h)+(Math.abs(v)+Math.abs(x))*Math.abs(p));return _>b||-_>b?_:f(t,e,r,n)}];function d(t){var e=p[t.length];return e||(e=p[t.length]=u(t.length)),e.apply(void 0,t)}function m(t,e,r,n,i,a,o){return function(e,r,s,l,c){switch(arguments.length){case 0:case 1:return 0;case 2:return n(e,r);case 3:return i(e,r,s);case 4:return a(e,r,s,l);case 5:return o(e,r,s,l,c)}for(var u=new Array(arguments.length),h=0;h<arguments.length;++h)u[h]=arguments[h];return t(u)}}!function(){for(;p.length<=5;)p.push(u(p.length));t.exports=m.apply(void 0,[d].concat(p));for(var e=0;e<=5;++e)t.exports[e]=p[e]}()},5382:function(t,e,r){\"use strict\";var n=r(8210),i=r(3012);t.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},3012:function(t,e,r){\"use strict\";var n=r(5250),i=r(9362);t.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,m=p-(d-f);s[1]=d,m&&(o[c++]=m)}return s[1]&&(o[c++]=s[1]),0===c&&(o[c++]=0),o.length=c,o}},1125:function(t,e,r){\"use strict\";t.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);return!(s>0&&l>0||s<0&&l<0)&&(0!==a||0!==o||0!==s||0!==l||function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u);if(Math.max(c,u)<s||l<h)return!1}return!0}(t,e,r,i))};var n=r(3250)[3]},8545:function(t){\"use strict\";t.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);return i?[i,r]:[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(f=u(h=t[l]))):(a=p,(c+=1)<n&&(d=u(p=-e[c]))),l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(f=u(h=t[l]))):(i=p,(c+=1)<n&&(d=u(p=-e[c])));for(var m,g,y=i+a,v=y-i,x=a-v,_=x,b=y;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(f=u(h=t[l]))):(i=p,(c+=1)<n&&(d=u(p=-e[c]))),(x=(a=_)-(v=(y=i+a)-i))&&(o[s++]=x),_=b-((m=b+y)-(g=m-b))+(y-g),b=m;for(;l<r;)(x=(a=_)-(v=(y=(i=h)+a)-i))&&(o[s++]=x),_=b-((m=b+y)-(g=m-b))+(y-g),b=m,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=_)-(v=(y=(i=p)+a)-i))&&(o[s++]=x),_=b-((m=b+y)-(g=m-b))+(y-g),b=m,(c+=1)<n&&(p=-e[c]);return _&&(o[s++]=_),b&&(o[s++]=b),s||(o[s++]=0),o.length=s,o}},8210:function(t){\"use strict\";t.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);return i?[i,r]:[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(f=u(h=t[l]))):(a=p,(c+=1)<n&&(d=u(p=e[c]))),l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(f=u(h=t[l]))):(i=p,(c+=1)<n&&(d=u(p=e[c])));for(var m,g,y=i+a,v=y-i,x=a-v,_=x,b=y;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(f=u(h=t[l]))):(i=p,(c+=1)<n&&(d=u(p=e[c]))),(x=(a=_)-(v=(y=i+a)-i))&&(o[s++]=x),_=b-((m=b+y)-(g=m-b))+(y-g),b=m;for(;l<r;)(x=(a=_)-(v=(y=(i=h)+a)-i))&&(o[s++]=x),_=b-((m=b+y)-(g=m-b))+(y-g),b=m,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=_)-(v=(y=(i=p)+a)-i))&&(o[s++]=x),_=b-((m=b+y)-(g=m-b))+(y-g),b=m,(c+=1)<n&&(p=e[c]);return _&&(o[s++]=_),b&&(o[s++]=b),s||(o[s++]=0),o.length=s,o}},9127:function(t,e,r){\"use strict\";t.exports=function(t){return i(n(t))};var n=r(6204),i=r(5771)},7765:function(t,e,r){\"use strict\";t.exports=function(t,e,r,s){if(r=r||0,void 0===s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t)),0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],h=(e=u.length,0);h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));var m=2;for(c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[m++]=s[c],s[m++]=s[c+1]);return n(s,[m/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}for(r[2*o+1]=n;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=r(9618),i=r(1888),a=r(446),o=r(1570)},1570:function(t){\"use strict\";t.exports=function(t){return e[t]()};var e=[function(){return function(t,e,r,n){for(var i=t.length,a=0;a<i;++a)t[a].length;return[]}},function(){function t(t,e,r,n){for(var i=0|Math.min(r,n),a=0|Math.max(r,n),o=t[2*i],s=t[2*i+1];o<s;){var l=o+s>>1,c=e[2*l+1];if(c===a)return l;a<c?s=l:o=l+1}return o}return function(e,r,n,i){for(var a=e.length,o=[],s=0;s<a;++s){var l=e[s];if(2===l.length){var c=(i[l[0]]<<0)+(i[l[1]]<<1);if(0===c||3===c)continue;switch(c){case 0:case 3:break;case 1:o.push([t(n,r,l[0],l[1])]);break;case 2:o.push([t(n,r,l[1],l[0])])}}}return o}},function(){function t(t,e,r,n){for(var i=0|Math.min(r,n),a=0|Math.max(r,n),o=t[2*i],s=t[2*i+1];o<s;){var l=o+s>>1,c=e[2*l+1];if(c===a)return l;a<c?s=l:o=l+1}return o}return function(e,r,n,i){for(var a=e.length,o=[],s=0;s<a;++s){var l=e[s],c=l.length;if(3===c){if(0==(u=(i[l[0]]<<0)+(i[l[1]]<<1)+(i[l[2]]<<2))||7===u)continue;switch(u){case 0:case 7:break;case 1:o.push([t(n,r,l[0],l[2]),t(n,r,l[0],l[1])]);break;case 2:o.push([t(n,r,l[1],l[0]),t(n,r,l[1],l[2])]);break;case 3:o.push([t(n,r,l[0],l[2]),t(n,r,l[1],l[2])]);break;case 4:o.push([t(n,r,l[2],l[1]),t(n,r,l[2],l[0])]);break;case 5:o.push([t(n,r,l[2],l[1]),t(n,r,l[0],l[1])]);break;case 6:o.push([t(n,r,l[1],l[0]),t(n,r,l[2],l[0])])}}else if(2===c){var u;if(0==(u=(i[l[0]]<<0)+(i[l[1]]<<1))||3===u)continue;switch(u){case 0:case 3:break;case 1:o.push([t(n,r,l[0],l[1])]);break;case 2:o.push([t(n,r,l[1],l[0])])}}}return o}},function(){function t(t,e,r,n){for(var i=0|Math.min(r,n),a=0|Math.max(r,n),o=t[2*i],s=t[2*i+1];o<s;){var l=o+s>>1,c=e[2*l+1];if(c===a)return l;a<c?s=l:o=l+1}return o}return function(e,r,n,i){for(var a=e.length,o=[],s=0;s<a;++s){var l=e[s],c=l.length;if(4===c){if(0==(u=(i[l[0]]<<0)+(i[l[1]]<<1)+(i[l[2]]<<2)+(i[l[3]]<<3))||15===u)continue;switch(u){case 0:case 15:break;case 1:o.push([t(n,r,l[0],l[1]),t(n,r,l[0],l[2]),t(n,r,l[0],l[3])]);break;case 2:o.push([t(n,r,l[1],l[2]),t(n,r,l[1],l[0]),t(n,r,l[1],l[3])]);break;case 3:o.push([t(n,r,l[1],l[2]),t(n,r,l[0],l[2]),t(n,r,l[0],l[3])],[t(n,r,l[1],l[3]),t(n,r,l[1],l[2]),t(n,r,l[0],l[3])]);break;case 4:o.push([t(n,r,l[2],l[0]),t(n,r,l[2],l[1]),t(n,r,l[2],l[3])]);break;case 5:o.push([t(n,r,l[0],l[1]),t(n,r,l[2],l[1]),t(n,r,l[0],l[3])],[t(n,r,l[2],l[1]),t(n,r,l[2],l[3]),t(n,r,l[0],l[3])]);break;case 6:o.push([t(n,r,l[2],l[0]),t(n,r,l[1],l[0]),t(n,r,l[1],l[3])],[t(n,r,l[2],l[3]),t(n,r,l[2],l[0]),t(n,r,l[1],l[3])]);break;case 7:o.push([t(n,r,l[0],l[3]),t(n,r,l[1],l[3]),t(n,r,l[2],l[3])]);break;case 8:o.push([t(n,r,l[3],l[1]),t(n,r,l[3],l[0]),t(n,r,l[3],l[2])]);break;case 9:o.push([t(n,r,l[3],l[1]),t(n,r,l[0],l[1]),t(n,r,l[0],l[2])],[t(n,r,l[3],l[2]),t(n,r,l[3],l[1]),t(n,r,l[0],l[2])]);break;case 10:o.push([t(n,r,l[1],l[0]),t(n,r,l[3],l[0]),t(n,r,l[1],l[2])],[t(n,r,l[3],l[0]),t(n,r,l[3],l[2]),t(n,r,l[1],l[2])]);break;case 11:o.push([t(n,r,l[1],l[2]),t(n,r,l[0],l[2]),t(n,r,l[3],l[2])]);break;case 12:o.push([t(n,r,l[3],l[0]),t(n,r,l[2],l[0]),t(n,r,l[2],l[1])],[t(n,r,l[3],l[1]),t(n,r,l[3],l[0]),t(n,r,l[2],l[1])]);break;case 13:o.push([t(n,r,l[0],l[1]),t(n,r,l[2],l[1]),t(n,r,l[3],l[1])]);break;case 14:o.push([t(n,r,l[2],l[0]),t(n,r,l[1],l[0]),t(n,r,l[3],l[0])])}}else if(3===c){if(0==(u=(i[l[0]]<<0)+(i[l[1]]<<1)+(i[l[2]]<<2))||7===u)continue;switch(u){case 0:case 7:break;case 1:o.push([t(n,r,l[0],l[2]),t(n,r,l[0],l[1])]);break;case 2:o.push([t(n,r,l[1],l[0]),t(n,r,l[1],l[2])]);break;case 3:o.push([t(n,r,l[0],l[2]),t(n,r,l[1],l[2])]);break;case 4:o.push([t(n,r,l[2],l[1]),t(n,r,l[2],l[0])]);break;case 5:o.push([t(n,r,l[2],l[1]),t(n,r,l[0],l[1])]);break;case 6:o.push([t(n,r,l[1],l[0]),t(n,r,l[2],l[0])])}}else if(2===c){var u;if(0==(u=(i[l[0]]<<0)+(i[l[1]]<<1))||3===u)continue;switch(u){case 0:case 3:break;case 1:o.push([t(n,r,l[0],l[1])]);break;case 2:o.push([t(n,r,l[1],l[0])])}}}return o}}]},6803:function(t,e,r){\"use strict\";r(8828),r(1755);function n(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}e.Fw=n},3105:function(t,e){\"use strict\";function r(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}e.INT_BITS=32,e.INT_MAX=2147483647,e.INT_MIN=-1<<31,e.sign=function(t){return(t>0)-(t<0)},e.abs=function(t){var e=t>>31;return(t^e)-e},e.min=function(t,e){return e^(t^e)&-(t<e)},e.max=function(t,e){return t^(t^e)&-(t<e)},e.isPow2=function(t){return!(t&t-1||!t)},e.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},e.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},e.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},e.countTrailingZeros=r,e.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,1+(t|=t>>>16)},e.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},e.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var n=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(n),e.reverse=function(t){return n[255&t]<<24|n[t>>>8&255]<<16|n[t>>>16&255]<<8|n[t>>>24&255]},e.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},e.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},e.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},e.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},e.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>r(t)+1}},2014:function(t,e,r){\"use strict\";var n=r(3105),i=r(4623);function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];for(n.sort(o),i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,m=0;m<h;++m)f&1<<m&&(s[d++]=u[m]);var g=c(t,s);if(!(g<0))for(;r[g++].push(i),!(g>=t.length||0!==a(t[g],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}e.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},e.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},e.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},e.compareCells=a,e.normalize=s,e.unique=l,e.findCell=c,e.incidence=u,e.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},e.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},e.skeleton=h,e.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},e.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var m=r.find(c(e,[t[n][0]]));d[m]<0?(d[m]=p.length,p.push([t[n].slice(0)])):p[d[m]].push(t[n].slice(0))}return p}(t)}},4623:function(t){\"use strict\";function e(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}t.exports=e,e.prototype.length=function(){return this.roots.length},e.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},e.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},e.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},5878:function(t,e,r){\"use strict\";t.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function m(t){if(u[t])return 1/0;var r,i,a,o=s[t],c=l[t];return o<0||c<0?1/0:(r=e[t],i=e[o],a=e[c],Math.abs(n(r,i,a))/Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)))}function g(t,e){var r=k[t],n=k[e];k[t]=n,k[e]=r,A[r]=e,A[n]=t}function y(t){return c[k[t]]}function v(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=y(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<M){var o=y(n);o<r&&(a=n,r=o)}if(i<M&&y(i)<r&&(a=i),a===t)return t;g(t,a),t=a}}function _(t){for(var e=y(t);t>0;){var r=v(t);if(!(r>=0&&e<y(r)))return t;g(t,r),t=r}}function b(){if(M>0){var t=k[0];return g(0,M-1),M-=1,x(0),t}return-1}function w(t,e){var r=k[t];return c[r]===e?t:(c[r]=-1/0,_(t),b(),c[r]=e,_((M+=1)-1))}function T(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],m(e)),A[r]>=0&&w(A[r],m(r))}}var k=[],A=new Array(a);for(h=0;h<a;++h)(c[h]=m(h))<1/0?(A[h]=k.length,k.push(h)):A[h]=-1;var M=k.length;for(h=M>>1;h>=0;--h)x(h);for(;;){var S=b();if(S<0||c[S]>r)break;T(S)}var E=[];for(h=0;h<a;++h)u[h]||(A[h]=E.length,E.push(e[h].slice()));function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}E.length;var L=[];return t.forEach((function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&L.push([n,i])}})),i.unique(i.normalize(L)),{positions:E,edges:L}};var n=r(3250),i=r(2014)},1303:function(t,e,r){\"use strict\";t.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=r(3250);function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||(h=n(i,r,o))||o-i}},4209:function(t,e,r){\"use strict\";t.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort((function(t,e){var r=t.x-e.x;return r||(r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1])}));var f=i(o),p=[],d=[],m=[];for(a=0;a<r;){for(var g=n[a].x,y=[];a<r;){var v=n[a];if(v.x!==g)break;a+=1,v.segment[0][0]===v.x&&v.segment[1][0]===v.x?v.create&&(v.segment[0][1]<v.segment[1][1]?(y.push(new u(v.segment[0][1],v.index,!0,!0)),y.push(new u(v.segment[1][1],v.index,!1,!1))):(y.push(new u(v.segment[1][1],v.index,!0,!1)),y.push(new u(v.segment[0][1],v.index,!1,!0)))):f=v.create?f.insert(v.segment,v.index):f.remove(v.segment)}p.push(f.root),d.push(g),m.push(y)}return new s(p,d,m)};var n=r(2478),i=r(3840),a=r(3250),o=r(1303);function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},5202:function(t,e,r){\"use strict\";var n=r(1944),i=r(8210);function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}t.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},t.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},t.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},3387:function(t,e,r){var n;!function(){\"use strict\";var i={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function a(t){return function(t,e){var r,n,o,s,l,c,u,h,f,p=1,d=t.length,m=\"\";for(n=0;n<d;n++)if(\"string\"==typeof t[n])m+=t[n];else if(\"object\"==typeof t[n]){if((s=t[n]).keys)for(r=e[p],o=0;o<s.keys.length;o++){if(null==r)throw new Error(a('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));r=r[s.keys[o]]}else r=s.param_no?e[s.param_no]:e[p++];if(i.not_type.test(s.type)&&i.not_primitive.test(s.type)&&r instanceof Function&&(r=r()),i.numeric_arg.test(s.type)&&\"number\"!=typeof r&&isNaN(r))throw new TypeError(a(\"[sprintf] expecting number but found %T\",r));switch(i.number.test(s.type)&&(h=r>=0),s.type){case\"b\":r=parseInt(r,10).toString(2);break;case\"c\":r=String.fromCharCode(parseInt(r,10));break;case\"d\":case\"i\":r=parseInt(r,10);break;case\"j\":r=JSON.stringify(r,null,s.width?parseInt(s.width):0);break;case\"e\":r=s.precision?parseFloat(r).toExponential(s.precision):parseFloat(r).toExponential();break;case\"f\":r=s.precision?parseFloat(r).toFixed(s.precision):parseFloat(r);break;case\"g\":r=s.precision?String(Number(r.toPrecision(s.precision))):parseFloat(r);break;case\"o\":r=(parseInt(r,10)>>>0).toString(8);break;case\"s\":r=String(r),r=s.precision?r.substring(0,s.precision):r;break;case\"t\":r=String(!!r),r=s.precision?r.substring(0,s.precision):r;break;case\"T\":r=Object.prototype.toString.call(r).slice(8,-1).toLowerCase(),r=s.precision?r.substring(0,s.precision):r;break;case\"u\":r=parseInt(r,10)>>>0;break;case\"v\":r=r.valueOf(),r=s.precision?r.substring(0,s.precision):r;break;case\"x\":r=(parseInt(r,10)>>>0).toString(16);break;case\"X\":r=(parseInt(r,10)>>>0).toString(16).toUpperCase()}i.json.test(s.type)?m+=r:(!i.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",r=r.toString().replace(i.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+r).length,l=s.width&&u>0?c.repeat(u):\"\",m+=s.align?f+r+l:\"0\"===c?f+l+r:l+f+r)}return m}(function(t){if(s[t])return s[t];for(var e,r=t,n=[],a=0;r;){if(null!==(e=i.text.exec(r)))n.push(e[0]);else if(null!==(e=i.modulo.exec(r)))n.push(\"%\");else{if(null===(e=i.placeholder.exec(r)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(e[2]){a|=1;var o=[],l=e[2],c=[];if(null===(c=i.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(o.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=i.key_access.exec(l)))o.push(c[1]);else{if(null===(c=i.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");o.push(c[1])}e[2]=o}else a|=2;if(3===a)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");n.push({placeholder:e[0],param_no:e[1],keys:e[2],sign:e[3],pad_char:e[4],align:e[5],width:e[6],precision:e[7],type:e[8]})}r=r.substring(e[0].length)}return s[t]=n}(t),arguments)}function o(t,e){return a.apply(null,[t].concat(e||[]))}var s=Object.create(null);e.sprintf=a,e.vsprintf=o,\"undefined\"!=typeof window&&(window.sprintf=a,window.vsprintf=o,void 0===(n=function(){return{sprintf:a,vsprintf:o}}.call(e,r,e,t))||(t.exports=n))}()},3711:function(t,e,r){\"use strict\";t.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=i(t,e),n=r.length,a=new Array(n),o=new Array(n),s=0;s<n;++s)a[s]=[r[s]],o[s]=[s];return{positions:a,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r];return e=+e||0,s||(s=o[r]=function(t,e){var r=t.length+\"d\",i=a[r];if(i)return i(n,t,e)}(t.order,t.dtype)),s(t,e)};var n=r(2640),i=r(781),a={\"2d\":function(t,e,r){var n=t({order:e,scalarArguments:3,getters:\"generic\"===r?[0]:void 0,phase:function(t,e,r,n){return t>n|0},vertex:function(t,e,r,n,i,a,o,s,l,c,u,h,f){var p=(o<<0)+(s<<1)+(l<<2)+(c<<3)|0;if(0!==p&&15!==p)switch(p){case 0:case 15:u.push([t-.5,e-.5]);break;case 1:u.push([t-.25-.25*(n+r-2*f)/(r-n),e-.25-.25*(i+r-2*f)/(r-i)]);break;case 2:u.push([t-.75-.25*(-n-r+2*f)/(n-r),e-.25-.25*(a+n-2*f)/(n-a)]);break;case 3:u.push([t-.5,e-.5-.5*(i+r+a+n-4*f)/(r-i+n-a)]);break;case 4:u.push([t-.25-.25*(a+i-2*f)/(i-a),e-.75-.25*(-i-r+2*f)/(i-r)]);break;case 5:u.push([t-.5-.5*(n+r+a+i-4*f)/(r-n+i-a),e-.5]);break;case 6:u.push([t-.5-.25*(-n-r+a+i)/(n-r+i-a),e-.5-.25*(-i-r+a+n)/(i-r+n-a)]);break;case 7:u.push([t-.75-.25*(a+i-2*f)/(i-a),e-.75-.25*(a+n-2*f)/(n-a)]);break;case 8:u.push([t-.75-.25*(-a-i+2*f)/(a-i),e-.75-.25*(-a-n+2*f)/(a-n)]);break;case 9:u.push([t-.5-.25*(n+r+-a-i)/(r-n+a-i),e-.5-.25*(i+r+-a-n)/(r-i+a-n)]);break;case 10:u.push([t-.5-.5*(-n-r-a-i+4*f)/(n-r+a-i),e-.5]);break;case 11:u.push([t-.25-.25*(-a-i+2*f)/(a-i),e-.75-.25*(i+r-2*f)/(r-i)]);break;case 12:u.push([t-.5,e-.5-.5*(-i-r-a-n+4*f)/(i-r+a-n)]);break;case 13:u.push([t-.75-.25*(n+r-2*f)/(r-n),e-.25-.25*(-a-n+2*f)/(a-n)]);break;case 14:u.push([t-.25-.25*(-n-r+2*f)/(n-r),e-.25-.25*(-i-r+2*f)/(i-r)])}},cell:function(t,e,r,n,i,a,o,s,l){i?s.push([t,e]):s.push([e,t])}});return function(t,e){var r=[],i=[];return n(t,r,i,e),{positions:r,cells:i}}}},o={}},529:function(t,e,r){\"use strict\";t.exports=function t(e,r,i){var a=(i=i||{}).fontStyle||\"normal\",s=i.fontWeight||\"normal\",l=i.fontVariant||\"normal\",c=[a,s,l,e].join(\"_\"),u=o[c];u||(u=o[c]={\" \":{data:new Float32Array(0),shape:.2}});var h=u[r];if(!h)if(r.length<=1||!/\\d/.test(r))h=u[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,fontStyle:a,fontWeight:s,fontVariant:l,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var f=r.split(/(\\d|\\s)/),p=new Array(f.length),d=0,m=0,g=0;g<f.length;++g)p[g]=t(e,f[g]),d+=p[g].data.length,m+=p[g].shape,g>0&&(m+=.02);var y=new Float32Array(d),v=0,x=-.5*m;for(g=0;g<p.length;++g){for(var _=p[g].data,b=0;b<_.length;b+=2)y[v++]=_[b]+x,y[v++]=_[b+1];x+=p[g].shape+.02}h=u[r]={data:y,shape:m}}return h};var n=r(4359),a=window||i.global||{},o=a.__TEXT_CACHE||{};a.__TEXT_CACHE={}},665:function(t,e,r){\"use strict\";var n=r(3202);t.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},7261:function(t,e,r){\"use strict\";t.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var m=l(r,d)/i,g=l(n,d)/i;u=Math.acos(m),a=Math.acos(g)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=r(9215),i=r(7608),a=r(6079),o=r(5911),s=r(3536),l=r(244);function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],m=this.computedAngle[1],g=Math.cos(d),y=Math.sin(d),v=Math.cos(m),x=Math.sin(m),_=this.computedCenter,b=g*v,w=y*v,T=x,k=-g*x,A=-y*x,M=v,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=b*r[a]+w*f[a]+T*e[a];E[4*a+1]=k*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],I=E[5],P=E[9],z=E[2],O=E[6],D=E[10],R=I*D-P*O,F=P*z-L*D,B=L*O-I*z,N=c(R,F,B);for(R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B,a=0;a<3;++a)S[a]=_[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];for(a(i,i,n,d),c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),m=(u/=d)*e+a*r,g=(h/=d)*e+o*r,y=(f/=d)*e+s*r;this.center.move(t,m,g,y);var v=Math.exp(this.computedRadius[0]);v=Math.max(1e-4,v+n),this.radius.set(t,Math.log(v))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),m=Math.max(f,p,d);f===m?(s=s<0?-1:1,l=h=0):d===m?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var g=c(s,l,h);s/=g,l/=g,h/=g}var y,v,x=e[o],_=e[o+4],b=e[o+8],w=x*s+_*l+b*h,T=c(x-=s*w,_-=l*w,b-=h*w),k=l*(b/=T)-h*(_/=T),A=h*(x/=T)-s*b,M=s*_-l*x,S=c(k,A,M);if(k/=S,A/=S,M/=S,this.center.jump(t,H,G,Z),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,_,b),2===a){var E=e[1],C=e[5],L=e[9],I=E*x+C*_+L*b,P=E*k+C*A+L*M;y=R<0?-Math.PI/2:Math.PI/2,v=Math.atan2(P,I)}else{var z=e[2],O=e[6],D=e[10],R=z*s+O*l+D*h,F=z*x+O*_+D*b,B=z*k+O*A+D*M;y=Math.asin(u(R)),v=Math.atan2(B,F)}this.angle.jump(t,v,y),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Z=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Z-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,m=d[0],g=d[1],y=d[2],v=i*m+a*g+o*y,x=c(m-=v*i,g-=v*a,y-=v*o);if(!(x<.01&&(x=c(m=a*f-o*h,g=o*l-i*f,y=i*h-a*l))<1e-6)){m/=x,g/=x,y/=x,this.up.set(t,i,a,o),this.right.set(t,m,g,y),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var _=a*y-o*g,b=o*m-i*y,w=i*g-a*m,T=c(_,b,w),k=i*l+a*h+o*f,A=m*l+g*h+y*f,M=(_/=T)*l+(b/=T)*h+(w/=T)*f,S=Math.asin(u(k)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],I=C[C.length-2];L%=2*Math.PI;var P=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),O=Math.abs(L-2*Math.PI-E);P<z&&(L+=2*Math.PI),O<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,I),this.angle.set(t,E,S)}}}}},5250:function(t){\"use strict\";t.exports=function(t,r,n){var i=t*r,a=e*t,o=a-(a-t),s=t-o,l=e*r,c=l-(l-r),u=r-c,h=s*u-(i-o*c-s*c-o*u);return n?(n[0]=h,n[1]=i,n):[h,i]};var e=+(Math.pow(2,27)+1)},9362:function(t){\"use strict\";t.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);return r?(r[0]=o+a,r[1]=n,r):[o+a,n]}},1888:function(t,e,r){\"use strict\";var n=r(8828),i=r(1338),a=r(4793).hp;r.g.__TYPEDARRAY_POOL||(r.g.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),BIGUINT64:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),BIGINT64:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=r.g.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=i([32,0])),c.BIGUINT64||(c.BIGUINT64=i([32,0])),c.BIGINT64||(c.BIGINT64=i([32,0])),c.BUFFER||(c.BUFFER=i([32,0]));var u=c.DATA,h=c.BUFFER;function f(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function m(t){return new Uint16Array(p(2*t),0,t)}function g(t){return new Uint32Array(p(4*t),0,t)}function y(t){return new Int8Array(p(t),0,t)}function v(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function _(t){return new Float32Array(p(4*t),0,t)}function b(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function A(t){return new DataView(p(t),0,t)}function M(t){t=n.nextPow2(t);var e=n.log2(t),r=h[e];return r.length>0?r.pop():new a(t)}e.free=function(t){if(a.isBuffer(t))h[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},e.freeUint8=e.freeUint16=e.freeUint32=e.freeBigUint64=e.freeInt8=e.freeInt16=e.freeInt32=e.freeBigInt64=e.freeFloat32=e.freeFloat=e.freeFloat64=e.freeDouble=e.freeUint8Clamped=e.freeDataView=function(t){f(t.buffer)},e.freeArrayBuffer=f,e.freeBuffer=function(t){h[n.log2(t.length)].push(t)},e.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return m(t);case\"uint32\":return g(t);case\"int8\":return y(t);case\"int16\":return v(t);case\"int32\":return x(t);case\"float\":case\"float32\":return _(t);case\"double\":case\"float64\":return b(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return M(t);case\"data\":case\"dataview\":return A(t);default:return null}return null},e.mallocArrayBuffer=p,e.mallocUint8=d,e.mallocUint16=m,e.mallocUint32=g,e.mallocInt8=y,e.mallocInt16=v,e.mallocInt32=x,e.mallocFloat32=e.mallocFloat=_,e.mallocFloat64=e.mallocDouble=b,e.mallocUint8Clamped=w,e.mallocBigUint64=T,e.mallocBigInt64=k,e.mallocDataView=A,e.mallocBuffer=M,e.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,h[t].length=0}},1755:function(t){\"use strict\";function e(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}t.exports=e;var r=e.prototype;Object.defineProperty(r,\"length\",{get:function(){return this.roots.length}}),r.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},r.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},r.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},1682:function(t){\"use strict\";t.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},4359:function(t,e,r){\"use strict\";t.exports=function(t,e){return\"object\"==typeof e&&null!==e||(e={}),n(t,e.canvas||i,e.context||a,e)};var n=r(7718),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},7718:function(t,e,r){t.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};return n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts)),r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter((function(t){return t})).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(T=0;T<r.length;++T)l[T]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,m,r,l)),!0===o.subscripts&&(l=x(g,v,r,l));var _=[],b=\"\";for(T=0;T<r.length;++T)null!==l[T]&&(b+=r[T],_.push(l[T]));var w,T,k,A,M,S=b.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,I=2*n,P=0,z=E*C+I;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var O=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+k,I+A),k+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(y),a=r.indexOf(y),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,m=h>-1?parseInt(r[1+h]):0;p!==m&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,m-p),n=n.replace(\"?px \",F())),A-=.25*C*(m-p)}if(!0===o.bolds){var g=t.indexOf(u)>-1,v=r.indexOf(u)>-1;!g&&v&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),g&&!v&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,_=r.indexOf(f)>-1;!x&&_&&(n=\"italic \"+n),x&&!_&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(k=0,A=w*C,M=n,D=\"\",T=0;T<N.length;++T){var j=T+O<_.length?_[T+O]:_[_.length-1];s===j?D+=N[T]:(R(),D=N[T],void 0!==j&&(B(s,j),s=j))}R(),O+=N.length;var U=0|Math.round(k+2*L);P<U&&(P=U)}var V=P,q=I+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},t.exports.processPixels=w;var n=r(3711),i=r(9618),a=r(5878),o=r(332),s=r(2538),l=r(2095),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",m=\"+1\",g=\"sub\",y=\"-\",v=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===y,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,m=r.substr(p,u-p).indexOf(i);c=-1!==m?m:u+s}return n}function _(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function b(t,e,r,n){var i=_(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map((function(t){return[p*(t[0]+h),p*(t[1]+f)]}))}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],m=new Array(d.length),g=0;g<d.length;++g){for(var y=d[g],v=new Array(y.length),x=0;x<y.length;++x)v[x]=a[y[x]].slice();u&&v.reverse(),m[g]=v}f[p]=m}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return b(t,e,r,!0)}catch(t){}try{return b(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},1538:function(t){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=g);var e=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(t.exports=WeakMap);e=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,(function(t){return(t%36).toString(36)})).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(y)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(y)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return v(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return v(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return v(t),r(t)}})}();var p=!1,d=0,m=function(){this instanceof m||_();var t=[],e=[],r=d++;return Object.create(m.prototype,{get___:{value:x((function(n,i){var a,o=v(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i}))},has___:{value:x((function(e){var n=v(e);return n?r in n:t.indexOf(e)>=0}))},set___:{value:x((function(n,i){var a,o=v(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this}))},delete___:{value:x((function(n){var i,a,o=v(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))}))}})};m.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof m||_();var t,n=new r,i=void 0,a=!1;return t=e?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new m),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new m),i.set___(t,e)}else n.set(t,e);return this},Object.create(m.prototype,{get___:{value:x((function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)}))},has___:{value:x((function(t){return n.has(t)||!!i&&i.has___(t)}))},set___:{value:x(t)},delete___:{value:x((function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e}))},permitHostObjects___:{value:x((function(t){if(t!==g)throw new Error(\"bogus call to permitHostObjects___\");a=!0}))}})}e&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=m.prototype,t.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),t.exports=m)}function g(t){t.permitHostObjects___&&t.permitHostObjects___(g)}function y(t){return!(t.substr(0,8)==l&&\"___\"===t.substr(t.length-3))}function v(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function _(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},236:function(t,e,r){var n=r(8284);t.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},8284:function(t){t.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},606:function(t,e,r){var n=r(236);t.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},3349:function(t){\"use strict\";t.exports=function(t){var e={};return function(r,n,i){var a=r.dtype,o=r.order,s=[a,o.join()].join(),l=e[s];return l||(e[s]=l=t([a,o])),l(r.shape.slice(0),r.data,r.stride,0|r.offset,n,i)}}(function(){return function(t,e,r,n,i,a){var o=t[0],s=r[0],l=[0],c=s;n|=0;var u=0,h=s;for(u=0;u<o;++u){var f=e[n]-a,p=e[n+c]-a;f>=0!=p>=0&&i.push(l[0]+.5+.5*(f+p)/(f-p)),n+=h,++l[0]}}}.bind(void 0,{funcName:\"zeroCrossings\"}))},781:function(t,e,r){\"use strict\";t.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=r(3349)},7790:function(){}},r={};function a(t){var n=r[t];if(void 0!==n)return n.exports;var i=r[t]={id:t,loaded:!1,exports:{}};return e[t].call(i.exports,i,i.exports,a),i.loaded=!0,i.exports}a.g=function(){if(\"object\"==typeof globalThis)return globalThis;try{return this||new Function(\"return this\")()}catch(t){if(\"object\"==typeof window)return window}}(),a.nmd=function(t){return t.paths=[],t.children||(t.children=[]),t};var o=a(1964);t.exports=o}()},45708:function(t,e,r){\"use strict\";function n(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(t,i(n.key),n)}}function i(t){var e=function(t,e){if(\"object\"!=c(t)||!t)return t;var r=t[Symbol.toPrimitive];if(void 0!==r){var n=r.call(t,\"string\");if(\"object\"!=c(n))return n;throw new TypeError(\"@@toPrimitive must return a primitive value.\")}return String(t)}(t);return\"symbol\"==c(e)?e:e+\"\"}function a(){try{var t=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){})))}catch(t){}return(a=function(){return!!t})()}function o(t){return o=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},o(t)}function s(t){if(void 0===t)throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\");return t}function l(t,e){return l=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(t,e){return t.__proto__=e,t},l(t,e)}function c(t){return c=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},c(t)}var u=r(76226),h=r(27415),f=\"function\"==typeof Symbol&&\"function\"==typeof Symbol.for?Symbol.for(\"nodejs.util.inspect.custom\"):null;e.Buffer=m,e.SlowBuffer=function(t){return+t!=t&&(t=0),m.alloc(+t)},e.INSPECT_MAX_BYTES=50;var p=2147483647;function d(t){if(t>p)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return Object.setPrototypeOf(e,m.prototype),e}function m(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return v(t)}return g(t,e,r)}function g(t,e,r){if(\"string\"==typeof t)return function(t,e){if(\"string\"==typeof e&&\"\"!==e||(e=\"utf8\"),!m.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|w(t,e),n=d(r),i=n.write(t,e);return i!==r&&(n=n.slice(0,i)),n}(t,e);if(ArrayBuffer.isView(t))return function(t){if(rt(t,Uint8Array)){var e=new Uint8Array(t);return _(e.buffer,e.byteOffset,e.byteLength)}return x(t)}(t);if(null==t)throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+c(t));if(rt(t,ArrayBuffer)||t&&rt(t.buffer,ArrayBuffer))return _(t,e,r);if(\"undefined\"!=typeof SharedArrayBuffer&&(rt(t,SharedArrayBuffer)||t&&rt(t.buffer,SharedArrayBuffer)))return _(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return m.from(n,e,r);var i=function(t){if(m.isBuffer(t)){var e=0|b(t.length),r=d(e);return 0===r.length||t.copy(r,0,0,e),r}return void 0!==t.length?\"number\"!=typeof t.length||nt(t.length)?d(0):x(t):\"Buffer\"===t.type&&Array.isArray(t.data)?x(t.data):void 0}(t);if(i)return i;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return m.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+c(t))}function y(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function v(t){return y(t),d(t<0?0:0|b(t))}function x(t){for(var e=t.length<0?0:0|b(t.length),r=d(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function _(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;return n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r),Object.setPrototypeOf(n,m.prototype),n}function b(t){if(t>=p)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+p.toString(16)+\" bytes\");return 0|t}function w(t,e){if(m.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||rt(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+c(t));var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return Q(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return tt(t).length;default:if(i)return n?-1:Q(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function T(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return F(this,e,r);case\"utf8\":case\"utf-8\":return z(this,e,r);case\"ascii\":return D(this,e,r);case\"latin1\":case\"binary\":return R(this,e,r);case\"base64\":return P(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return B(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function k(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function A(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),nt(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=m.from(e,n)),m.isBuffer(e))return 0===e.length?-1:M(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):M(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function M(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function S(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a,o=e.length;for(n>o/2&&(n=o/2),a=0;a<n;++a){var s=parseInt(e.substr(2*a,2),16);if(nt(s))return a;t[r+a]=s}return a}function E(t,e,r,n){return et(Q(e,t.length-r),t,r,n)}function C(t,e,r,n){return et(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function L(t,e,r,n){return et(tt(e),t,r,n)}function I(t,e,r,n){return et(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)n=(r=t.charCodeAt(o))>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function P(t,e,r){return 0===e&&r===t.length?u.fromByteArray(t):u.fromByteArray(t.slice(e,r))}function z(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a=t[i],o=null,s=a>239?4:a>223?3:a>191?2:1;if(i+s<=r){var l=void 0,c=void 0,u=void 0,h=void 0;switch(s){case 1:a<128&&(o=a);break;case 2:128==(192&(l=t[i+1]))&&(h=(31&a)<<6|63&l)>127&&(o=h);break;case 3:l=t[i+1],c=t[i+2],128==(192&l)&&128==(192&c)&&(h=(15&a)<<12|(63&l)<<6|63&c)>2047&&(h<55296||h>57343)&&(o=h);break;case 4:l=t[i+1],c=t[i+2],u=t[i+3],128==(192&l)&&128==(192&c)&&128==(192&u)&&(h=(15&a)<<18|(63&l)<<12|(63&c)<<6|63&u)>65535&&h<1114112&&(o=h)}}null===o?(o=65533,s=1):o>65535&&(o-=65536,n.push(o>>>10&1023|55296),o=56320|1023&o),n.push(o),i+=s}return function(t){var e=t.length;if(e<=O)return String.fromCharCode.apply(String,t);for(var r=\"\",n=0;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=O));return r}(n)}e.kMaxLength=p,m.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1),e={foo:function(){return 42}};return Object.setPrototypeOf(e,Uint8Array.prototype),Object.setPrototypeOf(t,e),42===t.foo()}catch(t){return!1}}(),m.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(m.prototype,\"parent\",{enumerable:!0,get:function(){if(m.isBuffer(this))return this.buffer}}),Object.defineProperty(m.prototype,\"offset\",{enumerable:!0,get:function(){if(m.isBuffer(this))return this.byteOffset}}),m.poolSize=8192,m.from=function(t,e,r){return g(t,e,r)},Object.setPrototypeOf(m.prototype,Uint8Array.prototype),Object.setPrototypeOf(m,Uint8Array),m.alloc=function(t,e,r){return function(t,e,r){return y(t),t<=0?d(t):void 0!==e?\"string\"==typeof r?d(t).fill(e,r):d(t).fill(e):d(t)}(t,e,r)},m.allocUnsafe=function(t){return v(t)},m.allocUnsafeSlow=function(t){return v(t)},m.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==m.prototype},m.compare=function(t,e){if(rt(t,Uint8Array)&&(t=m.from(t,t.offset,t.byteLength)),rt(e,Uint8Array)&&(e=m.from(e,e.offset,e.byteLength)),!m.isBuffer(t)||!m.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},m.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},m.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return m.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=m.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var a=t[r];if(rt(a,Uint8Array))i+a.length>n.length?(m.isBuffer(a)||(a=m.from(a)),a.copy(n,i)):Uint8Array.prototype.set.call(n,a,i);else{if(!m.isBuffer(a))throw new TypeError('\"list\" argument must be an Array of Buffers');a.copy(n,i)}i+=a.length}return n},m.byteLength=w,m.prototype._isBuffer=!0,m.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)k(this,e,e+1);return this},m.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)k(this,e,e+3),k(this,e+1,e+2);return this},m.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)k(this,e,e+7),k(this,e+1,e+6),k(this,e+2,e+5),k(this,e+3,e+4);return this},m.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?z(this,0,t):T.apply(this,arguments)},m.prototype.toLocaleString=m.prototype.toString,m.prototype.equals=function(t){if(!m.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===m.compare(this,t)},m.prototype.inspect=function(){var t=\"\",r=e.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,r).replace(/(.{2})/g,\"$1 \").trim(),this.length>r&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},f&&(m.prototype[f]=m.prototype.inspect),m.prototype.compare=function(t,e,r,n,i){if(rt(t,Uint8Array)&&(t=m.from(t,t.offset,t.byteLength)),!m.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+c(t));if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var a=(i>>>=0)-(n>>>=0),o=(r>>>=0)-(e>>>=0),s=Math.min(a,o),l=this.slice(n,i),u=t.slice(e,r),h=0;h<s;++h)if(l[h]!==u[h]){a=l[h],o=u[h];break}return a<o?-1:o<a?1:0},m.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},m.prototype.indexOf=function(t,e,r){return A(this,t,e,r,!0)},m.prototype.lastIndexOf=function(t,e,r){return A(this,t,e,r,!1)},m.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return S(this,t,e,r);case\"utf8\":case\"utf-8\":return E(this,t,e,r);case\"ascii\":case\"latin1\":case\"binary\":return C(this,t,e,r);case\"base64\":return L(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return I(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},m.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var O=4096;function D(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function R(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function F(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=it[t[a]];return i}function B(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length-1;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function N(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function j(t,e,r,n,i,a){if(!m.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<a)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function U(t,e,r,n,i){X(e,n,i,t,r,7);var a=Number(e&BigInt(4294967295));t[r++]=a,a>>=8,t[r++]=a,a>>=8,t[r++]=a,a>>=8,t[r++]=a;var o=Number(e>>BigInt(32)&BigInt(4294967295));return t[r++]=o,o>>=8,t[r++]=o,o>>=8,t[r++]=o,o>>=8,t[r++]=o,r}function V(t,e,r,n,i){X(e,n,i,t,r,7);var a=Number(e&BigInt(4294967295));t[r+7]=a,a>>=8,t[r+6]=a,a>>=8,t[r+5]=a,a>>=8,t[r+4]=a;var o=Number(e>>BigInt(32)&BigInt(4294967295));return t[r+3]=o,o>>=8,t[r+2]=o,o>>=8,t[r+1]=o,o>>=8,t[r]=o,r+8}function q(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function H(t,e,r,n,i){return e=+e,r>>>=0,i||q(t,0,r,4),h.write(t,e,r,n,23,4),r+4}function G(t,e,r,n,i){return e=+e,r>>>=0,i||q(t,0,r,8),h.write(t,e,r,n,52,8),r+8}m.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return Object.setPrototypeOf(n,m.prototype),n},m.prototype.readUintLE=m.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||N(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},m.prototype.readUintBE=m.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||N(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},m.prototype.readUint8=m.prototype.readUInt8=function(t,e){return t>>>=0,e||N(t,1,this.length),this[t]},m.prototype.readUint16LE=m.prototype.readUInt16LE=function(t,e){return t>>>=0,e||N(t,2,this.length),this[t]|this[t+1]<<8},m.prototype.readUint16BE=m.prototype.readUInt16BE=function(t,e){return t>>>=0,e||N(t,2,this.length),this[t]<<8|this[t+1]},m.prototype.readUint32LE=m.prototype.readUInt32LE=function(t,e){return t>>>=0,e||N(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},m.prototype.readUint32BE=m.prototype.readUInt32BE=function(t,e){return t>>>=0,e||N(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},m.prototype.readBigUInt64LE=at((function(t){$(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||J(t,this.length-8);var n=e+this[++t]*Math.pow(2,8)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,24),i=this[++t]+this[++t]*Math.pow(2,8)+this[++t]*Math.pow(2,16)+r*Math.pow(2,24);return BigInt(n)+(BigInt(i)<<BigInt(32))})),m.prototype.readBigUInt64BE=at((function(t){$(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||J(t,this.length-8);var n=e*Math.pow(2,24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+this[++t],i=this[++t]*Math.pow(2,24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+r;return(BigInt(n)<<BigInt(32))+BigInt(i)})),m.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||N(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},m.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||N(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},m.prototype.readInt8=function(t,e){return t>>>=0,e||N(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},m.prototype.readInt16LE=function(t,e){t>>>=0,e||N(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},m.prototype.readInt16BE=function(t,e){t>>>=0,e||N(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},m.prototype.readInt32LE=function(t,e){return t>>>=0,e||N(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},m.prototype.readInt32BE=function(t,e){return t>>>=0,e||N(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},m.prototype.readBigInt64LE=at((function(t){$(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||J(t,this.length-8);var n=this[t+4]+this[t+5]*Math.pow(2,8)+this[t+6]*Math.pow(2,16)+(r<<24);return(BigInt(n)<<BigInt(32))+BigInt(e+this[++t]*Math.pow(2,8)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,24))})),m.prototype.readBigInt64BE=at((function(t){$(t>>>=0,\"offset\");var e=this[t],r=this[t+7];void 0!==e&&void 0!==r||J(t,this.length-8);var n=(e<<24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+this[++t];return(BigInt(n)<<BigInt(32))+BigInt(this[++t]*Math.pow(2,24)+this[++t]*Math.pow(2,16)+this[++t]*Math.pow(2,8)+r)})),m.prototype.readFloatLE=function(t,e){return t>>>=0,e||N(t,4,this.length),h.read(this,t,!0,23,4)},m.prototype.readFloatBE=function(t,e){return t>>>=0,e||N(t,4,this.length),h.read(this,t,!1,23,4)},m.prototype.readDoubleLE=function(t,e){return t>>>=0,e||N(t,8,this.length),h.read(this,t,!0,52,8)},m.prototype.readDoubleBE=function(t,e){return t>>>=0,e||N(t,8,this.length),h.read(this,t,!1,52,8)},m.prototype.writeUintLE=m.prototype.writeUIntLE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||j(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},m.prototype.writeUintBE=m.prototype.writeUIntBE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||j(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},m.prototype.writeUint8=m.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,1,255,0),this[e]=255&t,e+1},m.prototype.writeUint16LE=m.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},m.prototype.writeUint16BE=m.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},m.prototype.writeUint32LE=m.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},m.prototype.writeUint32BE=m.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},m.prototype.writeBigUInt64LE=at((function(t){return U(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,BigInt(0),BigInt(\"0xffffffffffffffff\"))})),m.prototype.writeBigUInt64BE=at((function(t){return V(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,BigInt(0),BigInt(\"0xffffffffffffffff\"))})),m.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);j(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},m.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);j(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},m.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},m.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},m.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},m.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},m.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||j(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},m.prototype.writeBigInt64LE=at((function(t){return U(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,-BigInt(\"0x8000000000000000\"),BigInt(\"0x7fffffffffffffff\"))})),m.prototype.writeBigInt64BE=at((function(t){return V(this,t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,-BigInt(\"0x8000000000000000\"),BigInt(\"0x7fffffffffffffff\"))})),m.prototype.writeFloatLE=function(t,e,r){return H(this,t,e,!0,r)},m.prototype.writeFloatBE=function(t,e,r){return H(this,t,e,!1,r)},m.prototype.writeDoubleLE=function(t,e,r){return G(this,t,e,!0,r)},m.prototype.writeDoubleBE=function(t,e,r){return G(this,t,e,!1,r)},m.prototype.copy=function(t,e,r,n){if(!m.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;return this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin?this.copyWithin(e,r,n):Uint8Array.prototype.set.call(t,this.subarray(r,n),e),i},m.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!m.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t?t&=255:\"boolean\"==typeof t&&(t=Number(t));if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var a;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(a=e;a<r;++a)this[a]=t;else{var o=m.isBuffer(t)?t:m.from(t,n),s=o.length;if(0===s)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(a=0;a<r-e;++a)this[a+e]=o[a%s]}return this};var Z={};function W(t,e,r){Z[t]=function(r){function i(){var r;return function(t,e){if(!(t instanceof e))throw new TypeError(\"Cannot call a class as a function\")}(this,i),r=function(t,e,r){return e=o(e),function(t,e){if(e&&(\"object\"==c(e)||\"function\"==typeof e))return e;if(void 0!==e)throw new TypeError(\"Derived constructors may only return object or undefined\");return s(t)}(t,a()?Reflect.construct(e,r||[],o(t).constructor):e.apply(t,r))}(this,i),Object.defineProperty(s(r),\"message\",{value:e.apply(s(r),arguments),writable:!0,configurable:!0}),r.name=\"\".concat(r.name,\" [\").concat(t,\"]\"),r.stack,delete r.name,r}var u,h;return function(t,e){if(\"function\"!=typeof e&&null!==e)throw new TypeError(\"Super expression must either be null or a function\");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Object.defineProperty(t,\"prototype\",{writable:!1}),e&&l(t,e)}(i,r),u=i,(h=[{key:\"code\",get:function(){return t},set:function(t){Object.defineProperty(this,\"code\",{configurable:!0,enumerable:!0,value:t,writable:!0})}},{key:\"toString\",value:function(){return\"\".concat(this.name,\" [\").concat(t,\"]: \").concat(this.message)}}])&&n(u.prototype,h),Object.defineProperty(u,\"prototype\",{writable:!1}),i}(r)}function Y(t){for(var e=\"\",r=t.length,n=\"-\"===t[0]?1:0;r>=n+4;r-=3)e=\"_\".concat(t.slice(r-3,r)).concat(e);return\"\".concat(t.slice(0,r)).concat(e)}function X(t,e,r,n,i,a){if(t>r||t<e){var o,s=\"bigint\"==typeof e?\"n\":\"\";throw o=a>3?0===e||e===BigInt(0)?\">= 0\".concat(s,\" and < 2\").concat(s,\" ** \").concat(8*(a+1)).concat(s):\">= -(2\".concat(s,\" ** \").concat(8*(a+1)-1).concat(s,\") and < 2 ** \")+\"\".concat(8*(a+1)-1).concat(s):\">= \".concat(e).concat(s,\" and <= \").concat(r).concat(s),new Z.ERR_OUT_OF_RANGE(\"value\",o,t)}!function(t,e,r){$(e,\"offset\"),void 0!==t[e]&&void 0!==t[e+r]||J(e,t.length-(r+1))}(n,i,a)}function $(t,e){if(\"number\"!=typeof t)throw new Z.ERR_INVALID_ARG_TYPE(e,\"number\",t)}function J(t,e,r){if(Math.floor(t)!==t)throw $(t,r),new Z.ERR_OUT_OF_RANGE(r||\"offset\",\"an integer\",t);if(e<0)throw new Z.ERR_BUFFER_OUT_OF_BOUNDS;throw new Z.ERR_OUT_OF_RANGE(r||\"offset\",\">= \".concat(r?1:0,\" and <= \").concat(e),t)}W(\"ERR_BUFFER_OUT_OF_BOUNDS\",(function(t){return t?\"\".concat(t,\" is outside of buffer bounds\"):\"Attempt to access memory outside buffer bounds\"}),RangeError),W(\"ERR_INVALID_ARG_TYPE\",(function(t,e){return'The \"'.concat(t,'\" argument must be of type number. Received type ').concat(c(e))}),TypeError),W(\"ERR_OUT_OF_RANGE\",(function(t,e,r){var n='The value of \"'.concat(t,'\" is out of range.'),i=r;return Number.isInteger(r)&&Math.abs(r)>Math.pow(2,32)?i=Y(String(r)):\"bigint\"==typeof r&&(i=String(r),(r>Math.pow(BigInt(2),BigInt(32))||r<-Math.pow(BigInt(2),BigInt(32)))&&(i=Y(i)),i+=\"n\"),n+\" It must be \".concat(e,\". Received \").concat(i)}),RangeError);var K=/[^+/0-9A-Za-z-_]/g;function Q(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function tt(t){return u.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(K,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function et(t,e,r,n){var i;for(i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function rt(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function nt(t){return t!=t}var it=function(){for(var t=\"0123456789abcdef\",e=new Array(256),r=0;r<16;++r)for(var n=16*r,i=0;i<16;++i)e[n+i]=t[r]+t[i];return e}();function at(t){return\"undefined\"==typeof BigInt?ot:t}function ot(){throw new Error(\"BigInt not supported\")}},13087:function(t){\"use strict\";t.exports=i,t.exports.isMobile=i,t.exports.default=i;var e=/(android|bb\\d+|meego).+mobile|armv7l|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|samsungbrowser.*mobile|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,r=/CrOS/,n=/android|ipad|playbook|silk/i;function i(t){t||(t={});var i=t.ua;if(i||\"undefined\"==typeof navigator||(i=navigator.userAgent),i&&i.headers&&\"string\"==typeof i.headers[\"user-agent\"]&&(i=i.headers[\"user-agent\"]),\"string\"!=typeof i)return!1;var a=e.test(i)&&!r.test(i)||!!t.tablet&&n.test(i);return!a&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==i.indexOf(\"Macintosh\")&&-1!==i.indexOf(\"Safari\")&&(a=!0),a}},5955:function(t,e,r){\"use strict\";var n=r(22413),i=r.n(n),a=r(51070),o=r.n(a),s=r(62133),l=r.n(s),c=new URL(r(77035),r.b),u=new URL(r(43470),r.b),h=new URL(r(68164),r.b),f=new URL(r(64665),r.b),p=new URL(r(4890),r.b),d=new URL(r(13363),r.b),m=new URL(r(13490),r.b),g=new URL(r(47603),r.b),y=new URL(r(13913),r.b),v=new URL(r(91413),r.b),x=new URL(r(64643),r.b),_=new URL(r(80216),r.b),b=new URL(r(61907),r.b),w=new URL(r(68605),r.b),T=new URL(r(25446),r.b),k=new URL(r(56694),r.b),A=new URL(r(24420),r.b),M=new URL(r(75796),r.b),S=new URL(r(92228),r.b),E=new URL(r(9819),r.b),C=new URL(r(47695),r.b),L=new URL(r(28869),r.b),I=new URL(r(30557),r.b),P=new URL(r(48460),r.b),z=new URL(r(56539),r.b),O=new URL(r(43737),r.b),D=new URL(r(47914),r.b),R=new URL(r(26117),r.b),F=new URL(r(66311),r.b),B=o()(i()),N=l()(c),j=l()(u),U=l()(h),V=l()(f),q=l()(p),H=l()(d),G=l()(m),Z=l()(g),W=l()(y),Y=l()(v),X=l()(x),$=l()(_),J=l()(b),K=l()(w),Q=l()(T),tt=l()(k),et=l()(A),rt=l()(M),nt=l()(S),it=l()(E),at=l()(C),ot=l()(L),st=l()(I),lt=l()(P),ct=l()(z),ut=l()(O),ht=l()(D),ft=l()(R),pt=l()(F);B.push([t.id,\".maplibregl-map{font:12px/20px Helvetica Neue,Arial,Helvetica,sans-serif;overflow:hidden;position:relative;-webkit-tap-highlight-color:rgb(0 0 0/0)}.maplibregl-canvas{left:0;position:absolute;top:0}.maplibregl-map:fullscreen{height:100%;width:100%}.maplibregl-ctrl-group button.maplibregl-ctrl-compass{touch-action:none}.maplibregl-canvas-container.maplibregl-interactive,.maplibregl-ctrl-group button.maplibregl-ctrl-compass{cursor:grab;-webkit-user-select:none;-moz-user-select:none;user-select:none}.maplibregl-canvas-container.maplibregl-interactive.maplibregl-track-pointer{cursor:pointer}.maplibregl-canvas-container.maplibregl-interactive:active,.maplibregl-ctrl-group button.maplibregl-ctrl-compass:active{cursor:grabbing}.maplibregl-canvas-container.maplibregl-touch-zoom-rotate,.maplibregl-canvas-container.maplibregl-touch-zoom-rotate .maplibregl-canvas{touch-action:pan-x pan-y}.maplibregl-canvas-container.maplibregl-touch-drag-pan,.maplibregl-canvas-container.maplibregl-touch-drag-pan .maplibregl-canvas{touch-action:pinch-zoom}.maplibregl-canvas-container.maplibregl-touch-zoom-rotate.maplibregl-touch-drag-pan,.maplibregl-canvas-container.maplibregl-touch-zoom-rotate.maplibregl-touch-drag-pan .maplibregl-canvas{touch-action:none}.maplibregl-canvas-container.maplibregl-touch-drag-pan.maplibregl-cooperative-gestures,.maplibregl-canvas-container.maplibregl-touch-drag-pan.maplibregl-cooperative-gestures .maplibregl-canvas{touch-action:pan-x pan-y}.maplibregl-ctrl-bottom-left,.maplibregl-ctrl-bottom-right,.maplibregl-ctrl-top-left,.maplibregl-ctrl-top-right{pointer-events:none;position:absolute;z-index:2}.maplibregl-ctrl-top-left{left:0;top:0}.maplibregl-ctrl-top-right{right:0;top:0}.maplibregl-ctrl-bottom-left{bottom:0;left:0}.maplibregl-ctrl-bottom-right{bottom:0;right:0}.maplibregl-ctrl{clear:both;pointer-events:auto;transform:translate(0)}.maplibregl-ctrl-top-left .maplibregl-ctrl{float:left;margin:10px 0 0 10px}.maplibregl-ctrl-top-right .maplibregl-ctrl{float:right;margin:10px 10px 0 0}.maplibregl-ctrl-bottom-left .maplibregl-ctrl{float:left;margin:0 0 10px 10px}.maplibregl-ctrl-bottom-right .maplibregl-ctrl{float:right;margin:0 10px 10px 0}.maplibregl-ctrl-group{background:#fff;border-radius:4px}.maplibregl-ctrl-group:not(:empty){box-shadow:0 0 0 2px rgba(0,0,0,.1)}@media (forced-colors:active){.maplibregl-ctrl-group:not(:empty){box-shadow:0 0 0 2px ButtonText}}.maplibregl-ctrl-group button{background-color:transparent;border:0;box-sizing:border-box;cursor:pointer;display:block;height:29px;outline:none;padding:0;width:29px}.maplibregl-ctrl-group button+button{border-top:1px solid #ddd}.maplibregl-ctrl button .maplibregl-ctrl-icon{background-position:50%;background-repeat:no-repeat;display:block;height:100%;width:100%}@media (forced-colors:active){.maplibregl-ctrl-icon{background-color:transparent}.maplibregl-ctrl-group button+button{border-top:1px solid ButtonText}}.maplibregl-ctrl button::-moz-focus-inner{border:0;padding:0}.maplibregl-ctrl-attrib-button:focus,.maplibregl-ctrl-group button:focus{box-shadow:0 0 2px 2px #0096ff}.maplibregl-ctrl button:disabled{cursor:not-allowed}.maplibregl-ctrl button:disabled .maplibregl-ctrl-icon{opacity:.25}.maplibregl-ctrl button:not(:disabled):hover{background-color:rgb(0 0 0/5%)}.maplibregl-ctrl-group button:focus:focus-visible{box-shadow:0 0 2px 2px #0096ff}.maplibregl-ctrl-group button:focus:not(:focus-visible){box-shadow:none}.maplibregl-ctrl-group button:focus:first-child{border-radius:4px 4px 0 0}.maplibregl-ctrl-group button:focus:last-child{border-radius:0 0 4px 4px}.maplibregl-ctrl-group button:focus:only-child{border-radius:inherit}.maplibregl-ctrl button.maplibregl-ctrl-zoom-out .maplibregl-ctrl-icon{background-image:url(\"+N+\")}.maplibregl-ctrl button.maplibregl-ctrl-zoom-in .maplibregl-ctrl-icon{background-image:url(\"+j+\")}@media (forced-colors:active){.maplibregl-ctrl button.maplibregl-ctrl-zoom-out .maplibregl-ctrl-icon{background-image:url(\"+U+\")}.maplibregl-ctrl button.maplibregl-ctrl-zoom-in .maplibregl-ctrl-icon{background-image:url(\"+V+\")}}@media (forced-colors:active) and (prefers-color-scheme:light){.maplibregl-ctrl button.maplibregl-ctrl-zoom-out .maplibregl-ctrl-icon{background-image:url(\"+q+\")}.maplibregl-ctrl button.maplibregl-ctrl-zoom-in .maplibregl-ctrl-icon{background-image:url(\"+H+\")}}.maplibregl-ctrl button.maplibregl-ctrl-fullscreen .maplibregl-ctrl-icon{background-image:url(\"+G+\")}.maplibregl-ctrl button.maplibregl-ctrl-shrink .maplibregl-ctrl-icon{background-image:url(\"+Z+\")}@media (forced-colors:active){.maplibregl-ctrl button.maplibregl-ctrl-fullscreen .maplibregl-ctrl-icon{background-image:url(\"+W+\")}.maplibregl-ctrl button.maplibregl-ctrl-shrink .maplibregl-ctrl-icon{background-image:url(\"+Y+\")}}@media (forced-colors:active) and (prefers-color-scheme:light){.maplibregl-ctrl button.maplibregl-ctrl-fullscreen .maplibregl-ctrl-icon{background-image:url(\"+X+\")}.maplibregl-ctrl button.maplibregl-ctrl-shrink .maplibregl-ctrl-icon{background-image:url(\"+Z+\")}}.maplibregl-ctrl button.maplibregl-ctrl-compass .maplibregl-ctrl-icon{background-image:url(\"+$+\")}@media (forced-colors:active){.maplibregl-ctrl button.maplibregl-ctrl-compass .maplibregl-ctrl-icon{background-image:url(\"+J+\")}}@media (forced-colors:active) and (prefers-color-scheme:light){.maplibregl-ctrl button.maplibregl-ctrl-compass .maplibregl-ctrl-icon{background-image:url(\"+K+\")}}.maplibregl-ctrl button.maplibregl-ctrl-terrain .maplibregl-ctrl-icon{background-image:url(\"+Q+\")}.maplibregl-ctrl button.maplibregl-ctrl-terrain-enabled .maplibregl-ctrl-icon{background-image:url(\"+tt+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate .maplibregl-ctrl-icon{background-image:url(\"+et+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate:disabled .maplibregl-ctrl-icon{background-image:url(\"+rt+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-active .maplibregl-ctrl-icon{background-image:url(\"+nt+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-active-error .maplibregl-ctrl-icon{background-image:url(\"+it+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-background .maplibregl-ctrl-icon{background-image:url(\"+at+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-background-error .maplibregl-ctrl-icon{background-image:url(\"+ot+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-waiting .maplibregl-ctrl-icon{animation:maplibregl-spin 2s linear infinite}@media (forced-colors:active){.maplibregl-ctrl button.maplibregl-ctrl-geolocate .maplibregl-ctrl-icon{background-image:url(\"+st+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate:disabled .maplibregl-ctrl-icon{background-image:url(\"+lt+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-active .maplibregl-ctrl-icon{background-image:url(\"+nt+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-active-error .maplibregl-ctrl-icon{background-image:url(\"+it+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-background .maplibregl-ctrl-icon{background-image:url(\"+at+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate.maplibregl-ctrl-geolocate-background-error .maplibregl-ctrl-icon{background-image:url(\"+ot+\")}}@media (forced-colors:active) and (prefers-color-scheme:light){.maplibregl-ctrl button.maplibregl-ctrl-geolocate .maplibregl-ctrl-icon{background-image:url(\"+ct+\")}.maplibregl-ctrl button.maplibregl-ctrl-geolocate:disabled .maplibregl-ctrl-icon{background-image:url(\"+ut+\")}}@keyframes maplibregl-spin{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}a.maplibregl-ctrl-logo{background-image:url(\"+ht+\");background-repeat:no-repeat;cursor:pointer;display:block;height:23px;margin:0 0 -4px -4px;overflow:hidden;width:88px}a.maplibregl-ctrl-logo.maplibregl-compact{width:14px}@media (forced-colors:active){a.maplibregl-ctrl-logo{background-color:transparent;background-image:url(\"+ht+\")}}@media (forced-colors:active) and (prefers-color-scheme:light){a.maplibregl-ctrl-logo{background-image:url(\"+ht+\")}}.maplibregl-ctrl.maplibregl-ctrl-attrib{background-color:hsla(0,0%,100%,.5);margin:0;padding:0 5px}@media screen{.maplibregl-ctrl-attrib.maplibregl-compact{background-color:#fff;border-radius:12px;box-sizing:content-box;color:#000;margin:10px;min-height:20px;padding:2px 24px 2px 0;position:relative}.maplibregl-ctrl-attrib.maplibregl-compact-show{padding:2px 28px 2px 8px;visibility:visible}.maplibregl-ctrl-bottom-left>.maplibregl-ctrl-attrib.maplibregl-compact-show,.maplibregl-ctrl-top-left>.maplibregl-ctrl-attrib.maplibregl-compact-show{border-radius:12px;padding:2px 8px 2px 28px}.maplibregl-ctrl-attrib.maplibregl-compact .maplibregl-ctrl-attrib-inner{display:none}.maplibregl-ctrl-attrib-button{background-color:hsla(0,0%,100%,.5);background-image:url(\"+ft+\");border:0;border-radius:12px;box-sizing:border-box;cursor:pointer;display:none;height:24px;outline:none;position:absolute;right:0;top:0;width:24px}.maplibregl-ctrl-attrib summary.maplibregl-ctrl-attrib-button{-webkit-appearance:none;-moz-appearance:none;appearance:none;list-style:none}.maplibregl-ctrl-attrib summary.maplibregl-ctrl-attrib-button::-webkit-details-marker{display:none}.maplibregl-ctrl-bottom-left .maplibregl-ctrl-attrib-button,.maplibregl-ctrl-top-left .maplibregl-ctrl-attrib-button{left:0}.maplibregl-ctrl-attrib.maplibregl-compact .maplibregl-ctrl-attrib-button,.maplibregl-ctrl-attrib.maplibregl-compact-show .maplibregl-ctrl-attrib-inner{display:block}.maplibregl-ctrl-attrib.maplibregl-compact-show .maplibregl-ctrl-attrib-button{background-color:rgb(0 0 0/5%)}.maplibregl-ctrl-bottom-right>.maplibregl-ctrl-attrib.maplibregl-compact:after{bottom:0;right:0}.maplibregl-ctrl-top-right>.maplibregl-ctrl-attrib.maplibregl-compact:after{right:0;top:0}.maplibregl-ctrl-top-left>.maplibregl-ctrl-attrib.maplibregl-compact:after{left:0;top:0}.maplibregl-ctrl-bottom-left>.maplibregl-ctrl-attrib.maplibregl-compact:after{bottom:0;left:0}}@media screen and (forced-colors:active){.maplibregl-ctrl-attrib.maplibregl-compact:after{background-image:url(\"+pt+\")}}@media screen and (forced-colors:active) and (prefers-color-scheme:light){.maplibregl-ctrl-attrib.maplibregl-compact:after{background-image:url(\"+ft+')}}.maplibregl-ctrl-attrib a{color:rgba(0,0,0,.75);text-decoration:none}.maplibregl-ctrl-attrib a:hover{color:inherit;text-decoration:underline}.maplibregl-attrib-empty{display:none}.maplibregl-ctrl-scale{background-color:hsla(0,0%,100%,.75);border:2px solid #333;border-top:#333;box-sizing:border-box;color:#333;font-size:10px;padding:0 5px}.maplibregl-popup{display:flex;left:0;pointer-events:none;position:absolute;top:0;will-change:transform}.maplibregl-popup-anchor-top,.maplibregl-popup-anchor-top-left,.maplibregl-popup-anchor-top-right{flex-direction:column}.maplibregl-popup-anchor-bottom,.maplibregl-popup-anchor-bottom-left,.maplibregl-popup-anchor-bottom-right{flex-direction:column-reverse}.maplibregl-popup-anchor-left{flex-direction:row}.maplibregl-popup-anchor-right{flex-direction:row-reverse}.maplibregl-popup-tip{border:10px solid transparent;height:0;width:0;z-index:1}.maplibregl-popup-anchor-top .maplibregl-popup-tip{align-self:center;border-bottom-color:#fff;border-top:none}.maplibregl-popup-anchor-top-left .maplibregl-popup-tip{align-self:flex-start;border-bottom-color:#fff;border-left:none;border-top:none}.maplibregl-popup-anchor-top-right .maplibregl-popup-tip{align-self:flex-end;border-bottom-color:#fff;border-right:none;border-top:none}.maplibregl-popup-anchor-bottom .maplibregl-popup-tip{align-self:center;border-bottom:none;border-top-color:#fff}.maplibregl-popup-anchor-bottom-left .maplibregl-popup-tip{align-self:flex-start;border-bottom:none;border-left:none;border-top-color:#fff}.maplibregl-popup-anchor-bottom-right .maplibregl-popup-tip{align-self:flex-end;border-bottom:none;border-right:none;border-top-color:#fff}.maplibregl-popup-anchor-left .maplibregl-popup-tip{align-self:center;border-left:none;border-right-color:#fff}.maplibregl-popup-anchor-right .maplibregl-popup-tip{align-self:center;border-left-color:#fff;border-right:none}.maplibregl-popup-close-button{background-color:transparent;border:0;border-radius:0 3px 0 0;cursor:pointer;position:absolute;right:0;top:0}.maplibregl-popup-close-button:hover{background-color:rgb(0 0 0/5%)}.maplibregl-popup-content{background:#fff;border-radius:3px;box-shadow:0 1px 2px rgba(0,0,0,.1);padding:15px 10px;pointer-events:auto;position:relative}.maplibregl-popup-anchor-top-left .maplibregl-popup-content{border-top-left-radius:0}.maplibregl-popup-anchor-top-right .maplibregl-popup-content{border-top-right-radius:0}.maplibregl-popup-anchor-bottom-left .maplibregl-popup-content{border-bottom-left-radius:0}.maplibregl-popup-anchor-bottom-right .maplibregl-popup-content{border-bottom-right-radius:0}.maplibregl-popup-track-pointer{display:none}.maplibregl-popup-track-pointer *{pointer-events:none;-webkit-user-select:none;-moz-user-select:none;user-select:none}.maplibregl-map:hover .maplibregl-popup-track-pointer{display:flex}.maplibregl-map:active .maplibregl-popup-track-pointer{display:none}.maplibregl-marker{left:0;position:absolute;top:0;transition:opacity .2s;will-change:transform}.maplibregl-user-location-dot,.maplibregl-user-location-dot:before{background-color:#1da1f2;border-radius:50%;height:15px;width:15px}.maplibregl-user-location-dot:before{animation:maplibregl-user-location-dot-pulse 2s infinite;content:\"\";position:absolute}.maplibregl-user-location-dot:after{border:2px solid #fff;border-radius:50%;box-shadow:0 0 3px rgba(0,0,0,.35);box-sizing:border-box;content:\"\";height:19px;left:-2px;position:absolute;top:-2px;width:19px}@keyframes maplibregl-user-location-dot-pulse{0%{opacity:1;transform:scale(1)}70%{opacity:0;transform:scale(3)}to{opacity:0;transform:scale(1)}}.maplibregl-user-location-dot-stale{background-color:#aaa}.maplibregl-user-location-dot-stale:after{display:none}.maplibregl-user-location-accuracy-circle{background-color:#1da1f233;border-radius:100%;height:1px;width:1px}.maplibregl-crosshair,.maplibregl-crosshair .maplibregl-interactive,.maplibregl-crosshair .maplibregl-interactive:active{cursor:crosshair}.maplibregl-boxzoom{background:#fff;border:2px dotted #202020;height:0;left:0;opacity:.5;position:absolute;top:0;width:0}.maplibregl-cooperative-gesture-screen{align-items:center;background:rgba(0,0,0,.4);color:#fff;display:flex;font-size:1.4em;inset:0;justify-content:center;line-height:1.2;opacity:0;padding:1rem;pointer-events:none;position:absolute;transition:opacity 1s ease 1s;z-index:99999}.maplibregl-cooperative-gesture-screen.maplibregl-show{opacity:1;transition:opacity .05s}.maplibregl-cooperative-gesture-screen .maplibregl-mobile-message{display:none}@media (hover:none),(width <= 480px){.maplibregl-cooperative-gesture-screen .maplibregl-desktop-message{display:none}.maplibregl-cooperative-gesture-screen .maplibregl-mobile-message{display:block}}.maplibregl-pseudo-fullscreen{height:100%!important;left:0!important;position:fixed!important;top:0!important;width:100%!important;z-index:99999}',\"\"]),e.A=B},68735:function(t,e,r){\"use strict\";r.r(e),r.d(e,{sankeyCenter:function(){return f},sankeyCircular:function(){return L},sankeyJustify:function(){return h},sankeyLeft:function(){return c},sankeyRight:function(){return u}});var n=r(29725),i=r(4575),a=r(48544),o=r(96143),s=r.n(o);function l(t){return t.target.depth}function c(t){return t.depth}function u(t,e){return e-1-t.height}function h(t,e){return t.sourceLinks.length?t.depth:e-1}function f(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?(0,n.jk)(t.sourceLinks,l)-1:0}function p(t){return function(){return t}}var d=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function m(t,e){return y(t.source,e.source)||t.index-e.index}function g(t,e){return y(t.target,e.target)||t.index-e.index}function y(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function v(t){return t.value}function x(t){return(t.y0+t.y1)/2}function _(t){return x(t.source)}function b(t){return x(t.target)}function w(t){return t.index}function T(t){return t.nodes}function k(t){return t.links}function A(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function M(t,e){return e(t)}var S=25,E=10,C=.3;function L(){var t,e,r=0,a=0,o=1,l=1,c=24,u=w,f=h,M=T,L=k,P=32,O=2,D=null;function F(){var h={nodes:M.apply(null,arguments),links:L.apply(null,arguments)};!function(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=(0,i.Tj)(t.nodes,u);t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(void 0===n?\"undefined\":d(n))&&(n=t.source=A(e,n)),\"object\"!==(void 0===i?\"undefined\":d(i))&&(i=t.target=A(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)}))}(h),function(t,e,r){var n=0;if(null===r){for(var i=[],a=0;a<t.links.length;a++){var o=t.links[a],l=o.source.index,c=o.target.index;i[l]||(i[l]=[]),i[c]||(i[c]=[]),-1===i[l].indexOf(c)&&i[l].push(c)}var u=s()(i);u.sort((function(t,e){return t.length-e.length}));var h={};for(a=0;a<u.length;a++){var f=u[a].slice(-2);h[f[0]]||(h[f[0]]={}),h[f[0]][f[1]]=!0}t.links.forEach((function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1}))}else t.links.forEach((function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)}))}(h,0,D),function(t){t.nodes.forEach((function(t){t.partOfCycle=!1,t.value=Math.max((0,n.cz)(t.sourceLinks,v),(0,n.cz)(t.targetLinks,v)),t.sourceLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})),t.targetLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}))}))}(h),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.depth=n,t.sourceLinks.forEach((function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)}))}));for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.height=n,t.targetLinks.forEach((function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)}))}));t.nodes.forEach((function(t){t.column=Math.floor(f.call(null,t,n))}))}(h),I(h,u),function(s,u,h){var f=(0,i.$I)().key((function(t){return t.column})).sortKeys(n.V_).entries(s.nodes).map((function(t){return t.values}));(function(i){if(e){var u=1/0;f.forEach((function(t){var r=l*e/(t.length+1);u=r<u?r:u})),t=u}var h=(0,n.jk)(f,(function(e){return(l-a-(e.length-1)*t)/(0,n.cz)(e,v)}));h*=C,s.links.forEach((function(t){t.width=t.value*h}));var p=function(t){var e=0,r=0,i=0,a=0,o=(0,n.T9)(t.nodes,(function(t){return t.column}));return t.links.forEach((function(t){t.circular&&(\"top\"==t.circularLinkType?e+=t.width:r+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))})),{top:e=e>0?e+S+E:e,bottom:r=r>0?r+S+E:r,left:a=a>0?a+S+E:a,right:i=i>0?i+S+E:i}}(s),d=function(t,e){var i=(0,n.T9)(t.nodes,(function(t){return t.column})),s=o-r,u=l-a,h=s/(s+e.right+e.left),f=u/(u+e.top+e.bottom);return r=r*h+e.left,o=0==e.right?o:o*h,a=a*f+e.top,l*=f,t.nodes.forEach((function(t){t.x0=r+t.column*((o-r-c)/i),t.x1=t.x0+c})),f}(s,p);h*=d,s.links.forEach((function(t){t.width=t.value*h})),f.forEach((function(t){var e=t.length;t.forEach((function(t,r){t.depth==f.length-1&&1==e||0==t.depth&&1==e?(t.y0=l/2-t.value*h,t.y1=t.y0+t.value*h):t.partOfCycle?0==z(t,i)?(t.y0=l/2+r,t.y1=t.y0+t.value*h):\"top\"==t.circularLinkType?(t.y0=a+r,t.y1=t.y0+t.value*h):(t.y0=l-t.value*h-r,t.y1=t.y0+t.value*h):0==p.top||0==p.bottom?(t.y0=(l-a)/e*r,t.y1=t.y0+t.value*h):(t.y0=(l-a)/2-e/2+r,t.y1=t.y0+t.value*h)}))}))})(h),g();for(var p=1,d=u;d>0;--d)m(p*=.99,h),g();function m(t,e){var r=f.length;f.forEach((function(i){var a=i.length,o=i[0].depth;i.forEach((function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&z(i,e)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=l/2-s/2,i.y1=l/2+s/2;else if(o==r-1&&1==a)s=i.y1-i.y0,i.y0=l/2-s/2,i.y1=l/2+s/2;else{var c=(0,n.i2)(i.sourceLinks,b),u=(0,n.i2)(i.targetLinks,_),h=((c&&u?(c+u)/2:c||u)-x(i))*t;i.y0+=h,i.y1+=h}}))}))}function g(){f.forEach((function(e){var r,n,i,o=a,s=e.length;for(e.sort(y),i=0;i<s;++i)(n=o-(r=e[i]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+t;if((n=o-t-l)>0)for(o=r.y0-=n,r.y1-=n,i=s-2;i>=0;--i)(n=(r=e[i]).y1+t-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}(h,P,u),B(h);for(var p=0;p<4;p++)Y(h,l,u),X(h,0,u),Z(h,a,l,u),Y(h,l,u),X(h,0,u);return function(t,e,r){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach((function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)})),0==o||0==s){var l=(0,n.jk)(i,(function(t){return t.y0})),c=(r-e)/((0,n.T9)(i,(function(t){return t.y1}))-l);i.forEach((function(t){var e=(t.y1-t.y0)*c;t.y0=(t.y0-l)*c,t.y1=t.y0+e})),a.forEach((function(t){t.y0=(t.y0-l)*c,t.y1=(t.y1-l)*c,t.width=t.width*c}))}}(h,a,l),R(h,O,l,u),h}function B(t){t.nodes.forEach((function(t){t.sourceLinks.sort(g),t.targetLinks.sort(m)})),t.nodes.forEach((function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach((function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)})),t.targetLinks.forEach((function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)}))}))}return F.nodeId=function(t){return arguments.length?(u=\"function\"==typeof t?t:p(t),F):u},F.nodeAlign=function(t){return arguments.length?(f=\"function\"==typeof t?t:p(t),F):f},F.nodeWidth=function(t){return arguments.length?(c=+t,F):c},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(M=\"function\"==typeof t?t:p(t),F):M},F.links=function(t){return arguments.length?(L=\"function\"==typeof t?t:p(t),F):L},F.size=function(t){return arguments.length?(r=a=0,o=+t[0],l=+t[1],F):[o-r,l-a]},F.extent=function(t){return arguments.length?(r=+t[0][0],o=+t[1][0],a=+t[0][1],l=+t[1][1],F):[[r,a],[o,l]]},F.iterations=function(t){return arguments.length?(P=+t,F):P},F.circularLinkGap=function(t){return arguments.length?(O=+t,F):O},F.nodePaddingRatio=function(t){return arguments.length?(e=+t,F):e},F.sortNodes=function(t){return arguments.length?(D=t,F):D},F.update=function(t){return I(t,u),B(t),t.links.forEach((function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<l?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)})),Y(t,l,u,!1),X(t,0,u),R(t,O,l,u),t},F}function I(t,e){var r=0,n=0;t.links.forEach((function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach((function(t){M(t,e)!=M(i.source,e)&&M(t,e)!=M(i.target,e)||(t.circularLinkType=i.circularLinkType)})))})),t.links.forEach((function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),K(t,e)&&(t.circularLinkType=t.source.circularLinkType))}))}function P(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function z(t,e){var r=0;t.sourceLinks.forEach((function(t){r=t.circular&&!K(t,e)?r+1:r}));var n=0;return t.targetLinks.forEach((function(t){n=t.circular&&!K(t,e)?n+1:n})),r+n}function O(t){var e=t.source.sourceLinks,r=0;e.forEach((function(t){r=t.circular?r+1:r}));var n=t.target.targetLinks,i=0;return n.forEach((function(t){i=t.circular?i+1:i})),!(r>1||i>1)}function D(t,e,r){return t.sort(F),t.forEach((function(n,i){var a,o,s=0;if(K(n,r)&&O(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}})),t}function R(t,e,r,i){var o=(0,n.jk)(t.links,(function(t){return t.source.y0}));t.links.forEach((function(t){t.circular&&(t.circularPathData={})})),D(t.links.filter((function(t){return\"top\"==t.circularLinkType})),e,i),D(t.links.filter((function(t){return\"bottom\"==t.circularLinkType})),e,i),t.links.forEach((function(n){if(n.circular){if(n.circularPathData.arcRadius=n.width+E,n.circularPathData.leftNodeBuffer=5,n.circularPathData.rightNodeBuffer=5,n.circularPathData.sourceWidth=n.source.x1-n.source.x0,n.circularPathData.sourceX=n.source.x0+n.circularPathData.sourceWidth,n.circularPathData.targetX=n.target.x0,n.circularPathData.sourceY=n.y0,n.circularPathData.targetY=n.y1,K(n,i)&&O(n))n.circularPathData.leftSmallArcRadius=E+n.width/2,n.circularPathData.leftLargeArcRadius=E+n.width/2,n.circularPathData.rightSmallArcRadius=E+n.width/2,n.circularPathData.rightLargeArcRadius=E+n.width/2,\"bottom\"==n.circularLinkType?(n.circularPathData.verticalFullExtent=n.source.y1+S+n.circularPathData.verticalBuffer,n.circularPathData.verticalLeftInnerExtent=n.circularPathData.verticalFullExtent-n.circularPathData.leftLargeArcRadius,n.circularPathData.verticalRightInnerExtent=n.circularPathData.verticalFullExtent-n.circularPathData.rightLargeArcRadius):(n.circularPathData.verticalFullExtent=n.source.y0-S-n.circularPathData.verticalBuffer,n.circularPathData.verticalLeftInnerExtent=n.circularPathData.verticalFullExtent+n.circularPathData.leftLargeArcRadius,n.circularPathData.verticalRightInnerExtent=n.circularPathData.verticalFullExtent+n.circularPathData.rightLargeArcRadius);else{var s=n.source.column,l=n.circularLinkType,c=t.links.filter((function(t){return t.source.column==s&&t.circularLinkType==l}));\"bottom\"==n.circularLinkType?c.sort(N):c.sort(B);var u=0;c.forEach((function(t,r){t.circularLinkID==n.circularLinkID&&(n.circularPathData.leftSmallArcRadius=E+n.width/2+u,n.circularPathData.leftLargeArcRadius=E+n.width/2+r*e+u),u+=t.width})),s=n.target.column,c=t.links.filter((function(t){return t.target.column==s&&t.circularLinkType==l})),\"bottom\"==n.circularLinkType?c.sort(U):c.sort(j),u=0,c.forEach((function(t,r){t.circularLinkID==n.circularLinkID&&(n.circularPathData.rightSmallArcRadius=E+n.width/2+u,n.circularPathData.rightLargeArcRadius=E+n.width/2+r*e+u),u+=t.width})),\"bottom\"==n.circularLinkType?(n.circularPathData.verticalFullExtent=Math.max(r,n.source.y1,n.target.y1)+S+n.circularPathData.verticalBuffer,n.circularPathData.verticalLeftInnerExtent=n.circularPathData.verticalFullExtent-n.circularPathData.leftLargeArcRadius,n.circularPathData.verticalRightInnerExtent=n.circularPathData.verticalFullExtent-n.circularPathData.rightLargeArcRadius):(n.circularPathData.verticalFullExtent=o-S-n.circularPathData.verticalBuffer,n.circularPathData.verticalLeftInnerExtent=n.circularPathData.verticalFullExtent+n.circularPathData.leftLargeArcRadius,n.circularPathData.verticalRightInnerExtent=n.circularPathData.verticalFullExtent+n.circularPathData.rightLargeArcRadius)}n.circularPathData.leftInnerExtent=n.circularPathData.sourceX+n.circularPathData.leftNodeBuffer,n.circularPathData.rightInnerExtent=n.circularPathData.targetX-n.circularPathData.rightNodeBuffer,n.circularPathData.leftFullExtent=n.circularPathData.sourceX+n.circularPathData.leftLargeArcRadius+n.circularPathData.leftNodeBuffer,n.circularPathData.rightFullExtent=n.circularPathData.targetX-n.circularPathData.rightLargeArcRadius-n.circularPathData.rightNodeBuffer}if(n.circular)n.path=function(t){return\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY}(n);else{var h=(0,a.pq)().source((function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]})).target((function(t){return[t.target.x0,t.y1]}));n.path=h(n)}}))}function F(t,e){return V(t)==V(e)?\"bottom\"==t.circularLinkType?N(t,e):B(t,e):V(e)-V(t)}function B(t,e){return t.y0-e.y0}function N(t,e){return e.y0-t.y0}function j(t,e){return t.y1-e.y1}function U(t,e){return e.y1-t.y1}function V(t){return t.target.column-t.source.column}function q(t){return t.target.x0-t.source.x1}function H(t,e){var r=P(t),n=q(e)/Math.tan(r);return\"up\"==J(t)?t.y1+n:t.y1-n}function G(t,e){var r=P(t),n=q(e)/Math.tan(r);return\"up\"==J(t)?t.y1-n:t.y1+n}function Z(t,e,r,n){t.links.forEach((function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach((function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),m=h*i.y0+f*i.y0+p*i.y1+d*i.y1,g=m-i.width/2,y=m+i.width/2;g>o.y0&&g<o.y1?(c=o.y1-g+10,c=\"bottom\"==o.circularLinkType?c:-c,o=W(o,c,e,r),t.nodes.forEach((function(t){var i,a;M(t,n)!=M(o,n)&&t.column==o.column&&(a=t,(i=o).y0>a.y0&&i.y0<a.y1||i.y1>a.y0&&i.y1<a.y1||i.y0<a.y0&&i.y1>a.y1)&&W(t,c,e,r)}))):(y>o.y0&&y<o.y1||g<o.y0&&y>o.y1)&&(c=y-o.y0+10,o=W(o,c,e,r),t.nodes.forEach((function(t){M(t,n)!=M(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&W(t,c,e,r)})))}}))}}))}function W(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach((function(t){t.y1=t.y1+e})),t.sourceLinks.forEach((function(t){t.y0=t.y0+e}))),t}function Y(t,e,r,n){t.nodes.forEach((function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter((function(t){return M(t.source,r)==M(i,r)})),o=a.length;o>1&&a.sort((function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!$(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=G(e,t);return t.y1-r}if(e.target.column>t.target.column)return G(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0}));var s=i.y0;a.forEach((function(t){t.y0=s+t.width/2,s+=t.width})),a.forEach((function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}}))}))}function X(t,e,r){t.nodes.forEach((function(e){var n=t.links.filter((function(t){return M(t.target,r)==M(e,r)})),i=n.length;i>1&&n.sort((function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!$(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=H(e,t);return t.y0-r}if(t.source.column<e.source.column)return H(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0}));var a=e.y0;n.forEach((function(t){t.y1=a+t.width/2,a+=t.width})),n.forEach((function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}}))}))}function $(t,e){return J(t)==J(e)}function J(t){return t.y0-t.y1>0?\"up\":\"down\"}function K(t,e){return M(t.source,e)==M(t.target,e)}},62369:function(t,e,r){\"use strict\";r.r(e),r.d(e,{sankey:function(){return w},sankeyCenter:function(){return c},sankeyJustify:function(){return l},sankeyLeft:function(){return o},sankeyLinkHorizontal:function(){return M},sankeyRight:function(){return s}});var n=r(29725),i=r(4575);function a(t){return t.target.depth}function o(t){return t.depth}function s(t,e){return e-1-t.height}function l(t,e){return t.sourceLinks.length?t.depth:e-1}function c(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?(0,n.jk)(t.sourceLinks,a)-1:0}function u(t){return function(){return t}}function h(t,e){return p(t.source,e.source)||t.index-e.index}function f(t,e){return p(t.target,e.target)||t.index-e.index}function p(t,e){return t.y0-e.y0}function d(t){return t.value}function m(t){return(t.y0+t.y1)/2}function g(t){return m(t.source)*t.value}function y(t){return m(t.target)*t.value}function v(t){return t.index}function x(t){return t.nodes}function _(t){return t.links}function b(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function w(){var t=0,e=0,r=1,a=1,o=24,s=8,c=v,w=l,T=x,k=_,A=32;function M(){var l={nodes:T.apply(null,arguments),links:k.apply(null,arguments)};return function(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=(0,i.Tj)(t.nodes,c);t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=b(e,n)),\"object\"!=typeof i&&(i=t.target=b(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)}))}(l),function(t){t.nodes.forEach((function(t){t.value=Math.max((0,n.cz)(t.sourceLinks,d),(0,n.cz)(t.targetLinks,d))}))}(l),function(e){var n,i,a;for(n=e.nodes,i=[],a=0;n.length;++a,n=i,i=[])n.forEach((function(t){t.depth=a,t.sourceLinks.forEach((function(t){i.indexOf(t.target)<0&&i.push(t.target)}))}));for(n=e.nodes,i=[],a=0;n.length;++a,n=i,i=[])n.forEach((function(t){t.height=a,t.targetLinks.forEach((function(t){i.indexOf(t.source)<0&&i.push(t.source)}))}));var s=(r-t-o)/(a-1);e.nodes.forEach((function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*s)+o}))}(l),function(t){var r=(0,i.$I)().key((function(t){return t.x0})).sortKeys(n.V_).entries(t.nodes).map((function(t){return t.values}));(function(){var i=(0,n.T9)(r,(function(t){return t.length})),o=.6666666666666666*(a-e)/(i-1);s>o&&(s=o);var l=(0,n.jk)(r,(function(t){return(a-e-(t.length-1)*s)/(0,n.cz)(t,d)}));r.forEach((function(t){t.forEach((function(t,e){t.y1=(t.y0=e)+t.value*l}))})),t.links.forEach((function(t){t.width=t.value*l}))})(),h();for(var o=1,l=A;l>0;--l)u(o*=.99),h(),c(o),h();function c(t){r.forEach((function(e){e.forEach((function(e){if(e.targetLinks.length){var r=((0,n.cz)(e.targetLinks,g)/(0,n.cz)(e.targetLinks,d)-m(e))*t;e.y0+=r,e.y1+=r}}))}))}function u(t){r.slice().reverse().forEach((function(e){e.forEach((function(e){if(e.sourceLinks.length){var r=((0,n.cz)(e.sourceLinks,y)/(0,n.cz)(e.sourceLinks,d)-m(e))*t;e.y0+=r,e.y1+=r}}))}))}function h(){r.forEach((function(t){var r,n,i,o=e,l=t.length;for(t.sort(p),i=0;i<l;++i)(n=o-(r=t[i]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+s;if((n=o-s-a)>0)for(o=r.y0-=n,r.y1-=n,i=l-2;i>=0;--i)(n=(r=t[i]).y1+s-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}(l),S(l),l}function S(t){t.nodes.forEach((function(t){t.sourceLinks.sort(f),t.targetLinks.sort(h)})),t.nodes.forEach((function(t){var e=t.y0,r=e;t.sourceLinks.forEach((function(t){t.y0=e+t.width/2,e+=t.width})),t.targetLinks.forEach((function(t){t.y1=r+t.width/2,r+=t.width}))}))}return M.update=function(t){return S(t),t},M.nodeId=function(t){return arguments.length?(c=\"function\"==typeof t?t:u(t),M):c},M.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:u(t),M):w},M.nodeWidth=function(t){return arguments.length?(o=+t,M):o},M.nodePadding=function(t){return arguments.length?(s=+t,M):s},M.nodes=function(t){return arguments.length?(T=\"function\"==typeof t?t:u(t),M):T},M.links=function(t){return arguments.length?(k=\"function\"==typeof t?t:u(t),M):k},M.size=function(n){return arguments.length?(t=e=0,r=+n[0],a=+n[1],M):[r-t,a-e]},M.extent=function(n){return arguments.length?(t=+n[0][0],r=+n[1][0],e=+n[0][1],a=+n[1][1],M):[[t,e],[r,a]]},M.iterations=function(t){return arguments.length?(A=+t,M):A},M}var T=r(48544);function k(t){return[t.source.x1,t.y0]}function A(t){return[t.target.x0,t.y1]}function M(){return(0,T.pq)().source(k).target(A)}},45568:function(t,e,r){var n,i;(function(){var a={version:\"3.8.2\"},o=[].slice,s=function(t){return o.call(t)},l=self.document;function c(t){return t&&(t.ownerDocument||t.document||t).documentElement}function u(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(l)try{s(l.documentElement.childNodes)[0].nodeType}catch(t){s=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),l)try{l.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var h=this.Element.prototype,f=h.setAttribute,p=h.setAttributeNS,d=this.CSSStyleDeclaration.prototype,m=d.setProperty;h.setAttribute=function(t,e){f.call(this,t,e+\"\")},h.setAttributeNS=function(t,e,r){p.call(this,t,e,r+\"\")},d.setProperty=function(t,e,r){m.call(this,t,e+\"\",r)}}function g(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function y(t){return null===t?NaN:+t}function v(t){return!isNaN(t)}function x(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}a.ascending=g,a.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},a.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},a.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},a.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},a.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)v(r=+t[a])&&(n+=r);else for(;++a<i;)v(r=+e.call(t,t[a],a))&&(n+=r);return n},a.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)v(r=y(t[a]))?n+=r:--o;else for(;++a<i;)v(r=y(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},a.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},a.median=function(t,e){var r,n=[],i=t.length,o=-1;if(1===arguments.length)for(;++o<i;)v(r=y(t[o]))&&n.push(r);else for(;++o<i;)v(r=y(e.call(t,t[o],o)))&&n.push(r);if(n.length)return a.quantile(n.sort(g),.5)},a.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)v(r=y(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)v(r=y(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},a.deviation=function(){var t=a.variance.apply(this,arguments);return t?Math.sqrt(t):t};var _=x(g);function b(t){return t.length}a.bisectLeft=_.left,a.bisect=a.bisectRight=_.right,a.bisector=function(t){return x(1===t.length?function(e,r){return g(t(e),r)}:t)},a.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},a.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},a.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},a.transpose=function(t){if(!(i=t.length))return[];for(var e=-1,r=a.min(t,b),n=new Array(r);++e<r;)for(var i,o=-1,s=n[e]=new Array(i);++o<i;)s[o]=t[o][e];return n},a.zip=function(){return a.transpose(arguments)},a.keys=function(t){var e=[];for(var r in t)e.push(r);return e},a.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},a.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},a.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var w=Math.abs;function T(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function k(){this._=Object.create(null)}a.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){for(var e=1;t*e%1;)e*=10;return e}(w(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},a.map=function(t,e){var r=new k;if(t instanceof k)t.forEach((function(t,e){r.set(t,e)}));else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var A=\"__proto__\",M=\"\\0\";function S(t){return(t+=\"\")===A||t[0]===M?M+t:t}function E(t){return(t+=\"\")[0]===M?t.slice(1):t}function C(t){return S(t)in this._}function L(t){return(t=S(t))in this._&&delete this._[t]}function I(){var t=[];for(var e in this._)t.push(E(e));return t}function P(){var t=0;for(var e in this._)++t;return t}function z(){for(var t in this._)return!1;return!0}function O(){this._=Object.create(null)}function D(t){return t}function R(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function F(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=B.length;r<n;++r){var i=B[r]+e;if(i in t)return i}}T(k,{has:C,get:function(t){return this._[S(t)]},set:function(t,e){return this._[S(t)]=e},remove:L,keys:I,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:E(e),value:this._[e]});return t},size:P,empty:z,forEach:function(t){for(var e in this._)t.call(this,E(e),this._[e])}}),a.nest=function(){var t,e,r={},n=[],i=[];function o(i,a,s){if(s>=n.length)return e?e.call(r,a):t?a.sort(t):a;for(var l,c,u,h,f=-1,p=a.length,d=n[s++],m=new k;++f<p;)(h=m.get(l=d(c=a[f])))?h.push(c):m.set(l,[c]);return i?(c=i(),u=function(t,e){c.set(t,o(i,e,s))}):(c={},u=function(t,e){c[t]=o(i,e,s)}),m.forEach(u),c}function s(t,e){if(e>=n.length)return t;var r=[],a=i[e++];return t.forEach((function(t,n){r.push({key:t,values:s(n,e)})})),a?r.sort((function(t,e){return a(t.key,e.key)})):r}return r.map=function(t,e){return o(e,t,0)},r.entries=function(t){return s(o(a.map,t,0),0)},r.key=function(t){return n.push(t),r},r.sortKeys=function(t){return i[n.length-1]=t,r},r.sortValues=function(e){return t=e,r},r.rollup=function(t){return e=t,r},r},a.set=function(t){var e=new O;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},T(O,{has:C,add:function(t){return this._[S(t+=\"\")]=!0,t},remove:L,values:I,size:P,empty:z,forEach:function(t){for(var e in this._)t.call(this,E(e))}}),a.behavior={},a.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=R(t,e,e[r]);return t};var B=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function N(){}function j(){}function U(t){var e=[],r=new k;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function V(){a.event.preventDefault()}function q(){for(var t,e=a.event;t=e.sourceEvent;)e=t;return e}function H(t){for(var e=new j,r=0,n=arguments.length;++r<n;)e[arguments[r]]=U(e);return e.of=function(r,n){return function(i){try{var o=i.sourceEvent=a.event;i.target=t,a.event=i,e[i.type].apply(r,n)}finally{a.event=o}}},e}a.dispatch=function(){for(var t=new j,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=U(t);return t},j.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},a.event=null,a.requote=function(t){return t.replace(G,\"\\\\$&\")};var G=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,Z={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function W(t){return Z(t,J),t}var Y=function(t,e){return e.querySelector(t)},X=function(t,e){return e.querySelectorAll(t)},$=function(t,e){var r=t.matches||t[F(t,\"matchesSelector\")];return $=function(t,e){return r.call(t,e)},$(t,e)};\"function\"==typeof Sizzle&&(Y=function(t,e){return Sizzle(t,e)[0]||null},X=Sizzle,$=Sizzle.matchesSelector),a.selection=function(){return a.select(l.documentElement)};var J=a.selection.prototype=[];function K(t){return\"function\"==typeof t?t:function(){return Y(t,this)}}function Q(t){return\"function\"==typeof t?t:function(){return X(t,this)}}J.select=function(t){var e,r,n,i,a=[];t=K(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return W(a)},J.selectAll=function(t){var e,r,n=[];t=Q(t);for(var i=-1,a=this.length;++i<a;)for(var o=this[i],l=-1,c=o.length;++l<c;)(r=o[l])&&(n.push(e=s(t.call(r,r.__data__,l,i))),e.parentNode=r);return W(n)};var tt=\"http://www.w3.org/1999/xhtml\",et={svg:\"http://www.w3.org/2000/svg\",xhtml:tt,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function rt(t,e){return t=a.ns.qualify(t),null==e?t.local?function(){this.removeAttributeNS(t.space,t.local)}:function(){this.removeAttribute(t)}:\"function\"==typeof e?t.local?function(){var r=e.apply(this,arguments);null==r?this.removeAttributeNS(t.space,t.local):this.setAttributeNS(t.space,t.local,r)}:function(){var r=e.apply(this,arguments);null==r?this.removeAttribute(t):this.setAttribute(t,r)}:t.local?function(){this.setAttributeNS(t.space,t.local,e)}:function(){this.setAttribute(t,e)}}function nt(t){return t.trim().replace(/\\s+/g,\" \")}function it(t){return new RegExp(\"(?:^|\\\\s+)\"+a.requote(t)+\"(?:\\\\s+|$)\",\"g\")}function at(t){return(t+\"\").trim().split(/^|\\s+/)}function ot(t,e){var r=(t=at(t).map(st)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function st(t){var e=it(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",nt(i+\" \"+t))):r.setAttribute(\"class\",nt(i.replace(e,\" \")))}}function lt(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function ct(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ut(t){return\"function\"==typeof t?t:(t=a.ns.qualify(t)).local?function(){return this.ownerDocument.createElementNS(t.space,t.local)}:function(){var e=this.ownerDocument,r=this.namespaceURI;return r===tt&&e.documentElement.namespaceURI===tt?e.createElement(t):e.createElementNS(r,t)}}function ht(){var t=this.parentNode;t&&t.removeChild(this)}function ft(t){return{__data__:t}}function pt(t){return function(){return $(this,t)}}function dt(t){return arguments.length||(t=g),function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}function mt(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function gt(t){return Z(t,yt),t}a.ns={prefix:et,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),et.hasOwnProperty(r)?{space:et[r],local:t}:t}},J.attr=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node();return(t=a.ns.qualify(t)).local?r.getAttributeNS(t.space,t.local):r.getAttribute(t)}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},J.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=at(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!it(t[i]).test(e))return!1;return!0}for(e in t)this.each(ot(e,t[e]));return this}return this.each(ot(t,e))},J.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(lt(r,t[r],e));return this}if(n<2){var i=this.node();return u(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(lt(t,e,r))},J.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(ct(e,t[e]));return this}return this.each(ct(t,e))},J.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},J.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},J.append=function(t){return t=ut(t),this.select((function(){return this.appendChild(t.apply(this,arguments))}))},J.insert=function(t,e){return t=ut(t),e=K(e),this.select((function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)}))},J.remove=function(){return this.each(ht)},J.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var m,g=new k,y=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(g.has(m=e.call(i,i.__data__,n))?d[n]=i:g.set(m,i),y[n]=m);for(n=-1;++n<u;)(i=g.get(m=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=ft(a),g.set(m,!0);for(n=-1;++n<o;)n in y&&!0!==g.get(y[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=ft(a);for(;n<u;++n)p[n]=ft(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=gt([]),l=W([]),c=W([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},J.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},J.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=pt(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return W(i)},J.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},J.sort=function(t){t=dt.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},J.each=function(t){return mt(this,(function(e,r,n){t.call(e,e.__data__,r,n)}))},J.call=function(t){var e=s(arguments);return t.apply(e[0]=this,e),this},J.empty=function(){return!this.node()},J.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},J.size=function(){var t=0;return mt(this,(function(){++t})),t};var yt=[];function vt(t,e,r){var n=\"__on\"+t,i=t.indexOf(\".\"),o=_t;i>0&&(t=t.slice(0,i));var l=xt.get(t);function c(){var e=this[n];e&&(this.removeEventListener(t,e,e.$),delete this[n])}return l&&(t=l,o=bt),i?e?function(){var i=o(e,s(arguments));c.call(this),this.addEventListener(t,this[n]=i,i.$=r),i._=e}:c:e?N:function(){var e,r=new RegExp(\"^__on([^.]+)\"+a.requote(t)+\"$\");for(var n in this)if(e=n.match(r)){var i=this[n];this.removeEventListener(e[1],i,i.$),delete this[n]}}}a.selection.enter=gt,a.selection.enter.prototype=yt,yt.append=J.append,yt.empty=J.empty,yt.node=J.node,yt.call=J.call,yt.size=J.size,yt.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return W(o)},yt.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),J.insert.call(this,t,e)},a.select=function(t){var e;return\"string\"==typeof t?(e=[Y(t,l)]).parentNode=l.documentElement:(e=[t]).parentNode=c(t),W([e])},a.selectAll=function(t){var e;return\"string\"==typeof t?(e=s(X(t,l))).parentNode=l.documentElement:(e=s(t)).parentNode=null,W([e])},J.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(vt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(vt(t,e,r))};var xt=a.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function _t(t,e){return function(r){var n=a.event;a.event=r,e[0]=this.__data__;try{t.apply(this,e)}finally{a.event=n}}}function bt(t,e){var r=_t(t,e);return function(t){var e=this,n=t.relatedTarget;n&&(n===e||8&n.compareDocumentPosition(e))||r.call(e,t)}}l&&xt.forEach((function(t){\"on\"+t in l&&xt.remove(t)}));var wt,Tt=0;function kt(t){var e=\".dragsuppress-\"+ ++Tt,r=\"click\"+e,n=a.select(u(t)).on(\"touchmove\"+e,V).on(\"dragstart\"+e,V).on(\"selectstart\"+e,V);if(null==wt&&(wt=!(\"onselectstart\"in t)&&F(t.style,\"userSelect\")),wt){var i=c(t).style,o=i[wt];i[wt]=\"none\"}return function(t){if(n.on(e,null),wt&&(i[wt]=o),t){var a=function(){n.on(r,null)};n.on(r,(function(){V(),a()}),!0),setTimeout(a,0)}}}a.mouse=function(t){return Mt(t,q())};var At=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function Mt(t,e){e.changedTouches&&(e=e.changedTouches[0]);var r=t.ownerSVGElement||t;if(r.createSVGPoint){var n=r.createSVGPoint();if(At<0){var i=u(t);if(i.scrollX||i.scrollY){var o=(r=a.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();At=!(o.f||o.e),r.remove()}}return At?(n.x=e.pageX,n.y=e.pageY):(n.x=e.clientX,n.y=e.clientY),[(n=n.matrixTransform(t.getScreenCTM().inverse())).x,n.y]}var s=t.getBoundingClientRect();return[e.clientX-s.left-t.clientLeft,e.clientY-s.top-t.clientTop]}function St(){return a.event.changedTouches[0].identifier}a.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=q().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return Mt(t,n)},a.behavior.drag=function(){var t=H(i,\"drag\",\"dragstart\",\"dragend\"),e=null,r=o(N,a.mouse,u,\"mousemove\",\"mouseup\"),n=o(St,a.touch,D,\"touchmove\",\"touchend\");function i(){this.on(\"mousedown.drag\",r).on(\"touchstart.drag\",n)}function o(r,n,i,o,s){return function(){var l,c=this,u=a.event.target.correspondingElement||a.event.target,h=c.parentNode,f=t.of(c,arguments),p=0,d=r(),m=\".drag\"+(null==d?\"\":\"-\"+d),g=a.select(i(u)).on(o+m,(function(){var t,e,r=n(h,d);r&&(t=r[0]-v[0],e=r[1]-v[1],p|=t|e,v=r,f({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e}))})).on(s+m,(function(){n(h,d)&&(g.on(o+m,null).on(s+m,null),y(p),f({type:\"dragend\"}))})),y=kt(u),v=n(h,d);l=e?[(l=e.apply(c,arguments)).x-v[0],l.y-v[1]]:[0,0],f({type:\"dragstart\"})}}return i.origin=function(t){return arguments.length?(e=t,i):e},a.rebind(i,t,\"on\")},a.touches=function(t,e){return arguments.length<2&&(e=q().touches),e?s(e).map((function(e){var r=Mt(t,e);return r.identifier=e.identifier,r})):[]};var Et=1e-6,Ct=Et*Et,Lt=Math.PI,It=2*Lt,Pt=It-Et,zt=Lt/2,Ot=Lt/180,Dt=180/Lt;function Rt(t){return t>1?zt:t<-1?-zt:Math.asin(t)}function Ft(t){return((t=Math.exp(t))+1/t)/2}var Bt=Math.SQRT2;a.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Ct)n=Math.log(c/o)/Bt,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Bt*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),m=(c*c-o*o-4*f)/(2*c*2*p),g=Math.log(Math.sqrt(d*d+1)-d),y=Math.log(Math.sqrt(m*m+1)-m);n=(y-g)/Bt,r=function(t){var e,r=t*n,s=Ft(g),l=o/(2*p)*(s*(e=Bt*r+g,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(g));return[i+l*u,a+l*h,o*s/Ft(Bt*r+g)]}}return r.duration=1e3*n,r},a.behavior.zoom=function(){var t,e,r,n,i,o,s,c,h,f={x:0,y:0,k:1},p=[960,500],d=Ut,m=250,g=0,y=\"mousedown.zoom\",v=\"mousemove.zoom\",x=\"mouseup.zoom\",_=\"touchstart.zoom\",b=H(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(y,I).on(jt+\".zoom\",z).on(\"dblclick.zoom\",O).on(_,P)}function T(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function k(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(t,r,n,i){t.__chart__={x:f.x,y:f.y,k:f.k},k(Math.pow(2,i)),A(e=r,n),t=a.select(t),m>0&&(t=t.transition().duration(m)),t.call(w.event)}function S(){s&&s.domain(o.range().map((function(t){return(t-f.x)/f.k})).map(o.invert)),h&&h.domain(c.range().map((function(t){return(t-f.y)/f.k})).map(c.invert))}function E(t){g++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--g||(t({type:\"zoomend\"}),e=null)}function I(){var t=this,e=b.of(t,arguments),r=0,n=a.select(u(t)).on(v,(function(){r=1,A(a.mouse(t),i),C(e)})).on(x,(function(){n.on(v,null).on(x,null),o(r),L(e)})),i=T(a.mouse(t)),o=kt(t);$i.call(t),E(e)}function P(){var t,e=this,r=b.of(e,arguments),n={},o=0,s=\".zoom-\"+a.event.changedTouches[0].identifier,l=\"touchmove\"+s,c=\"touchend\"+s,u=[],h=a.select(e),p=kt(e);function d(){var r=a.touches(e);return t=f.k,r.forEach((function(t){t.identifier in n&&(n[t.identifier]=T(t))})),r}function m(){var t=a.event.target;a.select(t).on(l,g).on(c,v),u.push(t);for(var r=a.event.changedTouches,s=0,h=r.length;s<h;++s)n[r[s].identifier]=null;var p=d(),m=Date.now();if(1===p.length){if(m-i<500){var y=p[0];M(e,y,n[y.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),V()}i=m}else if(p.length>1){y=p[0];var x=p[1],_=y[0]-x[0],b=y[1]-x[1];o=_*_+b*b}}function g(){var s,l,c,u,h=a.touches(e);$i.call(e);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=n[c.identifier]){if(l)break;s=c,l=u}if(u){var d=(d=c[0]-s[0])*d+(d=c[1]-s[1])*d,m=o&&Math.sqrt(d/o);s=[(s[0]+c[0])/2,(s[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],k(m*t)}i=null,A(s,l),C(r)}function v(){if(a.event.touches.length){for(var t=a.event.changedTouches,e=0,i=t.length;e<i;++e)delete n[t[e].identifier];for(var o in n)return void d()}a.selectAll(u).on(s,null),h.on(y,I).on(_,P),p(),L(r)}m(),E(r),h.on(y,null).on(_,m)}function z(){var i=b.of(this,arguments);n?clearTimeout(n):($i.call(this),t=T(e=r||a.mouse(this)),E(i)),n=setTimeout((function(){n=null,L(i)}),50),V(),k(Math.pow(2,.002*Nt())*f.k),A(e,t),C(i)}function O(){var t=a.mouse(this),e=Math.log(f.k)/Math.LN2;M(this,t,T(t),a.event.shiftKey?Math.ceil(e)-1:Math.floor(e)+1)}return jt||(jt=\"onwheel\"in l?(Nt=function(){return-a.event.deltaY*(a.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in l?(Nt=function(){return a.event.wheelDelta},\"mousewheel\"):(Nt=function(){return-a.event.detail},\"MozMousePixelScroll\")),w.event=function(t){t.each((function(){var t=b.of(this,arguments),r=f;Qi?a.select(this).transition().each(\"start.zoom\",(function(){f=this.__chart__||{x:0,y:0,k:1},E(t)})).tween(\"zoom:zoom\",(function(){var n=p[0],i=p[1],o=e?e[0]:n/2,s=e?e[1]:i/2,l=a.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,n/f.k],[(o-r.x)/r.k,(s-r.y)/r.k,n/r.k]);return function(e){var r=l(e),i=n/r[2];this.__chart__=f={x:o-r[0]*i,y:s-r[1]*i,k:i},C(t)}})).each(\"interrupt.zoom\",(function(){L(t)})).each(\"end.zoom\",(function(){L(t)})):(this.__chart__=f,E(t),C(t),L(t))}))},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},k(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?Ut:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(r=t&&[+t[0],+t[1]],w):r},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(m=+t,w):m},w.x=function(t){return arguments.length?(s=t,o=t.copy(),f={x:0,y:0,k:1},w):s},w.y=function(t){return arguments.length?(h=t,c=t.copy(),f={x:0,y:0,k:1},w):h},a.rebind(w,b,\"on\")};var Nt,jt,Ut=[0,1/0];function Vt(){}function qt(t,e,r){return this instanceof qt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof qt?new qt(t.h,t.s,t.l):ue(\"\"+t,he,qt):new qt(t,e,r)}a.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},a.hsl=qt;var Ht=qt.prototype=new Vt;function Gt(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)||e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Zt(t,e,r){return this instanceof Zt?(this.h=+t,this.c=+e,void(this.l=+r)):arguments.length<2?t instanceof Zt?new Zt(t.h,t.c,t.l):function(t,e,r){return t>0?new Zt(Math.atan2(r,e)*Dt,Math.sqrt(e*e+r*r),t):new Zt(NaN,NaN,t)}(t instanceof Xt?t.l:(t=fe((t=a.rgb(t)).r,t.g,t.b)).l,t.a,t.b):new Zt(t,e,r)}Ht.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,this.l/t)},Ht.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,t*this.l)},Ht.rgb=function(){return Gt(this.h,this.s,this.l)},a.hcl=Zt;var Wt=Zt.prototype=new Vt;function Yt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ot)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Zt?Yt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Wt.brighter=function(t){return new Zt(this.h,this.c,Math.min(100,this.l+$t*(arguments.length?t:1)))},Wt.darker=function(t){return new Zt(this.h,this.c,Math.max(0,this.l-$t*(arguments.length?t:1)))},Wt.rgb=function(){return Yt(this.h,this.c,this.l).rgb()},a.lab=Xt;var $t=18,Jt=.95047,Kt=1,Qt=1.08883,te=Xt.prototype=new Vt;function ee(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*Qt)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Gt):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}te.brighter=function(t){return new Xt(Math.min(100,this.l+$t*(arguments.length?t:1)),this.a,this.b)},te.darker=function(t){return new Xt(Math.max(0,this.l-$t*(arguments.length?t:1)),this.a,this.b)},te.rgb=function(){return ee(this.l,this.a,this.b)},a.rgb=ae;var le=ae.prototype=new Vt;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=me.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new qt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/Qt)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var me=a.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ge(t){return\"function\"==typeof t?t:function(){return t}}function ye(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ve(e,r,t,n)}}function ve(t,e,r,n){var i={},o=a.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=r.call(i,c)}catch(t){return void o.error.call(i,t)}o.load.call(i,t)}else o.error.call(i,c)}return self.XDomainRequest&&!(\"withCredentials\"in c)&&/^(http(s)?:)?\\/\\//.test(t)&&(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(t){var e=a.event;a.event=t;try{o.progress.call(i,c)}finally{a.event=e}},i.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",i)},i.mimeType=function(t){return arguments.length?(e=null==t?null:t+\"\",i):e},i.responseType=function(t){return arguments.length?(u=t,i):u},i.response=function(t){return r=t,i},[\"get\",\"post\"].forEach((function(t){i[t]=function(){return i.send.apply(i,[t].concat(s(arguments)))}})),i.send=function(r,n,a){if(2===arguments.length&&\"function\"==typeof n&&(a=n,n=null),c.open(r,t,!0),null==e||\"accept\"in l||(l.accept=e+\",*/*\"),c.setRequestHeader)for(var s in l)c.setRequestHeader(s,l[s]);return null!=e&&c.overrideMimeType&&c.overrideMimeType(e),null!=u&&(c.responseType=u),null!=a&&i.on(\"error\",a).on(\"load\",(function(t){a(null,t)})),o.beforesend.call(i,c),c.send(null==n?null:n),i},i.abort=function(){return c.abort(),i},a.rebind(i,o,\"on\"),null==n?i:i.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(n))}me.forEach((function(t,e){me.set(t,oe(e))})),a.functor=ge,a.xhr=ye(D),a.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ve(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,(function(t,n){if(r)return r(t,n-1);var i=function(e){for(var r={},n=t.length,i=0;i<n;++i)r[t[i]]=e[i];return r};r=e?function(t,r){return e(i(t),r)}:i}))},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new O,n=[];return e.forEach((function(t){for(var e in t)r.has(e)||n.push(r.add(e))})),[n.map(l).join(t)].concat(e.map((function(e){return n.map((function(t){return l(e[t])})).join(t)}))).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},a.csv=a.dsv(\",\",\"text/csv\"),a.tsv=a.dsv(\"\\t\",\"text/tab-separated-values\");var xe,_e,be,we,Te=this[F(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function ke(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return _e?_e.n=i:xe=i,_e=i,be||(we=clearTimeout(we),be=1,Te(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),be=0):(be=1,Te(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return _e=t,r}function Ee(t){return t[0]}function Ce(t){return t[1]}function Le(t){for(var e,r,n,i=t.length,a=[0,1],o=2,s=2;s<i;s++){for(;o>1&&(e=t[a[o-2]],r=t[a[o-1]],n=t[s],(r[0]-e[0])*(n[1]-e[1])-(r[1]-e[1])*(n[0]-e[0])<=0);)--o;a[o++]=s}return a.slice(0,o)}function Ie(t,e){return t[0]-e[0]||t[1]-e[1]}a.timer=function(){ke.apply(this,arguments)},a.timer.flush=function(){Me(),Se()},a.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)},a.geom={},a.geom.hull=function(t){var e=Ee,r=Ce;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ge(e),a=ge(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(Ie),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=Le(s),u=Le(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},a.geom.polygon=function(t){return Z(t,Pe),t};var Pe=a.geom.polygon.prototype=[];function ze(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function Oe(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function De(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}Pe.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},Pe.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},Pe.clip=function(t){for(var e,r,n,i,a,o,s=De(t),l=-1,c=this.length-De(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)ze(o=e[r],u,i)?(ze(a,u,i)||t.push(Oe(a,o,u,i)),t.push(o)):ze(a,u,i)&&t.push(Oe(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var Re,Fe,Be,Ne,je,Ue=[],Ve=[];function qe(){sr(this),this.edge=this.site=this.circle=null}function He(t){var e=Ue.pop()||new qe;return e.site=t,e}function Ge(t){tr(t),Be.remove(t),Ue.push(t),sr(t)}function Ze(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];Ge(t);for(var l=a;l.circle&&w(r-l.circle.x)<Et&&w(n-l.circle.cy)<Et;)a=l.P,s.unshift(l),Ge(l),l=a;s.unshift(l),tr(l);for(var c=o;c.circle&&w(r-c.circle.x)<Et&&w(n-c.circle.cy)<Et;)o=c.N,s.push(c),Ge(c),c=o;s.push(c),tr(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],ir(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=nr(l.site,c.site,null,i),Qe(l),Qe(c)}function We(t){for(var e,r,n,i,a=t.x,o=t.y,s=Be._;s;)if((n=Ye(s,o)-a)>Et)s=s.L;else{if(!((i=a-Xe(s,o))>Et)){n>-Et?(e=s.P,r=s):i>-Et?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=He(t);if(Be.insert(e,l),e||r){if(e===r)return tr(e),r=He(e.site),Be.insert(l,r),l.edge=r.edge=nr(e.site,l.site),Qe(e),void Qe(r);if(r){tr(e),tr(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,m=d.x-u,g=d.y-h,y=2*(f*g-p*m),v=f*f+p*p,x=m*m+g*g,_={x:(g*v-p*x)/y+u,y:(f*x-m*v)/y+h};ir(r.edge,c,d,_),l.edge=nr(c,t,null,_),r.edge=nr(t,d,null,_),Qe(e),Qe(r)}else l.edge=nr(e.site,l.site)}}function Ye(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function Xe(t,e){var r=t.N;if(r)return Ye(r,e);var n=t.site;return n.y===e?n.x:1/0}function $e(t){this.site=t,this.edges=[]}function Je(t,e){return e.angle-t.angle}function Ke(){sr(this),this.x=this.y=this.arc=this.site=this.cy=null}function Qe(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(g=a.y-s)-c*u);if(!(h>=-Ct)){var f=l*l+c*c,p=u*u+g*g,d=(g*f-c*p)/h,m=(l*p-u*f)/h,g=m+s,y=Ve.pop()||new Ke;y.arc=t,y.site=i,y.x=d+o,y.y=g+Math.sqrt(d*d+m*m),y.cy=g,t.circle=y;for(var v=null,x=je._;x;)if(y.y<x.y||y.y===x.y&&y.x<=x.x){if(!x.L){v=x.P;break}x=x.L}else{if(!x.R){v=x;break}x=x.R}je.insert(v,y),v||(Ne=y)}}}}function tr(t){var e=t.circle;e&&(e.P||(Ne=e.N),je.remove(e),Ve.push(e),sr(e),t.circle=null)}function er(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,m=h.y,g=(f+d)/2,y=(p+m)/2;if(m===p){if(g<o||g>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:g,y:l};r={x:g,y:c}}else{if(a){if(a.y<l)return}else a={x:g,y:c};r={x:g,y:l}}}else if(i=y-(n=(f-d)/(m-p))*g,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<m){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function rr(t,e){this.l=t,this.r=e,this.a=this.b=null}function nr(t,e,r,n){var i=new rr(t,e);return Re.push(i),r&&ir(i,t,e,r),n&&ir(i,e,t,n),Fe[t.i].edges.push(new ar(i,t,e)),Fe[e.i].edges.push(new ar(i,e,t)),i}function ir(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function ar(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function or(){this._=null}function sr(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function lr(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function cr(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function ur(t){for(;t.L;)t=t.L;return t}function hr(t,e){var r,n,i,a=t.sort(fr).pop();for(Re=[],Fe=new Array(t.length),Be=new or,je=new or;;)if(i=Ne,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(Fe[a.i]=new $e(a),We(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;Ze(i.arc)}e&&(function(t){for(var e,r,n,i,a,o=Re,s=(r=t[0][0],n=t[0][1],i=t[1][0],a=t[1][1],function(t){var e,o=t.a,s=t.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(e=r-l,f||!(e>0)){if(e/=f,f<0){if(e<u)return;e<h&&(h=e)}else if(f>0){if(e>h)return;e>u&&(u=e)}if(e=i-l,f||!(e<0)){if(e/=f,f<0){if(e>h)return;e>u&&(u=e)}else if(f>0){if(e<u)return;e<h&&(h=e)}if(e=n-c,p||!(e>0)){if(e/=p,p<0){if(e<u)return;e<h&&(h=e)}else if(p>0){if(e>h)return;e>u&&(u=e)}if(e=a-c,p||!(e<0)){if(e/=p,p<0){if(e>h)return;e>u&&(u=e)}else if(p>0){if(e<u)return;e<h&&(h=e)}return u>0&&(t.a={x:l+u*f,y:c+u*p}),h<1&&(t.b={x:l+h*f,y:c+h*p}),t}}}}}),l=o.length;l--;)(!er(e=o[l],t)||!s(e)||w(e.a.x-e.b.x)<Et&&w(e.a.y-e.b.y)<Et)&&(e.a=e.b=null,o.splice(l,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],m=Fe,g=m.length;g--;)if((a=m[g])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(w(n-e)>Et||w(i-r)>Et)&&(s.splice(o,0,new ar((y=a.site,v=u,x=w(n-h)<Et&&d-i>Et?{x:h,y:w(e-h)<Et?r:d}:w(i-d)<Et&&f-n>Et?{x:w(r-d)<Et?e:f,y:d}:w(n-f)<Et&&i-p>Et?{x:f,y:w(e-f)<Et?r:p}:w(i-p)<Et&&n-h>Et?{x:w(r-p)<Et?e:h,y:p}:null,_=void 0,(_=new rr(y,null)).a=v,_.b=x,Re.push(_),_),a.site,null)),++l);var y,v,x,_}(e));var o={cells:Fe,edges:Re};return Be=je=Re=Fe=null,o}function fr(t,e){return e.y-t.y||e.x-t.x}$e.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Je),e.length},ar.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},or.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=ur(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(lr(this,r),r=(t=r).U),r.C=!1,n.C=!0,cr(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(cr(this,r),r=(t=r).U),r.C=!1,n.C=!0,lr(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?ur(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,lr(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,cr(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,lr(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,cr(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,lr(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,cr(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},a.geom.voronoi=function(t){var e=Ee,r=Ce,n=e,i=r,a=pr;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return hr(s(t),a).cells.forEach((function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map((function(t){var e=t.start();return[e.x,e.y]})):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]})),e}function s(t){return t.map((function(t,e){return{x:Math.round(n(t,e)/Et)*Et,y:Math.round(i(t,e)/Et)*Et,i:e}}))}return o.links=function(t){return hr(s(t)).edges.filter((function(t){return t.l&&t.r})).map((function(e){return{source:t[e.l.i],target:t[e.r.i]}}))},o.triangles=function(t){var e=[];return hr(s(t)).cells.forEach((function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Je),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])})),e},o.x=function(t){return arguments.length?(n=ge(e=t),o):e},o.y=function(t){return arguments.length?(i=ge(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?pr:t,o):a===pr?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===pr?null:a&&a[1]},o};var pr=[[-1e6,-1e6],[1e6,1e6]];function dr(t){return t.x}function mr(t){return t.y}function gr(t,e,r,n,i,a){if(!t(e,r,n,i,a)){var o=.5*(r+i),s=.5*(n+a),l=e.nodes;l[0]&&gr(t,l[0],r,n,o,s),l[1]&&gr(t,l[1],o,n,i,s),l[2]&&gr(t,l[2],r,s,o,a),l[3]&&gr(t,l[3],o,s,i,a)}}function yr(t,e){t=a.rgb(t),e=a.rgb(e);var r=t.r,n=t.g,i=t.b,o=e.r-r,s=e.g-n,l=e.b-i;return function(t){return\"#\"+ce(Math.round(r+o*t))+ce(Math.round(n+s*t))+ce(Math.round(i+l*t))}}function vr(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Tr(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function xr(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function _r(t,e){var r,n,i,a=br.lastIndex=wr.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=br.exec(t))&&(n=wr.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:xr(r,n)})),a=wr.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}a.geom.delaunay=function(t){return a.geom.voronoi().triangles(t)},a.geom.quadtree=function(t,e,r,n,i){var a,o=Ee,s=Ce;if(a=arguments.length)return o=dr,s=mr,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,m,g,y=ge(o),v=ge(s);if(null!=e)p=e,d=r,m=n,g=i;else if(m=g=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>m&&(m=l.x),l.y>g&&(g=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var x=+y(l=t[h],h),_=+v(l,h);x<p&&(p=x),_<d&&(d=_),x>m&&(m=x),_>g&&(g=_),c.push(x),u.push(_)}var b=m-p,T=g-d;function k(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(w(l-r)+w(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,k(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,i,a,o,s)}b>T?g=d+b:m=p+T;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){k(M,t,+y(t,++h),+v(t,h),p,d,m,g)}};if(M.visit=function(t){gr(t,M,p,d,m,g)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,m=e-c.x,g=r-c.y,y=m*m+g*g;if(y<l){var v=Math.sqrt(l=y);n=e-v,i=r-v,a=e+v,o=r+v,s=d}}for(var x=c.nodes,_=.5*(u+f),b=.5*(h+p),w=(r>=b)<<1|e>=_,T=w+4;w<T;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,_,b);break;case 1:t(c,_,h,f,b);break;case 2:t(c,u,b,_,p);break;case 3:t(c,_,b,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,m,g)},h=-1,null==e){for(;++h<f;)k(M,t[h],c[h],u[h],p,d,m,g);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},a.interpolateRgb=yr,a.interpolateObject=vr,a.interpolateNumber=xr,a.interpolateString=_r;var br=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,wr=new RegExp(br.source,\"g\");function Tr(t,e){for(var r,n=a.interpolators.length;--n>=0&&!(r=a.interpolators[n](t,e)););return r}function kr(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Tr(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}a.interpolate=Tr,a.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?me.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?yr:_r:e instanceof Vt?yr:Array.isArray(e)?kr:\"object\"===r&&isNaN(e)?vr:xr)(t,e)}],a.interpolateArray=kr;var Ar=function(){return D},Mr=a.map({linear:Ar,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return Lr},cubic:function(){return Ir},sin:function(){return zr},exp:function(){return Or},circle:function(){return Dr},elastic:function(t,e){var r;return arguments.length<2&&(e=.45),arguments.length?r=e/It*Math.asin(1/t):(t=1,r=e/4),function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*It/e)}},back:function(t){return t||(t=1.70158),function(e){return e*e*((t+1)*e-t)}},bounce:function(){return Rr}}),Sr=a.map({in:D,out:Er,\"in-out\":Cr,\"out-in\":function(t){return Cr(Er(t))}});function Er(t){return function(e){return 1-t(1-e)}}function Cr(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function Lr(t){return t*t}function Ir(t){return t*t*t}function Pr(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function zr(t){return 1-Math.cos(t*zt)}function Or(t){return Math.pow(2,10*(t-1))}function Dr(t){return 1-Math.sqrt(1-t*t)}function Rr(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function Fr(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function Br(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=jr(i),s=Nr(i,a),l=jr(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Dt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Dt:0}function Nr(t,e){return t[0]*e[0]+t[1]*e[1]}function jr(t){var e=Math.sqrt(Nr(t,t));return e&&(t[0]/=e,t[1]/=e),e}a.ease=function(t){var e,r=t.indexOf(\"-\"),n=r>=0?t.slice(0,r):t,i=r>=0?t.slice(r+1):\"in\";return n=Mr.get(n)||Ar,i=Sr.get(i)||D,e=i(n.apply(null,o.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},a.interpolateHcl=function(t,e){t=a.hcl(t),e=a.hcl(e);var r=t.h,n=t.c,i=t.l,o=e.h-r,s=e.c-n,l=e.l-i;return isNaN(s)&&(s=0,n=isNaN(n)?e.c:n),isNaN(o)?(o=0,r=isNaN(r)?e.h:r):o>180?o-=360:o<-180&&(o+=360),function(t){return Yt(r+o*t,n+s*t,i+l*t)+\"\"}},a.interpolateHsl=function(t,e){t=a.hsl(t),e=a.hsl(e);var r=t.h,n=t.s,i=t.l,o=e.h-r,s=e.s-n,l=e.l-i;return isNaN(s)&&(s=0,n=isNaN(n)?e.s:n),isNaN(o)?(o=0,r=isNaN(r)?e.h:r):o>180?o-=360:o<-180&&(o+=360),function(t){return Gt(r+o*t,n+s*t,i+l*t)+\"\"}},a.interpolateLab=function(t,e){t=a.lab(t),e=a.lab(e);var r=t.l,n=t.a,i=t.b,o=e.l-r,s=e.a-n,l=e.b-i;return function(t){return ee(r+o*t,n+s*t,i+l*t)+\"\"}},a.interpolateRound=Fr,a.transform=function(t){var e=l.createElementNS(a.ns.prefix.svg,\"g\");return(a.transform=function(t){if(null!=t){e.setAttribute(\"transform\",t);var r=e.transform.baseVal.consolidate()}return new Br(r?r.matrix:Ur)})(t)},Br.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var Ur={a:1,b:0,c:0,d:1,e:0,f:0};function Vr(t){return t.length?t.pop()+\",\":\"\"}function qr(t,e){var r=[],n=[];return t=a.transform(t),e=a.transform(e),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:xr(t[0],e[0])},{i:i-2,x:xr(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(t.translate,e.translate,r,n),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(Vr(r)+\"rotate(\",null,\")\")-2,x:xr(t,e)})):e&&r.push(Vr(r)+\"rotate(\"+e+\")\")}(t.rotate,e.rotate,r,n),function(t,e,r,n){t!==e?n.push({i:r.push(Vr(r)+\"skewX(\",null,\")\")-2,x:xr(t,e)}):e&&r.push(Vr(r)+\"skewX(\"+e+\")\")}(t.skew,e.skew,r,n),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(Vr(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:xr(t[0],e[0])},{i:i-2,x:xr(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(Vr(r)+\"scale(\"+e+\")\")}(t.scale,e.scale,r,n),t=e=null,function(t){for(var e,i=-1,a=n.length;++i<a;)r[(e=n[i]).i]=e.x(t);return r.join(\"\")}}function Hr(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function Gr(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function Zr(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;for(var r=Wr(t),n=Wr(e),i=r.pop(),a=n.pop(),o=null;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function Wr(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function Yr(t){t.fixed|=2}function Xr(t){t.fixed&=-7}function $r(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Jr(t){t.fixed&=-5}function Kr(t,e,r){var n=0,i=0;if(t.charge=0,!t.leaf)for(var a,o=t.nodes,s=o.length,l=-1;++l<s;)null!=(a=o[l])&&(Kr(a,e,r),t.charge+=a.charge,n+=a.charge*a.cx,i+=a.charge*a.cy);if(t.point){t.leaf||(t.point.x+=Math.random()-.5,t.point.y+=Math.random()-.5);var c=e*r[t.point.index];t.charge+=t.pointCharge=c,n+=c*t.point.x,i+=c*t.point.y}t.cx=n/t.charge,t.cy=i/t.charge}a.interpolateTransform=qr,a.layout={},a.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(Zr(t[r]));return e}},a.layout.chord=function(){var t,e,r,n,i,o,s,l={},c=0;function u(){var l,u,f,p,d,m={},g=[],y=a.range(n),v=[];for(t=[],e=[],l=0,p=-1;++p<n;){for(u=0,d=-1;++d<n;)u+=r[p][d];g.push(u),v.push(a.range(n)),l+=u}for(i&&y.sort((function(t,e){return i(g[t],g[e])})),o&&v.forEach((function(t,e){t.sort((function(t,n){return o(r[e][t],r[e][n])}))})),l=(It-c*n)/l,u=0,p=-1;++p<n;){for(f=u,d=-1;++d<n;){var x=y[p],_=v[x][d],b=r[x][_],w=u,T=u+=b*l;m[x+\"-\"+_]={index:x,subindex:_,startAngle:w,endAngle:T,value:b}}e[x]={index:x,startAngle:f,endAngle:u,value:g[x]},u+=c}for(p=-1;++p<n;)for(d=p-1;++d<n;){var k=m[p+\"-\"+d],A=m[d+\"-\"+p];(k.value||A.value)&&t.push(k.value<A.value?{source:A,target:k}:{source:k,target:A})}s&&h()}function h(){t.sort((function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)}))}return l.matrix=function(i){return arguments.length?(n=(r=i)&&r.length,t=e=null,l):r},l.padding=function(r){return arguments.length?(c=r,t=e=null,l):c},l.sortGroups=function(r){return arguments.length?(i=r,t=e=null,l):i},l.sortSubgroups=function(e){return arguments.length?(o=e,t=null,l):o},l.sortChords=function(e){return arguments.length?(s=e,t&&h(),l):s},l.chords=function(){return t||u(),t},l.groups=function(){return e||u(),e},l},a.layout.force=function(){var t,e,r,n,i,o,s={},l=a.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Qr,f=tn,p=-30,d=en,m=.1,g=.64,y=[],v=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/g<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}e.point&&l&&l<d&&(c=e.pointCharge/l,t.px-=a*c,t.py-=o*c)}return!e.charge}}function _(t){t.px=a.event.x,t.py=a.event.y,s.resume()}return s.tick=function(){if((r*=.99)<.005)return t=null,l.end({type:\"end\",alpha:r=0}),!0;var e,s,h,f,d,g,_,b,w,T=y.length,k=v.length;for(s=0;s<k;++s)f=(h=v[s]).source,(g=(b=(d=h.target).x-f.x)*b+(w=d.y-f.y)*w)&&(b*=g=r*i[s]*((g=Math.sqrt(g))-n[s])/g,w*=g,d.x-=b*(_=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*_,f.x+=b*(_=1-_),f.y+=w*_);if((_=r*m)&&(b=c[0]/2,w=c[1]/2,s=-1,_))for(;++s<T;)(h=y[s]).x+=(b-h.x)*_,h.y+=(w-h.y)*_;if(p)for(Kr(e=a.geom.quadtree(y),r,o),s=-1;++s<T;)(h=y[s]).fixed||e.visit(x(h));for(s=-1;++s<T;)(h=y[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:r})},s.nodes=function(t){return arguments.length?(y=t,s):y},s.links=function(t){return arguments.length?(v=t,s):v},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(m=+t,s):m},s.theta=function(t){return arguments.length?(g=t*t,s):Math.sqrt(g)},s.alpha=function(e){return arguments.length?(e=+e,r?e>0?r=e:(t.c=null,t.t=NaN,t=null,l.end({type:\"end\",alpha:r=0})):e>0&&(l.start({type:\"start\",alpha:r=e}),t=ke(s.tick)),s):r},s.start=function(){var t,e,r,a=y.length,l=v.length,u=c[0],d=c[1];for(t=0;t<a;++t)(r=y[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=v[t]).source&&(r.source=y[r.source]),\"number\"==typeof r.target&&(r.target=y[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<a;++t)r=y[t],isNaN(r.x)&&(r.x=m(\"x\",u)),isNaN(r.y)&&(r.y=m(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(n=[],\"function\"==typeof h)for(t=0;t<l;++t)n[t]=+h.call(this,v[t],t);else for(t=0;t<l;++t)n[t]=h;if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,v[t],t);else for(t=0;t<l;++t)i[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<a;++t)o[t]=+p.call(this,y[t],t);else for(t=0;t<a;++t)o[t]=p;function m(r,n){if(!e){for(e=new Array(a),c=0;c<a;++c)e[c]=[];for(c=0;c<l;++c){var i=v[c];e[i.source.index].push(i.target),e[i.target.index].push(i.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*n}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(e||(e=a.behavior.drag().origin(D).on(\"dragstart.force\",Yr).on(\"drag.force\",_).on(\"dragend.force\",Xr)),!arguments.length)return e;this.on(\"mouseover.force\",$r).on(\"mouseout.force\",Jr).call(e)},a.rebind(s,l,\"on\")};var Qr=20,tn=1,en=1/0;function rn(t,e){return a.rebind(t,e,\"sort\",\"children\",\"value\"),t.nodes=t,t.links=cn,t}function nn(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function an(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function on(t){return t.children}function sn(t){return t.value}function ln(t,e){return e.value-t.value}function cn(t){return a.merge(t.map((function(t){return(t.children||[]).map((function(e){return{source:t,target:e}}))})))}a.layout.hierarchy=function(){var t=ln,e=on,r=sn;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return an(i,(function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)})),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(nn(t,(function(t){t.children&&(t.value=0)})),an(t,(function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)}))),t},n},a.layout.partition=function(){var t=a.layout.hierarchy(),e=[1,1];function r(t,e,n,i){var a=t.children;if(t.x=e,t.y=t.depth*i,t.dx=n,t.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=t.value?n/t.value:0;++c<o;)r(s=a[c],e,l=s.value*n,i),e+=l}}function n(t){var e=t.children,r=0;if(e&&(i=e.length))for(var i,a=-1;++a<i;)r=Math.max(r,n(e[a]));return 1+r}function i(i,a){var o=t.call(this,i,a);return r(o[0],0,e[0],e[1]/n(o[0])),o}return i.size=function(t){return arguments.length?(e=t,i):e},rn(i,t)},a.layout.pie=function(){var t=Number,e=un,r=0,n=It,i=0;function o(s){var l,c=s.length,u=s.map((function(e,r){return+t.call(o,e,r)})),h=+(\"function\"==typeof r?r.apply(this,arguments):r),f=(\"function\"==typeof n?n.apply(this,arguments):n)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof i?i.apply(this,arguments):i)),d=p*(f<0?-1:1),m=a.sum(u),g=m?(f-c*d)/m:0,y=a.range(c),v=[];return null!=e&&y.sort(e===un?function(t,e){return u[e]-u[t]}:function(t,r){return e(s[t],s[r])}),y.forEach((function(t){v[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*g+d,padAngle:p}})),v}return o.value=function(e){return arguments.length?(t=e,o):t},o.sort=function(t){return arguments.length?(e=t,o):e},o.startAngle=function(t){return arguments.length?(r=t,o):r},o.endAngle=function(t){return arguments.length?(n=t,o):n},o.padAngle=function(t){return arguments.length?(i=t,o):i},o};var un={};function hn(t){return t.x}function fn(t){return t.y}function pn(t,e,r){t.y0=e,t.y=r}a.layout.stack=function(){var t=D,e=gn,r=yn,n=pn,i=hn,o=fn;function s(l,c){if(!(p=l.length))return l;var u=l.map((function(e,r){return t.call(s,e,r)})),h=u.map((function(t){return t.map((function(t,e){return[i.call(s,t,e),o.call(s,t,e)]}))})),f=e.call(s,h,c);u=a.permute(u,f),h=a.permute(h,f);var p,d,m,g,y=r.call(s,h,c),v=u[0].length;for(m=0;m<v;++m)for(n.call(s,u[0][m],g=y[m],h[0][m][1]),d=1;d<p;++d)n.call(s,u[d][m],g+=h[d-1][m][1],h[d][m][1]);return l}return s.values=function(e){return arguments.length?(t=e,s):t},s.order=function(t){return arguments.length?(e=\"function\"==typeof t?t:dn.get(t)||gn,s):e},s.offset=function(t){return arguments.length?(r=\"function\"==typeof t?t:mn.get(t)||yn,s):r},s.x=function(t){return arguments.length?(i=t,s):i},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(n=t,s):n},s};var dn=a.map({\"inside-out\":function(t){var e,r,n=t.length,i=t.map(vn),o=t.map(xn),s=a.range(n).sort((function(t,e){return i[t]-i[e]})),l=0,c=0,u=[],h=[];for(e=0;e<n;++e)r=s[e],l<c?(l+=o[r],u.push(r)):(c+=o[r],h.push(r));return h.reverse().concat(u)},reverse:function(t){return a.range(t.length).reverse()},default:gn}),mn=a.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:yn});function gn(t){return a.range(t.length)}function yn(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function vn(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function xn(t){return t.reduce(_n,0)}function _n(t,e){return t+e[1]}function bn(t,e){return wn(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function wn(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Tn(t){return[a.min(t),a.max(t)]}function kn(t,e){return t.value-e.value}function An(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Mn(t,e){t._pack_next=e,e._pack_prev=t}function Sn(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function En(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Cn),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(Pn(r,n,i=e[2]),x(i),An(r,i),r._pack_prev=i,An(i,n),n=r._pack_next,a=3;a<l;a++){Pn(r,n,i=e[a]);var p=0,d=1,m=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Sn(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Sn(s,i);s=s._pack_prev,m++);p?(d<m||d==m&&n.r<r.r?Mn(r,n=o):Mn(r=s,n),a--):(An(r,i),n=i,x(i))}var g=(c+u)/2,y=(h+f)/2,v=0;for(a=0;a<l;a++)(i=e[a]).x-=g,i.y-=y,v=Math.max(v,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=v,e.forEach(Ln)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Cn(t){t._pack_next=t._pack_prev=t}function Ln(t){delete t._pack_next,delete t._pack_prev}function In(t,e,r,n){var i=t.children;if(t.x=e+=n*t.x,t.y=r+=n*t.y,t.r*=n,i)for(var a=-1,o=i.length;++a<o;)In(i[a],e,r,n)}function Pn(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function zn(t,e){return t.parent==e.parent?1:2}function On(t){var e=t.children;return e.length?e[0]:t.t}function Dn(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function Rn(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function Fn(t,e,r){return t.a.parent===e.parent?t.a:r}function Bn(t){var e=t.children;return e&&e.length?Bn(e[0]):t}function Nn(t){var e,r=t.children;return r&&(e=r.length)?Nn(r[e-1]):t}function jn(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function Un(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function Vn(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function qn(t){return t.rangeExtent?t.rangeExtent():Vn(t.range())}function Hn(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function Gn(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function Zn(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:Wn}a.layout.histogram=function(){var t=!0,e=Number,r=Tn,n=bn;function i(i,o){for(var s,l,c=[],u=i.map(e,this),h=r.call(this,u,o),f=n.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,m=t?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[a.bisect(f,l,1,d)-1]).y+=m,s.push(i[o]));return c}return i.value=function(t){return arguments.length?(e=t,i):e},i.range=function(t){return arguments.length?(r=ge(t),i):r},i.bins=function(t){return arguments.length?(n=\"number\"==typeof t?function(e){return wn(e,t)}:ge(t),i):n},i.frequency=function(e){return arguments.length?(t=!!e,i):t},i},a.layout.pack=function(){var t,e=a.layout.hierarchy().sort(kn),r=0,n=[1,1];function i(i,a){var o=e.call(this,i,a),s=o[0],l=n[0],c=n[1],u=null==t?Math.sqrt:\"function\"==typeof t?t:function(){return t};if(s.x=s.y=0,an(s,(function(t){t.r=+u(t.value)})),an(s,En),r){var h=r*(t?1:Math.max(2*s.r/l,2*s.r/c))/2;an(s,(function(t){t.r+=h})),an(s,En),an(s,(function(t){t.r-=h}))}return In(s,l/2,c/2,t?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return i.size=function(t){return arguments.length?(n=t,i):n},i.radius=function(e){return arguments.length?(t=null==e||\"function\"==typeof e?e:+e,i):t},i.padding=function(t){return arguments.length?(r=+t,i):r},rn(i,e)},a.layout.tree=function(){var t=a.layout.hierarchy().sort(null).value(null),e=zn,r=[1,1],n=null;function i(i,a){var c=t.call(this,i,a),u=c[0],h=function(t){for(var e,r={A:null,children:[t]},n=[r];null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(an(h,o),h.parent.m=-h.z,nn(h,s),n)nn(u,l);else{var f=u,p=u,d=u;nn(u,(function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)}));var m=e(f,p)/2-f.x,g=r[0]/(p.x+e(p,f)/2+m),y=r[1]/(d.depth||1);nn(u,(function(t){t.x=(t.x+m)*g,t.y=t.depth*y}))}return c}function o(t){var r=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(r.length){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(r[0].z+r[r.length-1].z)/2;i?(t.z=i.z+e(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+e(t._,i._));t.parent.A=function(t,r,n){if(r){for(var i,a=t,o=t,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=Dn(s),a=On(a),s&&a;)l=On(l),(o=Dn(o)).a=t,(i=s.z+h-a.z-c+e(s._,a._))>0&&(Rn(Fn(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!Dn(o)&&(o.t=s,o.m+=h-u),a&&!On(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=r[0],t.y=t.depth*r[1]}return i.separation=function(t){return arguments.length?(e=t,i):e},i.size=function(t){return arguments.length?(n=null==(r=t)?l:null,i):n?null:r},i.nodeSize=function(t){return arguments.length?(n=null==(r=t)?null:l,i):n?r:null},rn(i,t)},a.layout.cluster=function(){var t=a.layout.hierarchy().sort(null).value(null),e=zn,r=[1,1],n=!1;function i(i,o){var s,l=t.call(this,i,o),c=l[0],u=0;an(c,(function(t){var r=t.children;r&&r.length?(t.x=function(t){return t.reduce((function(t,e){return t+e.x}),0)/t.length}(r),t.y=function(t){return 1+a.max(t,(function(t){return t.y}))}(r)):(t.x=s?u+=e(t,s):0,t.y=0,s=t)}));var h=Bn(c),f=Nn(c),p=h.x-e(h,f)/2,d=f.x+e(f,h)/2;return an(c,n?function(t){t.x=(t.x-c.x)*r[0],t.y=(c.y-t.y)*r[1]}:function(t){t.x=(t.x-p)/(d-p)*r[0],t.y=(1-(c.y?t.y/c.y:1))*r[1]}),l}return i.separation=function(t){return arguments.length?(e=t,i):e},i.size=function(t){return arguments.length?(n=null==(r=t),i):n?null:r},i.nodeSize=function(t){return arguments.length?(n=null!=(r=t),i):n?r:null},rn(i,t)},a.layout.treemap=function(){var t,e=a.layout.hierarchy(),r=Math.round,n=[1,1],i=null,o=jn,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,m=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,m))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,m,a,!1),m=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,m,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,n,i){var a,o=-1,s=t.length,l=n.x,c=n.y,u=e?r(t.area/e):0;if(e==n.dx){for((i||u>n.dy)&&(u=n.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(n.x+n.dx-l,u?r(a.area/u):0);a.z=!0,a.dx+=n.x+n.dx-l,n.y+=u,n.dy-=u}else{for((i||u>n.dx)&&(u=n.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(n.y+n.dy-c,u?r(a.area/u):0);a.z=!1,a.dy+=n.y+n.dy-c,n.x+=u,n.dx-=u}}function m(r){var i=t||e(r),a=i[0];return a.x=a.y=0,a.value?(a.dx=n[0],a.dy=n[1]):a.dx=a.dy=0,t&&e.revalue(a),u([a],a.dx*a.dy/a.value),(t?f:h)(a),s&&(t=i),i}return m.size=function(t){return arguments.length?(n=t,m):n},m.padding=function(t){if(!arguments.length)return i;function e(e){return Un(e,t)}var r;return o=null==(i=t)?jn:\"function\"==(r=typeof t)?function(e){var r=t.call(m,e,e.depth);return null==r?jn(e):Un(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,m},m.round=function(t){return arguments.length?(r=t?Math.round:Number,m):r!=Number},m.sticky=function(e){return arguments.length?(s=e,t=null,m):s},m.ratio=function(t){return arguments.length?(c=t,m):c},m.mode=function(t){return arguments.length?(l=t+\"\",m):l},rn(m,e)},a.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var t=a.random.normal.apply(a,arguments);return function(){return Math.exp(t())}},bates:function(t){var e=a.random.irwinHall(t);return function(){return e()/t}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},a.scale={};var Wn={floor:D,ceil:D};function Yn(t,e,r,n){var i=[],o=[],s=0,l=Math.min(t.length,e.length)-1;for(t[l]<t[0]&&(t=t.slice().reverse(),e=e.slice().reverse());++s<=l;)i.push(r(t[s-1],t[s])),o.push(n(e[s-1],e[s]));return function(e){var r=a.bisect(t,e,1,l)-1;return o[r](i[r](e))}}function Xn(t,e,r,n){var i,a;function o(){var o=Math.min(t.length,e.length)>2?Yn:Hn,l=n?Gr:Hr;return i=o(t,e,l,r),a=o(e,t,l,Tr),s}function s(t){return i(t)}return s.invert=function(t){return a(t)},s.domain=function(e){return arguments.length?(t=e.map(Number),o()):t},s.range=function(t){return arguments.length?(e=t,o()):e},s.rangeRound=function(t){return s.range(t).interpolate(Fr)},s.clamp=function(t){return arguments.length?(n=t,o()):n},s.interpolate=function(t){return arguments.length?(r=t,o()):r},s.ticks=function(e){return Qn(t,e)},s.tickFormat=function(e,r){return d3_scale_linearTickFormat(t,e,r)},s.nice=function(e){return Jn(t,e),o()},s.copy=function(){return Xn(t,e,r,n)},o()}function $n(t,e){return a.rebind(t,e,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function Jn(t,e){return Gn(t,Zn(Kn(t,e)[2])),Gn(t,Zn(Kn(t,e)[2])),t}function Kn(t,e){null==e&&(e=10);var r=Vn(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function Qn(t,e){return a.range.apply(a,Kn(t,e))}function ti(t,e,r,n){function i(t){return(r?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(e)}function a(t){return r?Math.pow(e,t):-Math.pow(e,-t)}function o(e){return t(i(e))}return o.invert=function(e){return a(t.invert(e))},o.domain=function(e){return arguments.length?(r=e[0]>=0,t.domain((n=e.map(Number)).map(i)),o):n},o.base=function(r){return arguments.length?(e=+r,t.domain(n.map(i)),o):e},o.nice=function(){var e=Gn(n.map(i),r?Math:ei);return t.domain(e),n=e.map(a),o},o.ticks=function(){var t=Vn(n),o=[],s=t[0],l=t[1],c=Math.floor(i(s)),u=Math.ceil(i(l)),h=e%1?2:e;if(isFinite(u-c)){if(r){for(;c<u;c++)for(var f=1;f<h;f++)o.push(a(c)*f);o.push(a(c))}else for(o.push(a(c));c++<u;)for(f=h-1;f>0;f--)o.push(a(c)*f);for(c=0;o[c]<s;c++);for(u=o.length;o[u-1]>l;u--);o=o.slice(c,u)}return o},o.copy=function(){return ti(t.copy(),e,r,n)},$n(o,t)}a.scale.linear=function(){return Xn([0,1],[0,1],Tr,!1)},a.scale.log=function(){return ti(a.scale.linear().domain([0,1]),10,!0,[1,10])};var ei={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function ri(t,e,r){var n=ni(e),i=ni(1/e);function a(e){return t(n(e))}return a.invert=function(e){return i(t.invert(e))},a.domain=function(e){return arguments.length?(t.domain((r=e.map(Number)).map(n)),a):r},a.ticks=function(t){return Qn(r,t)},a.tickFormat=function(t,e){return d3_scale_linearTickFormat(r,t,e)},a.nice=function(t){return a.domain(Jn(r,t))},a.exponent=function(o){return arguments.length?(n=ni(e=o),i=ni(1/e),t.domain(r.map(n)),a):e},a.copy=function(){return ri(t.copy(),e,r)},$n(a,t)}function ni(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}function ii(t,e){var r,n,i;function o(i){return n[((r.get(i)||(\"range\"===e.t?r.set(i,t.push(i)):NaN))-1)%n.length]}function s(e,r){return a.range(t.length).map((function(t){return e+r*t}))}return o.domain=function(n){if(!arguments.length)return t;t=[],r=new k;for(var i,a=-1,s=n.length;++a<s;)r.has(i=n[a])||r.set(i,t.push(i));return o[e.t].apply(o,e.a)},o.range=function(t){return arguments.length?(n=t,i=0,e={t:\"range\",a:arguments},o):n},o.rangePoints=function(r,a){arguments.length<2&&(a=0);var l=r[0],c=r[1],u=t.length<2?(l=(l+c)/2,0):(c-l)/(t.length-1+a);return n=s(l+u*a/2,u),i=0,e={t:\"rangePoints\",a:arguments},o},o.rangeRoundPoints=function(r,a){arguments.length<2&&(a=0);var l=r[0],c=r[1],u=t.length<2?(l=c=Math.round((l+c)/2),0):(c-l)/(t.length-1+a)|0;return n=s(l+Math.round(u*a/2+(c-l-(t.length-1+a)*u)/2),u),i=0,e={t:\"rangeRoundPoints\",a:arguments},o},o.rangeBands=function(r,a,l){arguments.length<2&&(a=0),arguments.length<3&&(l=a);var c=r[1]<r[0],u=r[c-0],h=(r[1-c]-u)/(t.length-a+2*l);return n=s(u+h*l,h),c&&n.reverse(),i=h*(1-a),e={t:\"rangeBands\",a:arguments},o},o.rangeRoundBands=function(r,a,l){arguments.length<2&&(a=0),arguments.length<3&&(l=a);var c=r[1]<r[0],u=r[c-0],h=r[1-c],f=Math.floor((h-u)/(t.length-a+2*l));return n=s(u+Math.round((h-u-(t.length-a)*f)/2),f),c&&n.reverse(),i=Math.round(f*(1-a)),e={t:\"rangeRoundBands\",a:arguments},o},o.rangeBand=function(){return i},o.rangeExtent=function(){return Vn(e.a[0])},o.copy=function(){return ii(t,e)},o.domain(t)}a.scale.pow=function(){return ri(a.scale.linear(),1,[0,1])},a.scale.sqrt=function(){return a.scale.pow().exponent(.5)},a.scale.ordinal=function(){return ii([],{t:\"range\",a:[[]]})},a.scale.category10=function(){return a.scale.ordinal().range(ai)},a.scale.category20=function(){return a.scale.ordinal().range(oi)},a.scale.category20b=function(){return a.scale.ordinal().range(si)},a.scale.category20c=function(){return a.scale.ordinal().range(li)};var ai=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),oi=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),si=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),li=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function ci(t,e){var r;function n(){var n=0,o=e.length;for(r=[];++n<o;)r[n-1]=a.quantile(t,n/o);return i}function i(t){if(!isNaN(t=+t))return e[a.bisect(r,t)]}return i.domain=function(e){return arguments.length?(t=e.map(y).filter(v).sort(g),n()):t},i.range=function(t){return arguments.length?(e=t,n()):e},i.quantiles=function(){return r},i.invertExtent=function(n){return(n=e.indexOf(n))<0?[NaN,NaN]:[n>0?r[n-1]:t[0],n<r.length?r[n]:t[t.length-1]]},i.copy=function(){return ci(t,e)},n()}function ui(t,e,r){var n,i;function a(e){return r[Math.max(0,Math.min(i,Math.floor(n*(e-t))))]}function o(){return n=r.length/(e-t),i=r.length-1,a}return a.domain=function(r){return arguments.length?(t=+r[0],e=+r[r.length-1],o()):[t,e]},a.range=function(t){return arguments.length?(r=t,o()):r},a.invertExtent=function(e){return[e=(e=r.indexOf(e))<0?NaN:e/n+t,e+1/n]},a.copy=function(){return ui(t,e,r)},o()}function hi(t,e){function r(r){if(r<=r)return e[a.bisect(t,r)]}return r.domain=function(e){return arguments.length?(t=e,r):t},r.range=function(t){return arguments.length?(e=t,r):e},r.invertExtent=function(r){return r=e.indexOf(r),[t[r-1],t[r]]},r.copy=function(){return hi(t,e)},r}function fi(t){function e(t){return+t}return e.invert=e,e.domain=e.range=function(r){return arguments.length?(t=r.map(e),e):t},e.ticks=function(e){return Qn(t,e)},e.tickFormat=function(e,r){return d3_scale_linearTickFormat(t,e,r)},e.copy=function(){return fi(t)},e}function pi(){return 0}a.scale.quantile=function(){return ci([],[])},a.scale.quantize=function(){return ui(0,1,[0,1])},a.scale.threshold=function(){return hi([.5],[0,1])},a.scale.identity=function(){return fi([0,1])},a.svg={},a.svg.arc=function(){var t=mi,e=gi,r=pi,n=di,i=yi,a=vi,o=xi;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-zt,h=a.apply(this,arguments)-zt,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=Pt)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,m,g,y,v,x,_,b,w,T,k,A,M=0,S=0,E=[];if((y=(+o.apply(this,arguments)||0)/2)&&(g=n===di?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Rt(g/c*Math.sin(y))),s&&(M=Rt(g/s*Math.sin(y)))),c){v=c*Math.cos(u+S),x=c*Math.sin(u+S),_=c*Math.cos(h-S),b=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=Lt?0:1;if(S&&_i(v,x,_,b)===p^C){var L=(u+h)/2;v=c*Math.cos(L),x=c*Math.sin(L),_=b=null}}else v=x=0;if(s){w=s*Math.cos(h-M),T=s*Math.sin(h-M),k=s*Math.cos(u+M),A=s*Math.sin(u+M);var I=Math.abs(u-h+2*M)<=Lt?0:1;if(M&&_i(w,T,k,A)===1-p^I){var P=(u+h)/2;w=s*Math.cos(P),T=s*Math.sin(P),k=A=null}}else w=T=0;if(f>Et&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){m=s<c^p?0:1;var z=d,O=d;if(f<Lt){var D=null==k?[w,T]:null==_?[v,x]:Oe([v,x],[k,A],[_,b],[w,T]),R=v-D[0],F=x-D[1],B=_-D[0],N=b-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);O=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=_){var V=bi(null==k?[w,T]:[k,A],[v,x],c,z,p),q=bi([_,b],[w,T],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",m,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^_i(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",m,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",m,\" \",q[0])}else E.push(\"M\",v,\",\",x);if(null!=k){var H=bi([v,x],[k,A],s,-O,p),G=bi([w,T],null==_?[v,x]:[_,b],s,-O,p);d===O?E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",m,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^_i(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",O,\",\",O,\" 0 0,\",m,\" \",H[0]):E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",m,\" \",H[0])}else E.push(\"L\",w,\",\",T)}else E.push(\"M\",v,\",\",x),null!=_&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",_,\",\",b),E.push(\"L\",w,\",\",T),null!=k&&E.push(\"A\",s,\",\",s,\" 0 \",I,\",\",1-p,\" \",k,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ge(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ge(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ge(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==di?di:ge(t),s):n},s.startAngle=function(t){return arguments.length?(i=ge(t),s):i},s.endAngle=function(t){return arguments.length?(a=ge(t),s):a},s.padAngle=function(t){return arguments.length?(o=ge(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-zt;return[Math.cos(n)*r,Math.sin(n)*r]},s};var di=\"auto\";function mi(t){return t.innerRadius}function gi(t){return t.outerRadius}function yi(t){return t.startAngle}function vi(t){return t.endAngle}function xi(t){return t&&t.padAngle}function _i(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function bi(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,m=(h+p)/2,g=f-u,y=p-h,v=g*g+y*y,x=r-n,_=u*p-f*h,b=(y<0?-1:1)*Math.sqrt(Math.max(0,x*x*v-_*_)),w=(_*y-g*b)/v,T=(-_*g-y*b)/v,k=(_*y+g*b)/v,A=(-_*g+y*b)/v,M=w-d,S=T-m,E=k-d,C=A-m;return M*M+S*S>E*E+C*C&&(w=k,T=A),[[w-l,T-c],[w*r/x,T*r/x]]}function wi(){return!0}function Ti(t){var e=Ee,r=Ce,n=wi,i=Ai,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ge(e),p=ge(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=ki.get(t)||Ai).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}a.svg.line=function(){return Ti(D)};var ki=a.map({linear:Ai,\"linear-closed\":Mi,step:function(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);return r>1&&i.push(\"H\",n[0]),i.join(\"\")},\"step-before\":Si,\"step-after\":Ei,basis:Ii,\"basis-open\":function(t){if(t.length<4)return Ai(t);for(var e,r=[],n=-1,i=t.length,a=[0],o=[0];++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);for(r.push(Pi(Di,a)+\",\"+Pi(Di,o)),--n;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Ri(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){for(var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);for(e=[Pi(Di,o),\",\",Pi(Di,s)],--n;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Ri(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)i=c/r,(n=t[c])[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Ii(t)},cardinal:function(t,e){return t.length<3?Ai(t):t[0]+Ci(t,Li(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Ai(t):t[1]+Ci(t.slice(1,-1),Li(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?Mi(t):t[0]+Ci((t.push(t[0]),t),Li([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Ai(t):t[0]+Ci(t,function(t){for(var e,r,n,i,a=[],o=function(t){for(var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=Fi(i,a);++e<r;)n[e]=(o+(o=Fi(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;++s<l;)e=Fi(t[s],t[s+1]),w(e)<Et?o[s]=o[s+1]=0:(i=(r=o[s]/e)*r+(n=o[s+1]/e)*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n);for(s=-1;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Ai(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function Mi(t){return t.join(\"L\")+\"Z\"}function Si(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Ei(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Ci(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Ai(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Li(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Ii(t){if(t.length<3)return Ai(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Pi(Di,o),\",\",Pi(Di,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Ri(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Pi(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}ki.forEach((function(t,e){e.key=t,e.closed=/-closed$/.test(t)}));var zi=[0,2/3,1/3,0],Oi=[0,1/3,2/3,0],Di=[0,1/6,2/3,1/6];function Ri(t,e,r){t.push(\"C\",Pi(zi,e),\",\",Pi(zi,r),\",\",Pi(Oi,e),\",\",Pi(Oi,r),\",\",Pi(Di,e),\",\",Pi(Di,r))}function Fi(t,e){return(e[1]-t[1])/(e[0]-t[0])}function Bi(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-zt,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function Ni(t){var e=Ee,r=Ee,n=0,i=Ce,a=wi,o=Ai,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],m=[],g=[],y=-1,v=s.length,x=ge(e),_=ge(n),b=e===r?function(){return f}:ge(r),w=n===i?function(){return p}:ge(i);function T(){d.push(\"M\",o(t(g),u),c,l(t(m.reverse()),u),\"Z\")}for(;++y<v;)a.call(this,h=s[y],y)?(m.push([f=+x.call(this,h,y),p=+_.call(this,h,y)]),g.push([+b.call(this,h,y),+w.call(this,h,y)])):m.length&&(T(),m=[],g=[]);return m.length&&T(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=ki.get(t)||Ai).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ji(t){return t.source}function Ui(t){return t.target}function Vi(t){return t.radius}function qi(t){return[t.x,t.y]}function Hi(){return 64}function Gi(){return\"circle\"}function Zi(t){var e=Math.sqrt(t/Lt);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}a.svg.line.radial=function(){var t=Ti(Bi);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Si.reverse=Ei,Ei.reverse=Si,a.svg.area=function(){return Ni(D)},a.svg.area.radial=function(){var t=Ni(Bi);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},a.svg.chord=function(){var t=ji,e=Ui,r=Vi,n=yi,i=vi;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,((i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\")}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-zt,u=i.call(t,s,o)-zt;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>Lt)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ge(t),a):r},a.source=function(e){return arguments.length?(t=ge(e),a):t},a.target=function(t){return arguments.length?(e=ge(t),a):e},a.startAngle=function(t){return arguments.length?(n=ge(t),a):n},a.endAngle=function(t){return arguments.length?(i=ge(t),a):i},a},a.svg.diagonal=function(){var t=ji,e=Ui,r=qi;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ge(e),n):t},n.target=function(t){return arguments.length?(e=ge(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},a.svg.diagonal.radial=function(){var t=a.svg.diagonal(),e=qi,r=t.projection;return t.projection=function(t){return arguments.length?r(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-zt;return[r*Math.cos(n),r*Math.sin(n)]}}(e=t)):e},t},a.svg.symbol=function(){var t=Gi,e=Hi;function r(r,n){return(Wi.get(t.call(this,r,n))||Zi)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ge(e),r):t},r.size=function(t){return arguments.length?(e=ge(t),r):e},r};var Wi=a.map({circle:Zi,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*Xi)),r=e*Xi;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/Yi),r=e*Yi/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/Yi),r=e*Yi/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});a.svg.symbolTypes=Wi.keys();var Yi=Math.sqrt(3),Xi=Math.tan(30*Ot);J.transition=function(t){for(var e,r,n=Qi||++ra,i=aa(t),a=[],o=ta||{time:Date.now(),ease:Pr,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&oa(r,u,i,n,o),e.push(r)}return Ki(a,i,n)},J.interrupt=function(t){return this.each(null==t?$i:Ji(aa(t)))};var $i=Ji(aa());function Ji(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function Ki(t,e,r){return Z(t,ea),t.namespace=e,t.id=r,t}var Qi,ta,ea=[],ra=0;function na(t,e,r,n){var i=t.id,a=t.namespace;return mt(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function ia(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function aa(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function oa(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var m=u[d];m.timer.c=null,m.timer.t=NaN,--u.count,delete u[d]}o.c=p,ke((function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1}),0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach((function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)})),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=ke((function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f}),0,a),h=u[n]={tween:new k,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}ea.call=J.call,ea.empty=J.empty,ea.node=J.node,ea.size=J.size,a.transition=function(t,e){return t&&t.transition?Qi?t.transition(e):t:a.selection().transition(t)},a.transition.prototype=ea,ea.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=K(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),oa(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return Ki(o,a,i)},ea.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Q(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,m=r.length;++d<m;)(i=r[d])&&oa(i,d,s,o,a),e.push(i)}return Ki(l,s,o)},ea.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=pt(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return Ki(n,this.namespace,this.id)},ea.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):mt(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},ea.attr=function(t,e){if(arguments.length<2){for(e in t)this.attr(e,t[e]);return this}var r=\"transform\"==t?qr:Tr,n=a.ns.qualify(t);function i(){this.removeAttribute(n)}function o(){this.removeAttributeNS(n.space,n.local)}return na(this,\"attr.\"+t,e,n.local?function(t){return null==t?o:(t+=\"\",function(){var e,i=this.getAttributeNS(n.space,n.local);return i!==t&&(e=r(i,t),function(t){this.setAttributeNS(n.space,n.local,e(t))})})}:function(t){return null==t?i:(t+=\"\",function(){var e,i=this.getAttribute(n);return i!==t&&(e=r(i,t),function(t){this.setAttribute(n,e(t))})})})},ea.attrTween=function(t,e){var r=a.ns.qualify(t);return this.tween(\"attr.\"+t,r.local?function(t,n){var i=e.call(this,t,n,this.getAttributeNS(r.space,r.local));return i&&function(t){this.setAttributeNS(r.space,r.local,i(t))}}:function(t,n){var i=e.call(this,t,n,this.getAttribute(r));return i&&function(t){this.setAttribute(r,i(t))}})},ea.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return na(this,\"style.\"+t,e,(function(e){return null==e?i:(e+=\"\",function(){var n,i=u(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Tr(i,e),function(e){this.style.setProperty(t,n(e),r)})})}))},ea.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,(function(n,i){var a=e.call(this,n,i,u(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}}))},ea.text=function(t){return na(this,\"text\",t,ia)},ea.remove=function(){var t=this.namespace;return this.each(\"end.transition\",(function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)}))},ea.ease=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].ease:(\"function\"!=typeof t&&(t=a.ease.apply(a,arguments)),mt(this,(function(n){n[r][e].ease=t})))},ea.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:mt(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},ea.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:mt(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ea.each=function(t,e){var r=this.id,n=this.namespace;if(arguments.length<2){var i=ta,o=Qi;try{Qi=r,mt(this,(function(e,i,a){ta=e[n][r],t.call(e,e.__data__,i,a)}))}finally{ta=i,Qi=o}}else mt(this,(function(i){var o=i[n][r];(o.event||(o.event=a.dispatch(\"start\",\"end\",\"interrupt\"))).on(t,e)}));return this},ea.transition=function(){for(var t,e,r,n=this.id,i=++ra,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&oa(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return Ki(o,a,i)},a.svg.axis=function(){var t,e=a.scale.linear(),r=sa,n=6,i=6,o=3,l=[10],c=null;function u(s){s.each((function(){var s,u=a.select(this),h=this.__chart__||e,f=this.__chart__=e.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==t?f.tickFormat?f.tickFormat.apply(f,l):D:t,m=u.selectAll(\".tick\").data(p,f),g=m.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",Et),y=a.transition(m.exit()).style(\"opacity\",Et).remove(),v=a.transition(m.order()).style(\"opacity\",1),x=Math.max(n,0)+o,_=qn(f),b=u.selectAll(\".domain\").data([0]),w=(b.enter().append(\"path\").attr(\"class\",\"domain\"),a.transition(b));g.append(\"line\"),g.append(\"text\");var T,k,A,M,S=g.select(\"line\"),E=v.select(\"line\"),C=m.select(\"text\").text(d),L=g.select(\"text\"),I=v.select(\"text\"),P=\"top\"===r||\"left\"===r?-1:1;if(\"bottom\"===r||\"top\"===r?(s=ca,T=\"x\",A=\"y\",k=\"x2\",M=\"y2\",C.attr(\"dy\",P<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+_[0]+\",\"+P*i+\"V0H\"+_[1]+\"V\"+P*i)):(s=ua,T=\"y\",A=\"x\",k=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",P<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+P*i+\",\"+_[0]+\"H0V\"+_[1]+\"H\"+P*i)),S.attr(M,P*n),L.attr(A,P*x),E.attr(k,0).attr(M,P*n),I.attr(T,0).attr(A,P*x),f.rangeBand){var z=f,O=z.rangeBand()/2;h=f=function(t){return z(t)+O}}else h.rangeBand?h=f:y.call(s,f,h);g.call(s,h,f),v.call(s,f,f)}))}return u.scale=function(t){return arguments.length?(e=t,u):e},u.orient=function(t){return arguments.length?(r=t in la?t+\"\":sa,u):r},u.ticks=function(){return arguments.length?(l=s(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(e){return arguments.length?(t=e,u):t},u.tickSize=function(t){var e=arguments.length;return e?(n=+t,i=+arguments[e-1],u):n},u.innerTickSize=function(t){return arguments.length?(n=+t,u):n},u.outerTickSize=function(t){return arguments.length?(i=+t,u):i},u.tickPadding=function(t){return arguments.length?(o=+t,u):o},u.tickSubdivide=function(){return arguments.length&&u},u};var sa=\"bottom\",la={top:1,right:1,bottom:1,left:1};function ca(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"}))}function ua(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"}))}a.svg.brush=function(){var t,e,r=H(f,\"brushstart\",\"brush\",\"brushend\"),n=null,i=null,o=[0,0],s=[0,0],l=!0,c=!0,h=fa[0];function f(t){t.each((function(){var t=a.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",g).on(\"touchstart.brush\",g),e=t.selectAll(\".background\").data([0]);e.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),t.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var r=t.selectAll(\".resize\").data(h,D);r.exit().remove(),r.enter().append(\"g\").attr(\"class\",(function(t){return\"resize \"+t})).style(\"cursor\",(function(t){return ha[t]})).append(\"rect\").attr(\"x\",(function(t){return/[ew]$/.test(t)?-3:null})).attr(\"y\",(function(t){return/^[ns]/.test(t)?-3:null})).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),r.style(\"display\",f.empty()?\"none\":null);var o,s=a.transition(t),l=a.transition(e);n&&(o=qn(n),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),i&&(o=qn(i),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),m(s)),p(s)}))}function p(t){t.selectAll(\".resize\").attr(\"transform\",(function(t){return\"translate(\"+o[+/e$/.test(t)]+\",\"+s[+/^s/.test(t)]+\")\"}))}function d(t){t.select(\".extent\").attr(\"x\",o[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",o[1]-o[0])}function m(t){t.select(\".extent\").attr(\"y\",s[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",s[1]-s[0])}function g(){var h,g,y=this,v=a.select(a.event.target),x=r.of(y,arguments),_=a.select(y),b=v.datum(),w=!/^(n|s)$/.test(b)&&n,T=!/^(e|w)$/.test(b)&&i,k=v.classed(\"extent\"),A=kt(y),M=a.mouse(y),S=a.select(u(y)).on(\"keydown.brush\",(function(){32==a.event.keyCode&&(k||(h=null,M[0]-=o[1],M[1]-=s[1],k=2),V())})).on(\"keyup.brush\",(function(){32==a.event.keyCode&&2==k&&(M[0]+=o[1],M[1]+=s[1],k=0,V())}));if(a.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",P):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",P),_.interrupt().selectAll(\"*\").interrupt(),k)M[0]=o[0]-M[0],M[1]=s[0]-M[1];else if(b){var E=+/w$/.test(b),C=+/^n/.test(b);g=[o[1-E]-M[0],s[1-C]-M[1]],M[0]=o[E],M[1]=s[C]}else a.event.altKey&&(h=M.slice());function L(){var t=a.mouse(y),e=!1;g&&(t[0]+=g[0],t[1]+=g[1]),k||(a.event.altKey?(h||(h=[(o[0]+o[1])/2,(s[0]+s[1])/2]),M[0]=o[+(t[0]<h[0])],M[1]=s[+(t[1]<h[1])]):h=null),w&&I(t,n,0)&&(d(_),e=!0),T&&I(t,i,1)&&(m(_),e=!0),e&&(p(_),x({type:\"brush\",mode:k?\"move\":\"resize\"}))}function I(r,n,i){var a,u,f=qn(n),p=f[0],d=f[1],m=M[i],g=i?s:o,y=g[1]-g[0];if(k&&(p-=m,d-=y+m),a=(i?c:l)?Math.max(p,Math.min(d,r[i])):r[i],k?u=(a+=m)+y:(h&&(m=Math.max(p,Math.min(d,2*h[i]-a))),m<a?(u=a,a=m):u=m),g[0]!=a||g[1]!=u)return i?e=null:t=null,g[0]=a,g[1]=u,!0}function P(){L(),_.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),a.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}_.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),a.select(\"body\").style(\"cursor\",v.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(n){n.each((function(){var n=r.of(this,arguments),i={x:o,y:s,i:t,j:e},l=this.__chart__||i;this.__chart__=i,Qi?a.select(this).transition().each(\"start.brush\",(function(){t=l.i,e=l.j,o=l.x,s=l.y,n({type:\"brushstart\"})})).tween(\"brush:brush\",(function(){var r=kr(o,i.x),a=kr(s,i.y);return t=e=null,function(t){o=i.x=r(t),s=i.y=a(t),n({type:\"brush\",mode:\"resize\"})}})).each(\"end.brush\",(function(){t=i.i,e=i.j,n({type:\"brush\",mode:\"resize\"}),n({type:\"brushend\"})})):(n({type:\"brushstart\"}),n({type:\"brush\",mode:\"resize\"}),n({type:\"brushend\"}))}))},f.x=function(t){return arguments.length?(h=fa[!(n=t)<<1|!i],f):n},f.y=function(t){return arguments.length?(h=fa[!n<<1|!(i=t)],f):i},f.clamp=function(t){return arguments.length?(n&&i?(l=!!t[0],c=!!t[1]):n?l=!!t:i&&(c=!!t),f):n&&i?[l,c]:n?l:i?c:null},f.extent=function(r){var a,l,c,u,h;return arguments.length?(n&&(a=r[0],l=r[1],i&&(a=a[0],l=l[0]),t=[a,l],n.invert&&(a=n(a),l=n(l)),l<a&&(h=a,a=l,l=h),a==o[0]&&l==o[1]||(o=[a,l])),i&&(c=r[0],u=r[1],n&&(c=c[1],u=u[1]),e=[c,u],i.invert&&(c=i(c),u=i(u)),u<c&&(h=c,c=u,u=h),c==s[0]&&u==s[1]||(s=[c,u])),f):(n&&(t?(a=t[0],l=t[1]):(a=o[0],l=o[1],n.invert&&(a=n.invert(a),l=n.invert(l)),l<a&&(h=a,a=l,l=h))),i&&(e?(c=e[0],u=e[1]):(c=s[0],u=s[1],i.invert&&(c=i.invert(c),u=i.invert(u)),u<c&&(h=c,c=u,u=h))),n&&i?[[a,c],[l,u]]:n?[a,l]:i&&[c,u])},f.clear=function(){return f.empty()||(o=[0,0],s=[0,0],t=e=null),f},f.empty=function(){return!!n&&o[0]==o[1]||!!i&&s[0]==s[1]},a.rebind(f,r,\"on\")};var ha={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},fa=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]];function pa(t){return JSON.parse(t.responseText)}function da(t){var e=l.createRange();return e.selectNode(l.body),e.createContextualFragment(t.responseText)}a.text=ye((function(t){return t.responseText})),a.json=function(t,e){return ve(t,\"application/json\",pa,e)},a.html=function(t,e){return ve(t,\"text/html\",da,e)},a.xml=ye((function(t){return t.responseXML})),void 0===(i=\"function\"==typeof(n=a)?n.call(e,r,e,t):n)||(t.exports=i)}).apply(self)},32280:function(t){t.exports=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),r=i(o),\"undefined\"!=typeof window&&(r.workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"})))}else e=i;else t=i}return n(0,(function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=\"1.13.4\",n=i;function i(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}i.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},i.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},i.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},i.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},i.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var a=o;function o(t,e){this.x=t,this.y=e}o.prototype={clone:function(){return new o(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},o.convert=function(t){return t instanceof o?t:Array.isArray(t)?new o(t[0],t[1]):t};var s=\"undefined\"!=typeof self?self:{};var l=Math.pow(2,53)-1;function c(t,e,r,i){var a=new n(t,e,r,i);return function(t){return a.solve(t)}}var u=c(.25,.1,.25,1);function h(t,e,r){return Math.min(r,Math.max(e,t))}function f(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function p(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var d=1;function m(){return d++}function g(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function y(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach((function(t){e[t]&&(e[t]=e[t].bind(e))}))}function x(t,e){return-1!==t.indexOf(e,t.length-e.length)}function _(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function b(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function w(t){return Array.isArray(t)?t.map(w):\"object\"==typeof t&&t?_(t,w):t}var T={};function k(t){T[t]||(\"undefined\"!=typeof console&&console.warn(t),T[t]=!0)}function A(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function M(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function S(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}function E(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,(function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"})),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}var C=null;function L(t){if(null==C){var e=t.navigator?t.navigator.userAgent:null;C=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return C}function I(t){try{var e=s[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var P,z,O,D,R=s.performance&&s.performance.now?s.performance.now.bind(s.performance):Date.now.bind(Date),F=s.requestAnimationFrame||s.mozRequestAnimationFrame||s.webkitRequestAnimationFrame||s.msRequestAnimationFrame,B=s.cancelAnimationFrame||s.mozCancelAnimationFrame||s.webkitCancelAnimationFrame||s.msCancelAnimationFrame,N={now:R,frame:function(t){var e=F(t);return{cancel:function(){return B(e)}}},getImageData:function(t,e){void 0===e&&(e=0);var r=s.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=t.width,r.height=t.height,n.drawImage(t,0,0,t.width,t.height),n.getImageData(-e,-e,t.width+2*e,t.height+2*e)},resolveURL:function(t){return P||(P=s.document.createElement(\"a\")),P.href=t,P.href},hardwareConcurrency:s.navigator&&s.navigator.hardwareConcurrency||4,get devicePixelRatio(){return s.devicePixelRatio},get prefersReducedMotion(){return!!s.matchMedia&&(null==z&&(z=s.matchMedia(\"(prefers-reduced-motion: reduce)\")),z.matches)}},j={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},U={supported:!1,testSupport:function(t){!V&&D&&(q?H(t):O=t)}},V=!1,q=!1;function H(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,D),t.isContextLost())return;U.supported=!0}catch(t){}t.deleteTexture(e),V=!0}s.document&&((D=s.document.createElement(\"img\")).onload=function(){O&&H(O),O=null,q=!0},D.onerror=function(){V=!0,O=null},D.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var G=\"01\";var Z=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function W(t){return 0===t.indexOf(\"mapbox:\")}Z.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",G,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},Z.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},Z.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},Z.prototype.normalizeStyleURL=function(t,e){if(!W(t))return t;var r=J(t);return r.path=\"/styles/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},Z.prototype.normalizeGlyphsURL=function(t,e){if(!W(t))return t;var r=J(t);return r.path=\"/fonts/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},Z.prototype.normalizeSourceURL=function(t,e){if(!W(t))return t;var r=J(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),this._makeAPIURL(r,this._customAccessToken||e)},Z.prototype.normalizeSpriteURL=function(t,e,r,n){var i=J(t);return W(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,this._makeAPIURL(i,this._customAccessToken||n)):(i.path+=\"\"+e+r,K(i))},Z.prototype.normalizeTileURL=function(t,e){if(this._isSkuTokenExpired()&&this._createSkuToken(),t&&!W(t))return t;var r=J(t),n=N.devicePixelRatio>=2||512===e?\"@2x\":\"\",i=U.supported?\".webp\":\"$1\";r.path=r.path.replace(/(\\.(png|jpg)\\d*)(?=$)/,\"\"+n+i),r.path=r.path.replace(/^.+\\/v4\\//,\"/\"),r.path=\"/v4\"+r.path;var a=this._customAccessToken||function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e].match(/^access_token=(.*)$/);if(n)return n[1]}return null}(r.params)||j.ACCESS_TOKEN;return j.REQUIRE_ACCESS_TOKEN&&a&&this._skuToken&&r.params.push(\"sku=\"+this._skuToken),this._makeAPIURL(r,a)},Z.prototype.canonicalizeTileURL=function(t,e){var r=J(t);if(!r.path.match(/(^\\/v4\\/)/)||!r.path.match(/\\.[\\w]+$/))return t;var n=\"mapbox://tiles/\";n+=r.path.replace(\"/v4/\",\"\");var i=r.params;return e&&(i=i.filter((function(t){return!t.match(/^access_token=/)}))),i.length&&(n+=\"?\"+i.join(\"&\")),n},Z.prototype.canonicalizeTileset=function(t,e){for(var r=!!e&&W(e),n=[],i=0,a=t.tiles||[];i<a.length;i+=1){var o=a[i];X(o)?n.push(this.canonicalizeTileURL(o,r)):n.push(o)}return n},Z.prototype._makeAPIURL=function(t,e){var r=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\",n=J(j.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,\"http\"===t.protocol){var i=t.params.indexOf(\"secure\");i>=0&&t.params.splice(i,1)}if(\"/\"!==n.path&&(t.path=\"\"+n.path+t.path),!j.REQUIRE_ACCESS_TOKEN)return K(t);if(!(e=e||j.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+r);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+r);return t.params=t.params.filter((function(t){return-1===t.indexOf(\"access_token\")})),t.params.push(\"access_token=\"+e),K(t)};var Y=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function X(t){return Y.test(t)}var $=/^(\\w+):\\/\\/([^/?]*)(\\/[^?]+)?\\??(.+)?/;function J(t){var e=t.match($);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function K(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}var Q=\"mapbox.eventData\";function tt(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(s.atob(e).split(\"\").map((function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)})).join(\"\"))))}catch(t){return null}}var et=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};et.prototype.getStorageKey=function(t){var e,r,n=tt(j.ACCESS_TOKEN);return e=n&&n.u?(r=n.u,s.btoa(encodeURIComponent(r).replace(/%([0-9A-F]{2})/g,(function(t,e){return String.fromCharCode(Number(\"0x\"+e))})))):j.ACCESS_TOKEN||\"\",t?Q+\".\"+t+\":\"+e:Q+\":\"+e},et.prototype.fetchEventData=function(){var t=I(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=s.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=s.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){k(\"Unable to read from LocalStorage\")}},et.prototype.saveEventData=function(){var t=I(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{s.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&s.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){k(\"Unable to write to LocalStorage\")}},et.prototype.processRequests=function(t){},et.prototype.postEvent=function(t,e,n,i){var a=this;if(j.EVENTS_URL){var o=J(j.EVENTS_URL);o.params.push(\"access_token=\"+(i||j.ACCESS_TOKEN||\"\"));var s={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:r,skuId:G,userId:this.anonId},l=e?p(s,e):s,c={url:K(o),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([l])};this.pendingRequest=St(c,(function(t){a.pendingRequest=null,n(t),a.saveEventData(),a.processRequests(i)}))}},et.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var rt,nt,it=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(j.EVENTS_URL&&n||j.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return W(t)||X(t)})))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,i=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),y(this.anonId)||(this.anonId=g()),this.postEvent(i,{skuToken:this.skuToken},(function(t){t||n&&(e.success[n]=!0)}),t))}},e}(et),at=function(t){function e(e){t.call(this,\"appUserTurnstile\"),this._customAccessToken=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t,e){j.EVENTS_URL&&j.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return W(t)||X(t)}))&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=tt(j.ACCESS_TOKEN),n=r?r.u:j.ACCESS_TOKEN,i=n!==this.eventData.tokenU;y(this.anonId)||(this.anonId=g(),i=!0);var a=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(a),l=(a-this.eventData.lastSuccess)/864e5;i=i||l>=1||l<-1||o.getDate()!==s.getDate()}else i=!0;if(!i)return this.processRequests();this.postEvent(a,{\"enabled.telemetry\":!1},(function(t){t||(e.eventData.lastSuccess=a,e.eventData.tokenU=n)}),t)}},e}(et),ot=new at,st=ot.postTurnstileEvent.bind(ot),lt=new it,ct=lt.postMapLoadEvent.bind(lt),ut=\"mapbox-tiles\",ht=500,ft=50,pt=42e4;function dt(){s.caches&&!rt&&(rt=s.caches.open(ut))}function mt(t,e,r){if(dt(),rt){var n={status:e.status,statusText:e.statusText,headers:new s.Headers};e.headers.forEach((function(t,e){return n.headers.set(e,t)}));var i=E(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<pt||function(t,e){if(void 0===nt)try{new Response(new ReadableStream),nt=!0}catch(t){nt=!1}nt?e(t.body):t.blob().then(e)}(e,(function(e){var r=new s.Response(e,n);dt(),rt&&rt.then((function(e){return e.put(gt(t.url),r)})).catch((function(t){return k(t.message)}))})))}}function gt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}function yt(t,e){if(dt(),!rt)return e(null);var r=gt(t.url);rt.then((function(t){t.match(r).then((function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")||0),r=E(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})).catch(e)})).catch(e)}var vt,xt=1/0;function _t(){return null==vt&&(vt=s.OffscreenCanvas&&new s.OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof s.createImageBitmap),vt}var bt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(bt);var wt=function(t){function e(e,r,n){401===r&&X(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error),Tt=S()?function(){return self.worker&&self.worker.referrer}:function(){return(\"blob:\"===s.location.protocol?s.parent:s).location.href};function kt(t,e){var r,n=new s.AbortController,i=new s.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:Tt(),signal:n.signal}),a=!1,o=!1,l=(r=i.url).indexOf(\"sku=\")>0&&X(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var c=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&k(r),n&&a)return u(n);var c=Date.now();s.fetch(i).then((function(r){if(r.ok){var n=l?r.clone():null;return u(r,n,c)}return e(new wt(r.statusText,r.status,t.url))})).catch((function(t){20!==t.code&&e(new Error(t.message))}))}},u=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then((function(t){o||(n&&s&&mt(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))})).catch((function(t){o||e(new Error(t.message))}))};return l?yt(i,c):c(null,null),{cancel:function(){o=!0,a||n.abort()}}}var At=function(t,e){if(r=t.url,!(/^file:/.test(r)||/^file:/.test(Tt())&&!/^\\w+:/.test(r))){if(s.fetch&&s.Request&&s.AbortController&&s.Request.prototype.hasOwnProperty(\"signal\"))return kt(t,e);if(S()&&self.worker&&self.worker.actor){return self.worker.actor.send(\"getResource\",t,e,void 0,!0)}}var r;return function(t,e){var r=new s.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&(r.responseType=\"text\",r.setRequestHeader(\"Accept\",\"application/json\")),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new wt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(p(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(p(t,{method:\"POST\"}),e)};var Et,Ct,Lt=\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\";Et=[],Ct=0;var It=function(t,e){if(U.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),Ct>=j.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return Et.push(r),r}Ct++;var n=!1,i=function(){if(!n)for(n=!0,Ct--;Et.length&&Ct<j.MAX_PARALLEL_IMAGE_REQUESTS;){var t=Et.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=It(e,r).cancel)}},a=Mt(t,(function(t,r,n,a){i(),t?e(t):r&&(_t()?function(t,e){var r=new s.Blob([new Uint8Array(t)],{type:\"image/png\"});s.createImageBitmap(r).then((function(t){e(null,t)})).catch((function(t){e(new Error(\"Could not load image because of \"+t.message+\". Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))}))}(r,e):function(t,e,r,n){var i=new s.Image,a=s.URL;i.onload=function(){e(null,i),a.revokeObjectURL(i.src),i.onload=null,s.requestAnimationFrame((function(){i.src=Lt}))},i.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var o=new s.Blob([new Uint8Array(t)],{type:\"image/png\"});i.cacheControl=r,i.expires=n,i.src=t.byteLength?a.createObjectURL(o):Lt}(r,e,n,a))}));return{cancel:function(){a.cancel(),i()}}};function Pt(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function zt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Ot=function(t,e){void 0===e&&(e={}),p(this,e),this.type=t},Dt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",p({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Ot),Rt=function(){};Rt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Pt(t,e,this._listeners),this},Rt.prototype.off=function(t,e){return zt(t,e,this._listeners),zt(t,e,this._oneTimeListeners),this},Rt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Pt(t,e,this._oneTimeListeners),this},Rt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Ot(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];zt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(p(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Dt&&console.error(t.error);return this},Rt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},Rt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var Ft={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},volatile:{type:\"boolean\",default:!1},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},volatile:{type:\"boolean\",default:!1},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},volatile:{type:\"boolean\",default:!1},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},filter:{type:\"*\"},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterMinPoints:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{},within:{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}},Bt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Nt(t){var e=t.key,r=t.value;return r?[new Bt(e,r,\"constants have been deprecated as of v8\")]:[]}function jt(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Ut(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function Vt(t){if(Array.isArray(t))return t.map(Vt);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){var e={};for(var r in t)e[r]=Vt(t[r]);return e}return Ut(t)}var qt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Ht=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Ht.prototype.concat=function(t){return new Ht(this,t)},Ht.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Ht.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var Gt={kind:\"null\"},Zt={kind:\"number\"},Wt={kind:\"string\"},Yt={kind:\"boolean\"},Xt={kind:\"color\"},$t={kind:\"object\"},Jt={kind:\"value\"},Kt={kind:\"collator\"},Qt={kind:\"formatted\"},te={kind:\"resolvedImage\"};function ee(t,e){return{kind:\"array\",itemType:t,N:e}}function re(t){if(\"array\"===t.kind){var e=re(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var ne=[Gt,Zt,Wt,Yt,Xt,Qt,$t,ee(Jt),te];function ie(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ie(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=ne;r<n.length;r+=1)if(!ie(n[r],e))return null}return\"Expected \"+re(t)+\" but found \"+re(e)+\" instead.\"}function ae(t,e){return e.some((function(e){return e.kind===t.kind}))}function oe(t,e){return e.some((function(e){return\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t}))}var se=e((function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),m=o(h[2]),g=m<=.5?m*(d+1):m+d-m*d,y=2*m-g;return[n(255*s(y,g,p+1/3)),n(255*s(y,g,p)),n(255*s(y,g,p-1/3)),f];default:return null}}return null}}catch(t){}})),le=se.parseCSSColor,ce=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ce.parse=function(t){if(t){if(t instanceof ce)return t;if(\"string\"==typeof t){var e=le(t);if(e)return new ce(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ce.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ce.prototype.toArray=function(){var t=this,e=t.r,r=t.g,n=t.b,i=t.a;return 0===i?[0,0,0,0]:[255*e/i,255*r/i,255*n/i,i]},ce.black=new ce(0,0,0,1),ce.white=new ce(1,1,1,1),ce.transparent=new ce(0,0,0,0),ce.red=new ce(1,0,0,1);var ue=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ue.prototype.compare=function(t,e){return this.collator.compare(t,e)},ue.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var he=function(t,e,r,n,i){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=i},fe=function(t){this.sections=t};fe.fromString=function(t){return new fe([new he(t,null,null,null,null)])},fe.prototype.isEmpty=function(){return 0===this.sections.length||!this.sections.some((function(t){return 0!==t.text.length||t.image&&0!==t.image.name.length}))},fe.factory=function(t){return t instanceof fe?t:fe.fromString(t)},fe.prototype.toString=function(){return 0===this.sections.length?\"\":this.sections.map((function(t){return t.text})).join(\"\")},fe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];if(n.image)t.push([\"image\",n.image.name]);else{t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),n.textColor&&(i[\"text-color\"]=[\"rgba\"].concat(n.textColor.toArray())),t.push(i)}}return t};var pe=function(t){this.name=t.name,this.available=t.available};function de(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function me(t){if(null===t)return!0;if(\"string\"==typeof t)return!0;if(\"boolean\"==typeof t)return!0;if(\"number\"==typeof t)return!0;if(t instanceof ce)return!0;if(t instanceof ue)return!0;if(t instanceof fe)return!0;if(t instanceof pe)return!0;if(Array.isArray(t)){for(var e=0,r=t;e<r.length;e+=1)if(!me(r[e]))return!1;return!0}if(\"object\"==typeof t){for(var n in t)if(!me(t[n]))return!1;return!0}return!1}function ge(t){if(null===t)return Gt;if(\"string\"==typeof t)return Wt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Zt;if(t instanceof ce)return Xt;if(t instanceof ue)return Kt;if(t instanceof fe)return Qt;if(t instanceof pe)return te;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=ge(i[n]);if(e){if(e===a)continue;e=Jt;break}e=a}return ee(e||Jt,r)}return $t}function ye(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ce||t instanceof fe||t instanceof pe?t.toString():JSON.stringify(t)}pe.prototype.toString=function(){return this.name},pe.fromString=function(t){return t?new pe({name:t,available:!1}):null},pe.prototype.serialize=function(){return[\"image\",this.name]};var ve=function(t,e){this.type=t,this.value=e};ve.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!me(t[1]))return e.error(\"invalid value\");var r=t[1],n=ge(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ve(n,r)},ve.prototype.evaluate=function(){return this.value},ve.prototype.eachChild=function(){},ve.prototype.outputDefined=function(){return!0},ve.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ce?[\"rgba\"].concat(this.value.toArray()):this.value instanceof fe?this.value.serialize():this.value};var xe=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};xe.prototype.toJSON=function(){return this.message};var _e={string:Wt,number:Zt,boolean:Yt,object:$t},be=function(t,e){this.type=t,this.args=e};be.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in _e)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=_e[s],n++}else a=Jt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=ee(a,o)}else r=_e[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Jt);if(!c)return null;l.push(c)}return new be(r,l)},be.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ie(this.type,ge(r)))return r;if(e===this.args.length-1)throw new xe(\"Expected value to be of type \"+re(this.type)+\", but found \"+re(ge(r))+\" instead.\")}return null},be.prototype.eachChild=function(t){this.args.forEach(t)},be.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},be.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map((function(t){return t.serialize()})))};var we=function(t){this.type=Qt,this.sections=t};we.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");for(var n=[],i=!1,a=1;a<=t.length-1;++a){var o=t[a];if(i&&\"object\"==typeof o&&!Array.isArray(o)){i=!1;var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Zt)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,ee(Wt))))return null;var c=null;if(o[\"text-color\"]&&!(c=e.parse(o[\"text-color\"],1,Xt)))return null;var u=n[n.length-1];u.scale=s,u.font=l,u.textColor=c}else{var h=e.parse(t[a],1,Jt);if(!h)return null;var f=h.type.kind;if(\"string\"!==f&&\"value\"!==f&&\"null\"!==f&&\"resolvedImage\"!==f)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");i=!0,n.push({content:h,scale:null,font:null,textColor:null})}}return new we(n)},we.prototype.evaluate=function(t){return new fe(this.sections.map((function(e){var r=e.content.evaluate(t);return ge(r)===te?new he(\"\",r,null,null,null):new he(ye(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))},we.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.content),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},we.prototype.outputDefined=function(){return!1},we.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.content.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),n.textColor&&(i[\"text-color\"]=n.textColor.serialize()),t.push(i)}return t};var Te=function(t){this.type=te,this.input=t};Te.parse=function(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Wt);return r?new Te(r):e.error(\"No image name provided.\")},Te.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=pe.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r},Te.prototype.eachChild=function(t){t(this.input)},Te.prototype.outputDefined=function(){return!1},Te.prototype.serialize=function(){return[\"image\",this.input.serialize()]};var ke={\"to-boolean\":Yt,\"to-color\":Xt,\"to-number\":Zt,\"to-string\":Wt},Ae=function(t,e){this.type=t,this.args=e};Ae.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ke[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Jt);if(!o)return null;i.push(o)}return new Ae(n,i)},Ae.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ce)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":de(e[0],e[1],e[2],e[3])))return new ce(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new xe(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new xe(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?fe.fromString(ye(this.args[0].evaluate(t))):\"resolvedImage\"===this.type.kind?pe.fromString(ye(this.args[0].evaluate(t))):ye(this.args[0].evaluate(t))},Ae.prototype.eachChild=function(t){this.args.forEach(t)},Ae.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},Ae.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new we([{content:this.args[0],scale:null,font:null,textColor:null}]).serialize();if(\"resolvedImage\"===this.type.kind)return new Te(this.args[0]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild((function(e){t.push(e.serialize())})),t};var Me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Se=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null};Se.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},Se.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?Me[this.feature.type]:this.feature.type:null},Se.prototype.geometry=function(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null},Se.prototype.canonicalID=function(){return this.canonical},Se.prototype.properties=function(){return this.feature&&this.feature.properties||{}},Se.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ce.parse(t)),e};var Ee=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};Ee.prototype.evaluate=function(t){return this._evaluate(t,this.args)},Ee.prototype.eachChild=function(t){this.args.forEach(t)},Ee.prototype.outputDefined=function(){return!1},Ee.prototype.serialize=function(){return[this.name].concat(this.args.map((function(t){return t.serialize()})))},Ee.parse=function(t,e){var r,n=t[0],i=Ee.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter((function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1})),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Je(e.registry,e.path,null,e.scope);for(var d=[],m=!1,g=1;g<t.length;g++){var y=t[g],v=Array.isArray(f)?f[g-1]:f.type,x=l.parse(y,1+d.length,v);if(!x){m=!0;break}d.push(x)}if(!m)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var _=0;_<d.length;_++){var b=Array.isArray(f)?f[_]:f.type,w=d[_];l.concat(_+1).checkSubtype(b,w.type)}if(0===l.errors.length)return new Ee(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var T=(s.length?s:o).map((function(t){return e=t[0],Array.isArray(e)?\"(\"+e.map(re).join(\", \")+\")\":\"(\"+re(e.type)+\"...)\";var e})).join(\" | \"),k=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+k.length);if(!M)return null;k.push(re(M.type))}e.error(\"Expected arguments of type \"+T+\", but found (\"+k.join(\", \")+\") instead.\")}return null},Ee.register=function(t,e){for(var r in Ee.definitions=e,e)t[r]=Ee};var Ce=function(t,e,r){this.type=Kt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};Ce.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Wt))?null:new Ce(n,i,a)},Ce.prototype.evaluate=function(t){return new ue(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},Ce.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},Ce.prototype.outputDefined=function(){return!1},Ce.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Le=8192;function Ie(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function Pe(t,e){return!(t[0]<=e[0]||t[2]>=e[2]||t[1]<=e[1]||t[3]>=e[3])}function ze(t,e){var r,n=(180+t[0])/360,i=(r=t[1],(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+r*Math.PI/360)))/360),a=Math.pow(2,e.z);return[Math.round(n*a*Le),Math.round(i*a*Le)]}function Oe(t,e,r){return e[1]>t[1]!=r[1]>t[1]&&t[0]<(r[0]-e[0])*(t[1]-e[1])/(r[1]-e[1])+e[0]}function De(t,e){for(var r=!1,n=0,i=e.length;n<i;n++)for(var a=e[n],o=0,s=a.length;o<s-1;o++){if(l=t,c=a[o],u=a[o+1],h=void 0,f=void 0,p=void 0,d=void 0,h=l[0]-c[0],f=l[1]-c[1],p=l[0]-u[0],d=l[1]-u[1],h*d-p*f==0&&h*p<=0&&f*d<=0)return!1;Oe(t,a[o],a[o+1])&&(r=!r)}var l,c,u,h,f,p,d;return r}function Re(t,e){for(var r=0;r<e.length;r++)if(De(t,e[r]))return!0;return!1}function Fe(t,e,r,n){var i=t[0]-r[0],a=t[1]-r[1],o=e[0]-r[0],s=e[1]-r[1],l=n[0]-r[0],c=n[1]-r[1],u=i*c-l*a,h=o*c-l*s;return u>0&&h<0||u<0&&h>0}function Be(t,e,r){for(var n=0,i=r;n<i.length;n+=1)for(var a=i[n],o=0;o<a.length-1;++o)if(s=t,l=e,c=a[o],u=a[o+1],h=void 0,f=void 0,p=void 0,p=[l[0]-s[0],l[1]-s[1]],0!=(h=[u[0]-c[0],u[1]-c[1]],f=p,h[0]*f[1]-h[1]*f[0])&&Fe(s,l,c,u)&&Fe(c,u,s,l))return!0;var s,l,c,u,h,f,p;return!1}function Ne(t,e){for(var r=0;r<t.length;++r)if(!De(t[r],e))return!1;for(var n=0;n<t.length-1;++n)if(Be(t[n],t[n+1],e))return!1;return!0}function je(t,e){for(var r=0;r<e.length;r++)if(Ne(t,e[r]))return!0;return!1}function Ue(t,e,r){for(var n=[],i=0;i<t.length;i++){for(var a=[],o=0;o<t[i].length;o++){var s=ze(t[i][o],r);Ie(e,s),a.push(s)}n.push(a)}return n}function Ve(t,e,r){for(var n=[],i=0;i<t.length;i++){var a=Ue(t[i],e,r);n.push(a)}return n}function qe(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){var i=.5*n,a=t[0]-r[0]>i?-n:r[0]-t[0]>i?n:0;0===a&&(a=t[0]-r[2]>i?-n:r[2]-t[0]>i?n:0),t[0]+=a}Ie(e,t)}function He(t,e,r,n){for(var i=Math.pow(2,n.z)*Le,a=[n.x*Le,n.y*Le],o=[],s=0,l=t;s<l.length;s+=1)for(var c=0,u=l[s];c<u.length;c+=1){var h=u[c],f=[h.x+a[0],h.y+a[1]];qe(f,e,r,i),o.push(f)}return o}function Ge(t,e,r,n){for(var i=Math.pow(2,n.z)*Le,a=[n.x*Le,n.y*Le],o=[],s=0,l=t;s<l.length;s+=1){for(var c=[],u=0,h=l[s];u<h.length;u+=1){var f=h[u],p=[f.x+a[0],f.y+a[1]];Ie(e,p),c.push(p)}o.push(c)}if(e[2]-e[0]<=i/2){(v=e)[0]=v[1]=1/0,v[2]=v[3]=-1/0;for(var d=0,m=o;d<m.length;d+=1)for(var g=0,y=m[d];g<y.length;g+=1)qe(y[g],e,r,i)}var v;return o}var Ze=function(t,e){this.type=Yt,this.geojson=t,this.geometries=e};function We(t){if(t instanceof Ee){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof Ze)return!1;var e=!0;return t.eachChild((function(t){e&&!We(t)&&(e=!1)})),e}function Ye(t){if(t instanceof Ee&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild((function(t){e&&!Ye(t)&&(e=!1)})),e}function Xe(t,e){if(t instanceof Ee&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild((function(t){r&&!Xe(t,e)&&(r=!1)})),r}Ze.parse=function(t,e){if(2!==t.length)return e.error(\"'within' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(me(t[1])){var r=t[1];if(\"FeatureCollection\"===r.type)for(var n=0;n<r.features.length;++n){var i=r.features[n].geometry.type;if(\"Polygon\"===i||\"MultiPolygon\"===i)return new Ze(r,r.features[n].geometry)}else if(\"Feature\"===r.type){var a=r.geometry.type;if(\"Polygon\"===a||\"MultiPolygon\"===a)return new Ze(r,r.geometry)}else if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type)return new Ze(r,r)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")},Ze.prototype.evaluate=function(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ue(e.coordinates,n,i),o=He(t.geometry(),r,n,i);if(!Pe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!De(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ve(e.coordinates,n,i),u=He(t.geometry(),r,n,i);if(!Pe(r,n))return!1;for(var h=0,f=u;h<f.length;h+=1)if(!Re(f[h],c))return!1}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ue(e.coordinates,n,i),o=Ge(t.geometry(),r,n,i);if(!Pe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!Ne(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ve(e.coordinates,n,i),u=Ge(t.geometry(),r,n,i);if(!Pe(r,n))return!1;for(var h=0,f=u;h<f.length;h+=1)if(!je(f[h],c))return!1}return!0}(t,this.geometries)}return!1},Ze.prototype.eachChild=function(){},Ze.prototype.outputDefined=function(){return!0},Ze.prototype.serialize=function(){return[\"within\",this.geojson]};var $e=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};$e.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new $e(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},$e.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},$e.prototype.eachChild=function(){},$e.prototype.outputDefined=function(){return!1},$e.prototype.serialize=function(){return[\"var\",this.name]};var Je=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Ht),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map((function(t){return\"[\"+t+\"]\"})).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Ke(t){if(t instanceof $e)return Ke(t.boundExpression);if(t instanceof Ee&&\"error\"===t.name)return!1;if(t instanceof Ce)return!1;if(t instanceof Ze)return!1;var e=t instanceof Ae||t instanceof be,r=!0;return t.eachChild((function(t){r=e?r&&Ke(t):r&&t instanceof ve})),!!r&&We(t)&&Xe(t,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}function Qe(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new xe(\"Input is not a number.\");o=s-1}return 0}Je.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Je.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new be(e,[t]):\"coerce\"===r?new Ae(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind&&\"resolvedImage\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ve)&&\"resolvedImage\"!==a.type.kind&&Ke(a)){var l=new Se;try{a=new ve(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Je.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Je(this.registry,n,e||null,i,this.errors)},Je.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map((function(t){return\"[\"+t+\"]\"})).join(\"\");this.errors.push(new qt(n,t))},Je.prototype.checkSubtype=function(t,e){var r=ie(t,e);return r&&this.error(r),r};var tr=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function er(t,e,r){return t*(1-r)+e*r}tr.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Zt);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new tr(i,r,n)},tr.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Qe(e,n)].evaluate(t)},tr.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},tr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},tr.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var rr=Object.freeze({__proto__:null,number:er,color:function(t,e,r){return new ce(er(t.r,e.r,r),er(t.g,e.g,r),er(t.b,e.b,r),er(t.a,e.a,r))},array:function(t,e,r){return t.map((function(t,n){return er(t,e[n],r)}))}}),nr=.95047,ir=1,ar=1.08883,or=4/29,sr=6/29,lr=3*sr*sr,cr=sr*sr*sr,ur=Math.PI/180,hr=180/Math.PI;function fr(t){return t>cr?Math.pow(t,1/3):t/lr+or}function pr(t){return t>sr?t*t*t:lr*(t-or)}function dr(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function mr(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function gr(t){var e=mr(t.r),r=mr(t.g),n=mr(t.b),i=fr((.4124564*e+.3575761*r+.1804375*n)/nr),a=fr((.2126729*e+.7151522*r+.072175*n)/ir);return{l:116*a-16,a:500*(i-a),b:200*(a-fr((.0193339*e+.119192*r+.9503041*n)/ar)),alpha:t.a}}function yr(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=ir*pr(e),r=nr*pr(r),n=ar*pr(n),new ce(dr(3.2404542*r-1.5371385*e-.4985314*n),dr(-.969266*r+1.8760108*e+.041556*n),dr(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function vr(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var xr={forward:gr,reverse:yr,interpolate:function(t,e,r){return{l:er(t.l,e.l,r),a:er(t.a,e.a,r),b:er(t.b,e.b,r),alpha:er(t.alpha,e.alpha,r)}}},_r={forward:function(t){var e=gr(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*hr;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*ur,r=t.c;return yr({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:vr(t.h,e.h,r),c:er(t.c,e.c,r),l:er(t.l,e.l,r),alpha:er(t.alpha,e.alpha,r)}}},br=Object.freeze({__proto__:null,lab:xr,hcl:_r}),wr=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Tr(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}wr.interpolationFactor=function(t,e,r,i){var a=0;if(\"exponential\"===t.name)a=Tr(e,t.base,r,i);else if(\"linear\"===t.name)a=Tr(e,1,r,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new n(o[0],o[1],o[2],o[3]).solve(Tr(e,1,r,i))}return a},wr.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some((function(t){return\"number\"!=typeof t||t<0||t>1})))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Zt)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Xt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var m=e.parse(f,d,c);if(!m)return null;c=c||m.type,l.push([h,m])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new wr(c,r,n,i,l):e.error(\"Type \"+re(c)+\" is not interpolatable.\")},wr.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Qe(e,n),o=e[a],s=e[a+1],l=wr.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?rr[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?_r.reverse(_r.interpolate(_r.forward(c),_r.forward(u),l)):xr.reverse(xr.interpolate(xr.forward(c),xr.forward(u),l))},wr.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},wr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},wr.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var kr=function(t,e){this.type=t,this.args=e};kr.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some((function(t){return ie(n,t.type)}));return new kr(c?Jt:r,i)},kr.prototype.evaluate=function(t){for(var e,r=null,n=0,i=0,a=this.args;i<a.length&&(n++,(r=a[i].evaluate(t))&&r instanceof pe&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null===r);i+=1);return r},kr.prototype.eachChild=function(t){this.args.forEach(t)},kr.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},kr.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Ar=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ar.prototype.evaluate=function(t){return this.result.evaluate(t)},Ar.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ar.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ar(r,o):null},Ar.prototype.outputDefined=function(){return this.result.outputDefined()},Ar.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var Mr=function(t,e,r){this.type=t,this.index=e,this.input=r};Mr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Zt),n=e.parse(t[2],2,ee(e.expectedType||Jt));if(!r||!n)return null;var i=n.type;return new Mr(i.itemType,r,n)},Mr.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new xe(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new xe(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new xe(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},Mr.prototype.eachChild=function(t){t(this.index),t(this.input)},Mr.prototype.outputDefined=function(){return!1},Mr.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Sr=function(t,e){this.type=Yt,this.needle=t,this.haystack=e};Sr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Jt),n=e.parse(t[2],2,Jt);return r&&n?ae(r.type,[Yt,Wt,Zt,Gt,Jt])?new Sr(r,n):e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+re(r.type)+\" instead\"):null},Sr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!oe(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new xe(\"Expected first argument to be of type boolean, string, number or null, but found \"+re(ge(e))+\" instead.\");if(!oe(r,[\"string\",\"array\"]))throw new xe(\"Expected second argument to be of type array or string, but found \"+re(ge(r))+\" instead.\");return r.indexOf(e)>=0},Sr.prototype.eachChild=function(t){t(this.needle),t(this.haystack)},Sr.prototype.outputDefined=function(){return!0},Sr.prototype.serialize=function(){return[\"in\",this.needle.serialize(),this.haystack.serialize()]};var Er=function(t,e,r){this.type=Zt,this.needle=t,this.haystack=e,this.fromIndex=r};Er.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Jt),n=e.parse(t[2],2,Jt);if(!r||!n)return null;if(!ae(r.type,[Yt,Wt,Zt,Gt,Jt]))return e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+re(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Zt);return i?new Er(r,n,i):null}return new Er(r,n)},Er.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!oe(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new xe(\"Expected first argument to be of type boolean, string, number or null, but found \"+re(ge(e))+\" instead.\");if(!oe(r,[\"string\",\"array\"]))throw new xe(\"Expected second argument to be of type array or string, but found \"+re(ge(r))+\" instead.\");if(this.fromIndex){var n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)},Er.prototype.eachChild=function(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)},Er.prototype.outputDefined=function(){return!1},Er.prototype.serialize=function(){if(null!=this.fromIndex&&void 0!==this.fromIndex){var t=this.fromIndex.serialize();return[\"index-of\",this.needle.serialize(),this.haystack.serialize(),t]}return[\"index-of\",this.needle.serialize(),this.haystack.serialize()]};var Cr=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Cr.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,ge(f)))return null}else r=ge(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Jt);if(!d)return null;var m=e.parse(t[t.length-1],t.length-1,n);return m?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Cr(r,n,d,i,a,m):null},Cr.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(ge(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Cr.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Cr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))&&this.otherwise.outputDefined()},Cr.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var Lr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};Lr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new Lr(r,n,s):null},Lr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},Lr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},Lr.prototype.outputDefined=function(){return this.branches.every((function(t){return t[0],t[1].outputDefined()}))&&this.otherwise.outputDefined()},Lr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Ir=function(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n};function Pr(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function zr(t,e,r,n){return 0===n.compare(e,r)}function Or(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Jt);if(!a)return null;if(!Pr(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+re(a.type)+\"'.\");var o=e.parse(t[2],2,Jt);if(!o)return null;if(!Pr(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+re(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+re(a.type)+\"' and '\"+re(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new be(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new be(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Kt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=ge(a),l=ge(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new xe('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=ge(a),u=ge(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.outputDefined=function(){return!0},i.prototype.serialize=function(){var e=[t];return this.eachChild((function(t){e.push(t.serialize())})),e},i}()}Ir.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Jt),n=e.parse(t[2],2,Zt);if(!r||!n)return null;if(!ae(r.type,[ee(Jt),Wt,Jt]))return e.error(\"Expected first argument to be of type array or string, but found \"+re(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Zt);return i?new Ir(r.type,r,n,i):null}return new Ir(r.type,r,n)},Ir.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!oe(e,[\"string\",\"array\"]))throw new xe(\"Expected first argument to be of type array or string, but found \"+re(ge(e))+\" instead.\");if(this.endIndex){var n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)},Ir.prototype.eachChild=function(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)},Ir.prototype.outputDefined=function(){return!1},Ir.prototype.serialize=function(){if(null!=this.endIndex&&void 0!==this.endIndex){var t=this.endIndex.serialize();return[\"slice\",this.input.serialize(),this.beginIndex.serialize(),t]}return[\"slice\",this.input.serialize(),this.beginIndex.serialize()]};var Dr=Or(\"==\",(function(t,e,r){return e===r}),zr),Rr=Or(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!zr(0,e,r,n)})),Fr=Or(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),Br=Or(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),Nr=Or(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),jr=Or(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0})),Ur=function(t,e,r,n,i){this.type=Wt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};Ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Zt);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Wt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Wt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Zt)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Zt))?null:new Ur(r,i,a,o,s)},Ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},Ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},Ur.prototype.outputDefined=function(){return!1},Ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var Vr=function(t){this.type=Zt,this.input=t};Vr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+re(r.type)+\" instead.\"):new Vr(r):null},Vr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new xe(\"Expected value to be of type string or array, but found \"+re(ge(e))+\" instead.\")},Vr.prototype.eachChild=function(t){t(this.input)},Vr.prototype.outputDefined=function(){return!1},Vr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var qr={\"==\":Dr,\"!=\":Rr,\">\":Br,\"<\":Fr,\">=\":jr,\"<=\":Nr,array:be,at:Mr,boolean:be,case:Lr,coalesce:kr,collator:Ce,format:we,image:Te,in:Sr,\"index-of\":Er,interpolate:wr,\"interpolate-hcl\":wr,\"interpolate-lab\":wr,length:Vr,let:Ar,literal:ve,match:Cr,number:be,\"number-format\":Ur,object:be,slice:Ir,step:tr,string:be,\"to-boolean\":Ae,\"to-color\":Ae,\"to-number\":Ae,\"to-string\":Ae,var:$e,within:Ze};function Hr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=de(r,n,i,o);if(s)throw new xe(s);return new ce(r/255*o,n/255*o,i/255*o,o)}function Gr(t,e){return t in e}function Zr(t,e){var r=e[t];return void 0===r?null:r}function Wr(t){return{type:t}}function Yr(t){return{result:\"success\",value:t}}function Xr(t){return{result:\"error\",value:t}}function $r(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function Jr(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function Kr(t){return!!t.expression&&t.expression.interpolated}function Qr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function tn(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function en(t){return t}function rn(t,e){var r,n,i,a=\"color\"===e.type,o=t.stops&&\"object\"==typeof t.stops[0][0],s=o||void 0!==t.property,l=o||!s,c=t.type||(Kr(e)?\"exponential\":\"interval\");if(a&&((t=jt({},t)).stops&&(t.stops=t.stops.map((function(t){return[t[0],ce.parse(t[1])]}))),t.default?t.default=ce.parse(t.default):t.default=ce.parse(e.default)),t.colorSpace&&\"rgb\"!==t.colorSpace&&!br[t.colorSpace])throw new Error(\"Unknown color space: \"+t.colorSpace);if(\"exponential\"===c)r=sn;else if(\"interval\"===c)r=on;else if(\"categorical\"===c){r=an,n=Object.create(null);for(var u=0,h=t.stops;u<h.length;u+=1){var f=h[u];n[f[0]]=f[1]}i=typeof t.stops[0][0]}else{if(\"identity\"!==c)throw new Error('Unknown function type \"'+c+'\"');r=ln}if(o){for(var p={},d=[],m=0;m<t.stops.length;m++){var g=t.stops[m],y=g[0].zoom;void 0===p[y]&&(p[y]={zoom:y,type:t.type,property:t.property,default:t.default,stops:[]},d.push(y)),p[y].stops.push([g[0].value,g[1]])}for(var v=[],x=0,_=d;x<_.length;x+=1){var b=_[x];v.push([p[b].zoom,rn(p[b],e)])}var w={name:\"linear\"};return{kind:\"composite\",interpolationType:w,interpolationFactor:wr.interpolationFactor.bind(void 0,w),zoomStops:v.map((function(t){return t[0]})),evaluate:function(r,n){var i=r.zoom;return sn({stops:v,base:t.base},e,i).evaluate(i,n)}}}if(l){var T=\"exponential\"===c?{name:\"exponential\",base:void 0!==t.base?t.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:wr.interpolationFactor.bind(void 0,T),zoomStops:t.stops.map((function(t){return t[0]})),evaluate:function(a){var o=a.zoom;return r(t,e,o,n,i)}}}return{kind:\"source\",evaluate:function(a,o){var s=o&&o.properties?o.properties[t.property]:void 0;return void 0===s?nn(t.default,e.default):r(t,e,s,n,i)}}}function nn(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function an(t,e,r,n,i){return nn(typeof r===i?n[r]:void 0,t.default,e.default)}function on(t,e,r){if(\"number\"!==Qr(r))return nn(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Qe(t.stops.map((function(t){return t[0]})),r);return t.stops[i][1]}function sn(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==Qr(r))return nn(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Qe(t.stops.map((function(t){return t[0]})),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=rr[e.type]||en;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=br[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function ln(t,e,r){return\"color\"===e.type?r=ce.parse(r):\"formatted\"===e.type?r=fe.fromString(r.toString()):\"resolvedImage\"===e.type?r=pe.fromString(r.toString()):Qr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),nn(r,t.default,e.default)}Ee.register(qr,{error:[{kind:\"error\"},[Wt],function(t,e){var r=e[0];throw new xe(r.evaluate(t))}],typeof:[Wt,[Jt],function(t,e){return re(ge(e[0].evaluate(t)))}],\"to-rgba\":[ee(Zt,4),[Xt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Xt,[Zt,Zt,Zt],Hr],rgba:[Xt,[Zt,Zt,Zt,Zt],Hr],has:{type:Yt,overloads:[[[Wt],function(t,e){return Gr(e[0].evaluate(t),t.properties())}],[[Wt,$t],function(t,e){var r=e[0],n=e[1];return Gr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Jt,overloads:[[[Wt],function(t,e){return Zr(e[0].evaluate(t),t.properties())}],[[Wt,$t],function(t,e){var r=e[0],n=e[1];return Zr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Jt,[Wt],function(t,e){return Zr(e[0].evaluate(t),t.featureState||{})}],properties:[$t,[],function(t){return t.properties()}],\"geometry-type\":[Wt,[],function(t){return t.geometryType()}],id:[Jt,[],function(t){return t.id()}],zoom:[Zt,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Zt,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Zt,[],function(t){return t.globals.lineProgress||0}],accumulated:[Jt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Zt,Wr(Zt),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Zt,Wr(Zt),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Zt,overloads:[[[Zt,Zt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Zt],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Zt,[Zt,Zt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Zt,[Zt,Zt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Zt,[],function(){return Math.LN2}],pi:[Zt,[],function(){return Math.PI}],e:[Zt,[],function(){return Math.E}],\"^\":[Zt,[Zt,Zt],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Zt,[Zt],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Zt,[Zt],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Zt,[Zt],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Zt,[Zt],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Zt,[Zt],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Zt,[Zt],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Zt,[Zt],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Zt,[Zt],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Zt,[Zt],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Zt,[Zt],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Zt,Wr(Zt),function(t,e){return Math.min.apply(Math,e.map((function(e){return e.evaluate(t)})))}],max:[Zt,Wr(Zt),function(t,e){return Math.max.apply(Math,e.map((function(e){return e.evaluate(t)})))}],abs:[Zt,[Zt],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Zt,[Zt],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Zt,[Zt],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Zt,[Zt],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Wt,Jt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Jt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Wt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Wt,Jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Wt,Jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Wt,Jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Wt,Jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Jt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()&&void 0!==t.id()}],\"filter-type-in\":[Yt,[ee(Wt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[ee(Jt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Wt,ee(Jt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Wt,ee(Jt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[Wr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[Wr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Wt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Wt,[Wt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Wt,[Wt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Wt,Wr(Jt),function(t,e){return e.map((function(e){return ye(e.evaluate(t))})).join(\"\")}],\"resolved-locale\":[Wt,[Kt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var cn=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new Se,this._defaultValue=e?function(t){return\"color\"===t.type&&tn(t.default)?new ce(0,0,0,0):\"color\"===t.type?ce.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function un(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in qr}function hn(t,e){var r=new Je(qr,[],e?function(t){var e={color:Xt,string:Wt,number:Zt,enum:Wt,boolean:Yt,formatted:Qt,resolvedImage:te};return\"array\"===t.type?ee(e[t.value]||Jt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?Yr(new cn(n,e)):Xr(r.errors)}cn.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a,this.expression.evaluate(this._evaluator)},cn.prototype.evaluate=function(t,e,r,n,i,a){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a||null;try{var o=this.expression.evaluate(this._evaluator);if(null==o||\"number\"==typeof o&&o!=o)return this._defaultValue;if(this._enumValues&&!(o in this._enumValues))throw new xe(\"Expected value to be one of \"+Object.keys(this._enumValues).map((function(t){return JSON.stringify(t)})).join(\", \")+\", but found \"+JSON.stringify(o)+\" instead.\");return o}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var fn=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!Ye(e.expression)};fn.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},fn.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)};var pn=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!Ye(e.expression),this.interpolationType=n};function dn(t,e){if(\"error\"===(t=hn(t,e)).result)return t;var r=t.value.expression,n=We(r);if(!n&&!$r(e))return Xr([new qt(\"\",\"data expressions not supported\")]);var i=Xe(r,[\"zoom\"]);if(!i&&!Jr(e))return Xr([new qt(\"\",\"zoom expressions not supported\")]);var a=gn(r);if(!a&&!i)return Xr([new qt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')]);if(a instanceof qt)return Xr([a]);if(a instanceof wr&&!Kr(e))return Xr([new qt(\"\",'\"interpolate\" expressions cannot be used with this property')]);if(!a)return Yr(new fn(n?\"constant\":\"source\",t.value));var o=a instanceof wr?a.interpolation:void 0;return Yr(new pn(n?\"camera\":\"composite\",t.value,a.labels,o))}pn.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},pn.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)},pn.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?wr.interpolationFactor(this.interpolationType,t,e,r):0};var mn=function(t,e){this._parameters=t,this._specification=e,jt(this,rn(this._parameters,this._specification))};function gn(t){var e=null;if(t instanceof Ar)e=gn(t.result);else if(t instanceof kr)for(var r=0,n=t.args;r<n.length;r+=1){var i=n[r];if(e=gn(i))break}else(t instanceof tr||t instanceof wr)&&t.input instanceof Ee&&\"zoom\"===t.input.name&&(e=t);return e instanceof qt||t.eachChild((function(t){var r=gn(t);r instanceof qt?e=r:!e&&r?e=new qt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):e&&r&&e!==r&&(e=new qt(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),e}function yn(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=Qr(r);if(\"object\"!==l)return[new Bt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=Hn;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Bt(e,r[c],'unknown property \"'+c+'\"'));continue}f=Hn}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Bt(e,r,'missing required property \"'+p+'\"'));return s}function vn(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||Hn;if(\"array\"!==Qr(e))return[new Bt(a,e,\"array expected, \"+Qr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Bt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Bt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===Qr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function xn(t){var e=t.key,r=t.value,n=t.valueSpec,i=Qr(r);return\"number\"===i&&r!=r&&(i=\"NaN\"),\"number\"!==i?[new Bt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Bt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Bt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function _n(t){var e,r,n,i=t.valueSpec,a=Ut(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===Qr(t.value.stops)&&\"array\"===Qr(t.value.stops[0])&&\"object\"===Qr(t.value.stops[0][0]),u=yn({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Bt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(vn({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===Qr(r)&&0===r.length&&e.push(new Bt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return Hn({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Bt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Bt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!Kr(t.valueSpec)&&u.push(new Bt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!$r(t.valueSpec)?u.push(new Bt(t.key,t.value,\"property functions not supported\")):s&&!Jr(t.valueSpec)&&u.push(new Bt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Bt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==Qr(a))return[new Bt(s,a,\"array expected, \"+Qr(a)+\" found\")];if(2!==a.length)return[new Bt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==Qr(a[0]))return[new Bt(s,a,\"object expected, \"+Qr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Bt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Bt(s,a,\"object stop key must have value\")];if(n&&n>Ut(a[0].zoom))return[new Bt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Ut(a[0].zoom)!==n&&(n=Ut(a[0].zoom),r=void 0,o={}),e=e.concat(yn({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:xn,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return un(Vt(a[1]))?e.concat([new Bt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(Hn({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=Qr(t.value),l=Ut(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Bt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Bt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return $r(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Bt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Bt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Bt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Bt(t.key,c,\"integer expected, found \"+l)]}}function bn(t){var e=(\"property\"===t.expressionContext?dn:hn)(Vt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((function(e){return new Bt(\"\"+t.key+e.key,t.value,e.message)}));var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new Bt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!Ye(r))return[new Bt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!Ye(r))return[new Bt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!Xe(r,[\"zoom\",\"feature-state\"]))return[new Bt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!We(r))return[new Bt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function wn(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Ut(r))&&i.push(new Bt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Ut(r))&&i.push(new Bt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function Tn(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!Tn(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}mn.deserialize=function(t){return new mn(t._parameters,t._specification)},mn.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var kn={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function An(t){if(null==t)return{filter:function(){return!0},needGeometry:!1};Tn(t)||(t=En(t));var e=hn(t,kn);if(\"error\"===e.result)throw new Error(e.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return{filter:function(t,r,n){return e.value.evaluate(t,r,{},n)},needGeometry:Sn(t)}}function Mn(t,e){return t<e?-1:t>e?1:0}function Sn(t){if(!Array.isArray(t))return!1;if(\"within\"===t[0])return!0;for(var e=1;e<t.length;e++)if(Sn(t[e]))return!0;return!1}function En(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Cn(t[1],t[2],\"==\"):\"!=\"===r?Pn(Cn(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Cn(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(En))):\"all\"===r?[\"all\"].concat(t.slice(1).map(En)):\"none\"===r?[\"all\"].concat(t.slice(1).map(En).map(Pn)):\"in\"===r?Ln(t[1],t.slice(2)):\"!in\"===r?Pn(Ln(t[1],t.slice(2))):\"has\"===r?In(t[1]):\"!has\"===r?Pn(In(t[1])):\"within\"!==r||t}function Cn(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Ln(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((function(t){return typeof t!=typeof e[0]}))?[\"filter-in-large\",t,[\"literal\",e.sort(Mn)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function In(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Pn(t){return[\"!\",t]}function zn(t){return Tn(Vt(t.value))?bn(jt({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):On(t)}function On(t){var e=t.value,r=t.key;if(\"array\"!==Qr(e))return[new Bt(r,e,\"array expected, \"+Qr(e)+\" found\")];var n,i=t.styleSpec,a=[];if(e.length<1)return[new Bt(r,e,\"filter array must have at least 1 element\")];switch(a=a.concat(wn({key:r+\"[0]\",value:e[0],valueSpec:i.filter_operator,style:t.style,styleSpec:t.styleSpec})),Ut(e[0])){case\"<\":case\"<=\":case\">\":case\">=\":e.length>=2&&\"$type\"===Ut(e[1])&&a.push(new Bt(r,e,'\"$type\" cannot be use with operator \"'+e[0]+'\"'));case\"==\":case\"!=\":3!==e.length&&a.push(new Bt(r,e,'filter array for operator \"'+e[0]+'\" must have 3 elements'));case\"in\":case\"!in\":e.length>=2&&\"string\"!==(n=Qr(e[1]))&&a.push(new Bt(r+\"[1]\",e[1],\"string expected, \"+n+\" found\"));for(var o=2;o<e.length;o++)n=Qr(e[o]),\"$type\"===Ut(e[1])?a=a.concat(wn({key:r+\"[\"+o+\"]\",value:e[o],valueSpec:i.geometry_type,style:t.style,styleSpec:t.styleSpec})):\"string\"!==n&&\"number\"!==n&&\"boolean\"!==n&&a.push(new Bt(r+\"[\"+o+\"]\",e[o],\"string, number, or boolean expected, \"+n+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var s=1;s<e.length;s++)a=a.concat(On({key:r+\"[\"+s+\"]\",value:e[s],style:t.style,styleSpec:t.styleSpec}));break;case\"has\":case\"!has\":n=Qr(e[1]),2!==e.length?a.push(new Bt(r,e,'filter array for \"'+e[0]+'\" operator must have 2 elements')):\"string\"!==n&&a.push(new Bt(r+\"[1]\",e[1],\"string expected, \"+n+\" found\"));break;case\"within\":n=Qr(e[1]),2!==e.length?a.push(new Bt(r,e,'filter array for \"'+e[0]+'\" operator must have 2 elements')):\"object\"!==n&&a.push(new Bt(r+\"[1]\",e[1],\"object expected, \"+n+\" found\"))}return a}function Dn(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return Hn({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Bt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===Qr(a)&&$r(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Bt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Bt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&tn(Vt(a))&&\"identity\"===Ut(a.type)&&h.push(new Bt(r,a,'\"text-font\" does not support identity functions'))),h.concat(Hn({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function Rn(t){return Dn(t,\"paint\")}function Fn(t){return Dn(t,\"layout\")}function Bn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Bt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Ut(r.type),l=Ut(r.ref);if(r.id)for(var c=Ut(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Ut(h.id)===c&&e.push(new Bt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((function(t){t in r&&e.push(new Bt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))})),i.layers.forEach((function(t){Ut(t.id)===l&&(o=t)})),o?o.ref?e.push(new Bt(n,r.ref,\"ref cannot reference another ref layer\")):s=Ut(o.type):e.push(new Bt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Ut(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Bt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Bt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Bt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Bt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Bt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Bt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Bt(n,r,'missing required property \"source\"'));return e=e.concat(yn({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return Hn({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:zn,layout:function(t){return yn({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return Fn(jt({layerType:s},t))}}})},paint:function(t){return yn({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return Rn(jt({layerType:s},t))}}})}}})),e}function Nn(t){var e=t.value,r=t.key,n=Qr(e);return\"string\"!==n?[new Bt(r,e,\"string expected, \"+n+\" found\")]:[]}var jn={promoteId:function(t){var e=t.key,r=t.value;if(\"string\"===Qr(r))return Nn({key:e,value:r});var n=[];for(var i in r)n.push.apply(n,Nn({key:e+\".\"+i,value:r[i]}));return n}};function Un(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Bt(r,e,'\"type\" is required')];var a,o=Ut(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":return yn({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n,objectElementValidators:jn});case\"geojson\":if(a=yn({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n,objectElementValidators:jn}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=l[1],h=\"string\"==typeof c?[c,[\"accumulated\"],[\"get\",s]]:c;a.push.apply(a,bn({key:r+\".\"+s+\".map\",value:u,expressionContext:\"cluster-map\"})),a.push.apply(a,bn({key:r+\".\"+s+\".reduce\",value:h,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return yn({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return yn({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Bt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return wn({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function Vn(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=Qr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Bt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(Hn({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(Hn({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Bt(s,e[s],'unknown property \"'+s+'\"')])}return a}var qn={\"*\":function(){return[]},array:vn,boolean:function(t){var e=t.value,r=t.key,n=Qr(e);return\"boolean\"!==n?[new Bt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:xn,color:function(t){var e=t.key,r=t.value,n=Qr(r);return\"string\"!==n?[new Bt(e,r,\"color expected, \"+n+\" found\")]:null===le(r)?[new Bt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Nt,enum:wn,filter:zn,function:_n,layer:Bn,object:yn,source:Un,light:Vn,string:Nn,formatted:function(t){return 0===Nn(t).length?[]:bn(t)},resolvedImage:function(t){return 0===Nn(t).length?[]:bn(t)}};function Hn(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&tn(Ut(e))?_n(t):r.expression&&un(Vt(e))?bn(t):r.type&&qn[r.type]?qn[r.type](t):yn(jt({},t,{valueSpec:r.type?n[r.type]:r}))}function Gn(t){var e=t.value,r=t.key,n=Nn(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new Bt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Bt(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function Zn(t,e){void 0===e&&(e=Ft);var r=[];return r=r.concat(Hn({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:Gn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Nt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),Wn(r)}function Wn(t){return[].concat(t).sort((function(t,e){return t.line-e.line}))}function Yn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return Wn(t.apply(this,e))}}Zn.source=Yn(Un),Zn.light=Yn(Vn),Zn.layer=Yn(Bn),Zn.filter=Yn(zn),Zn.paintProperty=Yn(Rn),Zn.layoutProperty=Yn(Fn);var Xn=Zn,$n=Xn.light,Jn=Xn.paintProperty,Kn=Xn.layoutProperty;function Qn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Dt(new Error(a.message))),r=!0}return r}var ti=ri,ei=3;function ri(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[ei+a],s=i[ei+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[ei+n.length],c=i[ei+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}ri.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},ri.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},ri.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},ri.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},ri.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},ri.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},ri.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},ri.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},ri.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=ei+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[ei+o]=a,i.set(s,a),a+=s.length}return i[ei+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[ei+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var ni=s.ImageData,ii=s.ImageBitmap,ai={};function oi(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),ai[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var si in oi(\"Object\",Object),ti.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},ti.deserialize=function(t){return new ti(t.buffer)},oi(\"Grid\",ti),oi(\"Color\",ce),oi(\"Error\",Error),oi(\"ResolvedImage\",pe),oi(\"StylePropertyFunction\",mn),oi(\"StyleExpression\",cn,{omit:[\"_evaluator\"]}),oi(\"ZoomDependentExpression\",pn),oi(\"ZoomConstantExpression\",fn),oi(\"CompoundExpression\",Ee,{omit:[\"_evaluate\"]}),qr)qr[si]._classRegistryKey||oi(\"Expression_\"+si,qr[si]);function li(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function ci(t){return ii&&t instanceof ii}function ui(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(li(t)||ci(t))return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof ni)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(ui(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(ai[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=ai[l].shallow.indexOf(u)>=0?h:ui(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function hi(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||li(t)||ci(t)||ArrayBuffer.isView(t)||t instanceof ni)return t;if(Array.isArray(t))return t.map(hi);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=ai[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=ai[e].shallow.indexOf(o)>=0?s:hi(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var fi=function(){this.first=!0};fi.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var pi={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function di(t){for(var e=0,r=t;e<r.length;e+=1)if(mi(r[e].charCodeAt(0)))return!0;return!1}function mi(t){return!(746!==t&&747!==t&&(t<4352||!(pi[\"Bopomofo Extended\"](t)||pi.Bopomofo(t)||pi[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||pi[\"CJK Compatibility Ideographs\"](t)||pi[\"CJK Compatibility\"](t)||pi[\"CJK Radicals Supplement\"](t)||pi[\"CJK Strokes\"](t)||!(!pi[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||pi[\"CJK Unified Ideographs Extension A\"](t)||pi[\"CJK Unified Ideographs\"](t)||pi[\"Enclosed CJK Letters and Months\"](t)||pi[\"Hangul Compatibility Jamo\"](t)||pi[\"Hangul Jamo Extended-A\"](t)||pi[\"Hangul Jamo Extended-B\"](t)||pi[\"Hangul Jamo\"](t)||pi[\"Hangul Syllables\"](t)||pi.Hiragana(t)||pi[\"Ideographic Description Characters\"](t)||pi.Kanbun(t)||pi[\"Kangxi Radicals\"](t)||pi[\"Katakana Phonetic Extensions\"](t)||pi.Katakana(t)&&12540!==t||!(!pi[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!pi[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||pi[\"Unified Canadian Aboriginal Syllabics\"](t)||pi[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||pi[\"Vertical Forms\"](t)||pi[\"Yijing Hexagram Symbols\"](t)||pi[\"Yi Syllables\"](t)||pi[\"Yi Radicals\"](t))))}function gi(t){return!(mi(t)||function(t){return!!(pi[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||pi[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||pi[\"Letterlike Symbols\"](t)||pi[\"Number Forms\"](t)||pi[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||pi[\"Control Pictures\"](t)&&9251!==t||pi[\"Optical Character Recognition\"](t)||pi[\"Enclosed Alphanumerics\"](t)||pi[\"Geometric Shapes\"](t)||pi[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||pi[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||pi[\"CJK Symbols and Punctuation\"](t)||pi.Katakana(t)||pi[\"Private Use Area\"](t)||pi[\"CJK Compatibility Forms\"](t)||pi[\"Small Form Variants\"](t)||pi[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function yi(t){return pi.Arabic(t)||pi[\"Arabic Supplement\"](t)||pi[\"Arabic Extended-A\"](t)||pi[\"Arabic Presentation Forms-A\"](t)||pi[\"Arabic Presentation Forms-B\"](t)}function vi(t){return t>=1424&&t<=2303||pi[\"Arabic Presentation Forms-A\"](t)||pi[\"Arabic Presentation Forms-B\"](t)}function xi(t,e){return!(!e&&vi(t)||t>=2304&&t<=3583||t>=3840&&t<=4255||pi.Khmer(t))}function _i(t){for(var e=0,r=t;e<r.length;e+=1)if(vi(r[e].charCodeAt(0)))return!0;return!1}var bi=\"deferred\",wi=\"loading\",Ti=\"loaded\",ki=\"error\",Ai=null,Mi=\"unavailable\",Si=null,Ei=function(t){t&&\"string\"==typeof t&&t.indexOf(\"NetworkError\")>-1&&(Mi=ki),Ai&&Ai(t)};function Ci(){Li.fire(new Ot(\"pluginStateChange\",{pluginStatus:Mi,pluginURL:Si}))}var Li=new Rt,Ii=function(){return Mi},Pi=function(){if(Mi!==bi||!Si)throw new Error(\"rtl-text-plugin cannot be downloaded unless a pluginURL is specified\");Mi=wi,Ci(),Si&&Mt({url:Si},(function(t){t?Ei(t):(Mi=Ti,Ci())}))},zi={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Mi===Ti||null!=zi.applyArabicShaping},isLoading:function(){return Mi===wi},setState:function(t){Mi=t.pluginStatus,Si=t.pluginURL},isParsed:function(){return null!=zi.applyArabicShaping&&null!=zi.processBidirectionalText&&null!=zi.processStyledBidirectionalText},getPluginURL:function(){return Si}},Oi=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new fi,this.transition={})};Oi.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!xi(n[r].charCodeAt(0),e))return!1;return!0}(t,zi.isLoaded())},Oi.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Oi.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Di=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(tn(t))return new mn(t,e);if(un(t)){var r=dn(t,e);if(\"error\"===r.result)throw new Error(r.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ce.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Di.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Di.prototype.possiblyEvaluate=function(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)};var Ri=function(t){this.property=t,this.value=new Di(t,void 0)};Ri.prototype.transitioned=function(t,e){return new Bi(this.property,this.value,e,p({},t.transition,this.transition),t.now)},Ri.prototype.untransitioned=function(){return new Bi(this.property,this.value,null,{},0)};var Fi=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Fi.prototype.getValue=function(t){return w(this._values[t].value.value)},Fi.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new Ri(this._values[t].property)),this._values[t].value=new Di(this._values[t].property,null===e?void 0:w(e))},Fi.prototype.getTransition=function(t){return w(this._values[t].transition)},Fi.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new Ri(this._values[t].property)),this._values[t].transition=w(e)||void 0},Fi.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Fi.prototype.transitioned=function(t,e){for(var r=new Ni(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Fi.prototype.untransitioned=function(){for(var t=new Ni(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Bi=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Bi.prototype.possiblyEvaluate=function(t,e,r){var n=t.now||0,i=this.value.possiblyEvaluate(t,e,r),a=this.prior;if(a){if(n>this.end)return this.prior=null,i;if(this.value.isDataDriven())return this.prior=null,i;if(n<this.begin)return a.possiblyEvaluate(t,e,r);var o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(a.possiblyEvaluate(t,e,r),i,function(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}return i};var Ni=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Ni.prototype.possiblyEvaluate=function(t,e,r){for(var n=new Vi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n},Ni.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var ji=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};ji.prototype.getValue=function(t){return w(this._values[t].value)},ji.prototype.setValue=function(t,e){this._values[t]=new Di(this._values[t].property,null===e?void 0:w(e))},ji.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},ji.prototype.possiblyEvaluate=function(t,e,r){for(var n=new Vi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n};var Ui=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Ui.prototype.isConstant=function(){return\"constant\"===this.value.kind},Ui.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Ui.prototype.evaluate=function(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)};var Vi=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Vi.prototype.get=function(t){return this._values[t]};var qi=function(t){this.specification=t};qi.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},qi.prototype.interpolate=function(t,e,r){var n=rr[this.specification.type];return n?n(t,e,r):t};var Hi=function(t,e){this.specification=t,this.overrides=e};Hi.prototype.possiblyEvaluate=function(t,e,r,n){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Ui(this,{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)},e):new Ui(this,t.expression,e)},Hi.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Ui(this,{kind:\"constant\",value:void 0},t.parameters);var n=rr[this.specification.type];return n?new Ui(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Hi.prototype.evaluate=function(t,e,r,n,i,a){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,i,a)};var Gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0===t.value)return new Ui(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n),a=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof i?i.name:i,o=this._calculate(a,a,a,e);return new Ui(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){var s=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Ui(this,{kind:\"constant\",value:s},e)}return new Ui(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n,i,a){if(\"source\"===t.kind){var o=t.evaluate(e,r,n,i,a);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Hi),Zi=function(t){this.specification=t};Zi.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n);return this._calculate(i,i,i,e)}return this._calculate(t.expression.evaluate(new Oi(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Oi(Math.floor(e.zoom),e)),t.expression.evaluate(new Oi(Math.floor(e.zoom+1),e)),e)}},Zi.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Zi.prototype.interpolate=function(t){return t};var Wi=function(t){this.specification=t};Wi.prototype.possiblyEvaluate=function(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)},Wi.prototype.interpolate=function(){return!1};var Yi=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new Di(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new Ri(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};oi(\"DataDrivenProperty\",Hi),oi(\"DataConstantProperty\",qi),oi(\"CrossFadedDataDrivenProperty\",Gi),oi(\"CrossFadedProperty\",Zi),oi(\"ColorRampProperty\",Wi);var Xi=\"-transition\",$i=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter={filter:function(){return!0},needGeometry:!1},\"custom\"!==e.type&&(this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new ji(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Fi(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new Vi(r.paint)}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(Kn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return x(t,Xi)?this._transitionablePaint.getTransition(t.slice(0,-11)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(Jn,n,t,e,r))return!1}if(x(t,Xi))return this._transitionablePaint.setTransition(t.slice(0,-11),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven(),s=i.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var l=this._transitionablePaint._values[t].value;return l.isDataDriven()||o||a||this._handleOverridablePaintPropertyUpdate(t,s,l)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),b(t,(function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)}))},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&Qn(this,t.call(Xn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:Ft,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Ui&&$r(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(Rt),Ji={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},Ki=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},Qi=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function ta(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map((function(t){var i,a=(i=t.type,Ji[i].BYTES_PER_ELEMENT),o=r=ea(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}})),size:ea(r,Math.max(n,e)),alignment:e}}function ea(t,e){return Math.ceil(t/e)*e}Qi.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},Qi.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},Qi.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},Qi.prototype.clear=function(){this.length=0},Qi.prototype.resize=function(t){this.reserve(t),this.length=t},Qi.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},Qi.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(Qi);ra.prototype.bytesPerElement=4,oi(\"StructArrayLayout2i4\",ra);var na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(Qi);na.prototype.bytesPerElement=8,oi(\"StructArrayLayout4i8\",na);var ia=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(Qi);ia.prototype.bytesPerElement=12,oi(\"StructArrayLayout2i4i12\",ia);var aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(Qi);aa.prototype.bytesPerElement=8,oi(\"StructArrayLayout2i4ub8\",aa);var oa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(Qi);oa.prototype.bytesPerElement=8,oi(\"StructArrayLayout2f8\",oa);var sa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c){var u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,i,a,o,s,l,c)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u){var h=10*t;return this.uint16[h+0]=e,this.uint16[h+1]=r,this.uint16[h+2]=n,this.uint16[h+3]=i,this.uint16[h+4]=a,this.uint16[h+5]=o,this.uint16[h+6]=s,this.uint16[h+7]=l,this.uint16[h+8]=c,this.uint16[h+9]=u,t},e}(Qi);sa.prototype.bytesPerElement=20,oi(\"StructArrayLayout10ui20\",sa);var la=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=this.length;return this.resize(f+1),this.emplace(f,t,e,r,n,i,a,o,s,l,c,u,h)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f){var p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=i,this.uint16[p+4]=a,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=h,this.int16[p+11]=f,t},e}(Qi);la.prototype.bytesPerElement=24,oi(\"StructArrayLayout4i4ui4i24\",la);var ca=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(Qi);ca.prototype.bytesPerElement=12,oi(\"StructArrayLayout3f12\",ca);var ua=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(Qi);ua.prototype.bytesPerElement=4,oi(\"StructArrayLayout1ul4\",ua);var ha=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l){var c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,i,a,o,s,l)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c){var u=10*t,h=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=i,this.int16[u+4]=a,this.int16[u+5]=o,this.uint32[h+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t},e}(Qi);ha.prototype.bytesPerElement=20,oi(\"StructArrayLayout6i1ul2ui20\",ha);var fa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(Qi);fa.prototype.bytesPerElement=12,oi(\"StructArrayLayout2i2i2i12\",fa);var pa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n,i)},e.prototype.emplace=function(t,e,r,n,i,a){var o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=i,this.int16[s+7]=a,t},e}(Qi);pa.prototype.bytesPerElement=16,oi(\"StructArrayLayout2f1f2i16\",pa);var da=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(Qi);da.prototype.bytesPerElement=12,oi(\"StructArrayLayout2ub2f12\",da);var ma=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(Qi);ma.prototype.bytesPerElement=6,oi(\"StructArrayLayout3ui6\",ma);var ga=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y){var v=24*t,x=12*t,_=48*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[x+2]=a,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[x+7]=h,this.float32[x+8]=f,this.uint8[_+36]=p,this.uint8[_+37]=d,this.uint8[_+38]=m,this.uint32[x+10]=g,this.int16[v+22]=y,t},e}(Qi);ga.prototype.bytesPerElement=48,oi(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",ga);var ya=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S){var E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S,E){var C=34*t,L=17*t;return this.int16[C+0]=e,this.int16[C+1]=r,this.int16[C+2]=n,this.int16[C+3]=i,this.int16[C+4]=a,this.int16[C+5]=o,this.int16[C+6]=s,this.int16[C+7]=l,this.uint16[C+8]=c,this.uint16[C+9]=u,this.uint16[C+10]=h,this.uint16[C+11]=f,this.uint16[C+12]=p,this.uint16[C+13]=d,this.uint16[C+14]=m,this.uint16[C+15]=g,this.uint16[C+16]=y,this.uint16[C+17]=v,this.uint16[C+18]=x,this.uint16[C+19]=_,this.uint16[C+20]=b,this.uint16[C+21]=w,this.uint16[C+22]=T,this.uint32[L+12]=k,this.float32[L+13]=A,this.float32[L+14]=M,this.float32[L+15]=S,this.float32[L+16]=E,t},e}(Qi);ya.prototype.bytesPerElement=68,oi(\"StructArrayLayout8i15ui1ul4f68\",ya);var va=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(Qi);va.prototype.bytesPerElement=4,oi(\"StructArrayLayout1f4\",va);var xa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(Qi);xa.prototype.bytesPerElement=6,oi(\"StructArrayLayout3i6\",xa);var _a=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(Qi);_a.prototype.bytesPerElement=8,oi(\"StructArrayLayout1ul2ui8\",_a);var ba=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(Qi);ba.prototype.bytesPerElement=4,oi(\"StructArrayLayout2ui4\",ba);var wa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(Qi);wa.prototype.bytesPerElement=2,oi(\"StructArrayLayout1ui2\",wa);var Ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(Qi);Ta.prototype.bytesPerElement=16,oi(\"StructArrayLayout4f16\",Ta);var ka=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.anchorPoint.get=function(){return new a(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(Ki);ka.prototype.size=20;var Aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new ka(this,t)},e}(ha);oi(\"CollisionBoxArray\",Aa);var Ma=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0},associatedIconIndex:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},r.associatedIconIndex.get=function(){return this._structArray.int16[this._pos2+22]},Object.defineProperties(e.prototype,r),e}(Ki);Ma.prototype.size=48;var Sa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ma(this,t)},e}(ga);oi(\"PlacedSymbolArray\",Sa);var Ea=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},placedIconSymbolIndex:{configurable:!0},verticalPlacedIconSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},verticalIconBoxStartIndex:{configurable:!0},verticalIconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},numVerticalIconVertices:{configurable:!0},useRuntimeCollisionCircles:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},textOffset0:{configurable:!0},textOffset1:{configurable:!0},collisionCircleDiameter:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.placedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+6]},r.verticalPlacedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+7]},r.key.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+14]},r.verticalIconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+15]},r.verticalIconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+16]},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+17]},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+18]},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+19]},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+20]},r.numVerticalIconVertices.get=function(){return this._structArray.uint16[this._pos2+21]},r.useRuntimeCollisionCircles.get=function(){return this._structArray.uint16[this._pos2+22]},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+12]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+12]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+13]},r.textOffset0.get=function(){return this._structArray.float32[this._pos4+14]},r.textOffset1.get=function(){return this._structArray.float32[this._pos4+15]},r.collisionCircleDiameter.get=function(){return this._structArray.float32[this._pos4+16]},Object.defineProperties(e.prototype,r),e}(Ki);Ea.prototype.size=68;var Ca=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ea(this,t)},e}(ya);oi(\"SymbolInstanceArray\",Ca);var La=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e}(va);oi(\"GlyphOffsetArray\",La);var Ia=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e}(xa);oi(\"SymbolLineVertexArray\",Ia);var Pa=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},Object.defineProperties(e.prototype,r),e}(Ki);Pa.prototype.size=8;var za=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pa(this,t)},e}(_a);oi(\"FeatureIndexArray\",za);var Oa=ta([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Da=function(t){void 0===t&&(t=[]),this.segments=t};function Ra(t,e){return 256*(t=h(Math.floor(t),0,255))+h(Math.floor(e),0,255)}Da.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Da.MAX_VERTEX_ARRAY_LENGTH&&k(\"Max vertices per segment is \"+Da.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Da.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Da.prototype.get=function(){return this.segments},Da.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Da.simpleSegment=function(t,e,r,n){return new Da([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Da.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,oi(\"SegmentVector\",Da);var Fa=ta([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint16\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint16\"}]),Ba=e((function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}})),Na=e((function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}})),ja=Ba,Ua=Ba,Va=Na;ja.murmur3=Ua,ja.murmur2=Va;var qa=function(){this.ids=[],this.positions=[],this.indexed=!1};qa.prototype.add=function(t,e,r,n){this.ids.push(Ga(t)),this.positions.push(e,r,n)},qa.prototype.getPositions=function(t){for(var e=Ga(t),r=0,n=this.ids.length-1;r<n;){var i=r+n>>1;this.ids[i]>=e?n=i:r=i+1}for(var a=[];this.ids[r]===e;){var o=this.positions[3*r],s=this.positions[3*r+1],l=this.positions[3*r+2];a.push({index:o,start:s,end:l}),r++}return a},qa.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return Za(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}},qa.deserialize=function(t){var e=new qa;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e};var Ha=Math.pow(2,53)-1;function Ga(t){var e=+t;return!isNaN(e)&&e<=Ha?e:ja(String(t))}function Za(t,e,r,n){for(;r<n;){for(var i=t[r+n>>1],a=r-1,o=n+1;;){do{a++}while(t[a]<i);do{o--}while(t[o]>i);if(a>=o)break;Wa(t,a,o),Wa(e,3*a,3*o),Wa(e,3*a+1,3*o+1),Wa(e,3*a+2,3*o+2)}o-r<n-o?(Za(t,e,r,o),r=o+1):(Za(t,e,o+1,n),n=o)}}function Wa(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}oi(\"FeaturePositionMap\",qa);var Ya=function(t,e){this.gl=t.gl,this.location=e},Xa=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Ya),$a=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Ya),Ja=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Ya),Ka=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Ya),Qa=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Ya),to=function(t){function e(e,r){t.call(this,e,r),this.current=ce.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Ya),eo=new Float32Array(16),ro=function(t){function e(e,r){t.call(this,e,r),this.current=eo}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Ya);function no(t){return[Ra(255*t.r,255*t.g),Ra(255*t.b,255*t.a)]}var io=function(t,e,r){this.value=t,this.uniformNames=e.map((function(t){return\"u_\"+t})),this.type=r};io.prototype.setUniform=function(t,e,r){t.set(r.constantOr(this.value))},io.prototype.getBinding=function(t,e,r){return\"color\"===this.type?new to(t,e):new $a(t,e)};var ao=function(t,e){this.uniformNames=e.map((function(t){return\"u_\"+t})),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1};ao.prototype.setConstantPatternPositions=function(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr},ao.prototype.setUniform=function(t,e,r,n){var i=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;i&&t.set(i)},ao.prototype.getBinding=function(t,e,r){return\"u_pattern\"===r.substr(0,9)?new Qa(t,e):new $a(t,e)};var oo=function(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}})),this.paintVertexArray=new n};oo.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.paintVertexArray.length,o=this.expression.evaluate(new Oi(0),e,{},n,[],i);this.paintVertexArray.resize(t),this._setPaintValue(a,t,o)},oo.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,i)},oo.prototype._setPaintValue=function(t,e,r){if(\"color\"===this.type)for(var n=no(r),i=t;i<e;i++)this.paintVertexArray.emplace(i,n[0],n[1]);else{for(var a=t;a<e;a++)this.paintVertexArray.emplace(a,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}},oo.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oo.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()};var so=function(t,e,r,n,i,a){this.expression=t,this.uniformNames=e.map((function(t){return\"u_\"+t+\"_t\"})),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}})),this.paintVertexArray=new a};so.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.expression.evaluate(new Oi(this.zoom),e,{},n,[],i),o=this.expression.evaluate(new Oi(this.zoom+1),e,{},n,[],i),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,a,o)},so.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:this.zoom},r,n),a=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,i,a)},so.prototype._setPaintValue=function(t,e,r,n){if(\"color\"===this.type)for(var i=no(r),a=no(n),o=t;o<e;o++)this.paintVertexArray.emplace(o,i[0],i[1],a[0],a[1]);else{for(var s=t;s<e;s++)this.paintVertexArray.emplace(s,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}},so.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},so.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},so.prototype.setUniform=function(t,e){var r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=h(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)},so.prototype.getBinding=function(t,e,r){return new $a(t,e)};var lo=function(t,e,r,n,i,a){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=a,this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};lo.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)},lo.prototype.updatePaintArray=function(t,e,r,n,i){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],i)},lo.prototype._setPaintValues=function(t,e,r,n){if(n&&r){var i=r.min,a=r.mid,o=r.max,s=n[i],l=n[a],c=n[o];if(s&&l&&c)for(var u=t;u<e;u++)this.zoomInPaintVertexArray.emplace(u,l.tl[0],l.tl[1],l.br[0],l.br[1],s.tl[0],s.tl[1],s.br[0],s.br[1],l.pixelRatio,s.pixelRatio),this.zoomOutPaintVertexArray.emplace(u,l.tl[0],l.tl[1],l.br[0],l.br[1],c.tl[0],c.tl[1],c.br[0],c.br[1],l.pixelRatio,c.pixelRatio)}},lo.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,Fa.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,Fa.members,this.expression.isStateDependent))},lo.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()};var co=function(t,e,r){this.binders={},this._buffers=[];var n=[];for(var i in t.paint._values)if(r(i)){var a=t.paint.get(i);if(a instanceof Ui&&$r(a.property.specification)){var o=ho(i,t.type),s=a.value,l=a.property.specification.type,c=a.property.useIntegerZoom,u=a.property.specification[\"property-type\"],h=\"cross-faded\"===u||\"cross-faded-data-driven\"===u;if(\"constant\"===s.kind)this.binders[i]=h?new ao(s.value,o):new io(s.value,o,l),n.push(\"/u_\"+i);else if(\"source\"===s.kind||h){var f=fo(i,l,\"source\");this.binders[i]=h?new lo(s,l,c,e,f,t.id):new oo(s,o,l,f),n.push(\"/a_\"+i)}else{var p=fo(i,l,\"composite\");this.binders[i]=new so(s,o,l,c,e,p),n.push(\"/z_\"+i)}}}this.cacheKey=n.sort().join(\"\")};co.prototype.getMaxValue=function(t){var e=this.binders[t];return e instanceof oo||e instanceof so?e.maxValue:0},co.prototype.populatePaintArrays=function(t,e,r,n,i){for(var a in this.binders){var o=this.binders[a];(o instanceof oo||o instanceof so||o instanceof lo)&&o.populatePaintArray(t,e,r,n,i)}},co.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders){var n=this.binders[r];n instanceof ao&&n.setConstantPatternPositions(t,e)}},co.prototype.updatePaintArrays=function(t,e,r,n,i){var a=!1;for(var o in t)for(var s=0,l=e.getPositions(o);s<l.length;s+=1){var c=l[s],u=r.feature(c.index);for(var h in this.binders){var f=this.binders[h];if((f instanceof oo||f instanceof so||f instanceof lo)&&!0===f.expression.isStateDependent){var p=n.paint.get(h);f.expression=p.value,f.updatePaintArray(c.start,c.end,u,t[o],i),a=!0}}}return a},co.prototype.defines=function(){var t=[];for(var e in this.binders){var r=this.binders[e];(r instanceof io||r instanceof ao)&&t.push.apply(t,r.uniformNames.map((function(t){return\"#define HAS_UNIFORM_\"+t})))}return t},co.prototype.getBinderAttributes=function(){var t=[];for(var e in this.binders){var r=this.binders[e];if(r instanceof oo||r instanceof so)for(var n=0;n<r.paintVertexAttributes.length;n++)t.push(r.paintVertexAttributes[n].name);else if(r instanceof lo)for(var i=0;i<Fa.members.length;i++)t.push(Fa.members[i].name)}return t},co.prototype.getBinderUniforms=function(){var t=[];for(var e in this.binders){var r=this.binders[e];if(r instanceof io||r instanceof ao||r instanceof so)for(var n=0,i=r.uniformNames;n<i.length;n+=1){var a=i[n];t.push(a)}}return t},co.prototype.getPaintVertexBuffers=function(){return this._buffers},co.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders){var i=this.binders[n];if(i instanceof io||i instanceof ao||i instanceof so)for(var a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s],s);r.push({name:s,property:n,binding:l})}}}return r},co.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniform(c,n,r.get(l),s)}},co.prototype.updatePaintBuffers=function(t){for(var e in this._buffers=[],this.binders){var r=this.binders[e];if(t&&r instanceof lo){var n=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;n&&this._buffers.push(n)}else(r instanceof oo||r instanceof so)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}},co.prototype.upload=function(t){for(var e in this.binders){var r=this.binders[e];(r instanceof oo||r instanceof so||r instanceof lo)&&r.upload(t)}this.updatePaintBuffers()},co.prototype.destroy=function(){for(var t in this.binders){var e=this.binders[t];(e instanceof oo||e instanceof so||e instanceof lo)&&e.destroy()}};var uo=function(t,e,r){void 0===r&&(r=function(){return!0}),this.programConfigurations={};for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.programConfigurations[a.id]=new co(a,e,r)}this.needsUpload=!1,this._featureMap=new qa,this._bufferOffset=0};function ho(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function fo(t,e,r){var n={color:{source:oa,composite:Ta},number:{source:va,composite:oa}},i=function(t){return{\"line-pattern\":{source:sa,composite:sa},\"fill-pattern\":{source:sa,composite:sa},\"fill-extrusion-pattern\":{source:sa,composite:sa}}[t]}(t);return i&&i[r]||n[e][r]}uo.prototype.populatePaintArrays=function(t,e,r,n,i,a){for(var o in this.programConfigurations)this.programConfigurations[o].populatePaintArrays(t,e,n,i,a);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0},uo.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,this._featureMap,e,o,n)||this.needsUpload}},uo.prototype.get=function(t){return this.programConfigurations[t]},uo.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},uo.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},oi(\"ConstantBinder\",io),oi(\"CrossFadedConstantBinder\",ao),oi(\"SourceExpressionBinder\",oo),oi(\"CrossFadedCompositeBinder\",lo),oi(\"CompositeExpressionBinder\",so),oi(\"ProgramConfiguration\",co,{omit:[\"_buffers\"]}),oi(\"ProgramConfigurationSet\",uo);var po=8192,mo=Math.pow(2,14)-1,go=-mo-1;function yo(t){for(var e=po/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a],s=Math.round(o.x*e),l=Math.round(o.y*e);o.x=h(s,go,mo),o.y=h(l,go,mo),(s<o.x||s>o.x+1||l<o.y||l>o.y+1)&&k(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function vo(t,e){return{type:t.type,id:t.id,properties:t.properties,geometry:e?yo(t):[]}}function xo(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var _o=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ra,this.indexArray=new ma,this.segments=new Da,this.programConfigurations=new uo(t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function bo(t,e){for(var r=0;r<t.length;r++)if(Lo(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Lo(t,e[n]))return!0;return!!Ao(t,e)}function wo(t,e,r){return!!Lo(t,e)||!!So(e,t,r)}function To(t,e){if(1===t.length)return Co(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Lo(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Co(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(Ao(t,e[o]))return!0;return!1}function ko(t,e,r){if(t.length>1){if(Ao(t,e))return!0;for(var n=0;n<e.length;n++)if(So(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(So(t[i],e,r))return!0;return!1}function Ao(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(Mo(n,i,e[a],e[a+1]))return!0;return!1}function Mo(t,e,r,n){return A(t,r,n)!==A(e,r,n)&&A(t,e,r)!==A(t,e,n)}function So(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(Eo(t,e[i-1],e[i])<n)return!0;return!1}function Eo(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Co(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Lo(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Io(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=A(t,e,r[0]);return a!==A(t,e,r[1])||a!==A(t,e,r[2])||a!==A(t,e,r[3])}function Po(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function zo(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Oo(t,e,r,n,i){if(!e[0]&&!e[1])return t;var o=a.convert(e)._mult(i);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}_o.prototype.populate=function(t,e,r){var n=this.layers[0],i=[],a=null;\"circle\"===n.type&&(a=n.layout.get(\"circle-sort-key\"));for(var o=0,s=t;o<s.length;o+=1){var l=s[o],c=l.feature,u=l.id,h=l.index,f=l.sourceLayerIndex,p=this.layers[0]._featureFilter.needGeometry,d=vo(c,p);if(this.layers[0]._featureFilter.filter(new Oi(this.zoom),d,r)){var m=a?a.evaluate(d,{},r):void 0,g={id:u,properties:c.properties,type:c.type,sourceLayerIndex:f,index:h,geometry:p?d.geometry:yo(c),patterns:{},sortKey:m};i.push(g)}}a&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var y=0,v=i;y<v.length;y+=1){var x=v[y],_=x,b=_.geometry,w=_.index,T=_.sourceLayerIndex,k=t[w].feature;this.addFeature(x,b,w,r),e.featureIndex.insert(k,b,w,T,this.index)}},_o.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},_o.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},_o.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},_o.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Oa),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},_o.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},_o.prototype.addFeature=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1)for(var o=0,s=a[i];o<s.length;o+=1){var l=s[o],c=l.x,u=l.y;if(!(c<0||c>=po||u<0||u>=po)){var h=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),f=h.vertexLength;xo(this.layoutVertexArray,c,u,-1,-1),xo(this.layoutVertexArray,c,u,1,-1),xo(this.layoutVertexArray,c,u,1,1),xo(this.layoutVertexArray,c,u,-1,1),this.indexArray.emplaceBack(f,f+1,f+2),this.indexArray.emplaceBack(f,f+3,f+2),h.vertexLength+=4,h.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)},oi(\"CircleBucket\",_o,{omit:[\"layers\"]});var Do=new Yi({\"circle-sort-key\":new Hi(Ft.layout_circle[\"circle-sort-key\"])}),Ro={paint:new Yi({\"circle-radius\":new Hi(Ft.paint_circle[\"circle-radius\"]),\"circle-color\":new Hi(Ft.paint_circle[\"circle-color\"]),\"circle-blur\":new Hi(Ft.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Hi(Ft.paint_circle[\"circle-opacity\"]),\"circle-translate\":new qi(Ft.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new qi(Ft.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new qi(Ft.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new qi(Ft.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Hi(Ft.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Hi(Ft.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Hi(Ft.paint_circle[\"circle-stroke-opacity\"])}),layout:Do},Fo=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Bo(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function No(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],m=e[12],g=e[13],y=e[14],v=e[15],x=r[0],_=r[1],b=r[2],w=r[3];return t[0]=x*n+_*s+b*h+w*m,t[1]=x*i+_*l+b*f+w*g,t[2]=x*a+_*c+b*p+w*y,t[3]=x*o+_*u+b*d+w*v,x=r[4],_=r[5],b=r[6],w=r[7],t[4]=x*n+_*s+b*h+w*m,t[5]=x*i+_*l+b*f+w*g,t[6]=x*a+_*c+b*p+w*y,t[7]=x*o+_*u+b*d+w*v,x=r[8],_=r[9],b=r[10],w=r[11],t[8]=x*n+_*s+b*h+w*m,t[9]=x*i+_*l+b*f+w*g,t[10]=x*a+_*c+b*p+w*y,t[11]=x*o+_*u+b*d+w*v,x=r[12],_=r[13],b=r[14],w=r[15],t[12]=x*n+_*s+b*h+w*m,t[13]=x*i+_*l+b*f+w*g,t[14]=x*a+_*c+b*p+w*y,t[15]=x*o+_*u+b*d+w*v,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)});var jo=No;var Uo,Vo=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t};function qo(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}Uo=new Fo(3),Fo!=Float32Array&&(Uo[0]=0,Uo[1]=0,Uo[2]=0),function(){var t=new Fo(4);Fo!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var Ho=function(t){var e=t[0],r=t[1];return e*e+r*r},Go=(function(){var t=new Fo(2);Fo!=Float32Array&&(t[0]=0,t[1]=0)}(),function(t){function e(e){t.call(this,e,Ro)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new _o(t)},e.prototype.queryRadius=function(t){var e=t;return Po(\"circle-radius\",this,e)+Po(\"circle-stroke-width\",this,e)+zo(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Oo(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return t.map((function(t){return Zo(t,e)}))}(l,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var m=0,g=d[p];m<g.length;m+=1){var y=g[m],v=u?y:Zo(y,s),x=f,_=qo([],[y.x,y.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=_[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/_[3]),wo(h,v,x))return!0}return!1},e}($i));function Zo(t,e){var r=qo([],[t.x,t.y,0,1],e);return new a(r[0]/r[3],r[1]/r[3])}var Wo=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(_o);function Yo(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Xo(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=Yo({},{width:n,height:i},r);$o(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function $o(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}oi(\"HeatmapBucket\",Wo,{omit:[\"layers\"]});var Jo=function(t,e){Yo(this,t,1,e)};Jo.prototype.resize=function(t){Xo(this,t,1)},Jo.prototype.clone=function(){return new Jo({width:this.width,height:this.height},new Uint8Array(this.data))},Jo.copy=function(t,e,r,n,i){$o(t,e,r,n,i,1)};var Ko=function(t,e){Yo(this,t,4,e)};Ko.prototype.resize=function(t){Xo(this,t,4)},Ko.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ko.prototype.clone=function(){return new Ko({width:this.width,height:this.height},new Uint8Array(this.data))},Ko.copy=function(t,e,r,n,i){$o(t,e,r,n,i,4)},oi(\"AlphaImage\",Jo),oi(\"RGBAImage\",Ko);var Qo={paint:new Yi({\"heatmap-radius\":new Hi(Ft.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Hi(Ft.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new qi(Ft.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new Wi(Ft.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new qi(Ft.paint_heatmap[\"heatmap-opacity\"])})};function ts(t){var e={},r=t.resolution||256,n=t.clips?t.clips.length:1,i=t.image||new Ko({width:r,height:n}),a=function(r,n,a){e[t.evaluationKey]=a;var o=t.expression.evaluate(e);i.data[r+n+0]=Math.floor(255*o.r/o.a),i.data[r+n+1]=Math.floor(255*o.g/o.a),i.data[r+n+2]=Math.floor(255*o.b/o.a),i.data[r+n+3]=Math.floor(255*o.a)};if(t.clips)for(var o=0,s=0;o<n;++o,s+=4*r)for(var l=0,c=0;l<r;l++,c+=4){var u=l/(r-1),h=t.clips[o];a(s,c,h.start*(1-u)+h.end*u)}else for(var f=0,p=0;f<r;f++,p+=4)a(0,p,f/(r-1));return i}var es=function(t){function e(e){t.call(this,e,Qo),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Wo(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=ts({expression:t,evaluationKey:\"heatmapDensity\",image:this.colorRamp}),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}($i),rs={paint:new Yi({\"hillshade-illumination-direction\":new qi(Ft.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new qi(Ft.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new qi(Ft.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new qi(Ft.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new qi(Ft.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new qi(Ft.paint_hillshade[\"hillshade-accent-color\"])})},ns=function(t){function e(e){t.call(this,e,rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}($i),is=ta([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,as=ss,os=ss;function ss(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=ls(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=ls(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(xs(o));for(s.sort(ms),i=0;i<s.length;i++)gs(s[i],r),r=cs(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return us(f,p,r,n,i,c),p}function ls(t,e,r,n,i){var a,o;if(i===Ps(t,e,r,n)>0)for(a=e;a<r;a+=n)o=Cs(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=Cs(a,t[a],t[a+1],o);return o&&Ts(o,o.next)&&(Ls(o),o=o.next),o}function cs(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!Ts(n,n.next)&&0!==ws(n.prev,n,n.next))n=n.next;else{if(Ls(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function us(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=vs(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?fs(t,n,i,a):hs(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),Ls(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?us(t=ps(cs(t),e,r),e,r,n,i,a,2):2===o&&ds(t,e,r,n,i,a):us(cs(t),e,r,n,i,a,1);break}}}function hs(t){var e=t.prev,r=t,n=t.next;if(ws(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(_s(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&ws(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function fs(t,e,r,n){var i=t.prev,a=t,o=t.next;if(ws(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=vs(s,l,e,r,n),f=vs(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&_s(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&ws(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&_s(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&ws(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&_s(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&ws(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&_s(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&ws(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ps(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!Ts(i,a)&&ks(i,n,n.next,a)&&Ss(i,a)&&Ss(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),Ls(n),Ls(n.next),n=t=a),n=n.next}while(n!==t);return cs(n)}function ds(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&bs(o,s)){var l=Es(o,s);return o=cs(o,o.next),l=cs(l,l.next),us(o,e,r,n,i,a),void us(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function ms(t,e){return t.x-e.x}function gs(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,h=r.y,f=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&_s(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),Ss(n,t)&&(l<f||l===f&&(n.x>r.x||n.x===r.x&&ys(r,n)))&&(r=n,f=l)),n=n.next}while(n!==c);return r}(t,e)){var r=Es(e,t);cs(e,e.next),cs(r,r.next)}}function ys(t,e){return ws(t.prev,t,e.prev)<0&&ws(e.next,t,t.next)<0}function vs(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function xs(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function _s(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function bs(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&ks(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(Ss(t,e)&&Ss(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(ws(t.prev,t,e.prev)||ws(t,e.prev,e))||Ts(t,e)&&ws(t.prev,t,t.next)>0&&ws(e.prev,e,e.next)>0)}function ws(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function Ts(t,e){return t.x===e.x&&t.y===e.y}function ks(t,e,r,n){var i=Ms(ws(t,e,r)),a=Ms(ws(t,e,n)),o=Ms(ws(r,n,t)),s=Ms(ws(r,n,e));return i!==a&&o!==s||!(0!==i||!As(t,r,e))||!(0!==a||!As(t,n,e))||!(0!==o||!As(r,t,n))||!(0!==s||!As(r,e,n))}function As(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function Ms(t){return t>0?1:t<0?-1:0}function Ss(t,e){return ws(t.prev,t,t.next)<0?ws(t,e,t.next)>=0&&ws(t,t.prev,e)>=0:ws(t,e,t.prev)<0||ws(t,t.next,e)<0}function Es(t,e){var r=new Is(t.i,t.x,t.y),n=new Is(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function Cs(t,e,r,n){var i=new Is(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function Ls(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function Is(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function Ps(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function zs(t,e,r,n,i){Os(t,e,r||0,n||t.length-1,i||Rs)}function Os(t,e,r,n,i){for(;n>r;){if(n-r>600){var a=n-r+1,o=e-r+1,s=Math.log(a),l=.5*Math.exp(2*s/3),c=.5*Math.sqrt(s*l*(a-l)/a)*(o-a/2<0?-1:1);Os(t,e,Math.max(r,Math.floor(e-o*l/a+c)),Math.min(n,Math.floor(e+(a-o)*l/a+c)),i)}var u=t[e],h=r,f=n;for(Ds(t,r,e),i(t[n],u)>0&&Ds(t,r,n);h<f;){for(Ds(t,h,f),h++,f--;i(t[h],u)<0;)h++;for(;i(t[f],u)>0;)f--}0===i(t[r],u)?Ds(t,r,f):Ds(t,++f,n),f<=e&&(r=f+1),e<=f&&(n=f-1)}}function Ds(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Rs(t,e){return t<e?-1:t>e?1:0}function Fs(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=M(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(zs(a[l],e,1,a[l].length-1,Bs),a[l]=a[l].slice(0,e));return a}function Bs(t,e){return e.area-t.area}function Ns(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function js(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{},i.availableImages),h=c.evaluate({zoom:n},r,{},i.availableImages),f=c.evaluate({zoom:n+1},r,{},i.availableImages);u=u&&u.name?u.name:u,h=h&&h.name?h.name:h,f=f&&f.name?f.name:f,a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}ss.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(Ps(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(Ps(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},ss.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},as.default=os;var Us=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new ra,this.indexArray=new ma,this.indexArray2=new ba,this.programConfigurations=new uo(t.layers,t.zoom),this.segments=new Da,this.segments2=new Da,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};Us.prototype.populate=function(t,e,r){this.hasPattern=Ns(\"fill\",this.layers,e);for(var n=this.layers[0].layout.get(\"fill-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,h=s.sourceLayerIndex,f=this.layers[0]._featureFilter.needGeometry,p=vo(l,f);if(this.layers[0]._featureFilter.filter(new Oi(this.zoom),p,r)){var d=n?n.evaluate(p,{},r,e.availableImages):void 0,m={id:c,properties:l.properties,type:l.type,sourceLayerIndex:h,index:u,geometry:f?p.geometry:yo(l),patterns:{},sortKey:d};i.push(m)}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,y=i;g<y.length;g+=1){var v=y[g],x=v,_=x.geometry,b=x.index,w=x.sourceLayerIndex;if(this.hasPattern){var T=js(\"fill\",this.layers,v,this.zoom,e);this.patternFeatures.push(T)}else this.addFeature(v,_,b,r,{});var k=t[b].feature;e.featureIndex.insert(k,_,b,w,this.index)}},Us.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Us.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},Us.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Us.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Us.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,is),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Us.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Us.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Fs(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var h=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray),f=h.vertexLength,p=[],d=[],m=0,g=s;m<g.length;m+=1){var y=g[m];if(0!==y.length){y!==s[0]&&d.push(p.length/2);var v=this.segments2.prepareSegment(y.length,this.layoutVertexArray,this.indexArray2),x=v.vertexLength;this.layoutVertexArray.emplaceBack(y[0].x,y[0].y),this.indexArray2.emplaceBack(x+y.length-1,x),p.push(y[0].x),p.push(y[0].y);for(var _=1;_<y.length;_++)this.layoutVertexArray.emplaceBack(y[_].x,y[_].y),this.indexArray2.emplaceBack(x+_-1,x+_),p.push(y[_].x),p.push(y[_].y);v.vertexLength+=y.length,v.primitiveLength+=y.length}}for(var b=as(p,d),w=0;w<b.length;w+=3)this.indexArray.emplaceBack(f+b[w],f+b[w+1],f+b[w+2]);h.vertexLength+=l,h.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},oi(\"FillBucket\",Us,{omit:[\"layers\",\"patternFeatures\"]});var Vs=new Yi({\"fill-sort-key\":new Hi(Ft.layout_fill[\"fill-sort-key\"])}),qs={paint:new Yi({\"fill-antialias\":new qi(Ft.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Hi(Ft.paint_fill[\"fill-opacity\"]),\"fill-color\":new Hi(Ft.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Hi(Ft.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new qi(Ft.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new qi(Ft.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new Gi(Ft.paint_fill[\"fill-pattern\"])}),layout:Vs},Hs=function(t){function e(e){t.call(this,e,qs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r);var n=this.paint._values[\"fill-outline-color\"];\"constant\"===n.value.kind&&void 0===n.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Us(t)},e.prototype.queryRadius=function(){return zo(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return To(Oo(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}($i),Gs=ta([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Zs=Ws;function Ws(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ys,this,e)}function Ys(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Xs(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Ws.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Ws.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,i=0,o=0,s=0,l=[];t.pos<r;){if(i<=0){var c=t.readVarint();n=7&c,i=c>>3}if(i--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new a(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Ws.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Ws.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Ws.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Xs(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var $s=Js;function Js(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(Ks,this,e),this.length=this._features.length}function Ks(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Qs(t,e,r){if(3===t){var n=new $s(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}Js.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Zs(this._pbf,e,this.extent,this._keys,this._values)};var tl={VectorTile:function(t,e){this.layers=t.readFields(Qs,{},e)},VectorTileFeature:Zs,VectorTileLayer:$s},el=tl.VectorTileFeature.types,rl=Math.pow(2,13);function nl(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*rl)+o,i*rl*2,a*rl*2,Math.round(s))}var il=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ia,this.indexArray=new ma,this.programConfigurations=new uo(t.layers,t.zoom),this.segments=new Da,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function al(t,e){return t.x===e.x&&(t.x<0||t.x>po)||t.y===e.y&&(t.y<0||t.y>po)}il.prototype.populate=function(t,e,r){this.features=[],this.hasPattern=Ns(\"fill-extrusion\",this.layers,e);for(var n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.feature,s=a.id,l=a.index,c=a.sourceLayerIndex,u=this.layers[0]._featureFilter.needGeometry,h=vo(o,u);if(this.layers[0]._featureFilter.filter(new Oi(this.zoom),h,r)){var f={id:s,sourceLayerIndex:c,index:l,geometry:u?h.geometry:yo(o),properties:o.properties,type:o.type,patterns:{}};this.hasPattern?this.features.push(js(\"fill-extrusion\",this.layers,f,this.zoom,e)):this.addFeature(f,f.geometry,l,r,{}),e.featureIndex.insert(o,f.geometry,l,c,this.index,!0)}}},il.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.features;n<i.length;n+=1){var a=i[n],o=a.geometry;this.addFeature(a,o,a.index,e,r)}},il.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},il.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},il.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},il.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Gs),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},il.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},il.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Fs(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var h=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),f=0,p=s;f<p.length;f+=1){var d=p[f];if(0!==d.length&&!((P=d).every((function(t){return t.x<0}))||P.every((function(t){return t.x>po}))||P.every((function(t){return t.y<0}))||P.every((function(t){return t.y>po}))))for(var m=0,g=0;g<d.length;g++){var y=d[g];if(g>=1){var v=d[g-1];if(!al(y,v)){h.vertexLength+4>Da.MAX_VERTEX_ARRAY_LENGTH&&(h=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var x=y.sub(v)._perp()._unit(),_=v.dist(y);m+_>32768&&(m=0),nl(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,0,m),nl(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,1,m),m+=_,nl(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,0,m),nl(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,1,m);var b=h.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),h.vertexLength+=4,h.primitiveLength+=2}}}}if(h.vertexLength+l>Da.MAX_VERTEX_ARRAY_LENGTH&&(h=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray)),\"Polygon\"===el[t.type]){for(var w=[],T=[],k=h.vertexLength,A=0,M=s;A<M.length;A+=1){var S=M[A];if(0!==S.length){S!==s[0]&&T.push(w.length/2);for(var E=0;E<S.length;E++){var C=S[E];nl(this.layoutVertexArray,C.x,C.y,0,0,1,1,0),w.push(C.x),w.push(C.y)}}}for(var L=as(w,T),I=0;I<L.length;I+=3)this.indexArray.emplaceBack(k+L[I],k+L[I+2],k+L[I+1]);h.primitiveLength+=L.length/3,h.vertexLength+=l}}var P;this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},oi(\"FillExtrusionBucket\",il,{omit:[\"layers\",\"features\"]});var ol={paint:new Yi({\"fill-extrusion-opacity\":new qi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Hi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new qi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new qi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new Gi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Hi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Hi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new qi(Ft[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},sl=function(t){function e(e){t.call(this,e,ol)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new il(t)},e.prototype.queryRadius=function(){return zo(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s,l){var c=Oo(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var i=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,n,1];qo(c,c,e),i.push(new a(c[0]/c[3],c[1]/c[3]))}return i}(c,l,0,0),p=function(t,e,r,n){for(var i=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,m=0,g=t;m<g.length;m+=1){for(var y=[],v=[],x=0,_=g[m];x<_.length;x+=1){var b=_[x],w=b.x,T=b.y,k=n[0]*w+n[4]*T+n[12],A=n[1]*w+n[5]*T+n[13],M=n[2]*w+n[6]*T+n[14],S=n[3]*w+n[7]*T+n[15],E=M+c,C=S+u,L=k+h,I=A+f,P=M+p,z=S+d,O=new a((k+s)/C,(A+l)/C);O.z=E/C,y.push(O);var D=new a(L/z,I/z);D.z=P/z,v.push(D)}i.push(y),o.push(v)}return[i,o]}(n,h,u,l);return function(t,e,r){var n=1/0;To(r,e)&&(n=cl(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];bo(r,h)&&(n=Math.min(n,cl(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}($i);function ll(t,e){return t.x*e.x+t.y*e.y}function cl(t,e){if(1===t.length){for(var r,n=0,i=e[n++];!r||i.equals(r);)if(!(r=e[n++]))return 1/0;for(;n<e.length;n++){var a=e[n],o=t[0],s=r.sub(i),l=a.sub(i),c=o.sub(i),u=ll(s,s),h=ll(s,l),f=ll(l,l),p=ll(c,s),d=ll(c,l),m=u*f-h*h,g=(f*p-h*d)/m,y=(u*d-h*p)/m,v=1-g-y,x=i.z*v+r.z*g+a.z*y;if(isFinite(x))return x}return 1/0}for(var _=1/0,b=0,w=e;b<w.length;b+=1){var T=w[b];_=Math.min(_,T.z)}return _}var ul=ta([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,hl=ta([{name:\"a_uv_x\",components:1,type:\"Float32\"},{name:\"a_split_index\",components:1,type:\"Float32\"}]).members,fl=tl.VectorTileFeature.types,pl=Math.cos(Math.PI/180*37.5),dl=Math.pow(2,14)/.5,ml=function(t){var e=this;this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.lineClipsArray=[],this.gradients={},this.layers.forEach((function(t){e.gradients[t.id]={}})),this.layoutVertexArray=new aa,this.layoutVertexArray2=new oa,this.indexArray=new ma,this.programConfigurations=new uo(t.layers,t.zoom),this.segments=new Da,this.maxLineLength=0,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};ml.prototype.populate=function(t,e,r){this.hasPattern=Ns(\"line\",this.layers,e);for(var n=this.layers[0].layout.get(\"line-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,h=s.sourceLayerIndex,f=this.layers[0]._featureFilter.needGeometry,p=vo(l,f);if(this.layers[0]._featureFilter.filter(new Oi(this.zoom),p,r)){var d=n?n.evaluate(p,{},r):void 0,m={id:c,properties:l.properties,type:l.type,sourceLayerIndex:h,index:u,geometry:f?p.geometry:yo(l),patterns:{},sortKey:d};i.push(m)}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,y=i;g<y.length;g+=1){var v=y[g],x=v,_=x.geometry,b=x.index,w=x.sourceLayerIndex;if(this.hasPattern){var T=js(\"line\",this.layers,v,this.zoom,e);this.patternFeatures.push(T)}else this.addFeature(v,_,b,r,{});var k=t[b].feature;e.featureIndex.insert(k,_,b,w,this.index)}},ml.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ml.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},ml.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ml.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ml.prototype.upload=function(t){this.uploaded||(0!==this.layoutVertexArray2.length&&(this.layoutVertexBuffer2=t.createVertexBuffer(this.layoutVertexArray2,hl)),this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ul),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ml.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ml.prototype.lineFeatureClips=function(t){if(t.properties&&t.properties.hasOwnProperty(\"mapbox_clip_start\")&&t.properties.hasOwnProperty(\"mapbox_clip_end\"))return{start:+t.properties.mapbox_clip_start,end:+t.properties.mapbox_clip_end}},ml.prototype.addFeature=function(t,e,r,n,i){var a=this.layers[0].layout,o=a.get(\"line-join\").evaluate(t,{}),s=a.get(\"line-cap\"),l=a.get(\"line-miter-limit\"),c=a.get(\"line-round-limit\");this.lineClips=this.lineFeatureClips(t);for(var u=0,h=e;u<h.length;u+=1){var f=h[u];this.addLine(f,t,o,s,l,c)}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},ml.prototype.addLine=function(t,e,r,n,i,a){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,this.lineClips){this.lineClipsArray.push(this.lineClips);for(var o=0;o<t.length-1;o++)this.totalDistance+=t[o].dist(t[o+1]);this.updateScaledDistance(),this.maxLineLength=Math.max(this.maxLineLength,this.totalDistance)}for(var s=\"Polygon\"===fl[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){\"bevel\"===r&&(i=1.05);var u,h=this.overscaling<=16?15*po/(512*this.overscaling):0,f=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray),p=void 0,d=void 0,m=void 0,g=void 0;this.e1=this.e2=-1,s&&(u=t[l-2],g=t[c].sub(u)._unit()._perp());for(var y=c;y<l;y++)if(!(d=y===l-1?s?t[c+1]:void 0:t[y+1])||!t[y].equals(d)){g&&(m=g),u&&(p=u),u=t[y],g=d?d.sub(u)._unit()._perp():m;var v=(m=m||g).add(g);0===v.x&&0===v.y||v._unit();var x=m.x*g.x+m.y*g.y,_=v.x*g.x+v.y*g.y,b=0!==_?1/_:1/0,w=2*Math.sqrt(2-2*_),T=_<pl&&p&&d,k=m.x*g.y-m.y*g.x>0;if(T&&y>c){var A=u.dist(p);if(A>2*h){var M=u.sub(u.sub(p)._mult(h/A)._round());this.updateDistance(p,M),this.addCurrentVertex(M,m,0,0,f),p=M}}var S=p&&d,E=S?r:s?\"butt\":n;if(S&&\"round\"===E&&(b<a?E=\"miter\":b<=2&&(E=\"fakeround\")),\"miter\"===E&&b>i&&(E=\"bevel\"),\"bevel\"===E&&(b>2&&(E=\"flipbevel\"),b<i&&(E=\"miter\")),p&&this.updateDistance(p,u),\"miter\"===E)v._mult(b),this.addCurrentVertex(u,v,0,0,f);else if(\"flipbevel\"===E){if(b>100)v=g.mult(-1);else{var C=b*m.add(g).mag()/m.sub(g).mag();v._perp()._mult(C*(k?-1:1))}this.addCurrentVertex(u,v,0,0,f),this.addCurrentVertex(u,v.mult(-1),0,0,f)}else if(\"bevel\"===E||\"fakeround\"===E){var L=-Math.sqrt(b*b-1),I=k?L:0,P=k?0:L;if(p&&this.addCurrentVertex(u,m,I,P,f),\"fakeround\"===E)for(var z=Math.round(180*w/Math.PI/20),O=1;O<z;O++){var D=O/z;if(.5!==D){var R=D-.5;D+=D*R*(D-1)*((1.0904+x*(x*(3.55645-1.43519*x)-3.2452))*R*R+(.848013+x*(.215638*x-1.06021)))}var F=g.sub(m)._mult(D)._add(m)._unit()._mult(k?-1:1);this.addHalfVertex(u,F.x,F.y,!1,k,0,f)}d&&this.addCurrentVertex(u,g,-I,-P,f)}else if(\"butt\"===E)this.addCurrentVertex(u,v,0,0,f);else if(\"square\"===E){var B=p?1:-1;this.addCurrentVertex(u,v,B,B,f)}else\"round\"===E&&(p&&(this.addCurrentVertex(u,m,0,0,f),this.addCurrentVertex(u,m,1,1,f,!0)),d&&(this.addCurrentVertex(u,g,-1,-1,f,!0),this.addCurrentVertex(u,g,0,0,f)));if(T&&y<l-1){var N=u.dist(d);if(N>2*h){var j=u.add(d.sub(u)._mult(h/N)._round());this.updateDistance(u,j),this.addCurrentVertex(j,g,0,0,f),u=j}}}}},ml.prototype.addCurrentVertex=function(t,e,r,n,i,a){void 0===a&&(a=!1);var o=e.x+e.y*r,s=e.y-e.x*r,l=-e.x+e.y*n,c=-e.y-e.x*n;this.addHalfVertex(t,o,s,a,!1,r,i),this.addHalfVertex(t,l,c,a,!0,-n,i),this.distance>dl/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,i,a))},ml.prototype.addHalfVertex=function(t,e,r,n,i,a,o){var s=t.x,l=t.y,c=.5*(this.lineClips?this.scaledDistance*(dl-1):this.scaledDistance);if(this.layoutVertexArray.emplaceBack((s<<1)+(n?1:0),(l<<1)+(i?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===a?0:a<0?-1:1)|(63&c)<<2,c>>6),this.lineClips){var u=(this.scaledDistance-this.lineClips.start)/(this.lineClips.end-this.lineClips.start);this.layoutVertexArray2.emplaceBack(u,this.lineClipsArray.length)}var h=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,h),o.primitiveLength++),i?this.e2=h:this.e1=h},ml.prototype.updateScaledDistance=function(){this.scaledDistance=this.lineClips?this.lineClips.start+(this.lineClips.end-this.lineClips.start)*this.distance/this.totalDistance:this.distance},ml.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.updateScaledDistance()},oi(\"LineBucket\",ml,{omit:[\"layers\",\"patternFeatures\"]});var gl=new Yi({\"line-cap\":new qi(Ft.layout_line[\"line-cap\"]),\"line-join\":new Hi(Ft.layout_line[\"line-join\"]),\"line-miter-limit\":new qi(Ft.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new qi(Ft.layout_line[\"line-round-limit\"]),\"line-sort-key\":new Hi(Ft.layout_line[\"line-sort-key\"])}),yl={paint:new Yi({\"line-opacity\":new Hi(Ft.paint_line[\"line-opacity\"]),\"line-color\":new Hi(Ft.paint_line[\"line-color\"]),\"line-translate\":new qi(Ft.paint_line[\"line-translate\"]),\"line-translate-anchor\":new qi(Ft.paint_line[\"line-translate-anchor\"]),\"line-width\":new Hi(Ft.paint_line[\"line-width\"]),\"line-gap-width\":new Hi(Ft.paint_line[\"line-gap-width\"]),\"line-offset\":new Hi(Ft.paint_line[\"line-offset\"]),\"line-blur\":new Hi(Ft.paint_line[\"line-blur\"]),\"line-dasharray\":new Zi(Ft.paint_line[\"line-dasharray\"]),\"line-pattern\":new Gi(Ft.paint_line[\"line-pattern\"]),\"line-gradient\":new Wi(Ft.paint_line[\"line-gradient\"])}),layout:gl},vl=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Oi(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=p({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Hi),xl=new vl(yl.paint.properties[\"line-width\"].specification);xl.useIntegerZoom=!0;var _l=function(t){function e(e){t.call(this,e,yl),this.gradientVersion=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){if(\"line-gradient\"===t){var e=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.stepInterpolant=e._styleExpression.expression instanceof tr,this.gradientVersion=(this.gradientVersion+1)%l}},e.prototype.gradientExpression=function(){return this._transitionablePaint._values[\"line-gradient\"].value.expression},e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r),this.paint._values[\"line-floorwidth\"]=xl.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new ml(t)},e.prototype.queryRadius=function(t){var e=t,r=bl(Po(\"line-width\",this,e),Po(\"line-gap-width\",this,e)),n=Po(\"line-offset\",this,e);return r/2+Math.abs(n)+zo(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s){var l=Oo(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*bl(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new a(0,0),i=0;i<t.length;i++){for(var o=t[i],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),m=d.x*p.x+d.y*p.y;d._mult(1/m),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Lo(t,i[a]))return!0;if(ko(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}($i);function bl(t,e){return e>0?e+2*t:t}var wl=ta([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),Tl=ta([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),kl=(ta([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),ta([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),Al=(ta([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]),ta([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),Ml=ta([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);function Sl(t,e,r){return t.sections.forEach((function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),zi.applyArabicShaping&&(t=zi.applyArabicShaping(t)),t}(t.text,e,r)})),t}ta([{name:\"triangle\",components:3,type:\"Uint16\"}]),ta([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),ta([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",components:2,name:\"textOffset\"},{type:\"Float32\",name:\"collisionCircleDiameter\"}]),ta([{type:\"Float32\",name:\"offsetX\"}]),ta([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var El={\"!\":\"\ufe15\",\"#\":\"\uff03\",$:\"\uff04\",\"%\":\"\uff05\",\"&\":\"\uff06\",\"(\":\"\ufe35\",\")\":\"\ufe36\",\"*\":\"\uff0a\",\"+\":\"\uff0b\",\",\":\"\ufe10\",\"-\":\"\ufe32\",\".\":\"\u30fb\",\"/\":\"\uff0f\",\":\":\"\ufe13\",\";\":\"\ufe14\",\"<\":\"\ufe3f\",\"=\":\"\uff1d\",\">\":\"\ufe40\",\"?\":\"\ufe16\",\"@\":\"\uff20\",\"[\":\"\ufe47\",\"\\\\\":\"\uff3c\",\"]\":\"\ufe48\",\"^\":\"\uff3e\",_:\"\ufe33\",\"`\":\"\uff40\",\"{\":\"\ufe37\",\"|\":\"\u2015\",\"}\":\"\ufe38\",\"~\":\"\uff5e\",\"\u00a2\":\"\uffe0\",\"\u00a3\":\"\uffe1\",\"\u00a5\":\"\uffe5\",\"\u00a6\":\"\uffe4\",\"\u00ac\":\"\uffe2\",\"\u00af\":\"\uffe3\",\"\u2013\":\"\ufe32\",\"\u2014\":\"\ufe31\",\"\u2018\":\"\ufe43\",\"\u2019\":\"\ufe44\",\"\u201c\":\"\ufe41\",\"\u201d\":\"\ufe42\",\"\u2026\":\"\ufe19\",\"\u2027\":\"\u30fb\",\"\u20a9\":\"\uffe6\",\"\u3001\":\"\ufe11\",\"\u3002\":\"\ufe12\",\"\u3008\":\"\ufe3f\",\"\u3009\":\"\ufe40\",\"\u300a\":\"\ufe3d\",\"\u300b\":\"\ufe3e\",\"\u300c\":\"\ufe41\",\"\u300d\":\"\ufe42\",\"\u300e\":\"\ufe43\",\"\u300f\":\"\ufe44\",\"\u3010\":\"\ufe3b\",\"\u3011\":\"\ufe3c\",\"\u3014\":\"\ufe39\",\"\u3015\":\"\ufe3a\",\"\u3016\":\"\ufe17\",\"\u3017\":\"\ufe18\",\"\uff01\":\"\ufe15\",\"\uff08\":\"\ufe35\",\"\uff09\":\"\ufe36\",\"\uff0c\":\"\ufe10\",\"\uff0d\":\"\ufe32\",\"\uff0e\":\"\u30fb\",\"\uff1a\":\"\ufe13\",\"\uff1b\":\"\ufe14\",\"\uff1c\":\"\ufe3f\",\"\uff1e\":\"\ufe40\",\"\uff1f\":\"\ufe16\",\"\uff3b\":\"\ufe47\",\"\uff3d\":\"\ufe48\",\"\uff3f\":\"\ufe33\",\"\uff5b\":\"\ufe37\",\"\uff5c\":\"\u2015\",\"\uff5d\":\"\ufe38\",\"\uff5f\":\"\ufe35\",\"\uff60\":\"\ufe36\",\"\uff61\":\"\ufe12\",\"\uff62\":\"\ufe41\",\"\uff63\":\"\ufe42\"};var Cl=24,Ll=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},Il=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,m=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*m},Pl=zl;function zl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}zl.Varint=0,zl.Fixed64=1,zl.Bytes=2,zl.Fixed32=5;var Ol=4294967296,Dl=1/Ol,Rl=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf8\");function Fl(t){return t.type===zl.Bytes?t.readVarint()+t.pos:t.pos+1}function Bl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function Nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function jl(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function Ul(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function Vl(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function ql(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function Hl(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function Gl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function Zl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function Wl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function Yl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function Xl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function $l(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function Jl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}zl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=Xl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=Jl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=Xl(this.buf,this.pos)+Xl(this.buf,this.pos+4)*Ol;return this.pos+=8,t},readSFixed64:function(){var t=Xl(this.buf,this.pos)+Jl(this.buf,this.pos+4)*Ol;return this.pos+=8,t},readFloat:function(){var t=Ll(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ll(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return Bl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return Bl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return Bl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return Bl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return Bl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return Bl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&Rl?function(t,e,r){return Rl.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==zl.Bytes)return t.push(this.readVarint(e));var r=Fl(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==zl.Bytes)return t.push(this.readSVarint());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==zl.Bytes)return t.push(this.readBoolean());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==zl.Bytes)return t.push(this.readFloat());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==zl.Bytes)return t.push(this.readDouble());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==zl.Bytes)return t.push(this.readFixed32());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==zl.Bytes)return t.push(this.readSFixed32());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==zl.Bytes)return t.push(this.readFixed64());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==zl.Bytes)return t.push(this.readSFixed64());var e=Fl(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===zl.Varint)for(;this.buf[this.pos++]>127;);else if(e===zl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===zl.Fixed32)this.pos+=4;else{if(e!==zl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),$l(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),$l(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),$l(this.buf,-1&t,this.pos),$l(this.buf,Math.floor(t*Dl),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),$l(this.buf,-1&t,this.pos),$l(this.buf,Math.floor(t*Dl),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&Nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),Il(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),Il(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&Nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,zl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,jl,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,Ul,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,Hl,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,Vl,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,ql,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,Gl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,Zl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,Wl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,Yl,e)},writeBytesField:function(t,e){this.writeTag(t,zl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,zl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,zl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,zl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,zl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,zl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,zl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,zl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,zl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,zl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var Kl=3;function Ql(t,e,r){1===t&&r.readMessage(tc,e)}function tc(t,e,r){if(3===t){var n=r.readMessage(ec,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new Jo({width:o+2*Kl,height:s+2*Kl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function ec(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var rc=Kl;function nc(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort((function(t,e){return e.h-t.h}));for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var ic=1,ac=function(t,e){var r=e.pixelRatio,n=e.version,i=e.stretchX,a=e.stretchY,o=e.content;this.paddedRect=t,this.pixelRatio=r,this.stretchX=i,this.stretchY=a,this.content=o,this.version=n},oc={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};oc.tl.get=function(){return[this.paddedRect.x+ic,this.paddedRect.y+ic]},oc.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-ic,this.paddedRect.y+this.paddedRect.h-ic]},oc.tlbr.get=function(){return this.tl.concat(this.br)},oc.displaySize.get=function(){return[(this.paddedRect.w-2*ic)/this.pixelRatio,(this.paddedRect.h-2*ic)/this.pixelRatio]},Object.defineProperties(ac.prototype,oc);var sc=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=nc(i),o=a.w,s=a.h,l=new Ko({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ko.copy(u.data,l,{x:0,y:0},{x:h.x+ic,y:h.y+ic},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,m=d.x+ic,g=d.y+ic,y=p.data.width,v=p.data.height;Ko.copy(p.data,l,{x:0,y:0},{x:m,y:g},p.data),Ko.copy(p.data,l,{x:0,y:v-1},{x:m,y:g-1},{width:y,height:1}),Ko.copy(p.data,l,{x:0,y:0},{x:m,y:g+v},{width:y,height:1}),Ko.copy(p.data,l,{x:y-1,y:0},{x:m-1,y:g},{width:1,height:v}),Ko.copy(p.data,l,{x:0,y:0},{x:m+y,y:g},{width:1,height:v})}this.image=l,this.iconPositions=r,this.patternPositions=n};sc.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2*ic,h:i.data.height+2*ic};r.push(a),e[n]=new ac(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},sc.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},sc.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},oi(\"ImagePosition\",ac),oi(\"ImageAtlas\",sc);var lc={horizontal:1,vertical:2,horizontalOnly:3},cc=-17;var uc=function(){this.scale=1,this.fontStack=\"\",this.imageName=null};uc.forText=function(t,e){var r=new uc;return r.scale=t||1,r.fontStack=e,r},uc.forImage=function(t){var e=new uc;return e.imageName=t,e};var hc=function(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null};function fc(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m){var g,y=hc.fromFeature(t,i);h===lc.vertical&&y.verticalizePunctuation();var v=zi.processBidirectionalText,x=zi.processStyledBidirectionalText;if(v&&1===y.sections.length){g=[];for(var _=0,b=v(y.toString(),_c(y,c,a,e,n,p,d));_<b.length;_+=1){var w=b[_],T=new hc;T.text=w,T.sections=y.sections;for(var k=0;k<w.length;k++)T.sectionIndex.push(0);g.push(T)}}else if(x){g=[];for(var A=0,M=x(y.text,y.sectionIndex,_c(y,c,a,e,n,p,d));A<M.length;A+=1){var S=M[A],E=new hc;E.text=S[0],E.sectionIndex=S[1],E.sections=y.sections,g.push(E)}}else g=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(y,_c(y,c,a,e,n,p,d));var C=[],L={positionedLines:C,text:y.toString(),top:u[1],bottom:u[1],left:u[0],right:u[0],writingMode:h,iconsInText:!1,verticalizable:!1};return function(t,e,r,n,i,a,o,s,l,c,u,h){for(var f=0,p=cc,d=0,m=0,g=\"right\"===s?1:\"left\"===s?0:.5,y=0,v=0,x=i;v<x.length;v+=1){var _=x[v];_.trim();var b=_.getMaxScale(),w=(b-1)*Cl,T={positionedGlyphs:[],lineOffset:0};t.positionedLines[y]=T;var k=T.positionedGlyphs,A=0;if(_.length()){for(var M=0;M<_.length();M++){var S=_.getSection(M),E=_.getSectionIndex(M),C=_.getCharCode(M),L=0,I=null,P=null,z=null,O=Cl,D=!(l===lc.horizontal||!u&&!mi(C)||u&&(pc[C]||yi(C)));if(S.imageName){var R=n[S.imageName];if(!R)continue;z=S.imageName,t.iconsInText=t.iconsInText||!0,P=R.paddedRect;var F=R.displaySize;S.scale=S.scale*Cl/h,I={width:F[0],height:F[1],left:ic,top:-rc,advance:D?F[1]:F[0]},L=w+(Cl-F[1]*S.scale),O=I.advance;var B=D?F[0]*S.scale-Cl*b:F[1]*S.scale-Cl*b;B>0&&B>A&&(A=B)}else{var N=r[S.fontStack],j=N&&N[C];if(j&&j.rect)P=j.rect,I=j.metrics;else{var U=e[S.fontStack],V=U&&U[C];if(!V)continue;I=V.metrics}L=(b-S.scale)*Cl}D?(t.verticalizable=!0,k.push({glyph:C,imageName:z,x:f,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),f+=O*S.scale+c):(k.push({glyph:C,imageName:z,x:f,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),f+=I.advance*S.scale+c)}if(0!==k.length){var q=f-c;d=Math.max(q,d),wc(k,0,k.length-1,g,A)}f=0;var H=a*b+A;T.lineOffset=Math.max(A,w),p+=H,m=Math.max(H,m),++y}else p+=a,++y}var G=p-cc,Z=bc(o),W=Z.horizontalAlign,Y=Z.verticalAlign;(function(t,e,r,n,i,a,o,s,l){var c=(e-r)*i,u=0;u=a!==o?-s*n-cc:(-n*l+.5)*o;for(var h=0,f=t;h<f.length;h+=1)for(var p=0,d=f[h].positionedGlyphs;p<d.length;p+=1){var m=d[p];m.x+=c,m.y+=u}})(t.positionedLines,g,W,Y,d,m,a,G,i.length),t.top+=-Y*G,t.bottom=t.top+G,t.left+=-W*d,t.right=t.left+d}(L,e,r,n,g,o,s,l,h,c,f,m),!function(t){for(var e=0,r=t;e<r.length;e+=1)if(0!==r[e].positionedGlyphs.length)return!1;return!0}(C)&&L}hc.fromFeature=function(t,e){for(var r=new hc,n=0;n<t.sections.length;n++){var i=t.sections[n];i.image?r.addImageSection(i):r.addTextSection(i,e)}return r},hc.prototype.length=function(){return this.text.length},hc.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},hc.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},hc.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},hc.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&gi(n)&&!El[t[r+1]]||i&&gi(i)&&!El[t[r-1]]||!El[t[r]]?e+=t[r]:e+=El[t[r]]}return e}(this.text)},hc.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&pc[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&pc[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},hc.prototype.substring=function(t,e){var r=new hc;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},hc.prototype.toString=function(){return this.text},hc.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce((function(e,r){return Math.max(e,t.sections[r].scale)}),0)},hc.prototype.addTextSection=function(t,e){this.text+=t.text,this.sections.push(uc.forText(t.scale,t.fontStack||e));for(var r=this.sections.length-1,n=0;n<t.text.length;++n)this.sectionIndex.push(r)},hc.prototype.addImageSection=function(t){var e=t.image?t.image.name:\"\";if(0!==e.length){var r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(uc.forImage(e)),this.sectionIndex.push(this.sections.length-1)):k(\"Reached maximum number of images 6401\")}else k(\"Can't add FormattedSection with an empty image.\")},hc.prototype.getNextImageSectionCharCode=function(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)};var pc={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},dc={};function mc(t,e,r,n,i,a){if(e.imageName){var o=n[e.imageName];return o?o.displaySize[0]*e.scale*Cl/a+i:0}var s=r[e.fontStack],l=s&&s[t];return l?l.metrics.advance*e.scale+i:0}function gc(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function yc(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function vc(t,e,r,n,i,a){for(var o=null,s=gc(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=gc(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function xc(t){return t?xc(t.priorBreak).concat(t.index):[]}function _c(t,e,r,n,i,a,o){if(\"point\"!==a)return[];if(!t)return[];for(var s=[],l=function(t,e,r,n,i,a){for(var o=0,s=0;s<t.length();s++){var l=t.getSection(s);o+=mc(t.getCharCode(s),l,n,i,e,a)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,i,o),c=t.text.indexOf(\"\u200b\")>=0,u=0,h=0;h<t.length();h++){var f=t.getSection(h),p=t.getCharCode(h);if(pc[p]||(u+=mc(p,f,n,i,e,o)),h<t.length()-1){var d=!((m=p)<11904||!(pi[\"Bopomofo Extended\"](m)||pi.Bopomofo(m)||pi[\"CJK Compatibility Forms\"](m)||pi[\"CJK Compatibility Ideographs\"](m)||pi[\"CJK Compatibility\"](m)||pi[\"CJK Radicals Supplement\"](m)||pi[\"CJK Strokes\"](m)||pi[\"CJK Symbols and Punctuation\"](m)||pi[\"CJK Unified Ideographs Extension A\"](m)||pi[\"CJK Unified Ideographs\"](m)||pi[\"Enclosed CJK Letters and Months\"](m)||pi[\"Halfwidth and Fullwidth Forms\"](m)||pi.Hiragana(m)||pi[\"Ideographic Description Characters\"](m)||pi[\"Kangxi Radicals\"](m)||pi[\"Katakana Phonetic Extensions\"](m)||pi.Katakana(m)||pi[\"Vertical Forms\"](m)||pi[\"Yi Radicals\"](m)||pi[\"Yi Syllables\"](m)));(dc[p]||d||f.imageName)&&s.push(vc(h+1,u,l,s,yc(p,t.getCharCode(h+1),d&&c),!1))}}var m;return xc(vc(t.length(),u,l,s,0,!0))}function bc(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function wc(t,e,r,n,i){if(n||i)for(var a=t[r],o=a.metrics.advance*a.scale,s=(t[r].x+o)*n,l=e;l<=r;l++)t[l].x-=s,t[l].y+=i}function Tc(t,e,r,n,i,a){var o,s=t.image;if(s.content){var l=s.content,c=s.pixelRatio||1;o=[l[0]/c,l[1]/c,s.displaySize[0]-l[2]/c,s.displaySize[1]-l[3]/c]}var u,h,f,p,d=e.left*a,m=e.right*a;\"width\"===r||\"both\"===r?(p=i[0]+d-n[3],h=i[0]+m+n[1]):h=(p=i[0]+(d+m-s.displaySize[0])/2)+s.displaySize[0];var g=e.top*a,y=e.bottom*a;return\"height\"===r||\"both\"===r?(u=i[1]+g-n[0],f=i[1]+y+n[2]):f=(u=i[1]+(g+y-s.displaySize[1])/2)+s.displaySize[1],{image:s,top:u,right:h,bottom:f,left:p,collisionPadding:o}}dc[10]=!0,dc[32]=!0,dc[38]=!0,dc[40]=!0,dc[41]=!0,dc[43]=!0,dc[45]=!0,dc[47]=!0,dc[173]=!0,dc[183]=!0,dc[8203]=!0,dc[8208]=!0,dc[8211]=!0,dc[8231]=!0;var kc=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(a);oi(\"Anchor\",kc);var Ac=128;function Mc(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Oi(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Oi(s)),maxSize:r.evaluate(new Oi(l)),interpolationType:i}}function Sc(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/Ac:\"composite\"===t.kind?er(a/Ac,o/Ac,i):n}function Ec(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?h(wr.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=er(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var Cc=Object.freeze({__proto__:null,getSizeData:Mc,evaluateSizeForFeature:Sc,evaluateSizeForZoom:Ec,SIZE_PACK_FACTOR:Ac});function Lc(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function Ic(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Pc(t,e,r){return t?.6*e*r:0}function zc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Oc(t,e,r,n,i,a){for(var o=Pc(r,i,a),s=zc(r,n)*a,l=0,c=Ic(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,m=er(h.x,f.x,d),g=er(h.y,f.y,d),y=new kc(m,g,f.angleTo(h),u);return y._round(),!o||Lc(t,y,s,o,e)?y:void 0}l+=p}}function Dc(t,e,r,n,i,a,o,s,l){var c=Pc(n,a,o),u=zc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),Rc(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}function Rc(t,e,r,n,i,a,o,s,l){for(var c=a/2,u=Ic(t),h=0,f=e-r,p=[],d=0;d<t.length-1;d++){for(var m=t[d],g=t[d+1],y=m.dist(g),v=g.angleTo(m);f+r<h+y;){var x=((f+=r)-h)/y,_=er(m.x,g.x,x),b=er(m.y,g.y,x);if(_>=0&&_<l&&b>=0&&b<l&&f-c>=0&&f+c<=u){var w=new kc(_,b,v,d);w._round(),n&&!Lc(t,w,a,n,i)||p.push(w)}}h+=y}return s||p.length||o||(p=Rc(t,h/2,r,n,i,a,o,!0,l)),p}function Fc(t,e,r,n,i){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<e&&f.x<e||(h.x<e?h=new a(e,h.y+(f.y-h.y)*((e-h.x)/(f.x-h.x)))._round():f.x<e&&(f=new a(e,h.y+(f.y-h.y)*((e-h.x)/(f.x-h.x)))._round()),h.y<r&&f.y<r||(h.y<r?h=new a(h.x+(f.x-h.x)*((r-h.y)/(f.y-h.y)),r)._round():f.y<r&&(f=new a(h.x+(f.x-h.x)*((r-h.y)/(f.y-h.y)),r)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new a(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new a(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=i&&f.y>=i||(h.y>=i?h=new a(h.x+(f.x-h.x)*((i-h.y)/(f.y-h.y)),i)._round():f.y>=i&&(f=new a(h.x+(f.x-h.x)*((i-h.y)/(f.y-h.y)),i)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}var Bc=ic;function Nc(t,e,r,n){var i=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2*Bc,c=o.paddedRect.h-2*Bc,u=t.right-t.left,h=t.bottom-t.top,f=o.stretchX||[[0,l]],p=o.stretchY||[[0,c]],d=function(t,e){return t+e[1]-e[0]},m=f.reduce(d,0),g=p.reduce(d,0),y=l-m,v=c-g,x=0,_=m,b=0,w=g,T=0,k=y,A=0,M=v;if(o.content&&n){var S=o.content;x=jc(f,0,S[0]),b=jc(p,0,S[1]),_=jc(f,S[0],S[2]),w=jc(p,S[1],S[3]),T=S[0]-x,A=S[1]-b,k=S[2]-S[0]-_,M=S[3]-S[1]-w}var E=function(n,i,l,c){var f=Vc(n.stretch-x,_,u,t.left),p=qc(n.fixed-T,k,n.stretch,m),d=Vc(i.stretch-b,w,h,t.top),y=qc(i.fixed-A,M,i.stretch,g),v=Vc(l.stretch-x,_,u,t.left),S=qc(l.fixed-T,k,l.stretch,m),E=Vc(c.stretch-b,w,h,t.top),C=qc(c.fixed-A,M,c.stretch,g),L=new a(f,d),I=new a(v,d),P=new a(v,E),z=new a(f,E),O=new a(p/s,y/s),D=new a(S/s,C/s),R=e*Math.PI/180;if(R){var F=Math.sin(R),B=Math.cos(R),N=[B,-F,F,B];L._matMult(N),I._matMult(N),z._matMult(N),P._matMult(N)}var j=n.stretch+n.fixed,U=l.stretch+l.fixed,V=i.stretch+i.fixed,q=c.stretch+c.fixed;return{tl:L,tr:I,bl:z,br:P,tex:{x:o.paddedRect.x+Bc+j,y:o.paddedRect.y+Bc+V,w:U-j,h:q-V},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:O,pixelOffsetBR:D,minFontScaleX:k/s/u,minFontScaleY:M/s/h,isSDF:r}};if(n&&(o.stretchX||o.stretchY))for(var C=Uc(f,y,m),L=Uc(p,v,g),I=0;I<C.length-1;I++)for(var P=C[I],z=C[I+1],O=0;O<L.length-1;O++){var D=L[O],R=L[O+1];i.push(E(P,D,z,R))}else i.push(E({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return i}function jc(t,e,r){for(var n=0,i=0,a=t;i<a.length;i+=1){var o=a[i];n+=Math.max(e,Math.min(r,o[1]))-Math.max(e,Math.min(r,o[0]))}return n}function Uc(t,e,r){for(var n=[{fixed:-Bc,stretch:0}],i=0,a=t;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=n[n.length-1];n.push({fixed:s-c.stretch,stretch:c.stretch}),n.push({fixed:s-c.stretch,stretch:c.stretch+(l-s)})}return n.push({fixed:e+Bc,stretch:r}),n}function Vc(t,e,r,n){return t/e*r+n}function qc(t,e,r,n){return t-e*r/n}var Hc=function(t,e,r,n,i,o,s,l,c,u){if(this.boxStartIndex=t.length,c){var h=o.top,f=o.bottom,p=o.collisionPadding;p&&(h-=p[1],f+=p[3]);var d=f-h;d>0&&(d=Math.max(10,d),this.circleDiameter=d)}else{var m=o.top*s-l,g=o.bottom*s+l,y=o.left*s-l,v=o.right*s+l,x=o.collisionPadding;if(x&&(y-=x[0]*s,m-=x[1]*s,v+=x[2]*s,g+=x[3]*s),u){var _=new a(y,m),b=new a(v,m),w=new a(y,g),T=new a(v,g),k=u*Math.PI/180;_._rotate(k),b._rotate(k),w._rotate(k),T._rotate(k),y=Math.min(_.x,b.x,w.x,T.x),v=Math.max(_.x,b.x,w.x,T.x),m=Math.min(_.y,b.y,w.y,T.y),g=Math.max(_.y,b.y,w.y,T.y)}t.emplaceBack(e.x,e.y,y,m,v,g,r,n,i)}this.boxEndIndex=t.length},Gc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=Zc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function Zc(t,e){return t<e?-1:t>e?1:0}function Wc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,i=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<i)&&(i=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-i,p=Math.min(h,f),d=p/2,m=new Gc([],Yc);if(0===p)return new a(n,i);for(var g=n;g<o;g+=p)for(var y=i;y<s;y+=p)m.push(new Xc(g+d,y+d,d,t));for(var v=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new Xc(r/e,n/e,0,t)}(t),x=m.length;m.length;){var _=m.pop();(_.d>v.d||!v.d)&&(v=_,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*_.d)/1e4,x)),_.max-v.d<=e||(d=_.h/2,m.push(new Xc(_.p.x-d,_.p.y-d,d,t)),m.push(new Xc(_.p.x+d,_.p.y-d,d,t)),m.push(new Xc(_.p.x-d,_.p.y+d,d,t)),m.push(new Xc(_.p.x+d,_.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+v.d)),v.p}function Yc(t,e){return e.max-t.max}function Xc(t,e,r,n){this.p=new a(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,Eo(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}Gc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},Gc.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},Gc.prototype.peek=function(){return this.data[0]},Gc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},Gc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var $c=7,Jc=Number.POSITIVE_INFINITY;function Kc(t,e){return e[1]!==Jc?function(t,e,r){var n=0,i=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":i=r-$c;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":i=-r+$c}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,i]}(t,e[0],e[1]):function(t,e){var r=0,n=0;e<0&&(e=0);var i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-$c;break;case\"bottom-right\":case\"bottom-left\":n=-i+$c;break;case\"bottom\":n=-e+$c;break;case\"top\":n=e-$c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function Qc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}var tu=255,eu=tu*Ac;function ru(t,e,r,n,i,o,s,l,c,u,h,f,p,d,m){var g=function(t,e,r,n,i,o,s,l){for(var c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[],h=0,f=e.positionedLines;h<f.length;h+=1)for(var p=f[h],d=0,m=p.positionedGlyphs;d<m.length;d+=1){var g=m[d];if(g.rect){var y=g.rect||{},v=rc+1,x=!0,_=1,b=0,w=(i||l)&&g.vertical,T=g.metrics.advance*g.scale/2;if(l&&e.verticalizable){var k=(g.scale-1)*Cl,A=(Cl-g.metrics.width*g.scale)/2;b=p.lineOffset/2-(g.imageName?-A:k)}if(g.imageName){var M=s[g.imageName];x=M.sdf,_=M.pixelRatio,v=ic/_}var S=i?[g.x+T,g.y]:[0,0],E=i?[0,0]:[g.x+T+r[0],g.y+r[1]-b],C=[0,0];w&&(C=E,E=[0,0]);var L=(g.metrics.left-v)*g.scale-T+E[0],I=(-g.metrics.top-v)*g.scale+E[1],P=L+y.w*g.scale/_,z=I+y.h*g.scale/_,O=new a(L,I),D=new a(P,I),R=new a(L,z),F=new a(P,z);if(w){var B=new a(-T,T-cc),N=-Math.PI/2,j=Cl/2-T,U=g.imageName?j:0,V=new a(5-cc-j,-U),q=new(Function.prototype.bind.apply(a,[null].concat(C)));O._rotateAround(N,B)._add(V)._add(q),D._rotateAround(N,B)._add(V)._add(q),R._rotateAround(N,B)._add(V)._add(q),F._rotateAround(N,B)._add(V)._add(q)}if(c){var H=Math.sin(c),G=Math.cos(c),Z=[G,-H,H,G];O._matMult(Z),D._matMult(Z),R._matMult(Z),F._matMult(Z)}var W=new a(0,0),Y=new a(0,0);u.push({tl:O,tr:D,bl:R,br:F,tex:y,writingMode:e.writingMode,glyphOffset:S,sectionIndex:g.sectionIndex,isSDF:x,pixelOffsetTL:W,pixelOffsetBR:Y,minFontScaleX:0,minFontScaleY:0})}}return u}(0,r,l,i,o,s,n,t.allowVerticalPlacement),y=t.textSizeData,v=null;\"source\"===y.kind?(v=[Ac*i.layout.get(\"text-size\").evaluate(s,{})])[0]>eu&&k(t.layerIds[0]+': Value for \"text-size\" is >= '+tu+'. Reduce your \"text-size\".'):\"composite\"===y.kind&&((v=[Ac*d.compositeTextSizes[0].evaluate(s,{},m),Ac*d.compositeTextSizes[1].evaluate(s,{},m)])[0]>eu||v[1]>eu)&&k(t.layerIds[0]+': Value for \"text-size\" is >= '+tu+'. Reduce your \"text-size\".'),t.addSymbols(t.text,g,v,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,m);for(var x=0,_=h;x<_.length;x+=1)f[_[x]]=t.text.placedSymbolArray.length-1;return 4*g.length}function nu(t){for(var e in t)return t[e];return null}function iu(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}var au=tl.VectorTileFeature.types,ou=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function su(t,e,r,n,i,a,o,s,l,c,u,h,f){var p=s?Math.min(eu,Math.round(s[0])):0,d=s?Math.min(eu,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,(p<<1)+(l?1:0),d,16*c,16*u,256*h,256*f)}function lu(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function cu(t){for(var e=0,r=t.sections;e<r.length;e+=1)if(_i(r[e].text))return!0;return!1}var uu=function(t){this.layoutVertexArray=new la,this.indexArray=new ma,this.programConfigurations=t,this.segments=new Da,this.dynamicLayoutVertexArray=new ca,this.opacityVertexArray=new ua,this.placedSymbolArray=new Sa};uu.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length},uu.prototype.upload=function(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,wl.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,Tl.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,ou,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))},uu.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},oi(\"SymbolBuffers\",uu);var hu=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Da,this.collisionVertexArray=new da};hu.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,kl.members,!0)},hu.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},oi(\"CollisionBuffers\",hu);var fu=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=Bo([]),this.placementViewportMatrix=Bo([]);var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Mc(this.zoom,e[\"text-size\"]),this.iconSizeData=Mc(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.canOverlap=r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\"),this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&this.canOverlap,\"point\"===r.get(\"symbol-placement\")&&(this.writingModes=r.get(\"text-writing-mode\").map((function(t){return lc[t]}))),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id})),this.sourceID=t.sourceID};fu.prototype.createArrays=function(){this.text=new uu(new uo(this.layers,this.zoom,(function(t){return/^text/.test(t)}))),this.icon=new uu(new uo(this.layers,this.zoom,(function(t){return/^icon/.test(t)}))),this.glyphOffsetArray=new La,this.lineVertexArray=new Ia,this.symbolInstances=new Ca},fu.prototype.calculateGlyphDependencies=function(t,e,r,n,i){for(var a=0;a<t.length;a++)if(e[t.charCodeAt(a)]=!0,(r||n)&&i){var o=El[t.charAt(a)];o&&(e[o.charCodeAt(0)]=!0)}},fu.prototype.populate=function(t,e,r){var n=this.layers[0],i=n.layout,a=i.get(\"text-font\"),o=i.get(\"text-field\"),s=i.get(\"icon-image\"),l=(\"constant\"!==o.value.kind||o.value.value instanceof fe&&!o.value.value.isEmpty()||o.value.value.toString().length>0)&&(\"constant\"!==a.value.kind||a.value.value.length>0),c=\"constant\"!==s.value.kind||!!s.value.value||Object.keys(s.parameters).length>0,u=i.get(\"symbol-sort-key\");if(this.features=[],l||c){for(var h=e.iconDependencies,f=e.glyphDependencies,p=e.availableImages,d=new Oi(this.zoom),m=0,g=t;m<g.length;m+=1){var y=g[m],v=y.feature,x=y.id,_=y.index,b=y.sourceLayerIndex,w=n._featureFilter.needGeometry,T=vo(v,w);if(n._featureFilter.filter(d,T,r)){w||(T.geometry=yo(v));var k=void 0;if(l){var A=n.getValueAndResolveTokens(\"text-field\",T,r,p),M=fe.factory(A);cu(M)&&(this.hasRTLText=!0),(!this.hasRTLText||\"unavailable\"===Ii()||this.hasRTLText&&zi.isParsed())&&(k=Sl(M,n,T))}var S=void 0;if(c){var E=n.getValueAndResolveTokens(\"icon-image\",T,r,p);S=E instanceof pe?E:pe.fromString(E)}if(k||S){var C=this.sortFeaturesByKey?u.evaluate(T,{},r):void 0,L={id:x,text:k,icon:S,index:_,sourceLayerIndex:b,geometry:T.geometry,properties:v.properties,type:au[v.type],sortKey:C};if(this.features.push(L),S&&(h[S.name]=!0),k){var I=a.evaluate(T,{},r).join(\",\"),P=\"map\"===i.get(\"text-rotation-alignment\")&&\"point\"!==i.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(lc.vertical)>=0;for(var z=0,O=k.sections;z<O.length;z+=1){var D=O[z];if(D.image)h[D.image.name]=!0;else{var R=di(k.toString()),F=D.fontStack||I,B=f[F]=f[F]||{};this.calculateGlyphDependencies(D.text,B,P,this.allowVerticalPlacement,R)}}}}}}\"line\"===i.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var m=s(p,d,h),g=o(p,d,n[m].geometry);delete e[p],delete r[d],r[l(f,n[g].geometry,!0)]=g,n[m].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter((function(t){return t.geometry}))}(this.features)),this.sortFeaturesByKey&&this.features.sort((function(t,e){return t.sortKey-e.sortKey}))}},fu.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},fu.prototype.isEmpty=function(){return 0===this.symbolInstances.length&&!this.hasRTLText},fu.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},fu.prototype.upload=function(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},fu.prototype.destroyDebugData=function(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()},fu.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()},fu.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},fu.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c,u,h){for(var f=t.indexArray,p=t.layoutVertexArray,d=t.segments.prepareSegment(4*e.length,p,f,this.canOverlap?a.sortKey:void 0),m=this.glyphOffsetArray.length,g=d.vertexLength,y=this.allowVerticalPlacement&&o===lc.vertical?Math.PI/2:0,v=a.text&&a.text.sections,x=0;x<e.length;x++){var _=e[x],b=_.tl,w=_.tr,T=_.bl,k=_.br,A=_.tex,M=_.pixelOffsetTL,S=_.pixelOffsetBR,E=_.minFontScaleX,C=_.minFontScaleY,L=_.glyphOffset,I=_.isSDF,P=_.sectionIndex,z=d.vertexLength,O=L[1];su(p,s.x,s.y,b.x,O+b.y,A.x,A.y,r,I,M.x,M.y,E,C),su(p,s.x,s.y,w.x,O+w.y,A.x+A.w,A.y,r,I,S.x,M.y,E,C),su(p,s.x,s.y,T.x,O+T.y,A.x,A.y+A.h,r,I,M.x,S.y,E,C),su(p,s.x,s.y,k.x,O+k.y,A.x+A.w,A.y+A.h,r,I,S.x,S.y,E,C),lu(t.dynamicLayoutVertexArray,s,y),f.emplaceBack(z,z+1,z+2),f.emplaceBack(z+1,z+2,z+3),d.vertexLength+=4,d.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(L[0]),x!==e.length-1&&P===e[x+1].sectionIndex||t.programConfigurations.populatePaintArrays(p.length,a,a.index,{},h,v&&v[P])}t.placedSymbolArray.emplaceBack(s.x,s.y,m,this.glyphOffsetArray.length-m,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0,u)},fu.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},fu.prototype.addCollisionDebugVertices=function(t,e,r,n,i,o,s){var l=i.segments.prepareSegment(4,i.layoutVertexArray,i.indexArray),c=l.vertexLength,u=i.layoutVertexArray,h=i.collisionVertexArray,f=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,h,o,f,p,new a(t,e)),this._addCollisionDebugVertex(u,h,o,f,p,new a(r,e)),this._addCollisionDebugVertex(u,h,o,f,p,new a(r,n)),this._addCollisionDebugVertex(u,h,o,f,p,new a(t,n)),l.vertexLength+=4;var d=i.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4},fu.prototype.addDebugCollisionBoxes=function(t,e,r,n){for(var i=t;i<e;i++){var a=this.collisionBoxArray.get(i),o=a.x1,s=a.y1,l=a.x2,c=a.y2;this.addCollisionDebugVertices(o,s,l,c,n?this.textCollisionBox:this.iconCollisionBox,a.anchorPoint,r)}},fu.prototype.generateCollisionDebugBuffers=function(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new hu(fa,Al.members,ba),this.iconCollisionBox=new hu(fa,Al.members,ba);for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}},fu.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i,a,o,s,l){for(var c={},u=e;u<r;u++){var h=t.get(u);c.textBox={x1:h.x1,y1:h.y1,x2:h.x2,y2:h.y2,anchorPointX:h.anchorPointX,anchorPointY:h.anchorPointY},c.textFeatureIndex=h.featureIndex;break}for(var f=n;f<i;f++){var p=t.get(f);c.verticalTextBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},c.verticalTextFeatureIndex=p.featureIndex;break}for(var d=a;d<o;d++){var m=t.get(d);c.iconBox={x1:m.x1,y1:m.y1,x2:m.x2,y2:m.y2,anchorPointX:m.anchorPointX,anchorPointY:m.anchorPointY},c.iconFeatureIndex=m.featureIndex;break}for(var g=s;g<l;g++){var y=t.get(g);c.verticalIconBox={x1:y.x1,y1:y.y1,x2:y.x2,y2:y.y2,anchorPointX:y.anchorPointX,anchorPointY:y.anchorPointY},c.verticalIconFeatureIndex=y.featureIndex;break}return c},fu.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}},fu.prototype.hasTextData=function(){return this.text.segments.get().length>0},fu.prototype.hasIconData=function(){return this.icon.segments.get().length>0},fu.prototype.hasDebugData=function(){return this.textCollisionBox&&this.iconCollisionBox},fu.prototype.hasTextCollisionBoxData=function(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0},fu.prototype.hasIconCollisionBoxData=function(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0},fu.prototype.addIndicesForPlacedSymbol=function(t,e){for(var r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs,i=r.vertexStartIndex;i<n;i+=4)t.indexArray.emplaceBack(i,i+1,i+2),t.indexArray.emplaceBack(i+1,i+2,i+3)},fu.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort((function(t,e){return n[t]-n[e]||i[e]-i[t]})),a},fu.prototype.addToSortKeyRanges=function(t,e){var r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})},fu.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedSymbol(e.text,t)})),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,a.verticalPlacedTextSymbolIndex),a.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,a.placedIconSymbolIndex),a.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,a.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},oi(\"SymbolBucket\",fu,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),fu.MAX_GLYPHS=65535,fu.addDynamicAttributes=lu;var pu=new Yi({\"symbol-placement\":new qi(Ft.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new qi(Ft.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new qi(Ft.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Hi(Ft.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new qi(Ft.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new qi(Ft.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new qi(Ft.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new qi(Ft.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new qi(Ft.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Hi(Ft.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new qi(Ft.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new qi(Ft.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Hi(Ft.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Hi(Ft.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new qi(Ft.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new qi(Ft.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Hi(Ft.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Hi(Ft.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new qi(Ft.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new qi(Ft.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new qi(Ft.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Hi(Ft.layout_symbol[\"text-field\"]),\"text-font\":new Hi(Ft.layout_symbol[\"text-font\"]),\"text-size\":new Hi(Ft.layout_symbol[\"text-size\"]),\"text-max-width\":new Hi(Ft.layout_symbol[\"text-max-width\"]),\"text-line-height\":new qi(Ft.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Hi(Ft.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Hi(Ft.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Hi(Ft.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new qi(Ft.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Hi(Ft.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new qi(Ft.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new qi(Ft.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new Hi(Ft.layout_symbol[\"text-rotate\"]),\"text-padding\":new qi(Ft.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new qi(Ft.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Hi(Ft.layout_symbol[\"text-transform\"]),\"text-offset\":new Hi(Ft.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new qi(Ft.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new qi(Ft.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new qi(Ft.layout_symbol[\"text-optional\"])}),du={paint:new Yi({\"icon-opacity\":new Hi(Ft.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Hi(Ft.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Hi(Ft.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Hi(Ft.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Hi(Ft.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new qi(Ft.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new qi(Ft.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Hi(Ft.paint_symbol[\"text-opacity\"]),\"text-color\":new Hi(Ft.paint_symbol[\"text-color\"],{runtimeType:Xt,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),\"text-halo-color\":new Hi(Ft.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Hi(Ft.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Hi(Ft.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new qi(Ft.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new qi(Ft.paint_symbol[\"text-translate-anchor\"])}),layout:pu},mu=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:Gt,this.defaultValue=t};mu.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},mu.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},mu.prototype.outputDefined=function(){return!1},mu.prototype.serialize=function(){return null},oi(\"FormatSectionOverride\",mu,{omit:[\"defaultValue\"]});var gu=function(t){function e(e){t.call(this,e,du)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e,r){if(t.prototype.recalculate.call(this,e,r),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){var n=this.layout.get(\"text-writing-mode\");if(n){for(var i=[],a=0,o=n;a<o.length;a+=1){var s=o[a];i.indexOf(s)<0&&i.push(s)}this.layout._values[\"text-writing-mode\"]=i}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e,r,n){var i=this.layout.get(t).evaluate(e,{},r,n),a=this._unevaluatedLayout._values[t];return a.isDataDriven()||un(a.value)||!i?i:function(t,e){return e.replace(/{([^{}]+)}/g,(function(e,r){return r in t?String(t[r]):\"\"}))}(e.properties,i)},e.prototype.createBucket=function(t){return new fu(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=du.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var i,a=this.paint.get(n),o=new mu(a),s=new cn(o,a.property.specification);i=\"constant\"===a.value.kind||\"source\"===a.value.kind?new fn(\"source\",s):new pn(\"composite\",s,a.value.zoomStops,a.value._interpolationType),this.paint._values[n]=new Ui(a.property,i,a.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get(\"text-field\"),n=du.paint.properties[e],i=!1,a=function(t){for(var e=0,r=t;e<r.length;e+=1){var a=r[e];if(n.overrides&&n.overrides.hasOverride(a))return void(i=!0)}};if(\"constant\"===r.value.kind&&r.value.value instanceof fe)a(r.value.value.sections);else if(\"source\"===r.value.kind){var o=function(t){if(!i)if(t instanceof ve&&ge(t.value)===Qt){var e=t.value;a(e.sections)}else t instanceof we?a(t.sections):t.eachChild(o)},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return i},e}($i),yu={paint:new Yi({\"background-color\":new qi(Ft.paint_background[\"background-color\"]),\"background-pattern\":new Zi(Ft.paint_background[\"background-pattern\"]),\"background-opacity\":new qi(Ft.paint_background[\"background-opacity\"])})},vu=function(t){function e(e){t.call(this,e,yu)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}($i),xu={paint:new Yi({\"raster-opacity\":new qi(Ft.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new qi(Ft.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new qi(Ft.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new qi(Ft.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new qi(Ft.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new qi(Ft.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new qi(Ft.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new qi(Ft.paint_raster[\"raster-fade-duration\"])})},_u=function(t){function e(e){t.call(this,e,xu)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}($i);var bu=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}($i),wu={circle:Go,heatmap:es,hillshade:ns,fill:Hs,\"fill-extrusion\":sl,line:_l,symbol:gu,background:vu,raster:_u};var Tu=s.HTMLImageElement,ku=s.HTMLCanvasElement,Au=s.HTMLVideoElement,Mu=s.ImageData,Su=s.ImageBitmap,Eu=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Eu.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Tu||t instanceof ku||t instanceof Au||t instanceof Mu||Su&&t instanceof Su?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Tu||t instanceof ku||t instanceof Au||t instanceof Mu||Su&&t instanceof Su?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Eu.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Eu.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Eu.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Cu=function(t){var e=this;this._callback=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};Cu.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((function(){t._triggered=!1,t._callback()}),0))},Cu.prototype.remove=function(){delete this._channel,this._callback=function(){}};var Lu=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},v([\"receive\",\"process\"],this),this.invoker=new Cu(this.process),this.target.addEventListener(\"message\",this.receive,!1),this.globalScope=S()?t:s};function Iu(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}Lu.prototype.send=function(t,e,r,n,i){var a=this;void 0===i&&(i=!1);var o=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[o]=r);var s=L(this.globalScope)?void 0:[];return this.target.postMessage({id:o,type:t,hasCallback:!!r,targetMapId:n,mustQueue:i,sourceMapId:this.mapId,data:ui(e,s)},s),{cancel:function(){r&&delete a.callbacks[o],a.target.postMessage({id:o,type:\"<cancel>\",targetMapId:n,sourceMapId:a.mapId})}}},Lu.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if(\"<cancel>\"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else S()||e.mustQueue?(this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()):this.processTask(r,e)},Lu.prototype.process=function(){if(this.taskQueue.length){var t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length&&this.invoker.trigger(),e&&this.processTask(t,e)}},Lu.prototype.processTask=function(t,e){var r=this;if(\"<response>\"===e.type){var n=this.callbacks[t];delete this.callbacks[t],n&&(e.error?n(hi(e.error)):n(null,hi(e.data)))}else{var i=!1,a=L(this.globalScope)?void 0:[],o=e.hasCallback?function(e,n){i=!0,delete r.cancelCallbacks[t],r.target.postMessage({id:t,type:\"<response>\",sourceMapId:r.mapId,error:e?ui(e):null,data:ui(n,a)},a)}:function(t){i=!0},s=null,l=hi(e.data);if(this.parent[e.type])s=this.parent[e.type](e.sourceMapId,l,o);else if(this.parent.getWorkerSource){var c=e.type.split(\".\");s=this.parent.getWorkerSource(e.sourceMapId,c[0],l.source)[c[1]](l,o)}else o(new Error(\"Could not find function \"+e.type));!i&&s&&s.cancel&&(this.cancelCallbacks[t]=s.cancel)}},Lu.prototype.remove=function(){this.invoker.remove(),this.target.removeEventListener(\"message\",this.receive,!1)};var Pu=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Pu.prototype.setNorthEast=function(t){return this._ne=t instanceof Ou?new Ou(t.lng,t.lat):Ou.convert(t),this},Pu.prototype.setSouthWest=function(t){return this._sw=t instanceof Ou?new Ou(t.lng,t.lat):Ou.convert(t),this},Pu.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Ou)e=t,r=t;else{if(!(t instanceof Pu)){if(Array.isArray(t)){if(4===t.length||t.every(Array.isArray)){var a=t;return this.extend(Pu.convert(a))}var o=t;return this.extend(Ou.convert(o))}return this}if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Ou(e.lng,e.lat),this._ne=new Ou(r.lng,r.lat)),this},Pu.prototype.getCenter=function(){return new Ou((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Pu.prototype.getSouthWest=function(){return this._sw},Pu.prototype.getNorthEast=function(){return this._ne},Pu.prototype.getNorthWest=function(){return new Ou(this.getWest(),this.getNorth())},Pu.prototype.getSouthEast=function(){return new Ou(this.getEast(),this.getSouth())},Pu.prototype.getWest=function(){return this._sw.lng},Pu.prototype.getSouth=function(){return this._sw.lat},Pu.prototype.getEast=function(){return this._ne.lng},Pu.prototype.getNorth=function(){return this._ne.lat},Pu.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Pu.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},Pu.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Pu.prototype.contains=function(t){var e=Ou.convert(t),r=e.lng,n=e.lat,i=this._sw.lat<=n&&n<=this._ne.lat,a=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(a=this._sw.lng>=r&&r>=this._ne.lng),i&&a},Pu.convert=function(t){return!t||t instanceof Pu?t:new Pu(t)};var zu=6371008.8,Ou=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};Ou.prototype.wrap=function(){return new Ou(f(this.lng,-180,180),this.lat)},Ou.prototype.toArray=function(){return[this.lng,this.lat]},Ou.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Ou.prototype.distanceTo=function(t){var e=Math.PI/180,r=this.lat*e,n=t.lat*e,i=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return zu*Math.acos(Math.min(i,1))},Ou.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Pu(new Ou(this.lng-r,this.lat-e),new Ou(this.lng+r,this.lat+e))},Ou.convert=function(t){if(t instanceof Ou)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Ou(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Ou(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Du=2*Math.PI*zu;function Ru(t){return Du*Math.cos(t*Math.PI/180)}function Fu(t){return(180+t)/360}function Bu(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Nu(t,e){return t/Ru(e)}function ju(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}var Uu=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Uu.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Ou.convert(t);return new Uu(Fu(r.lng),Bu(r.lat),Nu(e,r.lat))},Uu.prototype.toLngLat=function(){return new Ou(360*this.x-180,ju(this.y))},Uu.prototype.toAltitude=function(){return t=this.z,e=this.y,t*Ru(ju(e));var t,e},Uu.prototype.meterInMercatorCoordinateUnits=function(){return 1/Du*(t=ju(this.y),1/Math.cos(t*Math.PI/180));var t};var Vu=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Gu(0,t,t,e,r)};Vu.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Vu.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=Iu(256*r,256*(n=Math.pow(2,i)-n-1),i),o=Iu(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Vu.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new a((t.x*e-this.x)*po,(t.y*e-this.y)*po)},Vu.prototype.toString=function(){return this.z+\"/\"+this.x+\"/\"+this.y};var qu=function(t,e){this.wrap=t,this.canonical=e,this.key=Gu(t,e.z,e.z,e.x,e.y)},Hu=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Vu(r,+n,+i),this.key=Gu(e,t,r,n,i)};function Gu(t,e,r,n,i){(t*=2)<0&&(t=-1*t-1);var a=1<<r;return(a*a*t+a*i+n).toString(36)+r.toString(36)+e.toString(36)}Hu.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Hu.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Hu(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Hu(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Hu.prototype.calculateScaledKey=function(t,e){var r=this.canonical.z-t;return t>this.canonical.z?Gu(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):Gu(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)},Hu.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Hu.prototype.children=function(t){if(this.overscaledZ>=t)return[new Hu(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Hu(e,this.wrap,e,r,n),new Hu(e,this.wrap,e,r+1,n),new Hu(e,this.wrap,e,r,n+1),new Hu(e,this.wrap,e,r+1,n+1)]},Hu.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Hu.prototype.wrapped=function(){return new Hu(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Hu.prototype.unwrapTo=function(t){return new Hu(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Hu.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Hu.prototype.toUnwrapped=function(){return new qu(this.wrap,this.canonical)},Hu.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},Hu.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Uu(t.x-this.wrap,t.y))},oi(\"CanonicalTileID\",Vu),oi(\"OverscaledTileID\",Hu,{omit:[\"posMatrix\"]});var Zu=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return k('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');this.stride=e.height;var n=this.dim=e.height-2;this.data=new Uint32Array(e.data.buffer),this.encoding=r||\"mapbox\";for(var i=0;i<n;i++)this.data[this._idx(-1,i)]=this.data[this._idx(0,i)],this.data[this._idx(n,i)]=this.data[this._idx(n-1,i)],this.data[this._idx(i,-1)]=this.data[this._idx(i,0)],this.data[this._idx(i,n)]=this.data[this._idx(i,n-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(n,-1)]=this.data[this._idx(n-1,0)],this.data[this._idx(-1,n)]=this.data[this._idx(0,n-1)],this.data[this._idx(n,n)]=this.data[this._idx(n-1,n-1)]};Zu.prototype.get=function(t,e){var r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return(\"terrarium\"===this.encoding?this._unpackTerrarium:this._unpackMapbox)(r[n],r[n+1],r[n+2])},Zu.prototype.getUnpackVector=function(){return\"terrarium\"===this.encoding?[256,1,1/256,32768]:[6553.6,25.6,.1,1e4]},Zu.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Zu.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Zu.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Zu.prototype.getPixels=function(){return new Ko({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Zu.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.data[this._idx(u,c)]=t.data[this._idx(u+s,c+l)]},oi(\"DEMData\",Zu);var Wu=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Wu.prototype.encode=function(t){return this._stringToNumber[t]},Wu.prototype.decode=function(t){return this._numberToString[t]};var Yu=function(t,e,r,n,i){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=i},Xu={geometry:{configurable:!0}};Xu.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Xu.geometry.set=function(t){this._geometry=t},Yu.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Yu.prototype,Xu);var $u=function(){this.state={},this.stateChanges={},this.deletedStates={}};$u.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},p(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},$u.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},$u.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=p({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},$u.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},$u.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),p(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,h=Object.keys(this.deletedStates[o][c]);u<h.length;u+=1){var f=h[u];delete this.state[o][c][f]}s[c]=this.state[o][c]}r[o]=r[o]||{},p(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ju=function(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new ti(po,16,0),this.grid3D=new ti(po,16,0),this.featureIndexArray=new za,this.promoteId=e};function Ku(t,e,r,n,i){return _(t,(function(t,a){var o=e instanceof Vi?e.get(a):null;return o&&o.evaluate?o.evaluate(r,n,i):o}))}function Qu(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function th(t,e){return e-t}Ju.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<po&&u[1]<po&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ju.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new tl.VectorTile(new Pl(this.rawTileData)).layers,this.sourceLayerCoder=new Wu(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ju.prototype.query=function(t,e,r,n){var i=this;this.loadVTLayers();for(var o=t.params||{},s=po/t.tileSize/t.scale,l=An(o.filter),c=t.queryGeometry,u=t.queryPadding*s,h=Qu(c),f=this.grid.query(h.minX-u,h.minY-u,h.maxX+u,h.maxY+u),p=Qu(t.cameraQueryGeometry),d=0,m=this.grid3D.query(p.minX-u,p.minY-u,p.maxX+u,p.maxY+u,(function(e,r,n,i){return function(t,e,r,n,i){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&i>=l.y)return!0}var c=[new a(e,r),new a(e,i),new a(n,i),new a(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Lo(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Io(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-u,r-u,n+u,i+u)}));d<m.length;d+=1){var g=m[d];f.push(g)}f.sort(th);for(var y,v={},x=function(a){var u=f[a];if(u!==y){y=u;var h=i.featureIndexArray.get(u),p=null;i.loadMatchingFeature(v,h.bucketIndex,h.sourceLayerIndex,h.featureIndex,l,o.layers,o.availableImages,e,r,n,(function(e,r,n){return p||(p=yo(e)),r.queryIntersectsFeature(c,e,n,p,i.z,t.transform,s,t.pixelPosMatrix)}))}},_=0;_<f.length;_++)x(_);return v},Ju.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,h)){var f=this.sourceLayerCoder.decode(r),d=this.vtLayers[f].feature(n);if(i.needGeometry){var m=vo(d,!0);if(!i.filter(new Oi(this.tileID.overscaledZ),m,this.tileID.canonical))return}else if(!i.filter(new Oi(this.tileID.overscaledZ),d))return;for(var g=this.getId(d,f),y=0;y<h.length;y++){var v=h[y];if(!(a&&a.indexOf(v)<0)){var x=s[v];if(x){var _={};void 0!==g&&c&&(_=c.getState(x.sourceLayer||\"_geojsonTileLayer\",g));var b=p({},l[v]);b.paint=Ku(b.paint,x.paint,d,_,o),b.layout=Ku(b.layout,x.layout,d,_,o);var w=!u||u(d,x,_);if(w){var T=new Yu(d,this.z,this.x,this.y,g);T.layer=b;var k=t[v];void 0===k&&(k=t[v]=[]),k.push({featureIndex:n,feature:T,intersectionZ:w})}}}}}},Ju.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a,o,s){var l={};this.loadVTLayers();for(var c=An(i),u=0,h=t;u<h.length;u+=1){var f=h[u];this.loadMatchingFeature(l,r,n,f,c,a,o,s,e)}return l},Ju.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},Ju.prototype.getId=function(t,e){var r=t.id;if(this.promoteId){var n=\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e];\"boolean\"==typeof(r=t.properties[n])&&(r=Number(r))}return r},oi(\"FeatureIndex\",Ju,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var eh=function(t,e){this.tileID=t,this.uid=m(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.expiredRequestCount=0,this.state=\"loading\"};eh.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<N.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},eh.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},eh.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map((function(t){return e.getLayer(t)})).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map((function(t){return n.filter((function(e){return e.id===t}))[0]})));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof fu){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(var a in this.buckets){var o=this.buckets[a];if(o instanceof fu&&o.hasRTLText){this.hasRTLText=!0,zi.isLoading()||zi.isLoaded()||\"deferred\"!==Ii()||Pi();break}}for(var s in this.queryPadding=0,this.buckets){var l=this.buckets[s];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(s).queryRadius(l))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Aa},eh.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},eh.prototype.getBucket=function(t){return this.buckets[t.id]},eh.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Eu(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Eu(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},eh.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},eh.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:i,scale:a,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}},eh.prototype.querySourceFeatures=function(t,e){var r=this.latestFeatureIndex;if(r&&r.rawTileData){var n=r.loadVTLayers(),i=e?e.sourceLayer:\"\",a=n._geojsonTileLayer||n[i];if(a)for(var o=An(e&&e.filter),s=this.tileID.canonical,l=s.z,c=s.x,u=s.y,h={z:l,x:c,y:u},f=0;f<a.length;f++){var p=a.feature(f);if(o.needGeometry){var d=vo(p,!0);if(!o.filter(new Oi(this.tileID.overscaledZ),d,this.tileID.canonical))continue}else if(!o.filter(new Oi(this.tileID.overscaledZ),p))continue;var m=r.getId(p,i),g=new Yu(p,l,c,u,m);g.tile=h,t.push(g)}}},eh.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},eh.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},eh.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=E(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},eh.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},eh.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets)if(e.style.hasLayer(n)){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];if(o&&s&&0!==Object.keys(s).length){i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});var l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(i)))}}}},eh.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},eh.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<N.now()},eh.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},eh.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=N.now()+t},eh.prototype.setDependencies=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1)r[i[n]]=!0;this.dependencies[t]=r},eh.prototype.hasDependency=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=this.dependencies[i];if(a)for(var o=0,s=e;o<s.length;o+=1)if(a[s[o]])return!0}return!1};var rh=s.performance,nh=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},rh.mark(this._marks.start)};nh.prototype.finish=function(){rh.mark(this._marks.end);var t=rh.getEntriesByName(this._marks.measure);return 0===t.length&&(rh.measure(this._marks.measure,this._marks.start,this._marks.end),t=rh.getEntriesByName(this._marks.measure),rh.clearMarks(this._marks.start),rh.clearMarks(this._marks.end),rh.clearMeasures(this._marks.measure)),t},t.Actor=Lu,t.AlphaImage=Jo,t.CanonicalTileID=Vu,t.CollisionBoxArray=Aa,t.Color=ce,t.DEMData=Zu,t.DataConstantProperty=qi,t.DictionaryCoder=Wu,t.EXTENT=po,t.ErrorEvent=Dt,t.EvaluationParameters=Oi,t.Event=Ot,t.Evented=Rt,t.FeatureIndex=Ju,t.FillBucket=Us,t.FillExtrusionBucket=il,t.ImageAtlas=sc,t.ImagePosition=ac,t.LineBucket=ml,t.LngLat=Ou,t.LngLatBounds=Pu,t.MercatorCoordinate=Uu,t.ONE_EM=Cl,t.OverscaledTileID=Hu,t.Point=a,t.Point$1=a,t.Properties=Yi,t.Protobuf=Pl,t.RGBAImage=Ko,t.RequestManager=Z,t.RequestPerformance=nh,t.ResourceType=bt,t.SegmentVector=Da,t.SourceFeatureState=$u,t.StructArrayLayout1ui2=wa,t.StructArrayLayout2f1f2i16=pa,t.StructArrayLayout2i4=ra,t.StructArrayLayout3ui6=ma,t.StructArrayLayout4i8=na,t.SymbolBucket=fu,t.Texture=Eu,t.Tile=eh,t.Transitionable=Fi,t.Uniform1f=$a,t.Uniform1i=Xa,t.Uniform2f=Ja,t.Uniform3f=Ka,t.Uniform4f=Qa,t.UniformColor=to,t.UniformMatrix4f=ro,t.UnwrappedTileID=qu,t.ValidationError=Bt,t.WritingMode=lc,t.ZoomHistory=fi,t.add=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t},t.addDynamicAttributes=lu,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach((function(t,o){e(t,(function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)}))}))},t.bezier=c,t.bindAll=v,t.browser=N,t.cacheEntryPossiblyAdded=function(t){++xt>ft&&(t.getActor().send(\"enforceCacheSizeLimit\",ht),xt=0)},t.clamp=h,t.clearTileCache=function(t){var e=s.caches.delete(ut);t&&e.catch(t).then((function(){return t()}))},t.clipLine=Fc,t.clone=function(t){var e=new Fo(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=w,t.clone$2=function(t){var e=new Fo(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e},t.collisionCircleLayout=Ml,t.config=j,t.create=function(){var t=new Fo(16);return Fo!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new Fo(9);return Fo!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new Fo(4);return Fo!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=hn,t.createLayout=ta,t.createStyleLayer=function(t){return\"custom\"===t.type?new bu(t):new wu[t.type](t)},t.cross=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t},t.deepEqual=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var i in e)if(!t(e[i],r[i]))return!1;return!0}return e===r},t.dot=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]},t.dot$1=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.ease=u,t.emitValidationErrors=Qn,t.endsWith=x,t.enforceCacheSizeLimit=function(t){dt(),rt&&rt.then((function(e){e.keys().then((function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])}))}))},t.evaluateSizeForFeature=Sc,t.evaluateSizeForZoom=Ec,t.evaluateVariableOffset=Kc,t.evented=Li,t.extend=p,t.featureFilter=An,t.filterObject=b,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=bc,t.getAnchorJustification=Qc,t.getArrayBuffer=Mt,t.getImage=It,t.getJSON=function(t,e){return At(p(t,{type:\"json\"}),e)},t.getRTLTextPluginStatus=Ii,t.getReferrer=Tt,t.getVideo=function(t,e){var r,n,i=s.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=s.document.createElement(\"source\");r=t[a],n=void 0,(n=s.document.createElement(\"a\")).href=r,n.protocol===s.document.location.protocol&&n.host===s.document.location.host||(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=Bo,t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],m=e[13],g=e[14],y=e[15],v=r*s-n*o,x=r*l-i*o,_=r*c-a*o,b=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*m-h*d,A=u*g-f*d,M=u*y-p*d,S=h*g-f*m,E=h*y-p*m,C=f*y-p*g,L=v*C-x*E+_*S+b*M-w*A+T*k;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(m*T-g*w+y*b)*L,t[3]=(f*w-h*T-p*b)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(g*_-d*T-y*x)*L,t[7]=(u*T-f*_+p*x)*L,t[8]=(o*E-s*M+c*k)*L,t[9]=(n*M-r*E-a*k)*L,t[10]=(d*w-m*_+y*v)*L,t[11]=(h*_-u*w-p*v)*L,t[12]=(s*A-o*S-l*k)*L,t[13]=(r*S-n*A+i*k)*L,t[14]=(m*x-d*b-g*v)*L,t[15]=(u*b-h*x+f*v)*L,t):null},t.isChar=pi,t.isMapboxURL=W,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=_,t.mercatorXfromLng=Fu,t.mercatorYfromLat=Bu,t.mercatorZfromAltitude=Nu,t.mul=jo,t.multiply=No,t.mvt=tl,t.nextPowerOfTwo=function(t){return t<=1?1:Math.pow(2,Math.ceil(Math.log(t)/Math.LN2))},t.normalize=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a)),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a,t},t.number=er,t.offscreenCanvasSupported=_t,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Pl(t).readFields(Ql,[])},t.pbf=Pl,t.performSymbolLayout=function(t,e,r,n,i,a,o){t.createArrays();var s=512*t.overscaling;t.tilePixelRatio=po/s,t.compareText={},t.iconsNeedLinear=!1;var l=t.layers[0].layout,c=t.layers[0]._unevaluatedLayout._values,u={};if(\"composite\"===t.textSizeData.kind){var h=t.textSizeData,f=h.minZoom,p=h.maxZoom;u.compositeTextSizes=[c[\"text-size\"].possiblyEvaluate(new Oi(f),o),c[\"text-size\"].possiblyEvaluate(new Oi(p),o)]}if(\"composite\"===t.iconSizeData.kind){var d=t.iconSizeData,m=d.minZoom,g=d.maxZoom;u.compositeIconSizes=[c[\"icon-size\"].possiblyEvaluate(new Oi(m),o),c[\"icon-size\"].possiblyEvaluate(new Oi(g),o)]}u.layoutTextSize=c[\"text-size\"].possiblyEvaluate(new Oi(t.zoom+1),o),u.layoutIconSize=c[\"icon-size\"].possiblyEvaluate(new Oi(t.zoom+1),o),u.textMaxSize=c[\"text-size\"].possiblyEvaluate(new Oi(18));for(var y=l.get(\"text-line-height\")*Cl,v=\"map\"===l.get(\"text-rotation-alignment\")&&\"point\"!==l.get(\"symbol-placement\"),x=l.get(\"text-keep-upright\"),_=l.get(\"text-size\"),b=function(){var a=T[w],s=l.get(\"text-font\").evaluate(a,{},o).join(\",\"),c=_.evaluate(a,{},o),h=u.layoutTextSize.evaluate(a,{},o),f=u.layoutIconSize.evaluate(a,{},o),p={horizontal:{},vertical:void 0},d=a.text,m=[0,0];if(d){var g=d.toString(),b=l.get(\"text-letter-spacing\").evaluate(a,{},o)*Cl,A=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n=r[e].charCodeAt(0),pi.Arabic(n)||pi[\"Arabic Supplement\"](n)||pi[\"Arabic Extended-A\"](n)||pi[\"Arabic Presentation Forms-A\"](n)||pi[\"Arabic Presentation Forms-B\"](n))return!1;var n;return!0}(g)?b:0,M=l.get(\"text-anchor\").evaluate(a,{},o),S=l.get(\"text-variable-anchor\");if(!S){var E=l.get(\"text-radial-offset\").evaluate(a,{},o);m=E?Kc(M,[E*Cl,Jc]):l.get(\"text-offset\").evaluate(a,{},o).map((function(t){return t*Cl}))}var C=v?\"center\":l.get(\"text-justify\").evaluate(a,{},o),L=l.get(\"symbol-placement\"),I=\"point\"===L?l.get(\"text-max-width\").evaluate(a,{},o)*Cl:0,P=function(){t.allowVerticalPlacement&&di(g)&&(p.vertical=fc(d,e,r,i,s,I,y,M,\"left\",A,m,lc.vertical,!0,L,h,c))};if(!v&&S){for(var z=\"auto\"===C?S.map((function(t){return Qc(t)})):[C],O=!1,D=0;D<z.length;D++){var R=z[D];if(!p.horizontal[R])if(O)p.horizontal[R]=p.horizontal[0];else{var F=fc(d,e,r,i,s,I,y,\"center\",R,A,m,lc.horizontal,!1,L,h,c);F&&(p.horizontal[R]=F,O=1===F.positionedLines.length)}}P()}else{\"auto\"===C&&(C=Qc(M));var B=fc(d,e,r,i,s,I,y,M,C,A,m,lc.horizontal,!1,L,h,c);B&&(p.horizontal[C]=B),P(),di(g)&&v&&x&&(p.vertical=fc(d,e,r,i,s,I,y,M,C,A,m,lc.vertical,!1,L,h,c))}}var N=void 0,j=!1;if(a.icon&&a.icon.name){var U=n[a.icon.name];U&&(N=function(t,e,r){var n=bc(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}(i[a.icon.name],l.get(\"icon-offset\").evaluate(a,{},o),l.get(\"icon-anchor\").evaluate(a,{},o)),j=U.sdf,void 0===t.sdfIcons?t.sdfIcons=U.sdf:t.sdfIcons!==U.sdf&&k(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(U.pixelRatio!==t.pixelRatio||0!==l.get(\"icon-rotate\").constantOr(1))&&(t.iconsNeedLinear=!0))}var V=nu(p.horizontal)||p.vertical;t.iconsInText=!!V&&V.iconsInText,(V||N)&&function(t,e,r,n,i,a,o,s,l,c,u){var h=a.textMaxSize.evaluate(e,{});void 0===h&&(h=o);var f,p=t.layers[0].layout,d=p.get(\"icon-offset\").evaluate(e,{},u),m=nu(r.horizontal),g=24,y=o/g,v=t.tilePixelRatio*y,x=t.tilePixelRatio*h/g,_=t.tilePixelRatio*s,b=t.tilePixelRatio*p.get(\"symbol-spacing\"),w=p.get(\"text-padding\")*t.tilePixelRatio,T=p.get(\"icon-padding\")*t.tilePixelRatio,A=p.get(\"text-max-angle\")/180*Math.PI,M=\"map\"===p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),E=p.get(\"symbol-placement\"),C=b/2,L=p.get(\"icon-text-fit\");n&&\"none\"!==L&&(t.allowVerticalPlacement&&r.vertical&&(f=Tc(n,r.vertical,L,p.get(\"icon-text-fit-padding\"),d,y)),m&&(n=Tc(n,m,L,p.get(\"icon-text-fit-padding\"),d,y)));var I=function(s,h){h.x<0||h.x>=po||h.y<0||h.y>=po||function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,A){var M,S,E,C,L,I=t.addToLineVertexArray(e,r),P=0,z=0,O=0,D=0,R=-1,F=-1,B={},N=ja(\"\"),j=0,U=0;if(void 0===s._unevaluatedLayout.getValue(\"text-radial-offset\")?(j=(M=s.layout.get(\"text-offset\").evaluate(_,{},T).map((function(t){return t*Cl})))[0],U=M[1]):(j=s.layout.get(\"text-radial-offset\").evaluate(_,{},T)*Cl,U=Jc),t.allowVerticalPlacement&&n.vertical){var V=s.layout.get(\"text-rotate\").evaluate(_,{},T)+90,q=n.vertical;C=new Hc(l,e,c,u,h,q,f,p,d,V),o&&(L=new Hc(l,e,c,u,h,o,g,y,d,V))}if(i){var H=s.layout.get(\"icon-rotate\").evaluate(_,{}),G=\"none\"!==s.layout.get(\"icon-text-fit\"),Z=Nc(i,H,w,G),W=o?Nc(o,H,w,G):void 0;E=new Hc(l,e,c,u,h,i,g,y,!1,H),P=4*Z.length;var Y=t.iconSizeData,X=null;\"source\"===Y.kind?(X=[Ac*s.layout.get(\"icon-size\").evaluate(_,{})])[0]>eu&&k(t.layerIds[0]+': Value for \"icon-size\" is >= '+tu+'. Reduce your \"icon-size\".'):\"composite\"===Y.kind&&((X=[Ac*b.compositeIconSizes[0].evaluate(_,{},T),Ac*b.compositeIconSizes[1].evaluate(_,{},T)])[0]>eu||X[1]>eu)&&k(t.layerIds[0]+': Value for \"icon-size\" is >= '+tu+'. Reduce your \"icon-size\".'),t.addSymbols(t.icon,Z,X,x,v,_,!1,e,I.lineStartIndex,I.lineLength,-1,T),R=t.icon.placedSymbolArray.length-1,W&&(z=4*W.length,t.addSymbols(t.icon,W,X,x,v,_,lc.vertical,e,I.lineStartIndex,I.lineLength,-1,T),F=t.icon.placedSymbolArray.length-1)}for(var $ in n.horizontal){var J=n.horizontal[$];if(!S){N=ja(J.text);var K=s.layout.get(\"text-rotate\").evaluate(_,{},T);S=new Hc(l,e,c,u,h,J,f,p,d,K)}var Q=1===J.positionedLines.length;if(O+=ru(t,e,J,a,s,d,_,m,I,n.vertical?lc.horizontal:lc.horizontalOnly,Q?Object.keys(n.horizontal):[$],B,R,b,T),Q)break}n.vertical&&(D+=ru(t,e,n.vertical,a,s,d,_,m,I,lc.vertical,[\"vertical\"],B,F,b,T));var tt=S?S.boxStartIndex:t.collisionBoxArray.length,et=S?S.boxEndIndex:t.collisionBoxArray.length,rt=C?C.boxStartIndex:t.collisionBoxArray.length,nt=C?C.boxEndIndex:t.collisionBoxArray.length,it=E?E.boxStartIndex:t.collisionBoxArray.length,at=E?E.boxEndIndex:t.collisionBoxArray.length,ot=L?L.boxStartIndex:t.collisionBoxArray.length,st=L?L.boxEndIndex:t.collisionBoxArray.length,lt=-1,ct=function(t,e){return t&&t.circleDiameter?Math.max(t.circleDiameter,e):e};lt=ct(S,lt),lt=ct(C,lt),lt=ct(E,lt);var ut=(lt=ct(L,lt))>-1?1:0;ut&&(lt*=A/Cl),t.glyphOffsetArray.length>=fu.MAX_GLYPHS&&k(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),void 0!==_.sortKey&&t.addToSortKeyRanges(t.symbolInstances.length,_.sortKey),t.symbolInstances.emplaceBack(e.x,e.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,tt,et,rt,nt,it,at,ot,st,c,O,D,P,z,ut,0,f,j,U,lt)}(t,h,s,r,n,i,f,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,v,w,M,l,_,T,S,d,e,a,c,u,o)};if(\"line\"===E)for(var P=0,z=Fc(e.geometry,0,0,po,po);P<z.length;P+=1)for(var O=z[P],D=0,R=Dc(O,b,A,r.vertical||m,n,g,x,t.overscaling,po);D<R.length;D+=1){var F=R[D];m&&iu(t,m.text,C,F)||I(O,F)}else if(\"line-center\"===E)for(var B=0,N=e.geometry;B<N.length;B+=1){var j=N[B];if(j.length>1){var U=Oc(j,A,r.vertical||m,n,g,x);U&&I(j,U)}}else if(\"Polygon\"===e.type)for(var V=0,q=Fs(e.geometry,0);V<q.length;V+=1){var H=q[V],G=Wc(H,16);I(H[0],new kc(G.x,G.y,0))}else if(\"LineString\"===e.type)for(var Z=0,W=e.geometry;Z<W.length;Z+=1){var Y=W[Z];I(Y,new kc(Y[0].x,Y[0].y,0))}else if(\"Point\"===e.type)for(var X=0,$=e.geometry;X<$.length;X+=1)for(var J=0,K=$[X];J<K.length;J+=1){var Q=K[J];I([Q],new kc(Q.x,Q.y,0))}}(t,a,p,N,n,u,h,f,m,j,o)},w=0,T=t.features;w<T.length;w+=1)b();a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=zi,t.polygonIntersectsPolygon=bo,t.postMapLoadEvent=ct,t.postTurnstileEvent=st,t.potpack=nc,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=oi,t.registerForPluginStateChange=function(t){return t({pluginStatus:Mi,pluginURL:Si}),Li.on(\"pluginStateChange\",t),t},t.renderColorRamp=ts,t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.scale$1=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t},t.scale$2=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t},t.setCacheLimits=function(t,e){ht=t,ft=e},t.setRTLTextPlugin=function(t,e,r){if(void 0===r&&(r=!1),Mi===bi||Mi===wi||Mi===Ti)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Si=N.resolveURL(t),Mi=bi,Ai=e,Ci(),r||Pi()},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.sqrLen=Ho,t.styleSpec=Ft,t.sub=Vo,t.symbolSize=Cc,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=qo,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,m=r[0],g=r[1],y=r[2];return e===t?(t[12]=e[0]*m+e[4]*g+e[8]*y+e[12],t[13]=e[1]*m+e[5]*g+e[9]*y+e[13],t[14]=e[2]*m+e[6]*g+e[10]*y+e[14],t[15]=e[3]*m+e[7]*g+e[11]*y+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*m+s*g+h*y+e[12],t[13]=i*m+l*g+f*y+e[13],t[14]=a*m+c*g+p*y+e[14],t[15]=o*m+u*g+d*y+e[15]),t},t.triggerPluginCompletionEvent=Ei,t.uniqueId=m,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=$n,t.validateStyle=Xn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=tl,t.version=r,t.warnOnce=k,t.webpSupported=U,t.window=s,t.wrap=f})),n(0,(function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map((function(t){return i._layers[t.id]})),m=d[0];if(\"none\"!==m.visibility){var g=m.source||\"\",y=this.familiesBySource[g];y||(y=this.familiesBySource[g]={});var v=m.sourceLayer||\"_geojsonTileLayer\",x=y[v];x||(x=y[v]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var m=e[d];for(var g in m){var y=m[+g];if(y&&0!==y.bitmap.width&&0!==y.bitmap.height){var v=r[d][g].rect;t.AlphaImage.copy(y.bitmap,p,{x:0,y:0},{x:v.x+1,y:v.y+1},y.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId};function o(e,r,n){for(var i=new t.EvaluationParameters(r),a=0,o=e;a<o.length;a+=1)o[a].recalculate(i,n)}function s(e,r){var n=t.getArrayBuffer(e.request,(function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})}));return function(){n.cancel(),r()}}a.prototype.parse=function(e,r,n,a,s){var l=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var c=new t.DictionaryCoder(Object.keys(e.layers).sort()),u=new t.FeatureIndex(this.tileID,this.promoteId);u.bucketLayerIDs=[];var h,f,p,d,m={},g={featureIndex:u,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:n},y=r.familiesBySource[this.source];for(var v in y){var x=e.layers[v];if(x){1===x.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+v+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var _=c.encode(v),b=[],w=0;w<x.length;w++){var T=x.feature(w),k=u.getId(T,v);b.push({feature:T,id:k,index:w,sourceLayerIndex:_})}for(var A=0,M=y[v];A<M.length;A+=1){var S=M[A],E=S[0];E.minzoom&&this.zoom<Math.floor(E.minzoom)||E.maxzoom&&this.zoom>=E.maxzoom||\"none\"!==E.visibility&&(o(S,this.zoom,n),(m[E.id]=E.createBucket({index:u.bucketLayerIDs.length,layers:S,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:_,sourceID:this.source})).populate(b,g,this.tileID.canonical),u.bucketLayerIDs.push(S.map((function(t){return t.id}))))}}}var C=t.mapObject(g.glyphDependencies,(function(t){return Object.keys(t).map(Number)}));Object.keys(C).length?a.send(\"getGlyphs\",{uid:this.uid,stacks:C},(function(t,e){h||(h=t,f=e,P.call(l))})):f={};var L=Object.keys(g.iconDependencies);L.length?a.send(\"getImages\",{icons:L,source:this.source,tileID:this.tileID,type:\"icons\"},(function(t,e){h||(h=t,p=e,P.call(l))})):p={};var I=Object.keys(g.patternDependencies);function P(){if(h)return s(h);if(f&&p&&d){var e=new i(f),r=new t.ImageAtlas(p,d);for(var a in m){var l=m[a];l instanceof t.SymbolBucket?(o(l.layers,this.zoom,n),t.performSymbolLayout(l,f,e.positions,p,r.iconPositions,this.showCollisionBoxes,this.tileID.canonical)):l.hasPattern&&(l instanceof t.LineBucket||l instanceof t.FillBucket||l instanceof t.FillExtrusionBucket)&&(o(l.layers,this.zoom,n),l.addFeatures(g,this.tileID.canonical,r.patternPositions))}this.status=\"done\",s(null,{buckets:t.values(m).filter((function(t){return!t.isEmpty()})),featureIndex:u,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?f:null,iconMap:this.returnDependencies?p:null,glyphPositions:this.returnDependencies?e.positions:null})}}I.length?a.send(\"getImages\",{icons:I,source:this.source,tileID:this.tileID,type:\"patterns\"},(function(t,e){h||(h=t,d=e,P.call(l))})):d={},P.call(this)};var l=function(t,e,r,n){this.actor=t,this.layerIndex=e,this.availableImages=r,this.loadVectorData=n||s,this.loading={},this.loaded={}};l.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.RequestPerformance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,(function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.availableImages,n.actor,(function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))})),n.loaded=n.loaded||{},n.loaded[i]=s}))},l.prototype.reloadTile=function(t,e){var r=this,n=this.loaded,i=t.uid,a=this;if(n&&n[i]){var o=n[i];o.showCollisionBoxes=t.showCollisionBoxes;var s=function(t,n){var i=o.reloadCallback;i&&(delete o.reloadCallback,o.parse(o.vectorTile,a.layerIndex,r.availableImages,a.actor,i)),e(t,n)};\"parsing\"===o.status?o.reloadCallback=s:\"done\"===o.status&&(o.vectorTile?o.parse(o.vectorTile,this.layerIndex,this.availableImages,this.actor,s):s())}},l.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},l.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var c=t.window.ImageBitmap,u=function(){this.loaded={}};u.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=c&&a instanceof c?this.getImageData(a):a,s=new t.DEMData(n,o,i);this.loaded=this.loaded||{},this.loaded[n]=s,r(null,s)},u.prototype.getImageData=function(e){this.offscreenCanvas&&this.offscreenCanvasContext||(this.offscreenCanvas=new OffscreenCanvas(e.width,e.height),this.offscreenCanvasContext=this.offscreenCanvas.getContext(\"2d\")),this.offscreenCanvas.width=e.width,this.offscreenCanvas.height=e.height,this.offscreenCanvasContext.drawImage(e,0,0,e.width,e.height);var r=this.offscreenCanvasContext.getImageData(-1,-1,e.width+2,e.height+2);return this.offscreenCanvasContext.clearRect(0,0,this.offscreenCanvas.width,this.offscreenCanvas.height),new t.RGBAImage({width:r.width,height:r.height},r.data)},u.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var h=function t(e,r){var n,i=e&&e.type;if(\"FeatureCollection\"===i)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===i)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===i)t(e.geometry,r);else if(\"Polygon\"===i)f(e.coordinates,r);else if(\"MultiPolygon\"===i)for(n=0;n<e.coordinates.length;n++)f(e.coordinates[n],r);return e};function f(t,e){if(0!==t.length){p(t[0],e);for(var r=1;r<t.length;r++)p(t[r],!e)}}function p(t,e){for(var r=0,n=0,i=t.length,a=i-1;n<i;a=n++)r+=(t[n][0]-t[a][0])*(t[a][1]+t[n][1]);r>=0!=!!e&&t.reverse()}var d=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,m=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};m.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},m.prototype.toGeoJSON=function(t,e,r){return d.call(this,t,e,r)};var g=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};g.prototype.feature=function(t){return new m(this._features[t])};var y=t.vectorTile.VectorTileFeature,v=x;function x(t,e){this.options=e||{},this.features=t,this.length=t.length}function _(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}x.prototype.feature=function(t){return new _(this.features[t],this.options.extent)},_.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},_.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},_.prototype.toGeoJSON=y.prototype.toGeoJSON;var b=A,w=A,T=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new v(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return A({layers:r})},k=v;function A(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,M,t.layers[r])}(e,r),r.finish()}function M(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,S,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,P,a[r])}function S(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,E,t),e.writeVarintField(3,r.type),e.writeMessage(4,I,r)}function E(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function C(t,e){return(e<<3)+(7&t)}function L(t){return t<<1^t>>31}function I(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(C(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(C(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(L(f)),e.writeVarint(L(p)),i+=f,a+=p}3===n&&e.writeVarint(C(7,1))}}function P(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function z(t,e,r,n,i,a){if(!(i-n<=r)){var o=n+i>>1;O(t,e,o,n,i,a%2),z(t,e,r,n,o-1,a+1),z(t,e,r,o+1,i,a+1)}}function O(t,e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);O(t,e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[2*r+a],f=n,p=i;for(D(t,e,n,r),e[2*i+a]>h&&D(t,e,n,i);f<p;){for(D(t,e,f,p),f++,p--;e[2*f+a]<h;)f++;for(;e[2*p+a]>h;)p--}e[2*n+a]===h?D(t,e,n,p):D(t,e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}function D(t,e,r,n){R(t,r,n),R(e,2*r,2*n),R(e,2*r+1,2*n+1)}function R(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function F(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}b.fromVectorTileJs=w,b.fromGeojsonVt=T,b.GeoJSONWrapper=k;var B=function(t){return t[0]},N=function(t){return t[1]},j=function(t,e,r,n,i){void 0===e&&(e=B),void 0===r&&(r=N),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);z(o,s,n,0,o.length-1,0)};j.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var m=Math.floor((p+f)/2);s=e[2*m],l=e[2*m+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[m]);var g=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(m-1),c.push(g)),(0===h?i>=s:a>=l)&&(c.push(m+1),c.push(f),c.push(g))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},j.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)F(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],m=e[2*p+1];F(d,m,r,n)<=l&&s.push(t[p]);var g=(c+1)%2;(0===c?r-i<=d:n-i<=m)&&(o.push(h),o.push(p-1),o.push(g)),(0===c?r+i>=d:n+i>=m)&&(o.push(p+1),o.push(u),o.push(g))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var U={minZoom:0,maxZoom:16,minPoints:2,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:function(t){return t}},V=function(t){this.options=X(Object.create(U),t),this.trees=new Array(this.options.maxZoom+1)};function q(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function H(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:W(n),y:Y(i),zoom:1/0,index:e,parentId:-1}}function G(t){return{type:\"Feature\",id:t.id,properties:Z(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function Z(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return X(X({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function W(t){return t/360+.5}function Y(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function X(t,e){for(var r in e)t[r]=e[r];return t}function $(t){return t.x}function J(t){return t.y}function K(t,e,r,n){for(var i,a=n,o=r-e>>1,s=r-e,l=t[e],c=t[e+1],u=t[r],h=t[r+1],f=e+3;f<r;f+=3){var p=Q(t[f],t[f+1],l,c,u,h);if(p>a)i=f,a=p;else if(p===a){var d=Math.abs(f-o);d<s&&(i=f,s=d)}}a>n&&(i-e>3&&K(t,e,i,n),t[i+2]=a,r-i>3&&K(t,i,r,n))}function Q(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function tt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)et(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)et(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)et(t,e[n][i])}(i),i}function et(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function rt(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)nt(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)nt(i[c],s);else if(\"LineString\"===a)it(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],it(i[c],s,o,!1),t.push(tt(l,\"LineString\",s,e.properties));return}at(i,s,o,!1)}else if(\"Polygon\"===a)at(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)rt(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];at(i[c],u,o,!0),s.push(u)}}t.push(tt(l,a,s,e.properties))}}function nt(t,e){e.push(ot(t[0])),e.push(st(t[1])),e.push(0)}function it(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ot(t[s][0]),c=st(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,K(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function at(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];it(t[i],a,r,n),e.push(a)}}function ot(t){return t/360+.5}function st(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function lt(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var m=[];if(\"Point\"===f||\"MultiPoint\"===f)ct(h,m,r,n,i);else if(\"LineString\"===f)ut(h,m,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)ft(h,m,r,n,i,!1);else if(\"Polygon\"===f)ft(h,m,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var g=0;g<h.length;g++){var y=[];ft(h[g],y,r,n,i,!0),y.length&&m.push(y)}if(m.length){if(s.lineMetrics&&\"LineString\"===f){for(g=0;g<m.length;g++)l.push(tt(u.id,f,m[g],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===m.length?(f=\"LineString\",m=m[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===m.length?\"Point\":\"MultiPoint\"),l.push(tt(u.id,f,m,u.tags))}}}return l.length?l:null}function ct(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function ut(t,e,r,n,i,a,o){for(var s,l,c=ht(t),u=0===i?dt:mt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],m=t[f+2],g=t[f+3],y=t[f+4],v=0===i?p:d,x=0===i?g:y,_=!1;o&&(s=Math.sqrt(Math.pow(p-g,2)+Math.pow(d-y,2))),v<r?x>r&&(l=u(c,p,d,g,y,r),o&&(c.start=h+s*l)):v>n?x<n&&(l=u(c,p,d,g,y,n),o&&(c.start=h+s*l)):pt(c,p,d,m),x<r&&v>=r&&(l=u(c,p,d,g,y,r),_=!0),x>n&&v<=n&&(l=u(c,p,d,g,y,n),_=!0),!a&&_&&(o&&(c.end=h+s*l),e.push(c),c=ht(t)),o&&(h+=s)}var b=t.length-3;p=t[b],d=t[b+1],m=t[b+2],(v=0===i?p:d)>=r&&v<=n&&pt(c,p,d,m),b=c.length-3,a&&b>=3&&(c[b]!==c[0]||c[b+1]!==c[1])&&pt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function ht(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function ft(t,e,r,n,i,a){for(var o=0;o<t.length;o++)ut(t[o],e,r,n,i,a,!1)}function pt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function dt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function mt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function gt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=yt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(yt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(yt(a.geometry[s][c],e));i.push(l)}r.push(tt(a.id,o,i,a.tags))}return r}function yt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function vt(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(xt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(xt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function xt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function _t(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,bt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function bt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)wt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)wt(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)wt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function wt(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Tt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)rt(r,t.features[n],e,n);else\"Feature\"===t.type?rt(r,t,e):rt(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=lt(t,1,-1-r,r,0,-1,2,e),a=lt(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=lt(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=gt(i,1).concat(n)),a&&(n=n.concat(gt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function kt(t,e,r){return 32*((1<<t)*r+e)+t}function At(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new g(n.features),a=b(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}V.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(H(t[l],l));this.trees[i+1]=new j(s,$,J,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new j(s,$,J,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},V.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(W(r),Y(a),W(i),Y(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?G(p):this.points[p.index])}return c},V.prototype.getChildren=function(t){var e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?G(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},V.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},V.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},V.prototype.getClusterExpansionZoom=function(t){for(var e=this._getOriginZoom(t)-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},V.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},V.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c=l.numPoints,u={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:c?Z(l):this.points[l.index].properties},h=void 0;c?h=l.id:this.options.generateId?h=l.index:this.points[l.index].id&&(h=this.points[l.index].id),void 0!==h&&(u.id=h),a.features.push(u)}},V.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(+t,this.options.maxZoom+1))},V.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=n.minPoints,l=i/(a*Math.pow(2,e)),c=0;c<t.length;c++){var u=t[c];if(!(u.zoom<=e)){u.zoom=e;for(var h=this.trees[e+1],f=h.within(u.x,u.y,l),p=u.numPoints||1,d=p,m=0,g=f;m<g.length;m+=1){var y=g[m],v=h.points[y];v.zoom>e&&(d+=v.numPoints||1)}if(d>=s){for(var x=u.x*p,_=u.y*p,b=o&&p>1?this._map(u,!0):null,w=(c<<5)+(e+1)+this.points.length,T=0,k=f;T<k.length;T+=1){var A=k[T],M=h.points[A];if(!(M.zoom<=e)){M.zoom=e;var S=M.numPoints||1;x+=M.x*S,_+=M.y*S,M.parentId=w,o&&(b||(b=this._map(u,!0)),o(b,this._map(M)))}}u.parentId=w,r.push(q(x/d,_/d,w,d,b))}else if(r.push(u),d>1)for(var E=0,C=f;E<C.length;E+=1){var L=C[E],I=h.points[L];I.zoom<=e||(I.zoom=e,r.push(I))}}}return r},V.prototype._getOriginId=function(t){return t-this.points.length>>5},V.prototype._getOriginZoom=function(t){return(t-this.points.length)%32},V.prototype._map=function(t,e){if(t.numPoints)return e?X({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?X({},n):n},Tt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Tt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=kt(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=_t(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var m,g,y,v,x,_,b=.5*l.buffer/l.extent,w=.5-b,T=.5+b,k=1+b;m=g=y=v=null,x=lt(t,u,r-b,r+T,0,f.minX,f.maxX,l),_=lt(t,u,r+w,r+k,0,f.minX,f.maxX,l),t=null,x&&(m=lt(x,u,n-b,n+T,1,f.minY,f.maxY,l),g=lt(x,u,n+w,n+k,1,f.minY,f.maxY,l),x=null),_&&(y=lt(_,u,n-b,n+T,1,f.minY,f.maxY,l),v=lt(_,u,n+w,n+k,1,f.minY,f.maxY,l),_=null),c>1&&console.timeEnd(\"clipping\"),s.push(m||[],e+1,2*r,2*n),s.push(g||[],e+1,2*r,2*n+1),s.push(y||[],e+1,2*r+1,2*n),s.push(v||[],e+1,2*r+1,2*n+1)}}},Tt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=kt(t,e=(e%o+o)%o,r);if(this.tiles[s])return vt(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[kt(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?vt(this.tiles[s],i):null):null};var Mt=function(e){function r(t,r,n,i){e.call(this,t,r,n,At),i&&(this.loadGeoJSON=i)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new t.RequestPerformance(n.request);this.loadGeoJSON(n,(function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));h(o,!0);try{if(n.filter){var s=t.createExpression(n.filter,{type:\"boolean\",\"property-type\":\"data-driven\",overridable:!1,transition:!1});if(\"error\"===s.result)throw new Error(s.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));var l=o.features.filter((function(t){return s.value.evaluate({zoom:0},t)}));o={type:\"FeatureCollection\",features:l}}e._geoJSONIndex=n.cluster?new V(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],m=t.createExpression(d),g=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=m.value,a[h]=g.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):function(t,e){return new Tt(t,e)}(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var c={};if(i){var u=i.finish();u&&(c.resourceTiming={},c.resourceTiming[n.source]=JSON.parse(JSON.stringify(u)))}r(null,c)}))}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){try{e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterChildren=function(t,e){try{e(null,this._geoJSONIndex.getChildren(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterLeaves=function(t,e){try{e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))}catch(t){e(t)}},r}(l);var St=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.availableImages={},this.workerSourceTypes={vector:l,geojson:Mt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isParsed())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return St.prototype.setReferrer=function(t,e){this.referrer=e},St.prototype.setImages=function(t,e,r){for(var n in this.availableImages[t]=e,this.workerSources[t]){var i=this.workerSources[t][n];for(var a in i)i[a].availableImages=e}r()},St.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},St.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},St.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},St.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},St.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},St.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},St.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},St.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},St.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},St.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},St.prototype.syncRTLPluginState=function(e,r,n){try{t.plugin.setState(r);var i=t.plugin.getPluginURL();if(t.plugin.isLoaded()&&!t.plugin.isParsed()&&null!=i){this.self.importScripts(i);var a=t.plugin.isParsed();n(a?void 0:new Error(\"RTL Text Plugin failed to import scripts from \"+i),a)}}catch(t){n(t.toString())}},St.prototype.getAvailableImages=function(t){var e=this.availableImages[t];return e||(e=[]),e},St.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},St.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t),this.getAvailableImages(t))}return this.workerSources[t][e][r]},St.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new u),this.demWorkerSources[t][e]},St.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope&&(self.worker=new St(self)),St})),n(0,(function(t){var e=t.createCommonjsModule((function(t){function e(t){return!r(t)}function r(t){return\"undefined\"!=typeof window&&\"undefined\"!=typeof document?Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray?Function.prototype&&Function.prototype.bind?Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions?\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON?function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()?\"Uint8ClampedArray\"in window?ArrayBuffer.isView?function(){var t=document.createElement(\"canvas\");t.width=t.height=1;var e=t.getContext(\"2d\");if(!e)return!1;var r=e.getImageData(0,0,1,1);return r&&r.width===t.width}()?(r=t&&t.failIfMajorPerformanceCaveat,void 0===n[r]&&(n[r]=function(t){var r=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t);if(!r)return!1;var n=r.createShader(r.VERTEX_SHADER);return!(!n||r.isContextLost())&&(r.shaderSource(n,\"void main() {}\"),r.compileShader(n),!0===r.getShaderParameter(n,r.COMPILE_STATUS))}(r)),n[r]?void 0:\"insufficient WebGL support\"):\"insufficient Canvas/getImageData support\":\"insufficient ArrayBuffer support\":\"insufficient Uint8ClampedArray support\":\"insufficient worker support\":\"insufficient JSON support\":\"insufficient Object support\":\"insufficient Function support\":\"insufficent Array support\":\"not a browser\";var r}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e,window.mapboxgl.notSupportedReason=r);var n={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}})),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document&&t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout((function(){t.window.removeEventListener(\"click\",u,!0)}),0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect();return new t.Point(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=0;a<r.length;a++)i.push(new t.Point(r[a].clientX-n.left-e.clientLeft,r[a].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this._validate(t,e)&&(this.images[t]=e)},r.prototype._validate=function(e,r){var n=!0;return this._validateStretch(r.stretchX,r.data&&r.data.width)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchX\" value'))),n=!1),this._validateStretch(r.stretchY,r.data&&r.data.height)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchY\" value'))),n=!1),this._validateContent(r.content,r)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"content\" value'))),n=!1),n},r.prototype._validateStretch=function(t,e){if(!t)return!0;for(var r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];if(a[0]<r||a[1]<a[0]||e<a[1])return!1;r=a[1]}return!0},r.prototype._validateContent=function(t,e){return!(t&&(4!==t.length||t[0]<0||e.data.width<t[0]||t[1]<0||e.data.height<t[1]||t[2]<0||e.data.width<t[2]||t[3]<0||e.data.height<t[3]||t[2]<t[0]||t[3]<t[1]))},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,stretchX:s.stretchX,stretchY:s.stretchY,content:s.content,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented);var p=g,d=g,m=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function y(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(v(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(v(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function v(t,e,r,n,i){r[0]=0,n[0]=-m,n[1]=+m;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+m}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?m:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?m:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(y(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),y(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,(function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{},ranges:{}});var o=a.glyphs[i];if(void 0===o){if(o=n._tinySDF(a,r,i))return a.glyphs[i]=o,void e(null,{stack:r,id:i,glyph:o});var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else if(a.ranges[s])e(null,{stack:r,id:i,glyph:o});else{var l=a.requests[s];l||(l=a.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,(function(t,e){if(e){for(var r in e)n._doesCharSupportLocalGlyph(+r)||(a.glyphs[+r]=e[+r]);a.ranges[s]=!0}for(var i=0,o=l;i<o.length;i+=1)(0,o[i])(t,e);delete a.requests[s]}))),l.push((function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})}))}}else e(null,{stack:r,id:i,glyph:o})}),(function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}}))},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar[\"CJK Unified Ideographs\"](e)||t.isChar[\"Hangul Syllables\"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&this._doesCharSupportLocalGlyph(n)){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new x.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,(function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}}))},x.TinySDF=p;var _=function(){this.specification=t.styleSpec.light.position};_.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},_.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new _,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=\"-transition\",T=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,w)?this._transitionable.setTransition(n.slice(0,-11),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),k=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}};k.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]},k.prototype.getDashRanges=function(t,e,r){var n=[],i=t.length%2==1?-t[t.length-1]*r:0,a=t[0]*r,o=!0;n.push({left:i,right:a,isDash:o,zeroLength:0===t[0]});for(var s=t[0],l=1;l<t.length;l++){o=!o;var c=t[l];i=s*r,a=(s+=c)*r,n.push({left:i,right:a,isDash:o,zeroLength:0===c})}return n},k.prototype.addRoundDash=function(t,e,r){for(var n=e/2,i=-r;i<=r;i++)for(var a=this.nextRow+r+i,o=this.width*a,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),h=Math.abs(c-l.right),f=Math.min(u,h),p=void 0,d=i/r*(n+1);if(l.isDash){var m=n-Math.abs(d);p=Math.sqrt(f*f+m*m)}else p=n-Math.sqrt(f*f+d*d);this.data[o+c]=Math.max(0,Math.min(255,p+128))}},k.prototype.addRegularDash=function(t){for(var e=t.length-1;e>=0;--e){var r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}var i=t[0],a=t[t.length-1];i.isDash===a.isDash&&(i.left=a.left-this.width,a.right=i.right+this.width);for(var o=this.width*this.nextRow,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),h=Math.abs(c-l.right),f=Math.min(u,h),p=l.isDash?f:-f;this.data[o+c]=Math.max(0,Math.min(255,p+128))}},k.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];if(0!==a){var s=this.width/a,l=this.getDashRanges(e,this.width,s);r?this.addRoundDash(l,s,n):this.addRegularDash(l)}var c={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,c},k.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))};var A=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function M(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(t.extend(a,e),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map((function(t){return t.id}))),o.tiles=r.canonicalizeTileset(o,e.url),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame((function(){return i(null,e)}))}A.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,(function(t,n){t.send(e,r,n)}),n)},A.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},A.prototype.remove=function(){this.actors.forEach((function(t){t.remove()})),this.actors=[],this.workerPool.release(this.id)},A.Actor=t.Actor;var S=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};S.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},S.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var E=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new S(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setSourceProperty=function(t){this._tileJSONRequest&&this._tileJSONRequest.cancel(),t(),this.map.style.sourceCaches[this.id].clearTiles(),this.load()},r.prototype.setTiles=function(t){var e=this;return this.setSourceProperty((function(){e._options.tiles=t})),this},r.prototype.setUrl=function(t){var e=this;return this.setSourceProperty((function(){e.url=t,e._options.url=t})),this},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme)),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};function a(n,i){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,e.actor&&\"expired\"!==e.state?\"loading\"===e.state?e.reloadCallback=r:e.request=e.actor.send(\"reloadTile\",i,a.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send(\"loadTile\",i,a.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:\"raster\"},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new S(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),(function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}}))},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({type:\"raster-dem\"},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);function i(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=t.window.ImageBitmap&&a instanceof t.window.ImageBitmap&&t.offscreenCanvasSupported()?a:t.browser.getImageData(a,1),s={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:o,encoding:this.encoding};e.actor&&\"expired\"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send(\"loadDEMTile\",s,i.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&t.actor.send(\"removeDEMTile\",{uid:t.uid,source:this.id})},r}(C),I=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=i.getActor(),this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution),this.promoteId=n.promoteId;var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,minPoints:Math.max(2,n.clusterMinPoints||2),extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1,generateId:n.generateId||!1},clusterProperties:n.clusterProperties,filter:n.filter},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}}))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}})),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.actor.send(this.type+\".loadData\",n,(function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.actor.send(r.type+\".coalesce\",{source:n.source},null),e(t))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,i=e.actor?\"reloadTile\":\"loadTile\";e.actor=this.actor;var a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};e.request=this.actor.send(i,a,(function(t,a){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))}))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send(\"removeSource\",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),z=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),(function(i,a){n._loaded=!0,i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())}))},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,(function(){e.texture=null})),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map((function(t){return r.tileID.getTilePoint(t)._round()}));return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented);var O=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,(function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",(function(){e.map.triggerRepaint()})),e.map&&e.video.play(),e._finishLoading())}))},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+this.id,null,\"Playback for this video can be set only between the \"+r.start(0)+\" and \"+r.end(0)+\"-second mark.\"))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(z),D=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some((function(t){return!Array.isArray(t)||2!==t.length||t.some((function(t){return\"number\"!=typeof t}))}))||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(z),R={vector:E,raster:C,\"raster-dem\":L,geojson:I,video:O,image:z,canvas:D};function F(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function B(t,e,r,n,i,a){var o=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(i&&i.layers,e,t.id),s=a.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(N);for(var c=[],u=0,h=l;u<h.length;u+=1){var f=h[u];c.push({wrappedTileID:f.tileID.wrapped().key,queryResults:f.tile.queryRenderedFeatures(e,r,t._state,f.queryGeometry,f.cameraQueryGeometry,f.scale,i,a,s,F(t.transform,f.tileID))})}var p=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var m=d[p];h[m.featureIndex]||(h[m.featureIndex]=!0,f.push(m))}}return e}(c);for(var d in p)p[d].forEach((function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return p}function N(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var j=function(t,e){this.max=t,this.onRemove=e,this.reset()};j.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},j.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout((function(){n.remove(t,a)}),r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},j.prototype.has=function(t){return t.wrapped().key in this.data},j.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},j.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},j.prototype.getByKey=function(t){var e=this.data[t];return e?e[0].value:null},j.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},j.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},j.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this},j.prototype.filter=function(t){var e=[];for(var r in this.data)for(var n=0,i=this.data[r];n<i.length;n+=1){var a=i[n];t(a.value)||e.push(a)}for(var o=0,s=e;o<s.length;o+=1){var l=s[o];this.remove(l.value.tileID,l)}};var U=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},q=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};q.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},q.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},q.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},q.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[V[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},q.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var H=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};H.prototype.get=function(){return this.current},H.prototype.set=function(t){},H.prototype.getDefault=function(){return this.default},H.prototype.setDefault=function(){this.set(this.default)};var G=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(H),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(H),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(H),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(H),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(H),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(H),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(H),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(H),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(H),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(H),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(H),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(H),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(H),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(H),at=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(H),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(H),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(H),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(H),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(H),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(H),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(H),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(H),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(H),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(H),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(H),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(H),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(H),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(H),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(H),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(H),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(H),wt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(H),Tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(wt),kt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(wt),At=function(t,e,r,n){this.context=t,this.width=e,this.height=r;var i=t.gl,a=this.framebuffer=i.createFramebuffer();this.colorAttachment=new Tt(t,a),n&&(this.depthAttachment=new kt(t,a))};At.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r)}t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var St=7680,Et=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};Et.disabled=new Et({func:519,mask:0},0,0,St,St,St);var Ct=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Ct.Replace=[1,0],Ct.disabled=new Ct(Ct.Replace,t.Color.transparent,[!1,!1,!1,!1]),Ct.unblended=new Ct(Ct.Replace,t.Color.transparent,[!0,!0,!0,!0]),Ct.alphaBlended=new Ct([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Lt=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Lt.disabled=new Lt(!1,1029,2305),Lt.backCCW=new Lt(!0,1029,2305);var It=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new G(this),this.clearDepth=new Z(this),this.clearStencil=new W(this),this.colorMask=new Y(this),this.depthMask=new X(this),this.stencilMask=new $(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new tt(this),this.depthTest=new et(this),this.depthFunc=new rt(this),this.blend=new nt(this),this.blendFunc=new it(this),this.blendColor=new at(this),this.blendEquation=new ot(this),this.cullFace=new st(this),this.cullFaceSide=new lt(this),this.frontFace=new ct(this),this.program=new ut(this),this.activeTexture=new ht(this),this.viewport=new ft(this),this.bindFramebuffer=new pt(this),this.bindRenderbuffer=new dt(this),this.bindTexture=new mt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new yt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new xt(this),this.pixelStoreUnpackPremultiplyAlpha=new _t(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&(t.getExtension(\"OES_texture_half_float_linear\"),this.extRenderToTextureHalfFloat=t.getExtension(\"EXT_color_buffer_half_float\")),this.extTimerQuery=t.getExtension(\"EXT_disjoint_timer_query\"),this.maxTextureSize=t.getParameter(t.MAX_TEXTURE_SIZE)};It.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},It.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},It.prototype.createIndexBuffer=function(t,e){return new U(this,t,e)},It.prototype.createVertexBuffer=function(t,e,r){return new q(this,t,e,r)},It.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},It.prototype.createFramebuffer=function(t,e,r){return new At(this,t,e,r)},It.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},It.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},It.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},It.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},It.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Ct.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},It.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Pt=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",(function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))})),this.on(\"error\",(function(){a._sourceErrored=!0})),this._source=function(e,r,n,i){var a=new R[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a}(r,n,i,this),this._tiles={},this._cache=new j(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,(function(){}))},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,(function(){}))},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return t.values(this._tiles).map((function(t){return t.tileID})).sort(zt).map((function(t){return t.key}))},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(i,e)&&n.push(this._tiles[i]);return e?n.sort((function(e,n){var i=e.tileID,a=n.tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x})).map((function(t){return t.tileID.key})):n.map((function(t){return t.tileID})).sort(zt).map((function(t){return t.key}))},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){if(t.key in this._loadedParentTiles){var r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(var n=t.overscaledZ-1;n>=e;n--){var i=t.scaledTo(n),a=this._getLoadedTile(i);if(a)return a}},r.prototype._getLoadedTile=function(t){var e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map((function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)})):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter((function(t){return n._source.hasTile(t)})))):i=[];var a=e.coveringZoomLevel(this._source),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Ot(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],m=this._tiles[p];if(m&&!(m.fadeEndTime&&m.fadeEndTime<=t.browser.now())){var g=this.findLoadedParent(d,o);g&&(this._addTile(g.tileID),c[g.tileID.key]=g.tileID),u[p]=d}}for(var y in this._retainLoadedChildren(u,a,s,l),c)l[y]||(this._coveredTiles[y]=!0,l[y]=c[y])}for(var v in l)this._tiles[v].clearFadeHold();for(var x=0,_=t.keysDifference(this._tiles,l);x<_.length;x+=1){var b=_[x],w=this._tiles[b];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(b)}this._updateLoadedParentTileCache()}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],m=this._tiles[d.key];if(!m.hasData()){if(e+1>this._source.maxzoom){var g=d.children(this._source.maxzoom)[0],y=this.getTile(g);if(y&&y.hasData()){n[g.key]=g;continue}}else{var v=d.children(this._source.maxzoom);if(n[v[0].key]&&n[v[1].key]&&n[v[2].key]&&n[v[3].key])continue}for(var x=m.wasRequested(),_=d.overscaledZ-1;_>=a;--_){var b=d.scaledTo(_);if(i[b.key])break;if(i[b.key]=!0,!(m=this.getTile(b))&&x&&(m=this._addTile(b)),m&&(n[b.key]=b,x=m.wasRequested(),m.hasData()))break}}}return n},r.prototype._updateLoadedParentTileCache=function(){for(var t in this._loadedParentTiles={},this._tiles){for(var e=[],r=void 0,n=this._tiles[t].tileID;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);var i=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(i))break;n=i}for(var a=0,o=e;a<o.length;a+=1){var s=o[a];this._loadedParentTiles[s]=r}}},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout((function(){r._reloadTile(t,\"expired\"),delete r._timers[t]}),n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map((function(t){return o.pointCoordinate(t)})),c=s.map((function(t){return o.pointCoordinate(t)})),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,m=0,g=c;m<g.length;m+=1){var y=g[m];h=Math.min(h,y.x),f=Math.min(f,y.y),p=Math.max(p,y.x),d=Math.max(d,y.y)}for(var v=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,m=Math.pow(2,o.zoom-n.tileID.overscaledZ),g=r*n.queryPadding*t.EXTENT/n.tileSize/m,y=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(y[0].x-g<t.EXTENT&&y[0].y-g<t.EXTENT&&y[1].x+g>=0&&y[1].y+g>=0){var v=l.map((function(t){return s.getTilePoint(t)})),x=c.map((function(t){return s.getTilePoint(t)}));a.push({tile:n,tileID:s,queryGeometry:v,cameraQueryGeometry:x,scale:m})}}},x=0;x<u.length;x++)v(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map((function(t){return e._tiles[t].tileID})),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Ot(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r.prototype.setDependencies=function(t,e,r){var n=this._tiles[t];n&&n.setDependencies(e,r)},r.prototype.reloadTilesForDependencies=function(t,e){for(var r in this._tiles)this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\");this._cache.filter((function(r){return!r.hasDependency(t,e)}))},r}(t.Evented);function zt(t,e){var r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function Ot(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Dt(){return new t.window.Worker(oa.workerUrl)}Pt.maxOverzooming=10,Pt.maxUnderzooming=3;var Rt=\"mapboxgl_preloaded_worker_pool\",Ft=function(){this.active={}};Ft.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<Ft.workerCount;)this.workers.push(new Dt);return this.active[t]=!0,this.workers.slice()},Ft.prototype.release=function(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((function(t){t.terminate()})),this.workers=null)},Ft.prototype.isPreloaded=function(){return!!this.active[Rt]},Ft.prototype.numActive=function(){return Object.keys(this.active).length};var Bt,Nt=Math.floor(t.browser.hardwareConcurrency/2);function jt(){return Bt||(Bt=new Ft),Bt}function Ut(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach((function(t){t in r&&(n[t]=r[t])})),n}function Vt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Ut(t[n],e[t[n].ref]));return t}Ft.workerCount=Math.max(Math.min(Nt,6),1);var qt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Ht(t,e,r){r.push({command:qt.addSource,args:[t,e[t]]})}function Gt(t,e,r){e.push({command:qt.removeSource,args:[t]}),r[t]=!0}function Zt(t,e,r,n){Gt(t,r,n),Ht(t,e,r)}function Wt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function Yt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Xt(t){return t.id}function $t(t,e){return t[e.id]=e,t}function Jt(e,r){if(!e)return[{command:qt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:qt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:qt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:qt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:qt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:qt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:qt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:qt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:qt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:qt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||Gt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Wt(e,r,a)?n.push({command:qt.setGeoJSONSourceData,args:[a,r[a].data]}):Zt(a,r,n,i)):Ht(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach((function(t){i[t.source]?n.push({command:qt.removeLayer,args:[t.id]}):o.push(t)})),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Xt),f=r.map(Xt),p=e.reduce($t,{}),d=r.reduce($t,{}),m=h.slice(),g=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:qt.removeLayer,args:[o]}),m.splice(m.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],m[m.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:qt.removeLayer,args:[o]}),m.splice(m.lastIndexOf(o,m.length-a),1)):a++,c=m[m.length-i],n.push({command:qt.addLayer,args:[d[o],c]}),m.splice(m.length-i,0,o),g[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!g[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in Yt(s.layout,l.layout,n,o,null,qt.setLayoutProperty),Yt(s.paint,l.paint,n,o,null,qt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:qt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:qt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),qt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:qt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),qt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:qt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:qt.removeLayer,args:[o]}),c=m[m.lastIndexOf(o)+1],n.push({command:qt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:qt.setStyle,args:[r]}]}return n}var Kt=function(t,e){this.reset(t,e)};Kt.prototype.reset=function(t,e){this.points=t||[],this._distances=[0];for(var r=1;r<this.points.length;r++)this._distances[r]=this._distances[r-1]+this.points[r].dist(this.points[r-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding},Kt.prototype.lerp=function(e){if(1===this.points.length)return this.points[0];e=t.clamp(e,0,1);for(var r=1,n=this._distances[r],i=e*this.paddedLength+this.padding;n<i&&r<this._distances.length;)n=this._distances[++r];var a=r-1,o=this._distances[a],s=n-o,l=s>0?(i-o)/s:0;return this.points[a].mult(1-l).add(this.points[r].mult(l))};var Qt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function te(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function ee(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function re(e,r){var n=[e.x,e.y,0,1];pe(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function ne(t,e){return.5+t/e*.5}function ie(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function ae(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,m=n.transform.width/n.transform.height,g=!1,y=0;y<d.length;y++){var v=d.get(y);if(v.hidden||v.writingMode===t.WritingMode.vertical&&!g)fe(v.numGlyphs,f);else{g=!1;var x=[v.anchorX,v.anchorY,0,1];if(t.transformMat4(x,x,r),ie(x,h)){var _=x[3],b=ne(n.transform.cameraToCenterDistance,_),w=t.evaluateSizeForFeature(c,u,v),T=s?w/b:w*b,k=new t.Point(v.anchorX,v.anchorY),A=re(k,a).point,M={},S=le(v,T,!1,l,r,a,o,e.glyphOffsetArray,p,f,A,k,M,m);g=S.useVertical,(S.notEnoughRoom||g||S.needsFlipping&&le(v,T,!0,l,r,a,o,e.glyphOffsetArray,p,f,A,k,M,m).notEnoughRoom)&&fe(v.numGlyphs,f)}else fe(v.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function oe(t,e,r,n,i,a,o,s,l,c,u){var h=s.glyphStartIndex+s.numGlyphs,f=s.lineStartIndex,p=s.lineStartIndex+s.lineLength,d=e.getoffsetX(s.glyphStartIndex),m=e.getoffsetX(h-1),g=ue(t*d,r,n,i,a,o,s.segment,f,p,l,c,u);if(!g)return null;var y=ue(t*m,r,n,i,a,o,s.segment,f,p,l,c,u);return y?{first:g,last:y}:null}function se(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function le(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var m,g=r/24,y=e.lineOffsetX*g,v=e.lineOffsetY*g;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,_=e.lineStartIndex,b=e.lineStartIndex+e.lineLength,w=oe(g,l,y,v,n,h,f,e,c,o,p);if(!w)return{notEnoughRoom:!0};var T=re(w.first.point,s).point,k=re(w.last.point,s).point;if(i&&!n){var A=se(e.writingMode,T,k,d);if(A)return A}m=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)m.push(ue(g*l.getoffsetX(M),y,v,n,h,f,e.segment,_,b,c,o,p));m.push(w.last)}else{if(i&&!n){var S=re(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=re(C,a),I=L.signedDistanceFromCamera>0?L.point:ce(f,C,S,1,a),P=se(e.writingMode,S,I,d);if(P)return P}var z=ue(g*l.getoffsetX(e.glyphStartIndex),y,v,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p);if(!z)return{notEnoughRoom:!0};m=[z]}for(var O=0,D=m;O<D.length;O+=1){var R=D[O];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ce(t,e,r,n,i){var a=re(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function ue(e,r,n,i,a,o,s,l,c,u,h,f){var p=i?e-r:e+r,d=p>0?1:-1,m=0;i&&(d*=-1,m=Math.PI),d<0&&(m+=Math.PI);for(var g=d>0?l+s:l+s+1,y=a,v=a,x=0,_=0,b=Math.abs(p),w=[];x+_<=b;){if((g+=d)<l||g>=c)return null;if(v=y,w.push(y),void 0===(y=f[g])){var T=new t.Point(u.getx(g),u.gety(g)),k=re(T,h);if(k.signedDistanceFromCamera>0)y=f[g]=k.point;else{var A=g-d;y=ce(0===x?o:new t.Point(u.getx(A),u.gety(A)),T,v,b-x+1,h)}}x+=_,_=v.dist(y)}var M=(b-x)/_,S=y.sub(v),E=S.mult(M)._add(v);E._add(S._unit()._perp()._mult(n*d));var C=m+Math.atan2(y.y-v.y,y.x-v.x);return w.push(E),{point:E,angle:C,path:w}}Qt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Qt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Qt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Qt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Qt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Qt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Qt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Qt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Qt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Qt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Qt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var m=this.circleCells[i];if(null!==m)for(var g=this.circles,y=0,v=m;y<v.length;y+=1){var x=v[y];if(!l.circle[x]){l.circle[x]=!0;var _=3*x;if(this._circleAndRectCollide(g[_],g[_+1],g[_+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var b=g[_],w=g[_+1],T=g[_+2];a.push({key:this.circleKeys[x],x1:b-T,y1:w-T,x2:b+T,y2:w+T})}}}},Qt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var m=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[m+0],h[m+1],h[m+2],h[m+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var g=this.circleCells[i];if(null!==g)for(var y=this.circles,v=0,x=g;v<x.length;v+=1){var _=x[v];if(!c.circle[_]){c.circle[_]=!0;var b=3*_;if(this._circlesCollide(y[b],y[b+1],y[b+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[_])))return a.push(!0),!0}}},Qt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Qt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Qt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Qt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Qt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var he=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function fe(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(he,3*n)}}function pe(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var de=100,me=function(t,e,r){void 0===e&&(e=new Qt(t.width+200,t.height+200,25)),void 0===r&&(r=new Qt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+de,this.screenBottomBoundary=t.height+de,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function ge(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}me.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},me.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],m=new t.Point(r.anchorX,r.anchorY),g=re(m,o),y=ne(this.transform.cameraToCenterDistance,g.signedDistanceFromCamera),v=(u?a/y:a*y)/t.ONE_EM,x=re(m,s).point,_=oe(v,i,r.lineOffsetX*v,r.lineOffsetY*v,!1,x,m,r,n,s,{}),b=!1,w=!1,T=!0;if(_){for(var k=.5*f*y+p,A=new t.Point(-100,-100),M=new t.Point(this.screenRightBoundary,this.screenBottomBoundary),S=new Kt,E=_.first,C=_.last,L=[],I=E.path.length-1;I>=1;I--)L.push(E.path[I]);for(var P=1;P<C.path.length;P++)L.push(C.path[P]);var z=2.5*k;if(l){var O=L.map((function(t){return re(t,l)}));L=O.some((function(t){return t.signedDistanceFromCamera<=0}))?[]:O.map((function(t){return t.point}))}var D=[];if(L.length>0){for(var R=L[0].clone(),F=L[0].clone(),B=1;B<L.length;B++)R.x=Math.min(R.x,L[B].x),R.y=Math.min(R.y,L[B].y),F.x=Math.max(F.x,L[B].x),F.y=Math.max(F.y,L[B].y);D=R.x>=A.x&&F.x<=M.x&&R.y>=A.y&&F.y<=M.y?[L]:F.x<A.x||R.x>M.x||F.y<A.y||R.y>M.y?[]:t.clipLine([L],A.x,A.y,M.x,M.y)}for(var N=0,j=D;N<j.length;N+=1){var U=j[N];S.reset(U,.25*k);var V;V=S.length<=.5*k?1:Math.ceil(S.paddedLength/z)+1;for(var q=0;q<V;q++){var H=q/Math.max(V-1,1),G=S.lerp(H),Z=G.x+de,W=G.y+de;d.push(Z,W,k,0);var Y=Z-k,X=W-k,$=Z+k,J=W+k;if(T=T&&this.isOffscreen(Y,X,$,J),w=w||this.isInsideGrid(Y,X,$,J),!e&&this.grid.hitTestCircle(Z,W,k,h)&&(b=!0,!c))return{circles:[],offscreen:!1,collisionDetected:b}}}}return{circles:!c&&b||!w?[]:d,offscreen:T,collisionDetected:b}},me.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+de,c.y+de);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var m=d[p],g=m.key;if(void 0===h[g.bucketInstanceId]&&(h[g.bucketInstanceId]={}),!h[g.bucketInstanceId][g.featureIndex]){var y=[new t.Point(m.x1,m.y1),new t.Point(m.x2,m.y1),new t.Point(m.x2,m.y2),new t.Point(m.x1,m.y2)];t.polygonIntersectsPolygon(r,y)&&(h[g.bucketInstanceId][g.featureIndex]=!0,void 0===f[g.bucketInstanceId]&&(f[g.bucketInstanceId]=[]),f[g.bucketInstanceId].push(g.featureIndex))}}return f},me.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},me.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},me.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return pe(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+de,(-i[1]/i[3]+1)/2*this.transform.height+de),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},me.prototype.isOffscreen=function(t,e,r,n){return r<de||t>=this.screenRightBoundary||n<de||e>this.screenBottomBoundary},me.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary},me.prototype.getViewportMatrix=function(){var e=t.identity([]);return t.translate(e,e,[-100,-100,0]),e};var ye=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ye.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ve=function(t,e,r,n,i){this.text=new ye(t?t.text:null,e,r,i),this.icon=new ye(t?t.icon:null,e,n,i)};ve.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var xe=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},_e=function(){this.invProjMatrix=t.create(),this.viewportMatrix=t.create(),this.circles=[]},be=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},we=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function Te(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateVariableOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}function ke(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}we.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var Ae=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new me(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new we(r),this.collisionCircleArrays={},this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function Me(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}Ae.prototype.getBucketParts=function(e,r,n,i){var a=n.getBucket(r),o=n.latestFeatureIndex;if(a&&o&&r.id===a.layerIds[0]){var s=n.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),u=n.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(n.tileID.toUnwrapped()),f=\"map\"===l.get(\"text-pitch-alignment\"),p=\"map\"===l.get(\"text-rotation-alignment\"),d=ge(n,1,this.transform.zoom),m=te(h,f,p,this.transform,d),g=null;if(f){var y=ee(h,f,p,this.transform,d);g=t.multiply([],this.transform.labelPlaneMatrix,y)}this.retainedQueryData[a.bucketInstanceId]=new be(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,n.tileID);var v={bucket:a,layout:l,posMatrix:h,textLabelPlaneMatrix:m,labelToScreenMatrix:g,scale:c,textPixelRatio:u,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:t.evaluateSizeForZoom(a.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(a.sourceID)};if(i)for(var x=0,_=a.sortKeyRanges;x<_.length;x+=1){var b=_[x],w=b.sortKey,T=b.symbolInstanceStart,k=b.symbolInstanceEnd;e.push({sortKey:w,symbolInstanceStart:T,symbolInstanceEnd:k,parameters:v})}else e.push({symbolInstanceStart:0,symbolInstanceEnd:a.symbolInstances.length,parameters:v})}},Ae.prototype.attemptAnchorPlacement=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var m,g=[h.textOffset0,h.textOffset1],y=Te(t,r,n,g,i),v=this.collisionIndex.placeCollisionBox(ke(e,y.x,y.y,a,o,this.transform.angle),u,s,l,c.predicate);if(!d||0!==this.collisionIndex.placeCollisionBox(ke(d,y.x,y.y,a,o,this.transform.angle),u,s,l,c.predicate).box.length)return v.box.length>0?(this.prevPlacement&&this.prevPlacement.variableOffsets[h.crossTileID]&&this.prevPlacement.placements[h.crossTileID]&&this.prevPlacement.placements[h.crossTileID].text&&(m=this.prevPlacement.variableOffsets[h.crossTileID].anchor),this.variableOffsets[h.crossTileID]={textOffset:g,width:r,height:n,anchor:t,textBoxScale:i,prevAnchor:m},this.markUsedJustification(f,t,h,p),f.allowVerticalPlacement&&(this.markUsedOrientation(f,p,h),this.placedOrientations[h.crossTileID]=p),{shift:y,placedGlyphBoxes:v}):void 0},Ae.prototype.placeLayerBucketPart=function(e,r,n){var i=this,a=e.parameters,o=a.bucket,s=a.layout,l=a.posMatrix,c=a.textLabelPlaneMatrix,u=a.labelToScreenMatrix,h=a.textPixelRatio,f=a.holdingForFade,p=a.collisionBoxArray,d=a.partiallyEvaluatedTextSize,m=a.collisionGroup,g=s.get(\"text-optional\"),y=s.get(\"icon-optional\"),v=s.get(\"text-allow-overlap\"),x=s.get(\"icon-allow-overlap\"),_=\"map\"===s.get(\"text-rotation-alignment\"),b=\"map\"===s.get(\"text-pitch-alignment\"),w=\"none\"!==s.get(\"icon-text-fit\"),T=\"viewport-y\"===s.get(\"symbol-z-order\"),k=v&&(x||!o.hasIconData()||y),A=x&&(v||!o.hasTextData()||g);!o.collisionArrays&&p&&o.deserializeCollisionBoxes(p);var M=function(e,a){if(!r[e.crossTileID])if(f)i.placements[e.crossTileID]=new xe(!1,!1,!1);else{var p,T=!1,M=!1,S=!0,E=null,C={box:null,offscreen:null},L={box:null,offscreen:null},I=null,P=null,z=0,O=0,D=0;a.textFeatureIndex?z=a.textFeatureIndex:e.useRuntimeCollisionCircles&&(z=e.featureIndex),a.verticalTextFeatureIndex&&(O=a.verticalTextFeatureIndex);var R=a.textBox;if(R){var F=function(r){var n=t.WritingMode.horizontal;if(o.allowVerticalPlacement&&!r&&i.prevPlacement){var a=i.prevPlacement.placedOrientations[e.crossTileID];a&&(i.placedOrientations[e.crossTileID]=a,n=a,i.markUsedOrientation(o,n,e))}return n},B=function(r,n){if(o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&a.verticalTextBox)for(var i=0,s=o.writingModes;i<s.length&&(s[i]===t.WritingMode.vertical?(C=n(),L=C):C=r(),!(C&&C.box&&C.box.length));i+=1);else C=r()};if(s.get(\"text-variable-anchor\")){var N=s.get(\"text-variable-anchor\");if(i.prevPlacement&&i.prevPlacement.variableOffsets[e.crossTileID]){var j=i.prevPlacement.variableOffsets[e.crossTileID];N.indexOf(j.anchor)>0&&(N=N.filter((function(t){return t!==j.anchor}))).unshift(j.anchor)}var U=function(t,r,n){for(var a=t.x2-t.x1,s=t.y2-t.y1,c=e.textBoxScale,u=w&&!x?r:null,f={box:[],offscreen:!1},p=v?2*N.length:N.length,d=0;d<p;++d){var g=N[d%N.length],y=d>=N.length,k=i.attemptAnchorPlacement(g,t,a,s,c,_,b,h,l,m,y,e,o,n,u);if(k&&(f=k.placedGlyphBoxes)&&f.box&&f.box.length){T=!0,E=k.shift;break}}return f};B((function(){return U(R,a.iconBox,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox,n=C&&C.box&&C.box.length;return o.allowVerticalPlacement&&!n&&e.numVerticalGlyphVertices>0&&r?U(r,a.verticalIconBox,t.WritingMode.vertical):{box:null,offscreen:null}})),C&&(T=C.box,S=C.offscreen);var V=F(C&&C.box);if(!T&&i.prevPlacement){var q=i.prevPlacement.variableOffsets[e.crossTileID];q&&(i.variableOffsets[e.crossTileID]=q,i.markUsedJustification(o,q.anchor,e,V))}}else{var H=function(t,r){var n=i.collisionIndex.placeCollisionBox(t,v,h,l,m.predicate);return n&&n.box&&n.box.length&&(i.markUsedOrientation(o,r,e),i.placedOrientations[e.crossTileID]=r),n};B((function(){return H(R,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&r?H(r,t.WritingMode.vertical):{box:null,offscreen:null}})),F(C&&C.box&&C.box.length)}}if(T=(p=C)&&p.box&&p.box.length>0,S=p&&p.offscreen,e.useRuntimeCollisionCircles){var G=o.text.placedSymbolArray.get(e.centerJustifiedTextSymbolIndex),Z=t.evaluateSizeForFeature(o.textSizeData,d,G),W=s.get(\"text-padding\"),Y=e.collisionCircleDiameter;I=i.collisionIndex.placeCollisionCircles(v,G,o.lineVertexArray,o.glyphOffsetArray,Z,l,c,u,n,b,m.predicate,Y,W),T=v||I.circles.length>0&&!I.collisionDetected,S=S&&I.offscreen}if(a.iconFeatureIndex&&(D=a.iconFeatureIndex),a.iconBox){var X=function(t){var e=w&&E?ke(t,E.x,E.y,_,b,i.transform.angle):t;return i.collisionIndex.placeCollisionBox(e,x,h,l,m.predicate)};M=L&&L.box&&L.box.length&&a.verticalIconBox?(P=X(a.verticalIconBox)).box.length>0:(P=X(a.iconBox)).box.length>0,S=S&&P.offscreen}var $=g||0===e.numHorizontalGlyphVertices&&0===e.numVerticalGlyphVertices,J=y||0===e.numIconVertices;if($||J?J?$||(M=M&&T):T=M&&T:M=T=M&&T,T&&p&&p.box&&(L&&L.box&&O?i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,O,m.ID):i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,m.ID)),M&&P&&i.collisionIndex.insertCollisionBox(P.box,s.get(\"icon-ignore-placement\"),o.bucketInstanceId,D,m.ID),I&&(T&&i.collisionIndex.insertCollisionCircles(I.circles,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,m.ID),n)){var K=o.bucketInstanceId,Q=i.collisionCircleArrays[K];void 0===Q&&(Q=i.collisionCircleArrays[K]=new _e);for(var tt=0;tt<I.circles.length;tt+=4)Q.circles.push(I.circles[tt+0]),Q.circles.push(I.circles[tt+1]),Q.circles.push(I.circles[tt+2]),Q.circles.push(I.collisionDetected?1:0)}i.placements[e.crossTileID]=new xe(T||k,M||A,S||o.justReloaded),r[e.crossTileID]=!0}};if(T)for(var S=o.getSortedSymbolIndexes(this.transform.angle),E=S.length-1;E>=0;--E){var C=S[E];M(o.symbolInstances.get(C),o.collisionArrays[C])}else for(var L=e.symbolInstanceStart;L<e.symbolInstanceEnd;L++)M(o.symbolInstances.get(L),o.collisionArrays[L]);if(n&&o.bucketInstanceId in this.collisionCircleArrays){var I=this.collisionCircleArrays[o.bucketInstanceId];t.invert(I.invProjMatrix,l),I.viewportMatrix=this.collisionIndex.getViewportMatrix()}o.justReloaded=!1},Ae.prototype.markUsedJustification=function(e,r,n,i){var a,o={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex};a=i===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:o[t.getAnchorJustification(r)];for(var s=0,l=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];s<l.length;s+=1){var c=l[s];c>=0&&(e.text.placedSymbolArray.get(c).crossTileID=a>=0&&c!==a?0:n.crossTileID)}},Ae.prototype.markUsedOrientation=function(e,r,n){for(var i=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,a=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1){var l=s[o];e.text.placedSymbolArray.get(l).placedOrientation=i}n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=a)},Ae.prototype.commit=function(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;var e=this.prevPlacement,r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;var n=e?e.symbolFadeChange(t):1,i=e?e.opacities:{},a=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=i[s];c?(this.opacities[s]=new ve(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new ve(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in i){var h=i[u];if(!this.opacities[u]){var f=new ve(h,n,!1,!1);f.isHidden()||(this.opacities[u]=f,r=r||h.text.placed||h.icon.placed)}}for(var p in a)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=a[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},Ae.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},Ae.prototype.updateBucketOpacities=function(e,r,n){var i=this;e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexArray.clear(),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexArray.clear();var a=e.layers[0].layout,o=new ve(null,0,!1,!1,!0),s=a.get(\"text-allow-overlap\"),l=a.get(\"icon-allow-overlap\"),c=a.get(\"text-variable-anchor\"),u=\"map\"===a.get(\"text-rotation-alignment\"),h=\"map\"===a.get(\"text-pitch-alignment\"),f=\"none\"!==a.get(\"icon-text-fit\"),p=new ve(null,0,s&&(l||!e.hasIconData()||a.get(\"icon-optional\")),l&&(s||!e.hasTextData()||a.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData())&&e.deserializeCollisionBoxes(n);for(var d=function(t,e,r){for(var n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r)},m=function(n){var a=e.symbolInstances.get(n),s=a.numHorizontalGlyphVertices,l=a.numVerticalGlyphVertices,m=a.crossTileID,g=r[m],y=i.opacities[m];g?y=o:y||(y=p,i.opacities[m]=y),r[m]=!0;var v=s>0||l>0,x=a.numIconVertices>0,_=i.placedOrientations[a.crossTileID],b=_===t.WritingMode.vertical,w=_===t.WritingMode.horizontal||_===t.WritingMode.horizontalOnly;if(v){var T=Oe(y.text),k=b?De:T;d(e.text,s,k);var A=w?De:T;d(e.text,l,A);var M=y.text.isHidden();[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=M||b?1:0)})),a.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(a.verticalPlacedTextSymbolIndex).hidden=M||w?1:0);var S=i.variableOffsets[a.crossTileID];S&&i.markUsedJustification(e,S.anchor,a,_);var E=i.placedOrientations[a.crossTileID];E&&(i.markUsedJustification(e,\"left\",a,E),i.markUsedOrientation(e,E,a))}if(x){var C=Oe(y.icon),L=!(f&&a.verticalPlacedIconSymbolIndex&&b);if(a.placedIconSymbolIndex>=0){var I=L?C:De;d(e.icon,a.numIconVertices,I),e.icon.placedSymbolArray.get(a.placedIconSymbolIndex).hidden=y.icon.isHidden()}if(a.verticalPlacedIconSymbolIndex>=0){var P=L?De:C;d(e.icon,a.numVerticalIconVertices,P),e.icon.placedSymbolArray.get(a.verticalPlacedIconSymbolIndex).hidden=y.icon.isHidden()}}if(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData()){var z=e.collisionArrays[n];if(z){var O=new t.Point(0,0);if(z.textBox||z.verticalTextBox){var D=!0;if(c){var R=i.variableOffsets[m];R?(O=Te(R.anchor,R.width,R.height,R.textOffset,R.textBoxScale),u&&O._rotate(h?i.transform.angle:-i.transform.angle)):D=!1}z.textBox&&Me(e.textCollisionBox.collisionVertexArray,y.text.placed,!D||b,O.x,O.y),z.verticalTextBox&&Me(e.textCollisionBox.collisionVertexArray,y.text.placed,!D||w,O.x,O.y)}var F=Boolean(!w&&z.verticalIconBox);z.iconBox&&Me(e.iconCollisionBox.collisionVertexArray,y.icon.placed,F,f?O.x:0,f?O.y:0),z.verticalIconBox&&Me(e.iconCollisionBox.collisionVertexArray,y.icon.placed,!F,f?O.x:0,f?O.y:0)}}},g=0;g<e.symbolInstances.length;g++)m(g);if(e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexBuffer&&e.iconCollisionBox.collisionVertexBuffer.updateData(e.iconCollisionBox.collisionVertexArray),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexBuffer&&e.textCollisionBox.collisionVertexBuffer.updateData(e.textCollisionBox.collisionVertexArray),e.bucketInstanceId in this.collisionCircleArrays){var y=this.collisionCircleArrays[e.bucketInstanceId];e.placementInvProjMatrix=y.invProjMatrix,e.placementViewportMatrix=y.viewportMatrix,e.collisionCircleArray=y.circles,delete this.collisionCircleArrays[e.bucketInstanceId]}},Ae.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment},Ae.prototype.zoomAdjustment=function(t){return Math.max(0,(this.transform.zoom-t)/1.5)},Ae.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},Ae.prototype.stillRecent=function(t,e){var r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t},Ae.prototype.setStale=function(){this.stale=!0};var Se=Math.pow(2,25),Ee=Math.pow(2,24),Ce=Math.pow(2,17),Le=Math.pow(2,16),Ie=Math.pow(2,9),Pe=Math.pow(2,8),ze=Math.pow(2,1);function Oe(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Se+e*Ee+r*Ce+e*Le+r*Ie+e*Pe+r*ze+e}var De=0,Re=function(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&void 0!==t.layout.get(\"symbol-sort-key\").constantOr(1),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]};Re.prototype.continuePlacement=function(t,e,r,n,i){for(var a=this._bucketParts;this._currentTileIndex<t.length;){var o=t[this._currentTileIndex];if(e.getBucketParts(a,n,o,this._sortAcrossTiles),this._currentTileIndex++,i())return!0}for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,a.sort((function(t,e){return t.sortKey-e.sortKey})));this._currentPartIndex<a.length;){var s=a[this._currentPartIndex];if(e.placeLayerBucketPart(s,this._seenCrossTileIDs,r),this._currentPartIndex++,i())return!0}return!1};var Fe=function(t,e,r,n,i,a,o){this.placement=new Ae(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Fe.prototype.isDone=function(){return this._done},Fe.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Re(s)),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Fe.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Be=512/t.EXTENT/2,Ne=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ne.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Be/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ne.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var je=function(){this.maxCrossTileID=0};je.prototype.generate=function(){return++this.maxCrossTileID};var Ue=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Ue.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Ue.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ne(t,e.symbolInstances,e.bucketInstanceId),!0},Ue.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Ue.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Ve=function(){this.layerIndexes={},this.crossTileIDs=new je,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Ve.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Ue);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Ve.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach((function(t){e[t]=!0})),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var qe=function(e,r){return t.emitValidationErrors(e,r&&r.filter((function(t){return\"source.canvas\"!==t.identifier})))},He=t.pick(qt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ge=t.pick(qt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),Ze=function(){var e={},r=t.styleSpec.$version;for(var n in t.styleSpec.$root){var i=t.styleSpec.$root[n];if(i.required){var a;null!=(a=\"version\"===n?r:\"array\"===i.type?[]:{})&&(e[n]=a)}}return e}(),We=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new A(jt(),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new k(256,512),this.crossTileSymbolIndex=new Ve,this._layers={},this._serializedLayers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginStateChange((function(e){var r={pluginStatus:e.pluginStatus,pluginURL:e.pluginURL};o.dispatcher.broadcast(\"syncRTLPluginState\",r,(function(e,r){if(t.triggerPluginCompletionEvent(e),r&&r.every((function(t){return t})))for(var n in o.sourceCaches)o.sourceCaches[n].reload()}))})),this.on(\"data\",(function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}}))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,(function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)}))},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame((function(){n._request=null,n._load(e,!1!==r.validate)}))},r.prototype.loadEmpty=function(){this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._load(Ze,!1)},r.prototype._load=function(e,r){if(!r||!qe(this,t.validateStyle(e))){for(var n in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(n,e.sources[n],{validate:!1});e.sprite?this._loadSprite(e.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=Vt(this.stylesheet.layers);this._order=i.map((function(t){return t.id})),this._layers={},this._serializedLayers={};for(var a=0,o=i;a<o.length;a+=1){var s=o[a];(s=t.createStyleLayer(s)).setEventedParent(this,{layer:{id:s.id}}),this._layers[s.id]=s,this._serializedLayers[s.id]=s.serialize()}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new T(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._loadSprite=function(e){var r=this;this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),(function(t,e){l=null,o||(o=t,i=e,u())})),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),(function(t,e){c=null,o||(o=t,a=e,u())}));function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,m=l.stretchX,g=l.stretchY,y=l.content,v=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,v,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:v,pixelRatio:d,sdf:p,stretchX:m,stretchY:g,content:y}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e,this.map._requestManager,(function(e,n){if(r._spriteRequest=null,e)r.fire(new t.ErrorEvent(e));else if(n)for(var i in n)r.imageManager.addImage(i,n[i]);r.imageManager.setLoaded(!0),r._availableImages=r.imageManager.listImages(),r.dispatcher.broadcast(\"setImages\",r._availableImages),r.fire(new t.Event(\"data\",{dataType:\"style\"}))}))},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updateTilesForChangedImages(),this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}var l={};for(var c in this.sourceCaches){var u=this.sourceCaches[c];l[c]=u.used,u.used=!1}for(var h=0,f=this._order;h<f.length;h+=1){var p=f[h],d=this._layers[p];d.recalculate(e,this._availableImages),!d.isHidden(e.zoom)&&d.source&&(this.sourceCaches[d.source].used=!0)}for(var m in l){var g=this.sourceCaches[m];l[m]!==g.used&&g.fire(new t.Event(\"data\",{sourceDataType:\"visibility\",dataType:\"source\",sourceId:m}))}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateTilesForChangedImages=function(){var t=Object.keys(this._changedImages);if(t.length){for(var e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),qe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Vt(e.layers);var n=Jt(this.serialize(),e).filter((function(t){return!(t.command in Ge)}));if(0===n.length)return!1;var i=n.filter((function(t){return!(t.command in He)}));if(i.length>0)throw new Error(\"Unimplemented: \"+i.map((function(t){return t.command})).join(\", \")+\".\");return n.forEach((function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)})),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this._afterImageUpdated(e)},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this._afterImageUpdated(e)},r.prototype._afterImageUpdated=function(e){this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.dispatcher.broadcast(\"setImages\",this._availableImages),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Pt(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,(function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}})),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(qe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}}),this._serializedLayers[a.id]=a.serialize()}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._serializedLayers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.hasLayer=function(t){return t in this._layers},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n];if(void 0!==a){var o=a.getSource().type;\"geojson\"===o&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||i?(void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),a.setFeatureState(i,e.id,r)):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0;\"vector\"!==a||o?r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is required to remove its specific state property.\"))):i.removeFeatureState(o,e.id,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r];if(void 0!==i){if(\"vector\"!==i.getSource().type||n)return void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),i.getFeatureState(n,e.id);this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,(function(t){return t.serialize()})),layers:this._serializeLayers(this._order)},(function(t){return void 0!==t}))},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort((function(t,e){return e.intersectionZ-t.intersectionZ}));for(var p=[],d=this._order.length-1;d>=0;d--){var m=this._order[d];if(r(m))for(var g=i.length-1;g>=0;g--){var y=i[g].feature;if(n[y.layer.id]<d)break;p.push(y),i.pop()}else for(var v=0,x=t;v<x.length;v+=1){var _=x[v][m];if(_)for(var b=0,w=_;b<w.length;b+=1){var T=w[b];p.push(T.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in r.availableImages=this._availableImages,this.sourceCaches)r.layers&&!i[u]||c.push(B(this.sourceCaches[u],this._layers,this._serializedLayers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a,o){for(var s={},l=a.queryRenderedSymbols(n),c=[],u=0,h=Object.keys(l).map(Number);u<h.length;u+=1){var f=h[u];c.push(o[f])}c.sort(N);for(var p=function(){var r=m[d],n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,i.filter,i.layers,i.availableImages,t);for(var a in n){var o=s[a]=s[a]||[],c=n[a];c.sort((function(t,e){var n=r.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-i}return e.featureIndex-t.featureIndex}));for(var u=0,h=c;u<h.length;u+=1){var f=h[u];o.push(f)}}},d=0,m=c;d<m.length;d+=1)p();var g=function(e){s[e].forEach((function(n){var i=n.feature,a=t[e],o=r[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o}))};for(var y in s)g(y);return s}(this._layers,this._serializedLayers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map((function(e){return t.getTileByID(e)})),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&qe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginStateChange\",this._rtlTextPluginCallback),this._layers)this._layers[e].setEventedParent(null);for(var r in this.sourceCaches)this.sourceCaches[r].clearTiles(),this.sourceCaches[r].setEventedParent(null);this.imageManager.setEventedParent(null),this.setEventedParent(null),this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i,a){void 0===a&&(a=!1);for(var o=!1,s=!1,l={},c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];if(\"symbol\"===f.type){if(!l[f.source]){var p=this.sourceCaches[f.source];l[f.source]=p.getRenderableIds(!0).map((function(t){return p.getTileByID(t)})).sort((function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)}))}var d=this.crossTileSymbolIndex.addLayer(f,l[f.source],e.center.lng);o=o||d}}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((a=a||this._layerOrderChanged||0===n)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now(),e.zoom))&&(this.pauseablePlacement=new Fe(e,this._order,a,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(var m=0,g=this._order;m<g.length;m+=1){var y=g[m],v=this._layers[y];\"symbol\"===v.type&&this.placement.updateLayerOpacities(v,l[v.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r),this._updateTilesForChangedImages();var n=this.sourceCaches[e.source];n&&n.setDependencies(e.tileID.key,e.type,e.icons)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);We.getSourceType=function(t){return R[t]},We.setSourceType=function(t,e){R[t]=e},We.registerForPluginStateChange=t.registerForPluginStateChange;var Ye=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Xe=br(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),$e=br(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Je=br(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),Ke=br(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Qe=br(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),tr=br(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),er=br(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),rr=br(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),nr=br(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),ir=br(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,0,1);}\"),ar=br(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),or=br(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),sr=br(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),lr=br(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),cr=br(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),ur=br(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),hr=br(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggerationFactor=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;float exaggeration=u_zoom < 15.0 ? (u_zoom-15.0)*exaggerationFactor : 0.0;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/pow(2.0,exaggeration+(19.2562-u_zoom));gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),fr=br(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),pr=br(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),dr=br(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp vec2 v_uv;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,v_uv);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;attribute float a_uv_x;attribute float a_split_index;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;uniform float u_image_height;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp vec2 v_uv;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;highp float texel_height=1.0/u_image_height;highp float half_texel_height=0.5*texel_height;v_uv=vec2(a_uv_x,a_split_index*texel_height-half_texel_height);vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),mr=br(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),gr=br(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),yr=br(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),vr=br(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),xr=br(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),_r=br(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\");function br(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n=e.match(/attribute ([\\w]+) ([\\w]+)/g),i=t.match(/uniform ([\\w]+) ([\\w]+)([\\s]*)([\\w]*)/g),a=e.match(/uniform ([\\w]+) ([\\w]+)([\\s]*)([\\w]*)/g),o=a?a.concat(i):i,s={};return{fragmentSource:t=t.replace(r,(function(t,e,r,n,i){return s[i]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\nvarying \"+r+\" \"+n+\" \"+i+\";\\n#else\\nuniform \"+r+\" \"+n+\" u_\"+i+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+i+\"\\n    \"+r+\" \"+n+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\"})),vertexSource:e=e.replace(r,(function(t,e,r,n,i){var a=\"float\"===n?\"vec2\":\"vec4\",o=i.match(/color/)?\"color\":a;return s[i]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\nuniform lowp float u_\"+i+\"_t;\\nattribute \"+r+\" \"+a+\" a_\"+i+\";\\nvarying \"+r+\" \"+n+\" \"+i+\";\\n#else\\nuniform \"+r+\" \"+n+\" u_\"+i+\";\\n#endif\\n\":\"vec4\"===o?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+i+\" = a_\"+i+\";\\n#else\\n    \"+r+\" \"+n+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+i+\" = unpack_mix_\"+o+\"(a_\"+i+\", u_\"+i+\"_t);\\n#else\\n    \"+r+\" \"+n+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\nuniform lowp float u_\"+i+\"_t;\\nattribute \"+r+\" \"+a+\" a_\"+i+\";\\n#else\\nuniform \"+r+\" \"+n+\" u_\"+i+\";\\n#endif\\n\":\"vec4\"===o?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+r+\" \"+n+\" \"+i+\" = a_\"+i+\";\\n#else\\n    \"+r+\" \"+n+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+r+\" \"+n+\" \"+i+\" = unpack_mix_\"+o+\"(a_\"+i+\", u_\"+i+\"_t);\\n#else\\n    \"+r+\" \"+n+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\"})),staticAttributes:n,staticUniforms:o}}var wr=Object.freeze({__proto__:null,prelude:Xe,background:$e,backgroundPattern:Je,circle:Ke,clippingMask:Qe,heatmap:tr,heatmapTexture:er,collisionBox:rr,collisionCircle:nr,debug:ir,fill:ar,fillOutline:or,fillOutlinePattern:sr,fillPattern:lr,fillExtrusion:cr,fillExtrusionPattern:ur,hillshadePrepare:hr,hillshade:fr,line:pr,lineGradient:dr,linePattern:mr,lineSDF:gr,raster:yr,symbolIcon:vr,symbolSDF:xr,symbolTextAndIcon:_r}),Tr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};function kr(t){for(var e=[],r=0;r<t.length;r++)if(null!==t[r]){var n=t[r].split(\" \");e.push(n.pop())}return e}Tr.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},Tr.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,m=r;d<m.length;d+=1){var g=m[d];g.bind(),g.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},Tr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var Ar=function(t,e,r,n,i,a){var o=t.gl;this.program=o.createProgram();for(var s=kr(r.staticAttributes),l=n?n.getBinderAttributes():[],c=s.concat(l),u=r.staticUniforms?kr(r.staticUniforms):[],h=n?n.getBinderUniforms():[],f=[],p=0,d=u.concat(h);p<d.length;p+=1){var m=d[p];f.indexOf(m)<0&&f.push(m)}var g=n?n.defines():[];a&&g.push(\"#define OVERDRAW_INSPECTOR;\");var y=g.concat(Xe.fragmentSource,r.fragmentSource).join(\"\\n\"),v=g.concat(Xe.vertexSource,r.vertexSource).join(\"\\n\"),x=o.createShader(o.FRAGMENT_SHADER);if(o.isContextLost())this.failedToCreate=!0;else{o.shaderSource(x,y),o.compileShader(x),o.attachShader(this.program,x);var _=o.createShader(o.VERTEX_SHADER);if(o.isContextLost())this.failedToCreate=!0;else{o.shaderSource(_,v),o.compileShader(_),o.attachShader(this.program,_),this.attributes={};var b={};this.numAttributes=c.length;for(var w=0;w<this.numAttributes;w++)c[w]&&(o.bindAttribLocation(this.program,w,c[w]),this.attributes[c[w]]=w);o.linkProgram(this.program),o.deleteShader(_),o.deleteShader(x);for(var T=0;T<f.length;T++){var k=f[T];if(k&&!b[k]){var A=o.getUniformLocation(this.program,k);A&&(b[k]=A)}}this.fixedUniforms=i(t,b),this.binderUniforms=n?n.getUniforms(t,b):[]}}};function Mr(t,e,r){var n=1/ge(r,1,e.transform.tileZoom),i=Math.pow(2,r.tileID.overscaledZ),a=r.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(r.tileID.canonical.x+r.tileID.wrap*i),s=a*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}Ar.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m){var g,y=t.gl;if(!this.failedToCreate){for(var v in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[v].set(o[v]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(g={},g[y.LINES]=2,g[y.TRIANGLES]=3,g[y.LINE_STRIP]=1,g)[e],_=0,b=u.get();_<b.length;_+=1){var w=b[_],T=w.vaos||(w.vaos={});(T[s]||(T[s]=new Tr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,m),y.drawElements(e,w.primitiveLength*x,y.UNSIGNED_SHORT,w.primitiveOffset*x*2)}}};var Sr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},Er=function(e,r,n,i,a,o,s){return t.extend(Sr(e,r,n,i),Mr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},Cr=function(t){return{u_matrix:t}},Lr=function(e,r,n,i){return t.extend(Cr(e),Mr(n,r,i))},Ir=function(t,e){return{u_matrix:t,u_world:e}},Pr=function(e,r,n,i,a){return t.extend(Lr(e,r,n,i),{u_world:a})},zr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=ge(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},Or=function(t,e,r){var n=ge(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},Dr=function(t,e,r){return{u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}},Rr=function(t,e,r){return void 0===r&&(r=1),{u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}},Fr=function(t){return{u_matrix:t}},Br=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:ge(e,1,r),u_intensity:n}},Nr=function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}},jr=function(e,r,n){var i=n.paint.get(\"hillshade-shadow-color\"),a=n.paint.get(\"hillshade-highlight-color\"),o=n.paint.get(\"hillshade-accent-color\"),s=n.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===n.paint.get(\"hillshade-illumination-anchor\")&&(s-=e.transform.angle);var l,c,u,h=!e.options.moving;return{u_matrix:e.transform.calculatePosMatrix(r.tileID.toUnwrapped(),h),u_image:0,u_latrange:(l=r.tileID,c=Math.pow(2,l.canonical.z),u=l.canonical.y,[new t.MercatorCoordinate(0,u/c).toLngLat().lat,new t.MercatorCoordinate(0,(u+1)/c).toLngLat().lat]),u_light:[n.paint.get(\"hillshade-exaggeration\"),s],u_shadow:i,u_highlight:a,u_accent:o}},Ur=function(e,r){var n=r.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.overscaledZ,u_unpack:r.getUnpackVector()}};var Vr=function(e,r,n){var i=e.transform;return{u_matrix:Wr(e,r,n),u_ratio:1/ge(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},qr=function(e,r,n,i){return t.extend(Vr(e,r,n),{u_image:0,u_image_height:i})},Hr=function(e,r,n,i){var a=e.transform,o=Zr(r,a);return{u_matrix:Wr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/ge(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Gr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Zr(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Vr(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Zr(t,e){return 1/ge(t,1,e.tileZoom)}function Wr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Yr=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:Xr(i.paint.get(\"raster-hue-rotate\"))};var a,o};function Xr(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var $r,Jr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Kr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Jr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Qr=function(e,r,n,i,a,o,s,l,c,u){return t.extend(Kr(e,r,n,i,a,o,s,l,!0,c,!0),{u_texsize_icon:u,u_texture_icon:1})},tn=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},en=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from.toString()),a=r.imageManager.getPattern(t.to.toString()),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/ge(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},rn={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},collisionCircle:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_inv_matrix:new t.UniformMatrix4f(e,r.u_inv_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_viewport_size:new t.Uniform2f(e,r.u_viewport_size)}},debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_overlay:new t.Uniform1i(e,r.u_overlay),u_overlay_scale:new t.Uniform1f(e,r.u_overlay_scale)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_unpack:new t.Uniform4f(e,r.u_unpack)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image),u_image_height:new t.Uniform1f(e,r.u_image_height)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},symbolTextAndIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texsize_icon:new t.Uniform2f(e,r.u_texsize_icon),u_texture:new t.Uniform1i(e,r.u_texture),u_texture_icon:new t.Uniform1i(e,r.u_texture_icon),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function nn(e,r,n,i,a,o,s){for(var l=e.context,c=l.gl,u=e.useProgram(\"collisionBox\"),h=[],f=0,p=0,d=0;d<i.length;d++){var m=i[d],g=r.getTile(m),y=g.getBucket(n);if(y){var v=m.posMatrix;0===a[0]&&0===a[1]||(v=e.translatePosMatrix(m.posMatrix,g,a,o));var x=s?y.textCollisionBox:y.iconCollisionBox,_=y.collisionCircleArray;if(_.length>0){var b=t.create(),w=v;t.mul(b,y.placementInvProjMatrix,e.transform.glCoordMatrix),t.mul(b,b,y.placementViewportMatrix),h.push({circleArray:_,circleOffset:p,transform:w,invTransform:b}),p=f+=_.length/4}x&&u.draw(l,c.LINES,Mt.disabled,Et.disabled,e.colorModeForRenderPass(),Lt.disabled,Or(v,e.transform,g),n.id,x.layoutVertexBuffer,x.indexBuffer,x.segments,null,e.transform.zoom,null,null,x.collisionVertexBuffer)}}if(s&&h.length){var T=e.useProgram(\"collisionCircle\"),k=new t.StructArrayLayout2f1f2i16;k.resize(4*f),k._trim();for(var A=0,M=0,S=h;M<S.length;M+=1)for(var E=S[M],C=0;C<E.circleArray.length/4;C++){var L=4*C,I=E.circleArray[L+0],P=E.circleArray[L+1],z=E.circleArray[L+2],O=E.circleArray[L+3];k.emplace(A++,I,P,z,O,0),k.emplace(A++,I,P,z,O,1),k.emplace(A++,I,P,z,O,2),k.emplace(A++,I,P,z,O,3)}(!$r||$r.length<2*f)&&($r=function(e){var r=2*e,n=new t.StructArrayLayout3ui6;n.resize(r),n._trim();for(var i=0;i<r;i++){var a=6*i;n.uint16[a+0]=4*i+0,n.uint16[a+1]=4*i+1,n.uint16[a+2]=4*i+2,n.uint16[a+3]=4*i+2,n.uint16[a+4]=4*i+3,n.uint16[a+5]=4*i+0}return n}(f));for(var D=l.createIndexBuffer($r,!0),R=l.createVertexBuffer(k,t.collisionCircleLayout.members,!0),F=0,B=h;F<B.length;F+=1){var N=B[F],j=Dr(N.transform,N.invTransform,e.transform);T.draw(l,c.TRIANGLES,Mt.disabled,Et.disabled,e.colorModeForRenderPass(),Lt.disabled,j,n.id,R,D,t.SegmentVector.simpleSegment(0,2*N.circleOffset,N.circleArray.length,N.circleArray.length/2),null,e.transform.zoom,null,null,null)}R.destroy(),D.destroy()}}var an=t.identity(new Float32Array(16));function on(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateVariableOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function sn(e,r,n,i,a,o,s,l,c,u,h){var f=e.text.placedSymbolArray,p=e.text.dynamicLayoutVertexArray,d=e.icon.dynamicLayoutVertexArray,m={};p.clear();for(var g=0;g<f.length;g++){var y=f.get(g),v=e.allowVerticalPlacement&&!y.placedOrientation,x=y.hidden||!y.crossTileID||v?null:i[y.crossTileID];if(x){var _=new t.Point(y.anchorX,y.anchorY),b=re(_,n?l:s),w=ne(o.cameraToCenterDistance,b.signedDistanceFromCamera),T=a.evaluateSizeForFeature(e.textSizeData,u,y)*w/t.ONE_EM;n&&(T*=e.tilePixelRatio/c);for(var k=x.width,A=x.height,M=on(x.anchor,k,A,x.textOffset,x.textBoxScale,T),S=n?re(_.add(M),s).point:b.point.add(r?M.rotate(-o.angle):M),E=e.allowVerticalPlacement&&y.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,C=0;C<y.numGlyphs;C++)t.addDynamicAttributes(p,S,E);h&&y.associatedIconIndex>=0&&(m[y.associatedIconIndex]={shiftedAnchor:S,angle:E})}else fe(y.numGlyphs,p)}if(h){d.clear();for(var L=e.icon.placedSymbolArray,I=0;I<L.length;I++){var P=L.get(I);if(P.hidden)fe(P.numGlyphs,d);else{var z=m[I];if(z)for(var O=0;O<P.numGlyphs;O++)t.addDynamicAttributes(d,z.shiftedAnchor,z.angle);else fe(P.numGlyphs,d)}}e.icon.dynamicLayoutVertexBuffer.updateData(d)}e.text.dynamicLayoutVertexBuffer.updateData(p)}function ln(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function cn(e,r,n,i,a,o,s,l,c,u,h,f){for(var p=e.context,d=p.gl,m=e.transform,g=\"map\"===l,y=\"map\"===c,v=g&&\"point\"!==n.layout.get(\"symbol-placement\"),x=g&&!y&&!v,_=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),b=!1,w=e.depthModeForSublayer(0,Mt.ReadOnly),T=n.layout.get(\"text-variable-anchor\"),k=[],A=0,M=i;A<M.length;A+=1){var S=M[A],E=r.getTile(S),C=E.getBucket(n);if(C){var L=a?C.text:C.icon;if(L&&L.segments.get().length){var I=L.programConfigurations.get(n.id),P=a||C.sdfIcons,z=a?C.textSizeData:C.iconSizeData,O=y||0!==m.pitch,D=e.useProgram(ln(P,a,C),I),R=t.evaluateSizeForZoom(z,m.zoom),F=void 0,B=[0,0],N=void 0,j=void 0,U=null,V=void 0;if(a){if(N=E.glyphAtlasTexture,j=d.LINEAR,F=E.glyphAtlasTexture.size,C.iconsInText){B=E.imageAtlasTexture.size,U=E.imageAtlasTexture;var q=\"composite\"===z.kind||\"camera\"===z.kind;V=O||e.options.rotating||e.options.zooming||q?d.LINEAR:d.NEAREST}}else{var H=1!==n.layout.get(\"icon-size\").constantOr(0)||C.iconsNeedLinear;N=E.imageAtlasTexture,j=P||e.options.rotating||e.options.zooming||H||O?d.LINEAR:d.NEAREST,F=E.imageAtlasTexture.size}var G=ge(E,1,e.transform.zoom),Z=te(S.posMatrix,y,g,e.transform,G),W=ee(S.posMatrix,y,g,e.transform,G),Y=T&&C.hasTextData(),X=\"none\"!==n.layout.get(\"icon-text-fit\")&&Y&&C.hasIconData();v&&ae(C,S.posMatrix,e,a,Z,W,y,u);var $=e.translatePosMatrix(S.posMatrix,E,o,s),J=v||a&&T||X?an:Z,K=e.translatePosMatrix(W,E,o,s,!0),Q=P&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),tt={program:D,buffers:L,uniformValues:P?C.iconsInText?Qr(z.kind,R,x,y,e,$,J,K,F,B):Kr(z.kind,R,x,y,e,$,J,K,a,F,!0):Jr(z.kind,R,x,y,e,$,J,K,a,F),atlasTexture:N,atlasTextureIcon:U,atlasInterpolation:j,atlasInterpolationIcon:V,isSDF:P,hasHalo:Q};if(_&&C.canOverlap){b=!0;for(var et=0,rt=L.segments.get();et<rt.length;et+=1){var nt=rt[et];k.push({segments:new t.SegmentVector([nt]),sortKey:nt.sortKey,state:tt})}}else k.push({segments:L.segments,sortKey:0,state:tt})}}}b&&k.sort((function(t,e){return t.sortKey-e.sortKey}));for(var it=0,at=k;it<at.length;it+=1){var ot=at[it],st=ot.state;if(p.activeTexture.set(d.TEXTURE0),st.atlasTexture.bind(st.atlasInterpolation,d.CLAMP_TO_EDGE),st.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),st.atlasTextureIcon&&st.atlasTextureIcon.bind(st.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),st.isSDF){var lt=st.uniformValues;st.hasHalo&&(lt.u_is_halo=1,un(st.buffers,ot.segments,n,e,st.program,w,h,f,lt)),lt.u_is_halo=0}un(st.buffers,ot.segments,n,e,st.program,w,h,f,st.uniformValues)}}function un(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,Lt.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function hn(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),m=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var g=0,y=n;g<y.length;g+=1){var v=y[g],x=e.getTile(v);if(!d||x.patternsLoaded()){var _=x.getBucket(r);if(_){var b=_.programConfigurations.get(r.id),w=t.useProgram(l,b);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),b.updatePaintBuffers(m));var T=p.constantOr(null);if(T&&x.imageAtlas){var k=x.imageAtlas,A=k.patternPositions[T.to.toString()],M=k.patternPositions[T.from.toString()];A&&M&&b.setConstantPatternPositions(A,M)}var S=t.translatePosMatrix(v.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=_.indexBuffer2,h=_.segments2;var E=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?Pr(S,t,m,x,E):Ir(S,E)}else u=_.indexBuffer,h=_.segments,c=d?Lr(S,t,m,x):Cr(S);w.draw(t.context,s,i,t.stencilModeForClipping(v),a,Lt.disabled,c,r.id,_.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,b)}}}}function fn(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var m=d[p],g=e.getTile(m),y=g.getBucket(r);if(y){var v=y.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",v);u&&(t.context.activeTexture.set(l.TEXTURE0),g.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),v.updatePaintBuffers(h));var _=c.constantOr(null);if(_&&g.imageAtlas){var b=g.imageAtlas,w=b.patternPositions[_.to.toString()],T=b.patternPositions[_.from.toString()];w&&T&&v.setConstantPatternPositions(w,T)}var k=t.translatePosMatrix(m.posMatrix,g,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),A=r.paint.get(\"fill-extrusion-vertical-gradient\"),M=u?Er(k,t,A,f,m,h,g):Sr(k,t,A,f);x.draw(s,s.gl.TRIANGLES,i,a,o,Lt.backCCW,M,r.id,y.layoutVertexBuffer,y.indexBuffer,y.segments,r.paint,t.transform.zoom,v)}}}function pn(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=jr(t,e,r);c.draw(o,s.TRIANGLES,n,i,a,Lt.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function dn(e,r,n,i,a,o){var s=e.context,l=s.gl,c=r.dem;if(c&&c.data){var u=c.dim,h=c.stride,f=c.getPixels();if(s.activeTexture.set(l.TEXTURE1),s.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(l.NEAREST,l.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(s,f,l.RGBA,{premultiply:!1}),r.demTexture.bind(l.NEAREST,l.CLAMP_TO_EDGE);s.activeTexture.set(l.TEXTURE0);var d=r.fbo;if(!d){var m=new t.Texture(s,{width:u,height:u,data:null},l.RGBA);m.bind(l.LINEAR,l.CLAMP_TO_EDGE),(d=r.fbo=s.createFramebuffer(u,u,!0)).colorAttachment.set(m.texture)}s.bindFramebuffer.set(d.framebuffer),s.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(s,l.TRIANGLES,i,a,o,Lt.disabled,Ur(r.tileID,c),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function mn(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}var gn=new t.Color(1,0,0,1),yn=new t.Color(0,1,0,1),vn=new t.Color(0,0,1,1),xn=new t.Color(1,0,1,1),_n=new t.Color(0,1,1,1);function bn(t){var e=t.transform.padding;wn(t,t.transform.height-(e.top||0),3,gn),wn(t,e.bottom||0,3,yn),Tn(t,e.left||0,3,vn),Tn(t,t.transform.width-(e.right||0),3,xn);var r=t.transform.centerPoint;!function(t,e,r,n){var i=20,a=2;kn(t,e-a/2,r-i/2,a,i,n),kn(t,e-i/2,r-a/2,i,a,n)}(t,r.x,t.transform.height-r.y,_n)}function wn(t,e,r,n){kn(t,0,e+r/2,t.transform.width,r,n)}function Tn(t,e,r,n){kn(t,e-r/2,0,r,t.transform.height,n)}function kn(e,r,n,i,a,o){var s=e.context,l=s.gl;l.enable(l.SCISSOR_TEST),l.scissor(r*t.browser.devicePixelRatio,n*t.browser.devicePixelRatio,i*t.browser.devicePixelRatio,a*t.browser.devicePixelRatio),s.clear({color:o}),l.disable(l.SCISSOR_TEST)}function An(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Mt.disabled,c=Et.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";i.activeTexture.set(a.TEXTURE0),e.emptyTexture.bind(a.LINEAR,a.CLAMP_TO_EDGE),s.draw(i,a.LINE_STRIP,l,c,u,Lt.disabled,Rr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),m=r.getTile(n).tileSize,g=512/Math.min(m,512)*(n.overscaledZ/e.transform.zoom)*.5,y=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(y+=\" => \"+n.overscaledZ),function(t,e){t.initDebugOverlayCanvas();var r=t.debugOverlayCanvas,n=t.context.gl,i=t.debugOverlayCanvas.getContext(\"2d\");i.clearRect(0,0,r.width,r.height),i.shadowColor=\"white\",i.shadowBlur=2,i.lineWidth=1.5,i.strokeStyle=\"white\",i.textBaseline=\"top\",i.font=\"bold 36px Open Sans, sans-serif\",i.fillText(e,5,5),i.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(e,y+\" \"+d+\"kb\"),s.draw(i,a.TRIANGLES,l,c,Ct.alphaBlended,Lt.disabled,Rr(o,t.Color.transparent,g),h,e.debugBuffer,e.quadTriangleIndexBuffer,e.debugSegments)}var Mn={symbol:function(e,r,n,i,a){if(\"translucent\"===e.renderPass){var o=Et.disabled,s=e.colorModeForRenderPass();n.layout.get(\"text-variable-anchor\")&&function(e,r,n,i,a,o,s){for(var l=r.transform,c=\"map\"===a,u=\"map\"===o,h=0,f=e;h<f.length;h+=1){var p=f[h],d=i.getTile(p),m=d.getBucket(n);if(m&&m.text&&m.text.segments.get().length){var g=m.textSizeData,y=t.evaluateSizeForZoom(g,l.zoom),v=ge(d,1,r.transform.zoom),x=te(p.posMatrix,u,c,r.transform,v),_=\"none\"!==n.layout.get(\"icon-text-fit\")&&m.hasIconData();if(y){var b=Math.pow(2,l.zoom-d.tileID.overscaledZ);sn(m,c,u,s,t.symbolSize,l,x,p.posMatrix,b,y,_)}}}}(i,e,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),a),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&cn(e,r,n,i,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&cn(e,r,n,i,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(nn(e,r,n,i,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),!0),nn(e,r,n,i,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),!1))}},circle:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=void 0!==n.layout.get(\"circle-sort-key\").constantOr(1);if(0!==a.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,h=e.depthModeForSublayer(0,Mt.ReadOnly),f=Et.disabled,p=e.colorModeForRenderPass(),d=[],m=0;m<i.length;m++){var g=i[m],y=r.getTile(g),v=y.getBucket(n);if(v){var x=v.programConfigurations.get(n.id),_={programConfiguration:x,program:e.useProgram(\"circle\",x),layoutVertexBuffer:v.layoutVertexBuffer,indexBuffer:v.indexBuffer,uniformValues:zr(e,g,y,n)};if(l)for(var b=0,w=v.segments.get();b<w.length;b+=1){var T=w[b];d.push({segments:new t.SegmentVector([T]),sortKey:T.sortKey,state:_})}else d.push({segments:v.segments,sortKey:0,state:_})}}l&&d.sort((function(t,e){return t.sortKey-e.sortKey}));for(var k=0,A=d;k<A.length;k+=1){var M=A[k],S=M.state,E=S.programConfiguration,C=S.program,L=S.layoutVertexBuffer,I=S.indexBuffer,P=S.uniformValues,z=M.segments;C.draw(c,u.TRIANGLES,h,f,p,Lt.disabled,P,n.id,L,I,z,n.paint,e.transform.zoom,E)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=Et.disabled,l=new Ct([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);(function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1),function(t,e,r,n){var i=t.gl,a=t.extRenderToTextureHalfFloat?t.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,e.width/4,e.height/4,0,i.RGBA,a,null),n.colorAttachment.set(r)}(t,e,a,i)}})(a,e,n),a.clear({color:t.Color.transparent});for(var c=0;c<i.length;c++){var u=i[c];if(!r.hasRenderableParent(u)){var h=r.getTile(u),f=h.getBucket(n);if(f){var p=f.programConfigurations.get(n.id),d=e.useProgram(\"heatmap\",p),m=e.transform.zoom;d.draw(a,o.TRIANGLES,Mt.disabled,s,l,Lt.disabled,Br(u.posMatrix,h,m,n.paint.get(\"heatmap-intensity\")),n.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,n.paint,e.transform.zoom,p)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Mt.disabled,Et.disabled,e.colorModeForRenderPass(),Lt.disabled,Nr(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=h?\"linePattern\":c?\"lineSDF\":f?\"lineGradient\":\"line\",m=e.context,g=m.gl,y=!0,v=0,x=i;v<x.length;v+=1){var _=x[v],b=r.getTile(_);if(!h||b.patternsLoaded()){var w=b.getBucket(n);if(w){var T=w.programConfigurations.get(n.id),k=e.context.program.get(),A=e.useProgram(d,T),M=y||A.program!==k,S=u.constantOr(null);if(S&&b.imageAtlas){var E=b.imageAtlas,C=E.patternPositions[S.to.toString()],L=E.patternPositions[S.from.toString()];C&&L&&T.setConstantPatternPositions(C,L)}var I=h?Hr(e,b,n,p):c?Gr(e,b,n,c,p):f?qr(e,b,n,w.lineClipsArray.length):Vr(e,b,n);if(h)m.activeTexture.set(g.TEXTURE0),b.imageAtlasTexture.bind(g.LINEAR,g.CLAMP_TO_EDGE),T.updatePaintBuffers(p);else if(c&&(M||e.lineAtlas.dirty))m.activeTexture.set(g.TEXTURE0),e.lineAtlas.bind(m);else if(f){var P=w.gradients[n.id],z=P.texture;if(n.gradientVersion!==P.version){var O=256;if(n.stepInterpolant){var D=r.getSource().maxzoom,R=_.canonical.z===D?Math.ceil(1<<e.transform.maxZoom-_.canonical.z):1,F=w.maxLineLength/t.EXTENT*1024*R;O=t.clamp(t.nextPowerOfTwo(F),256,m.maxTextureSize)}P.gradient=t.renderColorRamp({expression:n.gradientExpression(),evaluationKey:\"lineProgress\",resolution:O,image:P.gradient||void 0,clips:w.lineClipsArray}),P.texture?P.texture.update(P.gradient):P.texture=new t.Texture(m,P.gradient,g.RGBA),P.version=n.gradientVersion,z=P.texture}m.activeTexture.set(g.TEXTURE0),z.bind(n.stepInterpolant?g.NEAREST:g.LINEAR,g.CLAMP_TO_EDGE)}A.draw(m,g.TRIANGLES,s,e.stencilModeForClipping(_),l,Lt.disabled,I,n.id,w.layoutVertexBuffer,w.indexBuffer,w.segments,n.paint,e.transform.zoom,T,w.layoutVertexBuffer2),y=!1}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);hn(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Mt.ReadOnly);hn(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))fn(t,e,r,n,a,Et.disabled,Ct.disabled),fn(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();fn(t,e,r,n,a,Et.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=t.depthModeForSublayer(0,Mt.ReadOnly),o=t.colorModeForRenderPass(),s=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n],l=s[0],c=0,u=s[1];c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?dn(t,f,r,a,Et.disabled,o):\"translucent\"===t.renderPass&&pn(t,f,r,a,l[h.overscaledZ],o)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")&&n.length)for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),c=o instanceof z?[{},n]:t.stencilConfigForOverlap(n),u=c[0],h=c[1],f=h[h.length-1].overscaledZ,p=!t.options.moving,d=0,m=h;d<m.length;d+=1){var g=m[d],y=t.depthModeForSublayer(g.overscaledZ-f,1===r.paint.get(\"raster-opacity\")?Mt.ReadWrite:Mt.ReadOnly,a.LESS),v=e.getTile(g),x=t.transform.calculatePosMatrix(g.toUnwrapped(),p);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var _=e.findLoadedParent(g,0),b=mn(v,_,e,r,t.transform),w=void 0,T=void 0,k=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),_?(_.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),w=Math.pow(2,_.tileID.overscaledZ-v.tileID.overscaledZ),T=[v.tileID.canonical.x*w%1,v.tileID.canonical.y*w%1]):v.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var A=Yr(x,T||[0,0],w||1,b,r);o instanceof z?s.draw(i,a.TRIANGLES,y,Et.disabled,l,Lt.disabled,A,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(i,a.TRIANGLES,y,u[g.overscaledZ],l,Lt.disabled,A,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===i&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass===u){var h=Et.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),m=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var g=r.getCrossfadeParameters(),y=0,v=m;y<v.length;y+=1){var x=v[y],_=t.transform.calculatePosMatrix(x.toUnwrapped()),b=c?en(_,i,t,c,{tileID:x,tileSize:l},g):tn(_,i,n);d.draw(a,o.TRIANGLES,f,h,p,Lt.disabled,b,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)An(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(Et.disabled);var o=\"3d\"===i.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},Sn=function(t,e){this.context=new It(t),this.transform=e,this._tileTextures={},this.setup(),this.numSublayers=Pt.maxUnderzooming+Pt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new Ve,this.gpuTimers={}};Sn.prototype.resize=function(e,r){if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,i=this.style._order;n<i.length;n+=1){var a=i[n];this.style._layers[a].resize()}},Sn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Ye.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Ye.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,P.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Ye.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s),this.emptyTexture=new t.Texture(e,{width:1,height:1,data:new Uint8Array([0,0,0,0])},e.gl.RGBA);var l=this.context.gl;this.stencilClearMode=new Et({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},Sn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,Ct.disabled,Lt.disabled,Fr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},Sn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Ct.disabled),r.setDepthMode(Mt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Mt.disabled,new Et({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Ct.disabled,Lt.disabled,Fr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},Sn.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new Et({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},Sn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new Et({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},Sn.prototype.stencilConfigForOverlap=function(t){var e,r=this.context.gl,n=t.sort((function(t,e){return e.overscaledZ-t.overscaledZ})),i=n[n.length-1].overscaledZ,a=n[0].overscaledZ-i+1;if(a>1){this.currentStencilSource=void 0,this.nextStencilID+a>256&&this.clearStencil();for(var o={},s=0;s<a;s++)o[s+i]=new Et({func:r.GEQUAL,mask:255},s+this.nextStencilID,255,r.KEEP,r.KEEP,r.REPLACE);return this.nextStencilID+=a,[o,n]}return[(e={},e[i]=Et.disabled,e),n]},Sn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;if(this._showOverdrawInspector){var r=1/8;return new Ct([e.CONSTANT_COLOR,e.ONE],new t.Color(r,r,r,0),[!0,!0,!0,!0])}return\"opaque\"===this.renderPass?Ct.unblended:Ct.alphaBlended},Sn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},Sn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},Sn.prototype.render=function(e,r){var n=this;this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var i=this.style._order,a=this.style.sourceCaches;for(var o in a){var s=a[o];s.used&&s.prepare(this.context)}var l,c,u={},h={},f={};for(var p in a){var d=a[p];u[p]=d.getVisibleCoordinates(),h[p]=u[p].slice().reverse(),f[p]=d.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(var m=0;m<i.length;m++){var g=i[m];if(this.style._layers[g].is3D()){this.opaquePassCutoff=m;break}}this.renderPass=\"offscreen\";for(var y=0,v=i;y<v.length;y+=1){var x=v[y],_=this.style._layers[x];if(_.hasOffscreenPass()&&!_.isHidden(this.transform.zoom)){var b=h[_.source];(\"custom\"===_.type||b.length)&&this.renderLayer(this,a[_.source],_,b)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=i.length-1;this.currentLayer>=0;this.currentLayer--){var w=this.style._layers[i[this.currentLayer]],T=a[w.source],k=u[w.source];this._renderTileClippingMasks(w,k),this.renderLayer(this,T,w,k)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<i.length;this.currentLayer++){var A=this.style._layers[i[this.currentLayer]],M=a[A.source],S=(\"symbol\"===A.type?f:h)[A.source];this._renderTileClippingMasks(A,u[A.source]),this.renderLayer(this,M,A,S)}this.options.showTileBoundaries&&(t.values(this.style._layers).forEach((function(t){t.source&&!t.isHidden(n.transform.zoom)&&(t.source!==(c&&c.id)&&(c=n.style.sourceCaches[t.source]),(!l||l.getSource().maxzoom<c.getSource().maxzoom)&&(l=c))})),l&&Mn.debug(this,l,l.getVisibleCoordinates())),this.options.showPadding&&bn(this),this.context.setDefault()},Sn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,this.gpuTimingStart(r),Mn[r.type](t,e,r,n,this.style.placement.variableOffsets),this.gpuTimingEnd())},Sn.prototype.gpuTimingStart=function(t){if(this.options.gpuTiming){var e=this.context.extTimerQuery,r=this.gpuTimers[t.id];r||(r=this.gpuTimers[t.id]={calls:0,cpuTime:0,query:e.createQueryEXT()}),r.calls++,e.beginQueryEXT(e.TIME_ELAPSED_EXT,r.query)}},Sn.prototype.gpuTimingEnd=function(){if(this.options.gpuTiming){var t=this.context.extTimerQuery;t.endQueryEXT(t.TIME_ELAPSED_EXT)}},Sn.prototype.collectGpuTimers=function(){var t=this.gpuTimers;return this.gpuTimers={},t},Sn.prototype.queryGpuTimers=function(t){var e={};for(var r in t){var n=t[r],i=this.context.extTimerQuery,a=i.getQueryObjectEXT(n.query,i.QUERY_RESULT_EXT)/1e6;i.deleteQueryEXT(n.query),e[r]=a}return e},Sn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:ge(r,n[0],this.transform.zoom),a?n[1]:ge(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},Sn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},Sn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},Sn.prototype.isPatternMissing=function(t){if(!t)return!1;if(!t.from||!t.to)return!0;var e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r},Sn.prototype.useProgram=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new Ar(this.context,t,wr[t],e,rn[t],this._showOverdrawInspector)),this.cache[r]},Sn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},Sn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)},Sn.prototype.initDebugOverlayCanvas=function(){if(null==this.debugOverlayCanvas){this.debugOverlayCanvas=t.window.document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512;var e=this.context.gl;this.debugOverlayTexture=new t.Texture(this.context,this.debugOverlayCanvas,e.RGBA)}},Sn.prototype.destroy=function(){this.emptyTexture.destroy(),this.debugOverlayTexture&&this.debugOverlayTexture.destroy()};var En=function(t,e){this.points=t,this.planes=e};En.fromInvProjectionMatrix=function(e,r,n){var i=Math.pow(2,n),a=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((function(r){return t.transformMat4([],r,e)})).map((function(e){return t.scale$1([],e,1/e[3]/r*i)})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((function(e){var r=t.sub([],a[e[0]],a[e[1]]),n=t.sub([],a[e[2]],a[e[1]]),i=t.normalize([],t.cross([],r,n)),o=-t.dot(i,a[e[1]]);return i.concat(o)}));return new En(a,o)};var Cn=function(e,r){this.min=e,this.max=r,this.center=t.scale$2([],t.add([],this.min,this.max),.5)};Cn.prototype.quadrant=function(e){for(var r=[e%2==0,e<2],n=t.clone$2(this.min),i=t.clone$2(this.max),a=0;a<r.length;a++)n[a]=r[a]?this.min[a]:this.center[a],i[a]=r[a]?this.center[a]:this.max[a];return i[2]=this.max[2],new Cn(n,i)},Cn.prototype.distanceX=function(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]},Cn.prototype.distanceY=function(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]},Cn.prototype.intersects=function(e){for(var r=[[this.min[0],this.min[1],0,1],[this.max[0],this.min[1],0,1],[this.max[0],this.max[1],0,1],[this.min[0],this.max[1],0,1]],n=!0,i=0;i<e.planes.length;i++){for(var a=e.planes[i],o=0,s=0;s<r.length;s++)o+=t.dot$1(a,r[s])>=0;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(var l=0;l<3;l++){for(var c=Number.MAX_VALUE,u=-Number.MAX_VALUE,h=0;h<e.points.length;h++){var f=e.points[h][l]-this.min[l];c=Math.min(c,f),u=Math.max(u,f)}if(u<0||c>this.max[l]-this.min[l])return 0}return 1};var Ln=function(t,e,r,n){if(void 0===t&&(t=0),void 0===e&&(e=0),void 0===r&&(r=0),void 0===n&&(n=0),isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n};Ln.prototype.interpolate=function(e,r,n){return null!=r.top&&null!=e.top&&(this.top=t.number(e.top,r.top,n)),null!=r.bottom&&null!=e.bottom&&(this.bottom=t.number(e.bottom,r.bottom,n)),null!=r.left&&null!=e.left&&(this.left=t.number(e.left,r.left,n)),null!=r.right&&null!=e.right&&(this.right=t.number(e.right,r.right,n)),this},Ln.prototype.getCenter=function(e,r){var n=t.clamp((this.left+e-this.right)/2,0,e),i=t.clamp((this.top+r-this.bottom)/2,0,r);return new t.Point(n,i)},Ln.prototype.equals=function(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right},Ln.prototype.clone=function(){return new Ln(this.top,this.bottom,this.left,this.right)},Ln.prototype.toJSON=function(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}};var In=function(e,r,n,i,a){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===a||a,this._minZoom=e||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==i?60:i,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new Ln,this._posMatrixCache={},this._alignedPosMatrixCache={}},Pn={minZoom:{configurable:!0},maxZoom:{configurable:!0},minPitch:{configurable:!0},maxPitch:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerOffset:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},padding:{configurable:!0},centerPoint:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};In.prototype.clone=function(){var t=new In(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._edgeInsets=this._edgeInsets.clone(),t._calcMatrices(),t},Pn.minZoom.get=function(){return this._minZoom},Pn.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},Pn.maxZoom.get=function(){return this._maxZoom},Pn.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},Pn.minPitch.get=function(){return this._minPitch},Pn.minPitch.set=function(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))},Pn.maxPitch.get=function(){return this._maxPitch},Pn.maxPitch.set=function(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))},Pn.renderWorldCopies.get=function(){return this._renderWorldCopies},Pn.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},Pn.worldSize.get=function(){return this.tileSize*this.scale},Pn.centerOffset.get=function(){return this.centerPoint._sub(this.size._div(2))},Pn.size.get=function(){return new t.Point(this.width,this.height)},Pn.bearing.get=function(){return-this.angle/Math.PI*180},Pn.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},Pn.pitch.get=function(){return this._pitch/Math.PI*180},Pn.pitch.set=function(e){var r=t.clamp(e,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},Pn.fov.get=function(){return this._fov/Math.PI*180},Pn.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},Pn.zoom.get=function(){return this._zoom},Pn.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},Pn.center.get=function(){return this._center},Pn.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},Pn.padding.get=function(){return this._edgeInsets.toJSON()},Pn.padding.set=function(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())},Pn.centerPoint.get=function(){return this._edgeInsets.getCenter(this.width,this.height)},In.prototype.isPaddingEqual=function(t){return this._edgeInsets.equals(t)},In.prototype.interpolatePadding=function(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()},In.prototype.coveringZoomLevel=function(t){var e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)},In.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},In.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=[a*i.x,a*i.y,0],s=En.fromInvProjectionMatrix(this.invProjMatrix,this.worldSize,r),l=e.minzoom||0;this.pitch<=60&&this._edgeInsets.top<.1&&(l=r);var c=function(t){return{aabb:new Cn([t*a,0,0],[(t+1)*a,a,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}},u=[],h=[],f=r,p=e.reparseOverscaled?n:r;if(this._renderWorldCopies)for(var d=1;d<=3;d++)u.push(c(-d)),u.push(c(d));for(u.push(c(0));u.length>0;){var m=u.pop(),g=m.x,y=m.y,v=m.fullyVisible;if(!v){var x=m.aabb.intersects(s);if(0===x)continue;v=2===x}var _=m.aabb.distanceX(o),b=m.aabb.distanceY(o),w=Math.max(Math.abs(_),Math.abs(b)),T=3+(1<<f-m.zoom)-2;if(m.zoom===f||w>T&&m.zoom>=l)h.push({tileID:new t.OverscaledTileID(m.zoom===f?p:m.zoom,m.wrap,m.zoom,g,y),distanceSq:t.sqrLen([o[0]-.5-g,o[1]-.5-y])});else for(var k=0;k<4;k++){var A=(g<<1)+k%2,M=(y<<1)+(k>>1);u.push({aabb:m.aabb.quadrant(k),zoom:m.zoom+1,x:A,y:M,wrap:m.wrap,fullyVisible:v})}}return h.sort((function(t,e){return t.distanceSq-e.distanceSq})).map((function(t){return t.tileID}))},In.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},Pn.unmodified.get=function(){return this._unmodified},In.prototype.zoomScale=function(t){return Math.pow(2,t)},In.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},In.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},In.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},Pn.point.get=function(){return this.project(this.center)},In.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},In.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},In.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},In.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},In.prototype.coordinateLocation=function(t){return t.toLngLat()},In.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},In.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},In.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},In.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},In.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},In.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},In.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},In.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var m=p.y,g=c.y/2;m-g<a&&(i=a+g),m+g>o&&(i=o-g)}if(this.lngRange){var y=p.x,v=c.x/2;y-v<s&&(n=s+v),y+v>l&&(n=l-v)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},In.prototype._calcMatrices=function(){if(this.height){var e=this._fov/2,r=this.centerOffset;this.cameraToCenterDistance=.5/Math.tan(e)*this.height;var n=Math.PI/2+this._pitch,i=this._fov*(.5+r.y/this.height),a=Math.sin(i)*this.cameraToCenterDistance/Math.sin(t.clamp(Math.PI-n-i,.01,Math.PI-.01)),o=this.point,s=o.x,l=o.y,c=1.01*(Math.cos(Math.PI/2-this._pitch)*a+this.cameraToCenterDistance),u=this.height/50,h=new Float64Array(16);t.perspective(h,this._fov,this.width/this.height,u,c),h[8]=2*-r.x/this.width,h[9]=2*r.y/this.height,t.scale(h,h,[1,-1,1]),t.translate(h,h,[0,0,-this.cameraToCenterDistance]),t.rotateX(h,h,this._pitch),t.rotateZ(h,h,this.angle),t.translate(h,h,[-s,-l,0]),this.mercatorMatrix=t.scale([],h,[this.worldSize,this.worldSize,this.worldSize]),t.scale(h,h,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=h,this.invProjMatrix=t.invert([],this.projMatrix);var f=this.width%2/2,p=this.height%2/2,d=Math.cos(this.angle),m=Math.sin(this.angle),g=s-Math.round(s)+d*f+m*p,y=l-Math.round(l)+d*p+m*f,v=new Float64Array(h);if(t.translate(v,v,[g>.5?g-1:g,y>.5?y-1:y,0]),this.alignedProjMatrix=v,h=t.create(),t.scale(h,h,[this.width/2,-this.height/2,1]),t.translate(h,h,[1,-1,0]),this.labelPlaneMatrix=h,h=t.create(),t.scale(h,h,[1,-1,1]),t.translate(h,h,[-1,-1,0]),t.scale(h,h,[2/this.width,2/this.height,1]),this.glCoordMatrix=h,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(h=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=h,this._posMatrixCache={},this._alignedPosMatrixCache={}}},In.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},In.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},In.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(In.prototype,Pn);var zn=function(e){var r,n,i,a,o;this._hashName=e&&encodeURIComponent(e),t.bindAll([\"_getCurrentHash\",\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(r=this._updateHashUnthrottled.bind(this),n=300,i=!1,a=null,o=function(){a=null,i&&(r(),a=setTimeout(o,n),i=!1)},function(){return i=!0,a||o(),a})};zn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},zn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},zn.prototype.getHashString=function(e){var r=this._map.getCenter(),n=Math.round(100*this._map.getZoom())/100,i=Math.ceil((n*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,i),o=Math.round(r.lng*a)/a,s=Math.round(r.lat*a)/a,l=this._map.getBearing(),c=this._map.getPitch(),u=\"\";if(u+=e?\"/\"+o+\"/\"+s+\"/\"+n:n+\"/\"+s+\"/\"+o,(l||c)&&(u+=\"/\"+Math.round(10*l)/10),c&&(u+=\"/\"+Math.round(c)),this._hashName){var h=this._hashName,f=!1,p=t.window.location.hash.slice(1).split(\"&\").map((function(t){var e=t.split(\"=\")[0];return e===h?(f=!0,e+\"=\"+u):t})).filter((function(t){return t}));return f||p.push(h+\"=\"+u),\"#\"+p.join(\"&\")}return\"#\"+u},zn.prototype._getCurrentHash=function(){var e,r=this,n=t.window.location.hash.replace(\"#\",\"\");return this._hashName?(n.split(\"&\").map((function(t){return t.split(\"=\")})).forEach((function(t){t[0]===r._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")):n.split(\"/\")},zn.prototype._onHashChange=function(){var t=this._getCurrentHash();if(t.length>=3&&!t.some((function(t){return isNaN(t)}))){var e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},zn.prototype._updateHashUnthrottled=function(){var e=t.window.location.href.replace(/(#.+)?$/,this.getHashString());try{t.window.history.replaceState(t.window.history.state,null,e)}catch(t){}};var On={linearity:.3,easing:t.bezier(0,0,.3,1)},Dn=t.extend({deceleration:2500,maxSpeed:1400},On),Rn=t.extend({deceleration:20,maxSpeed:1400},On),Fn=t.extend({deceleration:1e3,maxSpeed:360},On),Bn=t.extend({deceleration:1e3,maxSpeed:90},On),Nn=function(t){this._map=t,this.clear()};function jn(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function Un(e,r,n){var i=n.maxSpeed,a=n.linearity,o=n.deceleration,s=t.clamp(e*a/(r/1e3),-i,i),l=Math.abs(s)/(o*a);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}Nn.prototype.clear=function(){this._inertiaBuffer=[]},Nn.prototype.record=function(e){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:t.browser.now(),settings:e})},Nn.prototype._drainInertiaBuffer=function(){for(var e=this._inertiaBuffer,r=t.browser.now();e.length>0&&r-e[0].time>160;)e.shift()},Nn.prototype._onMoveEnd=function(e){if(this._drainInertiaBuffer(),!(this._inertiaBuffer.length<2)){for(var r={zoom:0,bearing:0,pitch:0,pan:new t.Point(0,0),pinchAround:void 0,around:void 0},n=0,i=this._inertiaBuffer;n<i.length;n+=1){var a=i[n].settings;r.zoom+=a.zoomDelta||0,r.bearing+=a.bearingDelta||0,r.pitch+=a.pitchDelta||0,a.panDelta&&r.pan._add(a.panDelta),a.around&&(r.around=a.around),a.pinchAround&&(r.pinchAround=a.pinchAround)}var o=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,s={};if(r.pan.mag()){var l=Un(r.pan.mag(),o,t.extend({},Dn,e||{}));s.offset=r.pan.mult(l.amount/r.pan.mag()),s.center=this._map.transform.center,jn(s,l)}if(r.zoom){var c=Un(r.zoom,o,Rn);s.zoom=this._map.transform.zoom+c.amount,jn(s,c)}if(r.bearing){var u=Un(r.bearing,o,Fn);s.bearing=this._map.transform.bearing+t.clamp(u.amount,-179,179),jn(s,u)}if(r.pitch){var h=Un(r.pitch,o,Bn);s.pitch=this._map.transform.pitch+h.amount,jn(s,h)}if(s.zoom||s.bearing){var f=void 0===r.pinchAround?r.around:r.pinchAround;s.around=f?this._map.unproject(f):this._map.getCenter()}return this.clear(),t.extend(s,{noMoveStart:!0})}};var Vn=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),qn=function(e){function n(n,i,a){var o=\"touchend\"===n?a.changedTouches:a.touches,s=r.touchPos(i.getCanvasContainer(),o),l=s.map((function(t){return i.unproject(t)})),c=s.reduce((function(t,e,r,n){return t.add(e.div(n.length))}),new t.Point(0,0)),u=i.unproject(c);e.call(this,n,{points:s,point:c,lngLats:l,lngLat:u,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),Hn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Gn=function(t,e){this._map=t,this._clickTolerance=e.clickTolerance};Gn.prototype.reset=function(){delete this._mousedownPos},Gn.prototype.wheel=function(t){return this._firePreventable(new Hn(t.type,this._map,t))},Gn.prototype.mousedown=function(t,e){return this._mousedownPos=e,this._firePreventable(new Vn(t.type,this._map,t))},Gn.prototype.mouseup=function(t){this._map.fire(new Vn(t.type,this._map,t))},Gn.prototype.click=function(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new Vn(t.type,this._map,t))},Gn.prototype.dblclick=function(t){return this._firePreventable(new Vn(t.type,this._map,t))},Gn.prototype.mouseover=function(t){this._map.fire(new Vn(t.type,this._map,t))},Gn.prototype.mouseout=function(t){this._map.fire(new Vn(t.type,this._map,t))},Gn.prototype.touchstart=function(t){return this._firePreventable(new qn(t.type,this._map,t))},Gn.prototype.touchmove=function(t){this._map.fire(new qn(t.type,this._map,t))},Gn.prototype.touchend=function(t){this._map.fire(new qn(t.type,this._map,t))},Gn.prototype.touchcancel=function(t){this._map.fire(new qn(t.type,this._map,t))},Gn.prototype._firePreventable=function(t){if(this._map.fire(t),t.defaultPrevented)return{}},Gn.prototype.isEnabled=function(){return!0},Gn.prototype.isActive=function(){return!1},Gn.prototype.enable=function(){},Gn.prototype.disable=function(){};var Zn=function(t){this._map=t};Zn.prototype.reset=function(){this._delayContextMenu=!1,delete this._contextMenuEvent},Zn.prototype.mousemove=function(t){this._map.fire(new Vn(t.type,this._map,t))},Zn.prototype.mousedown=function(){this._delayContextMenu=!0},Zn.prototype.mouseup=function(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new Vn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)},Zn.prototype.contextmenu=function(t){this._delayContextMenu?this._contextMenuEvent=t:this._map.fire(new Vn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()},Zn.prototype.isEnabled=function(){return!0},Zn.prototype.isActive=function(){return!1},Zn.prototype.enable=function(){},Zn.prototype.disable=function(){};var Wn=function(t,e){this._map=t,this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1};function Yn(t,e){for(var r={},n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}Wn.prototype.isEnabled=function(){return!!this._enabled},Wn.prototype.isActive=function(){return!!this._active},Wn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Wn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Wn.prototype.mousedown=function(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(r.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)},Wn.prototype.mousemoveWindow=function(t,e){if(this._active){var n=e;if(!(this._lastPos.equals(n)||!this._box&&n.dist(this._startPos)<this._clickTolerance)){var i=this._startPos;this._lastPos=n,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var a=Math.min(i.x,n.x),o=Math.max(i.x,n.x),s=Math.min(i.y,n.y),l=Math.max(i.y,n.y);r.setTransform(this._box,\"translate(\"+a+\"px,\"+s+\"px)\"),this._box.style.width=o-a+\"px\",this._box.style.height=l-s+\"px\"}}},Wn.prototype.mouseupWindow=function(e,n){var i=this;if(this._active&&0===e.button){var a=this._startPos,o=n;if(this.reset(),r.suppressClick(),a.x!==o.x||a.y!==o.y)return this._map.fire(new t.Event(\"boxzoomend\",{originalEvent:e})),{cameraAnimation:function(t){return t.fitScreenCoordinates(a,o,i._map.getBearing(),{linear:!0})}};this._fireEvent(\"boxzoomcancel\",e)}},Wn.prototype.keydown=function(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))},Wn.prototype.reset=function(){this._active=!1,this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},Wn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var Xn=function(t){this.reset(),this.numTouches=t.numTouches};Xn.prototype.reset=function(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1},Xn.prototype.touchstart=function(e,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=e.timeStamp),n.length===this.numTouches&&(this.centroid=function(e){for(var r=new t.Point(0,0),n=0,i=e;n<i.length;n+=1){var a=i[n];r._add(a)}return r.div(e.length)}(r),this.touches=Yn(n,r)))},Xn.prototype.touchmove=function(t,e,r){if(!this.aborted&&this.centroid){var n=Yn(r,e);for(var i in this.touches){var a=this.touches[i],o=n[i];(!o||o.dist(a)>30)&&(this.aborted=!0)}}},Xn.prototype.touchend=function(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){var n=!this.aborted&&this.centroid;if(this.reset(),n)return n}};var $n=function(t){this.singleTap=new Xn(t),this.numTaps=t.numTaps,this.reset()};$n.prototype.reset=function(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()},$n.prototype.touchstart=function(t,e,r){this.singleTap.touchstart(t,e,r)},$n.prototype.touchmove=function(t,e,r){this.singleTap.touchmove(t,e,r)},$n.prototype.touchend=function(t,e,r){var n=this.singleTap.touchend(t,e,r);if(n){var i=t.timeStamp-this.lastTime<500,a=!this.lastTap||this.lastTap.dist(n)<30;if(i&&a||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}};var Jn=function(){this._zoomIn=new $n({numTouches:1,numTaps:2}),this._zoomOut=new $n({numTouches:2,numTaps:1}),this.reset()};Jn.prototype.reset=function(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()},Jn.prototype.touchstart=function(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)},Jn.prototype.touchmove=function(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)},Jn.prototype.touchend=function(t,e,r){var n=this,i=this._zoomIn.touchend(t,e,r),a=this._zoomOut.touchend(t,e,r);return i?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()+1,around:e.unproject(i)},{originalEvent:t})}}):a?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()-1,around:e.unproject(a)},{originalEvent:t})}}):void 0},Jn.prototype.touchcancel=function(){this.reset()},Jn.prototype.enable=function(){this._enabled=!0},Jn.prototype.disable=function(){this._enabled=!1,this.reset()},Jn.prototype.isEnabled=function(){return this._enabled},Jn.prototype.isActive=function(){return this._active};var Kn={};Kn[0]=1,Kn[2]=2;var Qn=function(t){this.reset(),this._clickTolerance=t.clickTolerance||1};Qn.prototype.reset=function(){this._active=!1,this._moved=!1,delete this._lastPoint,delete this._eventButton},Qn.prototype._correctButton=function(t,e){return!1},Qn.prototype._move=function(t,e){return{}},Qn.prototype.mousedown=function(t,e){if(!this._lastPoint){var n=r.mouseButton(t);this._correctButton(t,n)&&(this._lastPoint=e,this._eventButton=n)}},Qn.prototype.mousemoveWindow=function(t,e){var r=this._lastPoint;if(r)if(t.preventDefault(),function(t,e){var r=Kn[e];return void 0===t.buttons||(t.buttons&r)!==r}(t,this._eventButton))this.reset();else if(this._moved||!(e.dist(r)<this._clickTolerance))return this._moved=!0,this._lastPoint=e,this._move(r,e)},Qn.prototype.mouseupWindow=function(t){this._lastPoint&&r.mouseButton(t)===this._eventButton&&(this._moved&&r.suppressClick(),this.reset())},Qn.prototype.enable=function(){this._enabled=!0},Qn.prototype.disable=function(){this._enabled=!1,this.reset()},Qn.prototype.isEnabled=function(){return this._enabled},Qn.prototype.isActive=function(){return this._active};var ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.mousedown=function(e,r){t.prototype.mousedown.call(this,e,r),this._lastPoint&&(this._active=!0)},e.prototype._correctButton=function(t,e){return 0===e&&!t.ctrlKey},e.prototype._move=function(t,e){return{around:e,panDelta:e.sub(t)}},e}(Qn),ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=.8*(e.x-t.x);if(r)return this._active=!0,{bearingDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(Qn),ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=-.5*(e.y-t.y);if(r)return this._active=!0,{pitchDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(Qn),ni=function(t){this._minTouches=1,this._clickTolerance=t.clickTolerance||1,this.reset()};ni.prototype.reset=function(){this._active=!1,this._touches={},this._sum=new t.Point(0,0)},ni.prototype.touchstart=function(t,e,r){return this._calculateTransform(t,e,r)},ni.prototype.touchmove=function(t,e,r){if(this._active&&!(r.length<this._minTouches))return t.preventDefault(),this._calculateTransform(t,e,r)},ni.prototype.touchend=function(t,e,r){this._calculateTransform(t,e,r),this._active&&r.length<this._minTouches&&this.reset()},ni.prototype.touchcancel=function(){this.reset()},ni.prototype._calculateTransform=function(e,r,n){n.length>0&&(this._active=!0);var i=Yn(n,r),a=new t.Point(0,0),o=new t.Point(0,0),s=0;for(var l in i){var c=i[l],u=this._touches[l];u&&(a._add(c),o._add(c.sub(u)),s++,i[l]=c)}if(this._touches=i,!(s<this._minTouches)&&o.mag()){var h=o.div(s);if(this._sum._add(h),!(this._sum.mag()<this._clickTolerance))return{around:a.div(s),panDelta:h}}},ni.prototype.enable=function(){this._enabled=!0},ni.prototype.disable=function(){this._enabled=!1,this.reset()},ni.prototype.isEnabled=function(){return this._enabled},ni.prototype.isActive=function(){return this._active};var ii=function(){this.reset()};function ai(t,e,r){for(var n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}ii.prototype.reset=function(){this._active=!1,delete this._firstTwoTouches},ii.prototype._start=function(t){},ii.prototype._move=function(t,e,r){return{}},ii.prototype.touchstart=function(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))},ii.prototype.touchmove=function(t,e,r){if(this._firstTwoTouches){t.preventDefault();var n=this._firstTwoTouches,i=n[0],a=n[1],o=ai(r,e,i),s=ai(r,e,a);if(o&&s){var l=this._aroundCenter?null:o.add(s).div(2);return this._move([o,s],l,t)}}},ii.prototype.touchend=function(t,e,n){if(this._firstTwoTouches){var i=this._firstTwoTouches,a=i[0],o=i[1],s=ai(n,e,a),l=ai(n,e,o);s&&l||(this._active&&r.suppressClick(),this.reset())}},ii.prototype.touchcancel=function(){this.reset()},ii.prototype.enable=function(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around},ii.prototype.disable=function(){this._enabled=!1,this.reset()},ii.prototype.isEnabled=function(){return this._enabled},ii.prototype.isActive=function(){return this._active};function oi(t,e){return Math.log(t/e)/Math.LN2}var si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._distance,delete this._startDistance},e.prototype._start=function(t){this._startDistance=this._distance=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs(oi(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:oi(this._distance,r),pinchAround:e}},e}(ii);function li(t,e){return 180*t.angleWith(e)/Math.PI}var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._minDiameter,delete this._startVector,delete this._vector},e.prototype._start=function(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:li(this._vector,r),pinchAround:e}},e.prototype._isBelowThreshold=function(t){this._minDiameter=Math.min(this._minDiameter,t.mag());var e=25/(Math.PI*this._minDiameter)*360,r=li(t,this._startVector);return Math.abs(r)<e},e}(ii);function ui(t){return Math.abs(t.y)>Math.abs(t.x)}var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),this._valid=void 0,delete this._firstMove,delete this._lastPoints},e.prototype._start=function(t){this._lastPoints=t,ui(t[0].sub(t[1]))&&(this._valid=!1)},e.prototype._move=function(t,e,r){var n=t[0].sub(this._lastPoints[0]),i=t[1].sub(this._lastPoints[1]);if(this._valid=this.gestureBeginsVertically(n,i,r.timeStamp),this._valid)return this._lastPoints=t,this._active=!0,{pitchDelta:(n.y+i.y)/2*-.5}},e.prototype.gestureBeginsVertically=function(t,e,r){if(void 0!==this._valid)return this._valid;var n=t.mag()>=2,i=e.mag()>=2;if(n||i){if(!n||!i)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;var a=t.y>0==e.y>0;return ui(t)&&ui(e)&&a}},e}(ii),fi={panStep:100,bearingStep:15,pitchStep:10},pi=function(){var t=fi;this._panStep=t.panStep,this._bearingStep=t.bearingStep,this._pitchStep=t.pitchStep,this._rotationDisabled=!1};function di(t){return t*(2-t)}pi.prototype.reset=function(){this._active=!1},pi.prototype.keydown=function(t){var e=this;if(!(t.altKey||t.ctrlKey||t.metaKey)){var r=0,n=0,i=0,a=0,o=0;switch(t.keyCode){case 61:case 107:case 171:case 187:r=1;break;case 189:case 109:case 173:r=-1;break;case 37:t.shiftKey?n=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?n=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?i=1:(t.preventDefault(),o=-1);break;case 40:t.shiftKey?i=-1:(t.preventDefault(),o=1);break;default:return}return this._rotationDisabled&&(n=0,i=0),{cameraAnimation:function(s){var l=s.getZoom();s.easeTo({duration:300,easeId:\"keyboardHandler\",easing:di,zoom:r?Math.round(l)+r*(t.shiftKey?2:1):l,bearing:s.getBearing()+n*e._bearingStep,pitch:s.getPitch()+i*e._pitchStep,offset:[-a*e._panStep,-o*e._panStep],center:s.getCenter()},{originalEvent:t})}}}},pi.prototype.enable=function(){this._enabled=!0},pi.prototype.disable=function(){this._enabled=!1,this.reset()},pi.prototype.isEnabled=function(){return this._enabled},pi.prototype.isActive=function(){return this._active},pi.prototype.disableRotation=function(){this._rotationDisabled=!0},pi.prototype.enableRotation=function(){this._rotationDisabled=!1};var mi=4.000244140625,gi=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._handler=r,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=.0022222222222222222,t.bindAll([\"_onTimeout\"],this)};gi.prototype.setZoomRate=function(t){this._defaultZoomRate=t},gi.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},gi.prototype.isEnabled=function(){return!!this._enabled},gi.prototype.isActive=function(){return!!this._active||void 0!==this._finishTimeout},gi.prototype.isZooming=function(){return!!this._zooming},gi.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},gi.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},gi.prototype.wheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%mi==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this._active||this._start(e)),e.preventDefault()}},gi.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},gi.prototype._start=function(e){if(this._delta){this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._handler._triggerRenderFrame())}},gi.prototype.renderFrame=function(){var e=this;if(this._frameId&&(this._frameId=null,this.isActive())){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>mi?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o,s=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,l=this._startZoom,c=this._easing,u=!1;if(\"wheel\"===this._type&&l&&c){var h=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),f=c(h);o=t.number(l,s,f),h<1?this._frameId||(this._frameId=!0):u=!0}else o=s,u=!0;return this._active=!0,u&&(this._active=!1,this._finishTimeout=setTimeout((function(){e._zooming=!1,e._handler._triggerRenderFrame(),delete e._targetZoom,delete e._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!u,zoomDelta:o-r.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}},gi.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r},gi.prototype.reset=function(){this._active=!1};var yi=function(t,e){this._clickZoom=t,this._tapZoom=e};yi.prototype.enable=function(){this._clickZoom.enable(),this._tapZoom.enable()},yi.prototype.disable=function(){this._clickZoom.disable(),this._tapZoom.disable()},yi.prototype.isEnabled=function(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()},yi.prototype.isActive=function(){return this._clickZoom.isActive()||this._tapZoom.isActive()};var vi=function(){this.reset()};vi.prototype.reset=function(){this._active=!1},vi.prototype.dblclick=function(t,e){return t.preventDefault(),{cameraAnimation:function(r){r.easeTo({duration:300,zoom:r.getZoom()+(t.shiftKey?-1:1),around:r.unproject(e)},{originalEvent:t})}}},vi.prototype.enable=function(){this._enabled=!0},vi.prototype.disable=function(){this._enabled=!1,this.reset()},vi.prototype.isEnabled=function(){return this._enabled},vi.prototype.isActive=function(){return this._active};var xi=function(){this._tap=new $n({numTouches:1,numTaps:1}),this.reset()};xi.prototype.reset=function(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,this._tap.reset()},xi.prototype.touchstart=function(t,e,r){this._swipePoint||(this._tapTime&&t.timeStamp-this._tapTime>500&&this.reset(),this._tapTime?r.length>0&&(this._swipePoint=e[0],this._swipeTouch=r[0].identifier):this._tap.touchstart(t,e,r))},xi.prototype.touchmove=function(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;var n=e[0],i=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:i/128}}}else this._tap.touchmove(t,e,r)},xi.prototype.touchend=function(t,e,r){this._tapTime?this._swipePoint&&0===r.length&&this.reset():this._tap.touchend(t,e,r)&&(this._tapTime=t.timeStamp)},xi.prototype.touchcancel=function(){this.reset()},xi.prototype.enable=function(){this._enabled=!0},xi.prototype.disable=function(){this._enabled=!1,this.reset()},xi.prototype.isEnabled=function(){return this._enabled},xi.prototype.isActive=function(){return this._active};var _i=function(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r};_i.prototype.enable=function(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"mapboxgl-touch-drag-pan\")},_i.prototype.disable=function(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"mapboxgl-touch-drag-pan\")},_i.prototype.isEnabled=function(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()},_i.prototype.isActive=function(){return this._mousePan.isActive()||this._touchPan.isActive()};var bi=function(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r};bi.prototype.enable=function(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()},bi.prototype.disable=function(){this._mouseRotate.disable(),this._mousePitch.disable()},bi.prototype.isEnabled=function(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())},bi.prototype.isActive=function(){return this._mouseRotate.isActive()||this._mousePitch.isActive()};var wi=function(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0};wi.prototype.enable=function(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"mapboxgl-touch-zoom-rotate\")},wi.prototype.disable=function(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\")},wi.prototype.isEnabled=function(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()},wi.prototype.isActive=function(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()},wi.prototype.disableRotation=function(){this._rotationDisabled=!0,this._touchRotate.disable()},wi.prototype.enableRotation=function(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()};var Ti=function(t){return t.zoom||t.drag||t.pitch||t.rotate},ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(t.Event);function Ai(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}var Mi=function(e,n){this._map=e,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new Nn(e),this._bearingSnap=n.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(n),t.bindAll([\"handleEvent\",\"handleWindowEvent\"],this);var i=this._el;this._listeners=[[i,\"touchstart\",{passive:!0}],[i,\"touchmove\",{passive:!1}],[i,\"touchend\",void 0],[i,\"touchcancel\",void 0],[i,\"mousedown\",void 0],[i,\"mousemove\",void 0],[i,\"mouseup\",void 0],[t.window.document,\"mousemove\",{capture:!0}],[t.window.document,\"mouseup\",void 0],[i,\"mouseover\",void 0],[i,\"mouseout\",void 0],[i,\"dblclick\",void 0],[i,\"click\",void 0],[i,\"keydown\",{capture:!1}],[i,\"keyup\",void 0],[i,\"wheel\",{passive:!1}],[i,\"contextmenu\",void 0],[t.window,\"blur\",void 0]];for(var a=0,o=this._listeners;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1],u=s[2];r.addEventListener(l,c,l===t.window.document?this.handleWindowEvent:this.handleEvent,u)}};Mi.prototype.destroy=function(){for(var e=0,n=this._listeners;e<n.length;e+=1){var i=n[e],a=i[0],o=i[1],s=i[2];r.removeEventListener(a,o,a===t.window.document?this.handleWindowEvent:this.handleEvent,s)}},Mi.prototype._addDefaultHandlers=function(t){var e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Gn(e,t));var n=e.boxZoom=new Wn(e,t);this._add(\"boxZoom\",n);var i=new Jn,a=new vi;e.doubleClickZoom=new yi(a,i),this._add(\"tapZoom\",i),this._add(\"clickZoom\",a);var o=new xi;this._add(\"tapDragZoom\",o);var s=e.touchPitch=new hi;this._add(\"touchPitch\",s);var l=new ei(t),c=new ri(t);e.dragRotate=new bi(t,l,c),this._add(\"mouseRotate\",l,[\"mousePitch\"]),this._add(\"mousePitch\",c,[\"mouseRotate\"]);var u=new ti(t),h=new ni(t);e.dragPan=new _i(r,u,h),this._add(\"mousePan\",u),this._add(\"touchPan\",h,[\"touchZoom\",\"touchRotate\"]);var f=new ci,p=new si;e.touchZoomRotate=new wi(r,p,f,o),this._add(\"touchRotate\",f,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",p,[\"touchPan\",\"touchRotate\"]);var d=e.scrollZoom=new gi(e,this);this._add(\"scrollZoom\",d,[\"mousePan\"]);var m=e.keyboard=new pi;this._add(\"keyboard\",m),this._add(\"blockableMapEvent\",new Zn(e));for(var g=0,y=[\"boxZoom\",\"doubleClickZoom\",\"tapDragZoom\",\"touchPitch\",\"dragRotate\",\"dragPan\",\"touchZoomRotate\",\"scrollZoom\",\"keyboard\"];g<y.length;g+=1){var v=y[g];t.interactive&&t[v]&&e[v].enable(t[v])}},Mi.prototype._add=function(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e},Mi.prototype.stop=function(t){if(!this._updatingCamera){for(var e=0,r=this._handlers;e<r.length;e+=1)r[e].handler.reset();this._inertia.clear(),this._fireEvents({},{},t),this._changes=[]}},Mi.prototype.isActive=function(){for(var t=0,e=this._handlers;t<e.length;t+=1)if(e[t].handler.isActive())return!0;return!1},Mi.prototype.isZooming=function(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()},Mi.prototype.isRotating=function(){return!!this._eventsInProgress.rotate},Mi.prototype.isMoving=function(){return Boolean(Ti(this._eventsInProgress))||this.isZooming()},Mi.prototype._blockedByActive=function(t,e,r){for(var n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1},Mi.prototype.handleWindowEvent=function(t){this.handleEvent(t,t.type+\"Window\")},Mi.prototype._getMapTouches=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.target;this._el.contains(a)&&e.push(i)}return e},Mi.prototype.handleEvent=function(t,e){if(\"blur\"!==t.type){this._updatingCamera=!0;for(var n=\"renderFrame\"===t.type?void 0:t,i={needsRenderFrame:!1},a={},o={},s=t.touches?this._getMapTouches(t.touches):void 0,l=s?r.touchPos(this._el,s):r.mousePos(this._el,t),c=0,u=this._handlers;c<u.length;c+=1){var h=u[c],f=h.handlerName,p=h.handler,d=h.allowed;if(p.isEnabled()){var m=void 0;this._blockedByActive(o,d,f)?p.reset():p[e||t.type]&&(m=p[e||t.type](t,l,s),this.mergeHandlerResult(i,a,m,f,n),m&&m.needsRenderFrame&&this._triggerRenderFrame()),(m||p.isActive())&&(o[f]=p)}}var g={};for(var y in this._previousActiveHandlers)o[y]||(g[y]=n);this._previousActiveHandlers=o,(Object.keys(g).length||Ai(i))&&(this._changes.push([i,a,g]),this._triggerRenderFrame()),(Object.keys(o).length||Ai(i))&&this._map._stop(!0),this._updatingCamera=!1;var v=i.cameraAnimation;v&&(this._inertia.clear(),this._fireEvents({},{},!0),this._changes=[],v(this._map))}else this.stop(!0)},Mi.prototype.mergeHandlerResult=function(e,r,n,i,a){if(n){t.extend(e,n);var o={handlerName:i,originalEvent:n.originalEvent||a};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}},Mi.prototype._applyChanges=function(){for(var e={},r={},n={},i=0,a=this._changes;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=o[2];s.panDelta&&(e.panDelta=(e.panDelta||new t.Point(0,0))._add(s.panDelta)),s.zoomDelta&&(e.zoomDelta=(e.zoomDelta||0)+s.zoomDelta),s.bearingDelta&&(e.bearingDelta=(e.bearingDelta||0)+s.bearingDelta),s.pitchDelta&&(e.pitchDelta=(e.pitchDelta||0)+s.pitchDelta),void 0!==s.around&&(e.around=s.around),void 0!==s.pinchAround&&(e.pinchAround=s.pinchAround),s.noInertia&&(e.noInertia=s.noInertia),t.extend(r,l),t.extend(n,c)}this._updateMapTransform(e,r,n),this._changes=[]},Mi.prototype._updateMapTransform=function(t,e,r){var n=this._map,i=n.transform;if(!Ai(t))return this._fireEvents(e,r,!0);var a=t.panDelta,o=t.zoomDelta,s=t.bearingDelta,l=t.pitchDelta,c=t.around,u=t.pinchAround;void 0!==u&&(c=u),n._stop(!0),c=c||n.transform.centerPoint;var h=i.pointLocation(a?c.sub(a):c);s&&(i.bearing+=s),l&&(i.pitch+=l),o&&(i.zoom+=o),i.setLocationAtPoint(h,c),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r,!0)},Mi.prototype._fireEvents=function(e,r,n){var i=this,a=Ti(this._eventsInProgress),o=Ti(e),s={};for(var l in e){var c=e[l].originalEvent;this._eventsInProgress[l]||(s[l+\"start\"]=c),this._eventsInProgress[l]=e[l]}for(var u in!a&&o&&this._fireEvent(\"movestart\",o.originalEvent),s)this._fireEvent(u,s[u]);for(var h in o&&this._fireEvent(\"move\",o.originalEvent),e){var f=e[h].originalEvent;this._fireEvent(h,f)}var p,d={};for(var m in this._eventsInProgress){var g=this._eventsInProgress[m],y=g.handlerName,v=g.originalEvent;this._handlersById[y].isActive()||(delete this._eventsInProgress[m],p=r[y]||v,d[m+\"end\"]=p)}for(var x in d)this._fireEvent(x,d[x]);var _=Ti(this._eventsInProgress);if(n&&(a||o)&&!_){this._updatingCamera=!0;var b=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),w=function(t){return 0!==t&&-i._bearingSnap<t&&t<i._bearingSnap};b?(w(b.bearing||this._map.getBearing())&&(b.bearing=0),this._map.easeTo(b,{originalEvent:p})):(this._map.fire(new t.Event(\"moveend\",{originalEvent:p})),w(this._map.getBearing())&&this._map.resetNorth()),this._updatingCamera=!1}},Mi.prototype._fireEvent=function(e,r){this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},Mi.prototype._requestFrame=function(){var t=this;return this._map.triggerRepaint(),this._map._renderTaskQueue.add((function(e){delete t._frameId,t.handleEvent(new ki(\"renderFrame\",{timeStamp:e})),t._applyChanges()}))},Mi.prototype._triggerRenderFrame=function(){void 0===this._frameId&&(this._frameId=this._requestFrame())};var Si=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.getPadding=function(){return this.transform.padding},r.prototype.setPadding=function(t,e){return this.jumpTo({padding:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){e=t.LngLatBounds.convert(e);var n=r&&r.bearing||0;return this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),n,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){var a={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(i=t.extend({padding:a,offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var o=i.padding;i.padding={top:o,bottom:o,right:o,left:o}}i.padding=t.extend(a,i.padding);var s=this.transform,l=s.padding,c=s.project(t.LngLat.convert(e)),u=s.project(t.LngLat.convert(r)),h=c.rotate(-n*Math.PI/180),f=u.rotate(-n*Math.PI/180),p=new t.Point(Math.max(h.x,f.x),Math.max(h.y,f.y)),d=new t.Point(Math.min(h.x,f.x),Math.min(h.y,f.y)),m=p.sub(d),g=(s.width-(l.left+l.right+i.padding.left+i.padding.right))/m.x,y=(s.height-(l.top+l.bottom+i.padding.top+i.padding.bottom))/m.y;if(!(y<0||g<0)){var v=Math.min(s.scaleZoom(s.scale*Math.min(g,y)),i.maxZoom),x=\"number\"==typeof i.offset.x?new t.Point(i.offset.x,i.offset.y):t.Point.convert(i.offset),_=(i.padding.left-i.padding.right)/2,b=(i.padding.top-i.padding.bottom)/2,w=new t.Point(_,b).rotate(n*Math.PI/180),T=x.add(w).mult(s.scale/s.zoomScale(v));return{center:s.unproject(c.add(u).div(2).sub(T)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(delete(r=t.extend(e,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),null==e.padding||n.isPaddingEqual(e.padding)||(n.padding=e.padding),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this._stop(!1,e.easeId),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||!e.essential&&t.browser.prefersReducedMotion)&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=this.getPadding(),c=\"zoom\"in e?+e.zoom:a,u=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,h=\"pitch\"in e?+e.pitch:s,f=\"padding\"in e?e.padding:i.padding,p=t.Point.convert(e.offset),d=i.centerPoint.add(p),m=i.pointLocation(d),g=t.LngLat.convert(e.center||m);this._normalizeCenter(g);var y,v,x=i.project(m),_=i.project(g).sub(x),b=i.zoomScale(c-a);e.around&&(y=t.LngLat.convert(e.around),v=i.locationPoint(y));var w={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||c!==a,this._rotating=this._rotating||o!==u,this._pitching=this._pitching||h!==s,this._padding=!i.isPaddingEqual(f),this._easeId=e.easeId,this._prepareEase(r,e.noMoveStart,w),this._ease((function(e){if(n._zooming&&(i.zoom=t.number(a,c,e)),n._rotating&&(i.bearing=t.number(o,u,e)),n._pitching&&(i.pitch=t.number(s,h,e)),n._padding&&(i.interpolatePadding(l,f,e),d=i.centerPoint.add(p)),y)i.setLocationAtPoint(y,v);else{var m=i.zoomScale(i.zoom-a),g=c>a?Math.min(2,b):Math.max(.5,b),w=Math.pow(g,1-e),T=i.unproject(x.add(_.mult(e*w)).mult(m));i.setLocationAtPoint(i.renderWorldCopies?T.wrap():T,d)}n._fireMoveEvents(r)}),(function(t){n._afterEase(r,t)}),e),this},r.prototype._prepareEase=function(e,r,n){void 0===n&&(n={}),this._moving=!0,r||n.moving||this.fire(new t.Event(\"movestart\",e)),this._zooming&&!n.zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&!n.rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&!n.pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e,r){if(!this._easeId||!r||this._easeId!==r){delete this._easeId;var n=this._zooming,i=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new t.Event(\"zoomend\",e)),i&&this.fire(new t.Event(\"rotateend\",e)),a&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))}},r.prototype.flyTo=function(e,r){var n=this;if(!e.essential&&t.browser.prefersReducedMotion){var i=t.pick(e,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(i,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var a=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c=this.getPadding(),u=\"zoom\"in e?t.clamp(+e.zoom,a.minZoom,a.maxZoom):o,h=\"bearing\"in e?this._normalizeBearing(e.bearing,s):s,f=\"pitch\"in e?+e.pitch:l,p=\"padding\"in e?e.padding:a.padding,d=a.zoomScale(u-o),m=t.Point.convert(e.offset),g=a.centerPoint.add(m),y=a.pointLocation(g),v=t.LngLat.convert(e.center||y);this._normalizeCenter(v);var x=a.project(y),_=a.project(v).sub(x),b=e.curve,w=Math.max(a.width,a.height),T=w/d,k=_.mag();if(\"minZoom\"in e){var A=t.clamp(Math.min(e.minZoom,o,u),a.minZoom,a.maxZoom),M=w/a.zoomScale(A-o);b=Math.sqrt(M/k*2)}var S=b*b;function E(t){var e=(T*T-w*w+(t?-1:1)*S*S*k*k)/(2*(t?T:w)*S*k);return Math.log(Math.sqrt(e*e+1)-e)}function C(t){return(Math.exp(t)-Math.exp(-t))/2}function L(t){return(Math.exp(t)+Math.exp(-t))/2}var I=E(0),P=function(t){return L(I)/L(I+b*t)},z=function(t){return w*((L(I)*(C(e=I+b*t)/L(e))-C(I))/S)/k;var e},O=(E(1)-I)/b;if(Math.abs(k)<1e-6||!isFinite(O)){if(Math.abs(w-T)<1e-6)return this.easeTo(e,r);var D=T<w?-1:1;O=Math.abs(Math.log(T/w))/b,z=function(){return 0},P=function(t){return Math.exp(D*b*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var R=\"screenSpeed\"in e?+e.screenSpeed/b:+e.speed;e.duration=1e3*O/R}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==h,this._pitching=f!==l,this._padding=!a.isPaddingEqual(p),this._prepareEase(r,!1),this._ease((function(e){var i=e*O,d=1/P(i);a.zoom=1===e?u:o+a.scaleZoom(d),n._rotating&&(a.bearing=t.number(s,h,e)),n._pitching&&(a.pitch=t.number(l,f,e)),n._padding&&(a.interpolatePadding(c,p,e),g=a.centerPoint.add(m));var y=1===e?v:a.unproject(x.add(_.mult(z(i))).mult(d));a.setLocationAtPoint(a.renderWorldCopies?y.wrap():y,g),n._fireMoveEvents(r)}),(function(){return n._afterEase(r)}),e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){return this._stop()},r.prototype._stop=function(t,e){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var r=this._onEaseEnd;delete this._onEaseEnd,r.call(this,e)}if(!t){var n=this.handlers;n&&n.stop(!1)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Ei=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_toggleAttribution\",\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Ei.prototype.getDefaultPosition=function(){return\"bottom-right\"},Ei.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._compactButton=r.create(\"button\",\"mapboxgl-ctrl-attrib-button\",this._container),this._compactButton.addEventListener(\"click\",this._toggleAttribution),this._setElementTitle(this._compactButton,\"ToggleAttribution\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),this._innerContainer.setAttribute(\"role\",\"list\"),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Ei.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._attribHTML=void 0},Ei.prototype._setElementTitle=function(t,e){var r=this._map._getUIString(\"AttributionControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)},Ei.prototype._toggleAttribution=function(){this._container.classList.contains(\"mapboxgl-compact-show\")?(this._container.classList.remove(\"mapboxgl-compact-show\"),this._compactButton.setAttribute(\"aria-pressed\",\"false\")):(this._container.classList.add(\"mapboxgl-compact-show\"),this._compactButton.setAttribute(\"aria-pressed\",\"true\"))},Ei.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce((function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t}),\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\",this._setElementTitle(e,\"MapFeedback\")}},Ei.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"visibility\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Ei.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((function(t){return\"string\"!=typeof t?\"\":t}))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort((function(t,e){return t.length-e.length}));var o=(t=t.filter((function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}))).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Ei.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\",\"mapboxgl-compact-show\")};var Ci=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Ci.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Ci.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Ci.prototype.getDefaultPosition=function(){return\"bottom-left\"},Ci.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Ci.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Ci.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var Li=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};Li.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},Li.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},Li.prototype.run=function(t){void 0===t&&(t=0);var e=this._currentlyRunning=this._queue;this._queue=[];for(var r=0,n=e;r<n.length;r+=1){var i=n[r];if(!i.cancelled&&(i.callback(t),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},Li.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Ii={\"AttributionControl.ToggleAttribution\":\"Toggle attribution\",\"AttributionControl.MapFeedback\":\"Map feedback\",\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"Mapbox logo\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\"},Pi=t.window.HTMLImageElement,zi=t.window.HTMLElement,Oi=t.window.ImageBitmap,Di=60,Ri={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:Di,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,bearingSnap:7,clickTolerance:3,pitchWithRotate:!0,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Fi=function(n){function i(e){var r=this;if(null!=(e=t.extend({},Ri,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=e.minPitch&&null!=e.maxPitch&&e.minPitch>e.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=e.minPitch&&e.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=e.maxPitch&&e.maxPitch>Di)throw new Error(\"maxPitch must be less than or equal to 60\");var i=new In(e.minZoom,e.maxZoom,e.minPitch,e.maxPitch,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new Li,this._controls=[],this._mapId=t.uniqueId(),this._locale=t.extend({},Ii,e.locale),this._clickTolerance=e.clickTolerance,this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof zi))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_onMapScroll\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",(function(){return r._update(!1)})),this.on(\"moveend\",(function(){return r._update(!1)})),this.on(\"zoom\",(function(){return r._update(!0)})),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1),t.window.addEventListener(\"orientationchange\",this._onWindowResize,!1)),this.handlers=new Mi(this,e);var a=\"string\"==typeof e.hash&&e.hash||void 0;this._hash=e.hash&&new zn(a).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Ei({customAttribution:e.customAttribution})),this.addControl(new Ci,e.logoPosition),this.on(\"style.load\",(function(){r.transform.unmodified&&r.jumpTo(r.style.stylesheet)})),this.on(\"data\",(function(e){r._update(\"style\"===e.dataType),r.fire(new t.Event(e.dataType+\"data\",e))})),this.on(\"dataloading\",(function(e){r.fire(new t.Event(e.dataType+\"dataloading\",e))}))}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showPadding:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&(r=e.getDefaultPosition?e.getDefaultPosition():\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.hasControl=function(t){return this._controls.indexOf(t)>-1},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i);var a=!this._moving;return a&&(this.stop(),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e))),this.fire(new t.Event(\"resize\",e)),a&&this.fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.setMinPitch=function(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")},i.prototype.getMinPitch=function(){return this.transform.minPitch},i.prototype.setMaxPitch=function(t){if((t=null==t?Di:t)>Di)throw new Error(\"maxPitch must be less than or equal to 60\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")},i.prototype.getMaxPitch=function(){return this.transform.maxPitch},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.handlers.isMoving()},i.prototype.isZooming=function(){return this._zooming||this.handlers.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.handlers.isRotating()},i.prototype._createDelegatedListener=function(t,e,r){var n,i=this;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new Vn(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new Vn(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new Vn(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}},i.prototype.on=function(t,e,r){if(void 0===r)return n.prototype.on.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(a,i.delegates[a]);return this},i.prototype.once=function(t,e,r){if(void 0===r)return n.prototype.once.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in i.delegates)this.once(a,i.delegates[a]);return this},i.prototype.off=function(t,e,r){var i=this;if(void 0===r)return n.prototype.off.call(this,t,e);return this._delegatedListeners&&this._delegatedListeners[t]&&function(n){for(var a=n[t],o=0;o<a.length;o++){var s=a[o];if(s.layer===e&&s.listener===r){for(var l in s.delegates)i.off(l,s.delegates[l]);return a.splice(o,1),i}}}(this._delegatedListeners),this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._getUIString=function(t){var e=this._locale[t];if(null==e)throw new Error(\"Missing UI string '\"+t+\"'\");return e},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new We(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._lazyInitEmptyStyle=function(){this.style||(this.style=new We(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,(function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)}))}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this._lazyInitEmptyStyle(),this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;void 0===a&&(a=!1);var o=n.stretchX,s=n.stretchY,l=n.content;this._lazyInitEmptyStyle();if(r instanceof Pi||Oi&&r instanceof Oi){var c=t.browser.getImageData(r),u=c.width,h=c.height,f=c.data;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},f),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var p=r.width,d=r.height,m=r.data,g=r;this.style.addImage(e,{data:new t.RGBAImage({width:p,height:d},new Uint8Array(m)),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0,userImage:g}),g.onAdd&&g.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Pi||Oi&&r instanceof Oi?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Pi||Oi&&r instanceof Oi);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\"),this._canvas.setAttribute(\"role\",\"region\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})),this._container.addEventListener(\"scroll\",this._onMapScroll,!1)},i.prototype._resizeCanvas=function(e,r){var n=t.browser.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new Sn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype._onMapScroll=function(t){if(t.target===this._container)return this._container.scrollTop=0,this._container.scrollLeft=0,!1},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(e){var r,n=this,i=0,a=this.painter.context.extTimerQuery;if(this.listens(\"gpu-timing-frame\")&&(r=a.createQueryEXT(),a.beginQueryEXT(a.TIME_ELAPSED_EXT,r),i=t.browser.now()),this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(e),!this._removed){var o=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var s=this.transform.zoom,l=t.browser.now();this.style.zoomHistory.update(s,l);var c=new t.EvaluationParameters(s,{now:l,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),u=c.crossFadingFactor();1===u&&u===this._crossFadingFactor||(o=!0,this._crossFadingFactor=u),this.style.update(c)}if(this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration,showPadding:this.showPadding,gpuTiming:!!this.listens(\"gpu-timing-layer\")}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||o)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this.listens(\"gpu-timing-frame\")){var h=t.browser.now()-i;a.endQueryEXT(a.TIME_ELAPSED_EXT,r),setTimeout((function(){var e=a.getQueryObjectEXT(r,a.QUERY_RESULT_EXT)/1e6;a.deleteQueryEXT(r),n.fire(new t.Event(\"gpu-timing-frame\",{cpuTime:h,gpuTime:e}))}),50)}if(this.listens(\"gpu-timing-layer\")){var f=this.painter.collectGpuTimers();setTimeout((function(){var e=n.painter.queryGpuTimers(f);n.fire(new t.Event(\"gpu-timing-layer\",{layerTimes:e}))}),50)}var p=this._sourcesDirty||this._styleDirty||this._placementDirty;return p||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),!this._loaded||this._fullyLoaded||p||(this._fullyLoaded=!0),this}},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"orientationchange\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext&&n.loseContext(),Bi(this._canvasContainer),Bi(this._controlContainer),Bi(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this._removed=!0,this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame((function(t){e._frame=null,e._render(t)})))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(t){this._trackResize&&this.resize({originalEvent:t})._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showPadding.get=function(){return!!this._showPadding},a.showPadding.set=function(t){this._showPadding!==t&&(this._showPadding=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},a.version.get=function(){return t.version},Object.defineProperties(i.prototype,a),i}(Si);function Bi(t){t.parentNode&&t.parentNode.removeChild(t)}var Ni={showCompass:!0,showZoom:!0,visualizePitch:!1},ji=function(e){var n=this;this.options=t.extend({},Ni,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this.options.showZoom&&(t.bindAll([\"_setButtonTitle\",\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-zoom-in\",(function(t){return n._map.zoomIn({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",!0),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-zoom-out\",(function(t){return n._map.zoomOut({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",!0)),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-compass\",(function(t){n.options.visualizePitch?n._map.resetNorthPitch({},{originalEvent:t}):n._map.resetNorth({},{originalEvent:t})})),this._compassIcon=r.create(\"span\",\"mapboxgl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",!0))};ji.prototype._updateZoomButtons=function(){var t=this._map.getZoom(),e=t===this._map.getMaxZoom(),r=t===this._map.getMinZoom();this._zoomInButton.disabled=e,this._zoomOutButton.disabled=r,this._zoomInButton.setAttribute(\"aria-disabled\",e.toString()),this._zoomOutButton.setAttribute(\"aria-disabled\",r.toString())},ji.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?\"scale(\"+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+\") rotateX(\"+this._map.transform.pitch+\"deg) rotateZ(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\":\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassIcon.style.transform=t},ji.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Ui(this._map,this._compass,this.options.visualizePitch)),this._container},ji.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map},ji.prototype._createButton=function(t,e){var n=r.create(\"button\",t,this._container);return n.type=\"button\",n.addEventListener(\"click\",e),n},ji.prototype._setButtonTitle=function(t,e){var r=this._map._getUIString(\"NavigationControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)};var Ui=function(e,n,i){void 0===i&&(i=!1),this._clickTolerance=10,this.element=n,this.mouseRotate=new ei({clickTolerance:e.dragRotate._mouseRotate._clickTolerance}),this.map=e,i&&(this.mousePitch=new ri({clickTolerance:e.dragRotate._mousePitch._clickTolerance})),t.bindAll([\"mousedown\",\"mousemove\",\"mouseup\",\"touchstart\",\"touchmove\",\"touchend\",\"reset\"],this),r.addEventListener(n,\"mousedown\",this.mousedown),r.addEventListener(n,\"touchstart\",this.touchstart,{passive:!1}),r.addEventListener(n,\"touchmove\",this.touchmove),r.addEventListener(n,\"touchend\",this.touchend),r.addEventListener(n,\"touchcancel\",this.reset)};function Vi(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Ui.prototype.down=function(t,e){this.mouseRotate.mousedown(t,e),this.mousePitch&&this.mousePitch.mousedown(t,e),r.disableDrag()},Ui.prototype.move=function(t,e){var r=this.map,n=this.mouseRotate.mousemoveWindow(t,e);if(n&&n.bearingDelta&&r.setBearing(r.getBearing()+n.bearingDelta),this.mousePitch){var i=this.mousePitch.mousemoveWindow(t,e);i&&i.pitchDelta&&r.setPitch(r.getPitch()+i.pitchDelta)}},Ui.prototype.off=function(){var t=this.element;r.removeEventListener(t,\"mousedown\",this.mousedown),r.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),r.removeEventListener(t,\"touchmove\",this.touchmove),r.removeEventListener(t,\"touchend\",this.touchend),r.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()},Ui.prototype.offTemp=function(){r.enableDrag(),r.removeEventListener(t.window,\"mousemove\",this.mousemove),r.removeEventListener(t.window,\"mouseup\",this.mouseup)},Ui.prototype.mousedown=function(e){this.down(t.extend({},e,{ctrlKey:!0,preventDefault:function(){return e.preventDefault()}}),r.mousePos(this.element,e)),r.addEventListener(t.window,\"mousemove\",this.mousemove),r.addEventListener(t.window,\"mouseup\",this.mouseup)},Ui.prototype.mousemove=function(t){this.move(t,r.mousePos(this.element,t))},Ui.prototype.mouseup=function(t){this.mouseRotate.mouseupWindow(t),this.mousePitch&&this.mousePitch.mouseupWindow(t),this.offTemp()},Ui.prototype.touchstart=function(t){1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.down({type:\"mousedown\",button:0,ctrlKey:!0,preventDefault:function(){return t.preventDefault()}},this._startPos))},Ui.prototype.touchmove=function(t){1!==t.targetTouches.length?this.reset():(this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.move({preventDefault:function(){return t.preventDefault()}},this._lastPos))},Ui.prototype.touchend=function(t){0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),this.reset()},Ui.prototype.reset=function(){this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()};var qi={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Hi(t,e,r){var n=t.classList;for(var i in qi)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Gi,Zi=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\",\"_onKeyPress\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._scale=n&&n.scale||1,this._draggable=n&&n.draggable||!1,this._clickTolerance=n&&n.clickTolerance||0,this._isDragging=!1,this._state=\"inactive\",this._rotation=n&&n.rotation||0,this._rotationAlignment=n&&n.rotationAlignment||\"auto\",this._pitchAlignment=n&&n.pitchAlignment&&\"auto\"!==n.pitchAlignment?n.pitchAlignment:this._rotationAlignment,n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\"),this._element.setAttribute(\"aria-label\",\"Map marker\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"opacity\",\"0.25\"),m.setAttributeNS(null,\"fill\",\"#000000\");var g=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");g.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),m.appendChild(g);var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),y.setAttributeNS(null,\"fill\",\"#FFFFFF\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");v.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var _=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");_.setAttributeNS(null,\"fill\",\"#FFFFFF\"),_.setAttributeNS(null,\"cx\",\"5.5\"),_.setAttributeNS(null,\"cy\",\"5.5\"),_.setAttributeNS(null,\"r\",\"5.4999962\"),v.appendChild(x),v.appendChild(_),s.appendChild(l),s.appendChild(p),s.appendChild(m),s.appendChild(y),s.appendChild(v),a.appendChild(s),a.setAttributeNS(null,\"height\",41*this._scale+\"px\"),a.setAttributeNS(null,\"width\",27*this._scale+\"px\"),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",(function(t){t.preventDefault()})),this._element.addEventListener(\"mousedown\",(function(t){t.preventDefault()})),Hi(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){var e=13.5,r=Math.sqrt(Math.pow(e,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[r,-1*(24.6+r)],\"bottom-right\":[-r,-1*(24.6+r)],left:[e,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat),this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this},n.prototype._onKeyPress=function(t){var e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){if(this._map){this._map.transform.renderWorldCopies&&(this._lngLat=Vi(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset);var e=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?e=\"rotateZ(\"+this._rotation+\"deg)\":\"map\"===this._rotationAlignment&&(e=\"rotateZ(\"+(this._rotation-this._map.getBearing())+\"deg)\");var n=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?n=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(n=\"rotateX(\"+this._map.getPitch()+\"deg)\"),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,qi[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px) \"+n+\" \"+e)}},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){if(!this._isDragging){var r=this._clickTolerance||this._map._clickTolerance;this._isDragging=e.point.dist(this._pointerdownPos)>=r}this._isDragging&&(this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\")))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._pointerdownPos=null,this._isDragging=!1,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._pointerdownPos=t.point,this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n.prototype.setRotation=function(t){return this._rotation=t||0,this._update(),this},n.prototype.getRotation=function(){return this._rotation},n.prototype.setRotationAlignment=function(t){return this._rotationAlignment=t||\"auto\",this._update(),this},n.prototype.getRotationAlignment=function(){return this._rotationAlignment},n.prototype.setPitchAlignment=function(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this},n.prototype.getPitchAlignment=function(){return this._pitchAlignment},n}(t.Evented),Wi={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0};var Yi=0,Xi=!1,$i=function(e){function n(r){e.call(this),this.options=t.extend({},Wi,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_onZoom\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Gi?n(Gi):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then((function(t){Gi=\"denied\"!==t.state,n(Gi)})):(Gi=!!t.window.navigator.geolocation,n(Gi)),this._container;var n},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),r.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Yi=0,Xi=!1},n.prototype._isOutOfMapMaxBounds=function(t){var e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())},n.prototype._setErrorState=function(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}},n.prototype._onSuccess=function(e){if(this._map){if(this._isOutOfMapMaxBounds(e))return this._setErrorState(),this.fire(new t.Event(\"outofmaxbounds\",e)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()}},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(e){if(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=e.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},n.prototype._updateCircleRadius=function(){var t=this._map._container.clientHeight/2,e=this._map.unproject([0,t]),r=this._map.unproject([1,t]),n=e.distanceTo(r),i=Math.ceil(2*this._accuracy/n);this._circleElement.style.width=i+\"px\",this._circleElement.style.height=i+\"px\"},n.prototype._onZoom=function(){this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},n.prototype._onError=function(e){if(this._map){if(this.options.trackUserLocation)if(1===e.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;var r=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=r,this._geolocateButton.setAttribute(\"aria-label\",r),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===e.code&&Xi)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()}},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;if(this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-geolocate\",this._container),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",!0),this._geolocateButton.type=\"button\",!1===e){t.warnOnce(\"Geolocation support is not available so the GeolocateControl will be disabled.\");var i=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=i,this._geolocateButton.setAttribute(\"aria-label\",i)}else{var a=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.title=a,this._geolocateButton.setAttribute(\"aria-label\",a)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new Zi(this._dotElement),this._circleElement=r.create(\"div\",\"mapboxgl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Zi({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(function(e){var r=e.originalEvent&&\"resize\"===e.originalEvent.type;e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||r||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))}))},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Yi--,Xi=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){var e;this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),++Yi>1?(e={maximumAge:6e5,timeout:0},Xi=!0):(e=this.options.positionOptions,Xi=!1),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,e)}}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Ji={maxWidth:100,unit:\"metric\"},Ki=function(e){this.options=t.extend({},Ji,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Qi(t,e,r){var n=r&&r.maxWidth||100,i=t._container.clientHeight/2,a=t.unproject([0,i]),o=t.unproject([n,i]),s=a.distanceTo(o);if(r&&\"imperial\"===r.unit){var l=3.2808*s;l>5280?ta(e,n,l/5280,t._getUIString(\"ScaleControl.Miles\")):ta(e,n,l,t._getUIString(\"ScaleControl.Feet\"))}else r&&\"nautical\"===r.unit?ta(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\")):s>=1e3?ta(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):ta(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function ta(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*((o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;t.style.width=e*l+\"px\",t.innerHTML=s+\"&nbsp;\"+n}Ki.prototype.getDefaultPosition=function(){return\"bottom-left\"},Ki.prototype._onMove=function(){Qi(this._map,this._container,this.options)},Ki.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Ki.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Ki.prototype.setUnit=function(t){this.options.unit=t,Qi(this._map,this._container,this.options)};var ea=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\")};ea.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},ea.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},ea.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},ea.prototype._setupUI=function(){var e=this._fullscreenButton=r.create(\"button\",\"mapboxgl-ctrl-fullscreen\",this._controlContainer);r.create(\"span\",\"mapboxgl-ctrl-icon\",e).setAttribute(\"aria-hidden\",!0),e.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},ea.prototype._updateTitle=function(){var t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},ea.prototype._getTitle=function(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")},ea.prototype._isFullscreen=function(){return this._fullscreen},ea.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-fullscreen\"),this._updateTitle())},ea.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var ra={closeButton:!0,closeOnClick:!0,focusAfterOpen:!0,className:\"\",maxWidth:\"240px\"},na=[\"a[href]\",\"[tabindex]:not([tabindex='-1'])\",\"[contenteditable]:not([contenteditable='false'])\",\"button:not([disabled])\",\"input:not([disabled])\",\"select:not([disabled])\",\"textarea:not([disabled])\"].join(\", \"),ia=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(ra),r),t.bindAll([\"_update\",\"_onClose\",\"remove\",\"_onMouseMove\",\"_onMouseUp\",\"_onDrag\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){return this._map&&this.remove(),this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._focusFirstElement(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this},n.prototype.trackPointer=function(){return this._trackPointer=!0,this._pos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container&&this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){if(this._content)for(;this._content.hasChildNodes();)this._content.firstChild&&this._content.removeChild(this._content.firstChild);else this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container);return this._content.appendChild(t),this._createCloseButton(),this._update(),this._focusFirstElement(),this},n.prototype.addClassName=function(t){this._container&&this._container.classList.add(t)},n.prototype.removeClassName=function(t){this._container&&this._container.classList.remove(t)},n.prototype.setOffset=function(t){return this.options.offset=t,this._update(),this},n.prototype.toggleClassName=function(t){if(this._container)return this._container.classList.toggle(t)},n.prototype._createCloseButton=function(){this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))},n.prototype._onMouseUp=function(t){this._update(t.point)},n.prototype._onMouseMove=function(t){this._update(t.point)},n.prototype._onDrag=function(t){this._update(t.point)},n.prototype._update=function(t){var e=this,n=this._lngLat||this._trackPointer;if(this._map&&n&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach((function(t){return e._container.classList.add(t)})),this._trackPointer&&this._container.classList.add(\"mapboxgl-popup-track-pointer\")),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Vi(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||t)){var i=this._pos=this._trackPointer&&t?t:this._map.project(this._lngLat),a=this.options.anchor,o=aa(this.options.offset);if(!a){var s,l=this._container.offsetWidth,c=this._container.offsetHeight;s=i.y+o.bottom.y<c?[\"top\"]:i.y>this._map.transform.height-c?[\"bottom\"]:[],i.x<l/2?s.push(\"left\"):i.x>this._map.transform.width-l/2&&s.push(\"right\"),a=0===s.length?\"bottom\":s.join(\"-\")}var u=i.add(o[a]).round();r.setTransform(this._container,qi[a]+\" translate(\"+u.x+\"px,\"+u.y+\"px)\"),Hi(this._container,a,\"popup\")}},n.prototype._focusFirstElement=function(){if(this.options.focusAfterOpen&&this._container){var t=this._container.querySelector(na);t&&t.focus()}},n.prototype._onClose=function(){this.remove()},n}(t.Evented);function aa(e){if(e){if(\"number\"==typeof e){var r=Math.round(Math.sqrt(.5*Math.pow(e,2)));return{center:new t.Point(0,0),top:new t.Point(0,e),\"top-left\":new t.Point(r,r),\"top-right\":new t.Point(-r,r),bottom:new t.Point(0,-e),\"bottom-left\":new t.Point(r,-r),\"bottom-right\":new t.Point(-r,-r),left:new t.Point(e,0),right:new t.Point(-e,0)}}if(e instanceof t.Point||Array.isArray(e)){var n=t.Point.convert(e);return{center:n,top:n,\"top-left\":n,\"top-right\":n,bottom:n,\"bottom-left\":n,\"bottom-right\":n,left:n,right:n}}return{center:t.Point.convert(e.center||[0,0]),top:t.Point.convert(e.top||[0,0]),\"top-left\":t.Point.convert(e[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(e[\"top-right\"]||[0,0]),bottom:t.Point.convert(e.bottom||[0,0]),\"bottom-left\":t.Point.convert(e[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(e[\"bottom-right\"]||[0,0]),left:t.Point.convert(e.left||[0,0]),right:t.Point.convert(e.right||[0,0])}}return aa(new t.Point(0,0))}var oa={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,getRTLTextPluginStatus:t.getRTLTextPluginStatus,Map:Fi,NavigationControl:ji,GeolocateControl:$i,AttributionControl:Ei,ScaleControl:Ki,FullscreenControl:ea,Popup:ia,Marker:Zi,Style:We,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,prewarm:function(){jt().acquire(Rt)},clearPrewarmedResources:function(){var t=Bt;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(Rt),Bt=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return Ft.workerCount},set workerCount(t){Ft.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return oa})),r}()},27549:function(t,e,r){\"use strict\";t.exports=r(55366)},55366:function(t,e,r){\"use strict\";var n=r(31625),i=r(75144),a=r(5137),o=r(78112),s=r(6807),l=r(68650),c=r(83473),u=r(60201),h=r(10275),f=r(62914);function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}t.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,m=p(t,i),g=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(g):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=g));for(var y=0;y<g;++y)d[y]=y;var v=[],x=[],_=[],b=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=v[o]||(v[o]=[]),c=_[o]||(_[o]=[]),u=x[o]||(x[o]=[]),h=l.length;if(++o>r||s>1073741824){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}if(l.push(a[0]),c.push(s),a.length<=1)return u.push(null,null,null,null),h;for(var p=.5*i,d=e+p,g=n+p,y=[],b=[],w=[],T=[],k=1,A=a.length;k<A;k++){var M=a[k],S=m[2*M],E=m[2*M+1];S<d?E<g?y.push(M):b.push(M):E<g?w.push(M):T.push(M)}return s<<=2,u.push(t(e,n,p,y,o,s),t(e,g,p,b,o,s+1),t(d,n,p,w,o,s+2),t(d,g,p,T,o,s+3)),h}(0,0,1,d,0,1);for(var w=0,T=0;T<v.length;T++){var k=v[T];if(d.set)d.set(k,w);else for(var A=0,M=k.length;A<M;A++)d[A+w]=k[A];var S=w+v[T].length;b[T]=[w,S],w=S}return d.range=function(){for(var e,r=[],o=arguments.length;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h,d=a.apply(void 0,r),m=[Math.min(d.x,d.x+d.width),Math.min(d.y,d.y+d.height),Math.max(d.x,d.x+d.width),Math.max(d.y,d.y+d.height)],g=m[0],y=m[1],w=m[2],T=m[3],k=p([g,y,w,T],i),A=k[0],M=k[1],S=k[2],C=k[3],L=l(e.level,v.length);null!=e.d&&(\"number\"==typeof e.d?h=[e.d,e.d]:e.d.length&&(h=e.d),L=Math.min(Math.max(Math.ceil(-f(Math.abs(h[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(h[1])/(i[3]-i[1])))),L));if(L=Math.min(L,v.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=b[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(A,M,S,C,L);var I=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s&&!(A>r+i||M>n+i||S<r||C<n||a>=L||o===s)){var l=v[a];void 0===s&&(s=l.length);for(var c=o;c<s;c++){var u=l[c],h=t[2*u],f=t[2*u+1];h>=g&&h<=w&&f>=y&&f<=T&&I.push(u)}var p=x[a],d=p[4*o+0],m=p[4*o+1],_=p[4*o+2],b=p[4*o+3],k=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(p,o+1),E=.5*i,P=a+1;e(r,n,E,P,d,m||_||b||k),e(r,n+E,E,P,m,_||b||k),e(r+E,n,E,P,_,b||k),e(r+E,n+E,E,P,b,k)}}(0,0,1,0,0,1),I},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},16844:function(t){t.exports=function(t){var e=0,r=0,n=0,i=0;return t.map((function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t}))}},78112:function(t){\"use strict\";t.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},33055:function(t){\"use strict\";t.exports=function(t,e,r){if(\"function\"==typeof Array.prototype.findIndex)return t.findIndex(e,r);if(\"function\"!=typeof e)throw new TypeError(\"predicate must be a function\");var n=Object(t),i=n.length;if(0===i)return-1;for(var a=0;a<i;a++)if(e.call(r,n[a],a,n))return a;return-1}},90956:function(t,e,r){\"use strict\";var n=r(78112);t.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1),null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},27902:function(t){t.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},85672:function(t,e,r){\"use strict\";var n=r(33282);function i(t){return i=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},i(t)}function a(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(t,(void 0,a=function(t,e){if(\"object\"!==i(t)||null===t)return t;var r=t[Symbol.toPrimitive];if(void 0!==r){var n=r.call(t,\"string\");if(\"object\"!==i(n))return n;throw new TypeError(\"@@toPrimitive must return a primitive value.\")}return String(t)}(n.key),\"symbol\"===i(a)?a:String(a)),n)}var a}function o(t,e,r){return e&&a(t.prototype,e),r&&a(t,r),Object.defineProperty(t,\"prototype\",{writable:!1}),t}var s,l,c=r(34585).codes,u=c.ERR_AMBIGUOUS_ARGUMENT,h=c.ERR_INVALID_ARG_TYPE,f=c.ERR_INVALID_ARG_VALUE,p=c.ERR_INVALID_RETURN_VALUE,d=c.ERR_MISSING_ARGS,m=r(68586),g=r(56557).inspect,y=r(56557).types,v=y.isPromise,x=y.isRegExp,_=r(68686)(),b=r(9622)(),w=r(63063)(\"RegExp.prototype.test\");function T(){var t=r(23879);s=t.isDeepEqual,l=t.isDeepStrictEqual}new Map;var k=!1,A=t.exports=C,M={};function S(t){if(t.message instanceof Error)throw t.message;throw new m(t)}function E(t,e,r,n){if(!r){var i=!1;if(0===e)i=!0,n=\"No value argument passed to `assert.ok()`\";else if(n instanceof Error)throw n;var a=new m({actual:r,expected:!0,message:n,operator:\"==\",stackStartFn:t});throw a.generatedMessage=i,a}}function C(){for(var t=arguments.length,e=new Array(t),r=0;r<t;r++)e[r]=arguments[r];E.apply(void 0,[C,e.length].concat(e))}A.fail=function t(e,r,i,a,o){var s,l=arguments.length;if(0===l?s=\"Failed\":1===l?(i=e,e=void 0):(!1===k&&(k=!0,(n.emitWarning?n.emitWarning:console.warn.bind(console))(\"assert.fail() with more than one argument is deprecated. Please use assert.strictEqual() instead or only pass a message.\",\"DeprecationWarning\",\"DEP0094\")),2===l&&(a=\"!=\")),i instanceof Error)throw i;var c={actual:e,expected:r,operator:void 0===a?\"fail\":a,stackStartFn:o||t};void 0!==i&&(c.message=i);var u=new m(c);throw s&&(u.message=s,u.generatedMessage=!0),u},A.AssertionError=m,A.ok=C,A.equal=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");e!=r&&S({actual:e,expected:r,message:n,operator:\"==\",stackStartFn:t})},A.notEqual=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");e==r&&S({actual:e,expected:r,message:n,operator:\"!=\",stackStartFn:t})},A.deepEqual=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");void 0===s&&T(),s(e,r)||S({actual:e,expected:r,message:n,operator:\"deepEqual\",stackStartFn:t})},A.notDeepEqual=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");void 0===s&&T(),s(e,r)&&S({actual:e,expected:r,message:n,operator:\"notDeepEqual\",stackStartFn:t})},A.deepStrictEqual=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");void 0===s&&T(),l(e,r)||S({actual:e,expected:r,message:n,operator:\"deepStrictEqual\",stackStartFn:t})},A.notDeepStrictEqual=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");void 0===s&&T(),l(e,r)&&S({actual:e,expected:r,message:n,operator:\"notDeepStrictEqual\",stackStartFn:t})},A.strictEqual=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");b(e,r)||S({actual:e,expected:r,message:n,operator:\"strictEqual\",stackStartFn:t})},A.notStrictEqual=function t(e,r,n){if(arguments.length<2)throw new d(\"actual\",\"expected\");b(e,r)&&S({actual:e,expected:r,message:n,operator:\"notStrictEqual\",stackStartFn:t})};var L=o((function t(e,r,n){var i=this;!function(t,e){if(!(t instanceof e))throw new TypeError(\"Cannot call a class as a function\")}(this,t),r.forEach((function(t){t in e&&(void 0!==n&&\"string\"==typeof n[t]&&x(e[t])&&w(e[t],n[t])?i[t]=n[t]:i[t]=e[t])}))}));function I(t,e,r,n){if(\"function\"!=typeof e){if(x(e))return w(e,t);if(2===arguments.length)throw new h(\"expected\",[\"Function\",\"RegExp\"],e);if(\"object\"!==i(t)||null===t){var a=new m({actual:t,expected:e,message:r,operator:\"deepStrictEqual\",stackStartFn:n});throw a.operator=n.name,a}var o=Object.keys(e);if(e instanceof Error)o.push(\"name\",\"message\");else if(0===o.length)throw new f(\"error\",e,\"may not be an empty object\");return void 0===s&&T(),o.forEach((function(i){\"string\"==typeof t[i]&&x(e[i])&&w(e[i],t[i])||function(t,e,r,n,i,a){if(!(r in t)||!l(t[r],e[r])){if(!n){var o=new L(t,i),s=new L(e,i,t),c=new m({actual:o,expected:s,operator:\"deepStrictEqual\",stackStartFn:a});throw c.actual=t,c.expected=e,c.operator=a.name,c}S({actual:t,expected:e,message:n,operator:a.name,stackStartFn:a})}}(t,e,i,r,o,n)})),!0}return void 0!==e.prototype&&t instanceof e||!Error.isPrototypeOf(e)&&!0===e.call({},t)}function P(t){if(\"function\"!=typeof t)throw new h(\"fn\",\"Function\",t);try{t()}catch(t){return t}return M}function z(t){return v(t)||null!==t&&\"object\"===i(t)&&\"function\"==typeof t.then&&\"function\"==typeof t.catch}function O(t){return Promise.resolve().then((function(){var e;if(\"function\"==typeof t){if(!z(e=t()))throw new p(\"instance of Promise\",\"promiseFn\",e)}else{if(!z(t))throw new h(\"promiseFn\",[\"Function\",\"Promise\"],t);e=t}return Promise.resolve().then((function(){return e})).then((function(){return M})).catch((function(t){return t}))}))}function D(t,e,r,n){if(\"string\"==typeof r){if(4===arguments.length)throw new h(\"error\",[\"Object\",\"Error\",\"Function\",\"RegExp\"],r);if(\"object\"===i(e)&&null!==e){if(e.message===r)throw new u(\"error/message\",'The error message \"'.concat(e.message,'\" is identical to the message.'))}else if(e===r)throw new u(\"error/message\",'The error \"'.concat(e,'\" is identical to the message.'));n=r,r=void 0}else if(null!=r&&\"object\"!==i(r)&&\"function\"!=typeof r)throw new h(\"error\",[\"Object\",\"Error\",\"Function\",\"RegExp\"],r);if(e===M){var a=\"\";r&&r.name&&(a+=\" (\".concat(r.name,\")\")),a+=n?\": \".concat(n):\".\";var o=\"rejects\"===t.name?\"rejection\":\"exception\";S({actual:void 0,expected:r,operator:t.name,message:\"Missing expected \".concat(o).concat(a),stackStartFn:t})}if(r&&!I(e,r,n,t))throw e}function R(t,e,r,n){if(e!==M){if(\"string\"==typeof r&&(n=r,r=void 0),!r||I(e,r)){var i=n?\": \".concat(n):\".\",a=\"doesNotReject\"===t.name?\"rejection\":\"exception\";S({actual:e,expected:r,operator:t.name,message:\"Got unwanted \".concat(a).concat(i,\"\\n\")+'Actual message: \"'.concat(e&&e.message,'\"'),stackStartFn:t})}throw e}}function F(t,e,r,n,a){if(!x(e))throw new h(\"regexp\",\"RegExp\",e);var o=\"match\"===a;if(\"string\"!=typeof t||w(e,t)!==o){if(r instanceof Error)throw r;var s=!r;r=r||(\"string\"!=typeof t?'The \"string\" argument must be of type string. Received type '+\"\".concat(i(t),\" (\").concat(g(t),\")\"):(o?\"The input did not match the regular expression \":\"The input was expected to not match the regular expression \")+\"\".concat(g(e),\". Input:\\n\\n\").concat(g(t),\"\\n\"));var l=new m({actual:t,expected:e,message:r,operator:a,stackStartFn:n});throw l.generatedMessage=s,l}}function B(){for(var t=arguments.length,e=new Array(t),r=0;r<t;r++)e[r]=arguments[r];E.apply(void 0,[B,e.length].concat(e))}A.throws=function t(e){for(var r=arguments.length,n=new Array(r>1?r-1:0),i=1;i<r;i++)n[i-1]=arguments[i];D.apply(void 0,[t,P(e)].concat(n))},A.rejects=function t(e){for(var r=arguments.length,n=new Array(r>1?r-1:0),i=1;i<r;i++)n[i-1]=arguments[i];return O(e).then((function(e){return D.apply(void 0,[t,e].concat(n))}))},A.doesNotThrow=function t(e){for(var r=arguments.length,n=new Array(r>1?r-1:0),i=1;i<r;i++)n[i-1]=arguments[i];R.apply(void 0,[t,P(e)].concat(n))},A.doesNotReject=function t(e){for(var r=arguments.length,n=new Array(r>1?r-1:0),i=1;i<r;i++)n[i-1]=arguments[i];return O(e).then((function(e){return R.apply(void 0,[t,e].concat(n))}))},A.ifError=function t(e){if(null!=e){var r=\"ifError got unwanted exception: \";\"object\"===i(e)&&\"string\"==typeof e.message?0===e.message.length&&e.constructor?r+=e.constructor.name:r+=e.message:r+=g(e);var n=new m({actual:e,expected:null,operator:\"ifError\",message:r,stackStartFn:t}),a=e.stack;if(\"string\"==typeof a){var o=a.split(\"\\n\");o.shift();for(var s=n.stack.split(\"\\n\"),l=0;l<o.length;l++){var c=s.indexOf(o[l]);if(-1!==c){s=s.slice(0,c);break}}n.stack=\"\".concat(s.join(\"\\n\"),\"\\n\").concat(o.join(\"\\n\"))}throw n}},A.match=function t(e,r,n){F(e,r,n,t,\"match\")},A.doesNotMatch=function t(e,r,n){F(e,r,n,t,\"doesNotMatch\")},A.strict=_(B,A,{equal:A.strictEqual,deepEqual:A.deepStrictEqual,notEqual:A.notStrictEqual,notDeepEqual:A.notDeepStrictEqual}),A.strict.strict=A.strict},68586:function(t,e,r){\"use strict\";var n=r(33282);function i(t,e){var r=Object.keys(t);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(t);e&&(n=n.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),r.push.apply(r,n)}return r}function a(t){for(var e=1;e<arguments.length;e++){var r=null!=arguments[e]?arguments[e]:{};e%2?i(Object(r),!0).forEach((function(e){var n,i,a;n=t,i=e,a=r[e],(i=s(i))in n?Object.defineProperty(n,i,{value:a,enumerable:!0,configurable:!0,writable:!0}):n[i]=a})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(r)):i(Object(r)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(r,e))}))}return t}function o(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(t,s(n.key),n)}}function s(t){var e=function(t,e){if(\"object\"!==m(t)||null===t)return t;var r=t[Symbol.toPrimitive];if(void 0!==r){var n=r.call(t,\"string\");if(\"object\"!==m(n))return n;throw new TypeError(\"@@toPrimitive must return a primitive value.\")}return String(t)}(t);return\"symbol\"===m(e)?e:String(e)}function l(t,e){if(e&&(\"object\"===m(e)||\"function\"==typeof e))return e;if(void 0!==e)throw new TypeError(\"Derived constructors may only return object or undefined\");return c(t)}function c(t){if(void 0===t)throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\");return t}function u(t){var e=\"function\"==typeof Map?new Map:void 0;return u=function(t){if(null===t||(r=t,-1===Function.toString.call(r).indexOf(\"[native code]\")))return t;var r;if(\"function\"!=typeof t)throw new TypeError(\"Super expression must either be null or a function\");if(void 0!==e){if(e.has(t))return e.get(t);e.set(t,n)}function n(){return h(t,arguments,d(this).constructor)}return n.prototype=Object.create(t.prototype,{constructor:{value:n,enumerable:!1,writable:!0,configurable:!0}}),p(n,t)},u(t)}function h(t,e,r){return h=f()?Reflect.construct.bind():function(t,e,r){var n=[null];n.push.apply(n,e);var i=new(Function.bind.apply(t,n));return r&&p(i,r.prototype),i},h.apply(null,arguments)}function f(){if(\"undefined\"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if(\"function\"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}function p(t,e){return p=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(t,e){return t.__proto__=e,t},p(t,e)}function d(t){return d=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},d(t)}function m(t){return m=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},m(t)}var g=r(56557).inspect,y=r(34585).codes.ERR_INVALID_ARG_TYPE;function v(t,e,r){return(void 0===r||r>t.length)&&(r=t.length),t.substring(r-e.length,r)===e}var x=\"\",_=\"\",b=\"\",w=\"\",T={deepStrictEqual:\"Expected values to be strictly deep-equal:\",strictEqual:\"Expected values to be strictly equal:\",strictEqualObject:'Expected \"actual\" to be reference-equal to \"expected\":',deepEqual:\"Expected values to be loosely deep-equal:\",equal:\"Expected values to be loosely equal:\",notDeepStrictEqual:'Expected \"actual\" not to be strictly deep-equal to:',notStrictEqual:'Expected \"actual\" to be strictly unequal to:',notStrictEqualObject:'Expected \"actual\" not to be reference-equal to \"expected\":',notDeepEqual:'Expected \"actual\" not to be loosely deep-equal to:',notEqual:'Expected \"actual\" to be loosely unequal to:',notIdentical:\"Values identical but not reference-equal:\"};function k(t){var e=Object.keys(t),r=Object.create(Object.getPrototypeOf(t));return e.forEach((function(e){r[e]=t[e]})),Object.defineProperty(r,\"message\",{value:t.message}),r}function A(t){return g(t,{compact:!1,customInspect:!1,depth:1e3,maxArrayLength:1/0,showHidden:!1,breakLength:1/0,showProxy:!1,sorted:!0,getters:!0})}var M=function(t,e){!function(t,e){if(\"function\"!=typeof e&&null!==e)throw new TypeError(\"Super expression must either be null or a function\");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Object.defineProperty(t,\"prototype\",{writable:!1}),e&&p(t,e)}(M,t);var r,i,s,u,h=(r=M,i=f(),function(){var t,e=d(r);if(i){var n=d(this).constructor;t=Reflect.construct(e,arguments,n)}else t=e.apply(this,arguments);return l(this,t)});function M(t){var e;if(function(t,e){if(!(t instanceof e))throw new TypeError(\"Cannot call a class as a function\")}(this,M),\"object\"!==m(t)||null===t)throw new y(\"options\",\"Object\",t);var r=t.message,i=t.operator,a=t.stackStartFn,o=t.actual,s=t.expected,u=Error.stackTraceLimit;if(Error.stackTraceLimit=0,null!=r)e=h.call(this,String(r));else if(n.stderr&&n.stderr.isTTY&&(n.stderr&&n.stderr.getColorDepth&&1!==n.stderr.getColorDepth()?(x=\"\u001b[34m\",_=\"\u001b[32m\",w=\"\u001b[39m\",b=\"\u001b[31m\"):(x=\"\",_=\"\",w=\"\",b=\"\")),\"object\"===m(o)&&null!==o&&\"object\"===m(s)&&null!==s&&\"stack\"in o&&o instanceof Error&&\"stack\"in s&&s instanceof Error&&(o=k(o),s=k(s)),\"deepStrictEqual\"===i||\"strictEqual\"===i)e=h.call(this,function(t,e,r){var i=\"\",a=\"\",o=0,s=\"\",l=!1,c=A(t),u=c.split(\"\\n\"),h=A(e).split(\"\\n\"),f=0,p=\"\";if(\"strictEqual\"===r&&\"object\"===m(t)&&\"object\"===m(e)&&null!==t&&null!==e&&(r=\"strictEqualObject\"),1===u.length&&1===h.length&&u[0]!==h[0]){var d=u[0].length+h[0].length;if(d<=10){if(!(\"object\"===m(t)&&null!==t||\"object\"===m(e)&&null!==e||0===t&&0===e))return\"\".concat(T[r],\"\\n\\n\")+\"\".concat(u[0],\" !== \").concat(h[0],\"\\n\")}else if(\"strictEqualObject\"!==r&&d<(n.stderr&&n.stderr.isTTY?n.stderr.columns:80)){for(;u[0][f]===h[0][f];)f++;f>2&&(p=\"\\n  \".concat(function(t,e){if(e=Math.floor(e),0==t.length||0==e)return\"\";var r=t.length*e;for(e=Math.floor(Math.log(e)/Math.log(2));e;)t+=t,e--;return t+t.substring(0,r-t.length)}(\" \",f),\"^\"),f=0)}}for(var g=u[u.length-1],y=h[h.length-1];g===y&&(f++<2?s=\"\\n  \".concat(g).concat(s):i=g,u.pop(),h.pop(),0!==u.length&&0!==h.length);)g=u[u.length-1],y=h[h.length-1];var k=Math.max(u.length,h.length);if(0===k){var M=c.split(\"\\n\");if(M.length>30)for(M[26]=\"\".concat(x,\"...\").concat(w);M.length>27;)M.pop();return\"\".concat(T.notIdentical,\"\\n\\n\").concat(M.join(\"\\n\"),\"\\n\")}f>3&&(s=\"\\n\".concat(x,\"...\").concat(w).concat(s),l=!0),\"\"!==i&&(s=\"\\n  \".concat(i).concat(s),i=\"\");var S=0,E=T[r]+\"\\n\".concat(_,\"+ actual\").concat(w,\" \").concat(b,\"- expected\").concat(w),C=\" \".concat(x,\"...\").concat(w,\" Lines skipped\");for(f=0;f<k;f++){var L=f-o;if(u.length<f+1)L>1&&f>2&&(L>4?(a+=\"\\n\".concat(x,\"...\").concat(w),l=!0):L>3&&(a+=\"\\n  \".concat(h[f-2]),S++),a+=\"\\n  \".concat(h[f-1]),S++),o=f,i+=\"\\n\".concat(b,\"-\").concat(w,\" \").concat(h[f]),S++;else if(h.length<f+1)L>1&&f>2&&(L>4?(a+=\"\\n\".concat(x,\"...\").concat(w),l=!0):L>3&&(a+=\"\\n  \".concat(u[f-2]),S++),a+=\"\\n  \".concat(u[f-1]),S++),o=f,a+=\"\\n\".concat(_,\"+\").concat(w,\" \").concat(u[f]),S++;else{var I=h[f],P=u[f],z=P!==I&&(!v(P,\",\")||P.slice(0,-1)!==I);z&&v(I,\",\")&&I.slice(0,-1)===P&&(z=!1,P+=\",\"),z?(L>1&&f>2&&(L>4?(a+=\"\\n\".concat(x,\"...\").concat(w),l=!0):L>3&&(a+=\"\\n  \".concat(u[f-2]),S++),a+=\"\\n  \".concat(u[f-1]),S++),o=f,a+=\"\\n\".concat(_,\"+\").concat(w,\" \").concat(P),i+=\"\\n\".concat(b,\"-\").concat(w,\" \").concat(I),S+=2):(a+=i,i=\"\",1!==L&&0!==f||(a+=\"\\n  \".concat(P),S++))}if(S>20&&f<k-2)return\"\".concat(E).concat(C,\"\\n\").concat(a,\"\\n\").concat(x,\"...\").concat(w).concat(i,\"\\n\")+\"\".concat(x,\"...\").concat(w)}return\"\".concat(E).concat(l?C:\"\",\"\\n\").concat(a).concat(i).concat(s).concat(p)}(o,s,i));else if(\"notDeepStrictEqual\"===i||\"notStrictEqual\"===i){var f=T[i],p=A(o).split(\"\\n\");if(\"notStrictEqual\"===i&&\"object\"===m(o)&&null!==o&&(f=T.notStrictEqualObject),p.length>30)for(p[26]=\"\".concat(x,\"...\").concat(w);p.length>27;)p.pop();e=1===p.length?h.call(this,\"\".concat(f,\" \").concat(p[0])):h.call(this,\"\".concat(f,\"\\n\\n\").concat(p.join(\"\\n\"),\"\\n\"))}else{var d=A(o),g=\"\",S=T[i];\"notDeepEqual\"===i||\"notEqual\"===i?(d=\"\".concat(T[i],\"\\n\\n\").concat(d)).length>1024&&(d=\"\".concat(d.slice(0,1021),\"...\")):(g=\"\".concat(A(s)),d.length>512&&(d=\"\".concat(d.slice(0,509),\"...\")),g.length>512&&(g=\"\".concat(g.slice(0,509),\"...\")),\"deepEqual\"===i||\"equal\"===i?d=\"\".concat(S,\"\\n\\n\").concat(d,\"\\n\\nshould equal\\n\\n\"):g=\" \".concat(i,\" \").concat(g)),e=h.call(this,\"\".concat(d).concat(g))}return Error.stackTraceLimit=u,e.generatedMessage=!r,Object.defineProperty(c(e),\"name\",{value:\"AssertionError [ERR_ASSERTION]\",enumerable:!1,writable:!0,configurable:!0}),e.code=\"ERR_ASSERTION\",e.actual=o,e.expected=s,e.operator=i,Error.captureStackTrace&&Error.captureStackTrace(c(e),a),e.stack,e.name=\"AssertionError\",l(e)}return s=M,(u=[{key:\"toString\",value:function(){return\"\".concat(this.name,\" [\").concat(this.code,\"]: \").concat(this.message)}},{key:e,value:function(t,e){return g(this,a(a({},e),{},{customInspect:!1,depth:0}))}}])&&o(s.prototype,u),Object.defineProperty(s,\"prototype\",{writable:!1}),M}(u(Error),g.custom);t.exports=M},34585:function(t,e,r){\"use strict\";function n(t){return n=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},n(t)}function i(t,e){return i=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(t,e){return t.__proto__=e,t},i(t,e)}function a(t){return a=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},a(t)}var o,s,l={};function c(t,e,r){r||(r=Error);var o=function(r){!function(t,e){if(\"function\"!=typeof e&&null!==e)throw new TypeError(\"Super expression must either be null or a function\");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Object.defineProperty(t,\"prototype\",{writable:!1}),e&&i(t,e)}(u,r);var o,s,l,c=(s=u,l=function(){if(\"undefined\"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if(\"function\"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}(),function(){var t,e=a(s);if(l){var r=a(this).constructor;t=Reflect.construct(e,arguments,r)}else t=e.apply(this,arguments);return function(t,e){if(e&&(\"object\"===n(e)||\"function\"==typeof e))return e;if(void 0!==e)throw new TypeError(\"Derived constructors may only return object or undefined\");return function(t){if(void 0===t)throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\");return t}(t)}(this,t)});function u(r,n,i){var a;return function(t,e){if(!(t instanceof e))throw new TypeError(\"Cannot call a class as a function\")}(this,u),a=c.call(this,function(t,r,n){return\"string\"==typeof e?e:e(t,r,n)}(r,n,i)),a.code=t,a}return o=u,Object.defineProperty(o,\"prototype\",{writable:!1}),o}(r);l[t]=o}function u(t,e){if(Array.isArray(t)){var r=t.length;return t=t.map((function(t){return String(t)})),r>2?\"one of \".concat(e,\" \").concat(t.slice(0,r-1).join(\", \"),\", or \")+t[r-1]:2===r?\"one of \".concat(e,\" \").concat(t[0],\" or \").concat(t[1]):\"of \".concat(e,\" \").concat(t[0])}return\"of \".concat(e,\" \").concat(String(t))}c(\"ERR_AMBIGUOUS_ARGUMENT\",'The \"%s\" argument is ambiguous. %s',TypeError),c(\"ERR_INVALID_ARG_TYPE\",(function(t,e,i){var a,s,l,c,h;if(void 0===o&&(o=r(85672)),o(\"string\"==typeof t,\"'name' must be a string\"),\"string\"==typeof e&&(s=\"not \",e.substr(0,4)===s)?(a=\"must not be\",e=e.replace(/^not /,\"\")):a=\"must be\",function(t,e,r){return(void 0===r||r>t.length)&&(r=t.length),t.substring(r-9,r)===e}(t,\" argument\"))l=\"The \".concat(t,\" \").concat(a,\" \").concat(u(e,\"type\"));else{var f=(\"number\"!=typeof h&&(h=0),h+1>(c=t).length||-1===c.indexOf(\".\",h)?\"argument\":\"property\");l='The \"'.concat(t,'\" ').concat(f,\" \").concat(a,\" \").concat(u(e,\"type\"))}return l+\". Received type \".concat(n(i))}),TypeError),c(\"ERR_INVALID_ARG_VALUE\",(function(t,e){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:\"is invalid\";void 0===s&&(s=r(56557));var i=s.inspect(e);return i.length>128&&(i=\"\".concat(i.slice(0,128),\"...\")),\"The argument '\".concat(t,\"' \").concat(n,\". Received \").concat(i)}),TypeError,RangeError),c(\"ERR_INVALID_RETURN_VALUE\",(function(t,e,r){var i;return i=r&&r.constructor&&r.constructor.name?\"instance of \".concat(r.constructor.name):\"type \".concat(n(r)),\"Expected \".concat(t,' to be returned from the \"').concat(e,'\"')+\" function but got \".concat(i,\".\")}),TypeError),c(\"ERR_MISSING_ARGS\",(function(){for(var t=arguments.length,e=new Array(t),n=0;n<t;n++)e[n]=arguments[n];void 0===o&&(o=r(85672)),o(e.length>0,\"At least one arg needs to be specified\");var i=\"The \",a=e.length;switch(e=e.map((function(t){return'\"'.concat(t,'\"')})),a){case 1:i+=\"\".concat(e[0],\" argument\");break;case 2:i+=\"\".concat(e[0],\" and \").concat(e[1],\" arguments\");break;default:i+=e.slice(0,a-1).join(\", \"),i+=\", and \".concat(e[a-1],\" arguments\")}return\"\".concat(i,\" must be specified\")}),TypeError),t.exports.codes=l},23879:function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=null==t?null:\"undefined\"!=typeof Symbol&&t[Symbol.iterator]||t[\"@@iterator\"];if(null!=r){var n,i,a,o,s=[],l=!0,c=!1;try{if(a=(r=r.call(t)).next,0===e){if(Object(r)!==r)return;l=!1}else for(;!(l=(n=a.call(r)).done)&&(s.push(n.value),s.length!==e);l=!0);}catch(t){c=!0,i=t}finally{try{if(!l&&null!=r.return&&(o=r.return(),Object(o)!==o))return}finally{if(c)throw i}}return s}}(t,e)||function(t,e){if(t){if(\"string\"==typeof t)return i(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?i(t,e):void 0}}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}function a(t){return a=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},a(t)}var o=void 0!==/a/g.flags,s=function(t){var e=[];return t.forEach((function(t){return e.push(t)})),e},l=function(t){var e=[];return t.forEach((function(t,r){return e.push([r,t])})),e},c=Object.is?Object.is:r(13969),u=Object.getOwnPropertySymbols?Object.getOwnPropertySymbols:function(){return[]},h=Number.isNaN?Number.isNaN:r(63057);function f(t){return t.call.bind(t)}var p=f(Object.prototype.hasOwnProperty),d=f(Object.prototype.propertyIsEnumerable),m=f(Object.prototype.toString),g=r(56557).types,y=g.isAnyArrayBuffer,v=g.isArrayBufferView,x=g.isDate,_=g.isMap,b=g.isRegExp,w=g.isSet,T=g.isNativeError,k=g.isBoxedPrimitive,A=g.isNumberObject,M=g.isStringObject,S=g.isBooleanObject,E=g.isBigIntObject,C=g.isSymbolObject,L=g.isFloat32Array,I=g.isFloat64Array;function P(t){if(0===t.length||t.length>10)return!0;for(var e=0;e<t.length;e++){var r=t.charCodeAt(e);if(r<48||r>57)return!0}return 10===t.length&&t>=Math.pow(2,32)}function z(t){return Object.keys(t).filter(P).concat(u(t).filter(Object.prototype.propertyIsEnumerable.bind(t)))}function O(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}var D=0,R=1,F=2,B=3;function N(t,e,r,n){if(t===e)return 0!==t||!r||c(t,e);if(r){if(\"object\"!==a(t))return\"number\"==typeof t&&h(t)&&h(e);if(\"object\"!==a(e)||null===t||null===e)return!1;if(Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1}else{if(null===t||\"object\"!==a(t))return(null===e||\"object\"!==a(e))&&t==e;if(null===e||\"object\"!==a(e))return!1}var i,s,l,u,f=m(t);if(f!==m(e))return!1;if(Array.isArray(t)){if(t.length!==e.length)return!1;var p=z(t),d=z(e);return p.length===d.length&&U(t,e,r,n,R,p)}if(\"[object Object]\"===f&&(!_(t)&&_(e)||!w(t)&&w(e)))return!1;if(x(t)){if(!x(e)||Date.prototype.getTime.call(t)!==Date.prototype.getTime.call(e))return!1}else if(b(t)){if(!b(e)||(l=t,u=e,!(o?l.source===u.source&&l.flags===u.flags:RegExp.prototype.toString.call(l)===RegExp.prototype.toString.call(u))))return!1}else if(T(t)||t instanceof Error){if(t.message!==e.message||t.name!==e.name)return!1}else{if(v(t)){if(r||!L(t)&&!I(t)){if(!function(t,e){return t.byteLength===e.byteLength&&0===O(new Uint8Array(t.buffer,t.byteOffset,t.byteLength),new Uint8Array(e.buffer,e.byteOffset,e.byteLength))}(t,e))return!1}else if(!function(t,e){if(t.byteLength!==e.byteLength)return!1;for(var r=0;r<t.byteLength;r++)if(t[r]!==e[r])return!1;return!0}(t,e))return!1;var g=z(t),P=z(e);return g.length===P.length&&U(t,e,r,n,D,g)}if(w(t))return!(!w(e)||t.size!==e.size)&&U(t,e,r,n,F);if(_(t))return!(!_(e)||t.size!==e.size)&&U(t,e,r,n,B);if(y(t)){if(s=e,(i=t).byteLength!==s.byteLength||0!==O(new Uint8Array(i),new Uint8Array(s)))return!1}else if(k(t)&&!function(t,e){return A(t)?A(e)&&c(Number.prototype.valueOf.call(t),Number.prototype.valueOf.call(e)):M(t)?M(e)&&String.prototype.valueOf.call(t)===String.prototype.valueOf.call(e):S(t)?S(e)&&Boolean.prototype.valueOf.call(t)===Boolean.prototype.valueOf.call(e):E(t)?E(e)&&BigInt.prototype.valueOf.call(t)===BigInt.prototype.valueOf.call(e):C(e)&&Symbol.prototype.valueOf.call(t)===Symbol.prototype.valueOf.call(e)}(t,e))return!1}return U(t,e,r,n,D)}function j(t,e){return e.filter((function(e){return d(t,e)}))}function U(t,e,r,i,o,c){if(5===arguments.length){c=Object.keys(t);var h=Object.keys(e);if(c.length!==h.length)return!1}for(var f=0;f<c.length;f++)if(!p(e,c[f]))return!1;if(r&&5===arguments.length){var m=u(t);if(0!==m.length){var g=0;for(f=0;f<m.length;f++){var y=m[f];if(d(t,y)){if(!d(e,y))return!1;c.push(y),g++}else if(d(e,y))return!1}var v=u(e);if(m.length!==v.length&&j(e,v).length!==g)return!1}else{var x=u(e);if(0!==x.length&&0!==j(e,x).length)return!1}}if(0===c.length&&(o===D||o===R&&0===t.length||0===t.size))return!0;if(void 0===i)i={val1:new Map,val2:new Map,position:0};else{var _=i.val1.get(t);if(void 0!==_){var b=i.val2.get(e);if(void 0!==b)return _===b}i.position++}i.val1.set(t,i.position),i.val2.set(e,i.position);var w=function(t,e,r,i,o,c){var u=0;if(c===F){if(!function(t,e,r,n){for(var i=null,o=s(t),l=0;l<o.length;l++){var c=o[l];if(\"object\"===a(c)&&null!==c)null===i&&(i=new Set),i.add(c);else if(!e.has(c)){if(r)return!1;if(!H(t,e,c))return!1;null===i&&(i=new Set),i.add(c)}}if(null!==i){for(var u=s(e),h=0;h<u.length;h++){var f=u[h];if(\"object\"===a(f)&&null!==f){if(!V(i,f,r,n))return!1}else if(!r&&!t.has(f)&&!V(i,f,r,n))return!1}return 0===i.size}return!0}(t,e,r,o))return!1}else if(c===B){if(!function(t,e,r,i){for(var o=null,s=l(t),c=0;c<s.length;c++){var u=n(s[c],2),h=u[0],f=u[1];if(\"object\"===a(h)&&null!==h)null===o&&(o=new Set),o.add(h);else{var p=e.get(h);if(void 0===p&&!e.has(h)||!N(f,p,r,i)){if(r)return!1;if(!G(t,e,h,f,i))return!1;null===o&&(o=new Set),o.add(h)}}}if(null!==o){for(var d=l(e),m=0;m<d.length;m++){var g=n(d[m],2),y=g[0],v=g[1];if(\"object\"===a(y)&&null!==y){if(!Z(o,t,y,v,r,i))return!1}else if(!(r||t.has(y)&&N(t.get(y),v,!1,i)||Z(o,t,y,v,!1,i)))return!1}return 0===o.size}return!0}(t,e,r,o))return!1}else if(c===R)for(;u<t.length;u++){if(!p(t,u)){if(p(e,u))return!1;for(var h=Object.keys(t);u<h.length;u++){var f=h[u];if(!p(e,f)||!N(t[f],e[f],r,o))return!1}return h.length===Object.keys(e).length}if(!p(e,u)||!N(t[u],e[u],r,o))return!1}for(u=0;u<i.length;u++){var d=i[u];if(!N(t[d],e[d],r,o))return!1}return!0}(t,e,r,c,i,o);return i.val1.delete(t),i.val2.delete(e),w}function V(t,e,r,n){for(var i=s(t),a=0;a<i.length;a++){var o=i[a];if(N(e,o,r,n))return t.delete(o),!0}return!1}function q(t){switch(a(t)){case\"undefined\":return null;case\"object\":return;case\"symbol\":return!1;case\"string\":t=+t;case\"number\":if(h(t))return!1}return!0}function H(t,e,r){var n=q(r);return null!=n?n:e.has(n)&&!t.has(n)}function G(t,e,r,n,i){var a=q(r);if(null!=a)return a;var o=e.get(a);return!(void 0===o&&!e.has(a)||!N(n,o,!1,i))&&!t.has(a)&&N(n,o,!1,i)}function Z(t,e,r,n,i,a){for(var o=s(t),l=0;l<o.length;l++){var c=o[l];if(N(r,c,i,a)&&N(n,e.get(c),i,a))return t.delete(c),!0}return!1}t.exports={isDeepEqual:function(t,e){return N(t,e,!1)},isDeepStrictEqual:function(t,e){return N(t,e,!0)}}},93229:function(t,e,r){\"use strict\";r.r(e),r.d(e,{decode:function(){return s},encode:function(){return o}});for(var n=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",i=\"undefined\"==typeof Uint8Array?[]:new Uint8Array(256),a=0;a<64;a++)i[n.charCodeAt(a)]=a;var o=function(t){var e,r=new Uint8Array(t),i=r.length,a=\"\";for(e=0;e<i;e+=3)a+=n[r[e]>>2],a+=n[(3&r[e])<<4|r[e+1]>>4],a+=n[(15&r[e+1])<<2|r[e+2]>>6],a+=n[63&r[e+2]];return i%3==2?a=a.substring(0,a.length-1)+\"=\":i%3==1&&(a=a.substring(0,a.length-2)+\"==\"),a},s=function(t){var e,r,n,a,o,s=.75*t.length,l=t.length,c=0;\"=\"===t[t.length-1]&&(s--,\"=\"===t[t.length-2]&&s--);var u=new ArrayBuffer(s),h=new Uint8Array(u);for(e=0;e<l;e+=4)r=i[t.charCodeAt(e)],n=i[t.charCodeAt(e+1)],a=i[t.charCodeAt(e+2)],o=i[t.charCodeAt(e+3)],h[c++]=r<<2|n>>4,h[c++]=(15&n)<<4|a>>2,h[c++]=(3&a)<<6|63&o;return u}},76226:function(t,e){\"use strict\";e.byteLength=function(t){var e=s(t),r=e[0],n=e[1];return 3*(r+n)/4-n},e.toByteArray=function(t){var e,r,a=s(t),o=a[0],l=a[1],c=new i(function(t,e,r){return 3*(e+r)/4-r}(0,o,l)),u=0,h=l>0?o-4:o;for(r=0;r<h;r+=4)e=n[t.charCodeAt(r)]<<18|n[t.charCodeAt(r+1)]<<12|n[t.charCodeAt(r+2)]<<6|n[t.charCodeAt(r+3)],c[u++]=e>>16&255,c[u++]=e>>8&255,c[u++]=255&e;return 2===l&&(e=n[t.charCodeAt(r)]<<2|n[t.charCodeAt(r+1)]>>4,c[u++]=255&e),1===l&&(e=n[t.charCodeAt(r)]<<10|n[t.charCodeAt(r+1)]<<4|n[t.charCodeAt(r+2)]>>2,c[u++]=e>>8&255,c[u++]=255&e),c},e.fromByteArray=function(t){for(var e,n=t.length,i=n%3,a=[],o=16383,s=0,c=n-i;s<c;s+=o)a.push(l(t,s,s+o>c?c:s+o));return 1===i?(e=t[n-1],a.push(r[e>>2]+r[e<<4&63]+\"==\")):2===i&&(e=(t[n-2]<<8)+t[n-1],a.push(r[e>>10]+r[e>>4&63]+r[e<<2&63]+\"=\")),a.join(\"\")};for(var r=[],n=[],i=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,a=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",o=0;o<64;++o)r[o]=a[o],n[a.charCodeAt(o)]=o;function s(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function l(t,e,n){for(var i,a,o=[],s=e;s<n;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(r[(a=i)>>18&63]+r[a>>12&63]+r[a>>6&63]+r[63&a]);return o.join(\"\")}n[\"-\".charCodeAt(0)]=62,n[\"_\".charCodeAt(0)]=63},31625:function(t){\"use strict\";function e(t,e,r,n,i){for(var a=i+1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)>=0?(a=o,i=o-1):n=o+1}return a}function r(t,e,r,n,i){for(var a=i+1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)>0?(a=o,i=o-1):n=o+1}return a}function n(t,e,r,n,i){for(var a=n-1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)<0?(a=o,n=o+1):i=o-1}return a}function i(t,e,r,n,i){for(var a=n-1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)<=0?(a=o,n=o+1):i=o-1}return a}function a(t,e,r,n,i){for(;n<=i;){var a=n+i>>>1,o=t[a],s=void 0!==r?r(o,e):o-e;if(0===s)return a;s<=0?n=a+1:i=a-1}return-1}function o(t,e,r,n,i,a){return\"function\"==typeof r?a(t,e,r,void 0===n?0:0|n,void 0===i?t.length-1:0|i):a(t,e,void 0,void 0===r?0:0|r,void 0===n?t.length-1:0|n)}t.exports={ge:function(t,r,n,i,a){return o(t,r,n,i,a,e)},gt:function(t,e,n,i,a){return o(t,e,n,i,a,r)},lt:function(t,e,r,i,a){return o(t,e,r,i,a,n)},le:function(t,e,r,n,a){return o(t,e,r,n,a,i)},eq:function(t,e,r,n,i){return o(t,e,r,n,i,a)}}},54689:function(t,e){\"use strict\";function r(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}e.INT_BITS=32,e.INT_MAX=2147483647,e.INT_MIN=-1<<31,e.sign=function(t){return(t>0)-(t<0)},e.abs=function(t){var e=t>>31;return(t^e)-e},e.min=function(t,e){return e^(t^e)&-(t<e)},e.max=function(t,e){return t^(t^e)&-(t<e)},e.isPow2=function(t){return!(t&t-1||!t)},e.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},e.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},e.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},e.countTrailingZeros=r,e.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,1+(t|=t>>>16)},e.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},e.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var n=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(n),e.reverse=function(t){return n[255&t]<<24|n[t>>>8&255]<<16|n[t>>>16&255]<<8|n[t>>>24&255]},e.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},e.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},e.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},e.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},e.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>r(t)+1}},88772:function(t,e,r){\"use strict\";var n=r(75144);t.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,m,g=null==e.cutoff?.25:e.cutoff,y=null==e.radius?8:e.radius,v=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,l=(p=h.getImageData(0,0,r,o)).data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(h=t,r=(f=t.canvas).width,o=f.height,l=(p=h.getImageData(0,0,r,o)).data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,m=c.length;d<m;d++)l[d]=c[d*u+v]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),_=Array(r*o),b=Array(s),w=Array(s),T=Array(s+1),k=Array(s);for(d=0,m=r*o;d<m;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),_[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,b,w,k,T),a(_,r,o,b,w,k,T);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,m=r*o;d<m;d++)M[d]=n(1-((x[d]-_[d])/y+g),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},63063:function(t,e,r){\"use strict\";var n=r(71129),i=r(87227),a=i(n(\"String.prototype.indexOf\"));t.exports=function(t,e){var r=n(t,!!e);return\"function\"==typeof r&&a(t,\".prototype.\")>-1?i(r):r}},87227:function(t,e,r){\"use strict\";var n=r(87547),i=r(71129),a=r(73285),o=r(48631),s=i(\"%Function.prototype.apply%\"),l=i(\"%Function.prototype.call%\"),c=i(\"%Reflect.apply%\",!0)||n.call(l,s),u=r(40891),h=i(\"%Math.max%\");t.exports=function(t){if(\"function\"!=typeof t)throw new o(\"a function is required\");var e=c(n,l,arguments);return a(e,1+h(0,t.length-(arguments.length-1)),!0)};var f=function(){return c(n,s,arguments)};u?u(t.exports,\"apply\",{value:f}):t.exports.apply=f},75144:function(t){t.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},46762:function(t,e,r){\"use strict\";var n=r(75144);function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(255&n(o,0,255))}t.exports=i,t.exports.to=i,t.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},86040:function(t){\"use strict\";t.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},162:function(t,e,r){\"use strict\";var n=r(16401),i=r(75144),a=r(10275);t.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},16401:function(t,e,r){\"use strict\";var n=r(10826),i=r(52132),a=r(75144);t.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},10826:function(t,e,r){\"use strict\";var n=r(86040);t.exports=function(t){var e,r,a=[],o=1;if(\"string\"==typeof t)if(t=t.toLowerCase(),n[t])a=n[t].slice(),r=\"rgb\";else if(\"transparent\"===t)o=0,r=\"rgb\",a=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var s=t.slice(1);o=1,(u=s.length)<=4?(a=[parseInt(s[0]+s[0],16),parseInt(s[1]+s[1],16),parseInt(s[2]+s[2],16)],4===u&&(o=parseInt(s[3]+s[3],16)/255)):(a=[parseInt(s[0]+s[1],16),parseInt(s[2]+s[3],16),parseInt(s[4]+s[5],16)],8===u&&(o=parseInt(s[6]+s[7],16)/255)),a[0]||(a[0]=0),a[1]||(a[1]=0),a[2]||(a[2]=0),r=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var l=e[1],c=\"rgb\"===l;r=s=l.replace(/a$/,\"\");var u=\"cmyk\"===s?4:\"gray\"===s?1:3;a=e[2].trim().split(/\\s*[,\\/]\\s*|\\s+/).map((function(t,e){if(/%$/.test(t))return e===u?parseFloat(t)/100:\"rgb\"===s?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===s[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==i[t])return i[t]}return parseFloat(t)})),l===s&&a.push(1),o=c||void 0===a[u]?1:a[u],a=a.slice(0,u)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(a=t.match(/([0-9]+)/g).map((function(t){return parseFloat(t)})),r=t.match(/([a-z])/gi).join(\"\").toLowerCase());else isNaN(t)?Array.isArray(t)||t.length?(a=[t[0],t[1],t[2]],r=\"rgb\",o=4===t.length?t[3]:1):t instanceof Object&&(null!=t.r||null!=t.red||null!=t.R?(r=\"rgb\",a=[t.r||t.red||t.R||0,t.g||t.green||t.G||0,t.b||t.blue||t.B||0]):(r=\"hsl\",a=[t.h||t.hue||t.H||0,t.s||t.saturation||t.S||0,t.l||t.lightness||t.L||t.b||t.brightness]),o=t.a||t.alpha||t.opacity||1,null!=t.opacity&&(o/=100)):(r=\"rgb\",a=[t>>>16,(65280&t)>>>8,255&t]);return{space:r,values:a,alpha:o}};var i={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}},52132:function(t,e,r){\"use strict\";var n=r(10520);t.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},10520:function(t){\"use strict\";t.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},78171:function(t){t.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\u00e7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\u00e9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\u00e9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\u00e3)o.?tom(e|\u00e9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},59518:function(t,e,r){\"use strict\";t.exports={parse:r(86029),stringify:r(38211)}},87724:function(t,e,r){\"use strict\";var n=r(23648);t.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},86029:function(t,e,r){\"use strict\";var n=r(80886),i=r(54324),a=r(94316),o=r(99803),s=r(87486),l=r(2362),c=r(28089),u=r(87724).isSize;t.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach((function(t){r[t]=e})),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},38211:function(t,e,r){\"use strict\";var n=r(6807),i=r(87724).isSize,a=d(r(54324)),o=d(r(94316)),s=d(r(99803)),l=d(r(87486)),c=d(r(2362)),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"serif\";function p(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function d(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}t.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&p(t.system,o),t.system;if(p(t.style,l),p(t.variant,u),p(t.weight,s),p(t.stretch,c),null==t.size&&(t.size=\"1rem\"),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=f),Array.isArray(t.family)&&(t.family.length||(t.family=[f]),t.family=t.family.map((function(t){return h[t]?t:'\"'+t+'\"'})).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},51070:function(t){\"use strict\";t.exports=function(t){var e=[];return e.toString=function(){return this.map((function(e){var r=\"\",n=void 0!==e[5];return e[4]&&(r+=\"@supports (\".concat(e[4],\") {\")),e[2]&&(r+=\"@media \".concat(e[2],\" {\")),n&&(r+=\"@layer\".concat(e[5].length>0?\" \".concat(e[5]):\"\",\" {\")),r+=t(e),n&&(r+=\"}\"),e[2]&&(r+=\"}\"),e[4]&&(r+=\"}\"),r})).join(\"\")},e.i=function(t,r,n,i,a){\"string\"==typeof t&&(t=[[null,t,void 0]]);var o={};if(n)for(var s=0;s<this.length;s++){var l=this[s][0];null!=l&&(o[l]=!0)}for(var c=0;c<t.length;c++){var u=[].concat(t[c]);n&&o[u[0]]||(void 0!==a&&(void 0===u[5]||(u[1]=\"@layer\".concat(u[5].length>0?\" \".concat(u[5]):\"\",\" {\").concat(u[1],\"}\")),u[5]=a),r&&(u[2]?(u[1]=\"@media \".concat(u[2],\" {\").concat(u[1],\"}\"),u[2]=r):u[2]=r),i&&(u[4]?(u[1]=\"@supports (\".concat(u[4],\") {\").concat(u[1],\"}\"),u[4]=i):u[4]=\"\".concat(i)),e.push(u))}},e}},62133:function(t){\"use strict\";t.exports=function(t,e){return e||(e={}),t?(t=String(t.__esModule?t.default:t),/^['\"].*['\"]$/.test(t)&&(t=t.slice(1,-1)),e.hash&&(t+=e.hash),/[\"'() \\t\\n]|(%20)/.test(t)||e.needQuotes?'\"'.concat(t.replace(/\"/g,'\\\\\"').replace(/\\n/g,\"\\\\n\"),'\"'):t):t}},22413:function(t){\"use strict\";t.exports=function(t){return t[1]}},84510:function(t,e,r){\"use strict\";var n,i=r(80299),a=r(9557),o=r(6887),s=r(86591),l=r(76504),c=r(29854),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=a(e)&&o(e.value);return delete(n=s(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},t.exports=function(t){var e=l(arguments[1]);return i(e.resolveContext)&&o(e.resolveContext),c(t,(function(t,r){return n(r,t,e)}))}},91819:function(t,e,r){\"use strict\";var n=r(80299),i=r(63461),a=r(1920),o=r(76504),s=r(2338),l=t.exports=function(t,e){var r,i,l,c,u;return arguments.length<2||\"string\"!=typeof t?(c=e,e=t,t=null):c=arguments[2],n(t)?(r=s.call(t,\"c\"),i=s.call(t,\"e\"),l=s.call(t,\"w\")):(r=l=!0,i=!1),u={value:e,configurable:r,enumerable:i,writable:l},c?a(o(c),u):u};l.gs=function(t,e,r){var l,c,u,h;return\"string\"!=typeof t?(u=r,r=e,e=t,t=null):u=arguments[3],n(e)?i(e)?n(r)?i(r)||(u=r,r=void 0):r=void 0:(u=e,e=r=void 0):e=void 0,n(t)?(l=s.call(t,\"c\"),c=s.call(t,\"e\")):(l=!0,c=!1),h={get:e,set:r,configurable:l,enumerable:c},u?a(o(u),h):h}},29725:function(t,e,r){\"use strict\";function n(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}r.d(e,{V_:function(){return n},T9:function(){return s},i2:function(){return c},Am:function(){return u},jk:function(){return h},y1:function(){return f},cz:function(){return p}}),1===(i=n).length&&(a=i,i=function(t,e){return n(a(t),e)});var i,a,o=Array.prototype;function s(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n}function l(t){return null===t?NaN:+t}function c(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=l(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=l(e(t[a],a,t)))?--i:o+=r;if(i)return o/i}function u(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r}function h(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function f(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}function p(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a}o.slice,o.map,Math.sqrt(50),Math.sqrt(10),Math.sqrt(2)},4575:function(t,e,r){\"use strict\";r.d(e,{Tj:function(){return o},$I:function(){return s}});var n=\"$\";function i(){}function a(t,e){var r=new i;if(t instanceof i)t.each((function(t,e){r.set(e,t)}));else if(Array.isArray(t)){var n,a=-1,o=t.length;if(null==e)for(;++a<o;)r.set(a,t[a]);else for(;++a<o;)r.set(e(n=t[a],a,t),n)}else if(t)for(var s in t)r.set(s,t[s]);return r}i.prototype=a.prototype={constructor:i,has:function(t){return n+t in this},get:function(t){return this[n+t]},set:function(t,e){return this[n+t]=e,this},remove:function(t){var e=n+t;return e in this&&delete this[e]},clear:function(){for(var t in this)t[0]===n&&delete this[t]},keys:function(){var t=[];for(var e in this)e[0]===n&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)e[0]===n&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)e[0]===n&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)e[0]===n&&++t;return t},empty:function(){for(var t in this)if(t[0]===n)return!1;return!0},each:function(t){for(var e in this)e[0]===n&&t(this[e],e.slice(1),this)}};var o=a;function s(){var t,e,r,n=[],i=[];function a(r,i,s,l){if(i>=n.length)return null!=t&&r.sort(t),null!=e?e(r):r;for(var c,u,h,f=-1,p=r.length,d=n[i++],m=o(),g=s();++f<p;)(h=m.get(c=d(u=r[f])+\"\"))?h.push(u):m.set(c,[u]);return m.each((function(t,e){l(g,e,a(t,i,s,l))})),g}function s(t,r){if(++r>n.length)return t;var a,o=i[r-1];return null!=e&&r>=n.length?a=t.entries():(a=[],t.each((function(t,e){a.push({key:e,values:s(t,r)})}))),null!=o?a.sort((function(t,e){return o(t.key,e.key)})):a}return r={object:function(t){return a(t,0,l,c)},map:function(t){return a(t,0,u,h)},entries:function(t){return s(a(t,0,u,h),0)},key:function(t){return n.push(t),r},sortKeys:function(t){return i[n.length-1]=t,r},sortValues:function(e){return t=e,r},rollup:function(t){return e=t,r}}}function l(){return{}}function c(t,e,r){t[e]=r}function u(){return o()}function h(t,e,r){t.set(e,r)}function f(){}var p=o.prototype;f.prototype=function(t,e){var r=new f;if(t instanceof f)t.each((function(t){r.add(t)}));else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}.prototype={constructor:f,has:p.has,add:function(t){return this[n+(t+=\"\")]=t,this},remove:p.remove,clear:p.clear,values:p.keys,size:p.size,empty:p.empty,each:p.each}},32702:function(t,e,r){\"use strict\";function n(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n}function i(t){return function(){return t}}function a(){return 1e-6*(Math.random()-.5)}function o(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},m=t._x0,g=t._y0,y=t._x1,v=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(m+y)/2))?m=a:y=a,(u=r>=(o=(g+v)/2))?g=o:v=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(m+y)/2))?m=a:y=a,(u=r>=(o=(g+v)/2))?g=o:v=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}function s(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i}function l(t){return t[0]}function c(t){return t[1]}function u(t,e,r){var n=new h(null==e?l:e,null==r?c:r,NaN,NaN,NaN,NaN);return null==t?n:n.addAll(t)}function h(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function f(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}r.r(e),r.d(e,{forceCenter:function(){return n},forceCollide:function(){return g},forceLink:function(){return _},forceManyBody:function(){return $},forceRadial:function(){return J},forceSimulation:function(){return X},forceX:function(){return K},forceY:function(){return Q}});var p=u.prototype=h.prototype;function d(t){return t.x+t.vx}function m(t){return t.y+t.vy}function g(t){var e,r,n=1,o=1;function s(){for(var t,i,s,c,h,f,p,g=e.length,y=0;y<o;++y)for(i=u(e,d,m).visitAfter(l),t=0;t<g;++t)s=e[t],f=r[s.index],p=f*f,c=s.x+s.vx,h=s.y+s.vy,i.visit(v);function v(t,e,r,i,o){var l=t.data,u=t.r,d=f+u;if(!l)return e>c+d||i<c-d||r>h+d||o<h-d;if(l.index>s.index){var m=c-l.x-l.vx,g=h-l.y-l.vy,y=m*m+g*g;y<d*d&&(0===m&&(y+=(m=a())*m),0===g&&(y+=(g=a())*g),y=(d-(y=Math.sqrt(y)))/y*n,s.vx+=(m*=y)*(d=(u*=u)/(p+u)),s.vy+=(g*=y)*d,l.vx-=m*(d=1-d),l.vy-=g*d)}}}function l(t){if(t.data)return t.r=r[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function c(){if(e){var n,i,a=e.length;for(r=new Array(a),n=0;n<a;++n)i=e[n],r[i.index]=+t(i,n,e)}}return\"function\"!=typeof t&&(t=i(null==t?1:+t)),s.initialize=function(t){e=t,c()},s.iterations=function(t){return arguments.length?(o=+t,s):o},s.strength=function(t){return arguments.length?(n=+t,s):n},s.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),c(),s):t},s}p.copy=function(){var t,e,r=new h(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=f(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=f(e));return r},p.add=function(t){var e=+this._x.call(null,t),r=+this._y.call(null,t);return o(this.cover(e,r),e,r,t)},p.addAll=function(t){var e,r,n,i,a=t.length,s=new Array(a),l=new Array(a),c=1/0,u=1/0,h=-1/0,f=-1/0;for(r=0;r<a;++r)isNaN(n=+this._x.call(null,e=t[r]))||isNaN(i=+this._y.call(null,e))||(s[r]=n,l[r]=i,n<c&&(c=n),n>h&&(h=n),i<u&&(u=i),i>f&&(f=i));if(c>h||u>f)return this;for(this.cover(c,u).cover(h,f),r=0;r<a;++r)o(this,s[r],l[r],t[r]);return this},p.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{for(var o,s,l=i-r,c=this._root;r>t||t>=i||n>e||e>=a;)switch(s=(e<n)<<1|t<r,(o=new Array(4))[s]=c,c=o,l*=2,s){case 0:i=r+l,a=n+l;break;case 1:r=i-l,a=n+l;break;case 2:i=r+l,n=a-l;break;case 3:r=i-l,n=a-l}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},p.data=function(){var t=[];return this.visit((function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)})),t},p.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},p.find=function(t,e,r){var n,i,a,o,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,m=[],g=this._root;for(g&&m.push(new s(g,h,f,p,d)),null==r?r=1/0:(h=t-r,f=e-r,p=t+r,d=e+r,r*=r);c=m.pop();)if(!(!(g=c.node)||(i=c.x0)>p||(a=c.y0)>d||(o=c.x1)<h||(l=c.y1)<f))if(g.length){var y=(i+o)/2,v=(a+l)/2;m.push(new s(g[3],y,v,o,l),new s(g[2],i,v,y,l),new s(g[1],y,a,o,v),new s(g[0],i,a,y,v)),(u=(e>=v)<<1|t>=y)&&(c=m[m.length-1],m[m.length-1]=m[m.length-1-u],m[m.length-1-u]=c)}else{var x=t-+this._x.call(null,g.data),_=e-+this._y.call(null,g.data),b=x*x+_*_;if(b<r){var w=Math.sqrt(r=b);h=t-w,f=e-w,p=t+w,d=e+w,n=g.data}}return n},p.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,m=this._y0,g=this._x1,y=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+g)/2))?d=s:g=s,(u=o>=(l=(m+y)/2))?m=l:y=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},p.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},p.root=function(){return this._root},p.size=function(){var t=0;return this.visit((function(e){if(!e.length)do{++t}while(e=e.next)})),t},p.visit=function(t){var e,r,n,i,a,o,l=[],c=this._root;for(c&&l.push(new s(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,n=e.x0,i=e.y0,a=e.x1,o=e.y1)&&c.length){var u=(n+a)/2,h=(i+o)/2;(r=c[3])&&l.push(new s(r,u,h,a,o)),(r=c[2])&&l.push(new s(r,n,h,u,o)),(r=c[1])&&l.push(new s(r,u,i,a,h)),(r=c[0])&&l.push(new s(r,n,i,u,h))}return this},p.visitAfter=function(t){var e,r=[],n=[];for(this._root&&r.push(new s(this._root,this._x0,this._y0,this._x1,this._y1));e=r.pop();){var i=e.node;if(i.length){var a,o=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(o+c)/2,f=(l+u)/2;(a=i[0])&&r.push(new s(a,o,l,h,f)),(a=i[1])&&r.push(new s(a,h,l,c,f)),(a=i[2])&&r.push(new s(a,o,f,h,u)),(a=i[3])&&r.push(new s(a,h,f,c,u))}n.push(e)}for(;e=n.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},p.x=function(t){return arguments.length?(this._x=t,this):this._x},p.y=function(t){return arguments.length?(this._y=t,this):this._y};var y=r(4575);function v(t){return t.index}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function _(t){var e,r,n,o,s,l=v,c=function(t){return 1/Math.min(o[t.source.index],o[t.target.index])},u=i(30),h=1;function f(n){for(var i=0,o=t.length;i<h;++i)for(var l,c,u,f,p,d,m,g=0;g<o;++g)c=(l=t[g]).source,f=(u=l.target).x+u.vx-c.x-c.vx||a(),p=u.y+u.vy-c.y-c.vy||a(),f*=d=((d=Math.sqrt(f*f+p*p))-r[g])/d*n*e[g],p*=d,u.vx-=f*(m=s[g]),u.vy-=p*m,c.vx+=f*(m=1-m),c.vy+=p*m}function p(){if(n){var i,a,c=n.length,u=t.length,h=(0,y.Tj)(n,l);for(i=0,o=new Array(c);i<u;++i)(a=t[i]).index=i,\"object\"!=typeof a.source&&(a.source=x(h,a.source)),\"object\"!=typeof a.target&&(a.target=x(h,a.target)),o[a.source.index]=(o[a.source.index]||0)+1,o[a.target.index]=(o[a.target.index]||0)+1;for(i=0,s=new Array(u);i<u;++i)a=t[i],s[i]=o[a.source.index]/(o[a.source.index]+o[a.target.index]);e=new Array(u),d(),r=new Array(u),m()}}function d(){if(n)for(var r=0,i=t.length;r<i;++r)e[r]=+c(t[r],r,t)}function m(){if(n)for(var e=0,i=t.length;e<i;++e)r[e]=+u(t[e],e,t)}return null==t&&(t=[]),f.initialize=function(t){n=t,p()},f.links=function(e){return arguments.length?(t=e,p(),f):t},f.id=function(t){return arguments.length?(l=t,f):l},f.iterations=function(t){return arguments.length?(h=+t,f):h},f.strength=function(t){return arguments.length?(c=\"function\"==typeof t?t:i(+t),d(),f):c},f.distance=function(t){return arguments.length?(u=\"function\"==typeof t?t:i(+t),m(),f):u},f}var b={value:function(){}};function w(){for(var t,e=0,r=arguments.length,n={};e<r;++e){if(!(t=arguments[e]+\"\")||t in n||/[\\s.]/.test(t))throw new Error(\"illegal type: \"+t);n[t]=[]}return new T(n)}function T(t){this._=t}function k(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function A(t,e,r){for(var n=0,i=t.length;n<i;++n)if(t[n].name===e){t[n]=b,t=t.slice(0,n).concat(t.slice(n+1));break}return null!=r&&t.push({name:e,value:r}),t}T.prototype=w.prototype={constructor:T,on:function(t,e){var r,n,i=this._,a=(n=i,(t+\"\").trim().split(/^|\\s+/).map((function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}}))),o=-1,s=a.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++o<s;)if(r=(t=a[o]).type)i[r]=A(i[r],t.name,e);else if(null==e)for(r in i)i[r]=A(i[r],t.name,null);return this}for(;++o<s;)if((r=(t=a[o]).type)&&(r=k(i[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new T(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}};var M,S,E=w,C=0,L=0,I=0,P=1e3,z=0,O=0,D=0,R=\"object\"==typeof performance&&performance.now?performance:Date,F=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function B(){return O||(F(N),O=R.now()+D)}function N(){O=0}function j(){this._call=this._time=this._next=null}function U(t,e,r){var n=new j;return n.restart(t,e,r),n}function V(){O=(z=R.now())+D,C=L=0;try{!function(){B(),++C;for(var t,e=M;e;)(t=O-e._time)>=0&&e._call.call(null,t),e=e._next;--C}()}finally{C=0,function(){for(var t,e,r=M,n=1/0;r;)r._call?(n>r._time&&(n=r._time),t=r,r=r._next):(e=r._next,r._next=null,r=t?t._next=e:M=e);S=t,H(n)}(),O=0}}function q(){var t=R.now(),e=t-z;e>P&&(D-=e,z=t)}function H(t){C||(L&&(L=clearTimeout(L)),t-O>24?(t<1/0&&(L=setTimeout(V,t-R.now()-D)),I&&(I=clearInterval(I))):(I||(z=R.now(),I=setInterval(q,P)),C=1,F(V)))}function G(t){return t.x}function Z(t){return t.y}j.prototype=U.prototype={constructor:j,restart:function(t,e,r){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");r=(null==r?B():+r)+(null==e?0:+e),this._next||S===this||(S?S._next=this:M=this,S=this),this._call=t,this._time=r,H()},stop:function(){this._call&&(this._call=null,this._time=1/0,H())}};var W=10,Y=Math.PI*(3-Math.sqrt(5));function X(t){var e,r=1,n=.001,i=1-Math.pow(n,1/300),a=0,o=.6,s=(0,y.Tj)(),l=U(u),c=E(\"tick\",\"end\");function u(){h(),c.call(\"tick\",e),r<n&&(l.stop(),c.call(\"end\",e))}function h(n){var l,c,u=t.length;void 0===n&&(n=1);for(var h=0;h<n;++h)for(r+=(a-r)*i,s.each((function(t){t(r)})),l=0;l<u;++l)null==(c=t[l]).fx?c.x+=c.vx*=o:(c.x=c.fx,c.vx=0),null==c.fy?c.y+=c.vy*=o:(c.y=c.fy,c.vy=0);return e}function f(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,null!=e.fx&&(e.x=e.fx),null!=e.fy&&(e.y=e.fy),isNaN(e.x)||isNaN(e.y)){var i=W*Math.sqrt(r),a=r*Y;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function p(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),f(),e={tick:h,restart:function(){return l.restart(u),e},stop:function(){return l.stop(),e},nodes:function(r){return arguments.length?(t=r,f(),s.each(p),e):t},alpha:function(t){return arguments.length?(r=+t,e):r},alphaMin:function(t){return arguments.length?(n=+t,e):n},alphaDecay:function(t){return arguments.length?(i=+t,e):+i},alphaTarget:function(t){return arguments.length?(a=+t,e):a},velocityDecay:function(t){return arguments.length?(o=1-t,e):1-o},force:function(t,r){return arguments.length>1?(null==r?s.remove(t):s.set(t,p(r)),e):s.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(c.on(t,r),e):c.on(t)}}}function $(){var t,e,r,n,o=i(-30),s=1,l=1/0,c=.81;function h(n){var i,a=t.length,o=u(t,G,Z).visitAfter(p);for(r=n,i=0;i<a;++i)e=t[i],o.visit(d)}function f(){if(t){var e,r,i=t.length;for(n=new Array(i),e=0;e<i;++e)r=t[e],n[r.index]=+o(r,e,t)}}function p(t){var e,r,i,a,o,s=0,l=0;if(t.length){for(i=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,i+=r*e.x,a+=r*e.y);t.x=i/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=n[e.data.index]}while(e=e.next)}t.value=s}function d(t,i,o,u){if(!t.value)return!0;var h=t.x-e.x,f=t.y-e.y,p=u-i,d=h*h+f*f;if(p*p/c<d)return d<l&&(0===h&&(d+=(h=a())*h),0===f&&(d+=(f=a())*f),d<s&&(d=Math.sqrt(s*d)),e.vx+=h*t.value*r/d,e.vy+=f*t.value*r/d),!0;if(!(t.length||d>=l)){(t.data!==e||t.next)&&(0===h&&(d+=(h=a())*h),0===f&&(d+=(f=a())*f),d<s&&(d=Math.sqrt(s*d)));do{t.data!==e&&(p=n[t.data.index]*r/d,e.vx+=h*p,e.vy+=f*p)}while(t=t.next)}}return h.initialize=function(e){t=e,f()},h.strength=function(t){return arguments.length?(o=\"function\"==typeof t?t:i(+t),f(),h):o},h.distanceMin=function(t){return arguments.length?(s=t*t,h):Math.sqrt(s)},h.distanceMax=function(t){return arguments.length?(l=t*t,h):Math.sqrt(l)},h.theta=function(t){return arguments.length?(c=t*t,h):Math.sqrt(c)},h}function J(t,e,r){var n,a,o,s=i(.1);function l(t){for(var i=0,s=n.length;i<s;++i){var l=n[i],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[i]-h)*a[i]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(a=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),a[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=i(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:i(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l}function K(t){var e,r,n,a=i(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return\"function\"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a=\"function\"==typeof t?t:i(+t),s(),o):a},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),s(),o):t},o}function Q(t){var e,r,n,a=i(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return\"function\"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a=\"function\"==typeof t?t:i(+t),s(),o):a},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),s(),o):t},o}},36464:function(t,e,r){\"use strict\";function n(t,e){if((r=(t=e?t.toExponential(e-1):t.toExponential()).indexOf(\"e\"))<0)return null;var r,n=t.slice(0,r);return[n.length>1?n[0]+n.slice(2):n,+t.slice(r+1)]}r.d(e,{GP:function(){return f},OE:function(){return m}});var i,a=/^(?:(.)?([<>=^]))?([+\\-( ])?([$#])?(0)?(\\d+)?(,)?(\\.\\d+)?(~)?([a-z%])?$/i;function o(t){if(!(e=a.exec(t)))throw new Error(\"invalid format: \"+t);var e;return new s({fill:e[1],align:e[2],sign:e[3],symbol:e[4],zero:e[5],width:e[6],comma:e[7],precision:e[8]&&e[8].slice(1),trim:e[9],type:e[10]})}function s(t){this.fill=void 0===t.fill?\" \":t.fill+\"\",this.align=void 0===t.align?\">\":t.align+\"\",this.sign=void 0===t.sign?\"-\":t.sign+\"\",this.symbol=void 0===t.symbol?\"\":t.symbol+\"\",this.zero=!!t.zero,this.width=void 0===t.width?void 0:+t.width,this.comma=!!t.comma,this.precision=void 0===t.precision?void 0:+t.precision,this.trim=!!t.trim,this.type=void 0===t.type?\"\":t.type+\"\"}function l(t,e){var r=n(t,e);if(!r)return t+\"\";var i=r[0],a=r[1];return a<0?\"0.\"+new Array(-a).join(\"0\")+i:i.length>a+1?i.slice(0,a+1)+\".\"+i.slice(a+1):i+new Array(a-i.length+2).join(\"0\")}o.prototype=s.prototype,s.prototype.toString=function(){return this.fill+this.align+this.sign+this.symbol+(this.zero?\"0\":\"\")+(void 0===this.width?\"\":Math.max(1,0|this.width))+(this.comma?\",\":\"\")+(void 0===this.precision?\"\":\".\"+Math.max(0,0|this.precision))+(this.trim?\"~\":\"\")+this.type};var c={\"%\":function(t,e){return(100*t).toFixed(e)},b:function(t){return Math.round(t).toString(2)},c:function(t){return t+\"\"},d:function(t){return Math.abs(t=Math.round(t))>=1e21?t.toLocaleString(\"en\").replace(/,/g,\"\"):t.toString(10)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},g:function(t,e){return t.toPrecision(e)},o:function(t){return Math.round(t).toString(8)},p:function(t,e){return l(100*t,e)},r:l,s:function(t,e){var r=n(t,e);if(!r)return t+\"\";var a=r[0],o=r[1],s=o-(i=3*Math.max(-8,Math.min(8,Math.floor(o/3))))+1,l=a.length;return s===l?a:s>l?a+new Array(s-l+1).join(\"0\"):s>0?a.slice(0,s)+\".\"+a.slice(s):\"0.\"+new Array(1-s).join(\"0\")+n(t,Math.max(0,e+s-1))[0]},X:function(t){return Math.round(t).toString(16).toUpperCase()},x:function(t){return Math.round(t).toString(16)}};function u(t){return t}var h,f,p=Array.prototype.map,d=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\u00b5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"];function m(t){var e,r,a=void 0===t.grouping||void 0===t.thousands?u:(e=p.call(t.grouping,Number),r=t.thousands+\"\",function(t,n){for(var i=t.length,a=[],o=0,s=e[0],l=0;i>0&&s>0&&(l+s+1>n&&(s=Math.max(1,n-l)),a.push(t.substring(i-=s,i+s)),!((l+=s+1)>n));)s=e[o=(o+1)%e.length];return a.reverse().join(r)}),s=void 0===t.currency?\"\":t.currency[0]+\"\",l=void 0===t.currency?\"\":t.currency[1]+\"\",h=void 0===t.decimal?\".\":t.decimal+\"\",f=void 0===t.numerals?u:function(t){return function(e){return e.replace(/[0-9]/g,(function(e){return t[+e]}))}}(p.call(t.numerals,String)),m=void 0===t.percent?\"%\":t.percent+\"\",g=void 0===t.minus?\"-\":t.minus+\"\",y=void 0===t.nan?\"NaN\":t.nan+\"\";function v(t){var e=(t=o(t)).fill,r=t.align,n=t.sign,u=t.symbol,p=t.zero,v=t.width,x=t.comma,_=t.precision,b=t.trim,w=t.type;\"n\"===w?(x=!0,w=\"g\"):c[w]||(void 0===_&&(_=12),b=!0,w=\"g\"),(p||\"0\"===e&&\"=\"===r)&&(p=!0,e=\"0\",r=\"=\");var T=\"$\"===u?s:\"#\"===u&&/[boxX]/.test(w)?\"0\"+w.toLowerCase():\"\",k=\"$\"===u?l:/[%p]/.test(w)?m:\"\",A=c[w],M=/[defgprs%]/.test(w);function S(t){var o,s,l,c=T,u=k;if(\"c\"===w)u=A(t)+u,t=\"\";else{var m=(t=+t)<0||1/t<0;if(t=isNaN(t)?y:A(Math.abs(t),_),b&&(t=function(t){t:for(var e,r=t.length,n=1,i=-1;n<r;++n)switch(t[n]){case\".\":i=e=n;break;case\"0\":0===i&&(i=n),e=n;break;default:if(!+t[n])break t;i>0&&(i=0)}return i>0?t.slice(0,i)+t.slice(e+1):t}(t)),m&&0==+t&&\"+\"!==n&&(m=!1),c=(m?\"(\"===n?n:g:\"-\"===n||\"(\"===n?\"\":n)+c,u=(\"s\"===w?d[8+i/3]:\"\")+u+(m&&\"(\"===n?\")\":\"\"),M)for(o=-1,s=t.length;++o<s;)if(48>(l=t.charCodeAt(o))||l>57){u=(46===l?h+t.slice(o+1):t.slice(o))+u,t=t.slice(0,o);break}}x&&!p&&(t=a(t,1/0));var S=c.length+t.length+u.length,E=S<v?new Array(v-S+1).join(e):\"\";switch(x&&p&&(t=a(E+t,E.length?v-u.length:1/0),E=\"\"),r){case\"<\":t=c+t+u+E;break;case\"=\":t=c+E+t+u;break;case\"^\":t=E.slice(0,S=E.length>>1)+c+t+u+E.slice(S);break;default:t=E+c+t+u}return f(t)}return _=void 0===_?6:/[gprs]/.test(w)?Math.max(1,Math.min(21,_)):Math.max(0,Math.min(20,_)),S.toString=function(){return t+\"\"},S}return{format:v,formatPrefix:function(t,e){var r,i=v(((t=o(t)).type=\"f\",t)),a=3*Math.max(-8,Math.min(8,Math.floor((r=e,((r=n(Math.abs(r)))?r[1]:NaN)/3)))),s=Math.pow(10,-a),l=d[8+a/3];return function(t){return i(s*t)+l}}}}h=m({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],minus:\"-\"}),f=h.format,h.formatPrefix},75987:function(t,e,r){\"use strict\";r.r(e),r.d(e,{geoAiry:function(){return D},geoAiryRaw:function(){return O},geoAitoff:function(){return F},geoAitoffRaw:function(){return R},geoArmadillo:function(){return N},geoArmadilloRaw:function(){return B},geoAugust:function(){return U},geoAugustRaw:function(){return j},geoBaker:function(){return G},geoBakerRaw:function(){return H},geoBerghaus:function(){return Y},geoBerghausRaw:function(){return W},geoBertin1953:function(){return rt},geoBertin1953Raw:function(){return et},geoBoggs:function(){return ut},geoBoggsRaw:function(){return ct},geoBonne:function(){return mt},geoBonneRaw:function(){return dt},geoBottomley:function(){return yt},geoBottomleyRaw:function(){return gt},geoBromley:function(){return xt},geoBromleyRaw:function(){return vt},geoChamberlin:function(){return Et},geoChamberlinAfrica:function(){return St},geoChamberlinRaw:function(){return At},geoCollignon:function(){return Lt},geoCollignonRaw:function(){return Ct},geoCraig:function(){return Pt},geoCraigRaw:function(){return It},geoCraster:function(){return Dt},geoCrasterRaw:function(){return Ot},geoCylindricalEqualArea:function(){return Ft},geoCylindricalEqualAreaRaw:function(){return Rt},geoCylindricalStereographic:function(){return Nt},geoCylindricalStereographicRaw:function(){return Bt},geoEckert1:function(){return Ut},geoEckert1Raw:function(){return jt},geoEckert2:function(){return qt},geoEckert2Raw:function(){return Vt},geoEckert3:function(){return Gt},geoEckert3Raw:function(){return Ht},geoEckert4:function(){return Wt},geoEckert4Raw:function(){return Zt},geoEckert5:function(){return Xt},geoEckert5Raw:function(){return Yt},geoEckert6:function(){return Jt},geoEckert6Raw:function(){return $t},geoEisenlohr:function(){return te},geoEisenlohrRaw:function(){return Qt},geoFahey:function(){return ne},geoFaheyRaw:function(){return re},geoFoucaut:function(){return ae},geoFoucautRaw:function(){return ie},geoFoucautSinusoidal:function(){return se},geoFoucautSinusoidalRaw:function(){return oe},geoGilbert:function(){return fe},geoGingery:function(){return ge},geoGingeryRaw:function(){return pe},geoGinzburg4:function(){return xe},geoGinzburg4Raw:function(){return ve},geoGinzburg5:function(){return be},geoGinzburg5Raw:function(){return _e},geoGinzburg6:function(){return Te},geoGinzburg6Raw:function(){return we},geoGinzburg8:function(){return Ae},geoGinzburg8Raw:function(){return ke},geoGinzburg9:function(){return Se},geoGinzburg9Raw:function(){return Me},geoGringorten:function(){return Le},geoGringortenQuincuncial:function(){return ii},geoGringortenRaw:function(){return Ce},geoGuyou:function(){return Oe},geoGuyouRaw:function(){return ze},geoHammer:function(){return K},geoHammerRaw:function(){return $},geoHammerRetroazimuthal:function(){return Be},geoHammerRetroazimuthalRaw:function(){return Re},geoHealpix:function(){return We},geoHealpixRaw:function(){return qe},geoHill:function(){return Xe},geoHillRaw:function(){return Ye},geoHomolosine:function(){return er},geoHomolosineRaw:function(){return tr},geoHufnagel:function(){return nr},geoHufnagelRaw:function(){return rr},geoHyperelliptical:function(){return sr},geoHyperellipticalRaw:function(){return or},geoInterrupt:function(){return ur},geoInterruptedBoggs:function(){return fr},geoInterruptedHomolosine:function(){return dr},geoInterruptedMollweide:function(){return gr},geoInterruptedMollweideHemispheres:function(){return vr},geoInterruptedQuarticAuthalic:function(){return hn},geoInterruptedSinuMollweide:function(){return _r},geoInterruptedSinusoidal:function(){return wr},geoKavrayskiy7:function(){return kr},geoKavrayskiy7Raw:function(){return Tr},geoLagrange:function(){return Mr},geoLagrangeRaw:function(){return Ar},geoLarrivee:function(){return Cr},geoLarriveeRaw:function(){return Er},geoLaskowski:function(){return Ir},geoLaskowskiRaw:function(){return Lr},geoLittrow:function(){return zr},geoLittrowRaw:function(){return Pr},geoLoximuthal:function(){return Dr},geoLoximuthalRaw:function(){return Or},geoMiller:function(){return Fr},geoMillerRaw:function(){return Rr},geoModifiedStereographic:function(){return Xr},geoModifiedStereographicAlaska:function(){return Hr},geoModifiedStereographicGs48:function(){return Gr},geoModifiedStereographicGs50:function(){return Zr},geoModifiedStereographicLee:function(){return Yr},geoModifiedStereographicMiller:function(){return Wr},geoModifiedStereographicRaw:function(){return Br},geoMollweide:function(){return ot},geoMollweideRaw:function(){return at},geoMtFlatPolarParabolic:function(){return Qr},geoMtFlatPolarParabolicRaw:function(){return Kr},geoMtFlatPolarQuartic:function(){return en},geoMtFlatPolarQuarticRaw:function(){return tn},geoMtFlatPolarSinusoidal:function(){return nn},geoMtFlatPolarSinusoidalRaw:function(){return rn},geoNaturalEarth:function(){return an.A},geoNaturalEarth2:function(){return sn},geoNaturalEarth2Raw:function(){return on},geoNaturalEarthRaw:function(){return an.P},geoNellHammer:function(){return cn},geoNellHammerRaw:function(){return ln},geoNicolosi:function(){return pn},geoNicolosiRaw:function(){return fn},geoPatterson:function(){return kn},geoPattersonRaw:function(){return Tn},geoPeirceQuincuncial:function(){return ai},geoPierceQuincuncial:function(){return ai},geoPolyconic:function(){return Mn},geoPolyconicRaw:function(){return An},geoPolyhedral:function(){return Pn},geoPolyhedralButterfly:function(){return Nn},geoPolyhedralCollignon:function(){return Vn},geoPolyhedralWaterman:function(){return qn},geoProject:function(){return Yn},geoQuantize:function(){return oi},geoQuincuncial:function(){return ni},geoRectangularPolyconic:function(){return li},geoRectangularPolyconicRaw:function(){return si},geoRobinson:function(){return hi},geoRobinsonRaw:function(){return ui},geoSatellite:function(){return pi},geoSatelliteRaw:function(){return fi},geoSinuMollweide:function(){return Qe},geoSinuMollweideRaw:function(){return Ke},geoSinusoidal:function(){return pt},geoSinusoidalRaw:function(){return ft},geoStitch:function(){return Pi},geoTimes:function(){return Oi},geoTimesRaw:function(){return zi},geoTwoPointAzimuthal:function(){return Bi},geoTwoPointAzimuthalRaw:function(){return Ri},geoTwoPointAzimuthalUsa:function(){return Fi},geoTwoPointEquidistant:function(){return Ui},geoTwoPointEquidistantRaw:function(){return Ni},geoTwoPointEquidistantUsa:function(){return ji},geoVanDerGrinten:function(){return qi},geoVanDerGrinten2:function(){return Gi},geoVanDerGrinten2Raw:function(){return Hi},geoVanDerGrinten3:function(){return Wi},geoVanDerGrinten3Raw:function(){return Zi},geoVanDerGrinten4:function(){return Xi},geoVanDerGrinten4Raw:function(){return Yi},geoVanDerGrintenRaw:function(){return Vi},geoWagner:function(){return Ji},geoWagner4:function(){return ra},geoWagner4Raw:function(){return ea},geoWagner6:function(){return ia},geoWagner6Raw:function(){return na},geoWagner7:function(){return Ki},geoWagnerRaw:function(){return $i},geoWiechel:function(){return oa},geoWiechelRaw:function(){return aa},geoWinkel3:function(){return la},geoWinkel3Raw:function(){return sa}});var n=r(94684),i=Math.abs,a=Math.atan,o=Math.atan2,s=(Math.ceil,Math.cos),l=Math.exp,c=Math.floor,u=Math.log,h=Math.max,f=Math.min,p=Math.pow,d=Math.round,m=Math.sign||function(t){return t>0?1:t<0?-1:0},g=Math.sin,y=Math.tan,v=1e-6,x=1e-12,_=Math.PI,b=_/2,w=_/4,T=Math.SQRT1_2,k=I(2),A=I(_),M=2*_,S=180/_,E=_/180;function C(t){return t>1?b:t<-1?-b:Math.asin(t)}function L(t){return t>1?0:t<-1?_:Math.acos(t)}function I(t){return t>0?Math.sqrt(t):0}function P(t){return(l(t)-l(-t))/2}function z(t){return(l(t)+l(-t))/2}function O(t){var e=y(t/2),r=2*u(s(t/2))/(e*e);function n(t,e){var n=s(t),i=s(e),a=g(e),o=i*n,l=-((1-o?u((1+o)/2)/(1-o):-.5)+r/(1+o));return[l*i*g(t),l*a]}return n.invert=function(e,n){var a,l=I(e*e+n*n),c=-t/2,h=50;if(!l)return[0,0];do{var f=c/2,p=s(f),d=g(f),m=d/p,y=-u(i(p));c-=a=(2/m*y-r*m-l)/(-y/(d*d)+1-r/(2*p*p))*(p<0?.7:1)}while(i(a)>v&&--h>0);var x=g(c);return[o(e*x,l*s(c)),C(n*x/l)]},n}function D(){var t=b,e=(0,n.U)(O),r=e(t);return r.radius=function(r){return arguments.length?e(t=r*E):t*S},r.scale(179.976).clipAngle(147)}function R(t,e){var r=s(e),n=function(t){return t?t/Math.sin(t):1}(L(r*s(t/=2)));return[2*r*g(t)*n,g(e)*n]}function F(){return(0,n.A)(R).scale(152.63)}function B(t){var e=g(t),r=s(t),n=t>=0?1:-1,a=y(n*t),l=(1+e-r)/2;function c(t,i){var c=s(i),u=s(t/=2);return[(1+c)*g(t),(n*i>-o(u,a)-.001?0:10*-n)+l+g(i)*r-(1+c)*e*u]}return c.invert=function(t,c){var u=0,h=0,f=50;do{var p=s(u),d=g(u),m=s(h),y=g(h),x=1+m,_=x*d-t,b=l+y*r-x*e*p-c,w=x*p/2,T=-d*y,k=e*x*d/2,A=r*m+e*p*y,M=T*k-A*w,S=(b*T-_*A)/M/2,E=(_*k-b*w)/M;i(E)>2&&(E/=2),u-=S,h-=E}while((i(S)>v||i(E)>v)&&--f>0);return n*h>-o(s(u),a)-.001?[2*u,h]:null},c}function N(){var t=20*E,e=t>=0?1:-1,r=y(e*t),i=(0,n.U)(B),a=i(t),l=a.stream;return a.parallel=function(n){return arguments.length?(r=y((e=(t=n*E)>=0?1:-1)*t),i(t)):t*S},a.stream=function(n){var i=a.rotate(),c=l(n),u=(a.rotate([0,0]),l(n)),h=a.precision();return a.rotate(i),c.sphere=function(){u.polygonStart(),u.lineStart();for(var n=-180*e;e*n<180;n+=90*e)u.point(n,90*e);if(t)for(;e*(n-=3*e*h)>=-180;)u.point(n,e*-o(s(n*E/2),r)*S);u.lineEnd(),u.polygonEnd()},c},a.scale(218.695).center([0,28.0974])}function j(t,e){var r=y(e/2),n=I(1-r*r),i=1+n*s(t/=2),a=g(t)*n/i,o=r/i,l=a*a,c=o*o;return[4/3*a*(3+l-3*c),4/3*o*(3+3*l-c)]}function U(){return(0,n.A)(j).scale(66.1603)}R.invert=function(t,e){if(!(t*t+4*e*e>_*_+v)){var r=t,n=e,a=25;do{var o,l=g(r),c=g(r/2),u=s(r/2),h=g(n),f=s(n),p=g(2*n),d=h*h,m=f*f,y=c*c,x=1-m*u*u,b=x?L(f*u)*I(o=1/x):o=0,w=2*b*f*c-t,T=b*h-e,k=o*(m*y+b*f*u*d),A=o*(.5*l*p-2*b*h*c),M=.25*o*(p*c-b*h*m*l),S=o*(d*u+b*y*f),E=A*M-S*k;if(!E)break;var C=(T*A-w*S)/E,P=(w*M-T*k)/E;r-=C,n-=P}while((i(C)>v||i(P)>v)&&--a>0);return[r,n]}},j.invert=function(t,e){if(e*=3/8,!(t*=3/8)&&i(e)>1)return null;var r=1+t*t+e*e,n=I((r-I(r*r-4*e*e))/2),a=C(n)/3,l=n?function(t){return u(t+I(t*t-1))}(i(e/n))/3:function(t){return u(t+I(t*t+1))}(i(t))/3,c=s(a),h=z(l),f=h*h-c*c;return[2*m(t)*o(P(l)*c,.25-f),2*m(e)*o(h*g(a),.25+f)]};var V=I(8),q=u(1+k);function H(t,e){var r=i(e);return r<w?[t,u(y(w+e/2))]:[t*s(r)*(2*k-1/g(r)),m(e)*(2*k*(r-w)-u(y(r/2)))]}function G(){return(0,n.A)(H).scale(112.314)}H.invert=function(t,e){if((n=i(e))<q)return[t,2*a(l(e))-b];var r,n,o=w,c=25;do{var h=s(o/2),f=y(o/2);o-=r=(V*(o-w)-u(f)-n)/(V-h*h/(2*f))}while(i(r)>x&&--c>0);return[t/(s(o)*(V-1/g(o))),m(e)*o]};var Z=r(61957);function W(t){var e=2*_/t;function r(t,r){var n=(0,Z.j)(t,r);if(i(t)>b){var a=o(n[1],n[0]),l=I(n[0]*n[0]+n[1]*n[1]),c=e*d((a-b)/e)+b,u=o(g(a-=c),2-s(a));a=c+C(_/l*g(u))-u,n[0]=l*s(a),n[1]=l*g(a)}return n}return r.invert=function(t,r){var n=I(t*t+r*r);if(n>b){var i=o(r,t),l=e*d((i-b)/e)+b,c=i>l?-1:1,u=n*s(l-i),h=1/y(c*L((u-_)/I(_*(_-2*u)+n*n)));i=l+2*a((h+c*I(h*h-3))/3),t=n*s(i),r=n*g(i)}return Z.j.invert(t,r)},r}function Y(){var t=5,e=(0,n.U)(W),r=e(t),i=r.stream,a=.01,l=-s(a*E),c=g(a*E);return r.lobes=function(r){return arguments.length?e(t=+r):t},r.stream=function(e){var n=r.rotate(),u=i(e),h=(r.rotate([0,0]),i(e));return r.rotate(n),u.sphere=function(){h.polygonStart(),h.lineStart();for(var e=0,r=360/t,n=2*_/t,i=90-180/t,u=b;e<t;++e,i-=r,u-=n)h.point(o(c*s(u),l)*S,C(c*g(u))*S),i<-90?(h.point(-90,-180-i-a),h.point(-90,-180-i+a)):(h.point(90,i+a),h.point(90,i-a));h.lineEnd(),h.polygonEnd()},u},r.scale(87.8076).center([0,17.1875]).clipAngle(179.999)}var X=r(30729);function $(t,e){if(arguments.length<2&&(e=t),1===e)return X.n;if(e===1/0)return J;function r(r,n){var i=(0,X.n)(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=X.n.invert(r/t,n);return i[0]*=e,i},r}function J(t,e){return[t*s(e)/s(e/=2),2*g(e)]}function K(){var t=2,e=(0,n.U)($),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r.scale(169.529)}function Q(t,e,r){var n,a,o,s=100;r=void 0===r?0:+r,e=+e;do{(a=t(r))===(o=t(r+v))&&(o=a+v),r-=n=-1*v*(a-e)/(a-o)}while(s-- >0&&i(n)>v);return s<0?NaN:r}function tt(t,e,r){return void 0===e&&(e=40),void 0===r&&(r=x),function(n,a,o,s){var l,c,u;o=void 0===o?0:+o,s=void 0===s?0:+s;for(var h=0;h<e;h++){var f=t(o,s),p=f[0]-n,d=f[1]-a;if(i(p)<r&&i(d)<r)break;var m=p*p+d*d;if(m>l)o-=c/=2,s-=u/=2;else{l=m;var g=(o>0?-1:1)*r,y=(s>0?-1:1)*r,v=t(o+g,s),x=t(o,s+y),_=(v[0]-f[0])/g,b=(v[1]-f[1])/g,w=(x[0]-f[0])/y,T=(x[1]-f[1])/y,k=T*_-b*w,A=(i(k)<.5?.5:1)/k;if(o+=c=(d*w-p*T)*A,s+=u=(p*b-d*_)*A,i(c)<r&&i(u)<r)break}}return[o,s]}}function et(){var t=$(1.68,2);function e(e,r){if(e+r<-1.4){var n=(e-r+1.6)*(e+r+1.4)/8;e+=n,r-=.8*n*g(r+_/2)}var i=t(e,r),a=(1-s(e*r))/12;return i[1]<0&&(i[0]*=1+a),i[1]>0&&(i[1]*=1+a/1.5*i[0]*i[0]),i}return e.invert=tt(e),e}function rt(){return(0,n.A)(et()).rotate([-16.5,-42]).scale(176.57).center([7.93,.09])}function nt(t,e){var r,n=t*g(e),a=30;do{e-=r=(e+g(e)-n)/(1+s(e))}while(i(r)>v&&--a>0);return e/2}function it(t,e,r){function n(n,i){return[t*n*s(i=nt(r,i)),e*g(i)]}return n.invert=function(n,i){return i=C(i/e),[n/(t*s(i)),C((2*i+g(2*i))/r)]},n}J.invert=function(t,e){var r=2*C(e/2);return[t*s(r/2)/s(r),r]};var at=it(k/b,k,_);function ot(){return(0,n.A)(at).scale(169.529)}var st=2.00276,lt=1.11072;function ct(t,e){var r=nt(_,e);return[st*t/(1/s(e)+lt/s(r)),(e+k*g(r))/st]}function ut(){return(0,n.A)(ct).scale(160.857)}function ht(t){var e=0,r=(0,n.U)(t),i=r(e);return i.parallel=function(t){return arguments.length?r(e=t*E):e*S},i}function ft(t,e){return[t*s(e),e]}function pt(){return(0,n.A)(ft).scale(152.63)}function dt(t){if(!t)return ft;var e=1/y(t);function r(r,n){var i=e+t-n,a=i?r*s(n)/i:i;return[i*g(a),e-i*s(a)]}return r.invert=function(r,n){var i=I(r*r+(n=e-n)*n),a=e+t-i;return[i/s(a)*o(r,n),a]},r}function mt(){return ht(dt).scale(123.082).center([0,26.1441]).parallel(45)}function gt(t){function e(e,r){var n=b-r,i=n?e*t*g(n)/n:n;return[n*g(i)/t,b-n*s(i)]}return e.invert=function(e,r){var n=e*t,i=b-r,a=I(n*n+i*i),s=o(n,i);return[(a?a/g(a):1)*s/t,b-a]},e}function yt(){var t=.5,e=(0,n.U)(gt),r=e(t);return r.fraction=function(r){return arguments.length?e(t=+r):t},r.scale(158.837)}ct.invert=function(t,e){var r,n,a=st*e,o=e<0?-w:w,l=25;do{n=a-k*g(o),o-=r=(g(2*o)+2*o-_*g(n))/(2*s(2*o)+2+_*s(n)*k*s(o))}while(i(r)>v&&--l>0);return n=a-k*g(o),[t*(1/s(n)+lt/s(o))/st,n]},ft.invert=function(t,e){return[t/s(e),e]};var vt=it(1,4/_,_);function xt(){return(0,n.A)(vt).scale(152.63)}var _t=r(30021),bt=r(30915);function wt(t,e,r,n,a,l){var c,u=s(l);if(i(t)>1||i(l)>1)c=L(r*a+e*n*u);else{var h=g(t/2),f=g(l/2);c=2*C(I(h*h+e*n*f*f))}return i(c)>v?[c,o(n*g(l),e*a-r*n*u)]:[0,0]}function Tt(t,e,r){return L((t*t+e*e-r*r)/(2*t*e))}function kt(t){return t-2*_*c((t+_)/(2*_))}function At(t,e,r){for(var n,i=[[t[0],t[1],g(t[1]),s(t[1])],[e[0],e[1],g(e[1]),s(e[1])],[r[0],r[1],g(r[1]),s(r[1])]],a=i[2],o=0;o<3;++o,a=n)n=i[o],a.v=wt(n[1]-a[1],a[3],a[2],n[3],n[2],n[0]-a[0]),a.point=[0,0];var l=Tt(i[0].v[0],i[2].v[0],i[1].v[0]),c=Tt(i[0].v[0],i[1].v[0],i[2].v[0]),u=_-l;i[2].point[1]=0,i[0].point[0]=-(i[1].point[0]=i[0].v[0]/2);var h=[i[2].point[0]=i[0].point[0]+i[2].v[0]*s(l),2*(i[0].point[1]=i[1].point[1]=i[2].v[0]*g(l))];return function(t,e){var r,n=g(e),a=s(e),o=new Array(3);for(r=0;r<3;++r){var l=i[r];if(o[r]=wt(e-l[1],l[3],l[2],a,n,t-l[0]),!o[r][0])return l.point;o[r][1]=kt(o[r][1]-l.v[1])}var f=h.slice();for(r=0;r<3;++r){var p=2==r?0:r+1,d=Tt(i[r].v[0],o[r][0],o[p][0]);o[r][1]<0&&(d=-d),r?1==r?(d=c-d,f[0]-=o[r][0]*s(d),f[1]-=o[r][0]*g(d)):(d=u-d,f[0]+=o[r][0]*s(d),f[1]+=o[r][0]*g(d)):(f[0]+=o[r][0]*s(d),f[1]-=o[r][0]*g(d))}return f[0]/=3,f[1]/=3,f}}function Mt(t){return t[0]*=E,t[1]*=E,t}function St(){return Et([0,22],[45,22],[22.5,-22]).scale(380).center([22.5,2])}function Et(t,e,r){var i=(0,_t.A)({type:\"MultiPoint\",coordinates:[t,e,r]}),a=[-i[0],-i[1]],o=(0,bt.A)(a),s=At(Mt(o(t)),Mt(o(e)),Mt(o(r)));s.invert=tt(s);var l=(0,n.A)(s).rotate(a),c=l.center;return delete l.rotate,l.center=function(t){return arguments.length?c(o(t)):o.invert(c())},l.clipAngle(90)}function Ct(t,e){var r=I(1-g(e));return[2/A*t*r,A*(1-r)]}function Lt(){return(0,n.A)(Ct).scale(95.6464).center([0,30])}function It(t){var e=y(t);function r(t,r){return[t,(t?t/g(t):1)*(g(r)*s(t)-e*s(r))]}return r.invert=e?function(t,r){t&&(r*=g(t)/t);var n=s(t);return[t,2*o(I(n*n+e*e-r*r)-n,e-r)]}:function(t,e){return[t,C(t?e*y(t)/t:e)]},r}function Pt(){return ht(It).scale(249.828).clipAngle(90)}Ct.invert=function(t,e){var r=(r=e/A-1)*r;return[r>0?t*I(_/r)/2:0,C(1-r)]};var zt=I(3);function Ot(t,e){return[zt*t*(2*s(2*e/3)-1)/A,zt*A*g(e/3)]}function Dt(){return(0,n.A)(Ot).scale(156.19)}function Rt(t){var e=s(t);function r(t,r){return[t*e,g(r)/e]}return r.invert=function(t,r){return[t/e,C(r*e)]},r}function Ft(){return ht(Rt).parallel(38.58).scale(195.044)}function Bt(t){var e=s(t);function r(t,r){return[t*e,(1+e)*y(r/2)]}return r.invert=function(t,r){return[t/e,2*a(r/(1+e))]},r}function Nt(){return ht(Bt).scale(124.75)}function jt(t,e){var r=I(8/(3*_));return[r*t*(1-i(e)/_),r*e]}function Ut(){return(0,n.A)(jt).scale(165.664)}function Vt(t,e){var r=I(4-3*g(i(e)));return[2/I(6*_)*t*r,m(e)*I(2*_/3)*(2-r)]}function qt(){return(0,n.A)(Vt).scale(165.664)}function Ht(t,e){var r=I(_*(4+_));return[2/r*t*(1+I(1-4*e*e/(_*_))),4/r*e]}function Gt(){return(0,n.A)(Ht).scale(180.739)}function Zt(t,e){var r=(2+b)*g(e);e/=2;for(var n=0,a=1/0;n<10&&i(a)>v;n++){var o=s(e);e-=a=(e+g(e)*(o+2)-r)/(2*o*(1+o))}return[2/I(_*(4+_))*t*(1+s(e)),2*I(_/(4+_))*g(e)]}function Wt(){return(0,n.A)(Zt).scale(180.739)}function Yt(t,e){return[t*(1+s(e))/I(2+_),2*e/I(2+_)]}function Xt(){return(0,n.A)(Yt).scale(173.044)}function $t(t,e){for(var r=(1+b)*g(e),n=0,a=1/0;n<10&&i(a)>v;n++)e-=a=(e+g(e)-r)/(1+s(e));return r=I(2+_),[t*(1+s(e))/r,2*e/r]}function Jt(){return(0,n.A)($t).scale(173.044)}Ot.invert=function(t,e){var r=3*C(e/(zt*A));return[A*t/(zt*(2*s(2*r/3)-1)),r]},jt.invert=function(t,e){var r=I(8/(3*_)),n=e/r;return[t/(r*(1-i(n)/_)),n]},Vt.invert=function(t,e){var r=2-i(e)/I(2*_/3);return[t*I(6*_)/(2*r),m(e)*C((4-r*r)/3)]},Ht.invert=function(t,e){var r=I(_*(4+_))/2;return[t*r/(1+I(1-e*e*(4+_)/(4*_))),e*r/2]},Zt.invert=function(t,e){var r=e*I((4+_)/_)/2,n=C(r),i=s(n);return[t/(2/I(_*(4+_))*(1+i)),C((n+r*(i+2))/(2+b))]},Yt.invert=function(t,e){var r=I(2+_),n=e*r/2;return[r*t/(1+s(n)),n]},$t.invert=function(t,e){var r=1+b,n=I(r/2);return[2*t*n/(1+s(e*=n)),C((e+g(e))/r)]};var Kt=3+2*k;function Qt(t,e){var r=g(t/=2),n=s(t),i=I(s(e)),o=s(e/=2),l=g(e)/(o+k*n*i),c=I(2/(1+l*l)),h=I((k*o+(n+r)*i)/(k*o+(n-r)*i));return[Kt*(c*(h-1/h)-2*u(h)),Kt*(c*l*(h+1/h)-2*a(l))]}function te(){return(0,n.A)(Qt).scale(62.5271)}Qt.invert=function(t,e){if(!(r=j.invert(t/1.2,1.065*e)))return null;var r,n=r[0],o=r[1],l=20;t/=Kt,e/=Kt;do{var c=n/2,p=o/2,d=g(c),m=s(c),y=g(p),x=s(p),_=s(o),w=I(_),A=y/(x+k*m*w),M=A*A,S=I(2/(1+M)),E=(k*x+(m+d)*w)/(k*x+(m-d)*w),C=I(E),L=C-1/C,P=C+1/C,z=S*L-2*u(C)-t,O=S*A*P-2*a(A)-e,D=y&&T*w*d*M/y,R=(k*m*x+w)/(2*(x+k*m*w)*(x+k*m*w)*w),F=-.5*A*S*S*S,B=F*D,N=F*R,U=(U=2*x+k*w*(m-d))*U*C,V=(k*m*x*w+_)/U,q=-k*d*y/(w*U),H=L*B-2*V/C+S*(V+V/E),G=L*N-2*q/C+S*(q+q/E),Z=A*P*B-2*D/(1+M)+S*P*D+S*A*(V-V/E),W=A*P*N-2*R/(1+M)+S*P*R+S*A*(q-q/E),Y=G*Z-W*H;if(!Y)break;var X=(O*G-z*W)/Y,$=(z*Z-O*H)/Y;n-=X,o=h(-b,f(b,o-$))}while((i(X)>v||i($)>v)&&--l>0);return i(i(o)-b)<v?[0,o]:l&&[n,o]};var ee=s(35*E);function re(t,e){var r=y(e/2);return[t*ee*I(1-r*r),(1+ee)*r]}function ne(){return(0,n.A)(re).scale(137.152)}function ie(t,e){var r=e/2,n=s(r);return[2*t/A*s(e)*n*n,A*y(r)]}function ae(){return(0,n.A)(ie).scale(135.264)}function oe(t){var e=1-t,r=i(_,0)[0]-i(-_,0)[0],n=I(2*(i(0,b)[1]-i(0,-b)[1])/r);function i(r,n){var i=s(n),a=g(n);return[i/(e+t*i)*r,e*n+t*a]}function a(t,e){var r=i(t,e);return[r[0]*n,r[1]/n]}function o(t){return a(0,t)[1]}return a.invert=function(r,i){var a=Q(o,i);return[r/n*(t+e/s(a)),a]},a}function se(){var t=.5,e=(0,n.U)(oe),r=e(t);return r.alpha=function(r){return arguments.length?e(t=+r):t},r.scale(168.725)}re.invert=function(t,e){var r=e/(1+ee);return[t&&t/(ee*I(1-r*r)),2*a(r)]},ie.invert=function(t,e){var r=a(e/A),n=s(r),i=2*r;return[t*A/2/(s(i)*n*n),i]};var le=r(53253),ce=r(18139);function ue(t){return[t[0]/2,C(y(t[1]/2*E))*S]}function he(t){return[2*t[0],2*a(g(t[1]*E))*S]}function fe(t){null==t&&(t=le.A);var e=t(),r=(0,ce.A)().scale(S).precision(0).clipAngle(null).translate([0,0]);function n(t){return e(ue(t))}function i(t){n[t]=function(){return arguments.length?(e[t].apply(e,arguments),n):e[t]()}}return e.invert&&(n.invert=function(t){return he(e.invert(t))}),n.stream=function(t){var n=e.stream(t),i=r.stream({point:function(t,e){n.point(t/2,C(y(-e/2*E))*S)},lineStart:function(){n.lineStart()},lineEnd:function(){n.lineEnd()},polygonStart:function(){n.polygonStart()},polygonEnd:function(){n.polygonEnd()}});return i.sphere=n.sphere,i},n.rotate=function(t){return arguments.length?(r.rotate(t),n):r.rotate()},n.center=function(t){return arguments.length?(e.center(ue(t)),n):he(e.center())},i(\"angle\"),i(\"clipAngle\"),i(\"clipExtent\"),i(\"fitExtent\"),i(\"fitHeight\"),i(\"fitSize\"),i(\"fitWidth\"),i(\"scale\"),i(\"translate\"),i(\"precision\"),n.scale(249.5)}function pe(t,e){var r=2*_/e,n=t*t;function a(e,a){var l=(0,Z.j)(e,a),c=l[0],u=l[1],h=c*c+u*u;if(h>n){var f=I(h),p=o(u,c),m=r*d(p/r),y=p-m,x=t*s(y),w=(t*g(y)-y*g(x))/(b-x),T=de(y,w),k=(_-t)/me(T,x,_);c=f;var A,M=50;do{c-=A=(t+me(T,x,c)*k-f)/(T(c)*k)}while(i(A)>v&&--M>0);u=y*g(c),c<b&&(u-=w*(c-b));var S=g(m),E=s(m);l[0]=c*E-u*S,l[1]=c*S+u*E}return l}return a.invert=function(e,a){var l=e*e+a*a;if(l>n){var c=I(l),u=o(a,e),h=r*d(u/r),f=u-h;e=c*s(f),a=c*g(f);for(var p=e-b,m=g(e),y=a/m,v=e<b?1/0:0,w=10;;){var T=t*g(y),k=t*s(y),A=g(k),M=b-k,S=(T-y*A)/M,E=de(y,S);if(i(v)<x||! --w)break;y-=v=(y*m-S*p-a)/(m-2*p*(M*(k+y*T*s(k)-A)-T*(T-y*A))/(M*M))}e=(c=t+me(E,k,e)*(_-t)/me(E,k,_))*s(u=h+y),a=c*g(u)}return Z.j.invert(e,a)},a}function de(t,e){return function(r){var n=t*s(r);return r<b&&(n-=e),I(1+n*n)}}function me(t,e,r){for(var n=(r-e)/50,i=t(e)+t(r),a=1,o=e;a<50;++a)i+=2*t(o+=n);return.5*i*n}function ge(){var t=6,e=30*E,r=s(e),i=g(e),a=(0,n.U)(pe),l=a(e,t),c=l.stream,u=-s(.01*E),h=g(.01*E);return l.radius=function(n){return arguments.length?(r=s(e=n*E),i=g(e),a(e,t)):e*S},l.lobes=function(r){return arguments.length?a(e,t=+r):t},l.stream=function(e){var n=l.rotate(),a=c(e),f=(l.rotate([0,0]),c(e));return l.rotate(n),a.sphere=function(){f.polygonStart(),f.lineStart();for(var e=0,n=2*_/t,a=0;e<t;++e,a-=n)f.point(o(h*s(a),u)*S,C(h*g(a))*S),f.point(o(i*s(a-n/2),r)*S,C(i*g(a-n/2))*S);f.lineEnd(),f.polygonEnd()},a},l.rotate([90,-40]).scale(91.7095).clipAngle(179.999)}function ye(t,e,r,n,a,o,l,c){function u(i,u){if(!u)return[t*i/_,0];var h=u*u,f=t+h*(e+h*(r+h*n)),p=u*(a-1+h*(o-c+h*l)),d=(f*f+p*p)/(2*p),m=i*C(f/d)/_;return[d*g(m),u*(1+h*c)+d*(1-s(m))]}return arguments.length<8&&(c=0),u.invert=function(u,h){var f,p,d=_*u/t,m=h,y=50;do{var x=m*m,b=t+x*(e+x*(r+x*n)),w=m*(a-1+x*(o-c+x*l)),T=b*b+w*w,k=2*w,A=T/k,M=A*A,S=C(b/A)/_,E=d*S,L=b*b,P=(2*e+x*(4*r+6*x*n))*m,z=a+x*(3*o+5*x*l),O=(2*(b*P+w*(z-1))*k-T*(2*(z-1)))/(k*k),D=s(E),R=g(E),F=A*D,B=A*R,N=d/_*(1/I(1-L/M))*(P*A-b*O)/M,j=B-u,U=m*(1+x*c)+A-F-h,V=O*R+F*N,q=F*S,H=1+O-(O*D-B*N),G=B*S,Z=V*G-H*q;if(!Z)break;d-=f=(U*V-j*H)/Z,m-=p=(j*G-U*q)/Z}while((i(f)>v||i(p)>v)&&--y>0);return[d,m]},u}var ve=ye(2.8284,-1.6988,.75432,-.18071,1.76003,-.38914,.042555);function xe(){return(0,n.A)(ve).scale(149.995)}var _e=ye(2.583819,-.835827,.170354,-.038094,1.543313,-.411435,.082742);function be(){return(0,n.A)(_e).scale(153.93)}var we=ye(5/6*_,-.62636,-.0344,0,1.3493,-.05524,0,.045);function Te(){return(0,n.A)(we).scale(130.945)}function ke(t,e){var r=t*t,n=e*e;return[t*(1-.162388*n)*(.87-952426e-9*r*r),e*(1+n/12)]}function Ae(){return(0,n.A)(ke).scale(131.747)}ke.invert=function(t,e){var r,n=t,a=e,o=50;do{var s=a*a;a-=r=(a*(1+s/12)-e)/(1+s/4)}while(i(r)>v&&--o>0);o=50,t/=1-.162388*s;do{var l=(l=n*n)*l;n-=r=(n*(.87-952426e-9*l)-t)/(.87-.00476213*l)}while(i(r)>v&&--o>0);return[n,a]};var Me=ye(2.6516,-.76534,.19123,-.047094,1.36289,-.13965,.031762);function Se(){return(0,n.A)(Me).scale(131.087)}function Ee(t){var e=t(b,0)[0]-t(-b,0)[0];function r(r,n){var i=r>0?-.5:.5,a=t(r+i*_,n);return a[0]-=i*e,a}return t.invert&&(r.invert=function(r,n){var i=r>0?-.5:.5,a=t.invert(r+i*e,n),o=a[0]-i*_;return o<-_?o+=2*_:o>_&&(o-=2*_),a[0]=o,a}),r}function Ce(t,e){var r=m(t),n=m(e),a=s(e),l=s(t)*a,c=g(t)*a,u=g(n*e);t=i(o(c,u)),e=C(l),i(t-b)>v&&(t%=b);var h=function(t,e){if(e===b)return[0,0];var r,n,a=g(e),o=a*a,l=o*o,c=1+l,u=1+3*l,h=1-l,f=C(1/I(c)),p=h+o*c*f,d=(1-a)/p,m=I(d),y=d*c,x=I(y),w=m*h;if(0===t)return[0,-(w+o*x)];var T,k=s(e),A=1/k,M=2*a*k,S=(-p*k-(1-a)*((-3*o+f*u)*M))/(p*p),E=-A*M,L=-A*(o*c*S+d*u*M),P=-2*A*(h*(.5*S/m)-2*o*m*M),z=4*t/_;if(t>.222*_||e<_/4&&t>.175*_){if(r=(w+o*I(y*(1+l)-w*w))/(1+l),t>_/4)return[r,r];var O=r,D=.5*r;r=.5*(D+O),n=50;do{var R=r*(P+E*I(y-r*r))+L*C(r/x)-z;if(!R)break;R<0?D=r:O=r,r=.5*(D+O)}while(i(O-D)>v&&--n>0)}else{r=v,n=25;do{var F=r*r,B=I(y-F),N=P+E*B,j=r*N+L*C(r/x)-z;r-=T=B?j/(N+(L-E*F)/B):0}while(i(T)>v&&--n>0)}return[r,-w-o*I(y-r*r)]}(t>_/4?b-t:t,e);return t>_/4&&(u=h[0],h[0]=-h[1],h[1]=-u),h[0]*=r,h[1]*=-n,h}function Le(){return(0,n.A)(Ee(Ce)).scale(239.75)}function Ie(t,e){var r,n,o,c,u,h;if(e<v)return[(c=g(t))-(r=e*(t-c*(n=s(t)))/4)*n,n+r*c,1-e*c*c/2,t-r];if(e>=1-v)return r=(1-e)/4,o=1/(n=z(t)),[(c=((h=l(2*(h=t)))-1)/(h+1))+r*((u=n*P(t))-t)/(n*n),o-r*c*o*(u-t),o+r*c*o*(u+t),2*a(l(t))-b+r*(u-t)/n];var f=[1,0,0,0,0,0,0,0,0],p=[I(e),0,0,0,0,0,0,0,0],d=0;for(n=I(1-e),u=1;i(p[d]/f[d])>v&&d<8;)r=f[d++],p[d]=(r-n)/2,f[d]=(r+n)/2,n=I(r*n),u*=2;o=u*f[d]*t;do{o=(C(c=p[d]*g(n=o)/f[d])+o)/2}while(--d);return[g(o),c=s(o),c/s(o-n),o]}function Pe(t,e){if(!e)return t;if(1===e)return u(y(t/2+w));for(var r=1,n=I(1-e),o=I(e),s=0;i(o)>v;s++){if(t%_){var l=a(n*y(t)/r);l<0&&(l+=_),t+=l+~~(t/_)*_}else t+=t;o=(r+n)/2,n=I(r*n),o=((r=o)-n)/2}return t/(p(2,s)*r)}function ze(t,e){var r=(k-1)/(k+1),n=I(1-r*r),c=Pe(b,n*n),h=u(y(_/4+i(e)/2)),f=l(-1*h)/I(r),p=function(t,e){var r=t*t,n=e+1,i=1-r-e*e;return[.5*((t>=0?b:-b)-o(i,2*t)),-.25*u(i*i+4*r)+.5*u(n*n+r)]}(f*s(-1*t),f*g(-1*t)),d=function(t,e,r){var n=i(t),o=P(i(e));if(n){var s=1/g(n),l=1/(y(n)*y(n)),c=-(l+r*(o*o*s*s)-1+r),u=(-c+I(c*c-(r-1)*l*4))/2;return[Pe(a(1/I(u)),r)*m(t),Pe(a(I((u/l-1)/r)),1-r)*m(e)]}return[0,Pe(a(o),1-r)*m(e)]}(p[0],p[1],n*n);return[-d[1],(e>=0?1:-1)*(.5*c-d[0])]}function Oe(){return(0,n.A)(Ee(ze)).scale(151.496)}Ce.invert=function(t,e){i(t)>1&&(t=2*m(t)-t),i(e)>1&&(e=2*m(e)-e);var r=m(t),n=m(e),a=-r*t,l=-n*e,c=l/a<1,u=function(t,e){for(var r=0,n=1,a=.5,o=50;;){var l=a*a,c=I(a),u=C(1/I(1+l)),h=1-l+a*(1+l)*u,f=(1-c)/h,p=I(f),d=f*(1+l),m=p*(1-l),g=I(d-t*t),y=e+m+a*g;if(i(n-r)<x||0==--o||0===y)break;y>0?r=a:n=a,a=.5*(r+n)}if(!o)return null;var v=C(c),b=s(v),w=1/b,T=2*c*b,k=(-h*b-(-3*a+u*(1+3*l))*T*(1-c))/(h*h);return[_/4*(t*(-2*w*((1-l)*(.5*k/p)-2*a*p*T)+-w*T*g)+-w*(a*(1+l)*k+f*(1+3*l)*T)*C(t/I(d))),v]}(c?l:a,c?a:l),h=u[0],f=u[1],p=s(f);return c&&(h=-b-h),[r*(o(g(h)*p,-g(f))+_),n*C(s(h)*p)]},ze.invert=function(t,e){var r,n,i,s,c,h,f=(k-1)/(k+1),p=I(1-f*f),d=(n=-t,i=p*p,(r=.5*Pe(b,p*p)-e)?(s=Ie(r,i),n?(h=(c=Ie(n,1-i))[1]*c[1]+i*s[0]*s[0]*c[0]*c[0],[[s[0]*c[2]/h,s[1]*s[2]*c[0]*c[1]/h],[s[1]*c[1]/h,-s[0]*s[2]*c[0]*c[2]/h],[s[2]*c[1]*c[2]/h,-i*s[0]*s[1]*c[0]/h]]):[[s[0],0],[s[1],0],[s[2],0]]):[[0,(c=Ie(n,1-i))[0]/c[1]],[1/c[1],0],[c[2]/c[1],0]]),m=function(t,e){var r=e[0]*e[0]+e[1]*e[1];return[(t[0]*e[0]+t[1]*e[1])/r,(t[1]*e[0]-t[0]*e[1])/r]}(d[0],d[1]);return[o(m[1],m[0])/-1,2*a(l(-.5*u(f*m[0]*m[0]+f*m[1]*m[1])))-b]};var De=r(39127);function Re(t){var e=g(t),r=s(t),n=Fe(t);function a(t,a){var o=n(t,a);t=o[0],a=o[1];var l=g(a),c=s(a),u=s(t),h=L(e*l+r*c*u),f=g(h),p=i(f)>v?h/f:1;return[p*r*g(t),(i(t)>b?p:-p)*(e*c-r*l*u)]}return n.invert=Fe(-t),a.invert=function(t,r){var i=I(t*t+r*r),a=-g(i),l=s(i),c=i*l,u=-r*a,h=i*e,f=I(c*c+u*u-h*h),p=o(c*h+u*f,u*h-c*f),d=(i>b?-1:1)*o(t*a,i*s(p)*l+r*g(p)*a);return n.invert(d,p)},a}function Fe(t){var e=g(t),r=s(t);return function(t,n){var i=s(n),a=s(t)*i,l=g(t)*i,c=g(n);return[o(l,a*r-c*e),C(c*r+a*e)]}}function Be(){var t=0,e=(0,n.U)(Re),r=e(t),i=r.rotate,a=r.stream,o=(0,De.A)();return r.parallel=function(n){if(!arguments.length)return t*S;var i=r.rotate();return e(t=n*E).rotate(i)},r.rotate=function(e){return arguments.length?(i.call(r,[e[0],e[1]-t*S]),o.center([-e[0],-e[1]]),r):((e=i.call(r))[1]+=t*S,e)},r.stream=function(t){return(t=a(t)).sphere=function(){t.polygonStart();var e,r=o.radius(89.99)().coordinates[0],n=r.length-1,i=-1;for(t.lineStart();++i<n;)t.point((e=r[i])[0],e[1]);for(t.lineEnd(),n=(r=o.radius(90.01)().coordinates[0]).length-1,t.lineStart();--i>=0;)t.point((e=r[i])[0],e[1]);t.lineEnd(),t.polygonEnd()},t},r.scale(79.4187).parallel(45).clipAngle(179.999)}var Ne=r(29725),je=r(20465),Ue=C(1-1/3)*S,Ve=Rt(0);function qe(t){var e=Ue*E,r=Ct(_,e)[0]-Ct(-_,e)[0],n=Ve(0,e)[1],a=Ct(0,e)[1],o=A-a,s=M/t,l=4/M,u=n+o*o*4/M;function p(p,d){var m,g=i(d);if(g>e){var y=f(t-1,h(0,c((p+_)/s)));(m=Ct(p+=_*(t-1)/t-y*s,g))[0]=m[0]*M/r-M*(t-1)/(2*t)+y*M/t,m[1]=n+4*(m[1]-a)*o/M,d<0&&(m[1]=-m[1])}else m=Ve(p,d);return m[0]*=l,m[1]/=u,m}return p.invert=function(e,p){e/=l;var d=i(p*=u);if(d>n){var m=f(t-1,h(0,c((e+_)/s)));e=(e+_*(t-1)/t-m*s)*r/M;var g=Ct.invert(e,.25*(d-n)*M/o+a);return g[0]-=_*(t-1)/t-m*s,p<0&&(g[1]=-g[1]),g}return Ve.invert(e,p)},p}function He(t,e){return[t,1&e?90-v:Ue]}function Ge(t,e){return[t,1&e?-90+v:-Ue]}function Ze(t){return[t[0]*(1-v),t[1]]}function We(){var t=4,e=(0,n.U)(qe),r=e(t),i=r.stream;return r.lobes=function(r){return arguments.length?e(t=+r):t},r.stream=function(e){var n=r.rotate(),a=i(e),o=(r.rotate([0,0]),i(e));return r.rotate(n),a.sphere=function(){var e,r;(0,je.A)((e=180/t,r=[].concat((0,Ne.y1)(-180,180+e/2,e).map(He),(0,Ne.y1)(180,-180-e/2,-e).map(Ge)),{type:\"Polygon\",coordinates:[180===e?r.map(Ze):r]}),o)},a},r.scale(239.75)}function Ye(t){var e,r=1+t,n=C(g(1/r)),a=2*I(_/(e=_+4*n*r)),l=.5*a*(r+I(t*(2+t))),c=t*t,u=r*r;function h(h,f){var p,d,m=1-g(f);if(m&&m<2){var y,v=b-f,w=25;do{var T=g(v),k=s(v),A=n+o(T,r-k),M=1+u-2*r*k;v-=y=(v-c*n-r*T+M*A-.5*m*e)/(2*r*T*A)}while(i(y)>x&&--w>0);p=a*I(M),d=h*A/_}else p=a*(t+m),d=h*n/_;return[p*g(d),l-p*s(d)]}return h.invert=function(t,i){var s=t*t+(i-=l)*i,h=(1+u-s/(a*a))/(2*r),f=L(h),p=g(f),d=n+o(p,r-h);return[C(t/I(s))*_/d,C(1-2*(f-c*n-r*p+(1+u-2*r*h)*d)/e)]},h}function Xe(){var t=1,e=(0,n.U)(Ye),r=e(t);return r.ratio=function(r){return arguments.length?e(t=+r):t},r.scale(167.774).center([0,18.67])}var $e=.7109889596207567,Je=.0528035274542;function Ke(t,e){return e>-$e?((t=at(t,e))[1]+=Je,t):ft(t,e)}function Qe(){return(0,n.A)(Ke).rotate([-20,-55]).scale(164.263).center([0,-5.4036])}function tr(t,e){return i(e)>$e?((t=at(t,e))[1]-=e>0?Je:-Je,t):ft(t,e)}function er(){return(0,n.A)(tr).scale(152.63)}function rr(t,e,r,n){var i=I(4*_/(2*r+(1+t-e/2)*g(2*r)+(t+e)/2*g(4*r)+e/2*g(6*r))),a=I(n*g(r)*I((1+t*s(2*r)+e*s(4*r))/(1+t+e))),o=r*c(1);function l(r){return I(1+t*s(2*r)+e*s(4*r))}function c(n){var i=n*r;return(2*i+(1+t-e/2)*g(2*i)+(t+e)/2*g(4*i)+e/2*g(6*i))/r}function u(t){return l(t)*g(t)}var h=function(t,e){var n=r*Q(c,o*g(e)/r,e/_);isNaN(n)&&(n=r*m(e));var u=i*l(n);return[u*a*t/_*s(n),u/a*g(n)]};return h.invert=function(t,e){var n=Q(u,e*a/i);return[t*_/(s(n)*i*a*l(n)),C(r*c(n/r)/o)]},0===r&&(i=I(n/_),(h=function(t,e){return[t*i,g(e)/i]}).invert=function(t,e){return[t/i,C(e*i)]}),h}function nr(){var t=1,e=0,r=45*E,i=2,a=(0,n.U)(rr),o=a(t,e,r,i);return o.a=function(n){return arguments.length?a(t=+n,e,r,i):t},o.b=function(n){return arguments.length?a(t,e=+n,r,i):e},o.psiMax=function(n){return arguments.length?a(t,e,r=+n*E,i):r*S},o.ratio=function(n){return arguments.length?a(t,e,r,i=+n):i},o.scale(180.739)}function ir(t,e,r,n,i,a,o,s,l,c,u){if(u.nanEncountered)return NaN;var h,f,p,d,m,g,y,v,x,_;if(f=t(e+.25*(h=r-e)),p=t(r-.25*h),isNaN(f))u.nanEncountered=!0;else{if(!isNaN(p))return _=((g=(d=h*(n+4*f+i)/12)+(m=h*(i+4*p+a)/12))-o)/15,c>l?(u.maxDepthCount++,g+_):Math.abs(_)<s?g+_:(v=ir(t,e,y=e+.5*h,n,f,i,d,.5*s,l,c+1,u),isNaN(v)?(u.nanEncountered=!0,NaN):(x=ir(t,y,r,i,p,a,m,.5*s,l,c+1,u),isNaN(x)?(u.nanEncountered=!0,NaN):v+x));u.nanEncountered=!0}}function ar(t,e,r,n,i){void 0===n&&(n=1e-8),void 0===i&&(i=20);var a=t(e),o=t(.5*(e+r)),s=t(r);return ir(t,e,r,a,o,s,(a+4*o+s)*(r-e)/6,n,i,1,{maxDepthCount:0,nanEncountered:!1})}function or(t,e,r){function n(r){return t+(1-t)*p(1-p(r,e),1/e)}function a(t){return ar(n,0,t,1e-4)}for(var o=1/a(1),s=1e3,l=(1+1e-8)*o,c=[],u=0;u<=s;u++)c.push(a(u/s)*l);function h(t){var e=0,r=s,n=500;do{c[n]>t?r=n:e=n,n=e+r>>1}while(n>e);var i=c[n+1]-c[n];return i&&(i=(t-c[n+1])/i),(n+1+i)/s}var f=2*h(1)/_*o/r,d=function(t,e){var r=h(i(g(e))),a=n(r)*t;return r/=f,[a,e>=0?r:-r]};return d.invert=function(t,e){var r;return i(e*=f)<1&&(r=m(e)*C(a(i(e))*o)),[t/n(i(e)),r]},d}function sr(){var t=0,e=2.5,r=1.183136,i=(0,n.U)(or),a=i(t,e,r);return a.alpha=function(n){return arguments.length?i(t=+n,e,r):t},a.k=function(n){return arguments.length?i(t,e=+n,r):e},a.gamma=function(n){return arguments.length?i(t,e,r=+n):r},a.scale(152.63)}function lr(t,e){return i(t[0]-e[0])<v&&i(t[1]-e[1])<v}function cr(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function ur(t,e,r){var i,a;function o(r,n){for(var i=n<0?-1:1,a=e[+(n<0)],o=0,s=a.length-1;o<s&&r>a[o][2][0];++o);var l=t(r-a[o][1][0],n);return l[0]+=t(a[o][1][0],i*n>i*a[o][0][1]?a[o][0][1]:n)[0],l}r?o.invert=r(o):t.invert&&(o.invert=function(r,n){for(var i=a[+(n<0)],s=e[+(n<0)],l=0,c=i.length;l<c;++l){var u=i[l];if(u[0][0]<=r&&r<u[1][0]&&u[0][1]<=n&&n<u[1][1]){var h=t.invert(r-t(s[l][1][0],0)[0],n);return h[0]+=s[l][1][0],lr(o(h[0],h[1]),[r,n])?h:null}}});var s=(0,n.A)(o),l=s.stream;return s.stream=function(t){var e=s.rotate(),r=l(t),n=(s.rotate([0,0]),l(t));return s.rotate(e),r.sphere=function(){(0,je.A)(i,n)},r},s.lobes=function(r){return arguments.length?(i=function(t){var e,r,n,i,a,o,s,l=[],c=t[0].length;for(s=0;s<c;++s)r=(e=t[0][s])[0][0],n=e[0][1],i=e[1][1],a=e[2][0],o=e[2][1],l.push(cr([[r+v,n+v],[r+v,i-v],[a-v,i-v],[a-v,o+v]],30));for(s=t[1].length-1;s>=0;--s)r=(e=t[1][s])[0][0],n=e[0][1],i=e[1][1],a=e[2][0],o=e[2][1],l.push(cr([[a-v,o-v],[a-v,i+v],[r+v,i+v],[r+v,n-v]],30));return{type:\"Polygon\",coordinates:[(0,Ne.Am)(l)]}}(r),e=r.map((function(t){return t.map((function(t){return[[t[0][0]*E,t[0][1]*E],[t[1][0]*E,t[1][1]*E],[t[2][0]*E,t[2][1]*E]]}))})),a=e.map((function(e){return e.map((function(e){var r,n=t(e[0][0],e[0][1])[0],i=t(e[2][0],e[2][1])[0],a=t(e[1][0],e[0][1])[1],o=t(e[1][0],e[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]}))})),s):e.map((function(t){return t.map((function(t){return[[t[0][0]*S,t[0][1]*S],[t[1][0]*S,t[1][1]*S],[t[2][0]*S,t[2][1]*S]]}))}))},null!=e&&s.lobes(e),s}Ke.invert=function(t,e){return e>-$e?at.invert(t,e-Je):ft.invert(t,e)},tr.invert=function(t,e){return i(e)>$e?at.invert(t,e+(e>0?Je:-Je)):ft.invert(t,e)};var hr=[[[[-180,0],[-100,90],[-40,0]],[[-40,0],[30,90],[180,0]]],[[[-180,0],[-160,-90],[-100,0]],[[-100,0],[-60,-90],[-20,0]],[[-20,0],[20,-90],[80,0]],[[80,0],[140,-90],[180,0]]]];function fr(){return ur(ct,hr).scale(160.857)}var pr=[[[[-180,0],[-100,90],[-40,0]],[[-40,0],[30,90],[180,0]]],[[[-180,0],[-160,-90],[-100,0]],[[-100,0],[-60,-90],[-20,0]],[[-20,0],[20,-90],[80,0]],[[80,0],[140,-90],[180,0]]]];function dr(){return ur(tr,pr).scale(152.63)}var mr=[[[[-180,0],[-100,90],[-40,0]],[[-40,0],[30,90],[180,0]]],[[[-180,0],[-160,-90],[-100,0]],[[-100,0],[-60,-90],[-20,0]],[[-20,0],[20,-90],[80,0]],[[80,0],[140,-90],[180,0]]]];function gr(){return ur(at,mr).scale(169.529)}var yr=[[[[-180,0],[-90,90],[0,0]],[[0,0],[90,90],[180,0]]],[[[-180,0],[-90,-90],[0,0]],[[0,0],[90,-90],[180,0]]]];function vr(){return ur(at,yr).scale(169.529).rotate([20,0])}var xr=[[[[-180,35],[-30,90],[0,35]],[[0,35],[30,90],[180,35]]],[[[-180,-10],[-102,-90],[-65,-10]],[[-65,-10],[5,-90],[77,-10]],[[77,-10],[103,-90],[180,-10]]]];function _r(){return ur(Ke,xr,tt).rotate([-20,-55]).scale(164.263).center([0,-5.4036])}var br=[[[[-180,0],[-110,90],[-40,0]],[[-40,0],[0,90],[40,0]],[[40,0],[110,90],[180,0]]],[[[-180,0],[-110,-90],[-40,0]],[[-40,0],[0,-90],[40,0]],[[40,0],[110,-90],[180,0]]]];function wr(){return ur(ft,br).scale(152.63).rotate([-20,0])}function Tr(t,e){return[3/M*t*I(_*_/3-e*e),e]}function kr(){return(0,n.A)(Tr).scale(158.837)}function Ar(t){function e(e,r){if(i(i(r)-b)<v)return[0,r<0?-2:2];var n=g(r),a=p((1+n)/(1-n),t/2),o=.5*(a+1/a)+s(e*=t);return[2*g(e)/o,(a-1/a)/o]}return e.invert=function(e,r){var n=i(r);if(i(n-2)<v)return e?null:[0,m(r)*b];if(n>2)return null;var a=(e/=2)*e,s=(r/=2)*r,l=2*r/(1+a+s);return l=p((1+l)/(1-l),1/t),[o(2*e,1-a-s)/t,C((l-1)/(l+1))]},e}function Mr(){var t=.5,e=(0,n.U)(Ar),r=e(t);return r.spacing=function(r){return arguments.length?e(t=+r):t},r.scale(124.75)}Tr.invert=function(t,e){return[M/3*t/I(_*_/3-e*e),e]};var Sr=_/k;function Er(t,e){return[t*(1+I(s(e)))/2,e/(s(e/2)*s(t/6))]}function Cr(){return(0,n.A)(Er).scale(97.2672)}function Lr(t,e){var r=t*t,n=e*e;return[t*(.975534+n*(-.0143059*r-.119161+-.0547009*n)),e*(1.00384+r*(.0802894+-.02855*n+199025e-9*r)+n*(.0998909+-.0491032*n))]}function Ir(){return(0,n.A)(Lr).scale(139.98)}function Pr(t,e){return[g(t)/s(e),y(e)*s(t)]}function zr(){return(0,n.A)(Pr).scale(144.049).clipAngle(89.999)}function Or(t){var e=s(t),r=y(w+t/2);function n(n,a){var o=a-t,s=i(o)<v?n*e:i(s=w+a/2)<v||i(i(s)-b)<v?0:n*o/u(y(s)/r);return[s,o]}return n.invert=function(n,a){var o,s=a+t;return[i(a)<v?n/e:i(o=w+s/2)<v||i(i(o)-b)<v?0:n*u(y(o)/r)/a,s]},n}function Dr(){return ht(Or).parallel(40).scale(158.837)}function Rr(t,e){return[t,1.25*u(y(w+.4*e))]}function Fr(){return(0,n.A)(Rr).scale(108.318)}function Br(t){var e=t.length-1;function r(r,n){for(var i,a=s(n),o=2/(1+a*s(r)),l=o*a*g(r),c=o*g(n),u=e,h=t[u],f=h[0],p=h[1];--u>=0;)f=(h=t[u])[0]+l*(i=f)-c*p,p=h[1]+l*p+c*i;return[f=l*(i=f)-c*p,p=l*p+c*i]}return r.invert=function(r,n){var l=20,c=r,u=n;do{for(var h,f=e,p=t[f],d=p[0],m=p[1],y=0,x=0;--f>=0;)y=d+c*(h=y)-u*x,x=m+c*x+u*h,d=(p=t[f])[0]+c*(h=d)-u*m,m=p[1]+c*m+u*h;var _,b,w=(y=d+c*(h=y)-u*x)*y+(x=m+c*x+u*h)*x;c-=_=((d=c*(h=d)-u*m-r)*y+(m=c*m+u*h-n)*x)/w,u-=b=(m*y-d*x)/w}while(i(_)+i(b)>v*v&&--l>0);if(l){var T=I(c*c+u*u),k=2*a(.5*T),A=g(k);return[o(c*A,T*s(k)),T?C(u*A/T):0]}},r}Er.invert=function(t,e){var r=i(t),n=i(e),a=v,o=b;n<Sr?o*=n/Sr:a+=6*L(Sr/n);for(var l=0;l<25;l++){var c=g(o),u=I(s(o)),h=g(o/2),f=s(o/2),p=g(a/6),d=s(a/6),m=.5*a*(1+u)-r,y=o/(f*d)-n,x=u?-.25*a*c/u:0,_=.5*(1+u),w=(1+.5*o*h/f)/(f*d),T=o/f*(p/6)/(d*d),k=x*T-w*_,A=(m*T-y*_)/k,M=(y*x-m*w)/k;if(o-=A,a-=M,i(A)<v&&i(M)<v)break}return[t<0?-a:a,e<0?-o:o]},Lr.invert=function(t,e){var r=m(t)*_,n=e/2,a=50;do{var o=r*r,s=n*n,l=r*n,c=r*(.975534+s*(-.0143059*o-.119161+-.0547009*s))-t,u=n*(1.00384+o*(.0802894+-.02855*s+199025e-9*o)+s*(.0998909+-.0491032*s))-e,h=.975534-s*(.119161+3*o*.0143059+.0547009*s),f=-l*(.238322+.2188036*s+.0286118*o),p=l*(.1605788+7961e-7*o+-.0571*s),d=1.00384+o*(.0802894+199025e-9*o)+s*(3*(.0998909-.02855*o)-.245516*s),g=f*p-d*h,y=(u*f-c*d)/g,x=(c*p-u*h)/g;r-=y,n-=x}while((i(y)>v||i(x)>v)&&--a>0);return a&&[r,n]},Pr.invert=function(t,e){var r=t*t,n=e*e+1,i=r+n,a=t?T*I((i-I(i*i-4*r))/r):1/I(n);return[C(t*a),m(e)*L(a)]},Rr.invert=function(t,e){return[t,2.5*a(l(.8*e))-.625*_]};var Nr=[[.9972523,0],[.0052513,-.0041175],[.0074606,.0048125],[-.0153783,-.1968253],[.0636871,-.1408027],[.3660976,-.2937382]],jr=[[.98879,0],[0,0],[-.050909,0],[0,0],[.075528,0]],Ur=[[.984299,0],[.0211642,.0037608],[-.1036018,-.0575102],[-.0329095,-.0320119],[.0499471,.1223335],[.026046,.0899805],[7388e-7,-.1435792],[.0075848,-.1334108],[-.0216473,.0776645],[-.0225161,.0853673]],Vr=[[.9245,0],[0,0],[.01943,0]],qr=[[.721316,0],[0,0],[-.00881625,-.00617325]];function Hr(){return Xr(Nr,[152,-64]).scale(1400).center([-160.908,62.4864]).clipAngle(30).angle(7.8)}function Gr(){return Xr(jr,[95,-38]).scale(1e3).clipAngle(55).center([-96.5563,38.8675])}function Zr(){return Xr(Ur,[120,-45]).scale(359.513).clipAngle(55).center([-117.474,53.0628])}function Wr(){return Xr(Vr,[-20,-18]).scale(209.091).center([20,16.7214]).clipAngle(82)}function Yr(){return Xr(qr,[165,10]).scale(250).clipAngle(130).center([-165,-10])}function Xr(t,e){var r=(0,n.A)(Br(t)).rotate(e).clipAngle(90),i=(0,bt.A)(e),a=r.center;return delete r.rotate,r.center=function(t){return arguments.length?a(i(t)):i.invert(a())},r}var $r=I(6),Jr=I(7);function Kr(t,e){var r=C(7*g(e)/(3*$r));return[$r*t*(2*s(2*r/3)-1)/Jr,9*g(r/3)/Jr]}function Qr(){return(0,n.A)(Kr).scale(164.859)}function tn(t,e){for(var r,n=(1+T)*g(e),a=e,o=0;o<25&&(a-=r=(g(a/2)+g(a)-n)/(.5*s(a/2)+s(a)),!(i(r)<v));o++);return[t*(1+2*s(a)/s(a/2))/(3*k),2*I(3)*g(a/2)/I(2+k)]}function en(){return(0,n.A)(tn).scale(188.209)}function rn(t,e){for(var r,n=I(6/(4+_)),a=(1+_/4)*g(e),o=e/2,l=0;l<25&&(o-=r=(o/2+g(o)-a)/(.5+s(o)),!(i(r)<v));l++);return[n*(.5+s(o))*t/1.5,n*o]}function nn(){return(0,n.A)(rn).scale(166.518)}Kr.invert=function(t,e){var r=3*C(e*Jr/9);return[t*Jr/($r*(2*s(2*r/3)-1)),C(3*g(r)*$r/7)]},tn.invert=function(t,e){var r=e*I(2+k)/(2*I(3)),n=2*C(r);return[3*k*t/(1+2*s(n)/s(n/2)),C((r+g(n))/(1+T))]},rn.invert=function(t,e){var r=I(6/(4+_)),n=e/r;return i(i(n)-b)<v&&(n=n<0?-b:b),[1.5*t/(r*(.5+s(n))),C((n/2+g(n))/(1+_/4))]};var an=r(57949);function on(t,e){var r=e*e,n=r*r,i=r*n;return[t*(.84719-.13063*r+i*i*(.05494*r-.04515-.02326*n+.00331*i)),e*(1.01183+n*n*(.01926*r-.02625-.00396*n))]}function sn(){return(0,n.A)(on).scale(175.295)}function ln(t,e){return[t*(1+s(e))/2,2*(e-y(e/2))]}function cn(){return(0,n.A)(ln).scale(152.63)}on.invert=function(t,e){var r,n,a,o,s=e,l=25;do{s-=r=(s*(1.01183+(a=(n=s*s)*n)*a*(.01926*n-.02625-.00396*a))-e)/(1.01183+a*a*(.21186*n-.23625+-.05148*a))}while(i(r)>x&&--l>0);return[t/(.84719-.13063*(n=s*s)+(o=n*(a=n*n))*o*(.05494*n-.04515-.02326*a+.00331*o)),s]},ln.invert=function(t,e){for(var r=e/2,n=0,a=1/0;n<10&&i(a)>v;++n){var o=s(e/2);e-=a=(e-y(e/2)-r)/(1-.5/(o*o))}return[2*t/(1+s(e)),e]};var un=[[[[-180,0],[-90,90],[0,0]],[[0,0],[90,90],[180,0]]],[[[-180,0],[-90,-90],[0,0]],[[0,0],[90,-90],[180,0]]]];function hn(){return ur($(1/0),un).rotate([20,0]).scale(152.63)}function fn(t,e){var r=g(e),n=s(e),a=m(t);if(0===t||i(e)===b)return[0,e];if(0===e)return[t,0];if(i(t)===b)return[t*n,b*r];var o=_/(2*t)-2*t/_,l=2*e/_,c=(1-l*l)/(r-l),u=o*o,h=c*c,f=1+u/h,p=1+h/u,d=(o*r/c-o/2)/f,y=(h*r/u+c/2)/p,v=y*y-(h*r*r/u+c*r-1)/p;return[b*(d+I(d*d+n*n/f)*a),b*(y+I(v<0?0:v)*m(-e*o)*a)]}function pn(){return(0,n.A)(fn).scale(127.267)}fn.invert=function(t,e){var r=(t/=b)*t,n=r+(e/=b)*e,i=_*_;return[t?(n-1+I((1-n)*(1-n)+4*r))/(2*t)*b:0,Q((function(t){return n*(_*g(t)-2*t)*_+4*t*t*(e-g(t))+2*_*t-i*e}),0)]};var dn=1.0148,mn=.23185,gn=-.14499,yn=.02406,vn=dn,xn=5*mn,_n=7*gn,bn=9*yn,wn=1.790857183;function Tn(t,e){var r=e*e;return[t,e*(dn+r*r*(mn+r*(gn+yn*r)))]}function kn(){return(0,n.A)(Tn).scale(139.319)}function An(t,e){if(i(e)<v)return[t,0];var r=y(e),n=t*g(e);return[g(n)/r,e+(1-s(n))/r]}function Mn(){return(0,n.A)(An).scale(103.74)}Tn.invert=function(t,e){e>wn?e=wn:e<-1.790857183&&(e=-1.790857183);var r,n=e;do{var a=n*n;n-=r=(n*(dn+a*a*(mn+a*(gn+yn*a)))-e)/(vn+a*a*(xn+a*(_n+bn*a)))}while(i(r)>v);return[t,n]},An.invert=function(t,e){if(i(e)<v)return[t,0];var r,n=t*t+e*e,a=.5*e,o=10;do{var l=y(a),c=1/s(a),u=n-2*e*a+a*a;a-=r=(l*u+2*(a-e))/(2+u*c*c+2*(a-e)*l)}while(i(r)>v&&--o>0);return l=y(a),[(i(e)<i(a+1/l)?C(t*l):m(e)*m(t)*(L(i(t*l))+b))/g(a),a]};var Sn=r(43212),En=r(81758);function Cn(t,e){return[t[0]*e[0]+t[1]*e[3],t[0]*e[1]+t[1]*e[4],t[0]*e[2]+t[1]*e[5]+t[2],t[3]*e[0]+t[4]*e[3],t[3]*e[1]+t[4]*e[4],t[3]*e[2]+t[4]*e[5]+t[5]]}function Ln(t,e){return[t[0]-e[0],t[1]-e[1]]}function In(t){return I(t[0]*t[0]+t[1]*t[1])}function Pn(t,e,r){function i(t,r){var n,i=e(t,r),a=i.project([t*S,r*S]);return(n=i.transform)?[n[0]*a[0]+n[1]*a[1]+n[2],-(n[3]*a[0]+n[4]*a[1]+n[5])]:(a[1]=-a[1],a)}function a(t,r){var n=t.project.invert,i=t.transform,o=r;if(i&&(i=function(t){var e=1/(t[0]*t[4]-t[1]*t[3]);return[e*t[4],-e*t[1],e*(t[1]*t[5]-t[2]*t[4]),-e*t[3],e*t[0],e*(t[2]*t[3]-t[0]*t[5])]}(i),o=[i[0]*o[0]+i[1]*o[1]+i[2],i[3]*o[0]+i[4]*o[1]+i[5]]),n&&t===function(t){return e(t[0]*E,t[1]*E)}(s=n(o)))return s;for(var s,l=t.children,c=0,u=l&&l.length;c<u;++c)if(s=a(l[c],r))return s}!function t(e,r){if(e.edges=function(t){for(var e=t.length,r=[],n=t[e-1],i=0;i<e;++i)r.push([n,n=t[i]]);return r}(e.face),r.face){var n=e.shared=function(t,e){for(var r,n,i=t.length,a=null,o=0;o<i;++o){r=t[o];for(var s=e.length;--s>=0;)if(n=e[s],r[0]===n[0]&&r[1]===n[1]){if(a)return[a,r];a=r}}}(e.face,r.face),i=(u=n.map(r.project),h=n.map(e.project),f=Ln(u[1],u[0]),p=Ln(h[1],h[0]),d=function(t,e){return o(t[0]*e[1]-t[1]*e[0],t[0]*e[0]+t[1]*e[1])}(f,p),m=In(f)/In(p),Cn([1,0,u[0][0],0,1,u[0][1]],Cn([m,0,0,0,m,0],Cn([s(d),g(d),0,-g(d),s(d),0],[1,0,-h[0][0],0,1,-h[0][1]]))));e.transform=r.transform?Cn(r.transform,i):i;for(var a=r.edges,l=0,c=a.length;l<c;++l)On(n[0],a[l][1])&&On(n[1],a[l][0])&&(a[l]=e),On(n[0],a[l][0])&&On(n[1],a[l][1])&&(a[l]=e);for(l=0,c=(a=e.edges).length;l<c;++l)On(n[0],a[l][0])&&On(n[1],a[l][1])&&(a[l]=r),On(n[0],a[l][1])&&On(n[1],a[l][0])&&(a[l]=r)}else e.transform=r.transform;var u,h,f,p,d,m;return e.children&&e.children.forEach((function(r){t(r,e)})),e}(t,{transform:null}),Dn(t)&&(i.invert=function(e,r){var n=a(t,[e,-r]);return n&&(n[0]*=E,n[1]*=E,n)});var l=(0,n.A)(i),c=l.stream;return l.stream=function(e){var r=l.rotate(),n=c(e),i=(l.rotate([0,0]),c(e));return l.rotate(r),n.sphere=function(){i.polygonStart(),i.lineStart(),zn(i,t),i.lineEnd(),i.polygonEnd()},n},l.angle(null==r?-30:r*S)}function zn(t,e,r){var n,a,o=e.edges,s=o.length,l={type:\"MultiPoint\",coordinates:e.face},c=e.face.filter((function(t){return 90!==i(t[1])})),u=(0,Sn.A)({type:\"MultiPoint\",coordinates:c}),h=!1,f=-1,p=u[1][0]-u[0][0],d=180===p||360===p?[(u[0][0]+u[1][0])/2,(u[0][1]+u[1][1])/2]:(0,_t.A)(l);if(r)for(;++f<s&&o[f]!==r;);++f;for(var m=0;m<s;++m)a=o[(m+f)%s],Array.isArray(a)?(h||(t.point((n=(0,En.A)(a[0],d)(v))[0],n[1]),h=!0),t.point((n=(0,En.A)(a[1],d)(v))[0],n[1])):(h=!1,a!==r&&zn(t,a,e))}function On(t,e){return t&&e&&t[0]===e[0]&&t[1]===e[1]}function Dn(t){return t.project.invert||t.children&&t.children.some(Dn)}var Rn=r(48419),Fn=[[0,90],[-90,0],[0,0],[90,0],[180,0],[0,-90]],Bn=[[0,2,1],[0,3,2],[5,1,2],[5,2,3],[0,1,4],[0,4,3],[5,4,1],[5,3,4]].map((function(t){return t.map((function(t){return Fn[t]}))}));function Nn(t){t=t||function(t){var e=(0,_t.A)({type:\"MultiPoint\",coordinates:t});return(0,Rn.A)().scale(1).translate([0,0]).rotate([-e[0],-e[1]])};var e=Bn.map((function(e){return{face:e,project:t(e)}}));return[-1,0,0,1,0,1,4,5].forEach((function(t,r){var n=e[t];n&&(n.children||(n.children=[])).push(e[r])})),Pn(e[0],(function(t,r){return e[t<-_/2?r<0?6:4:t<0?r<0?2:0:t<_/2?r<0?3:1:r<0?7:5]})).angle(-30).scale(101.858).center([0,45])}var jn=2/I(3);function Un(t,e){var r=Ct(t,e);return[r[0]*jn,r[1]]}function Vn(t){t=t||function(t){var e=(0,_t.A)({type:\"MultiPoint\",coordinates:t});return(0,n.A)(Un).translate([0,0]).scale(1).rotate(e[1]>0?[-e[0],0]:[180-e[0],180])};var e=Bn.map((function(e){return{face:e,project:t(e)}}));return[-1,0,0,1,0,1,4,5].forEach((function(t,r){var n=e[t];n&&(n.children||(n.children=[])).push(e[r])})),Pn(e[0],(function(t,r){return e[t<-_/2?r<0?6:4:t<0?r<0?2:0:t<_/2?r<0?3:1:r<0?7:5]})).angle(-30).scale(121.906).center([0,48.5904])}function qn(t){t=t||function(t){var e=6===t.length?(0,_t.A)({type:\"MultiPoint\",coordinates:t}):t[0];return(0,Rn.A)().scale(1).translate([0,0]).rotate([-e[0],-e[1]])};var e=Bn.map((function(t){for(var e,r=t.map(Zn),n=r.length,i=r[n-1],a=[],o=0;o<n;++o)e=r[o],a.push(Gn([.9486832980505138*i[0]+.31622776601683794*e[0],.9486832980505138*i[1]+.31622776601683794*e[1],.9486832980505138*i[2]+.31622776601683794*e[2]]),Gn([.9486832980505138*e[0]+.31622776601683794*i[0],.9486832980505138*e[1]+.31622776601683794*i[1],.9486832980505138*e[2]+.31622776601683794*i[2]])),i=e;return a})),r=[],n=[-1,0,0,1,0,1,4,5];e.forEach((function(t,i){for(var a,o,s=Bn[i],l=s.length,c=r[i]=[],u=0;u<l;++u)e.push([s[u],t[(2*u+2)%(2*l)],t[(2*u+1)%(2*l)]]),n.push(i),c.push((a=Zn(t[(2*u+2)%(2*l)]),o=Zn(t[(2*u+1)%(2*l)]),[a[1]*o[2]-a[2]*o[1],a[2]*o[0]-a[0]*o[2],a[0]*o[1]-a[1]*o[0]]))}));var i=e.map((function(e){return{project:t(e),face:e}}));return n.forEach((function(t,e){var r=i[t];r&&(r.children||(r.children=[])).push(i[e])})),Pn(i[0],(function(t,e){var n=s(e),a=[n*s(t),n*g(t),g(e)],o=t<-_/2?e<0?6:4:t<0?e<0?2:0:t<_/2?e<0?3:1:e<0?7:5,l=r[o];return i[Hn(l[0],a)<0?8+3*o:Hn(l[1],a)<0?8+3*o+1:Hn(l[2],a)<0?8+3*o+2:o]})).angle(-30).scale(110.625).center([0,45])}function Hn(t,e){for(var r=0,n=t.length,i=0;r<n;++r)i+=t[r]*e[r];return i}function Gn(t){return[o(t[1],t[0])*S,C(h(-1,f(1,t[2])))*S]}function Zn(t){var e=t[0]*E,r=t[1]*E,n=s(r);return[n*s(e),n*g(e),g(r)]}function Wn(){}function Yn(t,e){var r,n=e.stream;if(!n)throw new Error(\"invalid projection\");switch(t&&t.type){case\"Feature\":r=$n;break;case\"FeatureCollection\":r=Xn;break;default:r=Jn}return r(t,n)}function Xn(t,e){return{type:\"FeatureCollection\",features:t.features.map((function(t){return $n(t,e)}))}}function $n(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:Jn(t.geometry,e)}}function Jn(t,e){if(!t)return null;if(\"GeometryCollection\"===t.type)return function(t,e){return{type:\"GeometryCollection\",geometries:t.geometries.map((function(t){return Jn(t,e)}))}}(t,e);var r;switch(t.type){case\"Point\":case\"MultiPoint\":r=ti;break;case\"LineString\":case\"MultiLineString\":r=ei;break;case\"Polygon\":case\"MultiPolygon\":case\"Sphere\":r=ri;break;default:return null}return(0,je.A)(t,e(r)),r.result()}Un.invert=function(t,e){return Ct.invert(t/jn,e)};var Kn=[],Qn=[],ti={point:function(t,e){Kn.push([t,e])},result:function(){var t=Kn.length?Kn.length<2?{type:\"Point\",coordinates:Kn[0]}:{type:\"MultiPoint\",coordinates:Kn}:null;return Kn=[],t}},ei={lineStart:Wn,point:function(t,e){Kn.push([t,e])},lineEnd:function(){Kn.length&&(Qn.push(Kn),Kn=[])},result:function(){var t=Qn.length?Qn.length<2?{type:\"LineString\",coordinates:Qn[0]}:{type:\"MultiLineString\",coordinates:Qn}:null;return Qn=[],t}},ri={polygonStart:Wn,lineStart:Wn,point:function(t,e){Kn.push([t,e])},lineEnd:function(){var t=Kn.length;if(t){do{Kn.push(Kn[0].slice())}while(++t<4);Qn.push(Kn),Kn=[]}},polygonEnd:Wn,result:function(){if(!Qn.length)return null;var t=[],e=[];return Qn.forEach((function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])})),e.forEach((function(e){var r=e[0];t.some((function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0}))||t.push([e])})),Qn=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}};function ni(t){var e=t(b,0)[0]-t(-b,0)[0];function r(r,n){var a=i(r)<b,o=t(a?r:r>0?r-_:r+_,n),s=(o[0]-o[1])*T,l=(o[0]+o[1])*T;if(a)return[s,l];var c=e*T,u=s>0^l>0?-1:1;return[u*s-m(l)*c,u*l-m(s)*c]}return t.invert&&(r.invert=function(r,n){var a=(r+n)*T,o=(n-r)*T,s=i(a)<.5*e&&i(o)<.5*e;if(!s){var l=e*T,c=a>0^o>0?-1:1,u=-c*r+(o>0?1:-1)*l,h=-c*n+(a>0?1:-1)*l;a=(-u-h)*T,o=(u-h)*T}var f=t.invert(a,o);return s||(f[0]+=a>0?_:-_),f}),(0,n.A)(r).rotate([-90,-90,45]).clipAngle(179.999)}function ii(){return ni(Ce).scale(176.423)}function ai(){return ni(ze).scale(111.48)}function oi(t,e){if(!(0<=(e=+e)&&e<=20))throw new Error(\"invalid digits\");function r(t){var r=t.length,n=2,i=new Array(r);for(i[0]=+t[0].toFixed(e),i[1]=+t[1].toFixed(e);n<r;)i[n]=t[n],++n;return i}function n(t){return t.map(r)}function i(t){for(var e=r(t[0]),n=[e],i=1;i<t.length;i++){var a=r(t[i]);(a.length>2||a[0]!=e[0]||a[1]!=e[1])&&(n.push(a),e=a)}return 1===n.length&&t.length>1&&n.push(r(t[t.length-1])),n}function a(t){return t.map(i)}function o(t){if(null==t)return t;var e;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(o)};break;case\"Point\":e={type:\"Point\",coordinates:r(t.coordinates)};break;case\"MultiPoint\":e={type:t.type,coordinates:n(t.coordinates)};break;case\"LineString\":e={type:t.type,coordinates:i(t.coordinates)};break;case\"MultiLineString\":case\"Polygon\":e={type:t.type,coordinates:a(t.coordinates)};break;case\"MultiPolygon\":e={type:\"MultiPolygon\",coordinates:t.coordinates.map(a)};break;default:return t}return null!=t.bbox&&(e.bbox=t.bbox),e}function s(t){var e={type:\"Feature\",properties:t.properties,geometry:o(t.geometry)};return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),e}if(null!=t)switch(t.type){case\"Feature\":return s(t);case\"FeatureCollection\":var l={type:\"FeatureCollection\",features:t.features.map(s)};return null!=t.bbox&&(l.bbox=t.bbox),l;default:return o(t)}return t}function si(t){var e=g(t);function r(r,n){var i=e?y(r*e/2)/e:r/2;if(!n)return[2*i,-t];var o=2*a(i*g(n)),l=1/y(n);return[g(o)*l,n+(1-s(o))*l-t]}return r.invert=function(r,n){if(i(n+=t)<v)return[e?2*a(e*r/2)/e:r,0];var o,l=r*r+n*n,c=0,u=10;do{var h=y(c),f=1/s(c),p=l-2*n*c+c*c;c-=o=(h*p+2*(c-n))/(2+p*f*f+2*(c-n)*h)}while(i(o)>v&&--u>0);var d=r*(h=y(c)),m=y(i(n)<i(c+1/h)?.5*C(d):.5*L(d)+_/4)/g(c);return[e?2*a(e*m)/e:2*m,c]},r}function li(){return ht(si).scale(131.215)}var ci=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function ui(t,e){var r,n=f(18,36*i(e)/_),a=c(n),o=n-a,s=(r=ci[a])[0],l=r[1],u=(r=ci[++a])[0],h=r[1],p=(r=ci[f(19,++a)])[0],d=r[1];return[t*(u+o*(p-s)/2+o*o*(p-2*u+s)/2),(e>0?b:-b)*(h+o*(d-l)/2+o*o*(d-2*h+l)/2)]}function hi(){return(0,n.A)(ui).scale(152.63)}function fi(t,e){var r=function(t){function e(e,r){var n=s(r),i=(t-1)/(t-n*s(e));return[i*n*g(e),i*g(r)]}return e.invert=function(e,r){var n=e*e+r*r,i=I(n),a=(t-I(1-n*(t+1)/(t-1)))/((t-1)/i+i/(t-1));return[o(e*a,i*I(1-a*a)),i?C(r*a/i):0]},e}(t);if(!e)return r;var n=s(e),i=g(e);function a(e,a){var o=r(e,a),s=o[1],l=s*i/(t-1)+n;return[o[0]*n/l,s/l]}return a.invert=function(e,a){var o=(t-1)/(t-1-a*i);return r.invert(o*e,o*a*n)},a}function pi(){var t=2,e=0,r=(0,n.U)(fi),i=r(t,e);return i.distance=function(n){return arguments.length?r(t=+n,e):t},i.tilt=function(n){return arguments.length?r(t,e=n*E):e*S},i.scale(432.147).clipAngle(L(1/t)*S-1e-6)}ci.forEach((function(t){t[1]*=1.0144})),ui.invert=function(t,e){var r=e/b,n=90*r,a=f(18,i(n/5)),o=h(0,c(a));do{var s=ci[o][1],l=ci[o+1][1],u=ci[f(19,o+2)][1],p=u-s,d=u-2*l+s,m=2*(i(r)-l)/p,g=d/p,y=m*(1-g*m*(1-2*g*m));if(y>=0||1===o){n=(e>=0?5:-5)*(y+a);var v,_=50;do{y=(a=f(18,i(n)/5))-(o=c(a)),s=ci[o][1],l=ci[o+1][1],u=ci[f(19,o+2)][1],n-=(v=(e>=0?b:-b)*(l+y*(u-s)/2+y*y*(u-2*l+s)/2)-e)*S}while(i(v)>x&&--_>0);break}}while(--o>=0);var w=ci[o][0],T=ci[o+1][0],k=ci[f(19,o+2)][0];return[t/(T+y*(k-w)/2+y*y*(k-2*T+w)/2),n*E]};var di=1e-4,mi=1e4,gi=-180,yi=gi+di,vi=180,xi=vi-di,_i=-90,bi=_i+di,wi=90,Ti=wi-di;function ki(t){return t.length>0}function Ai(t){return t===_i||t===wi?[0,t]:[gi,(e=t,Math.floor(e*mi)/mi)];var e}function Mi(t){var e=t[0],r=t[1],n=!1;return e<=yi?(e=gi,n=!0):e>=xi&&(e=vi,n=!0),r<=bi?(r=_i,n=!0):r>=Ti&&(r=wi,n=!0),n?[e,r]:t}function Si(t){return t.map(Mi)}function Ei(t,e,r){for(var n=0,i=t.length;n<i;++n){var a=t[n].slice();r.push({index:-1,polygon:e,ring:a});for(var o=0,s=a.length;o<s;++o){var l=a[o],c=l[0],u=l[1];if(c<=yi||c>=xi||u<=bi||u>=Ti){a[o]=Mi(l);for(var h=o+1;h<s;++h){var f=a[h],p=f[0],d=f[1];if(p>yi&&p<xi&&d>bi&&d<Ti)break}if(h===o+1)continue;if(o){var m={index:-1,polygon:e,ring:a.slice(0,o+1)};m.ring[m.ring.length-1]=Ai(u),r[r.length-1]=m}else r.pop();if(h>=s)break;r.push({index:-1,polygon:e,ring:a=a.slice(h-1)}),a[0]=Ai(a[0][1]),o=-1,s=a.length}}}}function Ci(t){var e,r,n,i,a,o,s=t.length,l={},c={};for(e=0;e<s;++e)n=(r=t[e]).ring[0],a=r.ring[r.ring.length-1],n[0]!==a[0]||n[1]!==a[1]?(r.index=e,l[n]=c[a]=r):(r.polygon.push(r.ring),t[e]=null);for(e=0;e<s;++e)if(r=t[e]){if(n=r.ring[0],a=r.ring[r.ring.length-1],i=c[n],o=l[a],delete l[n],delete c[a],n[0]===a[0]&&n[1]===a[1]){r.polygon.push(r.ring);continue}i?(delete c[n],delete l[i.ring[0]],i.ring.pop(),t[i.index]=null,r={index:-1,polygon:i.polygon,ring:i.ring.concat(r.ring)},i===o?r.polygon.push(r.ring):(r.index=s++,t.push(l[r.ring[0]]=c[r.ring[r.ring.length-1]]=r))):o?(delete l[a],delete c[o.ring[o.ring.length-1]],r.ring.pop(),r={index:s++,polygon:o.polygon,ring:r.ring.concat(o.ring)},t[o.index]=null,t.push(l[r.ring[0]]=c[r.ring[r.ring.length-1]]=r)):(r.ring.push(r.ring[0]),r.polygon.push(r.ring))}}function Li(t){var e={type:\"Feature\",geometry:Ii(t.geometry)};return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),null!=t.properties&&(e.properties=t.properties),e}function Ii(t){if(null==t)return t;var e,r,n,i;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(Ii)};break;case\"Point\":e={type:\"Point\",coordinates:Mi(t.coordinates)};break;case\"MultiPoint\":case\"LineString\":e={type:t.type,coordinates:Si(t.coordinates)};break;case\"MultiLineString\":e={type:\"MultiLineString\",coordinates:t.coordinates.map(Si)};break;case\"Polygon\":var a=[];Ei(t.coordinates,a,r=[]),Ci(r),e={type:\"Polygon\",coordinates:a};break;case\"MultiPolygon\":r=[],n=-1,i=t.coordinates.length;for(var o=new Array(i);++n<i;)Ei(t.coordinates[n],o[n]=[],r);Ci(r),e={type:\"MultiPolygon\",coordinates:o.filter(ki)};break;default:return t}return null!=t.bbox&&(e.bbox=t.bbox),e}function Pi(t){if(null==t)return t;switch(t.type){case\"Feature\":return Li(t);case\"FeatureCollection\":var e={type:\"FeatureCollection\",features:t.features.map(Li)};return null!=t.bbox&&(e.bbox=t.bbox),e;default:return Ii(t)}}function zi(t,e){var r=y(e/2),n=g(w*r);return[t*(.74482-.34588*n*n),1.70711*r]}function Oi(){return(0,n.A)(zi).scale(146.153)}function Di(t,e,r){var i=(0,En.A)(e,r),a=i(.5),o=(0,bt.A)([-a[0],-a[1]])(e),s=i.distance/2,l=-C(g(o[1]*E)/g(s)),c=[-a[0],-a[1],-(o[0]>0?_-l:l)*S],u=(0,n.A)(t(s)).rotate(c),h=(0,bt.A)(c),f=u.center;return delete u.rotate,u.center=function(t){return arguments.length?f(h(t)):h.invert(f())},u.clipAngle(90)}function Ri(t){var e=s(t);function r(t,r){var n=(0,Rn.T)(t,r);return n[0]*=e,n}return r.invert=function(t,r){return Rn.T.invert(t/e,r)},r}function Fi(){return Bi([-158,21.5],[-77,39]).clipAngle(60).scale(400)}function Bi(t,e){return Di(Ri,t,e)}function Ni(t){if(!(t*=2))return Z.j;var e=-t/2,r=-e,n=t*t,i=y(r),a=.5/g(r);function l(i,a){var o=L(s(a)*s(i-e)),l=L(s(a)*s(i-r));return[((o*=o)-(l*=l))/(2*t),(a<0?-1:1)*I(4*n*l-(n-o+l)*(n-o+l))/(2*t)]}return l.invert=function(t,n){var l,c,u=n*n,h=s(I(u+(l=t+e)*l)),f=s(I(u+(l=t+r)*l));return[o(c=h-f,l=(h+f)*i),(n<0?-1:1)*L(I(l*l+c*c)*a)]},l}function ji(){return Ui([-158,21.5],[-77,39]).clipAngle(130).scale(122.571)}function Ui(t,e){return Di(Ni,t,e)}function Vi(t,e){if(i(e)<v)return[t,0];var r=i(e/b),n=C(r);if(i(t)<v||i(i(e)-b)<v)return[0,m(e)*_*y(n/2)];var a=s(n),o=i(_/t-t/_)/2,l=o*o,c=a/(r+a-1),u=c*(2/r-1),h=u*u,f=h+l,p=c-h,d=l+c;return[m(t)*_*(o*p+I(l*p*p-f*(c*c-h)))/f,m(e)*_*(u*d-o*I((l+1)*f-d*d))/f]}function qi(){return(0,n.A)(Vi).scale(79.4183)}function Hi(t,e){if(i(e)<v)return[t,0];var r=i(e/b),n=C(r);if(i(t)<v||i(i(e)-b)<v)return[0,m(e)*_*y(n/2)];var a=s(n),o=i(_/t-t/_)/2,l=o*o,c=a*(I(1+l)-o*a)/(1+l*r*r);return[m(t)*_*c,m(e)*_*I(1-c*(2*o+c))]}function Gi(){return(0,n.A)(Hi).scale(79.4183)}function Zi(t,e){if(i(e)<v)return[t,0];var r=e/b,n=C(r);if(i(t)<v||i(i(e)-b)<v)return[0,_*y(n/2)];var a=(_/t-t/_)/2,o=r/(1+s(n));return[_*(m(t)*I(a*a+1-o*o)-a),_*o]}function Wi(){return(0,n.A)(Zi).scale(79.4183)}function Yi(t,e){if(!e)return[t,0];var r=i(e);if(!t||r===b)return[0,e];var n=r/b,a=n*n,o=(8*n-a*(a+2)-5)/(2*a*(n-1)),s=o*o,l=n*o,c=a+s+2*l,u=n+3*o,h=t/b,f=h+1/h,p=m(i(t)-b)*I(f*f-4),d=p*p,g=(p*(c+s-1)+2*I(c*(a+s*d-1)+(1-a)*(a*(u*u+4*s)+12*l*s+4*s*s)))/(4*c+d);return[m(t)*b*g,m(e)*b*I(1+p*i(g)-g*g)]}function Xi(){return(0,n.A)(Yi).scale(127.16)}function $i(t,e,r,n){var i=_/3;t=h(t,v),e=h(e,v),t=f(t,b),e=f(e,_-v),r=h(r,0),r=f(r,100-v);var a=(n=h(n,v))/100,l=L((r/100+1)*s(i))/i,c=g(t)/g(l*b),u=e/_,p=I(a*g(t/2)/g(e/2));return function(t,e,r,n,i){function a(a,o){var l=r*g(n*o),c=I(1-l*l),u=I(2/(1+c*s(a*=i)));return[t*c*u*g(a),e*l*u]}return a.invert=function(a,s){var l=a/t,c=s/e,u=I(l*l+c*c),h=2*C(u/2);return[o(a*y(h),t*u)/i,u&&C(s*g(h)/(e*r*u))/n]},a}(p/I(u*c*l),1/(p*I(u*c*l)),c,l,u)}function Ji(){var t=65*E,e=60*E,r=20,i=200,a=(0,n.U)($i),o=a(t,e,r,i);return o.poleline=function(n){return arguments.length?a(t=+n*E,e,r,i):t*S},o.parallels=function(n){return arguments.length?a(t,e=+n*E,r,i):e*S},o.inflation=function(n){return arguments.length?a(t,e,r=+n,i):r},o.ratio=function(n){return arguments.length?a(t,e,r,i=+n):i},o.scale(163.775)}function Ki(){return Ji().poleline(65).parallels(60).inflation(0).ratio(200).scale(172.633)}zi.invert=function(t,e){var r=e/1.70711,n=g(w*r);return[t/(.74482-.34588*n*n),2*a(r)]},Vi.invert=function(t,e){if(i(e)<v)return[t,0];if(i(t)<v)return[0,b*g(2*a(e/_))];var r=(t/=_)*t,n=(e/=_)*e,o=r+n,l=o*o,c=-i(e)*(1+o),u=c-2*n+r,h=-2*c+1+2*n+l,f=n/h+(2*u*u*u/(h*h*h)-9*c*u/(h*h))/27,p=(c-u*u/(3*h))/h,d=2*I(-p/3),y=L(3*f/(p*d))/3;return[_*(o-1+I(1+2*(r-n)+l))/(2*t),m(e)*_*(-d*s(y+_/3)-u/(3*h))]},Hi.invert=function(t,e){if(!t)return[0,b*g(2*a(e/_))];var r=i(t/_),n=(1-r*r-(e/=_)*e)/(2*r),s=I(n*n+1);return[m(t)*_*(s-n),m(e)*b*g(2*o(I((1-2*n*r)*(n+s)-r),I(s+n+r)))]},Zi.invert=function(t,e){if(!e)return[t,0];var r=e/_,n=(_*_*(1-r*r)-t*t)/(2*_*t);return[t?_*(m(t)*I(n*n+1)-n):0,b*g(2*a(r))]},Yi.invert=function(t,e){var r;if(!t||!e)return[t,e];e/=_;var n=m(t)*t/b,a=(n*n-1+4*e*e)/i(n),o=a*a,s=2*e,l=50;do{var c=s*s,u=(8*s-c*(c+2)-5)/(2*c*(s-1)),h=(3*s-c*s-10)/(2*c*s),f=u*u,p=s*u,d=s+u,g=d*d,y=s+3*u,x=-2*d*(4*p*f+(1-4*c+3*c*c)*(1+h)+f*(14*c-6-o+(8*c-8-2*o)*h)+p*(12*c-8+(10*c-10-o)*h)),w=I(g*(c+f*o-1)+(1-c)*(c*(y*y+4*f)+f*(12*p+4*f)));s-=r=(a*(g+f-1)+2*w-n*(4*g+o))/(a*(2*u*h+2*d*(1+h))+x/w-8*d*(a*(-1+f+g)+2*w)*(1+h)/(o+4*g))}while(r>v&&--l>0);return[m(t)*(I(a*a+4)+a)*_/4,b*s]};var Qi=4*_+3*I(3),ta=2*I(2*_*I(3)/Qi),ea=it(ta*I(3)/_,ta,Qi/6);function ra(){return(0,n.A)(ea).scale(176.84)}function na(t,e){return[t*I(1-3*e*e/(_*_)),e]}function ia(){return(0,n.A)(na).scale(152.63)}function aa(t,e){var r=s(e),n=s(t)*r,i=1-n,a=s(t=o(g(t)*r,-g(e))),l=g(t);return[l*(r=I(1-n*n))-a*i,-a*r-l*i]}function oa(){return(0,n.A)(aa).rotate([0,-90,45]).scale(124.75).clipAngle(179.999)}function sa(t,e){var r=R(t,e);return[(r[0]+t/b)/2,(r[1]+e)/2]}function la(){return(0,n.A)(sa).scale(158.837)}na.invert=function(t,e){return[t/I(1-3*e*e/(_*_)),e]},aa.invert=function(t,e){var r=(t*t+e*e)/-2,n=I(-r*(2+r)),i=e*r+t*n,a=t*r-e*n,s=I(a*a+i*i);return[o(n*i,s*(1+r)),s?-C(n*a/s):0]},sa.invert=function(t,e){var r=t,n=e,a=25;do{var o,l=s(n),c=g(n),u=g(2*n),h=c*c,f=l*l,p=g(r),d=s(r/2),m=g(r/2),y=m*m,x=1-f*d*d,_=x?L(l*d)*I(o=1/x):o=0,w=.5*(2*_*l*m+r/b)-t,T=.5*(_*c+n)-e,k=.5*o*(f*y+_*l*d*h)+.5/b,A=o*(p*u/4-_*c*m),M=.125*o*(u*m-_*c*f*p),S=.5*o*(h*d+_*y*l)+.5,E=A*M-S*k,C=(T*A-w*S)/E,P=(w*M-T*k)/E;r-=C,n-=P}while((i(C)>v||i(P)>v)&&--a>0);return[r,n]}},49353:function(t,e,r){\"use strict\";function n(){return new i}function i(){this.reset()}r.d(e,{A:function(){return n}}),i.prototype={constructor:i,reset:function(){this.s=this.t=0},add:function(t){o(a,t,this.t),o(this,a.s,this.s),this.s?this.t+=a.t:this.s=a.t},valueOf:function(){return this.s}};var a=new i;function o(t,e,r){var n=t.s=e+r,i=n-e,a=n-i;t.t=e-a+(r-i)}},43976:function(t,e,r){\"use strict\";r.d(e,{Ay:function(){return x},B0:function(){return f},Y7:function(){return d}});var n,i,a,o,s,l=r(49353),c=r(61323),u=r(53341),h=r(20465),f=(0,l.A)(),p=(0,l.A)(),d={point:u.A,lineStart:u.A,lineEnd:u.A,polygonStart:function(){f.reset(),d.lineStart=m,d.lineEnd=g},polygonEnd:function(){var t=+f;p.add(t<0?c.FA+t:t),this.lineStart=this.lineEnd=this.point=u.A},sphere:function(){p.add(c.FA)}};function m(){d.point=y}function g(){v(n,i)}function y(t,e){d.point=v,n=t,i=e,t*=c.F2,e*=c.F2,a=t,o=(0,c.gn)(e=e/2+c.gz),s=(0,c.F8)(e)}function v(t,e){t*=c.F2,e=(e*=c.F2)/2+c.gz;var r=t-a,n=r>=0?1:-1,i=n*r,l=(0,c.gn)(e),u=(0,c.F8)(e),h=s*u,p=o*l+h*(0,c.gn)(i),d=h*n*(0,c.F8)(i);f.add((0,c.FP)(d,p)),a=t,o=l,s=u}function x(t){return p.reset(),(0,h.A)(t,d),2*p}},43212:function(t,e,r){\"use strict\";r.d(e,{A:function(){return L}});var n,i,a,o,s,l,c,u,h,f,p=r(49353),d=r(43976),m=r(20375),g=r(61323),y=r(20465),v=(0,p.A)(),x={point:_,lineStart:w,lineEnd:T,polygonStart:function(){x.point=k,x.lineStart=A,x.lineEnd=M,v.reset(),d.Y7.polygonStart()},polygonEnd:function(){d.Y7.polygonEnd(),x.point=_,x.lineStart=w,x.lineEnd=T,d.B0<0?(n=-(a=180),i=-(o=90)):v>g.Ni?o=90:v<-g.Ni&&(i=-90),f[0]=n,f[1]=a},sphere:function(){n=-(a=180),i=-(o=90)}};function _(t,e){h.push(f=[n=t,a=t]),e<i&&(i=e),e>o&&(o=e)}function b(t,e){var r=(0,m.jf)([t*g.F2,e*g.F2]);if(u){var l=(0,m.r8)(u,r),c=[l[1],-l[0],0],p=(0,m.r8)(c,l);(0,m.Cx)(p),p=(0,m.EV)(p);var d,y=t-s,v=y>0?1:-1,x=p[0]*g.uj*v,_=(0,g.tn)(y)>180;_^(v*s<x&&x<v*t)?(d=p[1]*g.uj)>o&&(o=d):_^(v*s<(x=(x+360)%360-180)&&x<v*t)?(d=-p[1]*g.uj)<i&&(i=d):(e<i&&(i=e),e>o&&(o=e)),_?t<s?S(n,t)>S(n,a)&&(a=t):S(t,a)>S(n,a)&&(n=t):a>=n?(t<n&&(n=t),t>a&&(a=t)):t>s?S(n,t)>S(n,a)&&(a=t):S(t,a)>S(n,a)&&(n=t)}else h.push(f=[n=t,a=t]);e<i&&(i=e),e>o&&(o=e),u=r,s=t}function w(){x.point=b}function T(){f[0]=n,f[1]=a,x.point=_,u=null}function k(t,e){if(u){var r=t-s;v.add((0,g.tn)(r)>180?r+(r>0?360:-360):r)}else l=t,c=e;d.Y7.point(t,e),b(t,e)}function A(){d.Y7.lineStart()}function M(){k(l,c),d.Y7.lineEnd(),(0,g.tn)(v)>g.Ni&&(n=-(a=180)),f[0]=n,f[1]=a,u=null}function S(t,e){return(e-=t)<0?e+360:e}function E(t,e){return t[0]-e[0]}function C(t,e){return t[0]<=t[1]?t[0]<=e&&e<=t[1]:e<t[0]||t[1]<e}function L(t){var e,r,s,l,c,u,p;if(o=a=-(n=i=1/0),h=[],(0,y.A)(t,x),r=h.length){for(h.sort(E),e=1,c=[s=h[0]];e<r;++e)C(s,(l=h[e])[0])||C(s,l[1])?(S(s[0],l[1])>S(s[0],s[1])&&(s[1]=l[1]),S(l[0],s[1])>S(s[0],s[1])&&(s[0]=l[0])):c.push(s=l);for(u=-1/0,e=0,s=c[r=c.length-1];e<=r;s=l,++e)l=c[e],(p=S(s[1],l[0]))>u&&(u=p,n=l[0],a=s[1])}return h=f=null,n===1/0||i===1/0?[[NaN,NaN],[NaN,NaN]]:[[n,i],[a,o]]}},20375:function(t,e,r){\"use strict\";r.d(e,{Cx:function(){return u},EV:function(){return i},W8:function(){return o},ep:function(){return l},jf:function(){return a},ly:function(){return c},r8:function(){return s}});var n=r(61323);function i(t){return[(0,n.FP)(t[1],t[0]),(0,n.qR)(t[2])]}function a(t){var e=t[0],r=t[1],i=(0,n.gn)(r);return[i*(0,n.gn)(e),i*(0,n.F8)(e),(0,n.F8)(r)]}function o(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function s(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function l(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function c(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function u(t){var e=(0,n.RZ)(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}},30021:function(t,e,r){\"use strict\";r.d(e,{A:function(){return z}});var n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x=r(61323),_=r(53341),b=r(20465),w={sphere:_.A,point:T,lineStart:A,lineEnd:E,polygonStart:function(){w.lineStart=C,w.lineEnd=L},polygonEnd:function(){w.lineStart=A,w.lineEnd=E}};function T(t,e){t*=x.F2,e*=x.F2;var r=(0,x.gn)(e);k(r*(0,x.gn)(t),r*(0,x.F8)(t),(0,x.F8)(e))}function k(t,e,r){++n,a+=(t-a)/n,o+=(e-o)/n,s+=(r-s)/n}function A(){w.point=M}function M(t,e){t*=x.F2,e*=x.F2;var r=(0,x.gn)(e);g=r*(0,x.gn)(t),y=r*(0,x.F8)(t),v=(0,x.F8)(e),w.point=S,k(g,y,v)}function S(t,e){t*=x.F2,e*=x.F2;var r=(0,x.gn)(e),n=r*(0,x.gn)(t),a=r*(0,x.F8)(t),o=(0,x.F8)(e),s=(0,x.FP)((0,x.RZ)((s=y*o-v*a)*s+(s=v*n-g*o)*s+(s=g*a-y*n)*s),g*n+y*a+v*o);i+=s,l+=s*(g+(g=n)),c+=s*(y+(y=a)),u+=s*(v+(v=o)),k(g,y,v)}function E(){w.point=T}function C(){w.point=I}function L(){P(d,m),w.point=T}function I(t,e){d=t,m=e,t*=x.F2,e*=x.F2,w.point=P;var r=(0,x.gn)(e);g=r*(0,x.gn)(t),y=r*(0,x.F8)(t),v=(0,x.F8)(e),k(g,y,v)}function P(t,e){t*=x.F2,e*=x.F2;var r=(0,x.gn)(e),n=r*(0,x.gn)(t),a=r*(0,x.F8)(t),o=(0,x.F8)(e),s=y*o-v*a,d=v*n-g*o,m=g*a-y*n,_=(0,x.RZ)(s*s+d*d+m*m),b=(0,x.qR)(_),w=_&&-b/_;h+=w*s,f+=w*d,p+=w*m,i+=b,l+=b*(g+(g=n)),c+=b*(y+(y=a)),u+=b*(v+(v=o)),k(g,y,v)}function z(t){n=i=a=o=s=l=c=u=h=f=p=0,(0,b.A)(t,w);var e=h,r=f,d=p,m=e*e+r*r+d*d;return m<x.$t&&(e=l,r=c,d=u,i<x.Ni&&(e=a,r=o,d=s),(m=e*e+r*r+d*d)<x.$t)?[NaN,NaN]:[(0,x.FP)(r,e)*x.uj,(0,x.qR)(d/(0,x.RZ)(m))*x.uj]}},39127:function(t,e,r){\"use strict\";r.d(e,{J:function(){return s},A:function(){return c}});var n=r(20375);function i(t){return function(){return t}}var a=r(61323),o=r(30915);function s(t,e,r,i,o,s){if(r){var c=(0,a.gn)(e),u=(0,a.F8)(e),h=i*r;null==o?(o=e+i*a.FA,s=e-h/2):(o=l(c,o),s=l(c,s),(i>0?o<s:o>s)&&(o+=i*a.FA));for(var f,p=o;i>0?p>s:p<s;p-=h)f=(0,n.EV)([c,-u*(0,a.gn)(p),-u*(0,a.F8)(p)]),t.point(f[0],f[1])}}function l(t,e){(e=(0,n.jf)(e))[0]-=t,(0,n.Cx)(e);var r=(0,a.HQ)(-e[1]);return((-e[2]<0?-r:r)+a.FA-a.Ni)%a.FA}function c(){var t,e,r=i([0,0]),n=i(90),l=i(6),c={point:function(r,n){t.push(r=e(r,n)),r[0]*=a.uj,r[1]*=a.uj}};function u(){var i=r.apply(this,arguments),u=n.apply(this,arguments)*a.F2,h=l.apply(this,arguments)*a.F2;return t=[],e=(0,o.y)(-i[0]*a.F2,-i[1]*a.F2,0).invert,s(c,u,h,1),i={type:\"Polygon\",coordinates:[t]},t=e=null,i}return u.center=function(t){return arguments.length?(r=\"function\"==typeof t?t:i([+t[0],+t[1]]),u):r},u.radius=function(t){return arguments.length?(n=\"function\"==typeof t?t:i(+t),u):n},u.precision=function(t){return arguments.length?(l=\"function\"==typeof t?t:i(+t),u):l},u}},42413:function(t,e,r){\"use strict\";var n=r(13720),i=r(61323);e.A=(0,n.A)((function(){return!0}),(function(t){var e,r=NaN,n=NaN,a=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(o,s){var l=o>0?i.pi:-i.pi,c=(0,i.tn)(o-r);(0,i.tn)(c-i.pi)<i.Ni?(t.point(r,n=(n+s)/2>0?i.TW:-i.TW),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(l,n),t.point(o,n),e=0):a!==l&&c>=i.pi&&((0,i.tn)(r-a)<i.Ni&&(r-=a*i.Ni),(0,i.tn)(o-l)<i.Ni&&(o-=l*i.Ni),n=function(t,e,r,n){var a,o,s=(0,i.F8)(t-r);return(0,i.tn)(s)>i.Ni?(0,i.rY)(((0,i.F8)(e)*(o=(0,i.gn)(n))*(0,i.F8)(r)-(0,i.F8)(n)*(a=(0,i.gn)(e))*(0,i.F8)(t))/(a*o*s)):(e+n)/2}(r,n,o,s),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(l,n),e=0),t.point(r=o,n=s),a=l},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}}),(function(t,e,r,n){var a;if(null==t)a=r*i.TW,n.point(-i.pi,a),n.point(0,a),n.point(i.pi,a),n.point(i.pi,0),n.point(i.pi,-a),n.point(0,-a),n.point(-i.pi,-a),n.point(-i.pi,0),n.point(-i.pi,a);else if((0,i.tn)(t[0]-e[0])>i.Ni){var o=t[0]<e[0]?i.pi:-i.pi;a=r*o/2,n.point(-o,a),n.point(0,a),n.point(o,a)}else n.point(e[0],e[1])}),[-i.pi,-i.TW])},39608:function(t,e,r){\"use strict\";r.d(e,{A:function(){return i}});var n=r(53341);function i(){var t,e=[];return{point:function(e,r,n){t.push([e,r,n])},lineStart:function(){e.push(t=[])},lineEnd:n.A,rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))},result:function(){var r=e;return e=[],t=null,r}}}},47402:function(t,e,r){\"use strict\";r.d(e,{A:function(){return l}});var n=r(20375),i=r(39127),a=r(61323),o=r(28759),s=r(13720);function l(t){var e=(0,a.gn)(t),r=6*a.F2,l=e>0,c=(0,a.tn)(e)>a.Ni;function u(t,r){return(0,a.gn)(t)*(0,a.gn)(r)>e}function h(t,r,i){var o=(0,n.jf)(t),s=(0,n.jf)(r),l=[1,0,0],c=(0,n.r8)(o,s),u=(0,n.W8)(c,c),h=c[0],f=u-h*h;if(!f)return!i&&t;var p=e*u/f,d=-e*h/f,m=(0,n.r8)(l,c),g=(0,n.ly)(l,p),y=(0,n.ly)(c,d);(0,n.ep)(g,y);var v=m,x=(0,n.W8)(g,v),_=(0,n.W8)(v,v),b=x*x-_*((0,n.W8)(g,g)-1);if(!(b<0)){var w=(0,a.RZ)(b),T=(0,n.ly)(v,(-x-w)/_);if((0,n.ep)(T,g),T=(0,n.EV)(T),!i)return T;var k,A=t[0],M=r[0],S=t[1],E=r[1];M<A&&(k=A,A=M,M=k);var C=M-A,L=(0,a.tn)(C-a.pi)<a.Ni;if(!L&&E<S&&(k=S,S=E,E=k),L||C<a.Ni?L?S+E>0^T[1]<((0,a.tn)(T[0]-A)<a.Ni?S:E):S<=T[1]&&T[1]<=E:C>a.pi^(A<=T[0]&&T[0]<=M)){var I=(0,n.ly)(v,(-x+w)/_);return(0,n.ep)(I,g),[T,(0,n.EV)(I)]}}}function f(e,r){var n=l?t:a.pi-t,i=0;return e<-n?i|=1:e>n&&(i|=2),r<-n?i|=4:r>n&&(i|=8),i}return(0,s.A)(u,(function(t){var e,r,n,i,s;return{lineStart:function(){i=n=!1,s=1},point:function(p,d){var m,g=[p,d],y=u(p,d),v=l?y?0:f(p,d):y?f(p+(p<0?a.pi:-a.pi),d):0;if(!e&&(i=n=y)&&t.lineStart(),y!==n&&(!(m=h(e,g))||(0,o.A)(e,m)||(0,o.A)(g,m))&&(g[2]=1),y!==n)s=0,y?(t.lineStart(),m=h(g,e),t.point(m[0],m[1])):(m=h(e,g),t.point(m[0],m[1],2),t.lineEnd()),e=m;else if(c&&e&&l^y){var x;v&r||!(x=h(g,e,!0))||(s=0,l?(t.lineStart(),t.point(x[0][0],x[0][1]),t.point(x[1][0],x[1][1]),t.lineEnd()):(t.point(x[1][0],x[1][1]),t.lineEnd(),t.lineStart(),t.point(x[0][0],x[0][1],3)))}!y||e&&(0,o.A)(e,g)||t.point(g[0],g[1]),e=g,n=y,r=v},lineEnd:function(){n&&t.lineEnd(),e=null},clean:function(){return s|(i&&n)<<1}}}),(function(e,n,a,o){(0,i.J)(o,t,r,a,e,n)}),l?[0,-t]:[-a.pi,t-a.pi])}},13720:function(t,e,r){\"use strict\";r.d(e,{A:function(){return l}});var n=r(39608),i=r(19119),a=r(61323),o=r(2274),s=r(29725);function l(t,e,r,a){return function(l){var h,f,p,d=e(l),m=(0,n.A)(),g=e(m),y=!1,v={point:x,lineStart:b,lineEnd:w,polygonStart:function(){v.point=T,v.lineStart=k,v.lineEnd=A,f=[],h=[]},polygonEnd:function(){v.point=x,v.lineStart=b,v.lineEnd=w,f=(0,s.Am)(f);var t=(0,o.A)(h,a);f.length?(y||(l.polygonStart(),y=!0),(0,i.A)(f,u,t,r,l)):t&&(y||(l.polygonStart(),y=!0),l.lineStart(),r(null,null,1,l),l.lineEnd()),y&&(l.polygonEnd(),y=!1),f=h=null},sphere:function(){l.polygonStart(),l.lineStart(),r(null,null,1,l),l.lineEnd(),l.polygonEnd()}};function x(e,r){t(e,r)&&l.point(e,r)}function _(t,e){d.point(t,e)}function b(){v.point=_,d.lineStart()}function w(){v.point=x,d.lineEnd()}function T(t,e){p.push([t,e]),g.point(t,e)}function k(){g.lineStart(),p=[]}function A(){T(p[0][0],p[0][1]),g.lineEnd();var t,e,r,n,i=g.clean(),a=m.result(),o=a.length;if(p.pop(),h.push(p),p=null,o)if(1&i){if((e=(r=a[0]).length-1)>0){for(y||(l.polygonStart(),y=!0),l.lineStart(),t=0;t<e;++t)l.point((n=r[t])[0],n[1]);l.lineEnd()}}else o>1&&2&i&&a.push(a.pop().concat(a.shift())),f.push(a.filter(c))}return v}}function c(t){return t.length>1}function u(t,e){return((t=t.x)[0]<0?t[1]-a.TW-a.Ni:a.TW-t[1])-((e=e.x)[0]<0?e[1]-a.TW-a.Ni:a.TW-e[1])}},21503:function(t,e,r){\"use strict\";r.d(e,{A:function(){return c}});var n=r(61323),i=r(39608),a=r(19119),o=r(29725),s=1e9,l=-s;function c(t,e,r,c){function u(n,i){return t<=n&&n<=r&&e<=i&&i<=c}function h(n,i,a,o){var s=0,l=0;if(null==n||(s=f(n,a))!==(l=f(i,a))||d(n,i)<0^a>0)do{o.point(0===s||3===s?t:r,s>1?c:e)}while((s=(s+a+4)%4)!==l);else o.point(i[0],i[1])}function f(i,a){return(0,n.tn)(i[0]-t)<n.Ni?a>0?0:3:(0,n.tn)(i[0]-r)<n.Ni?a>0?2:1:(0,n.tn)(i[1]-e)<n.Ni?a>0?1:0:a>0?3:2}function p(t,e){return d(t.x,e.x)}function d(t,e){var r=f(t,1),n=f(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}return function(n){var f,d,m,g,y,v,x,_,b,w,T,k=n,A=(0,i.A)(),M={point:S,lineStart:function(){M.point=E,d&&d.push(m=[]),w=!0,b=!1,x=_=NaN},lineEnd:function(){f&&(E(g,y),v&&b&&A.rejoin(),f.push(A.result())),M.point=S,b&&k.lineEnd()},polygonStart:function(){k=A,f=[],d=[],T=!0},polygonEnd:function(){var e=function(){for(var e=0,r=0,n=d.length;r<n;++r)for(var i,a,o=d[r],s=1,l=o.length,u=o[0],h=u[0],f=u[1];s<l;++s)i=h,a=f,h=(u=o[s])[0],f=u[1],a<=c?f>c&&(h-i)*(c-a)>(f-a)*(t-i)&&++e:f<=c&&(h-i)*(c-a)<(f-a)*(t-i)&&--e;return e}(),r=T&&e,i=(f=(0,o.Am)(f)).length;(r||i)&&(n.polygonStart(),r&&(n.lineStart(),h(null,null,1,n),n.lineEnd()),i&&(0,a.A)(f,p,e,h,n),n.polygonEnd()),k=n,f=d=m=null}};function S(t,e){u(t,e)&&k.point(t,e)}function E(n,i){var a=u(n,i);if(d&&m.push([n,i]),w)g=n,y=i,v=a,w=!1,a&&(k.lineStart(),k.point(n,i));else if(a&&b)k.point(n,i);else{var o=[x=Math.max(l,Math.min(s,x)),_=Math.max(l,Math.min(s,_))],h=[n=Math.max(l,Math.min(s,n)),i=Math.max(l,Math.min(s,i))];!function(t,e,r,n,i,a){var o,s=t[0],l=t[1],c=0,u=1,h=e[0]-s,f=e[1]-l;if(o=r-s,h||!(o>0)){if(o/=h,h<0){if(o<c)return;o<u&&(u=o)}else if(h>0){if(o>u)return;o>c&&(c=o)}if(o=i-s,h||!(o<0)){if(o/=h,h<0){if(o>u)return;o>c&&(c=o)}else if(h>0){if(o<c)return;o<u&&(u=o)}if(o=n-l,f||!(o>0)){if(o/=f,f<0){if(o<c)return;o<u&&(u=o)}else if(f>0){if(o>u)return;o>c&&(c=o)}if(o=a-l,f||!(o<0)){if(o/=f,f<0){if(o>u)return;o>c&&(c=o)}else if(f>0){if(o<c)return;o<u&&(u=o)}return c>0&&(t[0]=s+c*h,t[1]=l+c*f),u<1&&(e[0]=s+u*h,e[1]=l+u*f),!0}}}}}(o,h,t,e,r,c)?a&&(k.lineStart(),k.point(n,i),T=!1):(b||(k.lineStart(),k.point(o[0],o[1])),k.point(h[0],h[1]),a||k.lineEnd(),T=!1)}x=n,_=i,b=a}return M}}},19119:function(t,e,r){\"use strict\";r.d(e,{A:function(){return o}});var n=r(28759),i=r(61323);function a(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function o(t,e,r,o,l){var c,u,h=[],f=[];if(t.forEach((function(t){if(!((e=t.length-1)<=0)){var e,r,o=t[0],s=t[e];if((0,n.A)(o,s)){if(!o[2]&&!s[2]){for(l.lineStart(),c=0;c<e;++c)l.point((o=t[c])[0],o[1]);return void l.lineEnd()}s[0]+=2*i.Ni}h.push(r=new a(o,t,null,!0)),f.push(r.o=new a(o,null,r,!1)),h.push(r=new a(s,t,null,!1)),f.push(r.o=new a(s,null,r,!0))}})),h.length){for(f.sort(e),s(h),s(f),c=0,u=f.length;c<u;++c)f[c].e=r=!r;for(var p,d,m=h[0];;){for(var g=m,y=!0;g.v;)if((g=g.n)===m)return;p=g.z,l.lineStart();do{if(g.v=g.o.v=!0,g.e){if(y)for(c=0,u=p.length;c<u;++c)l.point((d=p[c])[0],d[1]);else o(g.x,g.n.x,1,l);g=g.n}else{if(y)for(p=g.p.z,c=p.length-1;c>=0;--c)l.point((d=p[c])[0],d[1]);else o(g.x,g.p.x,-1,l);g=g.p}p=(g=g.o).z,y=!y}while(!g.v);l.lineEnd()}}}function s(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}},19057:function(t,e,r){\"use strict\";function n(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}r.d(e,{A:function(){return n}})},26827:function(t,e,r){\"use strict\";function n(t){return t}r.d(e,{A:function(){return n}})},70884:function(t,e,r){\"use strict\";r.r(e),r.d(e,{geoAlbers:function(){return Gt},geoAlbersUsa:function(){return Wt},geoArea:function(){return n.Ay},geoAzimuthalEqualArea:function(){return Yt.A},geoAzimuthalEqualAreaRaw:function(){return Yt.n},geoAzimuthalEquidistant:function(){return Xt.A},geoAzimuthalEquidistantRaw:function(){return Xt.j},geoBounds:function(){return i.A},geoCentroid:function(){return a.A},geoCircle:function(){return o.A},geoClipAntimeridian:function(){return s.A},geoClipCircle:function(){return l.A},geoClipExtent:function(){return u},geoClipRectangle:function(){return c.A},geoConicConformal:function(){return re},geoConicConformalRaw:function(){return ee},geoConicEqualArea:function(){return Ht},geoConicEqualAreaRaw:function(){return qt},geoConicEquidistant:function(){return ae},geoConicEquidistantRaw:function(){return ie},geoContains:function(){return R},geoDistance:function(){return S},geoEqualEarth:function(){return fe},geoEqualEarthRaw:function(){return he},geoEquirectangular:function(){return ne.A},geoEquirectangularRaw:function(){return ne.f},geoGnomonic:function(){return pe.A},geoGnomonicRaw:function(){return pe.T},geoGraticule:function(){return j},geoGraticule10:function(){return U},geoIdentity:function(){return me},geoInterpolate:function(){return Z.A},geoLength:function(){return k},geoMercator:function(){return Kt},geoMercatorRaw:function(){return Jt},geoNaturalEarth1:function(){return ge.A},geoNaturalEarth1Raw:function(){return ge.P},geoOrthographic:function(){return ye.A},geoOrthographicRaw:function(){return ye.x},geoPath:function(){return jt},geoProjection:function(){return Ut.A},geoProjectionMutator:function(){return Ut.U},geoRotation:function(){return $t.A},geoStereographic:function(){return _e},geoStereographicRaw:function(){return xe},geoStream:function(){return v.A},geoTransform:function(){return de.A},geoTransverseMercator:function(){return we},geoTransverseMercatorRaw:function(){return be}});var n=r(43976),i=r(43212),a=r(30021),o=r(39127),s=r(42413),l=r(47402),c=r(21503);function u(){var t,e,r,n=0,i=0,a=960,o=500;return r={stream:function(r){return t&&e===r?t:t=(0,c.A)(n,i,a,o)(e=r)},extent:function(s){return arguments.length?(n=+s[0][0],i=+s[0][1],a=+s[1][0],o=+s[1][1],t=e=null,r):[[n,i],[a,o]]}}}var h,f,p,d=r(2274),m=r(49353),g=r(61323),y=r(53341),v=r(20465),x=(0,m.A)(),_={sphere:y.A,point:y.A,lineStart:function(){_.point=w,_.lineEnd=b},lineEnd:y.A,polygonStart:y.A,polygonEnd:y.A};function b(){_.point=_.lineEnd=y.A}function w(t,e){t*=g.F2,e*=g.F2,h=t,f=(0,g.F8)(e),p=(0,g.gn)(e),_.point=T}function T(t,e){t*=g.F2,e*=g.F2;var r=(0,g.F8)(e),n=(0,g.gn)(e),i=(0,g.tn)(t-h),a=(0,g.gn)(i),o=n*(0,g.F8)(i),s=p*r-f*n*a,l=f*r+p*n*a;x.add((0,g.FP)((0,g.RZ)(o*o+s*s),l)),h=t,f=r,p=n}function k(t){return x.reset(),(0,v.A)(t,_),+x}var A=[null,null],M={type:\"LineString\",coordinates:A};function S(t,e){return A[0]=t,A[1]=e,k(M)}var E={Feature:function(t,e){return L(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)if(L(r[n].geometry,e))return!0;return!1}},C={Sphere:function(){return!0},Point:function(t,e){return I(t.coordinates,e)},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)if(I(r[n],e))return!0;return!1},LineString:function(t,e){return P(t.coordinates,e)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)if(P(r[n],e))return!0;return!1},Polygon:function(t,e){return z(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)if(z(r[n],e))return!0;return!1},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)if(L(r[n],e))return!0;return!1}};function L(t,e){return!(!t||!C.hasOwnProperty(t.type))&&C[t.type](t,e)}function I(t,e){return 0===S(t,e)}function P(t,e){for(var r,n,i,a=0,o=t.length;a<o;a++){if(0===(n=S(t[a],e)))return!0;if(a>0&&(i=S(t[a],t[a-1]))>0&&r<=i&&n<=i&&(r+n-i)*(1-Math.pow((r-n)/i,2))<g.$t*i)return!0;r=n}return!1}function z(t,e){return!!(0,d.A)(t.map(O),D(e))}function O(t){return(t=t.map(D)).pop(),t}function D(t){return[t[0]*g.F2,t[1]*g.F2]}function R(t,e){return(t&&E.hasOwnProperty(t.type)?E[t.type]:L)(t,e)}var F=r(29725);function B(t,e,r){var n=(0,F.y1)(t,e-g.Ni,r).concat(e);return function(t){return n.map((function(e){return[t,e]}))}}function N(t,e,r){var n=(0,F.y1)(t,e-g.Ni,r).concat(e);return function(t){return n.map((function(e){return[e,t]}))}}function j(){var t,e,r,n,i,a,o,s,l,c,u,h,f=10,p=f,d=90,m=360,y=2.5;function v(){return{type:\"MultiLineString\",coordinates:x()}}function x(){return(0,F.y1)((0,g.mk)(n/d)*d,r,d).map(u).concat((0,F.y1)((0,g.mk)(s/m)*m,o,m).map(h)).concat((0,F.y1)((0,g.mk)(e/f)*f,t,f).filter((function(t){return(0,g.tn)(t%d)>g.Ni})).map(l)).concat((0,F.y1)((0,g.mk)(a/p)*p,i,p).filter((function(t){return(0,g.tn)(t%m)>g.Ni})).map(c))}return v.lines=function(){return x().map((function(t){return{type:\"LineString\",coordinates:t}}))},v.outline=function(){return{type:\"Polygon\",coordinates:[u(n).concat(h(o).slice(1),u(r).reverse().slice(1),h(s).reverse().slice(1))]}},v.extent=function(t){return arguments.length?v.extentMajor(t).extentMinor(t):v.extentMinor()},v.extentMajor=function(t){return arguments.length?(n=+t[0][0],r=+t[1][0],s=+t[0][1],o=+t[1][1],n>r&&(t=n,n=r,r=t),s>o&&(t=s,s=o,o=t),v.precision(y)):[[n,s],[r,o]]},v.extentMinor=function(r){return arguments.length?(e=+r[0][0],t=+r[1][0],a=+r[0][1],i=+r[1][1],e>t&&(r=e,e=t,t=r),a>i&&(r=a,a=i,i=r),v.precision(y)):[[e,a],[t,i]]},v.step=function(t){return arguments.length?v.stepMajor(t).stepMinor(t):v.stepMinor()},v.stepMajor=function(t){return arguments.length?(d=+t[0],m=+t[1],v):[d,m]},v.stepMinor=function(t){return arguments.length?(f=+t[0],p=+t[1],v):[f,p]},v.precision=function(f){return arguments.length?(y=+f,l=B(a,i,90),c=N(e,t,y),u=B(s,o,90),h=N(n,r,y),v):y},v.extentMajor([[-180,-90+g.Ni],[180,90-g.Ni]]).extentMinor([[-180,-80-g.Ni],[180,80+g.Ni]])}function U(){return j()()}var V,q,H,G,Z=r(81758),W=r(26827),Y=(0,m.A)(),X=(0,m.A)(),$={point:y.A,lineStart:y.A,lineEnd:y.A,polygonStart:function(){$.lineStart=J,$.lineEnd=tt},polygonEnd:function(){$.lineStart=$.lineEnd=$.point=y.A,Y.add((0,g.tn)(X)),X.reset()},result:function(){var t=Y/2;return Y.reset(),t}};function J(){$.point=K}function K(t,e){$.point=Q,V=H=t,q=G=e}function Q(t,e){X.add(G*t-H*e),H=t,G=e}function tt(){Q(V,q)}var et,rt,nt,it,at=$,ot=r(33028),st=0,lt=0,ct=0,ut=0,ht=0,ft=0,pt=0,dt=0,mt=0,gt={point:yt,lineStart:vt,lineEnd:bt,polygonStart:function(){gt.lineStart=wt,gt.lineEnd=Tt},polygonEnd:function(){gt.point=yt,gt.lineStart=vt,gt.lineEnd=bt},result:function(){var t=mt?[pt/mt,dt/mt]:ft?[ut/ft,ht/ft]:ct?[st/ct,lt/ct]:[NaN,NaN];return st=lt=ct=ut=ht=ft=pt=dt=mt=0,t}};function yt(t,e){st+=t,lt+=e,++ct}function vt(){gt.point=xt}function xt(t,e){gt.point=_t,yt(nt=t,it=e)}function _t(t,e){var r=t-nt,n=e-it,i=(0,g.RZ)(r*r+n*n);ut+=i*(nt+t)/2,ht+=i*(it+e)/2,ft+=i,yt(nt=t,it=e)}function bt(){gt.point=yt}function wt(){gt.point=kt}function Tt(){At(et,rt)}function kt(t,e){gt.point=At,yt(et=nt=t,rt=it=e)}function At(t,e){var r=t-nt,n=e-it,i=(0,g.RZ)(r*r+n*n);ut+=i*(nt+t)/2,ht+=i*(it+e)/2,ft+=i,pt+=(i=it*t-nt*e)*(nt+t),dt+=i*(it+e),mt+=3*i,yt(nt=t,it=e)}var Mt=gt;function St(t){this._context=t}St.prototype={_radius:4.5,pointRadius:function(t){return this._radius=t,this},polygonStart:function(){this._line=0},polygonEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){0===this._line&&this._context.closePath(),this._point=NaN},point:function(t,e){switch(this._point){case 0:this._context.moveTo(t,e),this._point=1;break;case 1:this._context.lineTo(t,e);break;default:this._context.moveTo(t+this._radius,e),this._context.arc(t,e,this._radius,0,g.FA)}},result:y.A};var Et,Ct,Lt,It,Pt,zt=(0,m.A)(),Ot={point:y.A,lineStart:function(){Ot.point=Dt},lineEnd:function(){Et&&Rt(Ct,Lt),Ot.point=y.A},polygonStart:function(){Et=!0},polygonEnd:function(){Et=null},result:function(){var t=+zt;return zt.reset(),t}};function Dt(t,e){Ot.point=Rt,Ct=It=t,Lt=Pt=e}function Rt(t,e){It-=t,Pt-=e,zt.add((0,g.RZ)(It*It+Pt*Pt)),It=t,Pt=e}var Ft=Ot;function Bt(){this._string=[]}function Nt(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}function jt(t,e){var r,n,i=4.5;function a(t){return t&&(\"function\"==typeof i&&n.pointRadius(+i.apply(this,arguments)),(0,v.A)(t,r(n))),n.result()}return a.area=function(t){return(0,v.A)(t,r(at)),at.result()},a.measure=function(t){return(0,v.A)(t,r(Ft)),Ft.result()},a.bounds=function(t){return(0,v.A)(t,r(ot.A)),ot.A.result()},a.centroid=function(t){return(0,v.A)(t,r(Mt)),Mt.result()},a.projection=function(e){return arguments.length?(r=null==e?(t=null,W.A):(t=e).stream,a):t},a.context=function(t){return arguments.length?(n=null==t?(e=null,new Bt):new St(e=t),\"function\"!=typeof i&&n.pointRadius(i),a):e},a.pointRadius=function(t){return arguments.length?(i=\"function\"==typeof t?t:(n.pointRadius(+t),+t),a):i},a.projection(t).context(e)}Bt.prototype={_radius:4.5,_circle:Nt(4.5),pointRadius:function(t){return(t=+t)!==this._radius&&(this._radius=t,this._circle=null),this},polygonStart:function(){this._line=0},polygonEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){0===this._line&&this._string.push(\"Z\"),this._point=NaN},point:function(t,e){switch(this._point){case 0:this._string.push(\"M\",t,\",\",e),this._point=1;break;case 1:this._string.push(\"L\",t,\",\",e);break;default:null==this._circle&&(this._circle=Nt(this._radius)),this._string.push(\"M\",t,\",\",e,this._circle)}},result:function(){if(this._string.length){var t=this._string.join(\"\");return this._string=[],t}return null}};var Ut=r(94684);function Vt(t){var e=0,r=g.pi/3,n=(0,Ut.U)(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*g.F2,r=t[1]*g.F2):[e*g.uj,r*g.uj]},i}function qt(t,e){var r=(0,g.F8)(t),n=(r+(0,g.F8)(e))/2;if((0,g.tn)(n)<g.Ni)return function(t){var e=(0,g.gn)(t);function r(t,r){return[t*e,(0,g.F8)(r)/e]}return r.invert=function(t,r){return[t/e,(0,g.qR)(r*e)]},r}(t);var i=1+r*(2*n-r),a=(0,g.RZ)(i)/n;function o(t,e){var r=(0,g.RZ)(i-2*n*(0,g.F8)(e))/n;return[r*(0,g.F8)(t*=n),a-r*(0,g.gn)(t)]}return o.invert=function(t,e){var r=a-e,o=(0,g.FP)(t,(0,g.tn)(r))*(0,g._S)(r);return r*n<0&&(o-=g.pi*(0,g._S)(t)*(0,g._S)(r)),[o/n,(0,g.qR)((i-(t*t+r*r)*n*n)/(2*n))]},o}function Ht(){return Vt(qt).scale(155.424).center([0,33.6442])}function Gt(){return Ht().parallels([29.5,45.5]).scale(1070).translate([480,250]).rotate([96,0]).center([-.6,38.7])}var Zt=r(7944);function Wt(){var t,e,r,n,i,a,o=Gt(),s=Ht().rotate([154,0]).center([-2,58.5]).parallels([55,65]),l=Ht().rotate([157,0]).center([-3,19.9]).parallels([8,18]),c={point:function(t,e){a=[t,e]}};function u(t){var e=t[0],o=t[1];return a=null,r.point(e,o),a||(n.point(e,o),a)||(i.point(e,o),a)}function h(){return t=e=null,u}return u.invert=function(t){var e=o.scale(),r=o.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?s:i>=.166&&i<.234&&n>=-.214&&n<-.115?l:o).invert(t)},u.stream=function(r){return t&&e===r?t:(n=[o.stream(e=r),s.stream(r),l.stream(r)],i=n.length,t={point:function(t,e){for(var r=-1;++r<i;)n[r].point(t,e)},sphere:function(){for(var t=-1;++t<i;)n[t].sphere()},lineStart:function(){for(var t=-1;++t<i;)n[t].lineStart()},lineEnd:function(){for(var t=-1;++t<i;)n[t].lineEnd()},polygonStart:function(){for(var t=-1;++t<i;)n[t].polygonStart()},polygonEnd:function(){for(var t=-1;++t<i;)n[t].polygonEnd()}});var n,i},u.precision=function(t){return arguments.length?(o.precision(t),s.precision(t),l.precision(t),h()):o.precision()},u.scale=function(t){return arguments.length?(o.scale(t),s.scale(.35*t),l.scale(t),u.translate(o.translate())):o.scale()},u.translate=function(t){if(!arguments.length)return o.translate();var e=o.scale(),a=+t[0],u=+t[1];return r=o.translate(t).clipExtent([[a-.455*e,u-.238*e],[a+.455*e,u+.238*e]]).stream(c),n=s.translate([a-.307*e,u+.201*e]).clipExtent([[a-.425*e+g.Ni,u+.12*e+g.Ni],[a-.214*e-g.Ni,u+.234*e-g.Ni]]).stream(c),i=l.translate([a-.205*e,u+.212*e]).clipExtent([[a-.214*e+g.Ni,u+.166*e+g.Ni],[a-.115*e-g.Ni,u+.234*e-g.Ni]]).stream(c),h()},u.fitExtent=function(t,e){return(0,Zt.sp)(u,t,e)},u.fitSize=function(t,e){return(0,Zt.Hv)(u,t,e)},u.fitWidth=function(t,e){return(0,Zt.G0)(u,t,e)},u.fitHeight=function(t,e){return(0,Zt.FL)(u,t,e)},u.scale(1070)}var Yt=r(30729),Xt=r(61957),$t=r(30915);function Jt(t,e){return[t,(0,g.Rm)((0,g.Ml)((g.TW+e)/2))]}function Kt(){return Qt(Jt).scale(961/g.FA)}function Qt(t){var e,r,n,i=(0,Ut.A)(t),a=i.center,o=i.scale,s=i.translate,l=i.clipExtent,c=null;function u(){var a=g.pi*o(),s=i((0,$t.A)(i.rotate()).invert([0,0]));return l(null==c?[[s[0]-a,s[1]-a],[s[0]+a,s[1]+a]]:t===Jt?[[Math.max(s[0]-a,c),e],[Math.min(s[0]+a,r),n]]:[[c,Math.max(s[1]-a,e)],[r,Math.min(s[1]+a,n)]])}return i.scale=function(t){return arguments.length?(o(t),u()):o()},i.translate=function(t){return arguments.length?(s(t),u()):s()},i.center=function(t){return arguments.length?(a(t),u()):a()},i.clipExtent=function(t){return arguments.length?(null==t?c=e=r=n=null:(c=+t[0][0],e=+t[0][1],r=+t[1][0],n=+t[1][1]),u()):null==c?null:[[c,e],[r,n]]},u()}function te(t){return(0,g.Ml)((g.TW+t)/2)}function ee(t,e){var r=(0,g.gn)(t),n=t===e?(0,g.F8)(t):(0,g.Rm)(r/(0,g.gn)(e))/(0,g.Rm)(te(e)/te(t)),i=r*(0,g.n7)(te(t),n)/n;if(!n)return Jt;function a(t,e){i>0?e<-g.TW+g.Ni&&(e=-g.TW+g.Ni):e>g.TW-g.Ni&&(e=g.TW-g.Ni);var r=i/(0,g.n7)(te(e),n);return[r*(0,g.F8)(n*t),i-r*(0,g.gn)(n*t)]}return a.invert=function(t,e){var r=i-e,a=(0,g._S)(n)*(0,g.RZ)(t*t+r*r),o=(0,g.FP)(t,(0,g.tn)(r))*(0,g._S)(r);return r*n<0&&(o-=g.pi*(0,g._S)(t)*(0,g._S)(r)),[o/n,2*(0,g.rY)((0,g.n7)(i/a,1/n))-g.TW]},a}function re(){return Vt(ee).scale(109.5).parallels([30,30])}Jt.invert=function(t,e){return[t,2*(0,g.rY)((0,g.oN)(e))-g.TW]};var ne=r(18139);function ie(t,e){var r=(0,g.gn)(t),n=t===e?(0,g.F8)(t):(r-(0,g.gn)(e))/(e-t),i=r/n+t;if((0,g.tn)(n)<g.Ni)return ne.f;function a(t,e){var r=i-e,a=n*t;return[r*(0,g.F8)(a),i-r*(0,g.gn)(a)]}return a.invert=function(t,e){var r=i-e,a=(0,g.FP)(t,(0,g.tn)(r))*(0,g._S)(r);return r*n<0&&(a-=g.pi*(0,g._S)(t)*(0,g._S)(r)),[a/n,i-(0,g._S)(n)*(0,g.RZ)(t*t+r*r)]},a}function ae(){return Vt(ie).scale(131.154).center([0,13.9389])}var oe=1.340264,se=-.081106,le=893e-6,ce=.003796,ue=(0,g.RZ)(3)/2;function he(t,e){var r=(0,g.qR)(ue*(0,g.F8)(e)),n=r*r,i=n*n*n;return[t*(0,g.gn)(r)/(ue*(oe+3*se*n+i*(7*le+9*ce*n))),r*(oe+se*n+i*(le+ce*n))]}function fe(){return(0,Ut.A)(he).scale(177.158)}he.invert=function(t,e){for(var r,n=e,i=n*n,a=i*i*i,o=0;o<12&&(a=(i=(n-=r=(n*(oe+se*i+a*(le+ce*i))-e)/(oe+3*se*i+a*(7*le+9*ce*i)))*n)*i*i,!((0,g.tn)(r)<g.$t));++o);return[ue*t*(oe+3*se*i+a*(7*le+9*ce*i))/(0,g.gn)(n),(0,g.qR)((0,g.F8)(n)/ue)]};var pe=r(48419),de=r(913);function me(){var t,e,r,n,i,a,o,s=1,l=0,u=0,h=1,f=1,p=0,d=null,m=1,y=1,v=(0,de.G)({point:function(t,e){var r=b([t,e]);this.stream.point(r[0],r[1])}}),x=W.A;function _(){return m=s*h,y=s*f,a=o=null,b}function b(r){var n=r[0]*m,i=r[1]*y;if(p){var a=i*t-n*e;n=n*t+i*e,i=a}return[n+l,i+u]}return b.invert=function(r){var n=r[0]-l,i=r[1]-u;if(p){var a=i*t+n*e;n=n*t-i*e,i=a}return[n/m,i/y]},b.stream=function(t){return a&&o===t?a:a=v(x(o=t))},b.postclip=function(t){return arguments.length?(x=t,d=r=n=i=null,_()):x},b.clipExtent=function(t){return arguments.length?(x=null==t?(d=r=n=i=null,W.A):(0,c.A)(d=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),_()):null==d?null:[[d,r],[n,i]]},b.scale=function(t){return arguments.length?(s=+t,_()):s},b.translate=function(t){return arguments.length?(l=+t[0],u=+t[1],_()):[l,u]},b.angle=function(r){return arguments.length?(p=r%360*g.F2,e=(0,g.F8)(p),t=(0,g.gn)(p),_()):p*g.uj},b.reflectX=function(t){return arguments.length?(h=t?-1:1,_()):h<0},b.reflectY=function(t){return arguments.length?(f=t?-1:1,_()):f<0},b.fitExtent=function(t,e){return(0,Zt.sp)(b,t,e)},b.fitSize=function(t,e){return(0,Zt.Hv)(b,t,e)},b.fitWidth=function(t,e){return(0,Zt.G0)(b,t,e)},b.fitHeight=function(t,e){return(0,Zt.FL)(b,t,e)},b}var ge=r(57949),ye=r(53253),ve=r(57738);function xe(t,e){var r=(0,g.gn)(e),n=1+(0,g.gn)(t)*r;return[r*(0,g.F8)(t)/n,(0,g.F8)(e)/n]}function _e(){return(0,Ut.A)(xe).scale(250).clipAngle(142)}function be(t,e){return[(0,g.Rm)((0,g.Ml)((g.TW+e)/2)),-t]}function we(){var t=Qt(be),e=t.center,r=t.rotate;return t.center=function(t){return arguments.length?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return arguments.length?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90]).scale(159.155)}xe.invert=(0,ve.I)((function(t){return 2*(0,g.rY)(t)})),be.invert=function(t,e){return[-e,2*(0,g.rY)((0,g.oN)(t))-g.TW]}},81758:function(t,e,r){\"use strict\";r.d(e,{A:function(){return i}});var n=r(61323);function i(t,e){var r=t[0]*n.F2,i=t[1]*n.F2,a=e[0]*n.F2,o=e[1]*n.F2,s=(0,n.gn)(i),l=(0,n.F8)(i),c=(0,n.gn)(o),u=(0,n.F8)(o),h=s*(0,n.gn)(r),f=s*(0,n.F8)(r),p=c*(0,n.gn)(a),d=c*(0,n.F8)(a),m=2*(0,n.qR)((0,n.RZ)((0,n.bo)(o-i)+s*c*(0,n.bo)(a-r))),g=(0,n.F8)(m),y=m?function(t){var e=(0,n.F8)(t*=m)/g,r=(0,n.F8)(m-t)/g,i=r*h+e*p,a=r*f+e*d,o=r*l+e*u;return[(0,n.FP)(a,i)*n.uj,(0,n.FP)(o,(0,n.RZ)(i*i+a*a))*n.uj]}:function(){return[r*n.uj,i*n.uj]};return y.distance=m,y}},61323:function(t,e,r){\"use strict\";r.d(e,{$t:function(){return i},F2:function(){return u},F8:function(){return x},FA:function(){return l},FP:function(){return p},HQ:function(){return T},Ml:function(){return w},Ni:function(){return n},RZ:function(){return b},Rm:function(){return y},TW:function(){return o},_S:function(){return _},bo:function(){return A},gn:function(){return d},gz:function(){return s},mk:function(){return m},n7:function(){return v},oN:function(){return g},pi:function(){return a},qR:function(){return k},rY:function(){return f},tn:function(){return h},uj:function(){return c}});var n=1e-6,i=1e-12,a=Math.PI,o=a/2,s=a/4,l=2*a,c=180/a,u=a/180,h=Math.abs,f=Math.atan,p=Math.atan2,d=Math.cos,m=Math.ceil,g=Math.exp,y=(Math.floor,Math.log),v=Math.pow,x=Math.sin,_=Math.sign||function(t){return t>0?1:t<0?-1:0},b=Math.sqrt,w=Math.tan;function T(t){return t>1?0:t<-1?a:Math.acos(t)}function k(t){return t>1?o:t<-1?-o:Math.asin(t)}function A(t){return(t=x(t/2))*t}},53341:function(t,e,r){\"use strict\";function n(){}r.d(e,{A:function(){return n}})},33028:function(t,e,r){\"use strict\";var n=r(53341),i=1/0,a=i,o=-i,s=o,l={point:function(t,e){t<i&&(i=t),t>o&&(o=t),e<a&&(a=e),e>s&&(s=e)},lineStart:n.A,lineEnd:n.A,polygonStart:n.A,polygonEnd:n.A,result:function(){var t=[[i,a],[o,s]];return o=s=-(a=i=1/0),t}};e.A=l},28759:function(t,e,r){\"use strict\";r.d(e,{A:function(){return i}});var n=r(61323);function i(t,e){return(0,n.tn)(t[0]-e[0])<n.Ni&&(0,n.tn)(t[1]-e[1])<n.Ni}},2274:function(t,e,r){\"use strict\";r.d(e,{A:function(){return l}});var n=r(49353),i=r(20375),a=r(61323),o=(0,n.A)();function s(t){return(0,a.tn)(t[0])<=a.pi?t[0]:(0,a._S)(t[0])*(((0,a.tn)(t[0])+a.pi)%a.FA-a.pi)}function l(t,e){var r=s(e),n=e[1],l=(0,a.F8)(n),c=[(0,a.F8)(r),-(0,a.gn)(r),0],u=0,h=0;o.reset(),1===l?n=a.TW+a.Ni:-1===l&&(n=-a.TW-a.Ni);for(var f=0,p=t.length;f<p;++f)if(m=(d=t[f]).length)for(var d,m,g=d[m-1],y=s(g),v=g[1]/2+a.gz,x=(0,a.F8)(v),_=(0,a.gn)(v),b=0;b<m;++b,y=T,x=A,_=M,g=w){var w=d[b],T=s(w),k=w[1]/2+a.gz,A=(0,a.F8)(k),M=(0,a.gn)(k),S=T-y,E=S>=0?1:-1,C=E*S,L=C>a.pi,I=x*A;if(o.add((0,a.FP)(I*E*(0,a.F8)(C),_*M+I*(0,a.gn)(C))),u+=L?S+E*a.FA:S,L^y>=r^T>=r){var P=(0,i.r8)((0,i.jf)(g),(0,i.jf)(w));(0,i.Cx)(P);var z=(0,i.r8)(c,P);(0,i.Cx)(z);var O=(L^S>=0?-1:1)*(0,a.qR)(z[2]);(n>O||n===O&&(P[0]||P[1]))&&(h+=L^S>=0?1:-1)}}return(u<-a.Ni||u<a.Ni&&o<-a.Ni)^1&h}},57738:function(t,e,r){\"use strict\";r.d(e,{I:function(){return a},c:function(){return i}});var n=r(61323);function i(t){return function(e,r){var i=(0,n.gn)(e),a=(0,n.gn)(r),o=t(i*a);return[o*a*(0,n.F8)(e),o*(0,n.F8)(r)]}}function a(t){return function(e,r){var i=(0,n.RZ)(e*e+r*r),a=t(i),o=(0,n.F8)(a),s=(0,n.gn)(a);return[(0,n.FP)(e*o,i*s),(0,n.qR)(i&&r*o/i)]}}},30729:function(t,e,r){\"use strict\";r.d(e,{A:function(){return s},n:function(){return o}});var n=r(61323),i=r(57738),a=r(94684),o=(0,i.c)((function(t){return(0,n.RZ)(2/(1+t))}));function s(){return(0,a.A)(o).scale(124.75).clipAngle(179.999)}o.invert=(0,i.I)((function(t){return 2*(0,n.qR)(t/2)}))},61957:function(t,e,r){\"use strict\";r.d(e,{A:function(){return s},j:function(){return o}});var n=r(61323),i=r(57738),a=r(94684),o=(0,i.c)((function(t){return(t=(0,n.HQ)(t))&&t/(0,n.F8)(t)}));function s(){return(0,a.A)(o).scale(79.4188).clipAngle(179.999)}o.invert=(0,i.I)((function(t){return t}))},18139:function(t,e,r){\"use strict\";r.d(e,{A:function(){return a},f:function(){return i}});var n=r(94684);function i(t,e){return[t,e]}function a(){return(0,n.A)(i).scale(152.63)}i.invert=i},7944:function(t,e,r){\"use strict\";r.d(e,{FL:function(){return c},G0:function(){return l},Hv:function(){return s},sp:function(){return o}});var n=r(20465),i=r(33028);function a(t,e,r){var a=t.clipExtent&&t.clipExtent();return t.scale(150).translate([0,0]),null!=a&&t.clipExtent(null),(0,n.A)(r,t.stream(i.A)),e(i.A.result()),null!=a&&t.clipExtent(a),t}function o(t,e,r){return a(t,(function(r){var n=e[1][0]-e[0][0],i=e[1][1]-e[0][1],a=Math.min(n/(r[1][0]-r[0][0]),i/(r[1][1]-r[0][1])),o=+e[0][0]+(n-a*(r[1][0]+r[0][0]))/2,s=+e[0][1]+(i-a*(r[1][1]+r[0][1]))/2;t.scale(150*a).translate([o,s])}),r)}function s(t,e,r){return o(t,[[0,0],e],r)}function l(t,e,r){return a(t,(function(r){var n=+e,i=n/(r[1][0]-r[0][0]),a=(n-i*(r[1][0]+r[0][0]))/2,o=-i*r[0][1];t.scale(150*i).translate([a,o])}),r)}function c(t,e,r){return a(t,(function(r){var n=+e,i=n/(r[1][1]-r[0][1]),a=-i*r[0][0],o=(n-i*(r[1][1]+r[0][1]))/2;t.scale(150*i).translate([a,o])}),r)}},48419:function(t,e,r){\"use strict\";r.d(e,{A:function(){return s},T:function(){return o}});var n=r(61323),i=r(57738),a=r(94684);function o(t,e){var r=(0,n.gn)(e),i=(0,n.gn)(t)*r;return[r*(0,n.F8)(t)/i,(0,n.F8)(e)/i]}function s(){return(0,a.A)(o).scale(144.049).clipAngle(60)}o.invert=(0,i.I)(n.rY)},94684:function(t,e,r){\"use strict\";r.d(e,{A:function(){return x},U:function(){return _}});var n=r(42413),i=r(47402),a=r(21503),o=r(19057),s=r(26827),l=r(61323),c=r(30915),u=r(913),h=r(7944),f=r(20375),p=16,d=(0,l.gn)(30*l.F2);function m(t,e){return+e?function(t,e){function r(n,i,a,o,s,c,u,h,f,p,m,g,y,v){var x=u-n,_=h-i,b=x*x+_*_;if(b>4*e&&y--){var w=o+p,T=s+m,k=c+g,A=(0,l.RZ)(w*w+T*T+k*k),M=(0,l.qR)(k/=A),S=(0,l.tn)((0,l.tn)(k)-1)<l.Ni||(0,l.tn)(a-f)<l.Ni?(a+f)/2:(0,l.FP)(T,w),E=t(S,M),C=E[0],L=E[1],I=C-n,P=L-i,z=_*I-x*P;(z*z/b>e||(0,l.tn)((x*I+_*P)/b-.5)>.3||o*p+s*m+c*g<d)&&(r(n,i,a,o,s,c,C,L,S,w/=A,T/=A,k,y,v),v.point(C,L),r(C,L,S,w,T,k,u,h,f,p,m,g,y,v))}}return function(e){var n,i,a,o,s,l,c,u,h,d,m,g,y={point:v,lineStart:x,lineEnd:b,polygonStart:function(){e.polygonStart(),y.lineStart=w},polygonEnd:function(){e.polygonEnd(),y.lineStart=x}};function v(r,n){r=t(r,n),e.point(r[0],r[1])}function x(){u=NaN,y.point=_,e.lineStart()}function _(n,i){var a=(0,f.jf)([n,i]),o=t(n,i);r(u,h,c,d,m,g,u=o[0],h=o[1],c=n,d=a[0],m=a[1],g=a[2],p,e),e.point(u,h)}function b(){y.point=v,e.lineEnd()}function w(){x(),y.point=T,y.lineEnd=k}function T(t,e){_(n=t,e),i=u,a=h,o=d,s=m,l=g,y.point=_}function k(){r(u,h,c,d,m,g,i,a,n,o,s,l,p,e),y.lineEnd=b,b()}return y}}(t,e):function(t){return(0,u.G)({point:function(e,r){e=t(e,r),this.stream.point(e[0],e[1])}})}(t)}var g=(0,u.G)({point:function(t,e){this.stream.point(t*l.F2,e*l.F2)}});function y(t,e,r,n,i){function a(a,o){return[e+t*(a*=n),r-t*(o*=i)]}return a.invert=function(a,o){return[(a-e)/t*n,(r-o)/t*i]},a}function v(t,e,r,n,i,a){var o=(0,l.gn)(a),s=(0,l.F8)(a),c=o*t,u=s*t,h=o/t,f=s/t,p=(s*r-o*e)/t,d=(s*e+o*r)/t;function m(t,a){return[c*(t*=n)-u*(a*=i)+e,r-u*t-c*a]}return m.invert=function(t,e){return[n*(h*t-f*e+p),i*(d-f*t-h*e)]},m}function x(t){return _((function(){return t}))()}function _(t){var e,r,f,p,d,x,_,b,w,T,k=150,A=480,M=250,S=0,E=0,C=0,L=0,I=0,P=0,z=1,O=1,D=null,R=n.A,F=null,B=s.A,N=.5;function j(t){return b(t[0]*l.F2,t[1]*l.F2)}function U(t){return(t=b.invert(t[0],t[1]))&&[t[0]*l.uj,t[1]*l.uj]}function V(){var t=v(k,0,0,z,O,P).apply(null,e(S,E)),n=(P?v:y)(k,A-t[0],M-t[1],z,O,P);return r=(0,c.y)(C,L,I),_=(0,o.A)(e,n),b=(0,o.A)(r,_),x=m(_,N),q()}function q(){return w=T=null,j}return j.stream=function(t){return w&&T===t?w:w=g(function(t){return(0,u.G)({point:function(e,r){var n=t(e,r);return this.stream.point(n[0],n[1])}})}(r)(R(x(B(T=t)))))},j.preclip=function(t){return arguments.length?(R=t,D=void 0,q()):R},j.postclip=function(t){return arguments.length?(B=t,F=f=p=d=null,q()):B},j.clipAngle=function(t){return arguments.length?(R=+t?(0,i.A)(D=t*l.F2):(D=null,n.A),q()):D*l.uj},j.clipExtent=function(t){return arguments.length?(B=null==t?(F=f=p=d=null,s.A):(0,a.A)(F=+t[0][0],f=+t[0][1],p=+t[1][0],d=+t[1][1]),q()):null==F?null:[[F,f],[p,d]]},j.scale=function(t){return arguments.length?(k=+t,V()):k},j.translate=function(t){return arguments.length?(A=+t[0],M=+t[1],V()):[A,M]},j.center=function(t){return arguments.length?(S=t[0]%360*l.F2,E=t[1]%360*l.F2,V()):[S*l.uj,E*l.uj]},j.rotate=function(t){return arguments.length?(C=t[0]%360*l.F2,L=t[1]%360*l.F2,I=t.length>2?t[2]%360*l.F2:0,V()):[C*l.uj,L*l.uj,I*l.uj]},j.angle=function(t){return arguments.length?(P=t%360*l.F2,V()):P*l.uj},j.reflectX=function(t){return arguments.length?(z=t?-1:1,V()):z<0},j.reflectY=function(t){return arguments.length?(O=t?-1:1,V()):O<0},j.precision=function(t){return arguments.length?(x=m(_,N=t*t),q()):(0,l.RZ)(N)},j.fitExtent=function(t,e){return(0,h.sp)(j,t,e)},j.fitSize=function(t,e){return(0,h.Hv)(j,t,e)},j.fitWidth=function(t,e){return(0,h.G0)(j,t,e)},j.fitHeight=function(t,e){return(0,h.FL)(j,t,e)},function(){return e=t.apply(this,arguments),j.invert=e.invert&&U,V()}}},57949:function(t,e,r){\"use strict\";r.d(e,{A:function(){return o},P:function(){return a}});var n=r(94684),i=r(61323);function a(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}function o(){return(0,n.A)(a).scale(175.295)}a.invert=function(t,e){var r,n=e,a=25;do{var o=n*n,s=o*o;n-=r=(n*(1.007226+o*(.015085+s*(.028874*o-.044475-.005916*s)))-e)/(1.007226+o*(.045255+s*(.259866*o-.311325-.005916*11*s)))}while((0,i.tn)(r)>i.Ni&&--a>0);return[t/(.8707+(o=n*n)*(o*(o*o*o*(.003971-.001529*o)-.013791)-.131979)),n]}},53253:function(t,e,r){\"use strict\";r.d(e,{A:function(){return s},x:function(){return o}});var n=r(61323),i=r(57738),a=r(94684);function o(t,e){return[(0,n.gn)(e)*(0,n.F8)(t),(0,n.F8)(e)]}function s(){return(0,a.A)(o).scale(249.5).clipAngle(90+n.Ni)}o.invert=(0,i.I)(n.qR)},30915:function(t,e,r){\"use strict\";r.d(e,{A:function(){return u},y:function(){return o}});var n=r(19057),i=r(61323);function a(t,e){return[(0,i.tn)(t)>i.pi?t+Math.round(-t/i.FA)*i.FA:t,e]}function o(t,e,r){return(t%=i.FA)?e||r?(0,n.A)(l(t),c(e,r)):l(t):e||r?c(e,r):a}function s(t){return function(e,r){return[(e+=t)>i.pi?e-i.FA:e<-i.pi?e+i.FA:e,r]}}function l(t){var e=s(t);return e.invert=s(-t),e}function c(t,e){var r=(0,i.gn)(t),n=(0,i.F8)(t),a=(0,i.gn)(e),o=(0,i.F8)(e);function s(t,e){var s=(0,i.gn)(e),l=(0,i.gn)(t)*s,c=(0,i.F8)(t)*s,u=(0,i.F8)(e),h=u*r+l*n;return[(0,i.FP)(c*a-h*o,l*r-u*n),(0,i.qR)(h*a+c*o)]}return s.invert=function(t,e){var s=(0,i.gn)(e),l=(0,i.gn)(t)*s,c=(0,i.F8)(t)*s,u=(0,i.F8)(e),h=u*a-c*o;return[(0,i.FP)(c*a+u*o,l*r+h*n),(0,i.qR)(h*r-l*n)]},s}function u(t){function e(e){return(e=t(e[0]*i.F2,e[1]*i.F2))[0]*=i.uj,e[1]*=i.uj,e}return t=o(t[0]*i.F2,t[1]*i.F2,t.length>2?t[2]*i.F2:0),e.invert=function(e){return(e=t.invert(e[0]*i.F2,e[1]*i.F2))[0]*=i.uj,e[1]*=i.uj,e},e}a.invert=a},20465:function(t,e,r){\"use strict\";function n(t,e){t&&a.hasOwnProperty(t.type)&&a[t.type](t,e)}r.d(e,{A:function(){return l}});var i={Feature:function(t,e){n(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,i=-1,a=r.length;++i<a;)n(r[i].geometry,e)}},a={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){o(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)o(r[n],e,0)},Polygon:function(t,e){s(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)s(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,i=-1,a=r.length;++i<a;)n(r[i],e)}};function o(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function s(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)o(t[r],e,1);e.polygonEnd()}function l(t,e){t&&i.hasOwnProperty(t.type)?i[t.type](t,e):n(t,e)}},913:function(t,e,r){\"use strict\";function n(t){return{stream:i(t)}}function i(t){return function(e){var r=new a;for(var n in t)r[n]=t[n];return r.stream=e,r}}function a(){}r.d(e,{A:function(){return n},G:function(){return i}}),a.prototype={constructor:a,point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}}},92264:function(t,e,r){\"use strict\";function n(t,e){return t.parent===e.parent?1:2}function i(t,e){return t+e.x}function a(t,e){return Math.max(t,e.y)}function o(){var t=n,e=1,r=1,o=!1;function s(n){var s,l=0;n.eachAfter((function(e){var r=e.children;r?(e.x=function(t){return t.reduce(i,0)/t.length}(r),e.y=function(t){return 1+t.reduce(a,0)}(r)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)}));var c=function(t){for(var e;e=t.children;)t=e[0];return t}(n),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(n),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return n.eachAfter(o?function(t){t.x=(t.x-n.x)*e,t.y=(n.y-t.y)*r}:function(t){t.x=(t.x-h)/(f-h)*e,t.y=(1-(n.y?t.y/n.y:1))*r})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,e=+t[0],r=+t[1],s):o?null:[e,r]},s.nodeSize=function(t){return arguments.length?(o=!0,e=+t[0],r=+t[1],s):o?[e,r]:null},s}function s(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function l(t,e){var r,n,i,a,o,s=new f(t),l=+t.value&&(s.value=t.value),u=[s];for(null==e&&(e=c);r=u.pop();)if(l&&(r.value=+r.data.value),(i=e(r.data))&&(o=i.length))for(r.children=new Array(o),a=o-1;a>=0;--a)u.push(n=r.children[a]=new f(i[a])),n.parent=r,n.depth=r.depth+1;return s.eachBefore(h)}function c(t){return t.children}function u(t){t.data=t.data.data}function h(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function f(t){this.data=t,this.depth=this.height=0,this.parent=null}r.r(e),r.d(e,{cluster:function(){return o},hierarchy:function(){return l},pack:function(){return P},packEnclose:function(){return d},packSiblings:function(){return S},partition:function(){return B},stratify:function(){return H},tree:function(){return J},treemap:function(){return rt},treemapBinary:function(){return nt},treemapDice:function(){return F},treemapResquarify:function(){return at},treemapSlice:function(){return K},treemapSliceDice:function(){return it},treemapSquarify:function(){return et}}),f.prototype=l.prototype={constructor:f,count:function(){return this.eachAfter(s)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter((function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r}))},sort:function(t){return this.eachBefore((function(e){e.children&&e.children.sort(t)}))},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each((function(e){t.push(e)})),t},leaves:function(){var t=[];return this.eachBefore((function(e){e.children||t.push(e)})),t},links:function(){var t=this,e=[];return t.each((function(r){r!==t&&e.push({source:r.parent,target:r})})),e},copy:function(){return l(this).eachBefore(u)}};var p=Array.prototype.slice;function d(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(p.call(t))).length,a=[];n<i;)e=t[n],r&&y(r,e)?++n:(r=x(a=m(a,e)),n=0);return r}function m(t,e){var r,n;if(v(e,t))return[e];for(r=0;r<t.length;++r)if(g(e,t[r])&&v(_(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(g(_(t[r],t[n]),e)&&g(_(t[r],e),t[n])&&g(_(t[n],e),t[r])&&v(b(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function g(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function y(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function v(t,e){for(var r=0;r<e.length;++r)if(!y(t,e[r]))return!1;return!0}function x(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return _(t[0],t[1]);case 3:return b(t[0],t[1],t[2])}var e}function _(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function b(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,m=i-u,g=l-a,y=h-a,v=n*n+i*i-a*a,x=v-o*o-s*s+l*l,_=v-c*c-u*u+h*h,b=p*d-f*m,w=(d*_-m*x)/(2*b)-n,T=(m*g-d*y)/b,k=(p*x-f*_)/(2*b)-i,A=(f*y-p*g)/b,M=T*T+A*A-1,S=2*(a+w*T+k*A),E=w*w+k*k-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+T*C,y:i+k+A*C,r:C}}function w(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function T(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function k(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function A(t){this._=t,this.next=null,this.previous=null}function M(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,h;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;w(r,e,n=t[2]),e=new A(e),r=new A(r),n=new A(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){w(e._,r._,n=t[s]),n=new A(n),l=r.next,c=e.previous,u=r._.r,h=e._.r;do{if(u<=h){if(T(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(T(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}h+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=k(e);(n=n.next)!==r;)(o=k(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=d(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function S(t){return M(t),t}function E(t){if(\"function\"!=typeof t)throw new Error;return t}function C(){return 0}function L(t){return function(){return t}}function I(t){return Math.sqrt(t.value)}function P(){var t=null,e=1,r=1,n=C;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(z(t)).eachAfter(O(n,.5)).eachBefore(D(1)):i.eachBefore(z(I)).eachAfter(O(C,1)).eachAfter(O(n,i.r/Math.min(e,r))).eachBefore(D(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:E(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:L(+t),i):n},i}function z(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function O(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=M(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function D(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function R(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function F(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}function B(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&F(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(R),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i}var N=\"$\",j={depth:-1},U={};function V(t){return t.id}function q(t){return t.parentId}function H(){var t=V,e=q;function r(r){var n,i,a,o,s,l,c,u=r.length,p=new Array(u),d={};for(i=0;i<u;++i)n=r[i],s=p[i]=new f(n),null!=(l=t(n,i,r))&&(l+=\"\")&&(d[c=N+(s.id=l)]=c in d?U:s);for(i=0;i<u;++i)if(s=p[i],null!=(l=e(r[i],i,r))&&(l+=\"\")){if(!(o=d[N+l]))throw new Error(\"missing: \"+l);if(o===U)throw new Error(\"ambiguous: \"+l);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=j,a.eachBefore((function(t){t.depth=t.parent.depth+1,--u})).eachBefore(h),a.parent=null,u>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=E(e),r):t},r.parentId=function(t){return arguments.length?(e=E(t),r):e},r}function G(t,e){return t.parent===e.parent?1:2}function Z(t){var e=t.children;return e?e[0]:t.t}function W(t){var e=t.children;return e?e[e.length-1]:t.t}function Y(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function X(t,e,r){return t.a.parent===e.parent?t.a:r}function $(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function J(){var t=G,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new $(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new $(n[i],i)),r.parent=e;return(o.parent=new $(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore((function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)}));var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),m=r/(h.depth||1);i.eachBefore((function(t){t.x=(t.x+p)*d,t.y=t.depth*m}))}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=W(s),a=Z(a),s&&a;)l=Z(l),(o=W(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(Y(X(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!W(o)&&(o.t=s,o.m+=h-u),a&&!Z(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i}function K(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}$.prototype=Object.create(f.prototype);var Q=(1+Math.sqrt(5))/2;function tt(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,m,g,y=[],v=e.children,x=0,_=0,b=v.length,w=e.value;x<b;){l=i-r,c=a-n;do{u=v[_++].value}while(!u&&_<b);for(h=f=u,g=u*u*(m=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/g,g/h);_<b;++_){if(u+=s=v[_].value,s<h&&(h=s),s>f&&(f=s),g=u*u*m,(p=Math.max(f/g,g/h))>d){u-=s;break}d=p}y.push(o={value:u,dice:l<c,children:v.slice(x,_)}),o.dice?F(o,r,n,i,w?n+=c*u/w:a):K(o,r,n,w?r+=l*u/w:i,a),w-=u,x=_}return y}var et=function t(e){function r(t,r,n,i,a){tt(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(Q);function rt(){var t=et,e=!1,r=1,n=1,i=[0],a=C,o=C,s=C,l=C,c=C;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(R),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=E(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:L(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:L(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:L(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:L(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:L(+t),u):c},u}function nt(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var m=p+d>>>1;c[m]<f?p=m+1:d=m}f-c[p-1]<c[p]-f&&e+1<p&&--p;var g=c[p]-h,y=n-g;if(o-i>l-a){var v=(i*y+o*g)/n;t(e,p,g,i,a,v,l),t(p,r,y,v,a,o,l)}else{var x=(a*y+l*g)/n;t(e,p,g,i,a,o,x),t(p,r,y,i,x,o,l)}}(0,l,t.value,e,r,n,i)}function it(t,e,r,n,i){(1&t.depth?K:F)(t,e,r,n,i)}var at=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?F(s,r,n,i,n+=(a-n)*s.value/p):K(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=tt(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(Q)},48544:function(t,e,r){\"use strict\";r.d(e,{pq:function(){return y}});var n=Math.PI,i=2*n,a=1e-6,o=i-a;function s(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function l(){return new s}s.prototype=l.prototype={constructor:s,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,e,r,i,o){t=+t,e=+e,r=+r,i=+i,o=+o;var s=this._x1,l=this._y1,c=r-t,u=i-e,h=s-t,f=l-e,p=h*h+f*f;if(o<0)throw new Error(\"negative radius: \"+o);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=e);else if(p>a)if(Math.abs(f*c-u*h)>a&&o){var d=r-s,m=i-l,g=c*c+u*u,y=d*d+m*m,v=Math.sqrt(g),x=Math.sqrt(p),_=o*Math.tan((n-Math.acos((g+p-y)/(2*v*x)))/2),b=_/x,w=_/v;Math.abs(b-1)>a&&(this._+=\"L\"+(t+b*h)+\",\"+(e+b*f)),this._+=\"A\"+o+\",\"+o+\",0,0,\"+ +(f*d>h*m)+\",\"+(this._x1=t+w*c)+\",\"+(this._y1=e+w*u)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=e)},arc:function(t,e,r,s,l,c){t=+t,e=+e,c=!!c;var u=(r=+r)*Math.cos(s),h=r*Math.sin(s),f=t+u,p=e+h,d=1^c,m=c?s-l:l-s;if(r<0)throw new Error(\"negative radius: \"+r);null===this._x1?this._+=\"M\"+f+\",\"+p:(Math.abs(this._x1-f)>a||Math.abs(this._y1-p)>a)&&(this._+=\"L\"+f+\",\"+p),r&&(m<0&&(m=m%i+i),m>o?this._+=\"A\"+r+\",\"+r+\",0,1,\"+d+\",\"+(t-u)+\",\"+(e-h)+\"A\"+r+\",\"+r+\",0,1,\"+d+\",\"+(this._x1=f)+\",\"+(this._y1=p):m>a&&(this._+=\"A\"+r+\",\"+r+\",0,\"+ +(m>=n)+\",\"+d+\",\"+(this._x1=t+r*Math.cos(l))+\",\"+(this._y1=e+r*Math.sin(l))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}};var c=l,u=Array.prototype.slice;function h(t){return function(){return t}}function f(t){return t[0]}function p(t){return t[1]}function d(t){return t.source}function m(t){return t.target}function g(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function y(){return function(t){var e=d,r=m,n=f,i=p,a=null;function o(){var o,s=u.call(arguments),l=e.apply(this,s),h=r.apply(this,s);if(a||(a=o=c()),t(a,+n.apply(this,(s[0]=l,s)),+i.apply(this,s),+n.apply(this,(s[0]=h,s)),+i.apply(this,s)),o)return a=null,o+\"\"||null}return o.source=function(t){return arguments.length?(e=t,o):e},o.target=function(t){return arguments.length?(r=t,o):r},o.x=function(t){return arguments.length?(n=\"function\"==typeof t?t:h(+t),o):n},o.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:h(+t),o):i},o.context=function(t){return arguments.length?(a=null==t?null:t,o):a},o}(g)}},42696:function(t,e,r){\"use strict\";r.d(e,{DC:function(){return d},de:function(){return f},aL:function(){return m}});var n=r(1681),i=r(72543),a=r(55735),o=r(47265),s=r(9830),l=r(59764);function c(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function u(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function h(t,e,r){return{y:t,m:e,d:r,H:0,M:0,S:0,L:0}}function f(t){var e=t.dateTime,r=t.date,s=t.time,l=t.periods,f=t.days,p=t.shortDays,d=t.months,m=t.shortMonths,y=w(l),v=T(l),x=w(f),_=T(f),b=w(p),St=T(p),Et=w(d),Ct=T(d),Lt=w(m),It=T(m),Pt={a:function(t){return p[t.getDay()]},A:function(t){return f[t.getDay()]},b:function(t){return m[t.getMonth()]},B:function(t){return d[t.getMonth()]},c:null,d:H,e:H,f:X,H:G,I:Z,j:W,L:Y,m:$,M:J,p:function(t){return l[+(t.getHours()>=12)]},q:function(t){return 1+~~(t.getMonth()/3)},Q:At,s:Mt,S:K,u:Q,U:tt,V:et,w:rt,W:nt,x:null,X:null,y:it,Y:at,Z:ot,\"%\":kt},zt={a:function(t){return p[t.getUTCDay()]},A:function(t){return f[t.getUTCDay()]},b:function(t){return m[t.getUTCMonth()]},B:function(t){return d[t.getUTCMonth()]},c:null,d:st,e:st,f:ft,H:lt,I:ct,j:ut,L:ht,m:pt,M:dt,p:function(t){return l[+(t.getUTCHours()>=12)]},q:function(t){return 1+~~(t.getUTCMonth()/3)},Q:At,s:Mt,S:mt,u:gt,U:yt,V:vt,w:xt,W:_t,x:null,X:null,y:bt,Y:wt,Z:Tt,\"%\":kt},Ot={a:function(t,e,r){var n=b.exec(e.slice(r));return n?(t.w=St[n[0].toLowerCase()],r+n[0].length):-1},A:function(t,e,r){var n=x.exec(e.slice(r));return n?(t.w=_[n[0].toLowerCase()],r+n[0].length):-1},b:function(t,e,r){var n=Lt.exec(e.slice(r));return n?(t.m=It[n[0].toLowerCase()],r+n[0].length):-1},B:function(t,e,r){var n=Et.exec(e.slice(r));return n?(t.m=Ct[n[0].toLowerCase()],r+n[0].length):-1},c:function(t,r,n){return Ft(t,e,r,n)},d:O,e:O,f:j,H:R,I:R,j:D,L:N,m:z,M:F,p:function(t,e,r){var n=y.exec(e.slice(r));return n?(t.p=v[n[0].toLowerCase()],r+n[0].length):-1},q:P,Q:V,s:q,S:B,u:A,U:M,V:S,w:k,W:E,x:function(t,e,n){return Ft(t,r,e,n)},X:function(t,e,r){return Ft(t,s,e,r)},y:L,Y:C,Z:I,\"%\":U};function Dt(t,e){return function(r){var n,i,a,o=[],s=-1,l=0,c=t.length;for(r instanceof Date||(r=new Date(+r));++s<c;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=g[n=t.charAt(++s)])?n=t.charAt(++s):i=\"e\"===n?\" \":\"0\",(a=e[n])&&(n=a(r,i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}}function Rt(t,e){return function(r){var s,l,f=h(1900,void 0,1);if(Ft(f,t,r+=\"\",0)!=r.length)return null;if(\"Q\"in f)return new Date(f.Q);if(\"s\"in f)return new Date(1e3*f.s+(\"L\"in f?f.L:0));if(e&&!(\"Z\"in f)&&(f.Z=0),\"p\"in f&&(f.H=f.H%12+12*f.p),void 0===f.m&&(f.m=\"q\"in f?f.q:0),\"V\"in f){if(f.V<1||f.V>53)return null;\"w\"in f||(f.w=1),\"Z\"in f?(l=(s=u(h(f.y,0,1))).getUTCDay(),s=l>4||0===l?n.rt.ceil(s):(0,n.rt)(s),s=i.A.offset(s,7*(f.V-1)),f.y=s.getUTCFullYear(),f.m=s.getUTCMonth(),f.d=s.getUTCDate()+(f.w+6)%7):(l=(s=c(h(f.y,0,1))).getDay(),s=l>4||0===l?a.By.ceil(s):(0,a.By)(s),s=o.A.offset(s,7*(f.V-1)),f.y=s.getFullYear(),f.m=s.getMonth(),f.d=s.getDate()+(f.w+6)%7)}else(\"W\"in f||\"U\"in f)&&(\"w\"in f||(f.w=\"u\"in f?f.u%7:\"W\"in f?1:0),l=\"Z\"in f?u(h(f.y,0,1)).getUTCDay():c(h(f.y,0,1)).getDay(),f.m=0,f.d=\"W\"in f?(f.w+6)%7+7*f.W-(l+5)%7:f.w+7*f.U-(l+6)%7);return\"Z\"in f?(f.H+=f.Z/100|0,f.M+=f.Z%100,u(f)):c(f)}}function Ft(t,e,r,n){for(var i,a,o=0,s=e.length,l=r.length;o<s;){if(n>=l)return-1;if(37===(i=e.charCodeAt(o++))){if(i=e.charAt(o++),!(a=Ot[i in g?e.charAt(o++):i])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}return Pt.x=Dt(r,Pt),Pt.X=Dt(s,Pt),Pt.c=Dt(e,Pt),zt.x=Dt(r,zt),zt.X=Dt(s,zt),zt.c=Dt(e,zt),{format:function(t){var e=Dt(t+=\"\",Pt);return e.toString=function(){return t},e},parse:function(t){var e=Rt(t+=\"\",!1);return e.toString=function(){return t},e},utcFormat:function(t){var e=Dt(t+=\"\",zt);return e.toString=function(){return t},e},utcParse:function(t){var e=Rt(t+=\"\",!0);return e.toString=function(){return t},e}}}var p,d,m,g={\"-\":\"\",_:\" \",0:\"0\"},y=/^\\s*\\d+/,v=/^%/,x=/[\\\\^$*+?|[\\]().{}]/g;function _(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function b(t){return t.replace(x,\"\\\\$&\")}function w(t){return new RegExp(\"^(?:\"+t.map(b).join(\"|\")+\")\",\"i\")}function T(t){for(var e={},r=-1,n=t.length;++r<n;)e[t[r].toLowerCase()]=r;return e}function k(t,e,r){var n=y.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function A(t,e,r){var n=y.exec(e.slice(r,r+1));return n?(t.u=+n[0],r+n[0].length):-1}function M(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.U=+n[0],r+n[0].length):-1}function S(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.V=+n[0],r+n[0].length):-1}function E(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.W=+n[0],r+n[0].length):-1}function C(t,e,r){var n=y.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function L(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.y=+n[0]+(+n[0]>68?1900:2e3),r+n[0].length):-1}function I(t,e,r){var n=/^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(e.slice(r,r+6));return n?(t.Z=n[1]?0:-(n[2]+(n[3]||\"00\")),r+n[0].length):-1}function P(t,e,r){var n=y.exec(e.slice(r,r+1));return n?(t.q=3*n[0]-3,r+n[0].length):-1}function z(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function O(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function D(t,e,r){var n=y.exec(e.slice(r,r+3));return n?(t.m=0,t.d=+n[0],r+n[0].length):-1}function R(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function F(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function B(t,e,r){var n=y.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function N(t,e,r){var n=y.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function j(t,e,r){var n=y.exec(e.slice(r,r+6));return n?(t.L=Math.floor(n[0]/1e3),r+n[0].length):-1}function U(t,e,r){var n=v.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function V(t,e,r){var n=y.exec(e.slice(r));return n?(t.Q=+n[0],r+n[0].length):-1}function q(t,e,r){var n=y.exec(e.slice(r));return n?(t.s=+n[0],r+n[0].length):-1}function H(t,e){return _(t.getDate(),e,2)}function G(t,e){return _(t.getHours(),e,2)}function Z(t,e){return _(t.getHours()%12||12,e,2)}function W(t,e){return _(1+o.A.count((0,s.A)(t),t),e,3)}function Y(t,e){return _(t.getMilliseconds(),e,3)}function X(t,e){return Y(t,e)+\"000\"}function $(t,e){return _(t.getMonth()+1,e,2)}function J(t,e){return _(t.getMinutes(),e,2)}function K(t,e){return _(t.getSeconds(),e,2)}function Q(t){var e=t.getDay();return 0===e?7:e}function tt(t,e){return _(a.fz.count((0,s.A)(t)-1,t),e,2)}function et(t,e){var r=t.getDay();return t=r>=4||0===r?(0,a.dt)(t):a.dt.ceil(t),_(a.dt.count((0,s.A)(t),t)+(4===(0,s.A)(t).getDay()),e,2)}function rt(t){return t.getDay()}function nt(t,e){return _(a.By.count((0,s.A)(t)-1,t),e,2)}function it(t,e){return _(t.getFullYear()%100,e,2)}function at(t,e){return _(t.getFullYear()%1e4,e,4)}function ot(t){var e=t.getTimezoneOffset();return(e>0?\"-\":(e*=-1,\"+\"))+_(e/60|0,\"0\",2)+_(e%60,\"0\",2)}function st(t,e){return _(t.getUTCDate(),e,2)}function lt(t,e){return _(t.getUTCHours(),e,2)}function ct(t,e){return _(t.getUTCHours()%12||12,e,2)}function ut(t,e){return _(1+i.A.count((0,l.A)(t),t),e,3)}function ht(t,e){return _(t.getUTCMilliseconds(),e,3)}function ft(t,e){return ht(t,e)+\"000\"}function pt(t,e){return _(t.getUTCMonth()+1,e,2)}function dt(t,e){return _(t.getUTCMinutes(),e,2)}function mt(t,e){return _(t.getUTCSeconds(),e,2)}function gt(t){var e=t.getUTCDay();return 0===e?7:e}function yt(t,e){return _(n.Hl.count((0,l.A)(t)-1,t),e,2)}function vt(t,e){var r=t.getUTCDay();return t=r>=4||0===r?(0,n.pT)(t):n.pT.ceil(t),_(n.pT.count((0,l.A)(t),t)+(4===(0,l.A)(t).getUTCDay()),e,2)}function xt(t){return t.getUTCDay()}function _t(t,e){return _(n.rt.count((0,l.A)(t)-1,t),e,2)}function bt(t,e){return _(t.getUTCFullYear()%100,e,2)}function wt(t,e){return _(t.getUTCFullYear()%1e4,e,4)}function Tt(){return\"+0000\"}function kt(){return\"%\"}function At(t){return+t}function Mt(t){return Math.floor(+t/1e3)}p=f({dateTime:\"%x, %X\",date:\"%-m/%-d/%Y\",time:\"%-I:%M:%S %p\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]}),d=p.format,p.parse,m=p.utcFormat,p.utcParse},47265:function(t,e,r){\"use strict\";r.d(e,{_:function(){return o}});var n=r(53398),i=r(66291),a=(0,n.A)((function(t){t.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t,e){return(e-t-(e.getTimezoneOffset()-t.getTimezoneOffset())*i.rR)/i.Nm}),(function(t){return t.getDate()-1}));e.A=a;var o=a.range},66291:function(t,e,r){\"use strict\";r.d(e,{Fq:function(){return s},JJ:function(){return a},Nm:function(){return o},Tt:function(){return n},rR:function(){return i}});var n=1e3,i=6e4,a=36e5,o=864e5,s=6048e5},50936:function(t,e,r){\"use strict\";r.r(e),r.d(e,{timeDay:function(){return y.A},timeDays:function(){return y._},timeFriday:function(){return v.Sh},timeFridays:function(){return v.tz},timeHour:function(){return m},timeHours:function(){return g},timeInterval:function(){return n.A},timeMillisecond:function(){return a},timeMilliseconds:function(){return o},timeMinute:function(){return f},timeMinutes:function(){return p},timeMonday:function(){return v.By},timeMondays:function(){return v.KP},timeMonth:function(){return _},timeMonths:function(){return b},timeSaturday:function(){return v.kS},timeSaturdays:function(){return v.t$},timeSecond:function(){return c},timeSeconds:function(){return u},timeSunday:function(){return v.fz},timeSundays:function(){return v.se},timeThursday:function(){return v.dt},timeThursdays:function(){return v.Q$},timeTuesday:function(){return v.eQ},timeTuesdays:function(){return v.yW},timeWednesday:function(){return v.l3},timeWednesdays:function(){return v.gf},timeWeek:function(){return v.fz},timeWeeks:function(){return v.se},timeYear:function(){return w.A},timeYears:function(){return w.V},utcDay:function(){return C.A},utcDays:function(){return C.o},utcFriday:function(){return L.a1},utcFridays:function(){return L.Zn},utcHour:function(){return S},utcHours:function(){return E},utcMillisecond:function(){return a},utcMilliseconds:function(){return o},utcMinute:function(){return k},utcMinutes:function(){return A},utcMonday:function(){return L.rt},utcMondays:function(){return L.ON},utcMonth:function(){return P},utcMonths:function(){return z},utcSaturday:function(){return L.c8},utcSaturdays:function(){return L.Xo},utcSecond:function(){return c},utcSeconds:function(){return u},utcSunday:function(){return L.Hl},utcSundays:function(){return L.aZ},utcThursday:function(){return L.pT},utcThursdays:function(){return L.wr},utcTuesday:function(){return L.sr},utcTuesdays:function(){return L.jN},utcWednesday:function(){return L.z2},utcWednesdays:function(){return L.G6},utcWeek:function(){return L.Hl},utcWeeks:function(){return L.aZ},utcYear:function(){return O.A},utcYears:function(){return O.j}});var n=r(53398),i=(0,n.A)((function(){}),(function(t,e){t.setTime(+t+e)}),(function(t,e){return e-t}));i.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?(0,n.A)((function(e){e.setTime(Math.floor(e/t)*t)}),(function(e,r){e.setTime(+e+r*t)}),(function(e,r){return(r-e)/t})):i:null};var a=i,o=i.range,s=r(66291),l=(0,n.A)((function(t){t.setTime(t-t.getMilliseconds())}),(function(t,e){t.setTime(+t+e*s.Tt)}),(function(t,e){return(e-t)/s.Tt}),(function(t){return t.getUTCSeconds()})),c=l,u=l.range,h=(0,n.A)((function(t){t.setTime(t-t.getMilliseconds()-t.getSeconds()*s.Tt)}),(function(t,e){t.setTime(+t+e*s.rR)}),(function(t,e){return(e-t)/s.rR}),(function(t){return t.getMinutes()})),f=h,p=h.range,d=(0,n.A)((function(t){t.setTime(t-t.getMilliseconds()-t.getSeconds()*s.Tt-t.getMinutes()*s.rR)}),(function(t,e){t.setTime(+t+e*s.JJ)}),(function(t,e){return(e-t)/s.JJ}),(function(t){return t.getHours()})),m=d,g=d.range,y=r(47265),v=r(55735),x=(0,n.A)((function(t){t.setDate(1),t.setHours(0,0,0,0)}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())}),(function(t){return t.getMonth()})),_=x,b=x.range,w=r(9830),T=(0,n.A)((function(t){t.setUTCSeconds(0,0)}),(function(t,e){t.setTime(+t+e*s.rR)}),(function(t,e){return(e-t)/s.rR}),(function(t){return t.getUTCMinutes()})),k=T,A=T.range,M=(0,n.A)((function(t){t.setUTCMinutes(0,0,0)}),(function(t,e){t.setTime(+t+e*s.JJ)}),(function(t,e){return(e-t)/s.JJ}),(function(t){return t.getUTCHours()})),S=M,E=M.range,C=r(72543),L=r(1681),I=(0,n.A)((function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCMonth(t.getUTCMonth()+e)}),(function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())}),(function(t){return t.getUTCMonth()})),P=I,z=I.range,O=r(59764)},53398:function(t,e,r){\"use strict\";r.d(e,{A:function(){return a}});var n=new Date,i=new Date;function a(t,e,r,o){function s(e){return t(e=0===arguments.length?new Date:new Date(+e)),e}return s.floor=function(e){return t(e=new Date(+e)),e},s.ceil=function(r){return t(r=new Date(r-1)),e(r,1),t(r),r},s.round=function(t){var e=s(t),r=s.ceil(t);return t-e<r-t?e:r},s.offset=function(t,r){return e(t=new Date(+t),null==r?1:Math.floor(r)),t},s.range=function(r,n,i){var a,o=[];if(r=s.ceil(r),i=null==i?1:Math.floor(i),!(r<n&&i>0))return o;do{o.push(a=new Date(+r)),e(r,i),t(r)}while(a<r&&r<n);return o},s.filter=function(r){return a((function(e){if(e>=e)for(;t(e),!r(e);)e.setTime(e-1)}),(function(t,n){if(t>=t)if(n<0)for(;++n<=0;)for(;e(t,-1),!r(t););else for(;--n>=0;)for(;e(t,1),!r(t););}))},r&&(s.count=function(e,a){return n.setTime(+e),i.setTime(+a),t(n),t(i),Math.floor(r(n,i))},s.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?s.filter(o?function(e){return o(e)%t==0}:function(e){return s.count(0,e)%t==0}):s:null}),s}},72543:function(t,e,r){\"use strict\";r.d(e,{o:function(){return o}});var n=r(53398),i=r(66291),a=(0,n.A)((function(t){t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+e)}),(function(t,e){return(e-t)/i.Nm}),(function(t){return t.getUTCDate()-1}));e.A=a;var o=a.range},1681:function(t,e,r){\"use strict\";r.d(e,{G6:function(){return g},Hl:function(){return o},ON:function(){return d},Xo:function(){return x},Zn:function(){return v},a1:function(){return h},aZ:function(){return p},c8:function(){return f},jN:function(){return m},pT:function(){return u},rt:function(){return s},sr:function(){return l},wr:function(){return y},z2:function(){return c}});var n=r(53398),i=r(66291);function a(t){return(0,n.A)((function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+7*e)}),(function(t,e){return(e-t)/i.Fq}))}var o=a(0),s=a(1),l=a(2),c=a(3),u=a(4),h=a(5),f=a(6),p=o.range,d=s.range,m=l.range,g=c.range,y=u.range,v=h.range,x=f.range},59764:function(t,e,r){\"use strict\";r.d(e,{j:function(){return a}});var n=r(53398),i=(0,n.A)((function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)}),(function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()}),(function(t){return t.getUTCFullYear()}));i.every=function(t){return isFinite(t=Math.floor(t))&&t>0?(0,n.A)((function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)}),(function(e,r){e.setUTCFullYear(e.getUTCFullYear()+r*t)})):null},e.A=i;var a=i.range},55735:function(t,e,r){\"use strict\";r.d(e,{By:function(){return s},KP:function(){return d},Q$:function(){return y},Sh:function(){return h},dt:function(){return u},eQ:function(){return l},fz:function(){return o},gf:function(){return g},kS:function(){return f},l3:function(){return c},se:function(){return p},t$:function(){return x},tz:function(){return v},yW:function(){return m}});var n=r(53398),i=r(66291);function a(t){return(0,n.A)((function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+7*e)}),(function(t,e){return(e-t-(e.getTimezoneOffset()-t.getTimezoneOffset())*i.rR)/i.Fq}))}var o=a(0),s=a(1),l=a(2),c=a(3),u=a(4),h=a(5),f=a(6),p=o.range,d=s.range,m=l.range,g=c.range,y=u.range,v=h.range,x=f.range},9830:function(t,e,r){\"use strict\";r.d(e,{V:function(){return a}});var n=r(53398),i=(0,n.A)((function(t){t.setMonth(0,1),t.setHours(0,0,0,0)}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t,e){return e.getFullYear()-t.getFullYear()}),(function(t){return t.getFullYear()}));i.every=function(t){return isFinite(t=Math.floor(t))&&t>0?(0,n.A)((function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)}),(function(e,r){e.setFullYear(e.getFullYear()+r*t)})):null},e.A=i;var a=i.range},70973:function(t,e,r){\"use strict\";var n=r(40891),i=r(98800),a=r(48631),o=r(52991);t.exports=function(t,e,r){if(!t||\"object\"!=typeof t&&\"function\"!=typeof t)throw new a(\"`obj` must be an object or a function`\");if(\"string\"!=typeof e&&\"symbol\"!=typeof e)throw new a(\"`property` must be a string or a symbol`\");if(arguments.length>3&&\"boolean\"!=typeof arguments[3]&&null!==arguments[3])throw new a(\"`nonEnumerable`, if provided, must be a boolean or null\");if(arguments.length>4&&\"boolean\"!=typeof arguments[4]&&null!==arguments[4])throw new a(\"`nonWritable`, if provided, must be a boolean or null\");if(arguments.length>5&&\"boolean\"!=typeof arguments[5]&&null!==arguments[5])throw new a(\"`nonConfigurable`, if provided, must be a boolean or null\");if(arguments.length>6&&\"boolean\"!=typeof arguments[6])throw new a(\"`loose`, if provided, must be a boolean\");var s=arguments.length>3?arguments[3]:null,l=arguments.length>4?arguments[4]:null,c=arguments.length>5?arguments[5]:null,u=arguments.length>6&&arguments[6],h=!!o&&o(t,e);if(n)n(t,e,{configurable:null===c&&h?h.configurable:!c,enumerable:null===s&&h?h.enumerable:!s,value:r,writable:null===l&&h?h.writable:!l});else{if(!u&&(s||l||c))throw new i(\"This environment does not support defining a property as non-configurable, non-writable, or non-enumerable.\");t[e]=r}}},97936:function(t,e,r){\"use strict\";var n=r(99433),i=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol(\"foo\"),a=Object.prototype.toString,o=Array.prototype.concat,s=Object.defineProperty,l=r(74268)(),c=s&&l,u=function(t,e,r,n){if(e in t)if(!0===n){if(t[e]===r)return}else if(\"function\"!=typeof(i=n)||\"[object Function]\"!==a.call(i)||!n())return;var i;c?s(t,e,{configurable:!0,enumerable:!1,value:r,writable:!0}):t[e]=r},h=function(t,e){var r=arguments.length>2?arguments[2]:{},a=n(e);i&&(a=o.call(a,Object.getOwnPropertySymbols(e)));for(var s=0;s<a.length;s+=1)u(t,a[s],e[a[s]],r[a[s]])};h.supportsDescriptors=!!c,t.exports=h},68650:function(t){t.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},44431:function(t){\"use strict\";t.exports=n;var e=(n.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),r=i([32,126]);function n(t,n){Array.isArray(t)&&(t=t.join(\", \"));var a,o={},s=16,l=.05;n&&(2===n.length&&\"number\"==typeof n[0]?a=i(n):Array.isArray(n)?a=n:(n.o?a=i(n.o):n.pairs&&(a=n.pairs),n.fontSize&&(s=n.fontSize),null!=n.threshold&&(l=n.threshold))),a||(a=r),e.font=s+\"px \"+t;for(var c=0;c<a.length;c++){var u=a[c],h=e.measureText(u[0]).width+e.measureText(u[1]).width,f=e.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;o[u]=1e3*p}}return o}function i(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}n.createPairs=i,n.ascii=r},95620:function(t,e,r){var n=r(16844),i=r(60265),a={M:\"moveTo\",C:\"bezierCurveTo\"};t.exports=function(t,e){t.beginPath(),i(n(e)).forEach((function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)})),t.closePath()}},10275:function(t){t.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},49523:function(t){\"use strict\";function e(t,r,n){var i=0|t[n];if(i<=0)return[];var a,o=new Array(i);if(n===t.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=e(t,r,n+1);return o}t.exports=function(t,r){switch(void 0===r&&(r=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,r);break;case\"object\":if(\"number\"==typeof t.length)return e(t,r,0)}return[]}},25782:function(t){\"use strict\";function e(t,e,n){n=n||2;var a,o,s,l,h,f,d,m=e&&e.length,g=m?e[0]*n:t.length,y=r(t,0,g,n,!0),v=[];if(!y||y.next===y.prev)return v;if(m&&(y=function(t,e,n,i){var a,o,s,l=[];for(a=0,o=e.length;a<o;a++)(s=r(t,e[a]*i,a<o-1?e[a+1]*i:t.length,i,!1))===s.next&&(s.steiner=!0),l.push(p(s));for(l.sort(c),a=0;a<l.length;a++)n=u(l[a],n);return n}(t,e,y,n)),t.length>80*n){a=s=t[0],o=l=t[1];for(var x=n;x<g;x+=n)(h=t[x])<a&&(a=h),(f=t[x+1])<o&&(o=f),h>s&&(s=h),f>l&&(l=f);d=0!==(d=Math.max(s-a,l-o))?32767/d:0}return i(y,v,n,a,o,d,0),v}function r(t,e,r,n,i){var a,o;if(i===M(t,e,r,n)>0)for(a=e;a<r;a+=n)o=T(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=T(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function n(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==g(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function i(t,e,r,c,u,h,p){if(t){!p&&h&&function(t,e,r,n){var i=t;do{0===i.z&&(i.z=f(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,c,u,h);for(var d,m,g=t;t.prev!==t.next;)if(d=t.prev,m=t.next,h?o(t,c,u,h):a(t))e.push(d.i/r|0),e.push(t.i/r|0),e.push(m.i/r|0),k(t),t=m.next,g=m.next;else if((t=m)===g){p?1===p?i(t=s(n(t),e,r),e,r,c,u,h,2):2===p&&l(t,e,r,c,u,h):i(n(t),e,r,c,u,h,1);break}}}function a(t){var e=t.prev,r=t,n=t.next;if(g(e,r,n)>=0)return!1;for(var i=e.x,a=r.x,o=n.x,s=e.y,l=r.y,c=n.y,u=i<a?i<o?i:o:a<o?a:o,h=s<l?s<c?s:c:l<c?l:c,f=i>a?i>o?i:o:a>o?a:o,p=s>l?s>c?s:c:l>c?l:c,m=n.next;m!==e;){if(m.x>=u&&m.x<=f&&m.y>=h&&m.y<=p&&d(i,s,a,l,o,c,m.x,m.y)&&g(m.prev,m,m.next)>=0)return!1;m=m.next}return!0}function o(t,e,r,n){var i=t.prev,a=t,o=t.next;if(g(i,a,o)>=0)return!1;for(var s=i.x,l=a.x,c=o.x,u=i.y,h=a.y,p=o.y,m=s<l?s<c?s:c:l<c?l:c,y=u<h?u<p?u:p:h<p?h:p,v=s>l?s>c?s:c:l>c?l:c,x=u>h?u>p?u:p:h>p?h:p,_=f(m,y,e,r,n),b=f(v,x,e,r,n),w=t.prevZ,T=t.nextZ;w&&w.z>=_&&T&&T.z<=b;){if(w.x>=m&&w.x<=v&&w.y>=y&&w.y<=x&&w!==i&&w!==o&&d(s,u,l,h,c,p,w.x,w.y)&&g(w.prev,w,w.next)>=0)return!1;if(w=w.prevZ,T.x>=m&&T.x<=v&&T.y>=y&&T.y<=x&&T!==i&&T!==o&&d(s,u,l,h,c,p,T.x,T.y)&&g(T.prev,T,T.next)>=0)return!1;T=T.nextZ}for(;w&&w.z>=_;){if(w.x>=m&&w.x<=v&&w.y>=y&&w.y<=x&&w!==i&&w!==o&&d(s,u,l,h,c,p,w.x,w.y)&&g(w.prev,w,w.next)>=0)return!1;w=w.prevZ}for(;T&&T.z<=b;){if(T.x>=m&&T.x<=v&&T.y>=y&&T.y<=x&&T!==i&&T!==o&&d(s,u,l,h,c,p,T.x,T.y)&&g(T.prev,T,T.next)>=0)return!1;T=T.nextZ}return!0}function s(t,e,r){var i=t;do{var a=i.prev,o=i.next.next;!y(a,o)&&v(a,i,i.next,o)&&b(a,o)&&b(o,a)&&(e.push(a.i/r|0),e.push(i.i/r|0),e.push(o.i/r|0),k(i),k(i.next),i=t=o),i=i.next}while(i!==t);return n(i)}function l(t,e,r,a,o,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&m(l,c)){var u=w(l,c);return l=n(l,l.next),u=n(u,u.next),i(l,e,r,a,o,s,0),void i(u,e,r,a,o,s,0)}c=c.next}l=l.next}while(l!==t)}function c(t,e){return t.x-e.x}function u(t,e){var r=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o&&(o=s,r=n.x<n.next.x?n:n.next,s===i))return r}n=n.next}while(n!==e);if(!r)return null;var l,c=r,u=r.x,f=r.y,p=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&d(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),b(n,t)&&(l<p||l===p&&(n.x>r.x||n.x===r.x&&h(r,n)))&&(r=n,p=l)),n=n.next}while(n!==c);return r}(t,e);if(!r)return e;var i=w(r,t);return n(i,i.next),n(r,r.next)}function h(t,e){return g(t.prev,t,e.prev)<0&&g(e.next,t,t.next)<0}function f(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=(t-r)*i|0)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=(e-n)*i|0)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function p(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function d(t,e,r,n,i,a,o,s){return(i-o)*(e-s)>=(t-o)*(a-s)&&(t-o)*(n-s)>=(r-o)*(e-s)&&(r-o)*(a-s)>=(i-o)*(n-s)}function m(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&v(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(g(t.prev,t,e.prev)||g(t,e.prev,e))||y(t,e)&&g(t.prev,t,t.next)>0&&g(e.prev,e,e.next)>0)}function g(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function v(t,e,r,n){var i=_(g(t,e,r)),a=_(g(t,e,n)),o=_(g(r,n,t)),s=_(g(r,n,e));return i!==a&&o!==s||!(0!==i||!x(t,r,e))||!(0!==a||!x(t,n,e))||!(0!==o||!x(r,t,n))||!(0!==s||!x(r,e,n))}function x(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function _(t){return t>0?1:t<0?-1:0}function b(t,e){return g(t.prev,t,t.next)<0?g(t,e,t.next)>=0&&g(t,t.prev,e)>=0:g(t,e,t.prev)<0||g(t,t.next,e)<0}function w(t,e){var r=new A(t.i,t.x,t.y),n=new A(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function T(t,e,r,n){var i=new A(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function A(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=0,this.prevZ=null,this.nextZ=null,this.steiner=!1}function M(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}t.exports=e,t.exports.default=e,e.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(M(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(M(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},e.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},96143:function(t,e,r){var n=r(26381);t.exports=function(t,e){var r,i=[],a=[],o=[],s={},l=[];function c(t){o[t]=!1,s.hasOwnProperty(t)&&Object.keys(s[t]).forEach((function(e){delete s[t][e],o[e]&&c(e)}))}function u(t){var e,n,i=!1;for(a.push(t),o[t]=!0,e=0;e<l[t].length;e++)(n=l[t][e])===r?(h(r,a),i=!0):o[n]||(i=u(n));if(i)c(t);else for(e=0;e<l[t].length;e++){n=l[t][e];var f=s[n];f||(f={},s[n]=f),f[n]=!0}return a.pop(),i}function h(t,r){var n=[].concat(r).concat(t);e?e(u):i.push(n)}function f(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter((function(t){return t>=e}))}(e);for(var r,i=n(t).components.filter((function(t){return t.length>1})),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];if(!l)return!1;var c=t.map((function(t,e){return-1===l.indexOf(e)?[]:t.filter((function(t){return-1!==l.indexOf(t)}))}));return{leastVertex:a,adjList:c}}r=0;for(var p=t.length;r<p;){var d=f(r);if(r=d.leastVertex,l=d.adjList){for(var m=0;m<l.length;m++)for(var g=0;g<l[m].length;g++){var y=l[m][g];o[+y]=!1,s[y]={}}u(r),r+=1}else r=p}return e?void 0:i}},40891:function(t,e,r){\"use strict\";var n=r(71129)(\"%Object.defineProperty%\",!0)||!1;if(n)try{n({},\"a\",{value:1})}catch(t){n=!1}t.exports=n},35465:function(t){\"use strict\";t.exports=EvalError},77731:function(t){\"use strict\";t.exports=Error},30582:function(t){\"use strict\";t.exports=RangeError},50294:function(t){\"use strict\";t.exports=ReferenceError},98800:function(t){\"use strict\";t.exports=SyntaxError},48631:function(t){\"use strict\";t.exports=TypeError},33149:function(t){\"use strict\";t.exports=URIError},91445:function(t,e,r){\"use strict\";var n=r(69746);t.exports=function(){return n(this).length=0,this}},82377:function(t,e,r){\"use strict\";t.exports=r(57712)()?Array.from:r(33468)},57712:function(t){\"use strict\";t.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},33468:function(t,e,r){\"use strict\";var n=r(63008).iterator,i=r(82262),a=r(59356),o=r(54653),s=r(52359),l=r(69746),c=r(1974),u=r(48488),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;t.exports=function(t){var e,r,m,g,y,v,x,_,b,w,T=arguments[1],k=arguments[2];if(t=Object(l(t)),c(T)&&s(T),this&&this!==Array&&a(this))e=this;else{if(!T){if(i(t))return 1!==(y=t.length)?Array.apply(null,t):((g=new Array(1))[0]=t[0],g);if(h(t)){for(g=new Array(y=t.length),r=0;r<y;++r)g[r]=t[r];return g}}g=[]}if(!h(t))if(void 0!==(b=t[n])){for(x=s(b).call(t),e&&(g=new e),_=x.next(),r=0;!_.done;)w=T?f.call(T,k,_.value,r):_.value,e?(p.value=w,d(g,r,p)):g[r]=w,_=x.next(),++r;y=r}else if(u(t)){for(y=t.length,e&&(g=new e),r=0,m=0;r<y;++r)w=t[r],r+1<y&&(v=w.charCodeAt(0))>=55296&&v<=56319&&(w+=t[++r]),w=T?f.call(T,k,w,m):w,e?(p.value=w,d(g,m,p)):g[m]=w,++m;y=m}if(void 0===y)for(y=o(t.length),e&&(g=new e(y)),r=0;r<y;++r)w=T?f.call(T,k,t[r],r):t[r],e?(p.value=w,d(g,r,p)):g[r]=w;return e&&(p.value=null,g.length=y),g}},82262:function(t){\"use strict\";var e=Object.prototype.toString,r=e.call(function(){return arguments}());t.exports=function(t){return e.call(t)===r}},59356:function(t){\"use strict\";var e=Object.prototype.toString,r=RegExp.prototype.test.bind(/^[object [A-Za-z0-9]*Function]$/);t.exports=function(t){return\"function\"==typeof t&&r(e.call(t))}},62039:function(t){\"use strict\";t.exports=function(){}},53579:function(t,e,r){\"use strict\";t.exports=r(67394)()?Math.sign:r(37122)},67394:function(t){\"use strict\";t.exports=function(){var t=Math.sign;return\"function\"==typeof t&&1===t(10)&&-1===t(-20)}},37122:function(t){\"use strict\";t.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},10226:function(t,e,r){\"use strict\";var n=r(53579),i=Math.abs,a=Math.floor;t.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},54653:function(t,e,r){\"use strict\";var n=r(10226),i=Math.max;t.exports=function(t){return i(0,n(t))}},39395:function(t,e,r){\"use strict\";var n=r(52359),i=r(69746),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;t.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,(function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e}))}}},1920:function(t,e,r){\"use strict\";t.exports=r(41271)()?Object.assign:r(26399)},41271:function(t){\"use strict\";t.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},26399:function(t,e,r){\"use strict\";var n=r(36353),i=r(69746),a=Math.max;t.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)n(e=arguments[o]).forEach(s);if(void 0!==r)throw r;return t}},86591:function(t,e,r){\"use strict\";var n=r(82377),i=r(1920),a=r(69746);t.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,(function(e){(o.ensure||e in t)&&(s[e]=t[e])})):i(s,t),s}},57842:function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;r(90361)()||(n=r(45765)),t.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach((function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}})),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},82813:function(t,e,r){\"use strict\";t.exports=r(39395)(\"forEach\")},76064:function(t,e,r){\"use strict\";var n=r(1974),i={function:!0,object:!0};t.exports=function(t){return n(t)&&i[typeof t]||!1}},1974:function(t,e,r){\"use strict\";var n=r(62039)();t.exports=function(t){return t!==n&&null!==t}},36353:function(t,e,r){\"use strict\";t.exports=r(83800)()?Object.keys:r(67044)},83800:function(t){\"use strict\";t.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},67044:function(t,e,r){\"use strict\";var n=r(1974),i=Object.keys;t.exports=function(t){return i(n(t)?Object(t):t)}},29854:function(t,e,r){\"use strict\";var n=r(52359),i=r(82813),a=Function.prototype.call;t.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,(function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)})),r}},76504:function(t,e,r){\"use strict\";var n=r(1974),i=Array.prototype.forEach,a=Object.create;t.exports=function(t){var e=a(null);return i.call(arguments,(function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)})),e}},22834:function(t,e,r){\"use strict\";t.exports=r(90361)()?Object.setPrototypeOf:r(45765)},90361:function(t){\"use strict\";var e=Object.create,r=Object.getPrototypeOf,n={};t.exports=function(){var t=Object.setPrototypeOf;return\"function\"==typeof t&&r(t((arguments[0]||e)(null),n))===n}},45765:function(t,e,r){\"use strict\";var n,i,a,o,s=r(76064),l=r(69746),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},t.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}(),i?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null),r(57842)},52359:function(t){\"use strict\";t.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},11004:function(t,e,r){\"use strict\";var n=r(76064);t.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},69746:function(t,e,r){\"use strict\";var n=r(1974);t.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},2338:function(t,e,r){\"use strict\";t.exports=r(65961)()?String.prototype.contains:r(9461)},65961:function(t){\"use strict\";var e=\"razdwatrzy\";t.exports=function(){return\"function\"==typeof e.contains&&!0===e.contains(\"dwa\")&&!1===e.contains(\"foo\")}},9461:function(t){\"use strict\";var e=String.prototype.indexOf;t.exports=function(t){return e.call(this,t,arguments[1])>-1}},48488:function(t){\"use strict\";var e=Object.prototype.toString,r=e.call(\"\");t.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||e.call(t)===r)||!1}},43497:function(t){\"use strict\";var e=Object.create(null),r=Math.random;t.exports=function(){var t;do{t=r().toString(36).slice(2)}while(e[t]);return t}},71343:function(t,e,r){\"use strict\";var n,i=r(22834),a=r(2338),o=r(91819),s=r(63008),l=r(85490),c=Object.defineProperty;n=t.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o((function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t}))}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},58755:function(t,e,r){\"use strict\";var n=r(82262),i=r(52359),a=r(48488),o=r(34494),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;t.exports=function(t,e){var r,u,h,f,p,d,m,g,y=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,y,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(m=t[p],p+1<d&&(g=m.charCodeAt(0))>=55296&&g<=56319&&(m+=t[++p]),l.call(e,y,m,h),!f);++p);else c.call(t,(function(t){return l.call(e,y,t,h),f}))}},34494:function(t,e,r){\"use strict\";var n=r(82262),i=r(48488),a=r(71343),o=r(23417),s=r(82831),l=r(63008).iterator;t.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},85490:function(t,e,r){\"use strict\";var n,i=r(91445),a=r(1920),o=r(52359),s=r(69746),l=r(91819),c=r(84510),u=r(63008),h=Object.defineProperty,f=Object.defineProperties;t.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l((function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()})),next:l((function(){return this._createResult(this._next())})),_createResult:l((function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}})),_resolve:l((function(t){return this.__list__[t]})),_unBind:l((function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)})),toString:l((function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"}))},c({_onAdd:l((function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach((function(e,r){e>=t&&(this.__redo__[r]=++e)}),this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))})),_onDelete:l((function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach((function(e,r){e>t&&(this.__redo__[r]=--e)}),this)))})),_onClear:l((function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0}))}))),h(n.prototype,u.iterator,l((function(){return this})))},50567:function(t,e,r){\"use strict\";var n=r(82262),i=r(1974),a=r(48488),o=r(63008).iterator,s=Array.isArray;t.exports=function(t){return!(!i(t)||!s(t)&&!a(t)&&!n(t)&&\"function\"!=typeof t[o])}},23417:function(t,e,r){\"use strict\";var n,i=r(22834),a=r(91819),o=r(63008),s=r(85490),l=Object.defineProperty;n=t.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a((function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()})),_resolve:a((function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r}))}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},82831:function(t,e,r){\"use strict\";var n=r(50567);t.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},63008:function(t,e,r){\"use strict\";t.exports=r(25143)()?r(64725).Symbol:r(81905)},25143:function(t,e,r){\"use strict\";var n=r(64725),i={object:!0,symbol:!0};t.exports=function(){var t,e=n.Symbol;if(\"function\"!=typeof e)return!1;t=e(\"test symbol\");try{String(t)}catch(t){return!1}return!!i[typeof e.iterator]&&!!i[typeof e.toPrimitive]&&!!i[typeof e.toStringTag]}},41707:function(t){\"use strict\";t.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag])}},74009:function(t,e,r){\"use strict\";var n=r(91819),i=Object.create,a=Object.defineProperty,o=Object.prototype,s=i(null);t.exports=function(t){for(var e,r,i=0;s[t+(i||\"\")];)++i;return s[t+=i||\"\"]=!0,a(o,e=\"@@\"+t,n.gs(null,(function(t){r||(r=!0,a(this,e,n(t)),r=!1)}))),e}},40313:function(t,e,r){\"use strict\";var n=r(91819),i=r(64725).Symbol;t.exports=function(t){return Object.defineProperties(t,{hasInstance:n(\"\",i&&i.hasInstance||t(\"hasInstance\")),isConcatSpreadable:n(\"\",i&&i.isConcatSpreadable||t(\"isConcatSpreadable\")),iterator:n(\"\",i&&i.iterator||t(\"iterator\")),match:n(\"\",i&&i.match||t(\"match\")),replace:n(\"\",i&&i.replace||t(\"replace\")),search:n(\"\",i&&i.search||t(\"search\")),species:n(\"\",i&&i.species||t(\"species\")),split:n(\"\",i&&i.split||t(\"split\")),toPrimitive:n(\"\",i&&i.toPrimitive||t(\"toPrimitive\")),toStringTag:n(\"\",i&&i.toStringTag||t(\"toStringTag\")),unscopables:n(\"\",i&&i.unscopables||t(\"unscopables\"))})}},21290:function(t,e,r){\"use strict\";var n=r(91819),i=r(91765),a=Object.create(null);t.exports=function(t){return Object.defineProperties(t,{for:n((function(e){return a[e]?a[e]:a[e]=t(String(e))})),keyFor:n((function(t){var e;for(e in i(t),a)if(a[e]===t)return e}))})}},81905:function(t,e,r){\"use strict\";var n,i,a,o=r(91819),s=r(91765),l=r(64725).Symbol,c=r(74009),u=r(40313),h=r(21290),f=Object.create,p=Object.defineProperties,d=Object.defineProperty;if(\"function\"==typeof l)try{String(l()),a=!0}catch(t){}else l=null;i=function(t){if(this instanceof i)throw new TypeError(\"Symbol is not a constructor\");return n(t)},t.exports=n=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return a?l(e):(r=f(i.prototype),e=void 0===e?\"\":String(e),p(r,{__description__:o(\"\",e),__name__:o(\"\",c(e))}))},u(n),h(n),p(i.prototype,{constructor:o(n),toString:o(\"\",(function(){return this.__name__}))}),p(n.prototype,{toString:o((function(){return\"Symbol (\"+s(this).__description__+\")\"})),valueOf:o((function(){return s(this)}))}),d(n.prototype,n.toPrimitive,o(\"\",(function(){var t=s(this);return\"symbol\"==typeof t?t:t.toString()}))),d(n.prototype,n.toStringTag,o(\"c\",\"Symbol\")),d(i.prototype,n.toStringTag,o(\"c\",n.prototype[n.toStringTag])),d(i.prototype,n.toPrimitive,o(\"c\",n.prototype[n.toPrimitive]))},91765:function(t,e,r){\"use strict\";var n=r(41707);t.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},93103:function(t,e,r){\"use strict\";t.exports=r(22742)()?WeakMap:r(21780)},22742:function(t){\"use strict\";t.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&\"function\"==typeof t.set&&t.set({},1)===t&&\"function\"==typeof t.delete&&\"function\"==typeof t.has&&\"one\"===t.get(e)}},81810:function(t){\"use strict\";t.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},21780:function(t,e,r){\"use strict\";var n,i=r(1974),a=r(22834),o=r(11004),s=r(69746),l=r(43497),c=r(91819),u=r(34494),h=r(58755),f=r(63008).toStringTag,p=r(81810),d=Array.isArray,m=Object.defineProperty,g=Object.prototype.hasOwnProperty,y=Object.getPrototypeOf;t.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,y(this)):this,i(e)&&(d(e)||(e=u(e))),m(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,(function(e){s(e),t.set(e[0],e[1])})),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c((function(t){return!!g.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)})),get:c((function(t){if(g.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]})),has:c((function(t){return g.call(o(t),this.__weakMapData__)})),set:c((function(t,e){return m(o(t),this.__weakMapData__,c(\"c\",e)),this})),toString:c((function(){return\"[object WeakMap]\"}))}),m(n.prototype,f,c(\"c\",\"WeakMap\"))},7683:function(t){\"use strict\";var e,r=\"object\"==typeof Reflect?Reflect:null,n=r&&\"function\"==typeof r.apply?r.apply:function(t,e,r){return Function.prototype.apply.call(t,e,r)};e=r&&\"function\"==typeof r.ownKeys?r.ownKeys:Object.getOwnPropertySymbols?function(t){return Object.getOwnPropertyNames(t).concat(Object.getOwnPropertySymbols(t))}:function(t){return Object.getOwnPropertyNames(t)};var i=Number.isNaN||function(t){return t!=t};function a(){a.init.call(this)}t.exports=a,t.exports.once=function(t,e){return new Promise((function(r,n){function i(r){t.removeListener(e,a),n(r)}function a(){\"function\"==typeof t.removeListener&&t.removeListener(\"error\",i),r([].slice.call(arguments))}m(t,e,a,{once:!0}),\"error\"!==e&&function(t,e,r){\"function\"==typeof t.on&&m(t,\"error\",e,{once:!0})}(t,i)}))},a.EventEmitter=a,a.prototype._events=void 0,a.prototype._eventsCount=0,a.prototype._maxListeners=void 0;var o=10;function s(t){if(\"function\"!=typeof t)throw new TypeError('The \"listener\" argument must be of type Function. Received type '+typeof t)}function l(t){return void 0===t._maxListeners?a.defaultMaxListeners:t._maxListeners}function c(t,e,r,n){var i,a,o,c;if(s(r),void 0===(a=t._events)?(a=t._events=Object.create(null),t._eventsCount=0):(void 0!==a.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),a=t._events),o=a[e]),void 0===o)o=a[e]=r,++t._eventsCount;else if(\"function\"==typeof o?o=a[e]=n?[r,o]:[o,r]:n?o.unshift(r):o.push(r),(i=l(t))>0&&o.length>i&&!o.warned){o.warned=!0;var u=new Error(\"Possible EventEmitter memory leak detected. \"+o.length+\" \"+String(e)+\" listeners added. Use emitter.setMaxListeners() to increase limit\");u.name=\"MaxListenersExceededWarning\",u.emitter=t,u.type=e,u.count=o.length,c=u,console&&console.warn&&console.warn(c)}return t}function u(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,0===arguments.length?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function h(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=u.bind(n);return i.listener=r,n.wrapFn=i,i}function f(t,e,r){var n=t._events;if(void 0===n)return[];var i=n[e];return void 0===i?[]:\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):d(i,i.length)}function p(t){var e=this._events;if(void 0!==e){var r=e[t];if(\"function\"==typeof r)return 1;if(void 0!==r)return r.length}return 0}function d(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}function m(t,e,r,n){if(\"function\"==typeof t.on)n.once?t.once(e,r):t.on(e,r);else{if(\"function\"!=typeof t.addEventListener)throw new TypeError('The \"emitter\" argument must be of type EventEmitter. Received type '+typeof t);t.addEventListener(e,(function i(a){n.once&&t.removeEventListener(e,i),r(a)}))}}Object.defineProperty(a,\"defaultMaxListeners\",{enumerable:!0,get:function(){return o},set:function(t){if(\"number\"!=typeof t||t<0||i(t))throw new RangeError('The value of \"defaultMaxListeners\" is out of range. It must be a non-negative number. Received '+t+\".\");o=t}}),a.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},a.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||i(t))throw new RangeError('The value of \"n\" is out of range. It must be a non-negative number. Received '+t+\".\");return this._maxListeners=t,this},a.prototype.getMaxListeners=function(){return l(this)},a.prototype.emit=function(t){for(var e=[],r=1;r<arguments.length;r++)e.push(arguments[r]);var i=\"error\"===t,a=this._events;if(void 0!==a)i=i&&void 0===a.error;else if(!i)return!1;if(i){var o;if(e.length>0&&(o=e[0]),o instanceof Error)throw o;var s=new Error(\"Unhandled error.\"+(o?\" (\"+o.message+\")\":\"\"));throw s.context=o,s}var l=a[t];if(void 0===l)return!1;if(\"function\"==typeof l)n(l,this,e);else{var c=l.length,u=d(l,c);for(r=0;r<c;++r)n(u[r],this,e)}return!0},a.prototype.addListener=function(t,e){return c(this,t,e,!1)},a.prototype.on=a.prototype.addListener,a.prototype.prependListener=function(t,e){return c(this,t,e,!0)},a.prototype.once=function(t,e){return s(e),this.on(t,h(this,t,e)),this},a.prototype.prependOnceListener=function(t,e){return s(e),this.prependListener(t,h(this,t,e)),this},a.prototype.removeListener=function(t,e){var r,n,i,a,o;if(s(e),void 0===(n=this._events))return this;if(void 0===(r=n[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=Object.create(null):(delete n[t],n.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(i=-1,a=r.length-1;a>=0;a--)if(r[a]===e||r[a].listener===e){o=r[a].listener,i=a;break}if(i<0)return this;0===i?r.shift():function(t,e){for(;e+1<t.length;e++)t[e]=t[e+1];t.pop()}(r,i),1===r.length&&(n[t]=r[0]),void 0!==n.removeListener&&this.emit(\"removeListener\",t,o||e)}return this},a.prototype.off=a.prototype.removeListener,a.prototype.removeAllListeners=function(t){var e,r,n;if(void 0===(r=this._events))return this;if(void 0===r.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==r[t]&&(0==--this._eventsCount?this._events=Object.create(null):delete r[t]),this;if(0===arguments.length){var i,a=Object.keys(r);for(n=0;n<a.length;++n)\"removeListener\"!==(i=a[n])&&this.removeAllListeners(i);return this.removeAllListeners(\"removeListener\"),this._events=Object.create(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(void 0!==e)for(n=e.length-1;n>=0;n--)this.removeListener(t,e[n]);return this},a.prototype.listeners=function(t){return f(this,t,!0)},a.prototype.rawListeners=function(t){return f(this,t,!1)},a.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):p.call(t,e)},a.prototype.listenerCount=p,a.prototype.eventNames=function(){return this._eventsCount>0?e(this._events):[]}},77083:function(t){var e=function(){if(\"object\"==typeof self&&self)return self;if(\"object\"==typeof window&&window)return window;throw new Error(\"Unable to resolve global `this`\")};t.exports=function(){if(this)return this;try{Object.defineProperty(Object.prototype,\"__global__\",{get:function(){return this},configurable:!0})}catch(t){return e()}try{return __global__||e()}finally{delete Object.prototype.__global__}}()},64725:function(t,e,r){\"use strict\";t.exports=r(17804)()?globalThis:r(77083)},17804:function(t){\"use strict\";t.exports=function(){return\"object\"==typeof globalThis&&!!globalThis&&globalThis.Array===Array}},10721:function(t,e,r){\"use strict\";var n=r(9914);t.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0==(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},83473:function(t,e,r){var n=r(10275);t.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(i=0,o=r,s=(e=new h(t.length+r)).length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},68950:function(t,e,r){\"use strict\";var n=r(38211),i=[32,126];t.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;if(a&&\"string\"!=typeof a&&(a=n(a)),Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";var f=o[0]/2,p=o[1]/2;for(c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},12673:function(t){\"use strict\";function e(t,a){a||(a={}),(\"string\"==typeof t||Array.isArray(t))&&(a.family=t);var o=Array.isArray(a.family)?a.family.join(\", \"):a.family;if(!o)throw Error(\"`family` must be defined\");var s=a.size||a.fontSize||a.em||48,l=a.weight||a.fontWeight||\"\",c=(t=[a.style||a.fontStyle||\"\",l,s].join(\" \")+\"px \"+o,a.origin||\"top\");if(e.cache[o]&&s<=e.cache[o].em)return r(e.cache[o],c);var u=a.canvas||e.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==a.upper?a.upper:\"H\",lower:void 0!==a.lower?a.lower:\"x\",descent:void 0!==a.descent?a.descent:\"p\",ascent:void 0!==a.ascent?a.ascent:\"h\",tittle:void 0!==a.tittle?a.tittle:\"i\",overshoot:void 0!==a.overshoot?a.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d=\"H\",m={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(d,0,0);var g=n(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(d,0,p);var y=n(h.getImageData(0,0,p,p));m.lineHeight=m.bottom=p-y+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(d,0,p);var v=p-n(h.getImageData(0,0,p,p))-1+g;m.baseline=m.alphabetic=v,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(d,0,.5*p);var x=n(h.getImageData(0,0,p,p));m.median=m.middle=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(d,0,.5*p);var _=n(h.getImageData(0,0,p,p));m.hanging=p-_-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(d,0,p);var b=n(h.getImageData(0,0,p,p));if(m.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),m.upper=n(h.getImageData(0,0,p,p)),m.capHeight=m.baseline-m.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),m.lower=n(h.getImageData(0,0,p,p)),m.xHeight=m.baseline-m.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),m.tittle=n(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),m.ascent=n(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),m.descent=i(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var w=i(h.getImageData(0,0,p,p));m.overshoot=w-v}for(var T in m)m[T]/=s;return m.em=s,e.cache[o]=m,r(m,c)}function r(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function n(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function i(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}t.exports=e,e.canvas=document.createElement(\"canvas\"),e.cache={}},61262:function(t,e,r){\"use strict\";var n=r(82756),i=Object.prototype.toString,a=Object.prototype.hasOwnProperty;t.exports=function(t,e,r){if(!n(e))throw new TypeError(\"iterator must be a function\");var o;arguments.length>=3&&(o=r),\"[object Array]\"===i.call(t)?function(t,e,r){for(var n=0,i=t.length;n<i;n++)a.call(t,n)&&(null==r?e(t[n],n,t):e.call(r,t[n],n,t))}(t,e,o):\"string\"==typeof t?function(t,e,r){for(var n=0,i=t.length;n<i;n++)null==r?e(t.charAt(n),n,t):e.call(r,t.charAt(n),n,t)}(t,e,o):function(t,e,r){for(var n in t)a.call(t,n)&&(null==r?e(t[n],n,t):e.call(r,t[n],n,t))}(t,e,o)}},31917:function(t){\"use strict\";var e=Object.prototype.toString,r=Math.max,n=function(t,e){for(var r=[],n=0;n<t.length;n+=1)r[n]=t[n];for(var i=0;i<e.length;i+=1)r[i+t.length]=e[i];return r};t.exports=function(t){var i=this;if(\"function\"!=typeof i||\"[object Function]\"!==e.apply(i))throw new TypeError(\"Function.prototype.bind called on incompatible \"+i);for(var a,o=function(t,e){for(var r=[],n=1,i=0;n<t.length;n+=1,i+=1)r[i]=t[n];return r}(arguments),s=r(0,i.length-o.length),l=[],c=0;c<s;c++)l[c]=\"$\"+c;if(a=Function(\"binder\",\"return function (\"+function(t,e){for(var r=\"\",n=0;n<t.length;n+=1)r+=t[n],n+1<t.length&&(r+=\",\");return r}(l)+\"){ return binder.apply(this,arguments); }\")((function(){if(this instanceof a){var e=i.apply(this,n(o,arguments));return Object(e)===e?e:this}return i.apply(t,n(o,arguments))})),i.prototype){var u=function(){};u.prototype=i.prototype,a.prototype=new u,u.prototype=null}return a}},87547:function(t,e,r){\"use strict\";var n=r(31917);t.exports=Function.prototype.bind||n},72880:function(t){t.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width),\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},71129:function(t,e,r){\"use strict\";var n,i=r(77731),a=r(35465),o=r(30582),s=r(50294),l=r(98800),c=r(48631),u=r(33149),h=Function,f=function(t){try{return h('\"use strict\"; return ('+t+\").constructor;\")()}catch(t){}},p=Object.getOwnPropertyDescriptor;if(p)try{p({},\"\")}catch(t){p=null}var d=function(){throw new c},m=p?function(){try{return d}catch(t){try{return p(arguments,\"callee\").get}catch(t){return d}}}():d,g=r(8771)(),y=r(58436)(),v=Object.getPrototypeOf||(y?function(t){return t.__proto__}:null),x={},_=\"undefined\"!=typeof Uint8Array&&v?v(Uint8Array):n,b={__proto__:null,\"%AggregateError%\":\"undefined\"==typeof AggregateError?n:AggregateError,\"%Array%\":Array,\"%ArrayBuffer%\":\"undefined\"==typeof ArrayBuffer?n:ArrayBuffer,\"%ArrayIteratorPrototype%\":g&&v?v([][Symbol.iterator]()):n,\"%AsyncFromSyncIteratorPrototype%\":n,\"%AsyncFunction%\":x,\"%AsyncGenerator%\":x,\"%AsyncGeneratorFunction%\":x,\"%AsyncIteratorPrototype%\":x,\"%Atomics%\":\"undefined\"==typeof Atomics?n:Atomics,\"%BigInt%\":\"undefined\"==typeof BigInt?n:BigInt,\"%BigInt64Array%\":\"undefined\"==typeof BigInt64Array?n:BigInt64Array,\"%BigUint64Array%\":\"undefined\"==typeof BigUint64Array?n:BigUint64Array,\"%Boolean%\":Boolean,\"%DataView%\":\"undefined\"==typeof DataView?n:DataView,\"%Date%\":Date,\"%decodeURI%\":decodeURI,\"%decodeURIComponent%\":decodeURIComponent,\"%encodeURI%\":encodeURI,\"%encodeURIComponent%\":encodeURIComponent,\"%Error%\":i,\"%eval%\":eval,\"%EvalError%\":a,\"%Float32Array%\":\"undefined\"==typeof Float32Array?n:Float32Array,\"%Float64Array%\":\"undefined\"==typeof Float64Array?n:Float64Array,\"%FinalizationRegistry%\":\"undefined\"==typeof FinalizationRegistry?n:FinalizationRegistry,\"%Function%\":h,\"%GeneratorFunction%\":x,\"%Int8Array%\":\"undefined\"==typeof Int8Array?n:Int8Array,\"%Int16Array%\":\"undefined\"==typeof Int16Array?n:Int16Array,\"%Int32Array%\":\"undefined\"==typeof Int32Array?n:Int32Array,\"%isFinite%\":isFinite,\"%isNaN%\":isNaN,\"%IteratorPrototype%\":g&&v?v(v([][Symbol.iterator]())):n,\"%JSON%\":\"object\"==typeof JSON?JSON:n,\"%Map%\":\"undefined\"==typeof Map?n:Map,\"%MapIteratorPrototype%\":\"undefined\"!=typeof Map&&g&&v?v((new Map)[Symbol.iterator]()):n,\"%Math%\":Math,\"%Number%\":Number,\"%Object%\":Object,\"%parseFloat%\":parseFloat,\"%parseInt%\":parseInt,\"%Promise%\":\"undefined\"==typeof Promise?n:Promise,\"%Proxy%\":\"undefined\"==typeof Proxy?n:Proxy,\"%RangeError%\":o,\"%ReferenceError%\":s,\"%Reflect%\":\"undefined\"==typeof Reflect?n:Reflect,\"%RegExp%\":RegExp,\"%Set%\":\"undefined\"==typeof Set?n:Set,\"%SetIteratorPrototype%\":\"undefined\"!=typeof Set&&g&&v?v((new Set)[Symbol.iterator]()):n,\"%SharedArrayBuffer%\":\"undefined\"==typeof SharedArrayBuffer?n:SharedArrayBuffer,\"%String%\":String,\"%StringIteratorPrototype%\":g&&v?v(\"\"[Symbol.iterator]()):n,\"%Symbol%\":g?Symbol:n,\"%SyntaxError%\":l,\"%ThrowTypeError%\":m,\"%TypedArray%\":_,\"%TypeError%\":c,\"%Uint8Array%\":\"undefined\"==typeof Uint8Array?n:Uint8Array,\"%Uint8ClampedArray%\":\"undefined\"==typeof Uint8ClampedArray?n:Uint8ClampedArray,\"%Uint16Array%\":\"undefined\"==typeof Uint16Array?n:Uint16Array,\"%Uint32Array%\":\"undefined\"==typeof Uint32Array?n:Uint32Array,\"%URIError%\":u,\"%WeakMap%\":\"undefined\"==typeof WeakMap?n:WeakMap,\"%WeakRef%\":\"undefined\"==typeof WeakRef?n:WeakRef,\"%WeakSet%\":\"undefined\"==typeof WeakSet?n:WeakSet};if(v)try{null.error}catch(t){var w=v(v(t));b[\"%Error.prototype%\"]=w}var T=function t(e){var r;if(\"%AsyncFunction%\"===e)r=f(\"async function () {}\");else if(\"%GeneratorFunction%\"===e)r=f(\"function* () {}\");else if(\"%AsyncGeneratorFunction%\"===e)r=f(\"async function* () {}\");else if(\"%AsyncGenerator%\"===e){var n=t(\"%AsyncGeneratorFunction%\");n&&(r=n.prototype)}else if(\"%AsyncIteratorPrototype%\"===e){var i=t(\"%AsyncGenerator%\");i&&v&&(r=v(i.prototype))}return b[e]=r,r},k={__proto__:null,\"%ArrayBufferPrototype%\":[\"ArrayBuffer\",\"prototype\"],\"%ArrayPrototype%\":[\"Array\",\"prototype\"],\"%ArrayProto_entries%\":[\"Array\",\"prototype\",\"entries\"],\"%ArrayProto_forEach%\":[\"Array\",\"prototype\",\"forEach\"],\"%ArrayProto_keys%\":[\"Array\",\"prototype\",\"keys\"],\"%ArrayProto_values%\":[\"Array\",\"prototype\",\"values\"],\"%AsyncFunctionPrototype%\":[\"AsyncFunction\",\"prototype\"],\"%AsyncGenerator%\":[\"AsyncGeneratorFunction\",\"prototype\"],\"%AsyncGeneratorPrototype%\":[\"AsyncGeneratorFunction\",\"prototype\",\"prototype\"],\"%BooleanPrototype%\":[\"Boolean\",\"prototype\"],\"%DataViewPrototype%\":[\"DataView\",\"prototype\"],\"%DatePrototype%\":[\"Date\",\"prototype\"],\"%ErrorPrototype%\":[\"Error\",\"prototype\"],\"%EvalErrorPrototype%\":[\"EvalError\",\"prototype\"],\"%Float32ArrayPrototype%\":[\"Float32Array\",\"prototype\"],\"%Float64ArrayPrototype%\":[\"Float64Array\",\"prototype\"],\"%FunctionPrototype%\":[\"Function\",\"prototype\"],\"%Generator%\":[\"GeneratorFunction\",\"prototype\"],\"%GeneratorPrototype%\":[\"GeneratorFunction\",\"prototype\",\"prototype\"],\"%Int8ArrayPrototype%\":[\"Int8Array\",\"prototype\"],\"%Int16ArrayPrototype%\":[\"Int16Array\",\"prototype\"],\"%Int32ArrayPrototype%\":[\"Int32Array\",\"prototype\"],\"%JSONParse%\":[\"JSON\",\"parse\"],\"%JSONStringify%\":[\"JSON\",\"stringify\"],\"%MapPrototype%\":[\"Map\",\"prototype\"],\"%NumberPrototype%\":[\"Number\",\"prototype\"],\"%ObjectPrototype%\":[\"Object\",\"prototype\"],\"%ObjProto_toString%\":[\"Object\",\"prototype\",\"toString\"],\"%ObjProto_valueOf%\":[\"Object\",\"prototype\",\"valueOf\"],\"%PromisePrototype%\":[\"Promise\",\"prototype\"],\"%PromiseProto_then%\":[\"Promise\",\"prototype\",\"then\"],\"%Promise_all%\":[\"Promise\",\"all\"],\"%Promise_reject%\":[\"Promise\",\"reject\"],\"%Promise_resolve%\":[\"Promise\",\"resolve\"],\"%RangeErrorPrototype%\":[\"RangeError\",\"prototype\"],\"%ReferenceErrorPrototype%\":[\"ReferenceError\",\"prototype\"],\"%RegExpPrototype%\":[\"RegExp\",\"prototype\"],\"%SetPrototype%\":[\"Set\",\"prototype\"],\"%SharedArrayBufferPrototype%\":[\"SharedArrayBuffer\",\"prototype\"],\"%StringPrototype%\":[\"String\",\"prototype\"],\"%SymbolPrototype%\":[\"Symbol\",\"prototype\"],\"%SyntaxErrorPrototype%\":[\"SyntaxError\",\"prototype\"],\"%TypedArrayPrototype%\":[\"TypedArray\",\"prototype\"],\"%TypeErrorPrototype%\":[\"TypeError\",\"prototype\"],\"%Uint8ArrayPrototype%\":[\"Uint8Array\",\"prototype\"],\"%Uint8ClampedArrayPrototype%\":[\"Uint8ClampedArray\",\"prototype\"],\"%Uint16ArrayPrototype%\":[\"Uint16Array\",\"prototype\"],\"%Uint32ArrayPrototype%\":[\"Uint32Array\",\"prototype\"],\"%URIErrorPrototype%\":[\"URIError\",\"prototype\"],\"%WeakMapPrototype%\":[\"WeakMap\",\"prototype\"],\"%WeakSetPrototype%\":[\"WeakSet\",\"prototype\"]},A=r(87547),M=r(80753),S=A.call(Function.call,Array.prototype.concat),E=A.call(Function.apply,Array.prototype.splice),C=A.call(Function.call,String.prototype.replace),L=A.call(Function.call,String.prototype.slice),I=A.call(Function.call,RegExp.prototype.exec),P=/[^%.[\\]]+|\\[(?:(-?\\d+(?:\\.\\d+)?)|([\"'])((?:(?!\\2)[^\\\\]|\\\\.)*?)\\2)\\]|(?=(?:\\.|\\[\\])(?:\\.|\\[\\]|%$))/g,z=/\\\\(\\\\)?/g,O=function(t,e){var r,n=t;if(M(k,n)&&(n=\"%\"+(r=k[n])[0]+\"%\"),M(b,n)){var i=b[n];if(i===x&&(i=T(n)),void 0===i&&!e)throw new c(\"intrinsic \"+t+\" exists, but is not available. Please file an issue!\");return{alias:r,name:n,value:i}}throw new l(\"intrinsic \"+t+\" does not exist!\")};t.exports=function(t,e){if(\"string\"!=typeof t||0===t.length)throw new c(\"intrinsic name must be a non-empty string\");if(arguments.length>1&&\"boolean\"!=typeof e)throw new c('\"allowMissing\" argument must be a boolean');if(null===I(/^%?[^%]*%?$/,t))throw new l(\"`%` may not be present anywhere but at the beginning and end of the intrinsic name\");var r=function(t){var e=L(t,0,1),r=L(t,-1);if(\"%\"===e&&\"%\"!==r)throw new l(\"invalid intrinsic syntax, expected closing `%`\");if(\"%\"===r&&\"%\"!==e)throw new l(\"invalid intrinsic syntax, expected opening `%`\");var n=[];return C(t,P,(function(t,e,r,i){n[n.length]=r?C(i,z,\"$1\"):e||t})),n}(t),n=r.length>0?r[0]:\"\",i=O(\"%\"+n+\"%\",e),a=i.name,o=i.value,s=!1,u=i.alias;u&&(n=u[0],E(r,S([0,1],u)));for(var h=1,f=!0;h<r.length;h+=1){var d=r[h],m=L(d,0,1),g=L(d,-1);if(('\"'===m||\"'\"===m||\"`\"===m||'\"'===g||\"'\"===g||\"`\"===g)&&m!==g)throw new l(\"property names with quotes must have matching quotes\");if(\"constructor\"!==d&&f||(s=!0),M(b,a=\"%\"+(n+=\".\"+d)+\"%\"))o=b[a];else if(null!=o){if(!(d in o)){if(!e)throw new c(\"base intrinsic for \"+t+\" exists, but the property is not available.\");return}if(p&&h+1>=r.length){var y=p(o,d);o=(f=!!y)&&\"get\"in y&&!(\"originalValue\"in y.get)?y.get:o[d]}else f=M(o,d),o=o[d];f&&!s&&(b[a]=o)}}return o}},84840:function(t){t.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],m=e[13],g=e[14],y=e[15];return t[0]=s*(f*y-p*g)-h*(l*y-c*g)+m*(l*p-c*f),t[1]=-(n*(f*y-p*g)-h*(i*y-a*g)+m*(i*p-a*f)),t[2]=n*(l*y-c*g)-s*(i*y-a*g)+m*(i*c-a*l),t[3]=-(n*(l*p-c*f)-s*(i*p-a*f)+h*(i*c-a*l)),t[4]=-(o*(f*y-p*g)-u*(l*y-c*g)+d*(l*p-c*f)),t[5]=r*(f*y-p*g)-u*(i*y-a*g)+d*(i*p-a*f),t[6]=-(r*(l*y-c*g)-o*(i*y-a*g)+d*(i*c-a*l)),t[7]=r*(l*p-c*f)-o*(i*p-a*f)+u*(i*c-a*l),t[8]=o*(h*y-p*m)-u*(s*y-c*m)+d*(s*p-c*h),t[9]=-(r*(h*y-p*m)-u*(n*y-a*m)+d*(n*p-a*h)),t[10]=r*(s*y-c*m)-o*(n*y-a*m)+d*(n*c-a*s),t[11]=-(r*(s*p-c*h)-o*(n*p-a*h)+u*(n*c-a*s)),t[12]=-(o*(h*g-f*m)-u*(s*g-l*m)+d*(s*f-l*h)),t[13]=r*(h*g-f*m)-u*(n*g-i*m)+d*(n*f-i*h),t[14]=-(r*(s*g-l*m)-o*(n*g-i*m)+d*(n*l-i*s)),t[15]=r*(s*f-l*h)-o*(n*f-i*h)+u*(n*l-i*s),t}},99698:function(t){t.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},57938:function(t){t.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},87519:function(t){t.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},6900:function(t){t.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],m=t[14],g=t[15];return(e*o-r*a)*(h*g-f*m)-(e*s-n*a)*(u*g-f*d)+(e*l-i*a)*(u*m-h*d)+(r*s-n*o)*(c*g-f*p)-(r*l-i*o)*(c*m-h*p)+(n*l-i*s)*(c*d-u*p)}},36472:function(t){t.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,m=a*o,g=a*s,y=a*l;return t[0]=1-h-d,t[1]=u+y,t[2]=f-g,t[3]=0,t[4]=u-y,t[5]=1-c-d,t[6]=p+m,t[7]=0,t[8]=f+g,t[9]=p-m,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},43061:function(t){t.exports=function(t,e,r){var n,i,a,o=r[0],s=r[1],l=r[2],c=Math.sqrt(o*o+s*s+l*l);return Math.abs(c)<1e-6?null:(o*=c=1/c,s*=c,l*=c,n=Math.sin(e),a=1-(i=Math.cos(e)),t[0]=o*o*a+i,t[1]=s*o*a+l*n,t[2]=l*o*a-s*n,t[3]=0,t[4]=o*s*a-l*n,t[5]=s*s*a+i,t[6]=l*s*a+o*n,t[7]=0,t[8]=o*l*a+s*n,t[9]=s*l*a-o*n,t[10]=l*l*a+i,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t)}},33606:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,m=a*c,g=o*s,y=o*l,v=o*c;return t[0]=1-(p+m),t[1]=h+v,t[2]=f-y,t[3]=0,t[4]=h-v,t[5]=1-(u+m),t[6]=d+g,t[7]=0,t[8]=f+y,t[9]=d-g,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},98698:function(t){t.exports=function(t,e){return t[0]=e[0],t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=e[1],t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=e[2],t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},6924:function(t){t.exports=function(t,e){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=e[0],t[13]=e[1],t[14]=e[2],t[15]=1,t}},81181:function(t){t.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=n,t[6]=r,t[7]=0,t[8]=0,t[9]=-r,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},95258:function(t){t.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=0,t[2]=-r,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=r,t[9]=0,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},94815:function(t){t.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=0,t[4]=-r,t[5]=n,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},87301:function(t){t.exports=function(t,e,r,n,i,a,o){var s=1/(r-e),l=1/(i-n),c=1/(a-o);return t[0]=2*a*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=2*a*l,t[6]=0,t[7]=0,t[8]=(r+e)*s,t[9]=(i+n)*l,t[10]=(o+a)*c,t[11]=-1,t[12]=0,t[13]=0,t[14]=o*a*2*c,t[15]=0,t}},87193:function(t){t.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},11191:function(t,e,r){t.exports={create:r(87519),clone:r(99698),copy:r(57938),identity:r(87193),transpose:r(10256),invert:r(96559),adjoint:r(84840),determinant:r(6900),multiply:r(14787),translate:r(4165),scale:r(8697),rotate:r(32416),rotateX:r(81066),rotateY:r(54201),rotateZ:r(33920),fromRotation:r(43061),fromRotationTranslation:r(33606),fromScaling:r(98698),fromTranslation:r(6924),fromXRotation:r(81181),fromYRotation:r(95258),fromZRotation:r(94815),fromQuat:r(36472),frustum:r(87301),perspective:r(5313),perspectiveFromFieldOfView:r(22253),ortho:r(4633),lookAt:r(26645),str:r(66992)}},96559:function(t){t.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],m=e[13],g=e[14],y=e[15],v=r*s-n*o,x=r*l-i*o,_=r*c-a*o,b=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*m-h*d,A=u*g-f*d,M=u*y-p*d,S=h*g-f*m,E=h*y-p*m,C=f*y-p*g,L=v*C-x*E+_*S+b*M-w*A+T*k;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(m*T-g*w+y*b)*L,t[3]=(f*w-h*T-p*b)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(g*_-d*T-y*x)*L,t[7]=(u*T-f*_+p*x)*L,t[8]=(o*E-s*M+c*k)*L,t[9]=(n*M-r*E-a*k)*L,t[10]=(d*w-m*_+y*v)*L,t[11]=(h*_-u*w-p*v)*L,t[12]=(s*A-o*S-l*k)*L,t[13]=(r*S-n*A+i*k)*L,t[14]=(m*x-d*b-g*v)*L,t[15]=(u*b-h*x+f*v)*L,t):null}},26645:function(t,e,r){var n=r(87193);t.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,m=e[0],g=e[1],y=e[2],v=i[0],x=i[1],_=i[2],b=r[0],w=r[1],T=r[2];return Math.abs(m-b)<1e-6&&Math.abs(g-w)<1e-6&&Math.abs(y-T)<1e-6?n(t):(h=m-b,f=g-w,p=y-T,a=x*(p*=d=1/Math.sqrt(h*h+f*f+p*p))-_*(f*=d),o=_*(h*=d)-v*p,s=v*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0),l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0),t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*m+o*g+s*y),t[13]=-(l*m+c*g+u*y),t[14]=-(h*m+f*g+p*y),t[15]=1,t)}},14787:function(t){t.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],m=e[12],g=e[13],y=e[14],v=e[15],x=r[0],_=r[1],b=r[2],w=r[3];return t[0]=x*n+_*s+b*h+w*m,t[1]=x*i+_*l+b*f+w*g,t[2]=x*a+_*c+b*p+w*y,t[3]=x*o+_*u+b*d+w*v,x=r[4],_=r[5],b=r[6],w=r[7],t[4]=x*n+_*s+b*h+w*m,t[5]=x*i+_*l+b*f+w*g,t[6]=x*a+_*c+b*p+w*y,t[7]=x*o+_*u+b*d+w*v,x=r[8],_=r[9],b=r[10],w=r[11],t[8]=x*n+_*s+b*h+w*m,t[9]=x*i+_*l+b*f+w*g,t[10]=x*a+_*c+b*p+w*y,t[11]=x*o+_*u+b*d+w*v,x=r[12],_=r[13],b=r[14],w=r[15],t[12]=x*n+_*s+b*h+w*m,t[13]=x*i+_*l+b*f+w*g,t[14]=x*a+_*c+b*p+w*y,t[15]=x*o+_*u+b*d+w*v,t}},4633:function(t){t.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},5313:function(t){t.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},22253:function(t){t.exports=function(t,e,r,n){var i=Math.tan(e.upDegrees*Math.PI/180),a=Math.tan(e.downDegrees*Math.PI/180),o=Math.tan(e.leftDegrees*Math.PI/180),s=Math.tan(e.rightDegrees*Math.PI/180),l=2/(o+s),c=2/(i+a);return t[0]=l,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=c,t[6]=0,t[7]=0,t[8]=-(o-s)*l*.5,t[9]=(i-a)*c*.5,t[10]=n/(r-n),t[11]=-1,t[12]=0,t[13]=0,t[14]=n*r/(r-n),t[15]=0,t}},32416:function(t){t.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S,E=n[0],C=n[1],L=n[2],I=Math.sqrt(E*E+C*C+L*L);return Math.abs(I)<1e-6?null:(E*=I=1/I,C*=I,L*=I,i=Math.sin(r),o=1-(a=Math.cos(r)),s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],m=e[8],g=e[9],y=e[10],v=e[11],x=E*E*o+a,_=C*E*o+L*i,b=L*E*o-C*i,w=E*C*o-L*i,T=C*C*o+a,k=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*_+m*b,t[1]=l*x+f*_+g*b,t[2]=c*x+p*_+y*b,t[3]=u*x+d*_+v*b,t[4]=s*w+h*T+m*k,t[5]=l*w+f*T+g*k,t[6]=c*w+p*T+y*k,t[7]=u*w+d*T+v*k,t[8]=s*A+h*M+m*S,t[9]=l*A+f*M+g*S,t[10]=c*A+p*M+y*S,t[11]=u*A+d*M+v*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t)}},81066:function(t){t.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},54201:function(t){t.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},33920:function(t){t.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},8697:function(t){t.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},66992:function(t){t.exports=function(t){return\"mat4(\"+t[0]+\", \"+t[1]+\", \"+t[2]+\", \"+t[3]+\", \"+t[4]+\", \"+t[5]+\", \"+t[6]+\", \"+t[7]+\", \"+t[8]+\", \"+t[9]+\", \"+t[10]+\", \"+t[11]+\", \"+t[12]+\", \"+t[13]+\", \"+t[14]+\", \"+t[15]+\")\"}},4165:function(t){t.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,m=r[0],g=r[1],y=r[2];return e===t?(t[12]=e[0]*m+e[4]*g+e[8]*y+e[12],t[13]=e[1]*m+e[5]*g+e[9]*y+e[13],t[14]=e[2]*m+e[6]*g+e[10]*y+e[14],t[15]=e[3]*m+e[7]*g+e[11]*y+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*m+s*g+h*y+e[12],t[13]=i*m+l*g+f*y+e[13],t[14]=a*m+c*g+p*y+e[14],t[15]=o*m+u*g+d*y+e[15]),t}},10256:function(t){t.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},74024:function(t,e,r){\"use strict\";var n=r(59518),i=r(6807),a=r(81330),o=r(38862),s=r(93103),l=r(162),c=r(68950),u=r(66127),h=r(5137),f=r(29388),p=r(4957),d=r(44626),m=r(44431),g=r(27976),y=r(12673),v=r(83473),x=r(54689).nextPow2,_=new s,b=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(b=!0),document.body.removeChild(w)}var T=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=_.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),_.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};T.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ vec2(positionOffset.x, -positionOffset.y)))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},T.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map((function(t){return parseFloat(t)})):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=v(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=T.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach((function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(T.baseFontSize+\"px \"+t)}else{var i=t.style,s=t.weight,l=t.stretch,c=t.variant;t=n.parse(n.stringify(t)),i&&(t.style=i),s&&(t.weight=s),l&&(t.stretch=l),c&&(t.variant=c)}var u=n.stringify({size:T.baseFontSize,family:t.family,stretch:b?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),h=p(t.size),f=Math.round(h[0]*d(h[1]));if(f!==e.fontSize[r]&&(o=!0,e.fontSize[r]=f),!(e.font[r]&&u==e.font[r].baseString||(a=!0,e.font[r]=T.fonts[u],e.font[r]))){var m=t.family.join(\", \"),g=[t.style];t.style!=t.variant&&g.push(t.variant),t.variant!=t.weight&&g.push(t.weight),b&&t.weight!=t.stretch&&g.push(t.stretch),e.font[r]={baseString:u,family:m,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:y(m,{origin:\"top\",fontSize:T.baseFontSize,fontStyle:g.join(\" \")})},T.fonts[u]=e.font[r]}})),(a||o)&&this.font.forEach((function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:b?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)})),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var _=1;_<t.text.length;_++)this.textOffsets[_]=this.textOffsets[_-1]+t.text[_-1].length,this.count+=t.text[_].length,this.counts.push(t.text[_].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach((function(t,n){T.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=T.atlasContext.measureText(o).width/T.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);g(t.kerning,m(t.family,{pairs:s}))}}}))}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,k=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)k[M++]=t.position[2*A],k[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)k[M++]=t.position[A][0],k[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:k}):this.position=this.regl.buffer({type:\"float\",data:k}),u.freeFloat(k)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),I=u.mallocFloat(2*this.count);this.textWidth=[];for(var P=0,z=0;P<this.counts.length;P++){for(var O=this.counts[P],D=this.font[P]||this.font[0],R=this.fontAtlas[P]||this.fontAtlas[0],F=0;F<O;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],I[2*z]=D.width[B],F){var j=I[2*z-2],U=I[2*z],V=I[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}I[2*z+1]=V}else I[2*z+1]=.5*I[2*z];z++}this.textWidth.push(I.length?.5*I[2*z-2]+I[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:I,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(I),r.length&&this.font.forEach((function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(T.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:T.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})}))}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map((function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0}))),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map((function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,-1*(i+=\"number\"==typeof t?t-n.baseline:-n[t])}))),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Z=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Z(W,W+4),\"uint8\"),W)}else{var Y=t.color.length;H=u.mallocUint8(4*Y);for(var X=0;X<Y;X++)H.set(l(t.color[X]||0,\"uint8\"),4*X)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var $=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array($);for(var J=0;J<this.batch.length;J++)this.batch[J]={count:this.counts.length>1?this.counts[J]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[J]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*J,4*J+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[J]:this.opacity,baseline:null!=this.baselineOffset[J]?this.baselineOffset[J]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[J]?this.alignOffset[J]:this.alignOffset[0]:0,atlas:this.fontAtlas[J]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*J,2*J+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},T.prototype.destroy=function(){},T.prototype.kerning=!0,T.prototype.position={constant:new Float32Array(2)},T.prototype.translate=null,T.prototype.scale=null,T.prototype.font=null,T.prototype.text=\"\",T.prototype.positionOffset=[0,0],T.prototype.opacity=1,T.prototype.color=new Uint8Array([0,0,0,255]),T.prototype.alignOffset=[0,0],T.maxAtlasSize=1024,T.atlasCanvas=document.createElement(\"canvas\"),T.atlasContext=T.atlasCanvas.getContext(\"2d\",{alpha:!1}),T.baseFontSize=64,T.fonts={},t.exports=T},38862:function(t,e,r){\"use strict\";var n=r(6807);function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.g.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.g.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}t.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},(t=a(t)||\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0)).pixelRatio||(t.pixelRatio=r.g.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}return t.gl||[\"webgl\",\"experimental-webgl\",\"webgl-experimental\"].some((function(e){try{t.gl=t.canvas.getContext(e,t.attrs)}catch(t){}return t.gl})),t.gl}},76765:function(t){t.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},52991:function(t,e,r){\"use strict\";var n=r(71129)(\"%Object.getOwnPropertyDescriptor%\",!0);if(n)try{n([],\"length\")}catch(t){n=null}t.exports=n},39784:function(t,e,r){\"use strict\";var n,i=r(78253);n=\"function\"==typeof r.g.matchMedia?!r.g.matchMedia(\"(hover: none)\").matches:i,t.exports=n},74043:function(t,e,r){\"use strict\";var n=r(78253);t.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},74268:function(t,e,r){\"use strict\";var n=r(40891),i=function(){return!!n};i.hasArrayLengthDefineBug=function(){if(!n)return null;try{return 1!==n([],\"length\",{value:1}).length}catch(t){return!0}},t.exports=i},58436:function(t){\"use strict\";var e={foo:{}},r=Object;t.exports=function(){return{__proto__:e}.foo===e.foo&&!({__proto__:null}instanceof r)}},8771:function(t,e,r){\"use strict\";var n=\"undefined\"!=typeof Symbol&&Symbol,i=r(59457);t.exports=function(){return\"function\"==typeof n&&\"function\"==typeof Symbol&&\"symbol\"==typeof n(\"foo\")&&\"symbol\"==typeof Symbol(\"bar\")&&i()}},59457:function(t){\"use strict\";t.exports=function(){if(\"function\"!=typeof Symbol||\"function\"!=typeof Object.getOwnPropertySymbols)return!1;if(\"symbol\"==typeof Symbol.iterator)return!0;var t={},e=Symbol(\"test\"),r=Object(e);if(\"string\"==typeof e)return!1;if(\"[object Symbol]\"!==Object.prototype.toString.call(e))return!1;if(\"[object Symbol]\"!==Object.prototype.toString.call(r))return!1;for(e in t[e]=42,t)return!1;if(\"function\"==typeof Object.keys&&0!==Object.keys(t).length)return!1;if(\"function\"==typeof Object.getOwnPropertyNames&&0!==Object.getOwnPropertyNames(t).length)return!1;var n=Object.getOwnPropertySymbols(t);if(1!==n.length||n[0]!==e)return!1;if(!Object.prototype.propertyIsEnumerable.call(t,e))return!1;if(\"function\"==typeof Object.getOwnPropertyDescriptor){var i=Object.getOwnPropertyDescriptor(t,e);if(42!==i.value||!0!==i.enumerable)return!1}return!0}},36912:function(t,e,r){\"use strict\";var n=r(59457);t.exports=function(){return n()&&!!Symbol.toStringTag}},80753:function(t,e,r){\"use strict\";var n=Function.prototype.call,i=Object.prototype.hasOwnProperty,a=r(87547);t.exports=a.call(n,i)},27415:function(t,e){e.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},e.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,m=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*m}},28062:function(t){\"function\"==typeof Object.create?t.exports=function(t,e){e&&(t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}))}:t.exports=function(t,e){if(e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}}},40280:function(t,e,r){\"use strict\";var n=r(36912)(),i=r(63063)(\"Object.prototype.toString\"),a=function(t){return!(n&&t&&\"object\"==typeof t&&Symbol.toStringTag in t)&&\"[object Arguments]\"===i(t)},o=function(t){return!!a(t)||null!==t&&\"object\"==typeof t&&\"number\"==typeof t.length&&t.length>=0&&\"[object Array]\"!==i(t)&&\"[object Function]\"===i(t.callee)},s=function(){return a(arguments)}();a.isLegacyArguments=o,t.exports=s?a:o},78253:function(t){t.exports=!0},82756:function(t){\"use strict\";var e,r,n=Function.prototype.toString,i=\"object\"==typeof Reflect&&null!==Reflect&&Reflect.apply;if(\"function\"==typeof i&&\"function\"==typeof Object.defineProperty)try{e=Object.defineProperty({},\"length\",{get:function(){throw r}}),r={},i((function(){throw 42}),null,e)}catch(t){t!==r&&(i=null)}else i=null;var a=/^\\s*class\\b/,o=function(t){try{var e=n.call(t);return a.test(e)}catch(t){return!1}},s=function(t){try{return!o(t)&&(n.call(t),!0)}catch(t){return!1}},l=Object.prototype.toString,c=\"function\"==typeof Symbol&&!!Symbol.toStringTag,u=!(0 in[,]),h=function(){return!1};if(\"object\"==typeof document){var f=document.all;l.call(f)===l.call(document.all)&&(h=function(t){if((u||!t)&&(void 0===t||\"object\"==typeof t))try{var e=l.call(t);return(\"[object HTMLAllCollection]\"===e||\"[object HTML document.all class]\"===e||\"[object HTMLCollection]\"===e||\"[object Object]\"===e)&&null==t(\"\")}catch(t){}return!1})}t.exports=i?function(t){if(h(t))return!0;if(!t)return!1;if(\"function\"!=typeof t&&\"object\"!=typeof t)return!1;try{i(t,null,e)}catch(t){if(t!==r)return!1}return!o(t)&&s(t)}:function(t){if(h(t))return!0;if(!t)return!1;if(\"function\"!=typeof t&&\"object\"!=typeof t)return!1;if(c)return s(t);if(o(t))return!1;var e=l.call(t);return!(\"[object Function]\"!==e&&\"[object GeneratorFunction]\"!==e&&!/^\\[object HTML/.test(e))&&s(t)}},80340:function(t,e,r){\"use strict\";var n,i=Object.prototype.toString,a=Function.prototype.toString,o=/^\\s*(?:function)?\\*/,s=r(36912)(),l=Object.getPrototypeOf;t.exports=function(t){if(\"function\"!=typeof t)return!1;if(o.test(a.call(t)))return!0;if(!s)return\"[object GeneratorFunction]\"===i.call(t);if(!l)return!1;if(void 0===n){var e=function(){if(!s)return!1;try{return Function(\"return function*() {}\")()}catch(t){}}();n=!!e&&l(e)}return l(t)===n}},39488:function(t){\"use strict\";t.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},73287:function(t){\"use strict\";t.exports=function(t){return t!=t}},63057:function(t,e,r){\"use strict\";var n=r(87227),i=r(97936),a=r(73287),o=r(60758),s=r(85684),l=n(o(),Number);i(l,{getPolyfill:o,implementation:a,shim:s}),t.exports=l},60758:function(t,e,r){\"use strict\";var n=r(73287);t.exports=function(){return Number.isNaN&&Number.isNaN(NaN)&&!Number.isNaN(\"a\")?Number.isNaN:n}},85684:function(t,e,r){\"use strict\";var n=r(97936),i=r(60758);t.exports=function(){var t=i();return n(Number,{isNaN:t},{isNaN:function(){return Number.isNaN!==t}}),t}},60201:function(t){\"use strict\";t.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},29388:function(t){\"use strict\";var e=Object.prototype.toString;t.exports=function(t){var r;return\"[object Object]\"===e.call(t)&&(null===(r=Object.getPrototypeOf(t))||r===Object.getPrototypeOf({}))}},9914:function(t){\"use strict\";t.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},13986:function(t){\"use strict\";t.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},15628:function(t,e,r){\"use strict\";var n=r(61262),i=r(70085),a=r(63063),o=a(\"Object.prototype.toString\"),s=r(36912)(),l=r(52991),c=\"undefined\"==typeof globalThis?r.g:globalThis,u=i(),h=a(\"Array.prototype.indexOf\",!0)||function(t,e){for(var r=0;r<t.length;r+=1)if(t[r]===e)return r;return-1},f=a(\"String.prototype.slice\"),p={},d=Object.getPrototypeOf;s&&l&&d&&n(u,(function(t){var e=new c[t];if(Symbol.toStringTag in e){var r=d(e),n=l(r,Symbol.toStringTag);if(!n){var i=d(r);n=l(i,Symbol.toStringTag)}p[t]=n.get}})),t.exports=function(t){if(!t||\"object\"!=typeof t)return!1;if(!s||!(Symbol.toStringTag in t)){var e=f(o(t),8,-1);return h(u,e)>-1}return!!l&&function(t){var e=!1;return n(p,(function(r,n){if(!e)try{e=r.call(t)===n}catch(t){}})),e}(t)}},62914:function(t){\"use strict\";t.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},99978:function(t,e,r){\"use strict\";t.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function m(t){c(r&~n.buttons(t),t)}function g(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",m),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}g();var y={element:t};return Object.defineProperties(y,{enabled:{get:function(){return s},set:function(e){e?g():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",m),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),y};var n=r(41926)},44039:function(t){var e={left:0,top:0};t.exports=function(t,r,n){r=r||t.currentTarget||t.srcElement,Array.isArray(n)||(n=[0,0]);var i,a=t.clientX||0,o=t.clientY||0,s=(i=r)===window||i===document||i===document.body?e:i.getBoundingClientRect();return n[0]=a-s.left,n[1]=o-s.top,n}},41926:function(t,e){\"use strict\";function r(t){return t.target||t.srcElement||window}e.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},e.element=r,e.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=r(t).getBoundingClientRect();return t.clientX-e.left}return 0},e.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=r(t).getBoundingClientRect();return t.clientY-e.top}return 0}},20573:function(t,e,r){\"use strict\";var n=r(44626);t.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=i;break;case 2:s=window.innerHeight}if(a*=s,o*=s,(n*=s)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},71116:function(t,e,r){var n;!function(i,a,o){a[i]=a[i]||function(){\"use strict\";var t,e,r,n=Object.prototype.toString,i=\"undefined\"!=typeof setImmediate?function(t){return setImmediate(t)}:setTimeout;try{Object.defineProperty({},\"x\",{}),t=function(t,e,r,n){return Object.defineProperty(t,e,{value:r,writable:!0,configurable:!1!==n})}}catch(e){t=function(t,e,r){return t[e]=r,t}}function a(t,n){r.add(t,n),e||(e=i(r.drain))}function o(t){var e,r=typeof t;return null==t||\"object\"!=r&&\"function\"!=r||(e=t.then),\"function\"==typeof e&&e}function s(){for(var t=0;t<this.chain.length;t++)l(this,1===this.state?this.chain[t].success:this.chain[t].failure,this.chain[t]);this.chain.length=0}function l(t,e,r){var n,i;try{!1===e?r.reject(t.msg):(n=!0===e?t.msg:e.call(void 0,t.msg))===r.promise?r.reject(TypeError(\"Promise-chain cycle\")):(i=o(n))?i.call(n,r.resolve,r.reject):r.resolve(n)}catch(t){r.reject(t)}}function c(t){var e,r=this;if(!r.triggered){r.triggered=!0,r.def&&(r=r.def);try{(e=o(t))?a((function(){var n=new f(r);try{e.call(t,(function(){c.apply(n,arguments)}),(function(){u.apply(n,arguments)}))}catch(t){u.call(n,t)}})):(r.msg=t,r.state=1,r.chain.length>0&&a(s,r))}catch(t){u.call(new f(r),t)}}}function u(t){var e=this;e.triggered||(e.triggered=!0,e.def&&(e=e.def),e.msg=t,e.state=2,e.chain.length>0&&a(s,e))}function h(t,e,r,n){for(var i=0;i<e.length;i++)!function(i){t.resolve(e[i]).then((function(t){r(i,t)}),n)}(i)}function f(t){this.def=t,this.triggered=!1}function p(t){this.promise=t,this.state=0,this.triggered=!1,this.chain=[],this.msg=void 0}function d(t){if(\"function\"!=typeof t)throw TypeError(\"Not a function\");if(0!==this.__NPO__)throw TypeError(\"Not a promise\");this.__NPO__=1;var e=new p(this);this.then=function(t,r){var n={success:\"function\"!=typeof t||t,failure:\"function\"==typeof r&&r};return n.promise=new this.constructor((function(t,e){if(\"function\"!=typeof t||\"function\"!=typeof e)throw TypeError(\"Not a function\");n.resolve=t,n.reject=e})),e.chain.push(n),0!==e.state&&a(s,e),n.promise},this.catch=function(t){return this.then(void 0,t)};try{t.call(void 0,(function(t){c.call(e,t)}),(function(t){u.call(e,t)}))}catch(t){u.call(e,t)}}r=function(){var t,r,n;function i(t,e){this.fn=t,this.self=e,this.next=void 0}return{add:function(e,a){n=new i(e,a),r?r.next=n:t=n,r=n,n=void 0},drain:function(){var n=t;for(t=r=e=void 0;n;)n.fn.call(n.self),n=n.next}}}();var m=t({},\"constructor\",d,!1);return d.prototype=m,t(m,\"__NPO__\",0,!1),t(d,\"resolve\",(function(t){return t&&\"object\"==typeof t&&1===t.__NPO__?t:new this((function(e,r){if(\"function\"!=typeof e||\"function\"!=typeof r)throw TypeError(\"Not a function\");e(t)}))})),t(d,\"reject\",(function(t){return new this((function(e,r){if(\"function\"!=typeof e||\"function\"!=typeof r)throw TypeError(\"Not a function\");r(t)}))})),t(d,\"all\",(function(t){var e=this;return\"[object Array]\"!=n.call(t)?e.reject(TypeError(\"Not an array\")):0===t.length?e.resolve([]):new e((function(r,n){if(\"function\"!=typeof r||\"function\"!=typeof n)throw TypeError(\"Not a function\");var i=t.length,a=Array(i),o=0;h(e,t,(function(t,e){a[t]=e,++o===i&&r(a)}),n)}))})),t(d,\"race\",(function(t){var e=this;return\"[object Array]\"!=n.call(t)?e.reject(TypeError(\"Not an array\")):new e((function(r,n){if(\"function\"!=typeof r||\"function\"!=typeof n)throw TypeError(\"Not a function\");h(e,t,(function(t,e){r(e)}),n)}))})),d}(),t.exports?t.exports=a[i]:void 0===(n=function(){return a[i]}.call(e,r,e,t))||(t.exports=n)}(\"Promise\",void 0!==r.g?r.g:this)},60265:function(t){var e=Math.PI,r=s(120);function n(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function i(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function a(t,n,i,s,l,c,u,h,f,p){if(p)T=p[0],k=p[1],b=p[2],w=p[3];else{var d=o(t,n,-l);t=d.x,n=d.y;var m=(t-(h=(d=o(h,f,-l)).x))/2,g=(n-(f=d.y))/2,y=m*m/(i*i)+g*g/(s*s);y>1&&(i*=y=Math.sqrt(y),s*=y);var v=i*i,x=s*s,_=(c==u?-1:1)*Math.sqrt(Math.abs((v*x-v*g*g-x*m*m)/(v*g*g+x*m*m)));_==1/0&&(_=1);var b=_*i*g/s+(t+h)/2,w=_*-s*m/i+(n+f)/2,T=Math.asin(((n-w)/s).toFixed(9)),k=Math.asin(((f-w)/s).toFixed(9));(T=t<b?e-T:T)<0&&(T=2*e+T),(k=h<b?e-k:k)<0&&(k=2*e+k),u&&T>k&&(T-=2*e),!u&&k>T&&(k-=2*e)}if(Math.abs(k-T)>r){var A=k,M=h,S=f;k=T+r*(u&&k>T?1:-1);var E=a(h=b+i*Math.cos(k),f=w+s*Math.sin(k),i,s,l,0,u,M,S,[k,A,b,w])}var C=Math.tan((k-T)/4),L=4/3*i*C,I=4/3*s*C,P=[2*t-(t+L*Math.sin(T)),2*n-(n-I*Math.cos(T)),h+L*Math.sin(k),f-I*Math.cos(k),h,f];if(p)return P;E&&(P=P.concat(E));for(var z=0;z<P.length;){var O=o(P[z],P[z+1],l);P[z++]=O.x,P[z++]=O.y}return P}function o(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function s(t){return t*(e/180)}t.exports=function(t){for(var e,r=[],o=0,l=0,c=0,u=0,h=null,f=null,p=0,d=0,m=0,g=t.length;m<g;m++){var y=t[m],v=y[0];switch(v){case\"M\":c=y[1],u=y[2];break;case\"A\":(y=a(p,d,y[1],y[2],s(y[3]),y[4],y[5],y[6],y[7])).unshift(\"C\"),y.length>7&&(r.push(y.splice(0,7)),y.unshift(\"C\"));break;case\"S\":var x=p,_=d;\"C\"!=e&&\"S\"!=e||(x+=x-o,_+=_-l),y=[\"C\",x,_,y[1],y[2],y[3],y[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),y=i(p,d,h,f,y[1],y[2]);break;case\"Q\":h=y[1],f=y[2],y=i(p,d,y[1],y[2],y[3],y[4]);break;case\"L\":y=n(p,d,y[1],y[2]);break;case\"H\":y=n(p,d,y[1],d);break;case\"V\":y=n(p,d,p,y[1]);break;case\"Z\":y=n(p,d,c,u)}e=v,p=y[y.length-2],d=y[y.length-1],y.length>4?(o=y[y.length-4],l=y[y.length-3]):(o=p,l=d),r.push(y)}return r}},27976:function(t){\"use strict\";var e=Object.getOwnPropertySymbols,r=Object.prototype.hasOwnProperty,n=Object.prototype.propertyIsEnumerable;t.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map((function(t){return e[t]})).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach((function(t){n[t]=t})),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,i){for(var a,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in a=Object(arguments[l]))r.call(a,c)&&(s[c]=a[c]);if(e){o=e(a);for(var u=0;u<o.length;u++)n.call(a,o[u])&&(s[o[u]]=a[o[u]])}}return s}},93063:function(t){\"use strict\";var e=function(t){return t!=t};t.exports=function(t,r){return 0===t&&0===r?1/t==1/r:t===r||!(!e(t)||!e(r))}},13969:function(t,e,r){\"use strict\";var n=r(97936),i=r(87227),a=r(93063),o=r(9622),s=r(79796),l=i(o(),Object);n(l,{getPolyfill:o,implementation:a,shim:s}),t.exports=l},9622:function(t,e,r){\"use strict\";var n=r(93063);t.exports=function(){return\"function\"==typeof Object.is?Object.is:n}},79796:function(t,e,r){\"use strict\";var n=r(9622),i=r(97936);t.exports=function(){var t=n();return i(Object,{is:t},{is:function(){return Object.is!==t}}),t}},61663:function(t,e,r){\"use strict\";var n;if(!Object.keys){var i=Object.prototype.hasOwnProperty,a=Object.prototype.toString,o=r(52385),s=Object.prototype.propertyIsEnumerable,l=!s.call({toString:null},\"toString\"),c=s.call((function(){}),\"prototype\"),u=[\"toString\",\"toLocaleString\",\"valueOf\",\"hasOwnProperty\",\"isPrototypeOf\",\"propertyIsEnumerable\",\"constructor\"],h=function(t){var e=t.constructor;return e&&e.prototype===t},f={$applicationCache:!0,$console:!0,$external:!0,$frame:!0,$frameElement:!0,$frames:!0,$innerHeight:!0,$innerWidth:!0,$onmozfullscreenchange:!0,$onmozfullscreenerror:!0,$outerHeight:!0,$outerWidth:!0,$pageXOffset:!0,$pageYOffset:!0,$parent:!0,$scrollLeft:!0,$scrollTop:!0,$scrollX:!0,$scrollY:!0,$self:!0,$webkitIndexedDB:!0,$webkitStorageInfo:!0,$window:!0},p=function(){if(\"undefined\"==typeof window)return!1;for(var t in window)try{if(!f[\"$\"+t]&&i.call(window,t)&&null!==window[t]&&\"object\"==typeof window[t])try{h(window[t])}catch(t){return!0}}catch(t){return!0}return!1}();n=function(t){var e=null!==t&&\"object\"==typeof t,r=\"[object Function]\"===a.call(t),n=o(t),s=e&&\"[object String]\"===a.call(t),f=[];if(!e&&!r&&!n)throw new TypeError(\"Object.keys called on a non-object\");var d=c&&r;if(s&&t.length>0&&!i.call(t,0))for(var m=0;m<t.length;++m)f.push(String(m));if(n&&t.length>0)for(var g=0;g<t.length;++g)f.push(String(g));else for(var y in t)d&&\"prototype\"===y||!i.call(t,y)||f.push(String(y));if(l)for(var v=function(t){if(\"undefined\"==typeof window||!p)return h(t);try{return h(t)}catch(t){return!1}}(t),x=0;x<u.length;++x)v&&\"constructor\"===u[x]||!i.call(t,u[x])||f.push(u[x]);return f}}t.exports=n},99433:function(t,e,r){\"use strict\";var n=Array.prototype.slice,i=r(52385),a=Object.keys,o=a?function(t){return a(t)}:r(61663),s=Object.keys;o.shim=function(){if(Object.keys){var t=function(){var t=Object.keys(arguments);return t&&t.length===arguments.length}(1,2);t||(Object.keys=function(t){return i(t)?s(n.call(t)):s(t)})}else Object.keys=o;return Object.keys||o},t.exports=o},52385:function(t){\"use strict\";var e=Object.prototype.toString;t.exports=function(t){var r=e.call(t),n=\"[object Arguments]\"===r;return n||(n=\"[object Array]\"!==r&&null!==t&&\"object\"==typeof t&&\"number\"==typeof t.length&&t.length>=0&&\"[object Function]\"===e.call(t.callee)),n}},96927:function(t,e,r){\"use strict\";var n=r(99433),i=r(59457)(),a=r(63063),o=Object,s=a(\"Array.prototype.push\"),l=a(\"Object.prototype.propertyIsEnumerable\"),c=i?Object.getOwnPropertySymbols:null;t.exports=function(t,e){if(null==t)throw new TypeError(\"target must be an object\");var r=o(t);if(1===arguments.length)return r;for(var a=1;a<arguments.length;++a){var u=o(arguments[a]),h=n(u),f=i&&(Object.getOwnPropertySymbols||c);if(f)for(var p=f(u),d=0;d<p.length;++d){var m=p[d];l(u,m)&&s(h,m)}for(var g=0;g<h.length;++g){var y=h[g];if(l(u,y)){var v=u[y];r[y]=v}}}return r}},68686:function(t,e,r){\"use strict\";var n=r(96927);t.exports=function(){return Object.assign?function(){if(!Object.assign)return!1;for(var t=\"abcdefghijklmnopqrst\",e=t.split(\"\"),r={},n=0;n<e.length;++n)r[e[n]]=e[n];var i=Object.assign({},r),a=\"\";for(var o in i)a+=o;return t!==a}()||function(){if(!Object.assign||!Object.preventExtensions)return!1;var t=Object.preventExtensions({1:2});try{Object.assign(t,\"xy\")}catch(e){return\"y\"===t[1]}return!1}()?n:Object.assign:n}},59811:function(t){\"use strict\";function e(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach((function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach((function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t})),n=n.reverse(),r=r.map((function(e){return n.forEach((function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])})),e}))}));var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function r(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce((function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r}),\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function n(t,n){return Array.isArray(t)?r(t,n):e(t,n)}n.parse=e,n.stringify=r,t.exports=n},5137:function(t,e,r){\"use strict\";var n=r(6807);t.exports=function(t){var e;return arguments.length>1&&(t=arguments),\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]),t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(e={x:(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"})).left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height),e}},26953:function(t){t.exports=function(t){var i=[];return t.replace(r,(function(t,r,a){var o=r.toLowerCase();for(a=function(t){var e=t.match(n);return e?e.map(Number):[]}(a),\"m\"==o&&a.length>2&&(i.push([r].concat(a.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(a.length==e[o])return a.unshift(r),i.push(a);if(a.length<e[o])throw new Error(\"malformed path data\");i.push([r].concat(a.splice(0,e[o])))}})),i};var e={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},r=/([astvzqmhlc])([^astvzqmhlc]*)/gi,n=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},4957:function(t){t.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},71879:function(t,e,r){var n=r(33282);(function(){var e,r,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?t.exports=function(){return performance.now()}:null!=n&&n.hrtime?(t.exports=function(){return(e()-o)/1e6},r=n.hrtime,a=(e=function(){var t;return 1e9*(t=r())[0]+t[1]})(),s=1e9*n.uptime(),o=a-s):Date.now?(t.exports=function(){return Date.now()-i},i=Date.now()):(t.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)},6807:function(t){\"use strict\";t.exports=function(t,e,n){var i,a,o={};if(\"string\"==typeof e&&(e=r(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(i in e)e[i]=r(e[i]);var l={};for(i in e){var c=e[i];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(n&&(l[u]=!0),u in t){if(o[i]=t[u],n)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else i in t&&(e[i]&&(o[i]=t[i]),n&&(l[i]=!0))}if(n)for(i in t)l[i]||(o[i]=t[i]);return o};var e={};function r(t){return e[t]?e[t]:(\"string\"==typeof t&&(t=e[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},52773:function(t){t.exports=function(t,e,r,n){var i=t[0],a=t[1],o=!1;void 0===r&&(r=0),void 0===n&&(n=e.length);for(var s=n-r,l=0,c=s-1;l<s;c=l++){var u=e[l+r][0],h=e[l+r][1],f=e[c+r][0],p=e[c+r][1];h>a!=p>a&&i<(f-u)*(a-h)/(p-h)+u&&(o=!o)}return o}},11516:function(t,e,r){var n,i=r(42391),a=r(92990),o=r(26202),s=r(22222),l=r(17527),c=r(24491),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),t.exports=n},42391:function(t){t.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},92990:function(t){t.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},24491:function(t){var e={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++)if(n(e,(s=t.children[r]).region))return void o(s,e);var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};t.exports=e},26202:function(t,e,r){var n=r(48916);t.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,(function(n){return i=t.isStart,a=t.pt,o=r,s=n.isStart,l=n.pt,c=n.other.pt,(0!==(u=e.pointsCompare(a,l))?u:e.pointsSame(o,c)?0:i!==s?i?1:-1:e.pointAboveOrOnLine(o,s?l:c,s?c:l)?1:-1)<0;var i,a,o,s,l,c,u}))}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition((function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)||e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0}))}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),m=!p&&e.pointBetween(s,c,u);if(f)return m?l(n,s):l(t,u),n;d&&(p||(m?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,m=p.after?p.after.ev:null;function g(){if(d){var t=u(f,d);if(t)return t}return!!m&&u(f,m)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!m&&m.seg);var y,v,x=g();if(x)t?(v=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(v=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=m?m.seg.myFill.above:i,f.seg.myFill.above=v?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(y=m?f.primary===m.primary?m.seg.otherFill.above:m.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:y,below:y}),r&&r.status(f.seg,!!d&&d.seg,!!m&&m.seg),f.other.status=p.insert(n.node({ev:f}))}else{var _=f.status;if(null===_)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(_.prev)&&s.exists(_.next)&&u(_.prev.ev,_.next.ev),r&&r.statusRemove(_.ev.seg),_.remove(),!f.primary){var b=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=b}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach((function(t){s(i(t.start,t.end,t),!0)})),r.forEach((function(t){s(i(t.start,t.end,t),!1)})),c(e,n)}}}},48916:function(t){t.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},22222:function(t){t.exports=function(t,e,r){var n=[],i=[];return t.forEach((function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(g=n[u])[0],f=(g[1],g[g.length-1]);if(g[g.length-2],e.pointsSame(h,a)){if(k(u,!0,!0))break}else if(e.pointsSame(h,o)){if(k(u,!0,!1))break}else if(e.pointsSame(f,a)){if(k(u,!1,!0))break}else if(e.pointsSame(f,o)&&k(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,m=s.matches_head,g=n[p],y=m?g[0]:g[g.length-1],v=m?g[1]:g[g.length-2],x=m?g[g.length-1]:g[0],_=m?g[g.length-2]:g[1];return e.pointsCollinear(v,y,d)&&(m?(r&&r.chainRemoveHead(s.index,d),g.shift()):(r&&r.chainRemoveTail(s.index,d),g.pop()),y=v),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(_,x,y)&&(m?(r&&r.chainRemoveTail(s.index,y),g.pop()):(r&&r.chainRemoveHead(s.index,y),g.shift())),r&&r.chainClose(s.index),void i.push(g)):void(m?(r&&r.chainAddHead(s.index,d),g.unshift(d)):(r&&r.chainAddTail(s.index,d),g.push(d)))}var b=s.index,w=l.index;r&&r.chainConnect(b,w);var T=n[b].length<n[w].length;s.matches_head?l.matches_head?T?(A(b),M(b,w)):(A(w),M(w,b)):M(w,b):l.matches_head?M(b,w):T?(A(b),M(w,b)):(A(w),M(b,w))}function k(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}})),i}},17527:function(t){function e(t,e,r){var n=[];return t.forEach((function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})})),r&&r.selected(n),n}var r={union:function(t,r){return e(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],r)},intersect:function(t,r){return e(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],r)},difference:function(t,r){return e(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],r)},differenceRev:function(t,r){return e(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],r)},xor:function(t,r){return e(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],r)}};t.exports=r},3944:function(t,e,r){\"use strict\";var n=r(90386).Transform,i=r(79743);function a(){n.call(this,{readableObjectMode:!0})}function o(t,e,r){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=(new Error).stack||\"\",this.name=this.constructor.name,this.message=t,e&&(this.code=e),r&&(this.statusCode=r)}a.prototype=Object.create(n.prototype),a.prototype.constructor=a,i(a.prototype),e.rU=function(t,e,r){for(var n=e,i=0;i<r.length;)if(t[n++]!==r[i++])return!1;return!0},e.VG=function(t,e){var r=[],n=0;if(e&&\"hex\"===e)for(;n<t.length;)r.push(parseInt(t.slice(n,n+2),16)),n+=2;else for(;n<t.length;n++)r.push(255&t.charCodeAt(n));return r},e.$l=function(t,e){return t[e]|t[e+1]<<8},e.bc=function(t,e){return t[e+1]|t[e]<<8},e.tF=function(t,e){return t[e]|t[e+1]<<8|t[e+2]<<16|16777216*t[e+3]},e.bb=function(t,e){return t[e+3]|t[e+2]<<8|t[e+1]<<16|16777216*t[e]},o.prototype=Object.create(Error.prototype),o.prototype.constructor=o},19789:function(t){\"use strict\";function e(t,e){var r=new Error(t);return r.code=e,r}function r(t){try{return decodeURIComponent(escape(t))}catch(e){return t}}function n(t,r,n){this.input=t.subarray(r,n),this.start=r;var i=String.fromCharCode.apply(null,this.input.subarray(0,4));if(\"II*\\0\"!==i&&\"MM\\0*\"!==i)throw e(\"invalid TIFF signature\",\"EBADDATA\");this.big_endian=\"M\"===i[0]}n.prototype.each=function(t){this.aborted=!1;var e=this.read_uint32(4);for(this.ifds_to_read=[{id:0,offset:e}];this.ifds_to_read.length>0&&!this.aborted;){var r=this.ifds_to_read.shift();r.offset&&this.scan_ifd(r.id,r.offset,t)}},n.prototype.read_uint16=function(t){var r=this.input;if(t+2>r.length)throw e(\"unexpected EOF\",\"EBADDATA\");return this.big_endian?256*r[t]+r[t+1]:r[t]+256*r[t+1]},n.prototype.read_uint32=function(t){var r=this.input;if(t+4>r.length)throw e(\"unexpected EOF\",\"EBADDATA\");return this.big_endian?16777216*r[t]+65536*r[t+1]+256*r[t+2]+r[t+3]:r[t]+256*r[t+1]+65536*r[t+2]+16777216*r[t+3]},n.prototype.is_subifd_link=function(t,e){return 0===t&&34665===e||0===t&&34853===e||34665===t&&40965===e},n.prototype.exif_format_length=function(t){switch(t){case 1:case 2:case 6:case 7:return 1;case 3:case 8:return 2;case 4:case 9:case 11:return 4;case 5:case 10:case 12:return 8;default:return 0}},n.prototype.exif_format_read=function(t,e){var r;switch(t){case 1:case 2:return this.input[e];case 6:return(r=this.input[e])|33554430*(128&r);case 3:return this.read_uint16(e);case 8:return(r=this.read_uint16(e))|131070*(32768&r);case 4:return this.read_uint32(e);case 9:return 0|this.read_uint32(e);default:return null}},n.prototype.scan_ifd=function(t,n,i){var a=this.read_uint16(n);n+=2;for(var o=0;o<a;o++){var s=this.read_uint16(n),l=this.read_uint16(n+2),c=this.read_uint32(n+4),u=this.exif_format_length(l),h=c*u,f=h<=4?n+8:this.read_uint32(n+8),p=!1;if(f+h>this.input.length)throw e(\"unexpected EOF\",\"EBADDATA\");for(var d=[],m=f,g=0;g<c;g++,m+=u){var y=this.exif_format_read(l,m);if(null===y){d=null;break}d.push(y)}if(Array.isArray(d)&&2===l&&(d=r(String.fromCharCode.apply(null,d)))&&\"\\0\"===d[d.length-1]&&(d=d.slice(0,-1)),this.is_subifd_link(t,s)&&Array.isArray(d)&&Number.isInteger(d[0])&&d[0]>0&&(this.ifds_to_read.push({id:s,offset:d[0]}),p=!0),!1===i({is_big_endian:this.big_endian,ifd:t,tag:s,format:l,count:c,entry_offset:n+this.start,data_length:h,data_offset:f+this.start,value:d,is_subifd_link:p}))return void(this.aborted=!0);n+=12}0===t&&this.ifds_to_read.push({id:1,offset:this.read_uint32(n)})},t.exports.ExifParser=n,t.exports.get_orientation=function(t){var e=0;try{return new n(t,0,t.length).each((function(t){if(0===t.ifd&&274===t.tag&&Array.isArray(t.value))return e=t.value[0],!1})),e}catch(t){return-1}}},20186:function(t,e,r){\"use strict\";var n=r(3944).bc,i=r(3944).bb;function a(t,e){if(t.length<4+e)return null;var r=i(t,e);return t.length<r+e||r<8?null:{boxtype:String.fromCharCode.apply(null,t.slice(e+4,e+8)),data:t.slice(e+8,e+r),end:e+r}}function o(t,e){for(var r=0;;){var n=a(t,r);if(!n)break;switch(n.boxtype){case\"ispe\":e.sizes.push({width:i(n.data,4),height:i(n.data,8)});break;case\"irot\":e.transforms.push({type:\"irot\",value:3&n.data[0]});break;case\"imir\":e.transforms.push({type:\"imir\",value:1&n.data[0]})}r=n.end}}function s(t,e,r){for(var n=0,i=0;i<r;i++)n=256*n+(t[e+i]||0);return n}function l(t,e){for(var r=t[4]>>4&15,i=15&t[4],a=t[5]>>4&15,o=n(t,6),l=8,c=0;c<o;c++){var u=n(t,l),h=n(t,l+=2),f=s(t,l+=2,a),p=n(t,l+=a);if(l+=2,0===h&&1===p){var d=s(t,l,r),m=s(t,l+r,i);e.item_loc[u]={length:m,offset:d+f}}l+=p*(r+i)}}function c(t,e){for(var r=n(t,4),i=6,o=0;o<r;o++){var s=a(t,i);if(!s)break;if(\"infe\"===s.boxtype){for(var l=n(s.data,4),c=\"\",u=8;u<s.data.length&&s.data[u];u++)c+=String.fromCharCode(s.data[u]);e.item_inf[c]=l}i=s.end}}function u(t,e){for(var r=0;;){var n=a(t,r);if(!n)break;\"ipco\"===n.boxtype&&o(n.data,e),r=n.end}}t.exports.unbox=a,t.exports.readSizeFromMeta=function(t){var e={sizes:[],transforms:[],item_inf:{},item_loc:{}};if(function(t,e){for(var r=4;;){var n=a(t,r);if(!n)break;\"iprp\"===n.boxtype&&u(n.data,e),\"iloc\"===n.boxtype&&l(n.data,e),\"iinf\"===n.boxtype&&c(n.data,e),r=n.end}}(t,e),e.sizes.length){var r,n,i,o=(n=(r=e.sizes).reduce((function(t,e){return t.width>e.width||t.width===e.width&&t.height>e.height?t:e})),i=r.reduce((function(t,e){return t.height>e.height||t.height===e.height&&t.width>e.width?t:e})),n.width>i.height||n.width===i.height&&n.height>i.width?n:i),s=1;e.transforms.forEach((function(t){var e={1:6,2:5,3:8,4:7,5:4,6:3,7:2,8:1},r={1:4,2:3,3:2,4:1,5:6,6:5,7:8,8:7};if(\"imir\"===t.type&&(s=0===t.value?r[s]:e[s=e[s=r[s]]]),\"irot\"===t.type)for(var n=0;n<t.value;n++)s=e[s]}));var h=null;return e.item_inf.Exif&&(h=e.item_loc[e.item_inf.Exif]),{width:o.width,height:o.height,orientation:e.transforms.length?s:null,variants:e.sizes,exif_location:h}}},t.exports.getMimeType=function(t){var e=String.fromCharCode.apply(null,t.slice(0,4)),r={};r[e]=!0;for(var n=8;n<t.length;n+=4)r[String.fromCharCode.apply(null,t.slice(n,n+4))]=!0;if(r.mif1||r.msf1||r.miaf)return\"avif\"===e||\"avis\"===e||\"avio\"===e?{type:\"avif\",mime:\"image/avif\"}:\"heic\"===e||\"heix\"===e?{type:\"heic\",mime:\"image/heic\"}:\"hevc\"===e||\"hevx\"===e?{type:\"heic\",mime:\"image/heic-sequence\"}:r.avif||r.avis?{type:\"avif\",mime:\"image/avif\"}:r.heic||r.heix||r.hevc||r.hevx||r.heis?r.msf1?{type:\"heif\",mime:\"image/heif-sequence\"}:{type:\"heif\",mime:\"image/heif\"}:{type:\"avif\",mime:\"image/avif\"}}},31149:function(t,e,r){\"use strict\";var n=r(3944).VG,i=r(3944).rU,a=r(3944).bb,o=r(20186),s=r(19789),l=n(\"ftyp\");t.exports=function(t){if(i(t,4,l)){var e=o.unbox(t,0);if(e){var r=o.getMimeType(e.data);if(r){for(var n,c=e.end;;){var u=o.unbox(t,c);if(!u)break;if(c=u.end,\"mdat\"===u.boxtype)return;if(\"meta\"===u.boxtype){n=u.data;break}}if(n){var h=o.readSizeFromMeta(n);if(h){var f={width:h.width,height:h.height,type:r.type,mime:r.mime,wUnits:\"px\",hUnits:\"px\"};if(h.variants.length>1&&(f.variants=h.variants),h.orientation&&(f.orientation=h.orientation),h.exif_location&&h.exif_location.offset+h.exif_location.length<=t.length){var p=a(t,h.exif_location.offset),d=t.slice(h.exif_location.offset+p+4,h.exif_location.offset+h.exif_location.length),m=s.get_orientation(d);m>0&&(f.orientation=m)}return f}}}}}}},78218:function(t,e,r){\"use strict\";var n=r(3944).VG,i=r(3944).rU,a=r(3944).$l,o=n(\"BM\");t.exports=function(t){if(!(t.length<26)&&i(t,0,o))return{width:a(t,18),height:a(t,22),type:\"bmp\",mime:\"image/bmp\",wUnits:\"px\",hUnits:\"px\"}}},37495:function(t,e,r){\"use strict\";var n=r(3944).VG,i=r(3944).rU,a=r(3944).$l,o=n(\"GIF87a\"),s=n(\"GIF89a\");t.exports=function(t){if(!(t.length<10)&&(i(t,0,o)||i(t,0,s)))return{width:a(t,6),height:a(t,8),type:\"gif\",mime:\"image/gif\",wUnits:\"px\",hUnits:\"px\"}}},88708:function(t,e,r){\"use strict\";var n=r(3944).$l;t.exports=function(t){var e=n(t,0),r=n(t,2),i=n(t,4);if(0===e&&1===r&&i){for(var a=[],o={width:0,height:0},s=0;s<i;s++){var l=t[6+16*s]||256,c=t[6+16*s+1]||256,u={width:l,height:c};a.push(u),(l>o.width||c>o.height)&&(o=u)}return{width:o.width,height:o.height,variants:a,type:\"ico\",mime:\"image/x-icon\",wUnits:\"px\",hUnits:\"px\"}}}},13827:function(t,e,r){\"use strict\";var n=r(3944).bc,i=r(3944).VG,a=r(3944).rU,o=r(19789),s=i(\"Exif\\0\\0\");t.exports=function(t){if(!(t.length<2)&&255===t[0]&&216===t[1]&&255===t[2])for(var e=2;;){for(;;){if(t.length-e<2)return;if(255===t[e++])break}for(var r,i,l=t[e++];255===l;)l=t[e++];if(208<=l&&l<=217||1===l)r=0;else{if(!(192<=l&&l<=254))return;if(t.length-e<2)return;r=n(t,e)-2,e+=2}if(217===l||218===l)return;if(225===l&&r>=10&&a(t,e,s)&&(i=o.get_orientation(t.slice(e+6,e+r))),r>=5&&192<=l&&l<=207&&196!==l&&200!==l&&204!==l){if(t.length-e<r)return;var c={width:n(t,e+3),height:n(t,e+1),type:\"jpg\",mime:\"image/jpeg\",wUnits:\"px\",hUnits:\"px\"};return i>0&&(c.orientation=i),c}e+=r}}},46594:function(t,e,r){\"use strict\";var n=r(3944).VG,i=r(3944).rU,a=r(3944).bb,o=n(\"\u0089PNG\\r\\n\u001a\\n\"),s=n(\"IHDR\");t.exports=function(t){if(!(t.length<24)&&i(t,0,o)&&i(t,12,s))return{width:a(t,16),height:a(t,20),type:\"png\",mime:\"image/png\",wUnits:\"px\",hUnits:\"px\"}}},13198:function(t,e,r){\"use strict\";var n=r(3944).VG,i=r(3944).rU,a=r(3944).bb,o=n(\"8BPS\\0\u0001\");t.exports=function(t){if(!(t.length<22)&&i(t,0,o))return{width:a(t,18),height:a(t,14),type:\"psd\",mime:\"image/vnd.adobe.photoshop\",wUnits:\"px\",hUnits:\"px\"}}},94203:function(t){\"use strict\";function e(t){return\"number\"==typeof t&&isFinite(t)&&t>0}var r=/<[-_.:a-zA-Z0-9][^>]*>/,n=/^<([-_.:a-zA-Z0-9]+:)?svg\\s/,i=/[^-]\\bwidth=\"([^%]+?)\"|[^-]\\bwidth='([^%]+?)'/,a=/\\bheight=\"([^%]+?)\"|\\bheight='([^%]+?)'/,o=/\\bview[bB]ox=\"(.+?)\"|\\bview[bB]ox='(.+?)'/,s=/in$|mm$|cm$|pt$|pc$|px$|em$|ex$/;function l(t){return s.test(t)?t.match(s)[0]:\"px\"}t.exports=function(t){if(function(t){var e,r=0,n=t.length;for(239===t[0]&&187===t[1]&&191===t[2]&&(r=3);r<n&&(32===(e=t[r])||9===e||13===e||10===e);)r++;return r!==n&&60===t[r]}(t)){for(var s=\"\",c=0;c<t.length;c++)s+=String.fromCharCode(t[c]);var u=(s.match(r)||[\"\"])[0];if(n.test(u)){var h=function(t){var e=t.match(i),r=t.match(a),n=t.match(o);return{width:e&&(e[1]||e[2]),height:r&&(r[1]||r[2]),viewbox:n&&(n[1]||n[2])}}(u),f=parseFloat(h.width),p=parseFloat(h.height);if(h.width&&h.height){if(!e(f)||!e(p))return;return{width:f,height:p,type:\"svg\",mime:\"image/svg+xml\",wUnits:l(h.width),hUnits:l(h.height)}}var d=(h.viewbox||\"\").split(\" \"),m={width:d[2],height:d[3]},g=parseFloat(m.width),y=parseFloat(m.height);if(e(g)&&e(y)&&l(m.width)===l(m.height)){var v=g/y;if(h.width){if(!e(f))return;return{width:f,height:f/v,type:\"svg\",mime:\"image/svg+xml\",wUnits:l(h.width),hUnits:l(h.width)}}if(h.height){if(!e(p))return;return{width:p*v,height:p,type:\"svg\",mime:\"image/svg+xml\",wUnits:l(h.height),hUnits:l(h.height)}}return{width:g,height:y,type:\"svg\",mime:\"image/svg+xml\",wUnits:l(m.width),hUnits:l(m.height)}}}}}},46966:function(t,e,r){\"use strict\";var n=r(3944).VG,i=r(3944).rU,a=r(3944).$l,o=r(3944).bc,s=r(3944).tF,l=r(3944).bb,c=n(\"II*\\0\"),u=n(\"MM\\0*\");function h(t,e,r){return r?o(t,e):a(t,e)}function f(t,e,r){return r?l(t,e):s(t,e)}function p(t,e,r){var n=h(t,e+2,r);return 1!==f(t,e+4,r)||3!==n&&4!==n?null:3===n?h(t,e+8,r):f(t,e+8,r)}t.exports=function(t){if(!(t.length<8)&&(i(t,0,c)||i(t,0,u))){var e=77===t[0],r=f(t,4,e)-8;if(!(r<0)){var n=r+8;if(!(t.length-n<2)){var a=12*h(t,n+0,e);if(!(a<=0||(n+=2,t.length-n<a))){var o,s,l,d;for(o=0;o<a;o+=12)256===(d=h(t,n+o,e))?s=p(t,n+o,e):257===d&&(l=p(t,n+o,e));return s&&l?{width:s,height:l,type:\"tiff\",mime:\"image/tiff\",wUnits:\"px\",hUnits:\"px\"}:void 0}}}}}},88023:function(t,e,r){\"use strict\";var n=r(3944).VG,i=r(3944).rU,a=r(3944).$l,o=r(3944).tF,s=r(19789),l=n(\"RIFF\"),c=n(\"WEBP\");function u(t,e){if(157===t[e+3]&&1===t[e+4]&&42===t[e+5])return{width:16383&a(t,e+6),height:16383&a(t,e+8),type:\"webp\",mime:\"image/webp\",wUnits:\"px\",hUnits:\"px\"}}function h(t,e){if(47===t[e]){var r=o(t,e+1);return{width:1+(16383&r),height:1+(r>>14&16383),type:\"webp\",mime:\"image/webp\",wUnits:\"px\",hUnits:\"px\"}}}function f(t,e){return{width:1+(t[e+6]<<16|t[e+5]<<8|t[e+4]),height:1+(t[e+9]<<e|t[e+8]<<8|t[e+7]),type:\"webp\",mime:\"image/webp\",wUnits:\"px\",hUnits:\"px\"}}t.exports=function(t){if(!(t.length<16)&&(i(t,0,l)||i(t,8,c))){var e=12,r=null,n=0,a=o(t,4)+8;if(!(a>t.length)){for(;e+8<a;)if(0!==t[e]){var p=String.fromCharCode.apply(null,t.slice(e,e+4)),d=o(t,e+4);\"VP8 \"===p&&d>=10?r=r||u(t,e+8):\"VP8L\"===p&&d>=9?r=r||h(t,e+8):\"VP8X\"===p&&d>=10?r=r||f(t,e+8):\"EXIF\"===p&&(n=s.get_orientation(t.slice(e+8,e+8+d)),e=1/0),e+=8+d}else e++;if(r)return n>0&&(r.orientation=n),r}}}},43751:function(t,e,r){\"use strict\";t.exports={avif:r(31149),bmp:r(78218),gif:r(37495),ico:r(88708),jpeg:r(13827),png:r(46594),psd:r(13198),svg:r(94203),tiff:r(46966),webp:r(88023)}},19490:function(t,e,r){\"use strict\";var n=r(43751);t.exports=function(t){return function(t){for(var e=Object.keys(n),r=0;r<e.length;r++){var i=n[e[r]](t);if(i)return i}return null}(t)},t.exports.parsers=n},33282:function(t){var e,r,n=t.exports={};function i(){throw new Error(\"setTimeout has not been defined\")}function a(){throw new Error(\"clearTimeout has not been defined\")}function o(t){if(e===setTimeout)return setTimeout(t,0);if((e===i||!e)&&setTimeout)return e=setTimeout,setTimeout(t,0);try{return e(t,0)}catch(r){try{return e.call(null,t,0)}catch(r){return e.call(this,t,0)}}}!function(){try{e=\"function\"==typeof setTimeout?setTimeout:i}catch(t){e=i}try{r=\"function\"==typeof clearTimeout?clearTimeout:a}catch(t){r=a}}();var s,l=[],c=!1,u=-1;function h(){c&&s&&(c=!1,s.length?l=s.concat(l):u=-1,l.length&&f())}function f(){if(!c){var t=o(h);c=!0;for(var e=l.length;e;){for(s=l,l=[];++u<e;)s&&s[u].run();u=-1,e=l.length}s=null,c=!1,function(t){if(r===clearTimeout)return clearTimeout(t);if((r===a||!r)&&clearTimeout)return r=clearTimeout,clearTimeout(t);try{return r(t)}catch(e){try{return r.call(null,t)}catch(e){return r.call(this,t)}}}(t)}}function p(t,e){this.fun=t,this.array=e}function d(){}n.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];l.push(new p(t,e)),1!==l.length||c||o(f)},p.prototype.run=function(){this.fun.apply(null,this.array)},n.title=\"browser\",n.browser=!0,n.env={},n.argv=[],n.version=\"\",n.versions={},n.on=d,n.addListener=d,n.once=d,n.off=d,n.removeListener=d,n.removeAllListeners=d,n.emit=d,n.prependListener=d,n.prependOnceListener=d,n.listeners=function(t){return[]},n.binding=function(t){throw new Error(\"process.binding is not supported\")},n.cwd=function(){return\"/\"},n.chdir=function(t){throw new Error(\"process.chdir is not supported\")},n.umask=function(){return 0}},16494:function(t,e,r){for(var n=r(71879),i=\"undefined\"==typeof window?r.g:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,16.666666666666668-(e-u));u=r+e,setTimeout((function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout((function(){throw t}),0)}}),Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}t.exports=function(t){return s.call(i,t)},t.exports.cancel=function(){l.apply(i,arguments)},t.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}},29978:function(t,e,r){\"use strict\";var n=r(78112),i=r(162),a=r(79788),o=r(6807),s=r(27976),l=r(83473),c=r(51498),u=c.float32,h=c.fract32;t.exports=function(t,e){if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,m,g,y=t._gl,v={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),m=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"static\",type:\"float\",data:f}),T(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:m,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:g,stride:24,offset:0},lineOffset:{buffer:g,stride:24,offset:8},capOffset:{buffer:g,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(_,{update:T,draw:b,destroy:k,regl:t,gl:y,canvas:y.canvas,groups:x}),_;function _(t){t?T(t):null===t&&k(),b()}function b(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach((function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)}))}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function T(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(_.groups=x=t.map((function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},v,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:y.drawingBufferWidth,height:y.drawingBufferHeight},e}}]),u):u})),e||r){var f=x.reduce((function(t,e,r){return t+(e?e.count:0)}),0),g=new Float64Array(2*f),b=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach((function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(b.set(a,4*i),w.set(o,4*i),g.set(r,2*i))}}));var T=u(g);c(T);var k=h(g,T);p(k),d(b),m(w)}}}function k(){c.destroy(),p.destroy(),d.destroy(),m.destroy(),g.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},49478:function(t,e,r){\"use strict\";var n=r(162),i=r(78112),a=r(27976),o=r(6807),s=r(83473),l=r(25782),c=r(90956),u=r(51498),h=u.float32,f=u.fract32,p=r(93103),d=r(5137),m=r(33055);function g(t,e){if(!(this instanceof g))return new g(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=g.shaders.has(t)?g.shaders.get(t):g.shaders.set(t,g.createShaders(t)).get(t),this.update(e)}t.exports=g,g.dashMult=2,g.maxPatternLength=256,g.precisionThreshold=3e6,g.maxPoints=1e4,g.maxLines=2048,g.shaders=new p,g.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashTexture:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashLength:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:\"\\nprecision highp float;\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\",frag:\"\\nprecision highp float;\\n\\nuniform float dashLength, pixelRatio, thickness, opacity, id;\\nuniform sampler2D dashTexture;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashLength) * .5 + .25;\\n\\tfloat dash = texture2D(dashTexture, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\",attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:\"\\nprecision highp float;\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\",frag:\"\\nprecision highp float;\\n\\nuniform float dashLength, pixelRatio, thickness, opacity, id, miterMode;\\nuniform sampler2D dashTexture;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashLength) * .5 + .25;\\n\\tfloat dash = texture2D(dashTexture, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\",attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:\"\\nprecision highp float;\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\",frag:\"\\nprecision highp float;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\",uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},g.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},g.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},g.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach((function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>g.precisionThreshold||e.scale[1]*e.viewport.height>g.precisionThreshold||\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=g.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))})),this},g.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,u=this.gl;if(t.forEach((function(t,p){var y=e.passes[p];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\",splitNull:\"splitNull\"}),y||(e.passes[p]=y={id:p,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},g.defaults,t)),null!=t.thickness&&(y.thickness=parseFloat(t.thickness)),null!=t.opacity&&(y.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(y.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(y.overlay=!!t.overlay,p<g.maxLines&&(y.depth=2*(g.maxLines-1-p%g.maxLines)/g.maxLines-1)),null!=t.join&&(y.join=t.join),null!=t.hole&&(y.hole=t.hole),null!=t.fill&&(y.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(y.viewport=d(t.viewport)),y.viewport||(y.viewport=d([u.drawingBufferWidth,u.drawingBufferHeight])),null!=t.close&&(y.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var v,x;if(t.positions.x&&t.positions.y){var _=t.positions.x,b=t.positions.y;x=y.count=Math.max(_.length,b.length),v=new Float64Array(2*x);for(var w=0;w<x;w++)v[2*w]=_[w],v[2*w+1]=b[w]}else v=s(t.positions,\"float64\"),x=y.count=Math.floor(v.length/2);var T=y.bounds=i(v,2);if(y.fill){for(var k=[],A={},M=0,S=0,E=0,C=y.count;S<C;S++){var L=v[2*S],I=v[2*S+1];isNaN(L)||isNaN(I)||null==L||null==I?(L=v[2*M],I=v[2*M+1],A[S]=M):M=S,k[E++]=L,k[E++]=I}if(t.splitNull){y.count-1 in A||(A[y.count]=y.count-1);var P=Object.keys(A).map(Number).sort((function(t,e){return t-e})),z=[],O=0,D=null!=y.hole?y.hole[0]:null;if(null!=D){var R=m(P,(function(t){return t>=D}));(P=P.slice(0,R)).push(D)}for(var F=function(t){var e=k.slice(2*O,2*P[t]).concat(D?k.slice(2*D):[]),r=(y.hole||[]).map((function(e){return e-D+(P[t]-O)})),n=l(e,r);n=n.map((function(e){return e+O+(e+O<P[t]?0:D-P[t])})),z.push.apply(z,n),O=P[t]+1},B=0;B<P.length;B++)F(B);for(var N=0,j=z.length;N<j;N++)null!=A[z[N]]&&(z[N]=A[z[N]]);y.triangles=z}else{for(var U=l(k,y.hole||[]),V=0,q=U.length;V<q;V++)null!=A[U[V]]&&(U[V]=A[U[V]]);y.triangles=U}}var H=new Float64Array(v);c(H,2,T);var G=new Float64Array(2*x+6);y.close?v[0]===v[2*x-2]&&v[1]===v[2*x-1]?(G[0]=H[2*x-4],G[1]=H[2*x-3]):(G[0]=H[2*x-2],G[1]=H[2*x-1]):(G[0]=H[0],G[1]=H[1]),G.set(H,2),y.close?v[0]===v[2*x-2]&&v[1]===v[2*x-1]?(G[2*x+2]=H[2],G[2*x+3]=H[3],y.count-=1):(G[2*x+2]=H[0],G[2*x+3]=H[1],G[2*x+4]=H[2],G[2*x+5]=H[3]):(G[2*x+2]=H[2*x-2],G[2*x+3]=H[2*x-1],G[2*x+4]=H[2*x-2],G[2*x+5]=H[2*x-1]);var Z=h(G);y.positionBuffer(Z);var W=f(G,Z);y.positionFractBuffer(W)}if(t.range?y.range=t.range:y.range||(y.range=y.bounds),(t.range||t.positions)&&y.count){var Y=y.bounds,X=Y[2]-Y[0],$=Y[3]-Y[1],J=y.range[2]-y.range[0],K=y.range[3]-y.range[1];y.scale=[X/J,$/K],y.translate=[-y.range[0]/J+Y[0]/J||0,-y.range[1]/K+Y[1]/K||0],y.scaleFract=f(y.scale),y.translateFract=f(y.translate)}if(t.dashes){var Q,tt=0;if(!t.dashes||t.dashes.length<2)tt=1,Q=new Uint8Array([255,255,255,255,255,255,255,255]);else{tt=0;for(var et=0;et<t.dashes.length;++et)tt+=t.dashes[et];Q=new Uint8Array(tt*g.dashMult);for(var rt=0,nt=255,it=0;it<2;it++)for(var at=0;at<t.dashes.length;++at){for(var ot=0,st=t.dashes[at]*g.dashMult*.5;ot<st;++ot)Q[rt++]=nt;nt^=255}}y.dashLength=tt,y.dashTexture({channels:1,data:Q,width:Q.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var lt=y.count,ct=t.color;ct||(ct=\"transparent\");var ut=new Uint8Array(4*lt+4);if(Array.isArray(ct)&&\"number\"!=typeof ct[0]){for(var ht=0;ht<lt;ht++){var ft=n(ct[ht],\"uint8\");ut.set(ft,4*ht)}ut.set(n(ct[0],\"uint8\"),4*lt)}else for(var pt=n(ct,\"uint8\"),dt=0;dt<lt+1;dt++)ut.set(pt,4*dt);y.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:ut})}}else e.passes[p]=null})),t.length<this.passes.length){for(var p=t.length;p<this.passes.length;p++){var y=this.passes[p];y&&(y.colorBuffer.destroy(),y.positionBuffer.destroy(),y.dashTexture.destroy())}this.passes.length=t.length}for(var v=[],x=0;x<this.passes.length;x++)null!==this.passes[x]&&v.push(this.passes[x]);return this.passes=v,this}},g.prototype.destroy=function(){return this.passes.forEach((function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()})),this.passes.length=0,this}},62172:function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=null==t?null:\"undefined\"!=typeof Symbol&&t[Symbol.iterator]||t[\"@@iterator\"];if(null!=r){var n,i,a,o,s=[],l=!0,c=!1;try{if(a=(r=r.call(t)).next,0===e){if(Object(r)!==r)return;l=!1}else for(;!(l=(n=a.call(r)).done)&&(s.push(n.value),s.length!==e);l=!0);}catch(t){c=!0,i=t}finally{try{if(!l&&null!=r.return&&(o=r.return(),Object(o)!==o))return}finally{if(c)throw i}}return s}}(t,e)||i(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t,e){if(t){if(\"string\"==typeof t)return a(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?a(t,e):void 0}}function a(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}var o=r(162),s=r(78112),l=r(46762),c=r(27549),u=r(27976),h=r(76765),f=r(6807),p=r(79788),d=r(83473),m=r(39488),g=r(51498),y=r(5137),v=x;function x(t,e){var r=this;if(!(this instanceof x))return new x(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=m,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),u(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{constPointSize:!!e.constPointSize,opacity:t.prop(\"opacity\"),paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},pixelRatio:t.context(\"pixelRatio\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),markerTexture:t.prop(\"markerTexture\"),paletteTexture:n},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=u({},o);s.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform float opacity;\\nuniform sampler2D markerTexture;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(markerTexture, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\n// `invariant` effectively turns off optimizations for the position.\\n// We need this because -fast-math on M1 Macs is re-ordering\\n// floating point operations in a way that causes floating point\\n// precision limits to put points in the wrong locations.\\ninvariant gl_Position;\\n\\nuniform bool constPointSize;\\nuniform float pixelRatio;\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform sampler2D paletteTexture;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(paletteTexture,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pointSizeScale;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\\n\"]),this.drawMarker=t(s);var l=u({},o);l.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nuniform float opacity;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\n// `invariant` effectively turns off optimizations for the position.\\n// We need this because -fast-math on M1 Macs is re-ordering\\n// floating point operations in a way that causes floating point\\n// precision limits to put points in the wrong locations.\\ninvariant gl_Position;\\n\\nuniform bool constPointSize;\\nuniform float pixelRatio;\\nuniform vec2 paletteSize, scale, scaleFract, translate, translateFract;\\nuniform sampler2D paletteTexture;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(paletteTexture,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pointSizeScale;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),m&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}x.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},x.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},x.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach((function(e,r){t.drawItem(r)}));return this},x.prototype.drawItem=function(t,e){var r,n=this.groups,o=n[t];if(\"number\"==typeof e&&(t=e,o=n[e],e=null),o&&o.count&&o.opacity){o.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,o,e));for(var s=[],l=1;l<o.activation.length;l++)o.activation[l]&&(!0===o.activation[l]||o.activation[l].data.length)&&s.push.apply(s,function(t){if(Array.isArray(t))return a(t)}(r=this.getMarkerDrawOptions(l,o,e))||function(t){if(\"undefined\"!=typeof Symbol&&null!=t[Symbol.iterator]||null!=t[\"@@iterator\"])return Array.from(t)}(r)||i(r)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}());s.length&&this.drawMarker(s)}},x.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,c=e.count;if(this.regl,!a)return r?[u({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[u({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(c),m=0;m<r.length;m++){var g=r[m];d[g]=p?p[g]:1}l.subdata(d)}for(var y=f.length;y--;){var v=n(f[y],2),x=v[0],_=v[1];h.push(u({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:_-x}))}return h},x.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,o=this.regl,l=this.maxSize,h=this.maxColors,m=this.palette;this.groups=i=r.map((function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=f(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:o.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=u({},x.defaults,e)),e.positions&&!(\"marker\"in e)&&(e.marker=n.marker,delete n.marker),e.marker&&!(\"positions\"in e)&&(e.positions=n.positions,delete n.positions);var v=0,_=0;if(p(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=x.defaults.size),v+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=x.defaults.borderSize),v+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=x.defaults.color),e=t.updateColor(e),_++,e},borderColor:function(e,r){return null==e&&(e=x.defaults.borderColor),e=t.updateColor(e),_++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,l=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:o.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:o.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=d(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?s(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=c(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=o.elements(f)}var p=g.float32(t);return i({data:p,usage:\"dynamic\"}),a({data:g.fract32(t,p),usage:\"dynamic\"}),l({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach((function(t){return t&&t.destroy&&t.destroy()})),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],s=0,l=Math.min(e.length,r.count);s<l;s++){var c=t.addMarker(e[s]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][s]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=o.buffer(h),i[u].data=a[u]}}else i[t.addMarker(e)]=!0;return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return y(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),v){var b=n,w=b.count,T=b.size,k=b.borderSize,A=b.sizeBuffer,M=new Uint8Array(2*w);if(T.length||k.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==T[S]?T:T[S])/l),M[2*S+1]=Math.round(255*(null==k[S]?k:k[S])/l);A({data:M,usage:\"dynamic\"})}if(_){var E,C=n,L=C.count,I=C.color,P=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(I.length||P.length){E=new Uint8Array(8*L);for(var O=0;O<L;O++){var D=I[O];E[8*O]=m[4*D],E[8*O+1]=m[4*D+1],E[8*O+2]=m[4*D+2],E[8*O+3]=m[4*D+3];var R=P[O];E[8*O+4]=m[4*R],E[8*O+5]=m[4*R+1],E[8*O+6]=m[4*R+2],E[8*O+7]=m[4*R+3]}}}else if(I.length||P.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=I[F]&&(E[4*F]=I[F]%h,E[4*F+1]=Math.floor(I[F]/h)),null!=P[F]&&(E[4*F+2]=P[F]%h,E[4*F+3]=Math.floor(P[F]/h))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n}))}},x.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},x.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var a=[];if(Array.isArray(t))for(var s=0;s<t.length;s+=4)a.push(t.slice(s,s+4));else for(var c=0;c<t.length;c+=4)a.push(t.subarray(c,c+4));t=a}for(var u=0;u<t.length;u++){var h=t[u];h=o(h,\"uint8\");var f=l(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},x.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},x.prototype.destroy=function(){return this.groups.forEach((function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach((function(t){return t&&t.destroy&&t.destroy()})),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()})),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach((function(t){return t&&t.destroy&&t.destroy()})),this};var _=r(27976);t.exports=function(t,e){var r=new v(t,e),n=r.render.bind(r);return _(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},31239:function(t,e,r){\"use strict\";var n=r(62172),i=r(6807),a=r(78112),o=r(16494),s=r(27902),l=r(5137),c=r(83473);function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x,s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y,l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}t.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o((function(){e.draw(),e.dirty=!0,e.planned=null}))):(this.draw(),this.dirty=!0,o((function(){e.dirty=!1}))),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var m=s.columns,g=s.count,y=s.viewport.width,v=s.viewport.height,x=s.viewport.x,_=s.viewport.y,b=y/m,w=v/m;s.passes=[];for(var T=0;T<m;T++)for(var k=0;k<m;k++)if((s.diagonal||k!==T)&&(s.upper||!(T>k))&&(s.lower||!(T<k))){var A=h(s.id,T,k),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:k,count:g,stride:m},y:{buffer:s.buffer,offset:T,count:g,stride:m}}:M.positions={x:{buffer:s.buffer,offset:k*g,count:g},y:{buffer:s.buffer,offset:T*g,count:g}},M.bounds=f(s.bounds,T,k)),o.domain||o.viewport||o.data){var S=d?f(s.padding,T,k):s.padding;if(s.domain){var E=f(s.domain,T,k),C=E[0],L=E[1],I=E[2],P=E[3];M.viewport=[x+C*y+S[0],_+L*v+S[1],x+I*y-S[2],_+P*v-S[3]]}else M.viewport=[x+k*b+b*S[0],_+T*w+w*S[1],x+(k+1)*b-b*S[2],_+(T+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,T,k):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map((function(t,e){n[f+e]=c}))}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach((function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()})),this.traces=null,this.passes=null,this.scatter.destroy(),this}},81330:function(t){t.exports=function(){function t(t,e){this.id=Z++,this.type=t,this.data=e}function e(t){if(0===t.length)return[];var r=t.charAt(0),n=t.charAt(t.length-1);if(1<t.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+t.substr(1,t.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(t))return e(t.substr(0,r.index)).concat(e(r[1])).concat(e(t.substr(r.index+r[0].length)));if(1===(r=t.split(\".\")).length)return['\"'+t.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(t=[],n=0;n<r.length;++n)t=t.concat(e(r[n]));return t}function r(t){return\"[\"+e(t).join(\"][\")+\"]\"}function n(t){return\"string\"==typeof t?t.split():t}function i(t){return\"string\"==typeof t?document.querySelector(t):t}function a(t){var e,r,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f={},p=function(t){},d=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=i(s.canvas):\"container\"in s&&(r=i(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=n(s.extensions)),\"optionalExtensions\"in s&&(c=n(s.optionalExtensions)),\"onDone\"in s&&(p=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio),\"cachedCode\"in s&&(f=s.cachedCode))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:r=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=a.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n}var i,a=document.createElement(\"canvas\");return G(a.style,{border:0,margin:0,padding:0,top:0,left:0,width:\"100%\",height:\"100%\"}),t.appendChild(a),t===document.body&&(a.style.position=\"absolute\",G(t.style,{margin:0,padding:0})),t!==document.body&&\"function\"==typeof ResizeObserver?(i=new ResizeObserver((function(){setTimeout(n)}))).observe(t):window.addEventListener(\"resize\",n,!1),n(),{canvas:a,onDestroy:function(){i?i.disconnect():window.removeEventListener(\"resize\",n),t.removeChild(a)}}}(r||document.body,0,u)))return null;a=e.canvas,d=e.onDestroy}void 0===t.premultipliedAlpha&&(t.premultipliedAlpha=!0),o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:r,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,cachedCode:f,onDone:p,onDestroy:d}:(d(),p(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function o(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function s(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function l(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[s(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[s(t.byteLength)>>2].push(t)}var r=o(8,(function(){return[]}));return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function c(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||K(t.data))}function u(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function h(t,e,r,n,i){for(var a=1,o=r+1;o<e.length;++o)a*=e[o];var s=e[r];if(4==e.length-r){var l=e[r+1],c=e[r+2];for(e=e[r+3],o=0;o<s;++o)u(t[o],l,c,e,n,i),i+=a}else for(o=0;o<s;++o)h(t[o],e,r+1,n,i),i+=a}function f(t){return 0|et[Object.prototype.toString.call(t)]}function p(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function d(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function m(t,e,r,n){function i(e){this.id=l++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=at(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=it(e,i,t.dtype),r),o?t.persistentData=e:$.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,p(i=$.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:$.freeType(i)):K(e[0])&&(t.dimension=e[0].length,t.dtype=n||f(e[0])||5126,a(t,e=it(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:$.freeType(e))}else if(K(e))t.dtype=n||f(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(c(e)){i=e.shape;var l=e.stride,u=(s=e.offset,0),h=0,m=0,g=0;1===i.length?(u=i[0],h=1,m=l[0],g=0):2===i.length&&(u=i[0],h=i[1],m=l[0],g=l[1]),t.dtype=n||f(e.data)||5126,t.dimension=h,d(i=$.allocType(t.dtype,u*h),e.data,u,h,m,g,s),a(t,i,r),o?t.persistentData=i:$.freeType(i)}else e instanceof ArrayBuffer&&(t.dtype=5121,t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e))))}function s(r){e.bufferCount--,n(r),t.deleteBuffer(r.buffer),r.buffer=null,delete u[r.id]}var l=0,u={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var h=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(n,a,l,h){function m(e){var n=35044,i=null,a=0,s=0,l=1;return Array.isArray(e)||K(e)||c(e)||e instanceof ArrayBuffer?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=nt[e.usage]),\"type\"in e&&(s=rt[e.type]),\"dimension\"in e&&(l=0|e.dimension),\"length\"in e&&(a=0|e.length)),g.bind(),i?o(g,i,n,s,l,h):(a&&t.bufferData(g.type,a,n),g.dtype=s||5121,g.usage=n,g.dimension=l,g.byteLength=a),r.profile&&(g.stats.size=g.byteLength*ot[g.dtype]),m}e.bufferCount++;var g=new i(a);return u[g.id]=g,l||m(n),m._reglType=\"buffer\",m._buffer=g,m.subdata=function(e,r){var n,i=0|(r||0);if(g.bind(),K(e)||e instanceof ArrayBuffer)t.bufferSubData(g.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=$.allocType(g.dtype,e.length);p(a,e),t.bufferSubData(g.type,i,a),$.freeType(a)}else(Array.isArray(e[0])||K(e[0]))&&(n=at(e),a=it(e,n,g.dtype),t.bufferSubData(g.type,i,a),$.freeType(a))}else if(c(e)){n=e.shape;var o=e.stride,s=a=0,l=0,u=0;1===n.length?(a=n[0],s=1,l=o[0],u=0):2===n.length&&(a=n[0],s=n[1],l=o[0],u=o[1]),n=Array.isArray(e.data)?g.dtype:f(e.data),d(n=$.allocType(n,a*s),e.data,a,s,l,u,e.offset),t.bufferSubData(g.type,i,n),$.freeType(n)}return m},r.profile&&(m.stats=g.stats),m.destroy=function(){s(g)},m},createStream:function(t,e){var r=h.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){h.push(t)},clear:function(){Q(u).forEach(s),h.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){Q(u).forEach((function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)}))},_initBuffer:o}}function g(t,e,r,n){function i(t){this.id=l++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,l,u){var h;if(n.buffer.bind(),i?((h=u)||K(i)&&(!c(i)||K(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)):(t.bufferData(34963,l,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=l),h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},l=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)l(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||K(t)||c(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=nt[t.usage]),\"primitive\"in t&&(n=st[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else l(),h.primType=4,h.vertCount=0,h.type=5121;return s}var l=r.create(null,34963,!0),h=new i(l._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return l.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){Q(s).forEach(o)}}}function y(t){for(var e=$.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{lt[0]=t[r];var n=(a=ct[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||K(t)}function x(t){return\"[object \"+t+\"]\"}function _(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function b(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function w(t){return Object.prototype.toString.call(t)}function T(t){if(!t)return!1;var e=w(t);return 0<=xt.indexOf(e)||_(t)||b(t)||c(t)}function k(t,e){36193===t.type?(t.data=y(e),$.freeType(e)):t.data=e}function A(t,e,r,n,i,a){if(t=void 0!==bt[t]?bt[t]:ft[t]*_t[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function M(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function l(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=V[e.colorSpace]),\"type\"in e&&(t.type=q[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=H[r],t.format=at[n],r in q&&!(\"type\"in e)&&(t.type=q[r]),r in Z&&(t.compressed=!0),r=!0),!a&&r?t.channels=ft[t.format]:a&&!r&&t.channels!==ht[t.format]&&(t.format=t.internalformat=ht[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(T(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),T(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(K(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|et[Object.prototype.toString.call(r)]);else if(_(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=$.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=y(n)}t.alignment=1,t.needsFree=!0}else if(c(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|et[Object.prototype.toString.call(n)]),a=r.shape;var o,s,l,h,f=r.stride;3===a.length?(l=a[2],h=f[2]):h=l=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=l,t.format=t.internalformat=ht[l],t.needsFree=!0,o=h,r=r.offset,l=t.width,h=t.height,s=t.channels;for(var p=$.allocType(36193===t.type?5126:t.type,l*h*s),d=0,m=0;m<h;++m)for(var g=0;g<l;++g)for(var x=0;x<s;++x)p[d++]=n[a*g+f*m+o*x+r];k(t,p)}else if(w(r)===pt||w(r)===dt||w(r)===mt)w(r)===pt||w(r)===dt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(w(r)===gt)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(w(r)===yt)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(w(r)===vt)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(b(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=tt.shape(r),l=1,h=0;h<o.length;++h)l*=o[h];l=$.allocType(36193===t.type?5126:t.type,l),tt.flatten(r,o,\"\",l),k(t,l),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ht[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return ot.pop()||new f}function g(t){t.needsFree&&$.freeType(t.data),f.call(t),ot.push(t)}function x(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(T(e))l(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)l(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else l(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;l(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,m=o.width,g=o.height;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,m,g,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,m,g,0)):t.texImage2D(s,l,p,m,g,0,p,d,u||null)}}function C(){var t=st.pop()||new x;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&g(e[r]),e[r]=null;st.push(t)}function I(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function P(t,e){\"min\"in e&&(t.minFilter=U[e.min],0<=ut.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=j[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function O(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=lt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new I,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=_t[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),_t[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete ct[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},j={nearest:9728,linear:9729},U=G({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},j),V={none:0,browser:37444},q={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},H={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},Z={};e.ext_srgb&&(H.srgb=35904,H.srgba=35906),e.oes_texture_float&&(q.float32=q.float=5126),e.oes_texture_half_float&&(q.float16=q[\"half float\"]=36193),e.webgl_depth_texture&&(G(H,{depth:6402,\"depth stencil\":34041}),G(q,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&G(Z,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&G(Z,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&G(Z,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(Z[\"rgb etc1\"]=36196);var W=Array.prototype.slice.call(t.getParameter(34467));Object.keys(Z).forEach((function(t){var e=Z[t];0<=W.indexOf(e)&&(H[t]=e)}));var Y=Object.keys(H);r.textureFormats=Y;var X=[];Object.keys(H).forEach((function(t){X[H[t]]=t}));var J=[];Object.keys(q).forEach((function(t){J[q[t]]=t}));var rt=[];Object.keys(j).forEach((function(t){rt[j[t]]=t}));var nt=[];Object.keys(U).forEach((function(t){nt[U[t]]=t}));var it=[];Object.keys(N).forEach((function(t){it[N[t]]=t}));var at=Y.reduce((function(t,r){var n=H[r];return 6409===n||6406===n||6409===n||6410===n||6402===n||34041===n||e.ext_srgb&&(35904===n||35906===n)?t[n]=n:32855===n||0<=r.indexOf(\"rgba\")?t[n]=6408:t[n]=6407,t}),{}),ot=[],st=[],lt=0,ct={},xt=r.maxTextureUnits,_t=Array(xt).map((function(){return null}));return G(O.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<xt;++r){var n=_t[r];if(n){if(0<n.bindCount)continue;n.unit=-1}_t[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(ct).forEach((function(e){t+=ct[e].stats.size})),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;I.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(P(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,l(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=A(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=X[i.internalformat],n.type=J[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new O(3553);return ct[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return l(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),g(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l=0;i.mipmask>>l;++l){var c=a>>l,u=s>>l;if(!c||!u)break;t.texImage2D(3553,l,i.format,c,u,0,i.format,i.type,null)}return R(),o.profile&&(i.stats.size=A(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,c){function h(t,e,r,n,i,a){var s,c=f.texInfo;for(I.call(c),s=0;6>s;++s)y[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(y[0],t),S(y[1],e),S(y[2],r),S(y[3],n),S(y[4],i),S(y[5],a);else if(P(c,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)l(y[s],f),S(y[s],t[s]);else for(s=0;6>s;++s)S(y[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(y[s],t,t);for(l(f,y[0]),f.mipmask=c.genMipmaps?(y[0].width<<1)-1:y[0].mipmask,f.internalformat=y[0].internalformat,h.width=y[0].width,h.height=y[0].height,D(f),s=0;6>s;++s)E(y[s],34069+s);for(z(c,34067),R(),o.profile&&(f.stats.size=A(f.internalformat,f.type,h.width,h.height,c.genMipmaps,!0)),h.format=X[f.internalformat],h.type=J[f.type],h.mag=rt[c.magFilter],h.min=nt[c.minFilter],h.wrapS=it[c.wrapS],h.wrapT=it[c.wrapT],s=0;6>s;++s)L(y[s]);return h}var f=new O(34067);ct[f.id]=f,a.cubeCount++;var y=Array(6);return h(e,r,n,i,s,c),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return l(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),g(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=A(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<xt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),_t[e]=null;Q(ct).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<xt;++e){var r=_t[e];r&&(r.bindCount=0,r.unit=-1,_t[e]=null)}Q(ct).forEach((function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)}))},refresh:function(){for(var e=0;e<xt;++e){var r=_t[e];r&&(r.bindCount=0,r.unit=-1,_t[e]=null),t.activeTexture(33984+e),t.bindTexture(3553,null),t.bindTexture(34067,null)}}}}function S(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)||\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=T++,k[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function m(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function g(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete k[e.id]}function y(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function v(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",g=\"uint8\",v=1,x=null,w=null,T=null,k=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(v=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(g=t.colorType,!p)&&(\"half float\"===g||\"float16\"===g?d=\"rgba16f\":\"float\"!==g&&\"float32\"!==g||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=_.indexOf(d)?p=!0:0<=b.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(k=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(T=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(v),i=0;i<v;++i)A[i]=h(a,o,p,d,g);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,k,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),T?E=u(T):!x&&!w&&c&&s&&(E=h(a,o,k,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=kt[A[i].texture._texture.format]*At[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),m(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,y(n),r}var n=new d;return a.framebufferCount++,r(t,e),G(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,y(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){g(n),m(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},_=[\"rgba\"],b=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&b.push(\"srgba\"),e.ext_color_buffer_half_float&&b.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&b.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var T=0,k={};return G(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:v,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=v(a)}return G(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),G(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach((function(t){t.destroy()}))}})},clear:function(){Q(k).forEach(g)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,Q(k).forEach((function(e){e.framebuffer=t.createFramebuffer(),y(e)}))}})}function E(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function C(t,e,r,n,i,a,o){function s(){this.id=++h,this.attributes=[],this.elements=null,this.ownsElements=!1,this.offset=this.count=0,this.instances=-1,this.primitive=4;var t=e.oes_vertex_array_object;this.vao=t?t.createVertexArrayOES():null,f[this.id]=this,this.buffers=[]}var l=r.maxAttributes,u=Array(l);for(r=0;r<l;++r)u[r]=new E;var h=0,f={},p={Record:E,scope:{},state:u,currentVAO:null,targetVAO:null,restore:e.oes_vertex_array_object?function(){e.oes_vertex_array_object&&Q(f).forEach((function(t){t.refresh()}))}:function(){},createVAO:function(t){function e(t){var n;Array.isArray(t)?(n=t,r.elements&&r.ownsElements&&r.elements.destroy(),r.elements=null,r.ownsElements=!1,r.offset=0,r.count=0,r.instances=-1,r.primitive=4):(t.elements?(n=t.elements,r.ownsElements?(\"function\"==typeof n&&\"elements\"===n._reglType?r.elements.destroy():r.elements(n),r.ownsElements=!1):a.getElements(t.elements)?(r.elements=t.elements,r.ownsElements=!1):(r.elements=a.create(t.elements),r.ownsElements=!0)):(r.elements=null,r.ownsElements=!1),n=t.attributes,r.offset=0,r.count=-1,r.instances=-1,r.primitive=4,r.elements&&(r.count=r.elements._elements.vertCount,r.primitive=r.elements._elements.primType),\"offset\"in t&&(r.offset=0|t.offset),\"count\"in t&&(r.count=0|t.count),\"instances\"in t&&(r.instances=0|t.instances),\"primitive\"in t&&(r.primitive=st[t.primitive])),t={};var o=r.attributes;o.length=n.length;for(var s=0;s<n.length;++s){var l,u=n[s],h=o[s]=new E,f=u.data||u;Array.isArray(f)||K(f)||c(f)?(r.buffers[s]&&(l=r.buffers[s],K(f)&&l._buffer.byteLength>=f.byteLength?l.subdata(f):(l.destroy(),r.buffers[s]=null)),r.buffers[s]||(l=r.buffers[s]=i.create(u,34962,!1,!0)),h.buffer=i.getBuffer(l),h.size=0|h.buffer.dimension,h.normalized=!1,h.type=h.buffer.dtype,h.offset=0,h.stride=0,h.divisor=0,h.state=1,t[s]=1):i.getBuffer(u)?(h.buffer=i.getBuffer(u),h.size=0|h.buffer.dimension,h.normalized=!1,h.type=h.buffer.dtype,h.offset=0,h.stride=0,h.divisor=0,h.state=1):i.getBuffer(u.buffer)?(h.buffer=i.getBuffer(u.buffer),h.size=0|(+u.size||h.buffer.dimension),h.normalized=!!u.normalized||!1,h.type=\"type\"in u?rt[u.type]:h.buffer.dtype,h.offset=0|(u.offset||0),h.stride=0|(u.stride||0),h.divisor=0|(u.divisor||0),h.state=1):\"x\"in u&&(h.x=+u.x||0,h.y=+u.y||0,h.z=+u.z||0,h.w=+u.w||0,h.state=2)}for(l=0;l<r.buffers.length;++l)!t[l]&&r.buffers[l]&&(r.buffers[l].destroy(),r.buffers[l]=null);return r.refresh(),e}var r=new s;return n.vaoCount+=1,e.destroy=function(){for(var t=0;t<r.buffers.length;++t)r.buffers[t]&&r.buffers[t].destroy();r.buffers.length=0,r.ownsElements&&(r.elements.destroy(),r.elements=null,r.ownsElements=!1),r.destroy()},e._vao=r,e._reglType=\"vao\",e(t)},getVAO:function(t){return\"function\"==typeof t&&t._vao?t._vao:null},destroyBuffer:function(e){for(var r=0;r<u.length;++r){var n=u[r];n.buffer===e&&(t.disableVertexAttribArray(r),n.buffer=null)}},setVAO:e.oes_vertex_array_object?function(t){if(t!==p.currentVAO){var r=e.oes_vertex_array_object;t?r.bindVertexArrayOES(t.vao):r.bindVertexArrayOES(null),p.currentVAO=t}}:function(r){if(r!==p.currentVAO){if(r)r.bindAttrs();else{for(var n=e.angle_instanced_arrays,i=0;i<u.length;++i){var a=u[i];a.buffer?(t.enableVertexAttribArray(i),a.buffer.bind(),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offfset),n&&a.divisor&&n.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}o.elements?t.bindBuffer(34963,o.elements.buffer.buffer):t.bindBuffer(34963,null)}p.currentVAO=r}},clear:e.oes_vertex_array_object?function(){Q(f).forEach((function(t){t.destroy()}))}:function(){}};return s.prototype.bindAttrs=function(){for(var r=e.angle_instanced_arrays,n=this.attributes,i=0;i<n.length;++i){var o=n[i];o.buffer?(t.enableVertexAttribArray(i),t.bindBuffer(34962,o.buffer.buffer),t.vertexAttribPointer(i,o.size,o.type,o.normalized,o.stride,o.offset),r&&o.divisor&&r.vertexAttribDivisorANGLE(i,o.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,o.x,o.y,o.z,o.w))}for(r=n.length;r<l;++r)t.disableVertexAttribArray(r);(r=a.getElements(this.elements))?t.bindBuffer(34963,r.buffer.buffer):t.bindBuffer(34963,null)},s.prototype.refresh=function(){var t=e.oes_vertex_array_object;t&&(t.bindVertexArrayOES(this.vao),this.bindAttrs(),p.currentVAO=null,t.bindVertexArrayOES(null))},s.prototype.destroy=function(){if(this.vao){var t=e.oes_vertex_array_object;this===p.currentVAO&&(p.currentVAO=null,t.bindVertexArrayOES(null)),t.deleteVertexArrayOES(this.vao),this.vao=null}this.ownsElements&&(this.elements.destroy(),this.elements=null,this.ownsElements=!1),f[this.id]&&(delete f[this.id],--n.vaoCount)},p}function L(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],this.refCount=1,n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s,l){var c;c=o(35632,r.fragId);var u=o(35633,r.vertId);if(s=r.program=t.createProgram(),t.attachShader(s,c),t.attachShader(s,u),l)for(c=0;c<l.length;++c)u=l[c],t.bindAttribLocation(s,u[0],u[1]);t.linkProgram(s),u=t.getProgramParameter(s,35718),n.profile&&(r.stats.uniformsCount=u);var h=r.uniforms;for(c=0;c<u;++c)if(l=t.getActiveUniform(s,c))if(1<l.size)for(var f=0;f<l.size;++f){var p=l.name.replace(\"[0]\",\"[\"+f+\"]\");a(h,new i(p,e.id(p),t.getUniformLocation(s,p),l))}else a(h,new i(l.name,e.id(l.name),t.getUniformLocation(s,l.name),l));for(u=t.getProgramParameter(s,35721),n.profile&&(r.stats.attributesCount=u),r=r.attributes,c=0;c<u;++c)(l=t.getActiveAttrib(s,c))&&a(r,new i(l.name,e.id(l.name),t.getAttribLocation(s,l.name),l))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach((function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)})),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach((function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)})),t}),{clear:function(){var e=t.deleteShader.bind(t);Q(c).forEach(e),c={},Q(u).forEach(e),u={},f.forEach((function(e){t.deleteProgram(e.program)})),f.length=0,h={},r.shaderCount=0},program:function(e,n,i,a){var o=h[n];o||(o=h[n]={});var p=o[e];if(p&&(p.refCount++,!a))return p;var d=new s(n,e);return r.shaderCount++,l(d,i,a),p||(o[e]=d),f.push(d),G(d,{destroy:function(){if(d.refCount--,0>=d.refCount){t.deleteProgram(d.program);var e=f.indexOf(d);f.splice(e,1),r.shaderCount--}0>=o[d.vertId].refCount&&(t.deleteShader(u[d.vertId]),delete u[d.vertId],delete h[d.fragId][d.vertId]),Object.keys(h[d.fragId]).length||(t.deleteShader(c[d.fragId]),delete c[d.fragId],delete h[d.fragId])}})},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t],null,f[t].attributes.map((function(t){return[t.location,t.name]})))},shader:o,frag:-1,vert:-1}}function I(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return K(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},(function(){r=s(t)})),r}(t):s(t)}}function P(t,e){return t>>>e|t<<32-e}function z(t,e){var r=(65535&t)+(65535&e);return(t>>16)+(e>>16)+(r>>16)<<16|65535&r}function O(t){return Array.prototype.slice.call(t)}function D(t){return O(t).join(\"\")}function R(t){function e(){var t=[],e=[];return G((function(){t.push.apply(t,O(arguments))}),{def:function(){var r=\"v\"+i++;return e.push(r),0<arguments.length&&(t.push(r,\"=\"),t.push.apply(t,O(arguments)),t.push(\";\")),r},toString:function(){return D([0<e.length?\"var \"+e.join(\",\")+\";\":\"\",D(t)])}})}function r(){function t(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=e(),n=e(),i=r.toString,a=n.toString;return G((function(){r.apply(r,O(arguments))}),{def:r.def,entry:r,exit:n,save:t,set:function(e,n,i){t(e,n),r(e,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var n=t&&t.cache,i=0,a=[],o=[],s=[],l=e(),c={};return{global:l,link:function(t,e){var r=e&&e.stable;if(!r)for(var n=0;n<o.length;++n)if(o[n]===t&&!s[n])return a[n];return n=\"g\"+i++,a.push(n),o.push(t),s.push(r),n},block:e,proc:function(t,e){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];e=e||0;for(var a=0;a<e;++a)n();var o=(a=r()).toString;return c[t]=G(a,{arg:n,toString:function(){return D([\"function(\",i.join(),\"){\",o(),\"}\"])}})},scope:r,cond:function(){var t=D(arguments),e=r(),n=r(),i=e.toString,a=n.toString;return G(e,{then:function(){return e.apply(e,O(arguments)),this},else:function(){return n.apply(n,O(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),D([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',l,\"return {\"];Object.keys(c).forEach((function(e){t.push('\"',e,'\":',c[e].toString(),\",\")})),t.push(\"}\");var e,r=D(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return n&&(e=function(t){for(var e,r=\"\",n=0;n<t.length;n++)e=t.charCodeAt(n),r+=\"0123456789abcdef\".charAt(e>>>4&15)+\"0123456789abcdef\".charAt(15&e);return r}(function(t){for(var e=Array(t.length>>2),r=0;r<e.length;r++)e[r]=0;for(r=0;r<8*t.length;r+=8)e[r>>5]|=(255&t.charCodeAt(r/8))<<24-r%32;var n,i,a,o,s,l,c,u,h,f,p,d=8*t.length;for(t=[1779033703,-1150833019,1013904242,-1521486534,1359893119,-1694144372,528734635,1541459225],r=Array(64),e[d>>5]|=128<<24-d%32,e[15+(d+64>>9<<4)]=d,u=0;u<e.length;u+=16){for(d=t[0],n=t[1],i=t[2],a=t[3],o=t[4],s=t[5],l=t[6],c=t[7],h=0;64>h;h++){var m;16>h?r[h]=e[h+u]:(f=h,p=z(p=P(p=r[h-2],17)^P(p,19)^p>>>10,r[h-7]),m=P(m=r[h-15],7)^P(m,18)^m>>>3,r[f]=z(z(p,m),r[h-16])),f=z(z(z(z(c,f=P(f=o,6)^P(f,11)^P(f,25)),o&s^~o&l),Mt[h]),r[h]),p=z(c=P(c=d,2)^P(c,13)^P(c,22),d&n^d&i^n&i),c=l,l=s,s=o,o=z(a,f),a=i,i=n,n=d,d=z(f,p)}t[0]=z(d,t[0]),t[1]=z(n,t[1]),t[2]=z(i,t[2]),t[3]=z(a,t[3]),t[4]=z(o,t[4]),t[5]=z(s,t[5]),t[6]=z(l,t[6]),t[7]=z(c,t[7])}for(e=\"\",r=0;r<32*t.length;r+=8)e+=String.fromCharCode(t[r>>5]>>>24-r%32&255);return e}(function(t){for(var e,r,n=\"\",i=-1;++i<t.length;)e=t.charCodeAt(i),r=i+1<t.length?t.charCodeAt(i+1):0,55296<=e&&56319>=e&&56320<=r&&57343>=r&&(e=65536+((1023&e)<<10)+(1023&r),i++),127>=e?n+=String.fromCharCode(e):2047>=e?n+=String.fromCharCode(192|e>>>6&31,128|63&e):65535>=e?n+=String.fromCharCode(224|e>>>12&15,128|e>>>6&63,128|63&e):2097151>=e&&(n+=String.fromCharCode(240|e>>>18&7,128|e>>>12&63,128|e>>>6&63,128|63&e));return n}(r))),n[e])?n[e].apply(null,o):(r=Function.apply(null,a.concat(r)),n&&(n[e]=r),r.apply(null,o))}}}function F(t){return Array.isArray(t)||K(t)||c(t)}function B(t){return t.sort((function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1}))}function N(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function j(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function U(t){return new N(!1,!1,!1,t)}function V(t,e){var r=t.type;if(0===r)return new N(!0,1<=(r=t.data.length),2<=r,e);if(4===r)return new N((r=t.data).thisDep,r.contextDep,r.propDep,e);if(5===r)return new N(!1,!1,!1,e);if(6===r){for(var n=r=!1,i=!1,a=0;a<t.data.length;++a){var o=t.data[a];1===o.type?i=!0:2===o.type?n=!0:3===o.type?r=!0:0===o.type?(r=!0,1<=(o=o.data)&&(n=!0),2<=o&&(i=!0)):4===o.type&&(r=r||o.data.thisDep,n=n||o.data.contextDep,i=i||o.data.propDep)}return new N(r,n,i,e)}return new N(3===r,2===r,1===r,e)}function q(t,e,r,n,i,a,s,l,c,u,h,f,p,d,m,g){function y(t){return t.replace(\".\",\"_\")}function x(t,e,r){var n=y(t);at.push(t),it[n]=nt[n]=!!r,ot[n]=e}function _(t,e,r){var n=y(t);at.push(t),Array.isArray(r)?(nt[n]=r.slice(),it[n]=r.slice()):nt[n]=it[n]=r,lt[n]=e}function b(){var t=R({cache:m}),r=t.link,n=t.global;t.id=ht++,t.batchId=\"0\";var i=r(ct),a=t.shared={props:\"a0\"};Object.keys(ct).forEach((function(t){a[t]=n.def(i,\".\",t)}));var o=t.next={},s=t.current={};Object.keys(lt).forEach((function(t){Array.isArray(nt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))}));var l=t.constants={};Object.keys(ut).forEach((function(t){l[t]=n.def(JSON.stringify(ut[t]))})),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref;case 5:return n.data.toString();case 6:return n.data.map((function(r){return t.invoke(e,r)}))}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new J),c[t]=r(n)},t}function w(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),U((function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r}))):U((function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"}))}if(\"framebuffer\"in n){var a=n.framebuffer;return V(a,(function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;return r=e.def(i,\".getFramebuffer(\",r,\")\"),e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r}))}return null}function T(t,r,n){function i(t){if(t in a){var r=e.id(a[t]);return(t=U((function(){return r}))).id=r,t}if(t in o){var n=o[t];return V(n,(function(t,e){var r=t.invoke(e,n);return e.def(t.shared.strings,\".id(\",r,\")\")}))}return null}var a=t.static,o=t.dynamic,s=i(\"frag\"),l=i(\"vert\"),c=null;return j(s)&&j(l)?(c=h.program(l.id,s.id,null,n),t=U((function(t,e){return t.link(c)}))):t=new N(s&&s.thisDep||l&&l.thisDep,s&&s.contextDep||l&&l.contextDep,s&&s.propDep||l&&l.propDep,(function(t,e){var r,n,i=t.shared.shader;return r=s?s.append(t,e):e.def(i,\".\",\"frag\"),n=l?l.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")})),{frag:s,vert:l,progVar:t,program:c}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return e?o.offset=r:o.instances=r,U((function(t,n){return e&&(t.OFFSET=r),r}))}if(t in i){var a=i[t];return V(a,(function(t,r){var n=t.invoke(r,a);return e&&(t.OFFSET=n),n}))}if(e){if(c)return U((function(t,e){return t.OFFSET=0}));if(s)return new N(l.thisDep,l.contextDep,l.propDep,(function(t,e){return e.def(t.shared.vao+\".currentVAO?\"+t.shared.vao+\".currentVAO.offset:0\")}))}else if(s)return new N(l.thisDep,l.contextDep,l.propDep,(function(t,e){return e.def(t.shared.vao+\".currentVAO?\"+t.shared.vao+\".currentVAO.instances:-1\")}));return null}var n=t.static,i=t.dynamic,o={},s=!1,l=function(){if(\"vao\"in n){var t=n.vao;return null!==t&&null===u.getVAO(t)&&(t=u.createVAO(t)),s=!0,o.vao=t,U((function(e){var r=u.getVAO(t);return r?e.link(r):\"null\"}))}if(\"vao\"in i){s=!0;var e=i.vao;return V(e,(function(t,r){var n=t.invoke(r,e);return r.def(t.shared.vao+\".getVAO(\"+n+\")\")}))}return null}(),c=!1,h=function(){if(\"elements\"in n){var t=n.elements;if(o.elements=t,F(t)){var e=o.elements=a.create(t,!0);t=a.getElements(e),c=!0}else t&&(t=a.getElements(t),c=!0);return e=U((function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null})),e.value=t,e}if(\"elements\"in i){c=!0;var r=i.elements;return V(r,(function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");return n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\"),e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o}))}return s?new N(l.thisDep,l.contextDep,l.propDep,(function(t,e){return e.def(t.shared.vao+\".currentVAO?\"+t.shared.elements+\".getElements(\"+t.shared.vao+\".currentVAO.elements):null\")})):null}(),f=r(\"offset\",!0),p=function(){if(\"primitive\"in n){var t=n.primitive;return o.primitive=t,U((function(e,r){return st[t]}))}if(\"primitive\"in i){var e=i.primitive;return V(e,(function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")}))}return c?j(h)?h.value?U((function(t,e){return e.def(t.ELEMENTS,\".primType\")})):U((function(){return 4})):new N(h.thisDep,h.contextDep,h.propDep,(function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)})):s?new N(l.thisDep,l.contextDep,l.propDep,(function(t,e){return e.def(t.shared.vao+\".currentVAO?\"+t.shared.vao+\".currentVAO.primitive:4\")})):null}(),d=function(){if(\"count\"in n){var t=0|n.count;return o.count=t,U((function(){return t}))}if(\"count\"in i){var e=i.count;return V(e,(function(t,r){return t.invoke(r,e)}))}return c?j(h)?h?f?new N(f.thisDep,f.contextDep,f.propDep,(function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)})):U((function(t,e){return e.def(t.ELEMENTS,\".vertCount\")})):U((function(){return-1})):new N(h.thisDep||f.thisDep,h.contextDep||f.contextDep,h.propDep||f.propDep,(function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")})):s?new N(l.thisDep,l.contextDep,l.propDep,(function(t,e){return e.def(t.shared.vao,\".currentVAO?\",t.shared.vao,\".currentVAO.count:-1\")})):null}(),m=r(\"instances\",!1);return{elements:h,primitive:p,count:d,instances:m,offset:f,vao:l,vaoActive:s,elementsActive:c,static:o}}function A(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach((function(t){var r=n[t],a=e.id(t),s=new J;if(F(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:St.forEach((function(t,e){e<l.length&&(s[t]=l[e])}))}else{var c=F(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=rt[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=U((function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach((function(t){n[t]=s[t]})),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n}))})),Object.keys(a).forEach((function(t){var e=a[t];o[t]=V(e,(function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=t.constants,s=a.isBufferArgs,l=(a=a.buffer,{isStream:r.def(!1)}),c=new J;c.state=1,Object.keys(c).forEach((function(t){l[t]=r.def(\"\"+c[t])}));var u=l.buffer,h=l.type;return r(\"if(\",s,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",a,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[St[0]],\"=\",i,\".constant;\",St.slice(1).map((function(t){return l[t]})).join(\"=\"),\"=0;\",\"}else{\",St.map((function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"})).join(\"\"),\"}}else{\",\"if(\",s,\"(\",i,\".buffer)){\",u,\"=\",a,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",o.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",a,\".destroyStream(\",u,\");\",\"}\"),l}))})),o}function M(t,e,n,i,a){function s(t){var e=c[t];e&&(f[t]=e)}var l=function(t,e){if(\"string\"==typeof(r=t.static).frag&&\"string\"==typeof r.vert){if(0<Object.keys(e.dynamic).length)return null;var r=e.static,n=Object.keys(r);if(0<n.length&&\"number\"==typeof r[n[0]]){for(var i=[],a=0;a<n.length;++a)i.push([0|r[n[a]],n[a]]);return i}}return null}(t,e),c=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new N(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,(function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]}))}if(t in a){var c=a[t];return t=V(c,(function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]})),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new N(e.thisDep,e.contextDep,e.propDep,(function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]})):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new N(t.thisDep,t.contextDep,t.propDep,(function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r}))}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,d=w(t)),h=k(t),f=function(t,e){var r=t.static,n=t.dynamic,i={};return at.forEach((function(t){function e(e,o){if(t in r){var s=e(r[t]);i[a]=U((function(){return s}))}else if(t in n){var l=n[t];i[a]=V(l,(function(t,e){return o(t,e,t.invoke(e,l))}))}}var a=y(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":case\"lineWidth\":return e((function(t){return t}),(function(t,e,r){return r}));case\"depth.func\":return e((function(t){return Lt[t]}),(function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")}));case\"depth.range\":return e((function(t){return t}),(function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]}));case\"blend.func\":return e((function(t){return[Ct[\"srcRGB\"in t?t.srcRGB:t.src],Ct[\"dstRGB\"in t?t.dstRGB:t.dst],Ct[\"srcAlpha\"in t?t.srcAlpha:t.src],Ct[\"dstAlpha\"in t?t.dstAlpha:t.dst]]}),(function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]}));case\"blend.equation\":return e((function(t){return\"string\"==typeof t?[K[t],K[t]]:\"object\"==typeof t?[K[t.rgb],K[t.alpha]]:void 0}),(function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]}));case\"blend.color\":return e((function(t){return o(4,(function(e){return+t[e]}))}),(function(t,e,r){return o(4,(function(t){return e.def(\"+\",r,\"[\",t,\"]\")}))}));case\"stencil.mask\":return e((function(t){return 0|t}),(function(t,e,r){return e.def(r,\"|0\")}));case\"stencil.func\":return e((function(t){return[Lt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]}),(function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]}));case\"stencil.opFront\":case\"stencil.opBack\":return e((function(e){return[\"stencil.opBack\"===t?1029:1028,It[e.fail||\"keep\"],It[e.zfail||\"keep\"],It[e.zpass||\"keep\"]]}),(function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]}));case\"polygonOffset.offset\":return e((function(t){return[0|t.factor,0|t.units]}),(function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]}));case\"cull.face\":return e((function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e}),(function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)}));case\"frontFace\":return e((function(t){return Pt[t]}),(function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')}));case\"colorMask\":return e((function(t){return t.map((function(t){return!!t}))}),(function(t,e,r){return o(4,(function(t){return\"!!\"+r+\"[\"+t+\"]\"}))}));case\"sample.coverage\":return e((function(t){return[\"value\"in t?t.value:1,!!t.invert]}),(function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]}))}})),i}(t),p=T(t,0,l);s(\"viewport\"),s(y(\"scissor.box\"));var d,m=0<Object.keys(f).length;if((d={framebuffer:d,draw:h,shader:p,state:f,dirty:m,scopeVAO:null,drawVAO:null,useVAO:!1,attributes:{}}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=U((function(t,e){return n}))).enable=n}else if(\"profile\"in t){var i=t.profile;e=V(i,(function(t,e){return t.invoke(e,i)}))}return e}(t),d.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach((function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=U((function(){return n}));else if(\"function\"==typeof n){var a=n._reglType;\"texture2d\"===a||\"textureCube\"===a?e=U((function(t){return t.link(n)})):\"framebuffer\"!==a&&\"framebufferCube\"!==a||(e=U((function(t){return t.link(n.color[0])})))}else v(n)&&(e=U((function(t){return t.global.def(\"[\",o(n.length,(function(t){return n[t]})),\"]\")})));e.value=n,i[t]=e})),Object.keys(n).forEach((function(t){var e=n[t];i[t]=V(e,(function(t,r){return t.invoke(r,e)}))})),i}(n),d.drawVAO=d.scopeVAO=h.vao,!d.drawVAO&&p.program&&!l&&r.angle_instanced_arrays&&h.static.elements){var g=!0;if(t=p.program.attributes.map((function(t){return t=e.static[t],g=g&&!!t,t})),g&&0<t.length){var x=u.getVAO(u.createVAO({attributes:t,elements:h.static.elements}));d.drawVAO=new N(null,null,null,(function(t,e){return t.link(x)})),d.useVAO=!0}}return l?d.useVAO=!0:d.attributes=A(e),d.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach((function(t){var r=e[t];n[t]=U((function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)}))})),Object.keys(r).forEach((function(t){var e=r[t];n[t]=V(e,(function(t,r){return t.invoke(r,e)}))})),n}(i),d}function S(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach((function(a){e.save(n,\".\"+a);var o=r[a].append(t,e);Array.isArray(o)?i(n,\".\",a,\"=[\",o.join(),\"];\"):i(n,\".\",a,\"=\",o,\";\")})),e(i)}function E(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;tt&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),tt&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),tt&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function C(t,e,r){var n=t.shared,i=n.gl,a=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");at.forEach((function(e){var n,h;if(!((e=y(e))in r.state))if(e in s){n=s[e],h=a[e];var f=o(nt[e].length,(function(t){return u.def(n,\"[\",t,\"]\")}));u(t.cond(f.map((function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"})).join(\"||\")).then(i,\".\",lt[e],\"(\",f,\");\",f.map((function(t,e){return h+\"[\"+e+\"]=\"+t})).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in ot?f(t.cond(n).then(i,\".enable(\",ot[e],\");\").else(i,\".disable(\",ot[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",lt[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")})),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function L(t,e,r,n){var i,a=t.shared,o=t.current,s=a.current,l=a.gl;B(Object.keys(r)).forEach((function(a){var c=r[a];if(!n||n(c)){var u=c.append(t,e);if(ot[a]){var h=ot[a];j(c)?(i=t.link(u,{stable:!0}),e(t.cond(i).then(l,\".enable(\",h,\");\").else(l,\".disable(\",h,\");\")),e(s,\".\",a,\"=\",i,\";\")):(e(t.cond(u).then(l,\".enable(\",h,\");\").else(l,\".disable(\",h,\");\")),e(s,\".\",a,\"=\",u,\";\"))}else if(v(u)){var f=o[a];e(l,\".\",lt[a],\"(\",u,\");\",u.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\")}else j(c)?(i=t.link(u,{stable:!0}),e(l,\".\",lt[a],\"(\",i,\");\",s,\".\",a,\"=\",i,\";\")):e(l,\".\",lt[a],\"(\",u,\");\",s,\".\",a,\"=\",u,\";\")}}))}function I(t,e){Q&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function P(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",m,\".getNumPendingQueries();\"):t(m,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(m,\".pushScopeStats(\",u,\",\",m,\".getNumPendingQueries(),\",f,\");\"):t(m,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,m=h.timer;if(r=r.profile){if(j(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function z(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map((function(t){return u+\".\"+t+\"!==\"+i[t]})).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map((function(t){return u+\".\"+t+\"=\"+i[t]+\";\"})).join(\"\"),\"}\"),Q&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",u,\".buffer=null;\",\"}if(\",St.map((function(t,e){return u+\".\"+t+\"!==\"+f[e]})).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",St.map((function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"})).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach((function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(zt))return;var c=t.scopeAttrib(s);o={},Object.keys(new J).forEach((function(t){o[t]=e.def(c,\".\",t)}))}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)}))}function O(t,r,n,i,a,s){for(var l,c=t.shared,u=c.gl,h=0;h<i.length;++h){var f,p=(g=i[h]).name,d=g.info.type,m=n.uniforms[p],g=t.link(g)+\".location\";if(m){if(!a(m))continue;if(j(m)){if(p=m.value,35678===d||35680===d)r(u,\".uniform1i(\",g,\",\",(d=t.link(p._texture||p.color[0]._texture))+\".bind());\"),r.exit(d,\".unbind();\");else if(35674===d||35675===d||35676===d)m=2,35675===d?m=3:35676===d&&(m=4),r(u,\".uniformMatrix\",m,\"fv(\",g,\",false,\",p=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(p)+\"])\"),\");\");else{switch(d){case 5126:l=\"1f\";break;case 35664:l=\"2f\";break;case 35665:l=\"3f\";break;case 35666:l=\"4f\";break;case 35670:case 5124:l=\"1i\";break;case 35671:case 35667:l=\"2i\";break;case 35672:case 35668:l=\"3i\";break;case 35673:case 35669:l=\"4i\"}r(u,\".uniform\",l,\"(\",g,\",\",v(p)?Array.prototype.slice.call(p):p,\");\")}continue}f=m.append(t,r)}else{if(!a(zt))continue;f=r.def(c.uniforms,\"[\",e.id(p),\"]\")}switch(35678===d?r(\"if(\",f,\"&&\",f,'._reglType===\"framebuffer\"){',f,\"=\",f,\".color[0];\",\"}\"):35680===d&&r(\"if(\",f,\"&&\",f,'._reglType===\"framebufferCube\"){',f,\"=\",f,\".color[0];\",\"}\"),p=1,d){case 35678:case 35680:d=r.def(f,\"._texture\"),r(u,\".uniform1i(\",g,\",\",d,\".bind());\"),r.exit(d,\".unbind();\");continue;case 5124:case 35670:l=\"1i\";break;case 35667:case 35671:l=\"2i\",p=2;break;case 35668:case 35672:l=\"3i\",p=3;break;case 35669:case 35673:l=\"4i\",p=4;break;case 5126:l=\"1f\";break;case 35664:l=\"2f\",p=2;break;case 35665:l=\"3f\",p=3;break;case 35666:l=\"4f\",p=4;break;case 35674:l=\"Matrix2fv\";break;case 35675:l=\"Matrix3fv\";break;case 35676:l=\"Matrix4fv\"}if(\"M\"===l.charAt(0)){r(u,\".uniform\",l,\"(\",g,\",\"),g=Math.pow(d-35674+2,2);var y=t.global.def(\"new Float32Array(\",g,\")\");Array.isArray(f)?r(\"false,(\",o(g,(function(t){return y+\"[\"+t+\"]=\"+f[t]})),\",\",y,\")\"):r(\"false,(Array.isArray(\",f,\")||\",f,\" instanceof Float32Array)?\",f,\":(\",o(g,(function(t){return y+\"[\"+t+\"]=\"+f+\"[\"+t+\"]\"})),\",\",y,\")\"),r(\");\")}else{if(1<p){d=[];var x=[];for(m=0;m<p;++m)Array.isArray(f)?x.push(f[m]):x.push(r.def(f+\"[\"+m+\"]\")),s&&d.push(r.def());s&&r(\"if(!\",t.batchId,\"||\",d.map((function(t,e){return t+\"!==\"+x[e]})).join(\"||\"),\"){\",d.map((function(t,e){return t+\"=\"+x[e]+\";\"})).join(\"\")),r(u,\".uniform\",l,\"(\",g,\",\",x.join(\",\"),\");\")}else s&&(d=r.def(),r(\"if(!\",t.batchId,\"||\",d,\"!==\",f,\"){\",d,\"=\",f,\";\")),r(u,\".uniform\",l,\"(\",g,\",\",f,\");\");s&&r(\"}\")}}}function D(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,g,y,m+\"<<((\"+y+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,m,g,s],\");\")}p&&\"null\"!==p?v?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,g,y,m+\"<<((\"+y+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,m,g]+\");\")}p&&\"null\"!==p?v?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a),f.elementsActive&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\")):(i=a.def(),a(i,\"=\",h,\".\",\"elements\",\";\",\"if(\",i,\"){\",u,\".bindBuffer(\",34963,\",\",i,\".buffer.buffer);}\",\"else if(\",c.vao,\".currentVAO){\",i,\"=\",t.shared.elements+\".getElements(\"+c.vao,\".currentVAO.elements);\",et?\"\":\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\",\"}\")),i}(),d=i(\"primitive\"),m=i(\"offset\"),g=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof g){if(0===g)return}else r(\"if(\",g,\"){\"),r.exit(\"}\");Q&&(s=i(\"instances\"),l=t.instancing);var y=p+\".type\",v=f.elements&&j(f.elements)&&!f.vaoActive;Q&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),Q&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){I(t,e),r.useVAO?r.drawVAO?e(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,e),\");\"):e(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(e(t.shared.vao,\".setVAO(null);\"),z(t,e,r,n.attributes,(function(){return!0}))),O(t,e,r,n.uniforms,(function(){return!0}),!1),D(t,e,e,r)}function Z(t,e,r,n){function i(){return!0}t.batchId=\"a1\",I(t,e),z(t,e,r,n.attributes,i),O(t,e,r,n.uniforms,i,!1),D(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}I(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&S(t,u,r.context),r.needsFramebuffer&&E(t,u,r.framebuffer),L(t,u,r.state,i),r.profile&&i(r.profile)&&P(t,u,r,!1,!0),n?(r.useVAO?r.drawVAO?i(r.drawVAO)?u(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,u),\");\"):c(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,c),\");\"):c(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(c(t.shared.vao,\".setVAO(null);\"),z(t,c,r,n.attributes,a),z(t,u,r,n.attributes,i)),O(t,c,r,n.uniforms,a,!1),O(t,u,r,n.uniforms,i,!0),D(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link((function(e){return q(Z,t,r,e,2)})),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function X(t,r){function n(e){var n=r.shader[e];n&&(n=n.append(t,i),isNaN(n)?i.set(a.shader,\".\"+e,n):i.set(a.shader,\".\"+e,t.link(n,{stable:!0})))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;if(S(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),B(Object.keys(r.state)).forEach((function(e){var n=r.state[e],o=n.append(t,i);v(o)?o.forEach((function(r,n){isNaN(r)?i.set(t.next[e],\"[\"+n+\"]\",r):i.set(t.next[e],\"[\"+n+\"]\",t.link(r,{stable:!0}))})):j(n)?i.set(a.next,\".\"+e,t.link(o,{stable:!0})):i.set(a.next,\".\"+e,o)})),P(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach((function(e){var n=r.draw[e];n&&(n=n.append(t,i),isNaN(n)?i.set(a.draw,\".\"+e,n):i.set(a.draw,\".\"+e,t.link(n),{stable:!0}))})),Object.keys(r.uniforms).forEach((function(n){var o=r.uniforms[n].append(t,i);Array.isArray(o)&&(o=\"[\"+o.map((function(e){return isNaN(e)?e:t.link(e,{stable:!0})}))+\"]\"),i.set(a.uniforms,\"[\"+t.link(e.id(n),{stable:!0})+\"]\",o)})),Object.keys(r.attributes).forEach((function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new J).forEach((function(t){i.set(a,\".\"+t,n[t])}))})),r.scopeVAO){var s=r.scopeVAO.append(t,i);isNaN(s)?i.set(a.vao,\".targetVAO\",s):i.set(a.vao,\".targetVAO\",t.link(s,{stable:!0}))}n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function $(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(W.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach((function(e){var r=n[e];if(W.isDynamic(r))\"function\"==typeof r&&(r=n[e]=W.unbox(r)),e=V(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}})),e.dynamic[r]=new W.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach((function(r){var i=n[r];W.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))}))}}),delete e.static[r]}}var J=u.Record,K={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(K.min=32775,K.max=32776);var Q=r.angle_instanced_arrays,tt=r.webgl_draw_buffers,et=r.oes_vertex_array_object,nt={dirty:!0,profile:g.profile},it={},at=[],ot={},lt={};x(\"dither\",3024),x(\"blend.enable\",3042),_(\"blend.color\",\"blendColor\",[0,0,0,0]),_(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),_(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),x(\"depth.enable\",2929,!0),_(\"depth.func\",\"depthFunc\",513),_(\"depth.range\",\"depthRange\",[0,1]),_(\"depth.mask\",\"depthMask\",!0),_(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),x(\"cull.enable\",2884),_(\"cull.face\",\"cullFace\",1029),_(\"frontFace\",\"frontFace\",2305),_(\"lineWidth\",\"lineWidth\",1),x(\"polygonOffset.enable\",32823),_(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),x(\"sample.alpha\",32926),x(\"sample.enable\",32928),_(\"sample.coverage\",\"sampleCoverage\",[1,!1]),x(\"stencil.enable\",2960),_(\"stencil.mask\",\"stencilMask\",-1),_(\"stencil.func\",\"stencilFunc\",[519,0,-1]),_(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),_(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),x(\"scissor.enable\",3089),_(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),_(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ct={gl:t,context:p,strings:e,next:it,current:nt,draw:f,elements:a,buffer:i,shader:h,attributes:u.state,vao:u,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:F},ut={primTypes:st,compareFuncs:Lt,blendFuncs:Ct,blendEquations:K,stencilOps:It,glTypes:rt,orientationType:Pt};tt&&(ut.backBuffer=[1029],ut.drawBuffer=o(n.maxDrawbuffers,(function(t){return 0===t?[0]:o(t,(function(t){return 36064+t}))})));var ht=0;return{next:it,current:nt,procs:function(){var t=b(),e=t.proc(\"poll\"),i=t.proc(\"refresh\"),a=t.block();e(a),i(a);var s,l=(h=t.shared).gl,c=h.next,u=h.current;a(u,\".dirty=false;\"),E(t,e),E(t,i,null,!0),Q&&(s=t.link(Q)),r.oes_vertex_array_object&&i(t.link(r.oes_vertex_array_object),\".bindVertexArrayOES(null);\");var h=i.def(h.attributes),f=i.def(0),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(i);\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(i,\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(i);\",l,\".vertexAttrib4f(i,\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\");var d=t.link(n.maxAttributes,{stable:!0});return i(\"for(var i=0;i<\",d,\";++i){\",f,\"=\",h,\"[i];\",p,\"}\"),Q&&i(\"for(var i=0;i<\",d,\";++i){\",s,\".vertexAttribDivisorANGLE(i,\",h,\"[i].divisor);\",\"}\"),i(t.shared.vao,\".currentVAO=null;\",t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"),Object.keys(ot).forEach((function(r){var n=ot[r],o=a.def(c,\".\",r),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",n,\")}else{\",l,\".disable(\",n,\")}\",u,\".\",r,\"=\",o,\";\"),i(s),e(\"if(\",o,\"!==\",u,\".\",r,\"){\",s,\"}\")})),Object.keys(lt).forEach((function(r){var n,s,h=lt[r],f=nt[r],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,n=t.global.def(c,\".\",r),s=t.global.def(u,\".\",r),p(o(h,(function(t){return n+\"[\"+t+\"]\"})),\");\",o(h,(function(t){return s+\"[\"+t+\"]=\"+n+\"[\"+t+\"];\"})).join(\"\")),e(\"if(\",o(h,(function(t){return n+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"})).join(\"||\"),\"){\",p,\"}\")):(n=a.def(c,\".\",r),s=a.def(u,\".\",r),p(n,\");\",u,\".\",r,\"=\",n,\";\"),e(\"if(\",n,\"!==\",s,\"){\",p,\"}\")),i(p)})),t.compile()}(),compile:function(t,e,r,n,i){var a=b();a.stats=a.link(i),Object.keys(e.static).forEach((function(t){$(a,e,t)})),Et.forEach((function(e){$(a,t,e)}));var o=M(t,e,r,n);return o.shader.program&&(o.shader.program.attributes.sort((function(t,e){return t.name<e.name?-1:1})),o.shader.program.uniforms.sort((function(t,e){return t.name<e.name?-1:1}))),function(t,e){var r=t.proc(\"draw\",1);I(t,r),S(t,r,e.context),E(t,r,e.framebuffer),C(t,r,e),L(t,r,e.state),P(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{r(t.shared.vao,\".setVAO(null);\");var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link((function(r){return q(H,t,e,r,1)})),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\"),t.shared.vao&&r(t.shared.vao,\".setVAO(null);\")}(a,o),X(a,o),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",I(t,n);var i=!1,a=!0;Object.keys(e.context).forEach((function(t){i=i||e.context[t].propDep})),i||(S(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||E(t,n,s)):E(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),C(t,n,e),L(t,n,e.state,(function(t){return!r(t)})),e.profile&&r(e.profile)||P(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{n(t.shared.vao,\".setVAO(null);\");var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link((function(r){return q(Y,t,e,r,2)})),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\"),t.shared.vao&&n(t.shared.vao,\".setVAO(null);\")}(a,o),G(a.compile(),{destroy:function(){o.shader.program.destroy()}})}}}function H(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var G=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},Z=0,W={DynamicVariable:t,define:function(e,n){return new t(e,r(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function e(r,n){return\"function\"==typeof r?new t(0,r):\"number\"==typeof r||\"boolean\"==typeof r?new t(5,r):Array.isArray(r)?new t(6,r.map((function(t,r){return e(t,n+\"[\"+r+\"]\")}))):r instanceof t?r:void 0},accessor:r},Y={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},X=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},$=l();$.zero=l();var J=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=$.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),$.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=$.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),$.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter((function(t){return!!e[t]})),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},K=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},Q=function(t){return Object.keys(t).map((function(e){return t[e]}))},tt={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||$.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:u(t,e[0],e[1],e[2],r,0);break;default:h(t,e,0,r,0)}return r}},et={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},rt={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},nt={dynamic:35048,stream:35040,static:35044},it=tt.flatten,at=tt.shape,ot=[];ot[5120]=1,ot[5122]=2,ot[5124]=4,ot[5121]=1,ot[5123]=2,ot[5125]=4,ot[5126]=4;var st={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},lt=new Float32Array(1),ct=new Uint32Array(lt.buffer),ut=[9984,9986,9985,9987],ht=[0,6409,6410,6407,6408],ft={};ft[6409]=ft[6406]=ft[6402]=1,ft[34041]=ft[6410]=2,ft[6407]=ft[35904]=3,ft[6408]=ft[35906]=4;var pt=x(\"HTMLCanvasElement\"),dt=x(\"OffscreenCanvas\"),mt=x(\"CanvasRenderingContext2D\"),gt=x(\"ImageBitmap\"),yt=x(\"HTMLImageElement\"),vt=x(\"HTMLVideoElement\"),xt=Object.keys(et).concat([pt,dt,mt,gt,yt,vt]),_t=[];_t[5121]=1,_t[5126]=4,_t[36193]=2,_t[5123]=2,_t[5125]=4;var bt=[];bt[32854]=2,bt[32855]=2,bt[36194]=2,bt[34041]=4,bt[33776]=.5,bt[33777]=.5,bt[33778]=1,bt[33779]=1,bt[35986]=.5,bt[35987]=1,bt[34798]=1,bt[35840]=.5,bt[35841]=.25,bt[35842]=.5,bt[35843]=.25,bt[36196]=.5;var wt=[];wt[32854]=2,wt[32855]=2,wt[36194]=2,wt[33189]=2,wt[36168]=1,wt[34041]=4,wt[35907]=4,wt[34836]=16,wt[34842]=8,wt[34843]=6;var Tt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach((function(t){l[s[t]]=t}));var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=wt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height||(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=wt[c.format]*c.width*c.height)),o},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){Q(u).forEach(o)},restore:function(){Q(u).forEach((function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)})),t.bindRenderbuffer(36161,null)}}},kt=[];kt[6408]=4,kt[6407]=3;var At=[];At[5121]=1,At[5126]=4,At[36193]=2;var Mt=[1116352408,1899447441,-1245643825,-373957723,961987163,1508970993,-1841331548,-1424204075,-670586216,310598401,607225278,1426881987,1925078388,-2132889090,-1680079193,-1046744716,-459576895,-272742522,264347078,604807628,770255983,1249150122,1555081692,1996064986,-1740746414,-1473132947,-1341970488,-1084653625,-958395405,-710438585,113926993,338241895,666307205,773529912,1294757372,1396182291,1695183700,1986661051,-2117940946,-1838011259,-1564481375,-1474664885,-1035236496,-949202525,-778901479,-694614492,-200395387,275423344,430227734,506948616,659060556,883997877,958139571,1322822218,1537002063,1747873779,1955562222,2024104815,-2067236844,-1933114872,-1866530822,-1538233109,-1090935817,-965641998],St=[\"x\",\"y\",\"z\",\"w\"],Et=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),Ct={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},Lt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},It={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},Pt={cw:2304,ccw:2305},zt=new N(!1,!1,!1,(function(){}));return function(t){function e(){if(0===$.length)T&&T.update(),et=null;else{et=Y.next(e),h();for(var t=$.length-1;0<=t;--t){var r=$[t];r&&r(P,null,0)}d.flush(),T&&T.update()}}function r(){!et&&0<$.length&&(et=Y.next(e))}function n(){et&&(Y.cancel(e),et=null)}function i(t){t.preventDefault(),n(),K.forEach((function(t){t()}))}function o(t){d.getError(),v.restore(),F.restore(),O.restore(),B.restore(),N.restore(),j.restore(),R.restore(),T&&T.restore(),U.procs.refresh(),r(),Q.forEach((function(t){t()}))}function s(t){function e(t,e){var r={},n={};return Object.keys(t).forEach((function(i){var a=t[i];if(W.isDynamic(a))n[i]=W.unbox(a,i);else{if(e&&Array.isArray(a))for(var o=0;o<a.length;++o)if(W.isDynamic(a[o]))return void(n[i]=W.unbox(a,i));r[i]=a}})),{dynamic:n,static:r}}var r=e(t.context||{},!0),n=e(t.uniforms||{},!0),i=e(t.attributes||{},!1);t=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach((function(n){r[t+\".\"+n]=e[n]}))}}var r=G({},t);return delete r.uniforms,delete r.attributes,delete r.context,delete r.vao,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),\"vao\"in t&&(r.vao=t.vao),r}(t),!1);var a={gpuTime:0,cpuTime:0,count:0},o=U.compile(t,i,n,r,a),s=o.draw,l=o.batch,c=o.scope,u=[];return G((function(t,e){var r;if(\"function\"==typeof t)return c.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)c.call(this,null,e,r);else{if(!Array.isArray(t))return c.call(this,t,e,0);for(r=0;r<t.length;++r)c.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return l.call(this,function(t){for(;u.length<t;)u.push(null);return u}(0|t),0|t)}else{if(!Array.isArray(t))return s.call(this,t);if(t.length)return l.call(this,t,t.length)}}),{stats:a,destroy:function(){o.destroy()}})}function l(t,e){var r=0;U.procs.poll();var n=e.color;n&&(d.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(d.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(d.clearStencil(0|e.stencil),r|=1024),d.clear(r)}function c(t){return $.push(t),r(),{cancel:function(){var e=H($,t);$[e]=function t(){var e=H($,t);$[e]=$[$.length-1],--$.length,0>=$.length&&n()}}}}function u(){var t=V.viewport,e=V.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=d.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=d.drawingBufferHeight}function h(){P.tick+=1,P.time=p(),u(),U.procs.poll()}function f(){B.refresh(),u(),U.procs.refresh(),T&&T.update()}function p(){return(X()-k)/1e3}if(!(t=a(t)))return null;var d=t.gl,y=d.getContextAttributes();d.isContextLost();var v=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach((function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)}))}}}(d,t);if(!v)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),_={vaoCount:0,bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},b=t.cachedCode||{},w=v.extensions,T=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,w),k=X(),A=d.drawingBufferWidth,E=d.drawingBufferHeight,P={tick:0,time:0,viewportWidth:A,viewportHeight:E,framebufferWidth:A,framebufferHeight:E,drawingBufferWidth:A,drawingBufferHeight:E,pixelRatio:t.pixelRatio},z=(A={elements:null,primitive:4,count:-1,offset:0,instances:-1},J(d,w)),O=m(d,_,t,(function(t){return R.destroyBuffer(t)})),D=g(d,w,O,_),R=C(d,w,z,_,O,D,A),F=L(d,x,_,t),B=M(d,w,z,(function(){U.procs.poll()}),P,_,t),N=Tt(d,w,0,_,t),j=S(d,w,z,B,N,_),U=q(d,x,w,z,O,D,0,j,{},R,F,A,P,T,b,t),V=(x=I(d,j,U.procs.poll,P),U.next),Z=d.canvas,$=[],K=[],Q=[],tt=[t.onDestroy],et=null;Z&&(Z.addEventListener(\"webglcontextlost\",i,!1),Z.addEventListener(\"webglcontextrestored\",o,!1));var rt=j.setFBO=s({framebuffer:W.define.call(null,1,\"framebuffer\")});return f(),y=G(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)rt(G({framebuffer:t.framebuffer.faces[e]},t),l);else rt(t,l);else l(0,t)},prop:W.define.bind(null,1),context:W.define.bind(null,2),this:W.define.bind(null,3),draw:s({}),buffer:function(t){return O.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:B.create2D,cube:B.createCube,renderbuffer:N.create,framebuffer:j.create,framebufferCube:j.createCube,vao:R.createVAO,attributes:y,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=K;break;case\"restore\":r=Q;break;case\"destroy\":r=tt}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:z,hasExtension:function(t){return 0<=z.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){$.length=0,n(),Z&&(Z.removeEventListener(\"webglcontextlost\",i),Z.removeEventListener(\"webglcontextrestored\",o)),F.clear(),j.clear(),N.clear(),R.clear(),B.clear(),D.clear(),O.clear(),T&&T.clear(),tt.forEach((function(t){t()}))},_gl:d,_refresh:f,poll:function(){h(),T&&T.update()},now:p,stats:_,getCachedCode:function(){return b},preloadCachedCode:function(t){Object.entries(t).forEach((function(t){b[t[0]]=t[1]}))}}),t.onDone(null,y),y}}()},41041:function(t,e,r){var n=r(45708),i=n.Buffer;function a(t,e){for(var r in t)e[r]=t[r]}function o(t,e,r){return i(t,e,r)}i.from&&i.alloc&&i.allocUnsafe&&i.allocUnsafeSlow?t.exports=n:(a(n,e),e.Buffer=o),o.prototype=Object.create(i.prototype),a(i,o),o.from=function(t,e,r){if(\"number\"==typeof t)throw new TypeError(\"Argument must not be a number\");return i(t,e,r)},o.alloc=function(t,e,r){if(\"number\"!=typeof t)throw new TypeError(\"Argument must be a number\");var n=i(t);return void 0!==e?\"string\"==typeof r?n.fill(e,r):n.fill(e):n.fill(0),n},o.allocUnsafe=function(t){if(\"number\"!=typeof t)throw new TypeError(\"Argument must be a number\");return i(t)},o.allocUnsafeSlow=function(t){if(\"number\"!=typeof t)throw new TypeError(\"Argument must be a number\");return n.SlowBuffer(t)}},73285:function(t,e,r){\"use strict\";var n=r(71129),i=r(70973),a=r(74268)(),o=r(52991),s=r(48631),l=n(\"%Math.floor%\");t.exports=function(t,e){if(\"function\"!=typeof t)throw new s(\"`fn` is not a function\");if(\"number\"!=typeof e||e<0||e>4294967295||l(e)!==e)throw new s(\"`length` must be a positive 32-bit integer\");var r=arguments.length>2&&!!arguments[2],n=!0,c=!0;if(\"length\"in t&&o){var u=o(t,\"length\");u&&!u.configurable&&(n=!1),u&&!u.writable&&(c=!1)}return(n||c||!r)&&(a?i(t,\"length\",e,!0,!0):i(t,\"length\",e)),t}},90386:function(t,e,r){t.exports=i;var n=r(7683).EventEmitter;function i(){n.call(this)}r(28062)(i,n),i.Readable=r(44639),i.Writable=r(84627),i.Duplex=r(71977),i.Transform=r(40255),i.PassThrough=r(28765),i.finished=r(37165),i.pipeline=r(6772),i.Stream=i,i.prototype.pipe=function(t,e){var r=this;function i(e){t.writable&&!1===t.write(e)&&r.pause&&r.pause()}function a(){r.readable&&r.resume&&r.resume()}r.on(\"data\",i),t.on(\"drain\",a),t._isStdio||e&&!1===e.end||(r.on(\"end\",s),r.on(\"close\",l));var o=!1;function s(){o||(o=!0,t.end())}function l(){o||(o=!0,\"function\"==typeof t.destroy&&t.destroy())}function c(t){if(u(),0===n.listenerCount(this,\"error\"))throw t}function u(){r.removeListener(\"data\",i),t.removeListener(\"drain\",a),r.removeListener(\"end\",s),r.removeListener(\"close\",l),r.removeListener(\"error\",c),t.removeListener(\"error\",c),r.removeListener(\"end\",u),r.removeListener(\"close\",u),t.removeListener(\"close\",u)}return r.on(\"error\",c),t.on(\"error\",c),r.on(\"end\",u),r.on(\"close\",u),t.on(\"close\",u),t.emit(\"pipe\",r),t}},44059:function(t){\"use strict\";var e={};function r(t,r,n){n||(n=Error);var i=function(t){var e,n;function i(e,n,i){return t.call(this,function(t,e,n){return\"string\"==typeof r?r:r(t,e,n)}(e,n,i))||this}return n=t,(e=i).prototype=Object.create(n.prototype),e.prototype.constructor=e,e.__proto__=n,i}(n);i.prototype.name=n.name,i.prototype.code=t,e[t]=i}function n(t,e){if(Array.isArray(t)){var r=t.length;return t=t.map((function(t){return String(t)})),r>2?\"one of \".concat(e,\" \").concat(t.slice(0,r-1).join(\", \"),\", or \")+t[r-1]:2===r?\"one of \".concat(e,\" \").concat(t[0],\" or \").concat(t[1]):\"of \".concat(e,\" \").concat(t[0])}return\"of \".concat(e,\" \").concat(String(t))}r(\"ERR_INVALID_OPT_VALUE\",(function(t,e){return'The value \"'+e+'\" is invalid for option \"'+t+'\"'}),TypeError),r(\"ERR_INVALID_ARG_TYPE\",(function(t,e,r){var i,a,o,s,l;if(\"string\"==typeof e&&(a=\"not \",e.substr(0,4)===a)?(i=\"must not be\",e=e.replace(/^not /,\"\")):i=\"must be\",function(t,e,r){return(void 0===r||r>t.length)&&(r=t.length),t.substring(r-9,r)===e}(t,\" argument\"))o=\"The \".concat(t,\" \").concat(i,\" \").concat(n(e,\"type\"));else{var c=(\"number\"!=typeof l&&(l=0),l+1>(s=t).length||-1===s.indexOf(\".\",l)?\"argument\":\"property\");o='The \"'.concat(t,'\" ').concat(c,\" \").concat(i,\" \").concat(n(e,\"type\"))}return o+\". Received type \".concat(typeof r)}),TypeError),r(\"ERR_STREAM_PUSH_AFTER_EOF\",\"stream.push() after EOF\"),r(\"ERR_METHOD_NOT_IMPLEMENTED\",(function(t){return\"The \"+t+\" method is not implemented\"})),r(\"ERR_STREAM_PREMATURE_CLOSE\",\"Premature close\"),r(\"ERR_STREAM_DESTROYED\",(function(t){return\"Cannot call \"+t+\" after a stream was destroyed\"})),r(\"ERR_MULTIPLE_CALLBACK\",\"Callback called multiple times\"),r(\"ERR_STREAM_CANNOT_PIPE\",\"Cannot pipe, not readable\"),r(\"ERR_STREAM_WRITE_AFTER_END\",\"write after end\"),r(\"ERR_STREAM_NULL_VALUES\",\"May not write null values to stream\",TypeError),r(\"ERR_UNKNOWN_ENCODING\",(function(t){return\"Unknown encoding: \"+t}),TypeError),r(\"ERR_STREAM_UNSHIFT_AFTER_END_EVENT\",\"stream.unshift() after end event\"),t.exports.F=e},71977:function(t,e,r){\"use strict\";var n=r(33282),i=Object.keys||function(t){var e=[];for(var r in t)e.push(r);return e};t.exports=u;var a=r(44639),o=r(84627);r(28062)(u,a);for(var s=i(o.prototype),l=0;l<s.length;l++){var c=s[l];u.prototype[c]||(u.prototype[c]=o.prototype[c])}function u(t){if(!(this instanceof u))return new u(t);a.call(this,t),o.call(this,t),this.allowHalfOpen=!0,t&&(!1===t.readable&&(this.readable=!1),!1===t.writable&&(this.writable=!1),!1===t.allowHalfOpen&&(this.allowHalfOpen=!1,this.once(\"end\",h)))}function h(){this._writableState.ended||n.nextTick(f,this)}function f(t){t.end()}Object.defineProperty(u.prototype,\"writableHighWaterMark\",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),Object.defineProperty(u.prototype,\"writableBuffer\",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(u.prototype,\"writableLength\",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(u.prototype,\"destroyed\",{enumerable:!1,get:function(){return void 0!==this._readableState&&void 0!==this._writableState&&this._readableState.destroyed&&this._writableState.destroyed},set:function(t){void 0!==this._readableState&&void 0!==this._writableState&&(this._readableState.destroyed=t,this._writableState.destroyed=t)}})},28765:function(t,e,r){\"use strict\";t.exports=i;var n=r(40255);function i(t){if(!(this instanceof i))return new i(t);n.call(this,t)}r(28062)(i,n),i.prototype._transform=function(t,e,r){r(null,t)}},44639:function(t,e,r){\"use strict\";var n,i=r(33282);t.exports=A,A.ReadableState=k,r(7683).EventEmitter;var a,o=function(t,e){return t.listeners(e).length},s=r(60032),l=r(45708).Buffer,c=r.g.Uint8Array||function(){},u=r(77199);a=u&&u.debuglog?u.debuglog(\"stream\"):function(){};var h,f,p,d=r(29930),m=r(52023),g=r(31976).getHighWaterMark,y=r(44059).F,v=y.ERR_INVALID_ARG_TYPE,x=y.ERR_STREAM_PUSH_AFTER_EOF,_=y.ERR_METHOD_NOT_IMPLEMENTED,b=y.ERR_STREAM_UNSHIFT_AFTER_END_EVENT;r(28062)(A,s);var w=m.errorOrDestroy,T=[\"error\",\"close\",\"destroy\",\"pause\",\"resume\"];function k(t,e,i){n=n||r(71977),t=t||{},\"boolean\"!=typeof i&&(i=e instanceof n),this.objectMode=!!t.objectMode,i&&(this.objectMode=this.objectMode||!!t.readableObjectMode),this.highWaterMark=g(this,t,\"readableHighWaterMark\",i),this.buffer=new d,this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.paused=!0,this.emitClose=!1!==t.emitClose,this.autoDestroy=!!t.autoDestroy,this.destroyed=!1,this.defaultEncoding=t.defaultEncoding||\"utf8\",this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,t.encoding&&(h||(h=r(54304).I),this.decoder=new h(t.encoding),this.encoding=t.encoding)}function A(t){if(n=n||r(71977),!(this instanceof A))return new A(t);var e=this instanceof n;this._readableState=new k(t,this,e),this.readable=!0,t&&(\"function\"==typeof t.read&&(this._read=t.read),\"function\"==typeof t.destroy&&(this._destroy=t.destroy)),s.call(this)}function M(t,e,r,n,i){a(\"readableAddChunk\",e);var o,s=t._readableState;if(null===e)s.reading=!1,function(t,e){if(a(\"onEofChunk\"),!e.ended){if(e.decoder){var r=e.decoder.end();r&&r.length&&(e.buffer.push(r),e.length+=e.objectMode?1:r.length)}e.ended=!0,e.sync?L(t):(e.needReadable=!1,e.emittedReadable||(e.emittedReadable=!0,I(t)))}}(t,s);else if(i||(o=function(t,e){var r,n;return n=e,l.isBuffer(n)||n instanceof c||\"string\"==typeof e||void 0===e||t.objectMode||(r=new v(\"chunk\",[\"string\",\"Buffer\",\"Uint8Array\"],e)),r}(s,e)),o)w(t,o);else if(s.objectMode||e&&e.length>0)if(\"string\"==typeof e||s.objectMode||Object.getPrototypeOf(e)===l.prototype||(e=function(t){return l.from(t)}(e)),n)s.endEmitted?w(t,new b):S(t,s,e,!0);else if(s.ended)w(t,new x);else{if(s.destroyed)return!1;s.reading=!1,s.decoder&&!r?(e=s.decoder.write(e),s.objectMode||0!==e.length?S(t,s,e,!1):P(t,s)):S(t,s,e,!1)}else n||(s.reading=!1,P(t,s));return!s.ended&&(s.length<s.highWaterMark||0===s.length)}function S(t,e,r,n){e.flowing&&0===e.length&&!e.sync?(e.awaitDrain=0,t.emit(\"data\",r)):(e.length+=e.objectMode?1:r.length,n?e.buffer.unshift(r):e.buffer.push(r),e.needReadable&&L(t)),P(t,e)}Object.defineProperty(A.prototype,\"destroyed\",{enumerable:!1,get:function(){return void 0!==this._readableState&&this._readableState.destroyed},set:function(t){this._readableState&&(this._readableState.destroyed=t)}}),A.prototype.destroy=m.destroy,A.prototype._undestroy=m.undestroy,A.prototype._destroy=function(t,e){e(t)},A.prototype.push=function(t,e){var r,n=this._readableState;return n.objectMode?r=!0:\"string\"==typeof t&&((e=e||n.defaultEncoding)!==n.encoding&&(t=l.from(t,e),e=\"\"),r=!0),M(this,t,e,!1,r)},A.prototype.unshift=function(t){return M(this,t,null,!0,!1)},A.prototype.isPaused=function(){return!1===this._readableState.flowing},A.prototype.setEncoding=function(t){h||(h=r(54304).I);var e=new h(t);this._readableState.decoder=e,this._readableState.encoding=this._readableState.decoder.encoding;for(var n=this._readableState.buffer.head,i=\"\";null!==n;)i+=e.write(n.data),n=n.next;return this._readableState.buffer.clear(),\"\"!==i&&this._readableState.buffer.push(i),this._readableState.length=i.length,this};var E=1073741824;function C(t,e){return t<=0||0===e.length&&e.ended?0:e.objectMode?1:t!=t?e.flowing&&e.length?e.buffer.head.data.length:e.length:(t>e.highWaterMark&&(e.highWaterMark=function(t){return t>=E?t=E:(t--,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,t|=t>>>16,t++),t}(t)),t<=e.length?t:e.ended?e.length:(e.needReadable=!0,0))}function L(t){var e=t._readableState;a(\"emitReadable\",e.needReadable,e.emittedReadable),e.needReadable=!1,e.emittedReadable||(a(\"emitReadable\",e.flowing),e.emittedReadable=!0,i.nextTick(I,t))}function I(t){var e=t._readableState;a(\"emitReadable_\",e.destroyed,e.length,e.ended),e.destroyed||!e.length&&!e.ended||(t.emit(\"readable\"),e.emittedReadable=!1),e.needReadable=!e.flowing&&!e.ended&&e.length<=e.highWaterMark,F(t)}function P(t,e){e.readingMore||(e.readingMore=!0,i.nextTick(z,t,e))}function z(t,e){for(;!e.reading&&!e.ended&&(e.length<e.highWaterMark||e.flowing&&0===e.length);){var r=e.length;if(a(\"maybeReadMore read 0\"),t.read(0),r===e.length)break}e.readingMore=!1}function O(t){var e=t._readableState;e.readableListening=t.listenerCount(\"readable\")>0,e.resumeScheduled&&!e.paused?e.flowing=!0:t.listenerCount(\"data\")>0&&t.resume()}function D(t){a(\"readable nexttick read 0\"),t.read(0)}function R(t,e){a(\"resume\",e.reading),e.reading||t.read(0),e.resumeScheduled=!1,t.emit(\"resume\"),F(t),e.flowing&&!e.reading&&t.read(0)}function F(t){var e=t._readableState;for(a(\"flow\",e.flowing);e.flowing&&null!==t.read(););}function B(t,e){return 0===e.length?null:(e.objectMode?r=e.buffer.shift():!t||t>=e.length?(r=e.decoder?e.buffer.join(\"\"):1===e.buffer.length?e.buffer.first():e.buffer.concat(e.length),e.buffer.clear()):r=e.buffer.consume(t,e.decoder),r);var r}function N(t){var e=t._readableState;a(\"endReadable\",e.endEmitted),e.endEmitted||(e.ended=!0,i.nextTick(j,e,t))}function j(t,e){if(a(\"endReadableNT\",t.endEmitted,t.length),!t.endEmitted&&0===t.length&&(t.endEmitted=!0,e.readable=!1,e.emit(\"end\"),t.autoDestroy)){var r=e._writableState;(!r||r.autoDestroy&&r.finished)&&e.destroy()}}function U(t,e){for(var r=0,n=t.length;r<n;r++)if(t[r]===e)return r;return-1}A.prototype.read=function(t){a(\"read\",t),t=parseInt(t,10);var e=this._readableState,r=t;if(0!==t&&(e.emittedReadable=!1),0===t&&e.needReadable&&((0!==e.highWaterMark?e.length>=e.highWaterMark:e.length>0)||e.ended))return a(\"read: emitReadable\",e.length,e.ended),0===e.length&&e.ended?N(this):L(this),null;if(0===(t=C(t,e))&&e.ended)return 0===e.length&&N(this),null;var n,i=e.needReadable;return a(\"need readable\",i),(0===e.length||e.length-t<e.highWaterMark)&&a(\"length less than watermark\",i=!0),e.ended||e.reading?a(\"reading or ended\",i=!1):i&&(a(\"do read\"),e.reading=!0,e.sync=!0,0===e.length&&(e.needReadable=!0),this._read(e.highWaterMark),e.sync=!1,e.reading||(t=C(r,e))),null===(n=t>0?B(t,e):null)?(e.needReadable=e.length<=e.highWaterMark,t=0):(e.length-=t,e.awaitDrain=0),0===e.length&&(e.ended||(e.needReadable=!0),r!==t&&e.ended&&N(this)),null!==n&&this.emit(\"data\",n),n},A.prototype._read=function(t){w(this,new _(\"_read()\"))},A.prototype.pipe=function(t,e){var r=this,n=this._readableState;switch(n.pipesCount){case 0:n.pipes=t;break;case 1:n.pipes=[n.pipes,t];break;default:n.pipes.push(t)}n.pipesCount+=1,a(\"pipe count=%d opts=%j\",n.pipesCount,e);var s=e&&!1===e.end||t===i.stdout||t===i.stderr?m:l;function l(){a(\"onend\"),t.end()}n.endEmitted?i.nextTick(s):r.once(\"end\",s),t.on(\"unpipe\",(function e(i,o){a(\"onunpipe\"),i===r&&o&&!1===o.hasUnpiped&&(o.hasUnpiped=!0,a(\"cleanup\"),t.removeListener(\"close\",p),t.removeListener(\"finish\",d),t.removeListener(\"drain\",c),t.removeListener(\"error\",f),t.removeListener(\"unpipe\",e),r.removeListener(\"end\",l),r.removeListener(\"end\",m),r.removeListener(\"data\",h),u=!0,!n.awaitDrain||t._writableState&&!t._writableState.needDrain||c())}));var c=function(t){return function(){var e=t._readableState;a(\"pipeOnDrain\",e.awaitDrain),e.awaitDrain&&e.awaitDrain--,0===e.awaitDrain&&o(t,\"data\")&&(e.flowing=!0,F(t))}}(r);t.on(\"drain\",c);var u=!1;function h(e){a(\"ondata\");var i=t.write(e);a(\"dest.write\",i),!1===i&&((1===n.pipesCount&&n.pipes===t||n.pipesCount>1&&-1!==U(n.pipes,t))&&!u&&(a(\"false write response, pause\",n.awaitDrain),n.awaitDrain++),r.pause())}function f(e){a(\"onerror\",e),m(),t.removeListener(\"error\",f),0===o(t,\"error\")&&w(t,e)}function p(){t.removeListener(\"finish\",d),m()}function d(){a(\"onfinish\"),t.removeListener(\"close\",p),m()}function m(){a(\"unpipe\"),r.unpipe(t)}return r.on(\"data\",h),function(t,e,r){if(\"function\"==typeof t.prependListener)return t.prependListener(e,r);t._events&&t._events[e]?Array.isArray(t._events[e])?t._events[e].unshift(r):t._events[e]=[r,t._events[e]]:t.on(e,r)}(t,\"error\",f),t.once(\"close\",p),t.once(\"finish\",d),t.emit(\"pipe\",r),n.flowing||(a(\"pipe resume\"),r.resume()),t},A.prototype.unpipe=function(t){var e=this._readableState,r={hasUnpiped:!1};if(0===e.pipesCount)return this;if(1===e.pipesCount)return t&&t!==e.pipes||(t||(t=e.pipes),e.pipes=null,e.pipesCount=0,e.flowing=!1,t&&t.emit(\"unpipe\",this,r)),this;if(!t){var n=e.pipes,i=e.pipesCount;e.pipes=null,e.pipesCount=0,e.flowing=!1;for(var a=0;a<i;a++)n[a].emit(\"unpipe\",this,{hasUnpiped:!1});return this}var o=U(e.pipes,t);return-1===o||(e.pipes.splice(o,1),e.pipesCount-=1,1===e.pipesCount&&(e.pipes=e.pipes[0]),t.emit(\"unpipe\",this,r)),this},A.prototype.on=function(t,e){var r=s.prototype.on.call(this,t,e),n=this._readableState;return\"data\"===t?(n.readableListening=this.listenerCount(\"readable\")>0,!1!==n.flowing&&this.resume()):\"readable\"===t&&(n.endEmitted||n.readableListening||(n.readableListening=n.needReadable=!0,n.flowing=!1,n.emittedReadable=!1,a(\"on readable\",n.length,n.reading),n.length?L(this):n.reading||i.nextTick(D,this))),r},A.prototype.addListener=A.prototype.on,A.prototype.removeListener=function(t,e){var r=s.prototype.removeListener.call(this,t,e);return\"readable\"===t&&i.nextTick(O,this),r},A.prototype.removeAllListeners=function(t){var e=s.prototype.removeAllListeners.apply(this,arguments);return\"readable\"!==t&&void 0!==t||i.nextTick(O,this),e},A.prototype.resume=function(){var t=this._readableState;return t.flowing||(a(\"resume\"),t.flowing=!t.readableListening,function(t,e){e.resumeScheduled||(e.resumeScheduled=!0,i.nextTick(R,t,e))}(this,t)),t.paused=!1,this},A.prototype.pause=function(){return a(\"call pause flowing=%j\",this._readableState.flowing),!1!==this._readableState.flowing&&(a(\"pause\"),this._readableState.flowing=!1,this.emit(\"pause\")),this._readableState.paused=!0,this},A.prototype.wrap=function(t){var e=this,r=this._readableState,n=!1;for(var i in t.on(\"end\",(function(){if(a(\"wrapped end\"),r.decoder&&!r.ended){var t=r.decoder.end();t&&t.length&&e.push(t)}e.push(null)})),t.on(\"data\",(function(i){a(\"wrapped data\"),r.decoder&&(i=r.decoder.write(i)),r.objectMode&&null==i||(r.objectMode||i&&i.length)&&(e.push(i)||(n=!0,t.pause()))})),t)void 0===this[i]&&\"function\"==typeof t[i]&&(this[i]=function(e){return function(){return t[e].apply(t,arguments)}}(i));for(var o=0;o<T.length;o++)t.on(T[o],this.emit.bind(this,T[o]));return this._read=function(e){a(\"wrapped _read\",e),n&&(n=!1,t.resume())},this},\"function\"==typeof Symbol&&(A.prototype[Symbol.asyncIterator]=function(){return void 0===f&&(f=r(73726)),f(this)}),Object.defineProperty(A.prototype,\"readableHighWaterMark\",{enumerable:!1,get:function(){return this._readableState.highWaterMark}}),Object.defineProperty(A.prototype,\"readableBuffer\",{enumerable:!1,get:function(){return this._readableState&&this._readableState.buffer}}),Object.defineProperty(A.prototype,\"readableFlowing\",{enumerable:!1,get:function(){return this._readableState.flowing},set:function(t){this._readableState&&(this._readableState.flowing=t)}}),A._fromList=B,Object.defineProperty(A.prototype,\"readableLength\",{enumerable:!1,get:function(){return this._readableState.length}}),\"function\"==typeof Symbol&&(A.from=function(t,e){return void 0===p&&(p=r(37108)),p(A,t,e)})},40255:function(t,e,r){\"use strict\";t.exports=u;var n=r(44059).F,i=n.ERR_METHOD_NOT_IMPLEMENTED,a=n.ERR_MULTIPLE_CALLBACK,o=n.ERR_TRANSFORM_ALREADY_TRANSFORMING,s=n.ERR_TRANSFORM_WITH_LENGTH_0,l=r(71977);function c(t,e){var r=this._transformState;r.transforming=!1;var n=r.writecb;if(null===n)return this.emit(\"error\",new a);r.writechunk=null,r.writecb=null,null!=e&&this.push(e),n(t);var i=this._readableState;i.reading=!1,(i.needReadable||i.length<i.highWaterMark)&&this._read(i.highWaterMark)}function u(t){if(!(this instanceof u))return new u(t);l.call(this,t),this._transformState={afterTransform:c.bind(this),needTransform:!1,transforming:!1,writecb:null,writechunk:null,writeencoding:null},this._readableState.needReadable=!0,this._readableState.sync=!1,t&&(\"function\"==typeof t.transform&&(this._transform=t.transform),\"function\"==typeof t.flush&&(this._flush=t.flush)),this.on(\"prefinish\",h)}function h(){var t=this;\"function\"!=typeof this._flush||this._readableState.destroyed?f(this,null,null):this._flush((function(e,r){f(t,e,r)}))}function f(t,e,r){if(e)return t.emit(\"error\",e);if(null!=r&&t.push(r),t._writableState.length)throw new s;if(t._transformState.transforming)throw new o;return t.push(null)}r(28062)(u,l),u.prototype.push=function(t,e){return this._transformState.needTransform=!1,l.prototype.push.call(this,t,e)},u.prototype._transform=function(t,e,r){r(new i(\"_transform()\"))},u.prototype._write=function(t,e,r){var n=this._transformState;if(n.writecb=r,n.writechunk=t,n.writeencoding=e,!n.transforming){var i=this._readableState;(n.needTransform||i.needReadable||i.length<i.highWaterMark)&&this._read(i.highWaterMark)}},u.prototype._read=function(t){var e=this._transformState;null===e.writechunk||e.transforming?e.needTransform=!0:(e.transforming=!0,this._transform(e.writechunk,e.writeencoding,e.afterTransform))},u.prototype._destroy=function(t,e){l.prototype._destroy.call(this,t,(function(t){e(t)}))}},84627:function(t,e,r){\"use strict\";var n,i=r(33282);function a(t){var e=this;this.next=null,this.entry=null,this.finish=function(){!function(t,e,r){var n=t.entry;for(t.entry=null;n;){var i=n.callback;e.pendingcb--,i(undefined),n=n.next}e.corkedRequestsFree.next=t}(e,t)}}t.exports=A,A.WritableState=k;var o,s={deprecate:r(71103)},l=r(60032),c=r(45708).Buffer,u=r.g.Uint8Array||function(){},h=r(52023),f=r(31976).getHighWaterMark,p=r(44059).F,d=p.ERR_INVALID_ARG_TYPE,m=p.ERR_METHOD_NOT_IMPLEMENTED,g=p.ERR_MULTIPLE_CALLBACK,y=p.ERR_STREAM_CANNOT_PIPE,v=p.ERR_STREAM_DESTROYED,x=p.ERR_STREAM_NULL_VALUES,_=p.ERR_STREAM_WRITE_AFTER_END,b=p.ERR_UNKNOWN_ENCODING,w=h.errorOrDestroy;function T(){}function k(t,e,o){n=n||r(71977),t=t||{},\"boolean\"!=typeof o&&(o=e instanceof n),this.objectMode=!!t.objectMode,o&&(this.objectMode=this.objectMode||!!t.writableObjectMode),this.highWaterMark=f(this,t,\"writableHighWaterMark\",o),this.finalCalled=!1,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1,this.destroyed=!1;var s=!1===t.decodeStrings;this.decodeStrings=!s,this.defaultEncoding=t.defaultEncoding||\"utf8\",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(t){!function(t,e){var r=t._writableState,n=r.sync,a=r.writecb;if(\"function\"!=typeof a)throw new g;if(function(t){t.writing=!1,t.writecb=null,t.length-=t.writelen,t.writelen=0}(r),e)!function(t,e,r,n,a){--e.pendingcb,r?(i.nextTick(a,n),i.nextTick(I,t,e),t._writableState.errorEmitted=!0,w(t,n)):(a(n),t._writableState.errorEmitted=!0,w(t,n),I(t,e))}(t,r,n,e,a);else{var o=C(r)||t.destroyed;o||r.corked||r.bufferProcessing||!r.bufferedRequest||E(t,r),n?i.nextTick(S,t,r,o,a):S(t,r,o,a)}}(e,t)},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.emitClose=!1!==t.emitClose,this.autoDestroy=!!t.autoDestroy,this.bufferedRequestCount=0,this.corkedRequestsFree=new a(this)}function A(t){var e=this instanceof(n=n||r(71977));if(!e&&!o.call(A,this))return new A(t);this._writableState=new k(t,this,e),this.writable=!0,t&&(\"function\"==typeof t.write&&(this._write=t.write),\"function\"==typeof t.writev&&(this._writev=t.writev),\"function\"==typeof t.destroy&&(this._destroy=t.destroy),\"function\"==typeof t.final&&(this._final=t.final)),l.call(this)}function M(t,e,r,n,i,a,o){e.writelen=n,e.writecb=o,e.writing=!0,e.sync=!0,e.destroyed?e.onwrite(new v(\"write\")):r?t._writev(i,e.onwrite):t._write(i,a,e.onwrite),e.sync=!1}function S(t,e,r,n){r||function(t,e){0===e.length&&e.needDrain&&(e.needDrain=!1,t.emit(\"drain\"))}(t,e),e.pendingcb--,n(),I(t,e)}function E(t,e){e.bufferProcessing=!0;var r=e.bufferedRequest;if(t._writev&&r&&r.next){var n=e.bufferedRequestCount,i=new Array(n),o=e.corkedRequestsFree;o.entry=r;for(var s=0,l=!0;r;)i[s]=r,r.isBuf||(l=!1),r=r.next,s+=1;i.allBuffers=l,M(t,e,!0,e.length,i,\"\",o.finish),e.pendingcb++,e.lastBufferedRequest=null,o.next?(e.corkedRequestsFree=o.next,o.next=null):e.corkedRequestsFree=new a(e),e.bufferedRequestCount=0}else{for(;r;){var c=r.chunk,u=r.encoding,h=r.callback;if(M(t,e,!1,e.objectMode?1:c.length,c,u,h),r=r.next,e.bufferedRequestCount--,e.writing)break}null===r&&(e.lastBufferedRequest=null)}e.bufferedRequest=r,e.bufferProcessing=!1}function C(t){return t.ending&&0===t.length&&null===t.bufferedRequest&&!t.finished&&!t.writing}function L(t,e){t._final((function(r){e.pendingcb--,r&&w(t,r),e.prefinished=!0,t.emit(\"prefinish\"),I(t,e)}))}function I(t,e){var r=C(e);if(r&&(function(t,e){e.prefinished||e.finalCalled||(\"function\"!=typeof t._final||e.destroyed?(e.prefinished=!0,t.emit(\"prefinish\")):(e.pendingcb++,e.finalCalled=!0,i.nextTick(L,t,e)))}(t,e),0===e.pendingcb&&(e.finished=!0,t.emit(\"finish\"),e.autoDestroy))){var n=t._readableState;(!n||n.autoDestroy&&n.endEmitted)&&t.destroy()}return r}r(28062)(A,l),k.prototype.getBuffer=function(){for(var t=this.bufferedRequest,e=[];t;)e.push(t),t=t.next;return e},function(){try{Object.defineProperty(k.prototype,\"buffer\",{get:s.deprecate((function(){return this.getBuffer()}),\"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.\",\"DEP0003\")})}catch(t){}}(),\"function\"==typeof Symbol&&Symbol.hasInstance&&\"function\"==typeof Function.prototype[Symbol.hasInstance]?(o=Function.prototype[Symbol.hasInstance],Object.defineProperty(A,Symbol.hasInstance,{value:function(t){return!!o.call(this,t)||this===A&&t&&t._writableState instanceof k}})):o=function(t){return t instanceof this},A.prototype.pipe=function(){w(this,new y)},A.prototype.write=function(t,e,r){var n,a=this._writableState,o=!1,s=!a.objectMode&&(n=t,c.isBuffer(n)||n instanceof u);return s&&!c.isBuffer(t)&&(t=function(t){return c.from(t)}(t)),\"function\"==typeof e&&(r=e,e=null),s?e=\"buffer\":e||(e=a.defaultEncoding),\"function\"!=typeof r&&(r=T),a.ending?function(t,e){var r=new _;w(t,r),i.nextTick(e,r)}(this,r):(s||function(t,e,r,n){var a;return null===r?a=new x:\"string\"==typeof r||e.objectMode||(a=new d(\"chunk\",[\"string\",\"Buffer\"],r)),!a||(w(t,a),i.nextTick(n,a),!1)}(this,a,t,r))&&(a.pendingcb++,o=function(t,e,r,n,i,a){if(!r){var o=function(t,e,r){return t.objectMode||!1===t.decodeStrings||\"string\"!=typeof e||(e=c.from(e,r)),e}(e,n,i);n!==o&&(r=!0,i=\"buffer\",n=o)}var s=e.objectMode?1:n.length;e.length+=s;var l=e.length<e.highWaterMark;if(l||(e.needDrain=!0),e.writing||e.corked){var u=e.lastBufferedRequest;e.lastBufferedRequest={chunk:n,encoding:i,isBuf:r,callback:a,next:null},u?u.next=e.lastBufferedRequest:e.bufferedRequest=e.lastBufferedRequest,e.bufferedRequestCount+=1}else M(t,e,!1,s,n,i,a);return l}(this,a,s,t,e,r)),o},A.prototype.cork=function(){this._writableState.corked++},A.prototype.uncork=function(){var t=this._writableState;t.corked&&(t.corked--,t.writing||t.corked||t.bufferProcessing||!t.bufferedRequest||E(this,t))},A.prototype.setDefaultEncoding=function(t){if(\"string\"==typeof t&&(t=t.toLowerCase()),!([\"hex\",\"utf8\",\"utf-8\",\"ascii\",\"binary\",\"base64\",\"ucs2\",\"ucs-2\",\"utf16le\",\"utf-16le\",\"raw\"].indexOf((t+\"\").toLowerCase())>-1))throw new b(t);return this._writableState.defaultEncoding=t,this},Object.defineProperty(A.prototype,\"writableBuffer\",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(A.prototype,\"writableHighWaterMark\",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),A.prototype._write=function(t,e,r){r(new m(\"_write()\"))},A.prototype._writev=null,A.prototype.end=function(t,e,r){var n=this._writableState;return\"function\"==typeof t?(r=t,t=null,e=null):\"function\"==typeof e&&(r=e,e=null),null!=t&&this.write(t,e),n.corked&&(n.corked=1,this.uncork()),n.ending||function(t,e,r){e.ending=!0,I(t,e),r&&(e.finished?i.nextTick(r):t.once(\"finish\",r)),e.ended=!0,t.writable=!1}(this,n,r),this},Object.defineProperty(A.prototype,\"writableLength\",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(A.prototype,\"destroyed\",{enumerable:!1,get:function(){return void 0!==this._writableState&&this._writableState.destroyed},set:function(t){this._writableState&&(this._writableState.destroyed=t)}}),A.prototype.destroy=h.destroy,A.prototype._undestroy=h.undestroy,A.prototype._destroy=function(t,e){e(t)}},73726:function(t,e,r){\"use strict\";var n,i=r(33282);function a(t,e,r){return e in t?Object.defineProperty(t,e,{value:r,enumerable:!0,configurable:!0,writable:!0}):t[e]=r,t}var o=r(37165),s=Symbol(\"lastResolve\"),l=Symbol(\"lastReject\"),c=Symbol(\"error\"),u=Symbol(\"ended\"),h=Symbol(\"lastPromise\"),f=Symbol(\"handlePromise\"),p=Symbol(\"stream\");function d(t,e){return{value:t,done:e}}function m(t){var e=t[s];if(null!==e){var r=t[p].read();null!==r&&(t[h]=null,t[s]=null,t[l]=null,e(d(r,!1)))}}function g(t){i.nextTick(m,t)}var y=Object.getPrototypeOf((function(){})),v=Object.setPrototypeOf((a(n={get stream(){return this[p]},next:function(){var t=this,e=this[c];if(null!==e)return Promise.reject(e);if(this[u])return Promise.resolve(d(void 0,!0));if(this[p].destroyed)return new Promise((function(e,r){i.nextTick((function(){t[c]?r(t[c]):e(d(void 0,!0))}))}));var r,n=this[h];if(n)r=new Promise(function(t,e){return function(r,n){t.then((function(){e[u]?r(d(void 0,!0)):e[f](r,n)}),n)}}(n,this));else{var a=this[p].read();if(null!==a)return Promise.resolve(d(a,!1));r=new Promise(this[f])}return this[h]=r,r}},Symbol.asyncIterator,(function(){return this})),a(n,\"return\",(function(){var t=this;return new Promise((function(e,r){t[p].destroy(null,(function(t){t?r(t):e(d(void 0,!0))}))}))})),n),y);t.exports=function(t){var e,r=Object.create(v,(a(e={},p,{value:t,writable:!0}),a(e,s,{value:null,writable:!0}),a(e,l,{value:null,writable:!0}),a(e,c,{value:null,writable:!0}),a(e,u,{value:t._readableState.endEmitted,writable:!0}),a(e,f,{value:function(t,e){var n=r[p].read();n?(r[h]=null,r[s]=null,r[l]=null,t(d(n,!1))):(r[s]=t,r[l]=e)},writable:!0}),e));return r[h]=null,o(t,(function(t){if(t&&\"ERR_STREAM_PREMATURE_CLOSE\"!==t.code){var e=r[l];return null!==e&&(r[h]=null,r[s]=null,r[l]=null,e(t)),void(r[c]=t)}var n=r[s];null!==n&&(r[h]=null,r[s]=null,r[l]=null,n(d(void 0,!0))),r[u]=!0})),t.on(\"readable\",g.bind(null,r)),r}},29930:function(t,e,r){\"use strict\";function n(t,e){var r=Object.keys(t);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(t);e&&(n=n.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),r.push.apply(r,n)}return r}function i(t,e,r){return e in t?Object.defineProperty(t,e,{value:r,enumerable:!0,configurable:!0,writable:!0}):t[e]=r,t}function a(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(t,n.key,n)}}var o=r(45708).Buffer,s=r(63779).inspect,l=s&&s.custom||\"inspect\";t.exports=function(){function t(){!function(t,e){if(!(t instanceof e))throw new TypeError(\"Cannot call a class as a function\")}(this,t),this.head=null,this.tail=null,this.length=0}var e,r;return e=t,r=[{key:\"push\",value:function(t){var e={data:t,next:null};this.length>0?this.tail.next=e:this.head=e,this.tail=e,++this.length}},{key:\"unshift\",value:function(t){var e={data:t,next:this.head};0===this.length&&(this.tail=e),this.head=e,++this.length}},{key:\"shift\",value:function(){if(0!==this.length){var t=this.head.data;return 1===this.length?this.head=this.tail=null:this.head=this.head.next,--this.length,t}}},{key:\"clear\",value:function(){this.head=this.tail=null,this.length=0}},{key:\"join\",value:function(t){if(0===this.length)return\"\";for(var e=this.head,r=\"\"+e.data;e=e.next;)r+=t+e.data;return r}},{key:\"concat\",value:function(t){if(0===this.length)return o.alloc(0);for(var e,r,n,i=o.allocUnsafe(t>>>0),a=this.head,s=0;a;)e=a.data,r=i,n=s,o.prototype.copy.call(e,r,n),s+=a.data.length,a=a.next;return i}},{key:\"consume\",value:function(t,e){var r;return t<this.head.data.length?(r=this.head.data.slice(0,t),this.head.data=this.head.data.slice(t)):r=t===this.head.data.length?this.shift():e?this._getString(t):this._getBuffer(t),r}},{key:\"first\",value:function(){return this.head.data}},{key:\"_getString\",value:function(t){var e=this.head,r=1,n=e.data;for(t-=n.length;e=e.next;){var i=e.data,a=t>i.length?i.length:t;if(a===i.length?n+=i:n+=i.slice(0,t),0==(t-=a)){a===i.length?(++r,e.next?this.head=e.next:this.head=this.tail=null):(this.head=e,e.data=i.slice(a));break}++r}return this.length-=r,n}},{key:\"_getBuffer\",value:function(t){var e=o.allocUnsafe(t),r=this.head,n=1;for(r.data.copy(e),t-=r.data.length;r=r.next;){var i=r.data,a=t>i.length?i.length:t;if(i.copy(e,e.length-t,0,a),0==(t-=a)){a===i.length?(++n,r.next?this.head=r.next:this.head=this.tail=null):(this.head=r,r.data=i.slice(a));break}++n}return this.length-=n,e}},{key:l,value:function(t,e){return s(this,function(t){for(var e=1;e<arguments.length;e++){var r=null!=arguments[e]?arguments[e]:{};e%2?n(Object(r),!0).forEach((function(e){i(t,e,r[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(r)):n(Object(r)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(r,e))}))}return t}({},e,{depth:0,customInspect:!1}))}}],r&&a(e.prototype,r),t}()},52023:function(t,e,r){\"use strict\";var n=r(33282);function i(t,e){o(t,e),a(t)}function a(t){t._writableState&&!t._writableState.emitClose||t._readableState&&!t._readableState.emitClose||t.emit(\"close\")}function o(t,e){t.emit(\"error\",e)}t.exports={destroy:function(t,e){var r=this,s=this._readableState&&this._readableState.destroyed,l=this._writableState&&this._writableState.destroyed;return s||l?(e?e(t):t&&(this._writableState?this._writableState.errorEmitted||(this._writableState.errorEmitted=!0,n.nextTick(o,this,t)):n.nextTick(o,this,t)),this):(this._readableState&&(this._readableState.destroyed=!0),this._writableState&&(this._writableState.destroyed=!0),this._destroy(t||null,(function(t){!e&&t?r._writableState?r._writableState.errorEmitted?n.nextTick(a,r):(r._writableState.errorEmitted=!0,n.nextTick(i,r,t)):n.nextTick(i,r,t):e?(n.nextTick(a,r),e(t)):n.nextTick(a,r)})),this)},undestroy:function(){this._readableState&&(this._readableState.destroyed=!1,this._readableState.reading=!1,this._readableState.ended=!1,this._readableState.endEmitted=!1),this._writableState&&(this._writableState.destroyed=!1,this._writableState.ended=!1,this._writableState.ending=!1,this._writableState.finalCalled=!1,this._writableState.prefinished=!1,this._writableState.finished=!1,this._writableState.errorEmitted=!1)},errorOrDestroy:function(t,e){var r=t._readableState,n=t._writableState;r&&r.autoDestroy||n&&n.autoDestroy?t.destroy(e):t.emit(\"error\",e)}}},37165:function(t,e,r){\"use strict\";var n=r(44059).F.ERR_STREAM_PREMATURE_CLOSE;function i(){}t.exports=function t(e,r,a){if(\"function\"==typeof r)return t(e,null,r);r||(r={}),a=function(t){var e=!1;return function(){if(!e){e=!0;for(var r=arguments.length,n=new Array(r),i=0;i<r;i++)n[i]=arguments[i];t.apply(this,n)}}}(a||i);var o=r.readable||!1!==r.readable&&e.readable,s=r.writable||!1!==r.writable&&e.writable,l=function(){e.writable||u()},c=e._writableState&&e._writableState.finished,u=function(){s=!1,c=!0,o||a.call(e)},h=e._readableState&&e._readableState.endEmitted,f=function(){o=!1,h=!0,s||a.call(e)},p=function(t){a.call(e,t)},d=function(){var t;return o&&!h?(e._readableState&&e._readableState.ended||(t=new n),a.call(e,t)):s&&!c?(e._writableState&&e._writableState.ended||(t=new n),a.call(e,t)):void 0},m=function(){e.req.on(\"finish\",u)};return function(t){return t.setHeader&&\"function\"==typeof t.abort}(e)?(e.on(\"complete\",u),e.on(\"abort\",d),e.req?m():e.on(\"request\",m)):s&&!e._writableState&&(e.on(\"end\",l),e.on(\"close\",l)),e.on(\"end\",f),e.on(\"finish\",u),!1!==r.error&&e.on(\"error\",p),e.on(\"close\",d),function(){e.removeListener(\"complete\",u),e.removeListener(\"abort\",d),e.removeListener(\"request\",m),e.req&&e.req.removeListener(\"finish\",u),e.removeListener(\"end\",l),e.removeListener(\"close\",l),e.removeListener(\"finish\",u),e.removeListener(\"end\",f),e.removeListener(\"error\",p),e.removeListener(\"close\",d)}}},37108:function(t){t.exports=function(){throw new Error(\"Readable.from is not available in the browser\")}},6772:function(t,e,r){\"use strict\";var n,i=r(44059).F,a=i.ERR_MISSING_ARGS,o=i.ERR_STREAM_DESTROYED;function s(t){if(t)throw t}function l(t){t()}function c(t,e){return t.pipe(e)}t.exports=function(){for(var t=arguments.length,e=new Array(t),i=0;i<t;i++)e[i]=arguments[i];var u,h=function(t){return t.length?\"function\"!=typeof t[t.length-1]?s:t.pop():s}(e);if(Array.isArray(e[0])&&(e=e[0]),e.length<2)throw new a(\"streams\");var f=e.map((function(t,i){var a=i<e.length-1;return function(t,e,i,a){a=function(t){var e=!1;return function(){e||(e=!0,t.apply(void 0,arguments))}}(a);var s=!1;t.on(\"close\",(function(){s=!0})),void 0===n&&(n=r(37165)),n(t,{readable:e,writable:i},(function(t){if(t)return a(t);s=!0,a()}));var l=!1;return function(e){if(!s&&!l)return l=!0,function(t){return t.setHeader&&\"function\"==typeof t.abort}(t)?t.abort():\"function\"==typeof t.destroy?t.destroy():void a(e||new o(\"pipe\"))}}(t,a,i>0,(function(t){u||(u=t),t&&f.forEach(l),a||(f.forEach(l),h(u))}))}));return e.reduce(c)}},31976:function(t,e,r){\"use strict\";var n=r(44059).F.ERR_INVALID_OPT_VALUE;t.exports={getHighWaterMark:function(t,e,r,i){var a=function(t,e,r){return null!=t.highWaterMark?t.highWaterMark:e?t[r]:null}(e,i,r);if(null!=a){if(!isFinite(a)||Math.floor(a)!==a||a<0)throw new n(i?r:\"highWaterMark\",a);return Math.floor(a)}return t.objectMode?16:16384}}},60032:function(t,e,r){t.exports=r(7683).EventEmitter},54304:function(t,e,r){\"use strict\";var n=r(41041).Buffer,i=n.isEncoding||function(t){switch((t=\"\"+t)&&t.toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":case\"raw\":return!0;default:return!1}};function a(t){var e;switch(this.encoding=function(t){var e=function(t){if(!t)return\"utf8\";for(var e;;)switch(t){case\"utf8\":case\"utf-8\":return\"utf8\";case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return\"utf16le\";case\"latin1\":case\"binary\":return\"latin1\";case\"base64\":case\"ascii\":case\"hex\":return t;default:if(e)return;t=(\"\"+t).toLowerCase(),e=!0}}(t);if(\"string\"!=typeof e&&(n.isEncoding===i||!i(t)))throw new Error(\"Unknown encoding: \"+t);return e||t}(t),this.encoding){case\"utf16le\":this.text=l,this.end=c,e=4;break;case\"utf8\":this.fillLast=s,e=4;break;case\"base64\":this.text=u,this.end=h,e=3;break;default:return this.write=f,void(this.end=p)}this.lastNeed=0,this.lastTotal=0,this.lastChar=n.allocUnsafe(e)}function o(t){return t<=127?0:t>>5==6?2:t>>4==14?3:t>>3==30?4:t>>6==2?-1:-2}function s(t){var e=this.lastTotal-this.lastNeed,r=function(t,e,r){if(128!=(192&e[0]))return t.lastNeed=0,\"\ufffd\";if(t.lastNeed>1&&e.length>1){if(128!=(192&e[1]))return t.lastNeed=1,\"\ufffd\";if(t.lastNeed>2&&e.length>2&&128!=(192&e[2]))return t.lastNeed=2,\"\ufffd\"}}(this,t);return void 0!==r?r:this.lastNeed<=t.length?(t.copy(this.lastChar,e,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal)):(t.copy(this.lastChar,e,0,t.length),void(this.lastNeed-=t.length))}function l(t,e){if((t.length-e)%2==0){var r=t.toString(\"utf16le\",e);if(r){var n=r.charCodeAt(r.length-1);if(n>=55296&&n<=56319)return this.lastNeed=2,this.lastTotal=4,this.lastChar[0]=t[t.length-2],this.lastChar[1]=t[t.length-1],r.slice(0,-1)}return r}return this.lastNeed=1,this.lastTotal=2,this.lastChar[0]=t[t.length-1],t.toString(\"utf16le\",e,t.length-1)}function c(t){var e=t&&t.length?this.write(t):\"\";if(this.lastNeed){var r=this.lastTotal-this.lastNeed;return e+this.lastChar.toString(\"utf16le\",0,r)}return e}function u(t,e){var r=(t.length-e)%3;return 0===r?t.toString(\"base64\",e):(this.lastNeed=3-r,this.lastTotal=3,1===r?this.lastChar[0]=t[t.length-1]:(this.lastChar[0]=t[t.length-2],this.lastChar[1]=t[t.length-1]),t.toString(\"base64\",e,t.length-r))}function h(t){var e=t&&t.length?this.write(t):\"\";return this.lastNeed?e+this.lastChar.toString(\"base64\",0,3-this.lastNeed):e}function f(t){return t.toString(this.encoding)}function p(t){return t&&t.length?this.write(t):\"\"}e.I=a,a.prototype.write=function(t){if(0===t.length)return\"\";var e,r;if(this.lastNeed){if(void 0===(e=this.fillLast(t)))return\"\";r=this.lastNeed,this.lastNeed=0}else r=0;return r<t.length?e?e+this.text(t,r):this.text(t,r):e||\"\"},a.prototype.end=function(t){var e=t&&t.length?this.write(t):\"\";return this.lastNeed?e+\"\ufffd\":e},a.prototype.text=function(t,e){var r=function(t,e,r){var n=e.length-1;if(n<r)return 0;var i=o(e[n]);return i>=0?(i>0&&(t.lastNeed=i-1),i):--n<r||-2===i?0:(i=o(e[n]))>=0?(i>0&&(t.lastNeed=i-2),i):--n<r||-2===i?0:(i=o(e[n]))>=0?(i>0&&(2===i?i=0:t.lastNeed=i-3),i):0}(this,t,e);if(!this.lastNeed)return t.toString(\"utf8\",e);this.lastTotal=r;var n=t.length-(r-this.lastNeed);return t.copy(this.lastChar,0,n),t.toString(\"utf8\",e,n)},a.prototype.fillLast=function(t){if(this.lastNeed<=t.length)return t.copy(this.lastChar,this.lastTotal-this.lastNeed,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal);t.copy(this.lastChar,this.lastTotal-this.lastNeed,0,t.length),this.lastNeed-=t.length}},79743:function(t,e,r){var n=r(45708).Buffer,i=r(85672),a=r(79399)(\"stream-parser\");t.exports=function(t){var e=t&&\"function\"==typeof t._transform,r=t&&\"function\"==typeof t._write;if(!e&&!r)throw new Error(\"must pass a Writable or Transform stream in\");a(\"extending Parser into stream\"),t._bytes=h,t._skipBytes=f,e&&(t._passthrough=p),e?t._transform=m:t._write=d};var o=-1,s=0,l=1,c=2;function u(t){a(\"initializing parser stream\"),t._parserBytesLeft=0,t._parserBuffers=[],t._parserBuffered=0,t._parserState=o,t._parserCallback=null,\"function\"==typeof t.push&&(t._parserOutput=t.push.bind(t)),t._parserInit=!0}function h(t,e){i(!this._parserCallback,'there is already a \"callback\" set!'),i(isFinite(t)&&t>0,'can only buffer a finite number of bytes > 0, got \"'+t+'\"'),this._parserInit||u(this),a(\"buffering %o bytes\",t),this._parserBytesLeft=t,this._parserCallback=e,this._parserState=s}function f(t,e){i(!this._parserCallback,'there is already a \"callback\" set!'),i(t>0,'can only skip > 0 bytes, got \"'+t+'\"'),this._parserInit||u(this),a(\"skipping %o bytes\",t),this._parserBytesLeft=t,this._parserCallback=e,this._parserState=l}function p(t,e){i(!this._parserCallback,'There is already a \"callback\" set!'),i(t>0,'can only pass through > 0 bytes, got \"'+t+'\"'),this._parserInit||u(this),a(\"passing through %o bytes\",t),this._parserBytesLeft=t,this._parserCallback=e,this._parserState=c}function d(t,e,r){this._parserInit||u(this),a(\"write(%o bytes)\",t.length),\"function\"==typeof e&&(r=e),y(this,t,null,r)}function m(t,e,r){this._parserInit||u(this),a(\"transform(%o bytes)\",t.length),\"function\"!=typeof e&&(e=this._parserOutput),y(this,t,e,r)}function g(t,e,r,i){if(t._parserBytesLeft-=e.length,a(\"%o bytes left for stream piece\",t._parserBytesLeft),t._parserState===s?(t._parserBuffers.push(e),t._parserBuffered+=e.length):t._parserState===c&&r(e),0!==t._parserBytesLeft)return i;var l=t._parserCallback;if(l&&t._parserState===s&&t._parserBuffers.length>1&&(e=n.concat(t._parserBuffers,t._parserBuffered)),t._parserState!==s&&(e=null),t._parserCallback=null,t._parserBuffered=0,t._parserState=o,t._parserBuffers.splice(0),l){var u=[];e&&u.push(e),r&&u.push(r);var h=l.length>u.length;h&&u.push(v(i));var f=l.apply(t,u);if(!h||i===f)return i}}var y=v((function t(e,r,n,i){return e._parserBytesLeft<=0?i(new Error(\"got data but not currently parsing anything\")):r.length<=e._parserBytesLeft?function(){return g(e,r,n,i)}:function(){var a=r.slice(0,e._parserBytesLeft);return g(e,a,n,(function(o){return o?i(o):r.length>a.length?function(){return t(e,r.slice(a.length),n,i)}:void 0}))}}));function v(t){return function(){for(var e=t.apply(this,arguments);\"function\"==typeof e;)e=e();return e}}},79399:function(t,e,r){var n=r(33282);function i(){var t;try{t=e.storage.debug}catch(t){}return!t&&void 0!==n&&\"env\"in n&&(t=n.env.DEBUG),t}(e=t.exports=r(43228)).log=function(){return\"object\"==typeof console&&console.log&&Function.prototype.apply.call(console.log,console,arguments)},e.formatArgs=function(t){var r=this.useColors;if(t[0]=(r?\"%c\":\"\")+this.namespace+(r?\" %c\":\" \")+t[0]+(r?\"%c \":\" \")+\"+\"+e.humanize(this.diff),r){var n=\"color: \"+this.color;t.splice(1,0,n,\"color: inherit\");var i=0,a=0;t[0].replace(/%[a-zA-Z%]/g,(function(t){\"%%\"!==t&&(i++,\"%c\"===t&&(a=i))})),t.splice(a,0,n)}},e.save=function(t){try{null==t?e.storage.removeItem(\"debug\"):e.storage.debug=t}catch(t){}},e.load=i,e.useColors=function(){return!(\"undefined\"==typeof window||!window.process||\"renderer\"!==window.process.type)||(\"undefined\"!=typeof document&&document.documentElement&&document.documentElement.style&&document.documentElement.style.WebkitAppearance||\"undefined\"!=typeof window&&window.console&&(window.console.firebug||window.console.exception&&window.console.table)||\"undefined\"!=typeof navigator&&navigator.userAgent&&navigator.userAgent.toLowerCase().match(/firefox\\/(\\d+)/)&&parseInt(RegExp.$1,10)>=31||\"undefined\"!=typeof navigator&&navigator.userAgent&&navigator.userAgent.toLowerCase().match(/applewebkit\\/(\\d+)/))},e.storage=\"undefined\"!=typeof chrome&&void 0!==chrome.storage?chrome.storage.local:function(){try{return window.localStorage}catch(t){}}(),e.colors=[\"lightseagreen\",\"forestgreen\",\"goldenrod\",\"dodgerblue\",\"darkorchid\",\"crimson\"],e.formatters.j=function(t){try{return JSON.stringify(t)}catch(t){return\"[UnexpectedJSONParseError]: \"+t.message}},e.enable(i())},43228:function(t,e,r){var n;function i(t){function r(){if(r.enabled){var t=r,i=+new Date,a=i-(n||i);t.diff=a,t.prev=n,t.curr=i,n=i;for(var o=new Array(arguments.length),s=0;s<o.length;s++)o[s]=arguments[s];o[0]=e.coerce(o[0]),\"string\"!=typeof o[0]&&o.unshift(\"%O\");var l=0;o[0]=o[0].replace(/%([a-zA-Z%])/g,(function(r,n){if(\"%%\"===r)return r;l++;var i=e.formatters[n];if(\"function\"==typeof i){var a=o[l];r=i.call(t,a),o.splice(l,1),l--}return r})),e.formatArgs.call(t,o),(r.log||e.log||console.log.bind(console)).apply(t,o)}}return r.namespace=t,r.enabled=e.enabled(t),r.useColors=e.useColors(),r.color=function(t){var r,n=0;for(r in t)n=(n<<5)-n+t.charCodeAt(r),n|=0;return e.colors[Math.abs(n)%e.colors.length]}(t),\"function\"==typeof e.init&&e.init(r),r}(e=t.exports=i.debug=i.default=i).coerce=function(t){return t instanceof Error?t.stack||t.message:t},e.disable=function(){e.enable(\"\")},e.enable=function(t){e.save(t),e.names=[],e.skips=[];for(var r=(\"string\"==typeof t?t:\"\").split(/[\\s,]+/),n=r.length,i=0;i<n;i++)r[i]&&(\"-\"===(t=r[i].replace(/\\*/g,\".*?\"))[0]?e.skips.push(new RegExp(\"^\"+t.substr(1)+\"$\")):e.names.push(new RegExp(\"^\"+t+\"$\")))},e.enabled=function(t){var r,n;for(r=0,n=e.skips.length;r<n;r++)if(e.skips[r].test(t))return!1;for(r=0,n=e.names.length;r<n;r++)if(e.names[r].test(t))return!0;return!1},e.humanize=r(13883),e.names=[],e.skips=[],e.formatters={}},13883:function(t){var e=1e3,r=60*e,n=60*r,i=24*n;function a(t,e,r){if(!(t<e))return t<1.5*e?Math.floor(t/e)+\" \"+r:Math.ceil(t/e)+\" \"+r+\"s\"}t.exports=function(t,o){o=o||{};var s,l=typeof t;if(\"string\"===l&&t.length>0)return function(t){if(!((t=String(t)).length>100)){var a=/^((?:\\d+)?\\.?\\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|years?|yrs?|y)?$/i.exec(t);if(a){var o=parseFloat(a[1]);switch((a[2]||\"ms\").toLowerCase()){case\"years\":case\"year\":case\"yrs\":case\"yr\":case\"y\":return 315576e5*o;case\"days\":case\"day\":case\"d\":return o*i;case\"hours\":case\"hour\":case\"hrs\":case\"hr\":case\"h\":return o*n;case\"minutes\":case\"minute\":case\"mins\":case\"min\":case\"m\":return o*r;case\"seconds\":case\"second\":case\"secs\":case\"sec\":case\"s\":return o*e;case\"milliseconds\":case\"millisecond\":case\"msecs\":case\"msec\":case\"ms\":return o;default:return}}}}(t);if(\"number\"===l&&!1===isNaN(t))return o.long?a(s=t,i,\"day\")||a(s,n,\"hour\")||a(s,r,\"minute\")||a(s,e,\"second\")||s+\" ms\":function(t){return t>=i?Math.round(t/i)+\"d\":t>=n?Math.round(t/n)+\"h\":t>=r?Math.round(t/r)+\"m\":t>=e?Math.round(t/e)+\"s\":t+\"ms\"}(t);throw new Error(\"val is not a non-empty string or a valid number. val=\"+JSON.stringify(t))}},28089:function(t,e,r){\"use strict\";var n=r(59811);t.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\u201c\u201d\",\"\u00ab\u00bb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map((function(t){return 1===t.length&&(t+=t),t})));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},26381:function(t){\"use strict\";t.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var m=p[d];if(r[m]<0){r[m]=n[m]=u,i[m]=!0,u+=1,l.push(m),c.push(m);break}i[m]&&(n[e]=0|Math.min(n[e],n[m])),o[m]>=0&&s[e].push(o[m])}a[e]=d}else{if(n[e]===r[e]){var g=[],y=[],v=0;for(d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,g.push(x),y.push(s[x]),v+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(g);var _=new Array(v);for(d=0;d<y.length;d++)for(var b=0;b<y[d].length;b++)_[--v]=y[d][b];f.push(_)}c.pop()}}}for(l=0;l<e;++l)r[l]<0&&p(l);for(l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort((function(t,e){return t-e})),c=[d[0]];for(var m=1;m<d.length;m++)d[m]!==d[m-1]&&c.push(d[m]);f[l]=c}}return{components:h,adjacencyList:f}}},13193:function(t,e,r){\"use strict\";r.r(e);var n=2*Math.PI,i=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},a=function(t,e){var r=1.5707963267948966===e?.551915024494:-1.5707963267948966===e?-.551915024494:4/3*Math.tan(e/4),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},o=function(t,e,r,n){var i=t*r+e*n;return i>1&&(i=1),i<-1&&(i=-1),(t*n-e*r<0?-1:1)*Math.acos(i)};e.default=function(t){var e=t.px,r=t.py,s=t.cx,l=t.cy,c=t.rx,u=t.ry,h=t.xAxisRotation,f=void 0===h?0:h,p=t.largeArcFlag,d=void 0===p?0:p,m=t.sweepFlag,g=void 0===m?0:m,y=[];if(0===c||0===u)return[];var v=Math.sin(f*n/360),x=Math.cos(f*n/360),_=x*(e-s)/2+v*(r-l)/2,b=-v*(e-s)/2+x*(r-l)/2;if(0===_&&0===b)return[];c=Math.abs(c),u=Math.abs(u);var w=Math.pow(_,2)/Math.pow(c,2)+Math.pow(b,2)/Math.pow(u,2);w>1&&(c*=Math.sqrt(w),u*=Math.sqrt(w));var T=function(t,e,r,i,a,s,l,c,u,h,f,p){var d=Math.pow(a,2),m=Math.pow(s,2),g=Math.pow(f,2),y=Math.pow(p,2),v=d*m-d*y-m*g;v<0&&(v=0),v/=d*y+m*g;var x=(v=Math.sqrt(v)*(l===c?-1:1))*a/s*p,_=v*-s/a*f,b=h*x-u*_+(t+r)/2,w=u*x+h*_+(e+i)/2,T=(f-x)/a,k=(p-_)/s,A=(-f-x)/a,M=(-p-_)/s,S=o(1,0,T,k),E=o(T,k,A,M);return 0===c&&E>0&&(E-=n),1===c&&E<0&&(E+=n),[b,w,S,E]}(e,r,s,l,c,u,d,g,v,x,_,b),k=function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}(T,4),A=k[0],M=k[1],S=k[2],E=k[3],C=Math.abs(E)/(n/4);Math.abs(1-C)<1e-7&&(C=1);var L=Math.max(Math.ceil(C),1);E/=L;for(var I=0;I<L;I++)y.push(a(S,E)),S+=E;return y.map((function(t){var e=i(t[0],c,u,x,v,A,M),r=e.x,n=e.y,a=i(t[1],c,u,x,v,A,M),o=a.x,s=a.y,l=i(t[2],c,u,x,v,A,M);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}}))}},97251:function(t,e,r){\"use strict\";var n=r(26953),i=r(16844),a=r(41883),o=r(13986),s=r(85672);t.exports=function(t){if(Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]),\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t)),s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},41883:function(t,e,r){\"use strict\";t.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,m=t.length;d<m;d++){var g=t[d],y=g[0];switch(y){case\"M\":l=g[1],c=g[2];break;case\"A\":var v=n({px:f,py:p,cx:g[6],cy:g[7],rx:g[1],ry:g[2],xAxisRotation:g[3],largeArcFlag:g[4],sweepFlag:g[5]});if(!v.length)continue;for(var x,_=0;_<v.length;_++)g=[\"C\",(x=v[_]).x1,x.y1,x.x2,x.y2,x.x,x.y],_<v.length-1&&r.push(g);break;case\"S\":var b=f,w=p;\"C\"!=e&&\"S\"!=e||(b+=b-o,w+=w-s),g=[\"C\",b,w,g[1],g[2],g[3],g[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),g=a(f,p,u,h,g[1],g[2]);break;case\"Q\":u=g[1],h=g[2],g=a(f,p,g[1],g[2],g[3],g[4]);break;case\"L\":g=i(f,p,g[1],g[2]);break;case\"H\":g=i(f,p,g[1],p);break;case\"V\":g=i(f,p,f,g[1]);break;case\"Z\":g=i(f,p,l,c)}e=y,f=g[g.length-2],p=g[g.length-1],g.length>4?(o=g[g.length-4],s=g[g.length-3]):(o=f,s=p),r.push(g)}return r};var n=r(13193);function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},96021:function(t,e,r){\"use strict\";var n,i=r(97251),a=r(26953),o=r(95620),s=r(13986),l=r(88772),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");t.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");var r,h;e||(e={}),e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),m=[r/(d[2]-d[0]),h/(d[3]-d[1])],g=Math.min(m[0]||0,m[1]||0)/2;if(u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p)),u.translate(.5*r,.5*h),u.scale(g,g),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var y=new Path2D(t);u.fill(y),p&&u.stroke(y)}else{var v=a(t);o(u,v),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},65657:function(t,e,r){var n;!function(i){var a=/^\\s+/,o=/\\s+$/,s=0,l=i.round,c=i.min,u=i.max,h=i.random;function f(t,e){if(e=e||{},(t=t||\"\")instanceof f)return t;if(!(this instanceof f))return new f(t,e);var r=function(t){var e,r,n,s={r:0,g:0,b:0},l=1,h=null,f=null,p=null,d=!1,m=!1;return\"string\"==typeof t&&(t=function(t){t=t.replace(a,\"\").replace(o,\"\").toLowerCase();var e,r=!1;if(L[t])t=L[t],r=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};return(e=q.rgb.exec(t))?{r:e[1],g:e[2],b:e[3]}:(e=q.rgba.exec(t))?{r:e[1],g:e[2],b:e[3],a:e[4]}:(e=q.hsl.exec(t))?{h:e[1],s:e[2],l:e[3]}:(e=q.hsla.exec(t))?{h:e[1],s:e[2],l:e[3],a:e[4]}:(e=q.hsv.exec(t))?{h:e[1],s:e[2],v:e[3]}:(e=q.hsva.exec(t))?{h:e[1],s:e[2],v:e[3],a:e[4]}:(e=q.hex8.exec(t))?{r:D(e[1]),g:D(e[2]),b:D(e[3]),a:N(e[4]),format:r?\"name\":\"hex8\"}:(e=q.hex6.exec(t))?{r:D(e[1]),g:D(e[2]),b:D(e[3]),format:r?\"name\":\"hex\"}:(e=q.hex4.exec(t))?{r:D(e[1]+\"\"+e[1]),g:D(e[2]+\"\"+e[2]),b:D(e[3]+\"\"+e[3]),a:N(e[4]+\"\"+e[4]),format:r?\"name\":\"hex8\"}:!!(e=q.hex3.exec(t))&&{r:D(e[1]+\"\"+e[1]),g:D(e[2]+\"\"+e[2]),b:D(e[3]+\"\"+e[3]),format:r?\"name\":\"hex\"}}(t)),\"object\"==typeof t&&(H(t.r)&&H(t.g)&&H(t.b)?(e=t.r,r=t.g,n=t.b,s={r:255*z(e,255),g:255*z(r,255),b:255*z(n,255)},d=!0,m=\"%\"===String(t.r).substr(-1)?\"prgb\":\"rgb\"):H(t.h)&&H(t.s)&&H(t.v)?(h=F(t.s),f=F(t.v),s=function(t,e,r){t=6*z(t,360),e=z(e,100),r=z(r,100);var n=i.floor(t),a=t-n,o=r*(1-e),s=r*(1-a*e),l=r*(1-(1-a)*e),c=n%6;return{r:255*[r,s,o,o,l,r][c],g:255*[l,r,r,s,o,o][c],b:255*[o,o,l,r,r,s][c]}}(t.h,h,f),d=!0,m=\"hsv\"):H(t.h)&&H(t.s)&&H(t.l)&&(h=F(t.s),p=F(t.l),s=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=z(t,360),e=z(e,100),r=z(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(t.h,h,p),d=!0,m=\"hsl\"),t.hasOwnProperty(\"a\")&&(l=t.a)),l=P(l),{ok:d,format:t.format||m,r:c(255,u(s.r,0)),g:c(255,u(s.g,0)),b:c(255,u(s.b,0)),a:l}}(t);this._originalInput=t,this._r=r.r,this._g=r.g,this._b=r.b,this._a=r.a,this._roundA=l(100*this._a)/100,this._format=e.format||r.format,this._gradientType=e.gradientType,this._r<1&&(this._r=l(this._r)),this._g<1&&(this._g=l(this._g)),this._b<1&&(this._b=l(this._b)),this._ok=r.ok,this._tc_id=s++}function p(t,e,r){t=z(t,255),e=z(e,255),r=z(r,255);var n,i,a=u(t,e,r),o=c(t,e,r),s=(a+o)/2;if(a==o)n=i=0;else{var l=a-o;switch(i=s>.5?l/(2-a-o):l/(a+o),a){case t:n=(e-r)/l+(e<r?6:0);break;case e:n=(r-t)/l+2;break;case r:n=(t-e)/l+4}n/=6}return{h:n,s:i,l:s}}function d(t,e,r){t=z(t,255),e=z(e,255),r=z(r,255);var n,i,a=u(t,e,r),o=c(t,e,r),s=a,l=a-o;if(i=0===a?0:l/a,a==o)n=0;else{switch(a){case t:n=(e-r)/l+(e<r?6:0);break;case e:n=(r-t)/l+2;break;case r:n=(t-e)/l+4}n/=6}return{h:n,s:i,v:s}}function m(t,e,r,n){var i=[R(l(t).toString(16)),R(l(e).toString(16)),R(l(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function g(t,e,r,n){return[R(B(n)),R(l(t).toString(16)),R(l(e).toString(16)),R(l(r).toString(16))].join(\"\")}function y(t,e){e=0===e?0:e||10;var r=f(t).toHsl();return r.s-=e/100,r.s=O(r.s),f(r)}function v(t,e){e=0===e?0:e||10;var r=f(t).toHsl();return r.s+=e/100,r.s=O(r.s),f(r)}function x(t){return f(t).desaturate(100)}function _(t,e){e=0===e?0:e||10;var r=f(t).toHsl();return r.l+=e/100,r.l=O(r.l),f(r)}function b(t,e){e=0===e?0:e||10;var r=f(t).toRgb();return r.r=u(0,c(255,r.r-l(-e/100*255))),r.g=u(0,c(255,r.g-l(-e/100*255))),r.b=u(0,c(255,r.b-l(-e/100*255))),f(r)}function w(t,e){e=0===e?0:e||10;var r=f(t).toHsl();return r.l-=e/100,r.l=O(r.l),f(r)}function T(t,e){var r=f(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,f(r)}function k(t){var e=f(t).toHsl();return e.h=(e.h+180)%360,f(e)}function A(t){var e=f(t).toHsl(),r=e.h;return[f(t),f({h:(r+120)%360,s:e.s,l:e.l}),f({h:(r+240)%360,s:e.s,l:e.l})]}function M(t){var e=f(t).toHsl(),r=e.h;return[f(t),f({h:(r+90)%360,s:e.s,l:e.l}),f({h:(r+180)%360,s:e.s,l:e.l}),f({h:(r+270)%360,s:e.s,l:e.l})]}function S(t){var e=f(t).toHsl(),r=e.h;return[f(t),f({h:(r+72)%360,s:e.s,l:e.l}),f({h:(r+216)%360,s:e.s,l:e.l})]}function E(t,e,r){e=e||6,r=r||30;var n=f(t).toHsl(),i=360/r,a=[f(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(f(n));return a}function C(t,e){e=e||6;for(var r=f(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(f({h:n,s:i,v:a})),a=(a+s)%1;return o}f.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var t,e,r,n=this.toRgb();return t=n.r/255,e=n.g/255,r=n.b/255,.2126*(t<=.03928?t/12.92:i.pow((t+.055)/1.055,2.4))+.7152*(e<=.03928?e/12.92:i.pow((e+.055)/1.055,2.4))+.0722*(r<=.03928?r/12.92:i.pow((r+.055)/1.055,2.4))},setAlpha:function(t){return this._a=P(t),this._roundA=l(100*this._a)/100,this},toHsv:function(){var t=d(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=d(this._r,this._g,this._b),e=l(360*t.h),r=l(100*t.s),n=l(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=p(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=p(this._r,this._g,this._b),e=l(360*t.h),r=l(100*t.s),n=l(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return m(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var a=[R(l(t).toString(16)),R(l(e).toString(16)),R(l(r).toString(16)),R(B(n))];return i&&a[0].charAt(0)==a[0].charAt(1)&&a[1].charAt(0)==a[1].charAt(1)&&a[2].charAt(0)==a[2].charAt(1)&&a[3].charAt(0)==a[3].charAt(1)?a[0].charAt(0)+a[1].charAt(0)+a[2].charAt(0)+a[3].charAt(0):a.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:l(this._r),g:l(this._g),b:l(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+l(this._r)+\", \"+l(this._g)+\", \"+l(this._b)+\")\":\"rgba(\"+l(this._r)+\", \"+l(this._g)+\", \"+l(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:l(100*z(this._r,255))+\"%\",g:l(100*z(this._g,255))+\"%\",b:l(100*z(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+l(100*z(this._r,255))+\"%, \"+l(100*z(this._g,255))+\"%, \"+l(100*z(this._b,255))+\"%)\":\"rgba(\"+l(100*z(this._r,255))+\"%, \"+l(100*z(this._g,255))+\"%, \"+l(100*z(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(I[m(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+g(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=f(t);r=\"#\"+g(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return f(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(_,arguments)},brighten:function(){return this._applyModification(b,arguments)},darken:function(){return this._applyModification(w,arguments)},desaturate:function(){return this._applyModification(y,arguments)},saturate:function(){return this._applyModification(v,arguments)},greyscale:function(){return this._applyModification(x,arguments)},spin:function(){return this._applyModification(T,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(E,arguments)},complement:function(){return this._applyCombination(k,arguments)},monochromatic:function(){return this._applyCombination(C,arguments)},splitcomplement:function(){return this._applyCombination(S,arguments)},triad:function(){return this._applyCombination(A,arguments)},tetrad:function(){return this._applyCombination(M,arguments)}},f.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:F(t[n]));t=r}return f(t,e)},f.equals=function(t,e){return!(!t||!e)&&f(t).toRgbString()==f(e).toRgbString()},f.random=function(){return f.fromRatio({r:h(),g:h(),b:h()})},f.mix=function(t,e,r){r=0===r?0:r||50;var n=f(t).toRgb(),i=f(e).toRgb(),a=r/100;return f({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},f.readability=function(t,e){var r=f(t),n=f(e);return(i.max(r.getLuminance(),n.getLuminance())+.05)/(i.min(r.getLuminance(),n.getLuminance())+.05)},f.isReadable=function(t,e,r){var n,i,a,o,s,l=f.readability(t,e);switch(i=!1,(a=r,\"AA\"!==(o=((a=a||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase())&&\"AAA\"!==o&&(o=\"AA\"),\"small\"!==(s=(a.size||\"small\").toLowerCase())&&\"large\"!==s&&(s=\"small\"),n={level:o,size:s}).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=l>=4.5;break;case\"AAlarge\":i=l>=3;break;case\"AAAsmall\":i=l>=7}return i},f.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var c=0;c<e.length;c++)(n=f.readability(t,e[c]))>l&&(l=n,s=f(e[c]));return f.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,f.mostReadable(t,[\"#fff\",\"#000\"],r))};var L=f.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},I=f.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(L);function P(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function z(t,e){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(t)&&(t=\"100%\");var r=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(t);return t=c(e,u(0,parseFloat(t))),r&&(t=parseInt(t*e,10)/100),i.abs(t-e)<1e-6?1:t%e/parseFloat(e)}function O(t){return c(1,u(0,t))}function D(t){return parseInt(t,16)}function R(t){return 1==t.length?\"0\"+t:\"\"+t}function F(t){return t<=1&&(t=100*t+\"%\"),t}function B(t){return i.round(255*parseFloat(t)).toString(16)}function N(t){return D(t)/255}var j,U,V,q=(U=\"[\\\\s|\\\\(]+(\"+(j=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+j+\")[,|\\\\s]+(\"+j+\")\\\\s*\\\\)?\",V=\"[\\\\s|\\\\(]+(\"+j+\")[,|\\\\s]+(\"+j+\")[,|\\\\s]+(\"+j+\")[,|\\\\s]+(\"+j+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(j),rgb:new RegExp(\"rgb\"+U),rgba:new RegExp(\"rgba\"+V),hsl:new RegExp(\"hsl\"+U),hsla:new RegExp(\"hsla\"+V),hsv:new RegExp(\"hsv\"+U),hsva:new RegExp(\"hsva\"+V),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function H(t){return!!q.CSS_UNIT.exec(t)}t.exports?t.exports=f:void 0===(n=function(){return f}.call(e,r,e,t))||(t.exports=n)}(Math)},51498:function(t){\"use strict\";t.exports=r,t.exports.float32=t.exports.float=r,t.exports.fract32=t.exports.fract=function(t,e){if(t.length){if(t instanceof Float32Array)return new Float32Array(t.length);e instanceof Float32Array||(e=r(t));for(var n=0,i=e.length;n<i;n++)e[n]=t[n]-e[n];return e}return r(t-r(t))};var e=new Float32Array(1);function r(t){return t.length?t instanceof Float32Array?t:new Float32Array(t):(e[0]=t,e[0])}},44626:function(t,e,r){\"use strict\";var n=r(4957);t.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},48640:function(t,e,r){\"use strict\";function n(t){return t}function i(t,e){return\"string\"==typeof e&&(e=t.objects[e]),\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map((function(e){return a(t,e)}))}:a(t,e)}function a(t,e){var r=e.id,i=e.bbox,a=null==e.properties?{}:e.properties,o=function(t,e){var r=function(t){if(null==t)return n;var e,r,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,n){n||(e=r=0);var l=2,c=t.length,u=new Array(c);for(u[0]=(e+=t[0])*i+o,u[1]=(r+=t[1])*a+s;l<c;)u[l]=t[l],++l;return u}}(t.transform),i=t.arcs;function a(t,e){e.length&&e.pop();for(var n=i[t<0?~t:t],a=0,o=n.length;a<o;++a)e.push(r(n[a],a));t<0&&function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r}(e,o)}function o(t){return r(t)}function s(t){for(var e=[],r=0,n=t.length;r<n;++r)a(t[r],e);return e.length<2&&e.push(e[0]),e}function l(t){for(var e=s(t);e.length<4;)e.push(e[0]);return e}function c(t){return t.map(l)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=o(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(o);break;case\"LineString\":r=s(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(s);break;case\"Polygon\":r=c(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(c);break;default:return null}return{type:n,coordinates:r}}(e)}(t,e);return null==r&&null==i?{type:\"Feature\",properties:a,geometry:o}:null==i?{type:\"Feature\",id:r,properties:a,geometry:o}:{type:\"Feature\",id:r,bbox:i,properties:a,geometry:o}}r.d(e,{N4:function(){return i}})},64276:function(t,e,r){\"use strict\";var n=r(31350);t.exports=function(t){if(\"function\"!=typeof t)return!1;if(!hasOwnProperty.call(t,\"length\"))return!1;try{if(\"number\"!=typeof t.length)return!1;if(\"function\"!=typeof t.call)return!1;if(\"function\"!=typeof t.apply)return!1}catch(t){return!1}return!n(t)}},99497:function(t,e,r){\"use strict\";var n=r(80299),i=r(76481),a=r(58698),o=r(60461),s=function(t,e){return t.replace(\"%v\",o(e))};t.exports=function(t,e,r){if(!i(r))throw new TypeError(s(e,t));if(!n(t)){if(\"default\"in r)return r.default;if(r.isOptional)return null}var o=a(r.errorMessage);throw n(o)||(o=e),new TypeError(s(o,t))}},78696:function(t){\"use strict\";t.exports=function(t){try{return t.toString()}catch(e){try{return String(t)}catch(t){return null}}}},60461:function(t,e,r){\"use strict\";var n=r(78696),i=/[\\n\\r\\u2028\\u2029]/g;t.exports=function(t){var e=n(t);return null===e?\"<Non-coercible to string value>\":(e.length>100&&(e=e.slice(0,99)+\"\u2026\"),e=e.replace(i,(function(t){switch(t){case\"\\n\":return\"\\\\n\";case\"\\r\":return\"\\\\r\";case\"\\u2028\":return\"\\\\u2028\";case\"\\u2029\":return\"\\\\u2029\";default:throw new Error(\"Unexpected character\")}})))}},76481:function(t,e,r){\"use strict\";var n=r(80299),i={object:!0,function:!0,undefined:!0};t.exports=function(t){return!!n(t)&&hasOwnProperty.call(i,typeof t)}},6887:function(t,e,r){\"use strict\";var n=r(99497),i=r(63461);t.exports=function(t){return i(t)?t:n(t,\"%v is not a plain function\",arguments[1])}},63461:function(t,e,r){\"use strict\";var n=r(64276),i=/^\\s*class[\\s{/}]/,a=Function.prototype.toString;t.exports=function(t){return!!n(t)&&!i.test(a.call(t))}},31350:function(t,e,r){\"use strict\";var n=r(76481);t.exports=function(t){if(!n(t))return!1;try{return!!t.constructor&&t.constructor.prototype===t}catch(t){return!1}}},58698:function(t,e,r){\"use strict\";var n=r(80299),i=r(76481),a=Object.prototype.toString;t.exports=function(t){if(!n(t))return null;if(i(t)){var e=t.toString;if(\"function\"!=typeof e)return null;if(e===a)return null}try{return\"\"+t}catch(t){return null}}},9557:function(t,e,r){\"use strict\";var n=r(99497),i=r(80299);t.exports=function(t){return i(t)?t:n(t,\"Cannot use %v\",arguments[1])}},80299:function(t){\"use strict\";t.exports=function(t){return null!=t}},66127:function(t,e,r){\"use strict\";var n=r(54689),i=r(49523),a=r(45708).Buffer;r.g.__TYPEDARRAY_POOL||(r.g.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),BIGUINT64:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),BIGINT64:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=r.g.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=i([32,0])),c.BIGUINT64||(c.BIGUINT64=i([32,0])),c.BIGINT64||(c.BIGINT64=i([32,0])),c.BUFFER||(c.BUFFER=i([32,0]));var u=c.DATA,h=c.BUFFER;function f(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function m(t){return new Uint16Array(p(2*t),0,t)}function g(t){return new Uint32Array(p(4*t),0,t)}function y(t){return new Int8Array(p(t),0,t)}function v(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function _(t){return new Float32Array(p(4*t),0,t)}function b(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function A(t){return new DataView(p(t),0,t)}function M(t){t=n.nextPow2(t);var e=n.log2(t),r=h[e];return r.length>0?r.pop():new a(t)}e.free=function(t){if(a.isBuffer(t))h[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},e.freeUint8=e.freeUint16=e.freeUint32=e.freeBigUint64=e.freeInt8=e.freeInt16=e.freeInt32=e.freeBigInt64=e.freeFloat32=e.freeFloat=e.freeFloat64=e.freeDouble=e.freeUint8Clamped=e.freeDataView=function(t){f(t.buffer)},e.freeArrayBuffer=f,e.freeBuffer=function(t){h[n.log2(t.length)].push(t)},e.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return m(t);case\"uint32\":return g(t);case\"int8\":return y(t);case\"int16\":return v(t);case\"int32\":return x(t);case\"float\":case\"float32\":return _(t);case\"double\":case\"float64\":return b(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return M(t);case\"data\":case\"dataview\":return A(t);default:return null}return null},e.mallocArrayBuffer=p,e.mallocUint8=d,e.mallocUint16=m,e.mallocUint32=g,e.mallocInt8=y,e.mallocInt16=v,e.mallocInt32=x,e.mallocFloat32=e.mallocFloat=_,e.mallocFloat64=e.mallocDouble=b,e.mallocUint8Clamped=w,e.mallocBigUint64=T,e.mallocBigInt64=k,e.mallocDataView=A,e.mallocBuffer=M,e.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,h[t].length=0}},80886:function(t){var e=/[\\'\\\"]/;t.exports=function(t){return t?(e.test(t.charAt(0))&&(t=t.substr(1)),e.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},79788:function(t){\"use strict\";t.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},71103:function(t,e,r){function n(t){try{if(!r.g.localStorage)return!1}catch(t){return!1}var e=r.g.localStorage[t];return null!=e&&\"true\"===String(e).toLowerCase()}t.exports=function(t,e){if(n(\"noDeprecation\"))return t;var r=!1;return function(){if(!r){if(n(\"throwDeprecation\"))throw new Error(e);n(\"traceDeprecation\")?console.trace(e):console.warn(e),r=!0}return t.apply(this,arguments)}}},44123:function(t){t.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},15724:function(t,e,r){\"use strict\";var n=r(40280),i=r(80340),a=r(96835),o=r(15628);function s(t){return t.call.bind(t)}var l=\"undefined\"!=typeof BigInt,c=\"undefined\"!=typeof Symbol,u=s(Object.prototype.toString),h=s(Number.prototype.valueOf),f=s(String.prototype.valueOf),p=s(Boolean.prototype.valueOf);if(l)var d=s(BigInt.prototype.valueOf);if(c)var m=s(Symbol.prototype.valueOf);function g(t,e){if(\"object\"!=typeof t)return!1;try{return e(t),!0}catch(t){return!1}}function y(t){return\"[object Map]\"===u(t)}function v(t){return\"[object Set]\"===u(t)}function x(t){return\"[object WeakMap]\"===u(t)}function _(t){return\"[object WeakSet]\"===u(t)}function b(t){return\"[object ArrayBuffer]\"===u(t)}function w(t){return\"undefined\"!=typeof ArrayBuffer&&(b.working?b(t):t instanceof ArrayBuffer)}function T(t){return\"[object DataView]\"===u(t)}function k(t){return\"undefined\"!=typeof DataView&&(T.working?T(t):t instanceof DataView)}e.isArgumentsObject=n,e.isGeneratorFunction=i,e.isTypedArray=o,e.isPromise=function(t){return\"undefined\"!=typeof Promise&&t instanceof Promise||null!==t&&\"object\"==typeof t&&\"function\"==typeof t.then&&\"function\"==typeof t.catch},e.isArrayBufferView=function(t){return\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(t):o(t)||k(t)},e.isUint8Array=function(t){return\"Uint8Array\"===a(t)},e.isUint8ClampedArray=function(t){return\"Uint8ClampedArray\"===a(t)},e.isUint16Array=function(t){return\"Uint16Array\"===a(t)},e.isUint32Array=function(t){return\"Uint32Array\"===a(t)},e.isInt8Array=function(t){return\"Int8Array\"===a(t)},e.isInt16Array=function(t){return\"Int16Array\"===a(t)},e.isInt32Array=function(t){return\"Int32Array\"===a(t)},e.isFloat32Array=function(t){return\"Float32Array\"===a(t)},e.isFloat64Array=function(t){return\"Float64Array\"===a(t)},e.isBigInt64Array=function(t){return\"BigInt64Array\"===a(t)},e.isBigUint64Array=function(t){return\"BigUint64Array\"===a(t)},y.working=\"undefined\"!=typeof Map&&y(new Map),e.isMap=function(t){return\"undefined\"!=typeof Map&&(y.working?y(t):t instanceof Map)},v.working=\"undefined\"!=typeof Set&&v(new Set),e.isSet=function(t){return\"undefined\"!=typeof Set&&(v.working?v(t):t instanceof Set)},x.working=\"undefined\"!=typeof WeakMap&&x(new WeakMap),e.isWeakMap=function(t){return\"undefined\"!=typeof WeakMap&&(x.working?x(t):t instanceof WeakMap)},_.working=\"undefined\"!=typeof WeakSet&&_(new WeakSet),e.isWeakSet=function(t){return _(t)},b.working=\"undefined\"!=typeof ArrayBuffer&&b(new ArrayBuffer),e.isArrayBuffer=w,T.working=\"undefined\"!=typeof ArrayBuffer&&\"undefined\"!=typeof DataView&&T(new DataView(new ArrayBuffer(1),0,1)),e.isDataView=k;var A=\"undefined\"!=typeof SharedArrayBuffer?SharedArrayBuffer:void 0;function M(t){return\"[object SharedArrayBuffer]\"===u(t)}function S(t){return void 0!==A&&(void 0===M.working&&(M.working=M(new A)),M.working?M(t):t instanceof A)}function E(t){return g(t,h)}function C(t){return g(t,f)}function L(t){return g(t,p)}function I(t){return l&&g(t,d)}function P(t){return c&&g(t,m)}e.isSharedArrayBuffer=S,e.isAsyncFunction=function(t){return\"[object AsyncFunction]\"===u(t)},e.isMapIterator=function(t){return\"[object Map Iterator]\"===u(t)},e.isSetIterator=function(t){return\"[object Set Iterator]\"===u(t)},e.isGeneratorObject=function(t){return\"[object Generator]\"===u(t)},e.isWebAssemblyCompiledModule=function(t){return\"[object WebAssembly.Module]\"===u(t)},e.isNumberObject=E,e.isStringObject=C,e.isBooleanObject=L,e.isBigIntObject=I,e.isSymbolObject=P,e.isBoxedPrimitive=function(t){return E(t)||C(t)||L(t)||I(t)||P(t)},e.isAnyArrayBuffer=function(t){return\"undefined\"!=typeof Uint8Array&&(w(t)||S(t))},[\"isProxy\",\"isExternal\",\"isModuleNamespaceObject\"].forEach((function(t){Object.defineProperty(e,t,{enumerable:!1,value:function(){throw new Error(t+\" is not supported in userland\")}})}))},56557:function(t,e,r){var n=r(33282),i=Object.getOwnPropertyDescriptors||function(t){for(var e=Object.keys(t),r={},n=0;n<e.length;n++)r[e[n]]=Object.getOwnPropertyDescriptor(t,e[n]);return r},a=/%[sdj%]/g;e.format=function(t){if(!x(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(c(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,i=n.length,o=String(t).replace(a,(function(t){if(\"%%\"===t)return\"%\";if(r>=i)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}})),s=n[r];r<i;s=n[++r])y(s)||!w(s)?o+=\" \"+s:o+=\" \"+c(s);return o},e.deprecate=function(t,r){if(void 0!==n&&!0===n.noDeprecation)return t;if(void 0===n)return function(){return e.deprecate(t,r).apply(this,arguments)};var i=!1;return function(){if(!i){if(n.throwDeprecation)throw new Error(r);n.traceDeprecation?console.trace(r):console.error(r),i=!0}return t.apply(this,arguments)}};var o={},s=/^$/;if(n.env.NODE_DEBUG){var l=n.env.NODE_DEBUG;l=l.replace(/[|\\\\{}()[\\]^$+?.]/g,\"\\\\$&\").replace(/\\*/g,\".*\").replace(/,/g,\"$|^\").toUpperCase(),s=new RegExp(\"^\"+l+\"$\",\"i\")}function c(t,r){var n={seen:[],stylize:h};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),g(r)?n.showHidden=r:r&&e._extend(n,r),_(n.showHidden)&&(n.showHidden=!1),_(n.depth)&&(n.depth=2),_(n.colors)&&(n.colors=!1),_(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=u),f(n,t,n.depth)}function u(t,e){var r=c.styles[e];return r?\"\u001b[\"+c.colors[r][0]+\"m\"+t+\"\u001b[\"+c.colors[r][1]+\"m\":t}function h(t,e){return t}function f(t,r,n){if(t.customInspect&&r&&A(r.inspect)&&r.inspect!==e.inspect&&(!r.constructor||r.constructor.prototype!==r)){var i=r.inspect(n,t);return x(i)||(i=f(t,i,n)),i}var a=function(t,e){if(_(e))return t.stylize(\"undefined\",\"undefined\");if(x(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}return v(e)?t.stylize(\"\"+e,\"number\"):g(e)?t.stylize(\"\"+e,\"boolean\"):y(e)?t.stylize(\"null\",\"null\"):void 0}(t,r);if(a)return a;var o=Object.keys(r),s=function(t){var e={};return t.forEach((function(t,r){e[t]=!0})),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(r)),k(r)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return p(r);if(0===o.length){if(A(r)){var l=r.name?\": \"+r.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(b(r))return t.stylize(RegExp.prototype.toString.call(r),\"regexp\");if(T(r))return t.stylize(Date.prototype.toString.call(r),\"date\");if(k(r))return p(r)}var c,u=\"\",h=!1,w=[\"{\",\"}\"];return m(r)&&(h=!0,w=[\"[\",\"]\"]),A(r)&&(u=\" [Function\"+(r.name?\": \"+r.name:\"\")+\"]\"),b(r)&&(u=\" \"+RegExp.prototype.toString.call(r)),T(r)&&(u=\" \"+Date.prototype.toUTCString.call(r)),k(r)&&(u=\" \"+p(r)),0!==o.length||h&&0!=r.length?n<0?b(r)?t.stylize(RegExp.prototype.toString.call(r),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(r),c=h?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)C(e,String(o))?a.push(d(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach((function(i){i.match(/^\\d+$/)||a.push(d(t,e,r,n,i,!0))})),a}(t,r,n,s,o):o.map((function(e){return d(t,r,n,s,e,h)})),t.seen.pop(),function(t,e,r){return t.reduce((function(t,e){return e.indexOf(\"\\n\"),t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1}),0)>60?r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1]:r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,u,w)):w[0]+u+w[1]}function p(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function d(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),C(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=y(r)?f(t,l.value,null):f(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map((function(t){return\"  \"+t})).join(\"\\n\").slice(2):\"\\n\"+s.split(\"\\n\").map((function(t){return\"   \"+t})).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),_(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.slice(1,-1),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function m(t){return Array.isArray(t)}function g(t){return\"boolean\"==typeof t}function y(t){return null===t}function v(t){return\"number\"==typeof t}function x(t){return\"string\"==typeof t}function _(t){return void 0===t}function b(t){return w(t)&&\"[object RegExp]\"===M(t)}function w(t){return\"object\"==typeof t&&null!==t}function T(t){return w(t)&&\"[object Date]\"===M(t)}function k(t){return w(t)&&(\"[object Error]\"===M(t)||t instanceof Error)}function A(t){return\"function\"==typeof t}function M(t){return Object.prototype.toString.call(t)}function S(t){return t<10?\"0\"+t.toString(10):t.toString(10)}e.debuglog=function(t){if(t=t.toUpperCase(),!o[t])if(s.test(t)){var r=n.pid;o[t]=function(){var n=e.format.apply(e,arguments);console.error(\"%s %d: %s\",t,r,n)}}else o[t]=function(){};return o[t]},e.inspect=c,c.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},c.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},e.types=r(15724),e.isArray=m,e.isBoolean=g,e.isNull=y,e.isNullOrUndefined=function(t){return null==t},e.isNumber=v,e.isString=x,e.isSymbol=function(t){return\"symbol\"==typeof t},e.isUndefined=_,e.isRegExp=b,e.types.isRegExp=b,e.isObject=w,e.isDate=T,e.types.isDate=T,e.isError=k,e.types.isNativeError=k,e.isFunction=A,e.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||void 0===t},e.isBuffer=r(44123);var E=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function C(t,e){return Object.prototype.hasOwnProperty.call(t,e)}e.log=function(){var t,r;console.log(\"%s - %s\",(r=[S((t=new Date).getHours()),S(t.getMinutes()),S(t.getSeconds())].join(\":\"),[t.getDate(),E[t.getMonth()],r].join(\" \")),e.format.apply(e,arguments))},e.inherits=r(28062),e._extend=function(t,e){if(!e||!w(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t};var L=\"undefined\"!=typeof Symbol?Symbol(\"util.promisify.custom\"):void 0;function I(t,e){if(!t){var r=new Error(\"Promise was rejected with a falsy value\");r.reason=t,t=r}return e(t)}e.promisify=function(t){if(\"function\"!=typeof t)throw new TypeError('The \"original\" argument must be of type Function');if(L&&t[L]){var e;if(\"function\"!=typeof(e=t[L]))throw new TypeError('The \"util.promisify.custom\" argument must be of type Function');return Object.defineProperty(e,L,{value:e,enumerable:!1,writable:!1,configurable:!0}),e}function e(){for(var e,r,n=new Promise((function(t,n){e=t,r=n})),i=[],a=0;a<arguments.length;a++)i.push(arguments[a]);i.push((function(t,n){t?r(t):e(n)}));try{t.apply(this,i)}catch(t){r(t)}return n}return Object.setPrototypeOf(e,Object.getPrototypeOf(t)),L&&Object.defineProperty(e,L,{value:e,enumerable:!1,writable:!1,configurable:!0}),Object.defineProperties(e,i(t))},e.promisify.custom=L,e.callbackify=function(t){if(\"function\"!=typeof t)throw new TypeError('The \"original\" argument must be of type Function');function e(){for(var e=[],r=0;r<arguments.length;r++)e.push(arguments[r]);var i=e.pop();if(\"function\"!=typeof i)throw new TypeError(\"The last argument must be of type Function\");var a=this,o=function(){return i.apply(a,arguments)};t.apply(this,e).then((function(t){n.nextTick(o.bind(null,null,t))}),(function(t){n.nextTick(I.bind(null,t,o))}))}return Object.setPrototypeOf(e,Object.getPrototypeOf(t)),Object.defineProperties(e,i(t)),e}},22248:function(t,e,r){var n=r(72880);t.exports=function(t){return n(\"webgl\",t)}},96835:function(t,e,r){\"use strict\";var n=r(61262),i=r(70085),a=r(87227),o=r(63063),s=r(52991),l=o(\"Object.prototype.toString\"),c=r(36912)(),u=\"undefined\"==typeof globalThis?r.g:globalThis,h=i(),f=o(\"String.prototype.slice\"),p=Object.getPrototypeOf,d=o(\"Array.prototype.indexOf\",!0)||function(t,e){for(var r=0;r<t.length;r+=1)if(t[r]===e)return r;return-1},m={__proto__:null};n(h,c&&s&&p?function(t){var e=new u[t];if(Symbol.toStringTag in e){var r=p(e),n=s(r,Symbol.toStringTag);if(!n){var i=p(r);n=s(i,Symbol.toStringTag)}m[\"$\"+t]=a(n.get)}}:function(t){var e=new u[t],r=e.slice||e.set;r&&(m[\"$\"+t]=a(r))}),t.exports=function(t){if(!t||\"object\"!=typeof t)return!1;if(!c){var e=f(l(t),8,-1);return d(h,e)>-1?e:\"Object\"===e&&function(t){var e=!1;return n(m,(function(r,n){if(!e)try{r(t),e=f(n,1)}catch(t){}})),e}(t)}return s?function(t){var e=!1;return n(m,(function(r,n){if(!e)try{\"$\"+r(t)===n&&(e=f(n,1))}catch(t){}})),e}(t):null}},1401:function(t,e,r){var n=r(24453),i=r(27976),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\u4e00\u6708\",\"\u4e8c\u6708\",\"\u4e09\u6708\",\"\u56db\u6708\",\"\u4e94\u6708\",\"\u516d\u6708\",\"\u4e03\u6708\",\"\u516b\u6708\",\"\u4e5d\u6708\",\"\u5341\u6708\",\"\u5341\u4e00\u6708\",\"\u5341\u4e8c\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\u4e00\",\"\u4e8c\",\"\u4e09\",\"\u56db\",\"\u4e94\",\"\u516d\",\"\u4e03\",\"\u516b\",\"\u4e5d\",\"\u5341\",\"\u5341\u4e00\",\"\u5341\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\u4e00\",\"\u4e8c\",\"\u4e09\",\"\u56db\",\"\u4e94\",\"\u516d\",\"\u4e03\",\"\u516b\",\"\u4e5d\",\"\u5341\",\"\u5341\u4e00\",\"\u5341\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l;if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Lunar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Lunar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=30))throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(l=!1,a=n):(l=!!n,a={}),o={year:t,month:e,day:r,isIntercalary:l}}s=o.day-1;var c,u=h[o.year-h[0]],p=u>>13;c=p&&(o.month>p||o.isIntercalary)?o.month:o.month-1;for(var d=0;d<c;d++)s+=u&1<<12-d?30:29;var m=f[o.year-f[0]],g=new Date(m>>9&4095,(m>>5&15)-1,(31&m)+s);return a.year=g.getFullYear(),a.month=1+g.getMonth(),a.day=g.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Solar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Solar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=31))throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a={}}var o=f[i.year-f[0]],s=i.year<<9|i.month<<5|i.day;a.year=s>=o?i.year:i.year-1,o=f[a.year-f[0]];var l,c=new Date(o>>9&4095,(o>>5&15)-1,31&o),u=new Date(i.year,i.month-1,i.day);l=Math.round((u-c)/864e5);var p,d=h[a.year-h[0]];for(p=0;p<13;p++){var m=d&1<<12-p?30:29;if(l<m)break;l-=m}var g=d>>13;return!g||p<g?(a.isIntercalary=!1,a.month=1+p):p===g?(a.isIntercalary=!0,a.month=p):(a.isIntercalary=!1,a.month=p),a.day=1+l,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-/](\\d?\\d)([iI]?)[-/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\u95f0?\u5341?[\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d]?\u6708/m,u=/^\u95f0?\u5341?[\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},72210:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},28569:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},81133:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},78295:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)||8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},25512:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},42645:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},62324:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o(8+(t-=this.jdEpoch)+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s(20+(t-=this.jdEpoch),20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},91662:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},66445:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),void 0===this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),void 0===this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)void 0===this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2e3:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},50506:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\u00e6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\u00e6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},84756:function(t,e,r){var n=r(24453),i=r(27976),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return t=this._t2gYear(e.year()),a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return t=this._t2gYear(i.year()),a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=this._t2gYear(i.year()),a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},41858:function(t,e,r){var n=r(24453),i=r(27976),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return t=this._t2gYear(e.year()),a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return t=this._t2gYear(i.year()),a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=this._t2gYear(i.year()),a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},57985:function(t,e,r){var n=r(24453),i=r(27976);function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\u0101th\u0101\u2019\",\"Yawm al-Arba\u2018\u0101\u2019\",\"Yawm al-Kham\u012bs\",\"Yawm al-Jum\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},24453:function(t,e,r){var n=r(27976);function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,(function(e){return t[e]}))}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day(),\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=1524+(r=e+1+r-Math.floor(r/4)),i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=t.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},23428:function(t,e,r){var n=r(27976),i=r(24453);n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s=(r=r||{}).dayNamesShort||this.local.dayNamesShort,l=r.dayNames||this.local.dayNames,c=r.monthNumbers||this.local.monthNumbers,u=r.monthNamesShort||this.local.monthNamesShort,h=r.monthNames||this.local.monthNames,f=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;b+n<t.length&&t.charAt(b+n)===e;)n++;return b+=n-1,Math.floor(n/(r||1))>1}),p=function(t,e,r,n){var i=\"\"+e;if(f(t,n))for(;i.length<r;)i=\"0\"+i;return i},d=this,m=function(t){return\"function\"==typeof c?c.call(d,t,f(\"m\")):v(p(\"m\",t.month(),2))},g=function(t,e){return e?\"function\"==typeof h?h.call(d,t):h[t.month()-d.minMonth]:\"function\"==typeof u?u.call(d,t):u[t.month()-d.minMonth]},y=this.local.digits,v=function(t){return r.localNumbers&&y?y(t):t},x=\"\",_=!1,b=0;b<t.length;b++)if(_)\"'\"!==t.charAt(b)||f(\"'\")?x+=t.charAt(b):_=!1;else switch(t.charAt(b)){case\"d\":x+=v(p(\"d\",e.day(),2));break;case\"D\":x+=(\"D\",n=e.dayOfWeek(),a=s,o=l,f(\"D\")?o[n]:a[n]);break;case\"o\":x+=p(\"o\",e.dayOfYear(),3);break;case\"w\":x+=p(\"w\",e.weekOfYear(),2);break;case\"m\":x+=m(e);break;case\"M\":x+=g(e,f(\"M\"));break;case\"y\":x+=f(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":f(\"Y\",2),x+=e.formatYear();break;case\"J\":x+=e.toJD();break;case\"@\":x+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":x+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":f(\"'\")?x+=\"'\":_=!0;break;default:x+=t.charAt(b)}return x},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,m=-1,g=!1,y=!1,v=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=v(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},_=this,b=function(){if(\"function\"==typeof l){v(\"m\");var t=l.call(_,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=v(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+_.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},T=function(){if(\"function\"==typeof u){var t=v(\"M\")?u.call(_,e.substring(A)):c.call(_,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},k=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(y)\"'\"!==t.charAt(M)||v(\"'\")?k():y=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":m=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=b();break;case\"M\":p=T();break;case\"y\":var S=M;g=!v(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":v(\"'\")?k():y=!0;break;default:k()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&g&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),m>-1){p=1,d=m;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},96144:function(t,e,r){\"use strict\";r.r(e);var n=r(85072),i=r.n(n),a=r(97825),o=r.n(a),s=r(77659),l=r.n(s),c=r(55056),u=r.n(c),h=r(10540),f=r.n(h),p=r(41113),d=r.n(p),m=r(5955),g={};g.styleTagTransform=d(),g.setAttributes=u(),g.insert=l().bind(null,\"head\"),g.domAPI=o(),g.insertStyleElement=f(),i()(m.A,g),e.default=m.A&&m.A.locals?m.A.locals:void 0},85072:function(t){\"use strict\";var e=[];function r(t){for(var r=-1,n=0;n<e.length;n++)if(e[n].identifier===t){r=n;break}return r}function n(t,n){for(var a={},o=[],s=0;s<t.length;s++){var l=t[s],c=n.base?l[0]+n.base:l[0],u=a[c]||0,h=\"\".concat(c,\" \").concat(u);a[c]=u+1;var f=r(h),p={css:l[1],media:l[2],sourceMap:l[3],supports:l[4],layer:l[5]};if(-1!==f)e[f].references++,e[f].updater(p);else{var d=i(p,n);n.byIndex=s,e.splice(s,0,{identifier:h,updater:d,references:1})}o.push(h)}return o}function i(t,e){var r=e.domAPI(e);return r.update(t),function(e){if(e){if(e.css===t.css&&e.media===t.media&&e.sourceMap===t.sourceMap&&e.supports===t.supports&&e.layer===t.layer)return;r.update(t=e)}else r.remove()}}t.exports=function(t,i){var a=n(t=t||[],i=i||{});return function(t){t=t||[];for(var o=0;o<a.length;o++){var s=r(a[o]);e[s].references--}for(var l=n(t,i),c=0;c<a.length;c++){var u=r(a[c]);0===e[u].references&&(e[u].updater(),e.splice(u,1))}a=l}}},77659:function(t){\"use strict\";var e={};t.exports=function(t,r){var n=function(t){if(void 0===e[t]){var r=document.querySelector(t);if(window.HTMLIFrameElement&&r instanceof window.HTMLIFrameElement)try{r=r.contentDocument.head}catch(t){r=null}e[t]=r}return e[t]}(t);if(!n)throw new Error(\"Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.\");n.appendChild(r)}},10540:function(t){\"use strict\";t.exports=function(t){var e=document.createElement(\"style\");return t.setAttributes(e,t.attributes),t.insert(e,t.options),e}},55056:function(t,e,r){\"use strict\";t.exports=function(t){var e=r.nc;e&&t.setAttribute(\"nonce\",e)}},97825:function(t){\"use strict\";t.exports=function(t){if(\"undefined\"==typeof document)return{update:function(){},remove:function(){}};var e=t.insertStyleElement(t);return{update:function(r){!function(t,e,r){var n=\"\";r.supports&&(n+=\"@supports (\".concat(r.supports,\") {\")),r.media&&(n+=\"@media \".concat(r.media,\" {\"));var i=void 0!==r.layer;i&&(n+=\"@layer\".concat(r.layer.length>0?\" \".concat(r.layer):\"\",\" {\")),n+=r.css,i&&(n+=\"}\"),r.media&&(n+=\"}\"),r.supports&&(n+=\"}\");var a=r.sourceMap;a&&\"undefined\"!=typeof btoa&&(n+=\"\\n/*# sourceMappingURL=data:application/json;base64,\".concat(btoa(unescape(encodeURIComponent(JSON.stringify(a)))),\" */\")),e.styleTagTransform(n,t,e.options)}(e,t,r)},remove:function(){!function(t){if(null===t.parentNode)return!1;t.parentNode.removeChild(t)}(e)}}}},41113:function(t){\"use strict\";t.exports=function(t,e){if(e.styleSheet)e.styleSheet.cssText=t;else{for(;e.firstChild;)e.removeChild(e.firstChild);e.appendChild(document.createTextNode(t))}}},25446:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2722%27 height=%2722%27 fill=%27%23333%27 viewBox=%270 0 22 22%27%3E%3Cpath d=%27m1.754 13.406 4.453-4.851 3.09 3.09 3.281 3.277.969-.969-3.309-3.312 3.844-4.121 6.148 6.886h1.082v-.855l-7.207-8.07-4.84 5.187L6.169 6.57l-5.48 5.965v.871ZM.688 16.844h20.625v1.375H.688Zm0 0%27/%3E%3C/svg%3E\"},56694:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2722%27 height=%2722%27 fill=%27%2333b5e5%27 viewBox=%270 0 22 22%27%3E%3Cpath d=%27m1.754 13.406 4.453-4.851 3.09 3.09 3.281 3.277.969-.969-3.309-3.312 3.844-4.121 6.148 6.886h1.082v-.855l-7.207-8.07-4.84 5.187L6.169 6.57l-5.48 5.965v.871ZM.688 16.844h20.625v1.375H.688Zm0 0%27/%3E%3C/svg%3E\"},26117:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2724%27 height=%2724%27 fill-rule=%27evenodd%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M4 10a6 6 0 1 0 12 0 6 6 0 1 0-12 0m5-3a1 1 0 1 0 2 0 1 1 0 1 0-2 0m0 3a1 1 0 1 1 2 0v3a1 1 0 1 1-2 0%27/%3E%3C/svg%3E\"},66311:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2724%27 height=%2724%27 fill=%27%23fff%27 fill-rule=%27evenodd%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M4 10a6 6 0 1 0 12 0 6 6 0 1 0-12 0m5-3a1 1 0 1 0 2 0 1 1 0 1 0-2 0m0 3a1 1 0 1 1 2 0v3a1 1 0 1 1-2 0%27/%3E%3C/svg%3E\"},24420:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23333%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3C/svg%3E\"},77035:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23333%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M10 13c-.75 0-1.5.75-1.5 1.5S9.25 16 10 16h9c.75 0 1.5-.75 1.5-1.5S19.75 13 19 13z%27/%3E%3C/svg%3E\"},43470:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23333%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M14.5 8.5c-.75 0-1.5.75-1.5 1.5v3h-3c-.75 0-1.5.75-1.5 1.5S9.25 16 10 16h3v3c0 .75.75 1.5 1.5 1.5S16 19.75 16 19v-3h3c.75 0 1.5-.75 1.5-1.5S19.75 13 19 13h-3v-3c0-.75-.75-1.5-1.5-1.5%27/%3E%3C/svg%3E\"},13490:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23333%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M24 16v5.5c0 1.75-.75 2.5-2.5 2.5H16v-1l3-1.5-4-5.5 1-1 5.5 4 1.5-3zM6 16l1.5 3 5.5-4 1 1-4 5.5 3 1.5v1H7.5C5.75 24 5 23.25 5 21.5V16zm7-11v1l-3 1.5 4 5.5-1 1-5.5-4L6 13H5V7.5C5 5.75 5.75 5 7.5 5zm11 2.5c0-1.75-.75-2.5-2.5-2.5H16v1l3 1.5-4 5.5 1 1 5.5-4 1.5 3h1z%27/%3E%3C/svg%3E\"},80216:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23333%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27m10.5 14 4-8 4 8z%27/%3E%3Cpath fill=%27%23ccc%27 d=%27m10.5 16 4 8 4-8z%27/%3E%3C/svg%3E\"},47695:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%2333b5e5%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3C/svg%3E\"},92228:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%2333b5e5%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3C/svg%3E\"},43737:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23666%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3Cpath fill=%27red%27 d=%27m14 5 1 1-9 9-1-1z%27/%3E%3C/svg%3E\"},48460:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23999%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3Cpath fill=%27red%27 d=%27m14 5 1 1-9 9-1-1z%27/%3E%3C/svg%3E\"},75796:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23aaa%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3Cpath fill=%27red%27 d=%27m14 5 1 1-9 9-1-1z%27/%3E%3C/svg%3E\"},28869:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23e54e33%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3C/svg%3E\"},9819:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23e58978%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3C/svg%3E\"},30557:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23fff%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3C/svg%3E\"},68164:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23fff%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M10 13c-.75 0-1.5.75-1.5 1.5S9.25 16 10 16h9c.75 0 1.5-.75 1.5-1.5S19.75 13 19 13z%27/%3E%3C/svg%3E\"},64665:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23fff%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M14.5 8.5c-.75 0-1.5.75-1.5 1.5v3h-3c-.75 0-1.5.75-1.5 1.5S9.25 16 10 16h3v3c0 .75.75 1.5 1.5 1.5S16 19.75 16 19v-3h3c.75 0 1.5-.75 1.5-1.5S19.75 13 19 13h-3v-3c0-.75-.75-1.5-1.5-1.5%27/%3E%3C/svg%3E\"},91413:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23fff%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M18.5 16c-1.75 0-2.5.75-2.5 2.5V24h1l1.5-3 5.5 4 1-1-4-5.5 3-1.5v-1zM13 18.5c0-1.75-.75-2.5-2.5-2.5H5v1l3 1.5L4 24l1 1 5.5-4 1.5 3h1zm3-8c0 1.75.75 2.5 2.5 2.5H24v-1l-3-1.5L25 5l-1-1-5.5 4L17 5h-1zM10.5 13c1.75 0 2.5-.75 2.5-2.5V5h-1l-1.5 3L5 4 4 5l4 5.5L5 12v1z%27/%3E%3C/svg%3E\"},13913:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23fff%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M24 16v5.5c0 1.75-.75 2.5-2.5 2.5H16v-1l3-1.5-4-5.5 1-1 5.5 4 1.5-3zM6 16l1.5 3 5.5-4 1 1-4 5.5 3 1.5v1H7.5C5.75 24 5 23.25 5 21.5V16zm7-11v1l-3 1.5 4 5.5-1 1-5.5-4L6 13H5V7.5C5 5.75 5.75 5 7.5 5zm11 2.5c0-1.75-.75-2.5-2.5-2.5H16v1l3 1.5-4 5.5 1 1 5.5-4 1.5 3h1z%27/%3E%3C/svg%3E\"},61907:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 fill=%27%23fff%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27m10.5 14 4-8 4 8z%27/%3E%3Cpath fill=%27%23ccc%27 d=%27m10.5 16 4 8 4-8z%27/%3E%3C/svg%3E\"},56539:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 viewBox=%270 0 20 20%27%3E%3Cpath d=%27M10 4C9 4 9 5 9 5v.1A5 5 0 0 0 5.1 9H5s-1 0-1 1 1 1 1 1h.1A5 5 0 0 0 9 14.9v.1s0 1 1 1 1-1 1-1v-.1a5 5 0 0 0 3.9-3.9h.1s1 0 1-1-1-1-1-1h-.1A5 5 0 0 0 11 5.1V5s0-1-1-1m0 2.5a3.5 3.5 0 1 1 0 7 3.5 3.5 0 1 1 0-7%27/%3E%3Ccircle cx=%2710%27 cy=%2710%27 r=%272%27/%3E%3C/svg%3E\"},4890:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M10 13c-.75 0-1.5.75-1.5 1.5S9.25 16 10 16h9c.75 0 1.5-.75 1.5-1.5S19.75 13 19 13z%27/%3E%3C/svg%3E\"},13363:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M14.5 8.5c-.75 0-1.5.75-1.5 1.5v3h-3c-.75 0-1.5.75-1.5 1.5S9.25 16 10 16h3v3c0 .75.75 1.5 1.5 1.5S16 19.75 16 19v-3h3c.75 0 1.5-.75 1.5-1.5S19.75 13 19 13h-3v-3c0-.75-.75-1.5-1.5-1.5%27/%3E%3C/svg%3E\"},47603:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M18.5 16c-1.75 0-2.5.75-2.5 2.5V24h1l1.5-3 5.5 4 1-1-4-5.5 3-1.5v-1zM13 18.5c0-1.75-.75-2.5-2.5-2.5H5v1l3 1.5L4 24l1 1 5.5-4 1.5 3h1zm3-8c0 1.75.75 2.5 2.5 2.5H24v-1l-3-1.5L25 5l-1-1-5.5 4L17 5h-1zM10.5 13c1.75 0 2.5-.75 2.5-2.5V5h-1l-1.5 3L5 4 4 5l4 5.5L5 12v1z%27/%3E%3C/svg%3E\"},64643:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27M24 16v5.5c0 1.75-.75 2.5-2.5 2.5H16v-1l3-1.5-4-5.5 1-1 5.5 4 1.5-3zM6 16l1.5 3 5.5-4 1 1-4 5.5 3 1.5v1H7.5C5.75 24 5 23.25 5 21.5V16zm7-11v1l-3 1.5 4 5.5-1 1-5.5-4L6 13H5V7.5C5 5.75 5.75 5 7.5 5zm11 2.5c0-1.75-.75-2.5-2.5-2.5H16v1l3 1.5-4 5.5 1 1 5.5-4 1.5 3h1z%27/%3E%3C/svg%3E\"},68605:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2729%27 height=%2729%27 viewBox=%270 0 29 29%27%3E%3Cpath d=%27m10.5 14 4-8 4 8z%27/%3E%3Cpath fill=%27%23ccc%27 d=%27m10.5 16 4 8 4-8z%27/%3E%3C/svg%3E\"},47914:function(t){\"use strict\";t.exports=\"data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 width=%2788%27 height=%2723%27 fill=%27none%27%3E%3Cpath fill=%27%23000%27 fill-opacity=%27.4%27 fill-rule=%27evenodd%27 d=%27M17.408 16.796h-1.827l2.501-12.095h.198l3.324 6.533.988 2.19.988-2.19 3.258-6.533h.181l2.6 12.095h-1.81l-1.218-5.644-.362-1.71-.658 1.71-2.929 5.644h-.098l-2.914-5.644-.757-1.71-.345 1.71zm1.958-3.42-.726 3.663a1.255 1.255 0 0 1-1.232 1.011h-1.827a1.255 1.255 0 0 1-1.229-1.509l2.501-12.095a1.255 1.255 0 0 1 1.23-1.001h.197a1.25 1.25 0 0 1 1.12.685l3.19 6.273 3.125-6.263a1.25 1.25 0 0 1 1.123-.695h.181a1.255 1.255 0 0 1 1.227.991l1.443 6.71a5 5 0 0 1 .314-.787l.009-.016a4.6 4.6 0 0 1 1.777-1.887c.782-.46 1.668-.667 2.611-.667a4.6 4.6 0 0 1 1.7.32l.306.134c.21-.16.474-.256.759-.256h1.694a1.255 1.255 0 0 1 1.212.925 1.255 1.255 0 0 1 1.212-.925h1.711c.284 0 .545.094.755.252.613-.3 1.312-.45 2.075-.45 1.356 0 2.557.445 3.482 1.4q.47.48.763 1.064V4.701a1.255 1.255 0 0 1 1.255-1.255h1.86A1.255 1.255 0 0 1 54.44 4.7v9.194h2.217c.19 0 .37.043.532.118v-4.77c0-.356.147-.678.385-.906a2.42 2.42 0 0 1-.682-1.71c0-.665.267-1.253.735-1.7a2.45 2.45 0 0 1 1.722-.674 2.43 2.43 0 0 1 1.705.675q.318.302.504.683V4.7a1.255 1.255 0 0 1 1.255-1.255h1.744A1.255 1.255 0 0 1 65.812 4.7v3.335a4.8 4.8 0 0 1 1.526-.246c.938 0 1.817.214 2.59.69a4.47 4.47 0 0 1 1.67 1.743v-.98a1.255 1.255 0 0 1 1.256-1.256h1.777c.233 0 .451.064.639.174a3.4 3.4 0 0 1 1.567-.372c.346 0 .861.02 1.285.232a1.25 1.25 0 0 1 .689 1.004 4.7 4.7 0 0 1 .853-.588c.795-.44 1.675-.647 2.61-.647 1.385 0 2.65.39 3.525 1.396.836.938 1.168 2.173 1.168 3.528q-.001.515-.056 1.051a1.255 1.255 0 0 1-.947 1.09l.408.952a1.255 1.255 0 0 1-.477 1.552c-.418.268-.92.463-1.458.612-.613.171-1.304.244-2.049.244-1.06 0-2.043-.207-2.886-.698l-.015-.008c-.798-.48-1.419-1.135-1.818-1.963l-.004-.008a5.8 5.8 0 0 1-.548-2.512q0-.429.053-.843a1.3 1.3 0 0 1-.333-.086l-.166-.004c-.223 0-.426.062-.643.228-.03.024-.142.139-.142.59v3.883a1.255 1.255 0 0 1-1.256 1.256h-1.777a1.255 1.255 0 0 1-1.256-1.256V15.69l-.032.057a4.8 4.8 0 0 1-1.86 1.833 5.04 5.04 0 0 1-2.484.634 4.5 4.5 0 0 1-1.935-.424 1.25 1.25 0 0 1-.764.258h-1.71a1.255 1.255 0 0 1-1.256-1.255V7.687a2.4 2.4 0 0 1-.428.625c.253.23.412.561.412.93v7.553a1.255 1.255 0 0 1-1.256 1.255h-1.843a1.25 1.25 0 0 1-.894-.373c-.228.23-.544.373-.894.373H51.32a1.255 1.255 0 0 1-1.256-1.255v-1.251l-.061.117a4.7 4.7 0 0 1-1.782 1.884 4.77 4.77 0 0 1-2.485.67 5.6 5.6 0 0 1-1.485-.188l.009 2.764a1.255 1.255 0 0 1-1.255 1.259h-1.729a1.255 1.255 0 0 1-1.255-1.255v-3.537a1.255 1.255 0 0 1-1.167.793h-1.679a1.25 1.25 0 0 1-.77-.263 4.5 4.5 0 0 1-1.945.429c-.885 0-1.724-.21-2.495-.632l-.017-.01a5 5 0 0 1-1.081-.836 1.255 1.255 0 0 1-1.254 1.312h-1.81a1.255 1.255 0 0 1-1.228-.99l-.782-3.625-2.044 3.939a1.25 1.25 0 0 1-1.115.676h-.098a1.25 1.25 0 0 1-1.116-.68l-2.061-3.994zM35.92 16.63l.207-.114.223-.15q.493-.356.735-.785l.061-.118.033 1.332h1.678V9.242h-1.694l-.033 1.267q-.133-.329-.526-.658l-.032-.028a3.2 3.2 0 0 0-.668-.428l-.27-.12a3.3 3.3 0 0 0-1.235-.23q-1.136-.001-1.974.493a3.36 3.36 0 0 0-1.3 1.382q-.445.89-.444 2.074 0 1.2.51 2.107a3.8 3.8 0 0 0 1.382 1.381 3.9 3.9 0 0 0 1.893.477q.795 0 1.455-.33zm-2.789-5.38q-.576.675-.575 1.762 0 1.102.559 1.794.576.675 1.645.675a2.25 2.25 0 0 0 .934-.19 2.2 2.2 0 0 0 .468-.29l.178-.161a2.2 2.2 0 0 0 .397-.561q.244-.5.244-1.15v-.115q0-.708-.296-1.267l-.043-.077a2.2 2.2 0 0 0-.633-.709l-.13-.086-.047-.028a2.1 2.1 0 0 0-1.073-.285q-1.052 0-1.629.692zm2.316 2.706c.163-.17.28-.407.28-.83v-.114c0-.292-.06-.508-.15-.68a.96.96 0 0 0-.353-.389.85.85 0 0 0-.464-.127c-.4 0-.56.114-.664.239l-.01.012c-.148.174-.275.45-.275.945 0 .506.122.801.27.99.097.11.266.224.68.224.303 0 .504-.09.687-.269zm7.545 1.705a2.6 2.6 0 0 0 .331.423q.319.33.755.548l.173.074q.65.255 1.49.255 1.02 0 1.844-.493a3.45 3.45 0 0 0 1.316-1.4q.493-.904.493-2.089 0-1.909-.988-2.913-.988-1.02-2.584-1.02-.898 0-1.575.347a3 3 0 0 0-.415.262l-.199.166a3.4 3.4 0 0 0-.64.82V9.242h-1.712v11.553h1.729l-.017-5.134zm.53-1.138q.206.29.48.5l.155.11.053.034q.51.296 1.119.297 1.07 0 1.645-.675.577-.69.576-1.762 0-1.119-.576-1.777-.558-.675-1.645-.675-.435 0-.835.16a2 2 0 0 0-.284.136 2 2 0 0 0-.363.254 2.2 2.2 0 0 0-.46.569l-.082.162a2.6 2.6 0 0 0-.213 1.072v.115q0 .707.296 1.267l.135.211zm.964-.818a1.1 1.1 0 0 0 .367.385.94.94 0 0 0 .476.118c.423 0 .59-.117.687-.23.159-.194.28-.478.28-.95 0-.53-.133-.8-.266-.952l-.021-.025c-.078-.094-.231-.221-.68-.221a1 1 0 0 0-.503.135l-.012.007a.86.86 0 0 0-.335.343c-.073.133-.132.324-.132.614v.115a1.4 1.4 0 0 0 .14.66zm15.7-6.222q.347-.346.346-.856a1.05 1.05 0 0 0-.345-.79 1.18 1.18 0 0 0-.84-.329q-.51 0-.855.33a1.05 1.05 0 0 0-.346.79q0 .51.346.855.345.346.856.346.51 0 .839-.346zm4.337 9.314.033-1.332q.191.403.59.747l.098.081a4 4 0 0 0 .316.224l.223.122a3.2 3.2 0 0 0 1.44.322 3.8 3.8 0 0 0 1.875-.477 3.5 3.5 0 0 0 1.382-1.366q.527-.89.526-2.09 0-1.184-.444-2.073a3.24 3.24 0 0 0-1.283-1.399q-.823-.51-1.942-.51a3.5 3.5 0 0 0-1.527.344l-.086.043-.165.09a3 3 0 0 0-.33.214q-.432.315-.656.707a2 2 0 0 0-.099.198l.082-1.283V4.701h-1.744v12.095zm.473-2.509a2.5 2.5 0 0 0 .566.7q.117.098.245.18l.144.08a2.1 2.1 0 0 0 .975.232q1.07 0 1.645-.675.576-.69.576-1.778 0-1.102-.576-1.777-.56-.691-1.645-.692a2.2 2.2 0 0 0-1.015.235q-.22.113-.415.282l-.15.142a2.1 2.1 0 0 0-.42.594q-.223.479-.223 1.1v.115q0 .705.293 1.26zm2.616-.293c.157-.191.28-.479.28-.967 0-.51-.13-.79-.276-.961l-.021-.026c-.082-.1-.232-.225-.67-.225a.87.87 0 0 0-.681.279l-.012.011c-.154.155-.274.38-.274.807v.115c0 .285.057.499.144.669a1.1 1.1 0 0 0 .367.405c.137.082.28.123.455.123.423 0 .59-.118.686-.23zm8.266-3.013q.345-.13.724-.14l.069-.002q.493 0 .642.099l.247-1.794q-.196-.099-.717-.099a2.3 2.3 0 0 0-.545.063 2 2 0 0 0-.411.148 2.2 2.2 0 0 0-.4.249 2.5 2.5 0 0 0-.485.499 2.7 2.7 0 0 0-.32.581l-.05.137v-1.48h-1.778v7.553h1.777v-3.884q0-.546.159-.943a1.5 1.5 0 0 1 .466-.636 2.5 2.5 0 0 1 .399-.253 2 2 0 0 1 .224-.099zm9.784 2.656.05-.922q0-1.743-.856-2.698-.838-.97-2.584-.97-1.119-.001-2.007.493a3.46 3.46 0 0 0-1.4 1.382q-.493.906-.493 2.106 0 1.07.428 1.975.428.89 1.332 1.432.906.526 2.255.526.973 0 1.668-.185l.044-.012.135-.04q.613-.184.984-.421l-.542-1.267q-.3.162-.642.274l-.297.087q-.51.131-1.3.131-.954 0-1.497-.444a1.6 1.6 0 0 1-.192-.193q-.366-.44-.512-1.234l-.004-.021zm-5.427-1.256-.003.022h3.752v-.138q-.011-.727-.288-1.118a1 1 0 0 0-.156-.176q-.46-.428-1.316-.428-.986 0-1.494.604-.379.45-.494 1.234zm-27.053 2.77V4.7h-1.86v12.095h5.333V15.15zm7.103-5.908v7.553h-1.843V9.242h1.843z%27/%3E%3Cpath fill=%27%23fff%27 d=%27m19.63 11.151-.757-1.71-.345 1.71-1.12 5.644h-1.827L18.083 4.7h.197l3.325 6.533.988 2.19.988-2.19L26.839 4.7h.181l2.6 12.095h-1.81l-1.218-5.644-.362-1.71-.658 1.71-2.93 5.644h-.098l-2.913-5.644zm14.836 5.81q-1.02 0-1.893-.478a3.8 3.8 0 0 1-1.381-1.382q-.51-.906-.51-2.106 0-1.185.444-2.074a3.36 3.36 0 0 1 1.3-1.382q.839-.494 1.974-.494a3.3 3.3 0 0 1 1.234.231 3.3 3.3 0 0 1 .97.575q.396.33.527.659l.033-1.267h1.694v7.553H37.18l-.033-1.332q-.279.593-1.02 1.053a3.17 3.17 0 0 1-1.662.444zm.296-1.482q.938 0 1.58-.642.642-.66.642-1.711v-.115q0-.708-.296-1.267a2.2 2.2 0 0 0-.807-.872 2.1 2.1 0 0 0-1.119-.313q-1.053 0-1.629.692-.575.675-.575 1.76 0 1.103.559 1.795.577.675 1.645.675zm6.521-6.237h1.711v1.4q.906-1.597 2.83-1.597 1.596 0 2.584 1.02.988 1.005.988 2.914 0 1.185-.493 2.09a3.46 3.46 0 0 1-1.316 1.399 3.5 3.5 0 0 1-1.844.493q-.954 0-1.662-.329a2.67 2.67 0 0 1-1.086-.97l.017 5.134h-1.728zm4.048 6.22q1.07 0 1.645-.674.577-.69.576-1.762 0-1.119-.576-1.777-.558-.675-1.645-.675-.592 0-1.12.296-.51.28-.822.823-.296.527-.296 1.234v.115q0 .708.296 1.267.313.543.823.855.51.296 1.119.297z%27/%3E%3Cpath fill=%27%23e1e3e9%27 d=%27M51.325 4.7h1.86v10.45h3.473v1.646h-5.333zm7.12 4.542h1.843v7.553h-1.843zm.905-1.415a1.16 1.16 0 0 1-.856-.346 1.17 1.17 0 0 1-.346-.856 1.05 1.05 0 0 1 .346-.79q.346-.329.856-.329.494 0 .839.33a1.05 1.05 0 0 1 .345.79 1.16 1.16 0 0 1-.345.855q-.33.346-.84.346zm7.875 9.133a3.17 3.17 0 0 1-1.662-.444q-.723-.46-1.004-1.053l-.033 1.332h-1.71V4.701h1.743v4.657l-.082 1.283q.279-.658 1.086-1.119a3.5 3.5 0 0 1 1.778-.477q1.119 0 1.942.51a3.24 3.24 0 0 1 1.283 1.4q.445.888.444 2.072 0 1.201-.526 2.09a3.5 3.5 0 0 1-1.382 1.366 3.8 3.8 0 0 1-1.876.477zm-.296-1.481q1.069 0 1.645-.675.577-.69.577-1.778 0-1.102-.577-1.776-.56-.691-1.645-.692a2.12 2.12 0 0 0-1.58.659q-.642.641-.642 1.694v.115q0 .71.296 1.267a2.4 2.4 0 0 0 .807.872 2.1 2.1 0 0 0 1.119.313zm5.927-6.237h1.777v1.481q.263-.757.856-1.217a2.14 2.14 0 0 1 1.349-.46q.527 0 .724.098l-.247 1.794q-.149-.099-.642-.099-.774 0-1.416.494-.626.493-.626 1.58v3.883h-1.777V9.242zm9.534 7.718q-1.35 0-2.255-.526-.904-.543-1.332-1.432a4.6 4.6 0 0 1-.428-1.975q0-1.2.493-2.106a3.46 3.46 0 0 1 1.4-1.382q.889-.495 2.007-.494 1.744 0 2.584.97.855.956.856 2.7 0 .444-.05.92h-5.43q.18 1.005.708 1.45.542.443 1.497.443.79 0 1.3-.131a4 4 0 0 0 .938-.362l.542 1.267q-.411.263-1.119.46-.708.198-1.711.197zm1.596-4.558q.016-1.02-.444-1.432-.46-.428-1.316-.428-1.728 0-1.991 1.86z%27/%3E%3Cpath d=%27M5.074 15.948a.484.657 0 0 0-.486.659v1.84a.484.657 0 0 0 .486.659h4.101a.484.657 0 0 0 .486-.659v-1.84a.484.657 0 0 0-.486-.659zm3.56 1.16H5.617v.838h3.017z%27 style=%27fill:%23fff;fill-rule:evenodd;stroke-width:1.03600001%27/%3E%3Cg style=%27stroke-width:1.12603545%27%3E%3Cpath d=%27M-9.408-1.416c-3.833-.025-7.056 2.912-7.08 6.615-.02 3.08 1.653 4.832 3.107 6.268.903.892 1.721 1.74 2.32 2.902l-.525-.004c-.543-.003-.992.304-1.24.639a1.87 1.87 0 0 0-.362 1.121l-.011 1.877c-.003.402.104.787.347 1.125.244.338.688.653 1.23.656l4.142.028c.542.003.99-.306 1.238-.641a1.87 1.87 0 0 0 .363-1.121l.012-1.875a1.87 1.87 0 0 0-.348-1.127c-.243-.338-.688-.653-1.23-.656l-.518-.004c.597-1.145 1.425-1.983 2.348-2.87 1.473-1.414 3.18-3.149 3.2-6.226-.016-3.59-2.923-6.684-6.993-6.707m-.006 1.1v.002c3.274.02 5.92 2.532 5.9 5.6-.017 2.706-1.39 4.026-2.863 5.44-1.034.994-2.118 2.033-2.814 3.633-.018.041-.052.055-.075.065q-.013.004-.02.01a.34.34 0 0 1-.226.084.34.34 0 0 1-.224-.086l-.092-.077c-.699-1.615-1.768-2.669-2.781-3.67-1.454-1.435-2.797-2.762-2.78-5.478.02-3.067 2.7-5.545 5.975-5.523m-.02 2.826c-1.62-.01-2.944 1.315-2.955 2.96-.01 1.646 1.295 2.988 2.916 2.999h.002c1.621.01 2.943-1.316 2.953-2.961.011-1.646-1.294-2.988-2.916-2.998m-.005 1.1c1.017.006 1.829.83 1.822 1.89s-.83 1.874-1.848 1.867c-1.018-.006-1.829-.83-1.822-1.89s.83-1.874 1.848-1.868m-2.155 11.857 4.14.025c.271.002.49.305.487.676l-.013 1.875c-.003.37-.224.67-.495.668l-4.14-.025c-.27-.002-.487-.306-.485-.676l.012-1.875c.003-.37.224-.67.494-.668%27 style=%27color:%23000;font-style:normal;font-variant:normal;font-weight:400;font-stretch:normal;font-size:medium;line-height:normal;font-family:sans-serif;font-variant-ligatures:normal;font-variant-position:normal;font-variant-caps:normal;font-variant-numeric:normal;font-variant-alternates:normal;font-feature-settings:normal;text-indent:0;text-align:start;text-decoration:none;text-decoration-line:none;text-decoration-style:solid;text-decoration-color:%23000;letter-spacing:normal;word-spacing:normal;text-transform:none;writing-mode:lr-tb;direction:ltr;text-orientation:mixed;dominant-baseline:auto;baseline-shift:baseline;text-anchor:start;white-space:normal;shape-padding:0;clip-rule:evenodd;display:inline;overflow:visible;visibility:visible;opacity:1;isolation:auto;mix-blend-mode:normal;color-interpolation:sRGB;color-interpolation-filters:linearRGB;solid-color:%23000;solid-opacity:1;vector-effect:none;fill:%23000;fill-opacity:.4;fill-rule:evenodd;stroke:none;stroke-width:2.47727823;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;color-rendering:auto;image-rendering:auto;shape-rendering:auto;text-rendering:auto%27 transform=%27translate%2815.553 2.85%29scale%28.88807%29%27/%3E%3Cpath d=%27M-9.415-.316C-12.69-.338-15.37 2.14-15.39 5.207c-.017 2.716 1.326 4.041 2.78 5.477 1.013 1 2.081 2.055 2.78 3.67l.092.076a.34.34 0 0 0 .225.086.34.34 0 0 0 .227-.083l.019-.01c.022-.009.057-.024.074-.064.697-1.6 1.78-2.64 2.814-3.634 1.473-1.414 2.847-2.733 2.864-5.44.02-3.067-2.627-5.58-5.901-5.601m-.057 8.784c1.621.011 2.944-1.315 2.955-2.96.01-1.646-1.295-2.988-2.916-2.999-1.622-.01-2.945 1.315-2.955 2.96s1.295 2.989 2.916 3%27 style=%27clip-rule:evenodd;fill:%23e1e3e9;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.47727823;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:.4%27 transform=%27translate%2815.553 2.85%29scale%28.88807%29%27/%3E%3Cpath d=%27M-11.594 15.465c-.27-.002-.492.297-.494.668l-.012 1.876c-.003.371.214.673.485.675l4.14.027c.271.002.492-.298.495-.668l.012-1.877c.003-.37-.215-.672-.485-.674z%27 style=%27clip-rule:evenodd;fill:%23fff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.47727823;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:.4%27 transform=%27translate%2815.553 2.85%29scale%28.88807%29%27/%3E%3C/g%3E%3C/svg%3E\"},63779:function(){},77199:function(){},61990:function(t,e,r){\"use strict\";Object.defineProperty(e,\"__esModule\",{value:!0});var n=r(85846),i=r(66030);function a(t){return i.geomReduce.call(void 0,t,((t,e)=>t+function(t){let e,r=0;switch(t.type){case\"Polygon\":return o(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=o(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)),0)}function o(t){let e=0;if(t&&t.length>0){e+=Math.abs(c(t[0]));for(let r=1;r<t.length;r++)e-=Math.abs(c(t[r]))}return e}var s=n.earthRadius*n.earthRadius/2,l=Math.PI/180;function c(t){const e=t.length-1;if(e<=2)return 0;let r=0,n=0;for(;n<e;){const i=t[n],a=t[n+1===e?0:n+1],o=t[n+2>=e?(n+2)%e:n+2],s=i[0]*l,c=a[1]*l;r+=(o[0]*l-s)*Math.sin(c),n++}return r*s}var u=a;e.area=a,e.default=u},25368:function(t,e,r){\"use strict\";Object.defineProperty(e,\"__esModule\",{value:!0});var n=r(66030);function i(t,e={}){if(null!=t.bbox&&!0!==e.recompute)return t.bbox;const r=[1/0,1/0,-1/0,-1/0];return n.coordEach.call(void 0,t,(t=>{r[0]>t[0]&&(r[0]=t[0]),r[1]>t[1]&&(r[1]=t[1]),r[2]<t[0]&&(r[2]=t[0]),r[3]<t[1]&&(r[3]=t[1])})),r}var a=i;e.bbox=i,e.default=a},30035:function(t,e,r){\"use strict\";Object.defineProperty(e,\"__esModule\",{value:!0});var n=r(85846),i=r(66030);function a(t,e={}){let r=0,a=0,o=0;return i.coordEach.call(void 0,t,(function(t){r+=t[0],a+=t[1],o++}),!0),n.point.call(void 0,[r/o,a/o],e.properties)}var o=a;e.centroid=a,e.default=o},85846:function(t,e){\"use strict\";Object.defineProperty(e,\"__esModule\",{value:!0});var r=6371008.8,n={centimeters:637100880,centimetres:637100880,degrees:360/(2*Math.PI),feet:20902260.511392,inches:39.37*r,kilometers:6371.0088,kilometres:6371.0088,meters:r,metres:r,miles:3958.761333810546,millimeters:6371008800,millimetres:6371008800,nauticalmiles:r/1852,radians:1,yards:6967335.223679999},i={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,hectares:1e-4,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,nauticalmiles:2.9155334959812285e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046};function a(t,e,r={}){const n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function o(t,e,r={}){if(!t)throw new Error(\"coordinates is required\");if(!Array.isArray(t))throw new Error(\"coordinates must be an Array\");if(t.length<2)throw new Error(\"coordinates must be at least 2 numbers long\");if(!g(t[0])||!g(t[1]))throw new Error(\"coordinates must contain numbers\");return a({type:\"Point\",coordinates:t},e,r)}function s(t,e,r={}){for(const e of t){if(e.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");if(e[e.length-1].length!==e[0].length)throw new Error(\"First and last Position are not equivalent.\");for(let t=0;t<e[e.length-1].length;t++)if(e[e.length-1][t]!==e[0][t])throw new Error(\"First and last Position are not equivalent.\")}return a({type:\"Polygon\",coordinates:t},e,r)}function l(t,e,r={}){if(t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return a({type:\"LineString\",coordinates:t},e,r)}function c(t,e={}){const r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function u(t,e,r={}){return a({type:\"MultiLineString\",coordinates:t},e,r)}function h(t,e,r={}){return a({type:\"MultiPoint\",coordinates:t},e,r)}function f(t,e,r={}){return a({type:\"MultiPolygon\",coordinates:t},e,r)}function p(t,e=\"kilometers\"){const r=n[e];if(!r)throw new Error(e+\" units is invalid\");return t*r}function d(t,e=\"kilometers\"){const r=n[e];if(!r)throw new Error(e+\" units is invalid\");return t/r}function m(t){return t%(2*Math.PI)*180/Math.PI}function g(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)}e.areaFactors=i,e.azimuthToBearing=function(t){return(t%=360)>0?t>180?t-360:t:t<-180?t+360:t},e.bearingToAzimuth=function(t){let e=t%360;return e<0&&(e+=360),e},e.convertArea=function(t,e=\"meters\",r=\"kilometers\"){if(!(t>=0))throw new Error(\"area must be a positive number\");const n=i[e];if(!n)throw new Error(\"invalid original units\");const a=i[r];if(!a)throw new Error(\"invalid final units\");return t/n*a},e.convertLength=function(t,e=\"kilometers\",r=\"kilometers\"){if(!(t>=0))throw new Error(\"length must be a positive number\");return p(d(t,e),r)},e.degreesToRadians=function(t){return t%360*Math.PI/180},e.earthRadius=r,e.factors=n,e.feature=a,e.featureCollection=c,e.geometry=function(t,e,r={}){switch(t){case\"Point\":return o(e).geometry;case\"LineString\":return l(e).geometry;case\"Polygon\":return s(e).geometry;case\"MultiPoint\":return h(e).geometry;case\"MultiLineString\":return u(e).geometry;case\"MultiPolygon\":return f(e).geometry;default:throw new Error(t+\" is invalid\")}},e.geometryCollection=function(t,e,r={}){return a({type:\"GeometryCollection\",geometries:t},e,r)},e.isNumber=g,e.isObject=function(t){return null!==t&&\"object\"==typeof t&&!Array.isArray(t)},e.lengthToDegrees=function(t,e){return m(d(t,e))},e.lengthToRadians=d,e.lineString=l,e.lineStrings=function(t,e,r={}){return c(t.map((t=>l(t,e))),r)},e.multiLineString=u,e.multiPoint=h,e.multiPolygon=f,e.point=o,e.points=function(t,e,r={}){return c(t.map((t=>o(t,e))),r)},e.polygon=s,e.polygons=function(t,e,r={}){return c(t.map((t=>s(t,e))),r)},e.radiansToDegrees=m,e.radiansToLength=p,e.round=function(t,e=0){if(e&&!(e>=0))throw new Error(\"precision must be a positive number\");const r=Math.pow(10,e||0);return Math.round(t*r)/r},e.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((t=>{if(!g(t))throw new Error(\"bbox must only contain numbers\")}))},e.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")}},66030:function(t,e,r){\"use strict\";Object.defineProperty(e,\"__esModule\",{value:!0});var n=r(85846);function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,m=\"FeatureCollection\"===d,g=\"Feature\"===d,y=m?t.features.length:1,v=0;v<y;v++){l=(h=!!(u=m?t.features[v].geometry:g?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var _=0,b=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,v,_,b))return!1;p++,_++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,v,_,b))return!1;p++,\"MultiPoint\"===w&&_++}\"LineString\"===w&&_++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,v,_,b))return!1;p++}\"MultiLineString\"===w&&_++,\"Polygon\"===w&&b++}\"Polygon\"===w&&_++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(b=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,v,_,b))return!1;p++}b++}_++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,m=p?t.features.length:1;for(r=0;r<m;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,(function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature.call(void 0,t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature.call(void 0,u,i),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,(function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var m=n.lineString.call(void 0,[l,i],t.properties);if(!1===e(m,r,a,d,o))return!1;o++,l=i}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString.call(void 0,o[s],t.properties),r,i,s))return!1}}}))}e.coordAll=function(t){var e=[];return i(t,(function(t){e.push(t)})),e},e.coordEach=i,e.coordReduce=function(t,e,r,n){var a=r;return i(t,(function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)}),n),a},e.featureEach=o,e.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},e.findPoint=function(t,e){if(e=e||{},!n.isObject.call(void 0,e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point.call(void 0,c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point.call(void 0,c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point.call(void 0,c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point.call(void 0,c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point.call(void 0,c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point.call(void 0,c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")},e.findSegment=function(t,e){if(e=e||{},!n.isObject.call(void 0,e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString.call(void 0,[c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString.call(void 0,[c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString.call(void 0,[c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString.call(void 0,[c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},e.flattenEach=l,e.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)})),n},e.geomEach=s,e.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)})),n},e.lineEach=u,e.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)})),n},e.propEach=a,e.propReduce=function(t,e,r){var n=r;return a(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},e.segmentEach=c,e.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,(function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0})),n}},70085:function(t,e,r){\"use strict\";var n=[\"BigInt64Array\",\"BigUint64Array\",\"Float32Array\",\"Float64Array\",\"Int16Array\",\"Int32Array\",\"Int8Array\",\"Uint16Array\",\"Uint32Array\",\"Uint8Array\",\"Uint8ClampedArray\"],i=\"undefined\"==typeof globalThis?r.g:globalThis;t.exports=function(){for(var t=[],e=0;e<n.length;e++)\"function\"==typeof i[n[e]]&&(t[t.length]=n[e]);return t}},89380:function(t){t.exports=function(){\"use strict\";var t={},e={};function r(r,n,i){if(e[r]=i,\"index\"===r){var a=\"var sharedModule = {}; (\"+e.shared+\")(sharedModule); (\"+e.worker+\")(sharedModule);\",o={};return e.shared(o),e.index(t,o),\"undefined\"!=typeof window&&t.setWorkerUrl(window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))),t}}return r(\"shared\",0,(function(t){function e(t,e,r,n){return new(r||(r=Promise))((function(i,a){function o(t){try{l(n.next(t))}catch(t){a(t)}}function s(t){try{l(n.throw(t))}catch(t){a(t)}}function l(t){var e;t.done?i(t.value):(e=t.value,e instanceof r?e:new r((function(t){t(e)}))).then(o,s)}l((n=n.apply(t,e||[])).next())}))}function r(t){return t&&t.__esModule&&Object.prototype.hasOwnProperty.call(t,\"default\")?t.default:t}\"function\"==typeof SuppressedError&&SuppressedError;var n=i;function i(t,e){this.x=t,this.y=e}i.prototype={clone:function(){return new i(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},i.convert=function(t){return t instanceof i?t:Array.isArray(t)?new i(t[0],t[1]):t};var a=r(n),o=s;function s(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=e,this.p2x=r,this.p2y=n}s.prototype={sampleCurveX:function(t){return((this.ax*t+this.bx)*t+this.cx)*t},sampleCurveY:function(t){return((this.ay*t+this.by)*t+this.cy)*t},sampleCurveDerivativeX:function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},solveCurveX:function(t,e){if(void 0===e&&(e=1e-6),t<0)return 0;if(t>1)return 1;for(var r=t,n=0;n<8;n++){var i=this.sampleCurveX(r)-t;if(Math.abs(i)<e)return r;var a=this.sampleCurveDerivativeX(r);if(Math.abs(a)<1e-6)break;r-=i/a}var o=0,s=1;for(r=t,n=0;n<20&&(i=this.sampleCurveX(r),!(Math.abs(i-t)<e));n++)t>i?o=r:s=r,r=.5*(s-o)+o;return r},solve:function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))}};var l=r(o);let c,u;function h(){return null==c&&(c=\"undefined\"!=typeof OffscreenCanvas&&new OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof createImageBitmap),c}function f(){if(null==u&&(u=!1,h())){const t=5,e=new OffscreenCanvas(t,t).getContext(\"2d\",{willReadFrequently:!0});if(e){for(let r=0;r<t*t;r++){const n=4*r;e.fillStyle=`rgb(${n},${n+1},${n+2})`,e.fillRect(r%t,Math.floor(r/t),1,1)}const r=e.getImageData(0,0,t,t).data;for(let e=0;e<t*t*4;e++)if(e%4!=3&&r[e]!==e){u=!0;break}}}return u||!1}function p(t,e,r,n){const i=new l(t,e,r,n);return t=>i.solve(t)}const d=p(.25,.1,.25,1);function m(t,e,r){return Math.min(r,Math.max(e,t))}function g(t,e,r){const n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function y(t,...e){for(const r of e)for(const e in r)t[e]=r[e];return t}let v=1;function x(t,e,r){const n={};for(const r in t)n[r]=e.call(this,t[r],r,t);return n}function _(t,e,r){const n={};for(const r in t)e.call(this,t[r],r,t)&&(n[r]=t[r]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?x(t,b):t}const w={};function T(t){w[t]||(\"undefined\"!=typeof console&&console.warn(t),w[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function A(t){return\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t&&t instanceof WorkerGlobalScope}let M=null;function S(t){return\"undefined\"!=typeof ImageBitmap&&t instanceof ImageBitmap}const E=\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\";function C(t,r,n,i,a){return e(this,void 0,void 0,(function*(){if(\"undefined\"==typeof VideoFrame)throw new Error(\"VideoFrame not supported\");const e=new VideoFrame(t,{timestamp:0});try{const o=null==e?void 0:e.format;if(!o||!o.startsWith(\"BGR\")&&!o.startsWith(\"RGB\"))throw new Error(`Unrecognized format ${o}`);const s=o.startsWith(\"BGR\"),l=new Uint8ClampedArray(i*a*4);if(yield e.copyTo(l,function(t,e,r,n,i){const a=4*Math.max(-e,0),o=(Math.max(0,r)-r)*n*4+a,s=4*n,l=Math.max(0,e),c=Math.max(0,r);return{rect:{x:l,y:c,width:Math.min(t.width,e+n)-l,height:Math.min(t.height,r+i)-c},layout:[{offset:o,stride:s}]}}(t,r,n,i,a)),s)for(let t=0;t<l.length;t+=4){const e=l[t];l[t]=l[t+2],l[t+2]=e}return l}finally{e.close()}}))}let L,I;const P=\"AbortError\";function z(){return new Error(P)}const O={MAX_PARALLEL_IMAGE_REQUESTS:16,MAX_PARALLEL_IMAGE_REQUESTS_PER_FRAME:8,MAX_TILE_CACHE_ZOOM_LEVELS:5,REGISTERED_PROTOCOLS:{},WORKER_URL:\"\"};function D(t){return O.REGISTERED_PROTOCOLS[t.substring(0,t.indexOf(\"://\"))]}const R=\"global-dispatcher\";class F extends Error{constructor(t,e,r,n){super(`AJAXError: ${e} (${t}): ${r}`),this.status=t,this.statusText=e,this.url=r,this.body=n}}const B=()=>A(self)?self.worker&&self.worker.referrer:(\"blob:\"===window.location.protocol?window.parent:window).location.href;const N=function(t,r){if(/:\\/\\//.test(t.url)&&!/^https?:|^file:/.test(t.url)){const e=D(t.url);if(e)return e(t,r);if(A(self)&&self.worker&&self.worker.actor)return self.worker.actor.sendAsync({type:\"GR\",data:t,targetMapId:R},r)}if(n=t.url,!(/^file:/.test(n)||/^file:/.test(B())&&!/^\\w+:/.test(n))){if(fetch&&Request&&AbortController&&Object.prototype.hasOwnProperty.call(Request.prototype,\"signal\"))return function(t,r){return e(this,void 0,void 0,(function*(){const e=new Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,cache:t.cache,referrer:B(),signal:r.signal});\"json\"!==t.type||e.headers.has(\"Accept\")||e.headers.set(\"Accept\",\"application/json\");const n=yield fetch(e);if(!n.ok){const e=yield n.blob();throw new F(n.status,n.statusText,t.url,e)}let i;i=\"arrayBuffer\"===t.type||\"image\"===t.type?n.arrayBuffer():\"json\"===t.type?n.json():n.text();const a=yield i;if(r.signal.aborted)throw z();return{data:a,cacheControl:n.headers.get(\"Cache-Control\"),expires:n.headers.get(\"Expires\")}}))}(t,r);if(A(self)&&self.worker&&self.worker.actor)return self.worker.actor.sendAsync({type:\"GR\",data:t,mustQueue:!0,targetMapId:R},r)}var n;return function(t,e){return new Promise(((r,n)=>{var i;const a=new XMLHttpRequest;a.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"!==t.type&&\"image\"!==t.type||(a.responseType=\"arraybuffer\");for(const e in t.headers)a.setRequestHeader(e,t.headers[e]);\"json\"===t.type&&(a.responseType=\"text\",(null===(i=t.headers)||void 0===i?void 0:i.Accept)||a.setRequestHeader(\"Accept\",\"application/json\")),a.withCredentials=\"include\"===t.credentials,a.onerror=()=>{n(new Error(a.statusText))},a.onload=()=>{if(!e.signal.aborted)if((a.status>=200&&a.status<300||0===a.status)&&null!==a.response){let e=a.response;if(\"json\"===t.type)try{e=JSON.parse(a.response)}catch(t){return void n(t)}r({data:e,cacheControl:a.getResponseHeader(\"Cache-Control\"),expires:a.getResponseHeader(\"Expires\")})}else{const e=new Blob([a.response],{type:a.getResponseHeader(\"Content-Type\")});n(new F(a.status,a.statusText,t.url,e))}},e.signal.addEventListener(\"abort\",(()=>{a.abort(),n(z())})),a.send(t.body)}))}(t,r)};function j(t){if(!t||t.indexOf(\"://\")<=0||0===t.indexOf(\"data:image/\")||0===t.indexOf(\"blob:\"))return!0;const e=new URL(t),r=window.location;return e.protocol===r.protocol&&e.host===r.host}function U(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function V(t,e,r){if(r&&r[t]){const n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}class q{constructor(t,e={}){y(this,e),this.type=t}}class H extends q{constructor(t,e={}){super(\"error\",y({error:t},e))}}class G{on(t,e){return this._listeners=this._listeners||{},U(t,e,this._listeners),this}off(t,e){return V(t,e,this._listeners),V(t,e,this._oneTimeListeners),this}once(t,e){return e?(this._oneTimeListeners=this._oneTimeListeners||{},U(t,e,this._oneTimeListeners),this):new Promise((e=>this.once(t,e)))}fire(t,e){\"string\"==typeof t&&(t=new q(t,e||{}));const r=t.type;if(this.listens(r)){t.target=this;const e=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];for(const r of e)r.call(this,t);const n=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];for(const e of n)V(r,e,this._oneTimeListeners),e.call(this,t);const i=this._eventedParent;i&&(y(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),i.fire(t))}else t instanceof H&&console.error(t.error);return this}listens(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)}setEventedParent(t,e){return this._eventedParent=t,this._eventedParentData=e,this}}var Z={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sky:{type:\"sky\"},projection:{type:\"projection\"},terrain:{type:\"terrain\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"sprite\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},volatile:{type:\"boolean\",default:!1},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},volatile:{type:\"boolean\",default:!1},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{},custom:{}},default:\"mapbox\"},redFactor:{type:\"number\",default:1},blueFactor:{type:\"number\",default:1},greenFactor:{type:\"number\",default:1},baseShift:{type:\"number\",default:0},volatile:{type:\"boolean\",default:!1},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{required:!0,type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},filter:{type:\"*\"},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterMinPoints:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"!\":\"icon-overlap\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-overlap\":{type:\"enum\",values:{never:{},always:{},cooperative:{}},requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"padding\",default:[2],units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},\"viewport-glyph\":{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-variable-anchor-offset\":{type:\"variableAnchorOffsetCollection\",requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\",{\"!\":\"text-overlap\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-overlap\":{type:\"enum\",values:{never:{},always:{},cooperative:{}},requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},sky:{\"sky-color\":{type:\"color\",\"property-type\":\"data-constant\",default:\"#88C6FC\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},\"horizon-color\":{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},\"fog-color\":{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},\"fog-ground-blend\":{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},\"horizon-fog-blend\":{type:\"number\",\"property-type\":\"data-constant\",default:.8,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},\"sky-horizon-blend\":{type:\"number\",\"property-type\":\"data-constant\",default:.8,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},\"atmosphere-blend\":{type:\"number\",\"property-type\":\"data-constant\",default:.8,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},terrain:{source:{type:\"string\",required:!0},exaggeration:{type:\"number\",minimum:0,default:1}},projection:{type:{type:\"enum\",default:\"mercator\",values:{mercator:{},globe:{}}}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}};const W=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"];function Y(t,e){const r={};for(const e in t)\"ref\"!==e&&(r[e]=t[e]);return W.forEach((t=>{t in e&&(r[t]=e[t])})),r}function X(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(let r=0;r<t.length;r++)if(!X(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(const r in t)if(!X(t[r],e[r]))return!1;return!0}return t===e}function $(t,e){t.push(e)}function J(t,e,r){$(r,{command:\"addSource\",args:[t,e[t]]})}function K(t,e,r){$(e,{command:\"removeSource\",args:[t]}),r[t]=!0}function Q(t,e,r,n){K(t,r,n),J(t,e,r)}function tt(t,e,r){let n;for(n in t[r])if(Object.prototype.hasOwnProperty.call(t[r],n)&&\"data\"!==n&&!X(t[r][n],e[r][n]))return!1;for(n in e[r])if(Object.prototype.hasOwnProperty.call(e[r],n)&&\"data\"!==n&&!X(t[r][n],e[r][n]))return!1;return!0}function et(t,e,r,n,i,a){t=t||{},e=e||{};for(const o in t)Object.prototype.hasOwnProperty.call(t,o)&&(X(t[o],e[o])||r.push({command:a,args:[n,o,e[o],i]}));for(const o in e)Object.prototype.hasOwnProperty.call(e,o)&&!Object.prototype.hasOwnProperty.call(t,o)&&(X(t[o],e[o])||r.push({command:a,args:[n,o,e[o],i]}))}function rt(t){return t.id}function nt(t,e){return t[e.id]=e,t}class it{constructor(t,e,r,n){this.message=(t?`${t}: `:\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)}}function at(t,...e){for(const r of e)for(const e in r)t[e]=r[e];return t}class ot extends Error{constructor(t,e){super(e),this.message=e,this.key=t}}class st{constructor(t,e=[]){this.parent=t,this.bindings={};for(const[t,r]of e)this.bindings[t]=r}concat(t){return new st(this,t)}get(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(`${t} not found in scope.`)}has(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)}}const lt={kind:\"null\"},ct={kind:\"number\"},ut={kind:\"string\"},ht={kind:\"boolean\"},ft={kind:\"color\"},pt={kind:\"object\"},dt={kind:\"value\"},mt={kind:\"collator\"},gt={kind:\"formatted\"},yt={kind:\"padding\"},vt={kind:\"resolvedImage\"},xt={kind:\"variableAnchorOffsetCollection\"};function _t(t,e){return{kind:\"array\",itemType:t,N:e}}function bt(t){if(\"array\"===t.kind){const e=bt(t.itemType);return\"number\"==typeof t.N?`array<${e}, ${t.N}>`:\"value\"===t.itemType.kind?\"array\":`array<${e}>`}return t.kind}const wt=[lt,ct,ut,ht,ft,gt,pt,_t(dt),yt,vt,xt];function Tt(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!Tt(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(const t of wt)if(!Tt(t,e))return null}return`Expected ${bt(t)} but found ${bt(e)} instead.`}function kt(t,e){return e.some((e=>e.kind===t.kind))}function At(t,e){return e.some((e=>\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t))}function Mt(t,e){return\"array\"===t.kind&&\"array\"===e.kind?t.itemType.kind===e.itemType.kind&&\"number\"==typeof t.N:t.kind===e.kind}const St=.96422,Et=1,Ct=.82521,Lt=4/29,It=6/29,Pt=3*It*It,zt=It*It*It,Ot=Math.PI/180,Dt=180/Math.PI;function Rt(t){return(t%=360)<0&&(t+=360),t}function Ft([t,e,r,n]){let i,a;const o=Nt((.2225045*(t=Bt(t))+.7168786*(e=Bt(e))+.0606169*(r=Bt(r)))/Et);t===e&&e===r?i=a=o:(i=Nt((.4360747*t+.3850649*e+.1430804*r)/St),a=Nt((.0139322*t+.0971045*e+.7141733*r)/Ct));const s=116*o-16;return[s<0?0:s,500*(i-o),200*(o-a),n]}function Bt(t){return t<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Nt(t){return t>zt?Math.pow(t,1/3):t/Pt+Lt}function jt([t,e,r,n]){let i=(t+16)/116,a=isNaN(e)?i:i+e/500,o=isNaN(r)?i:i-r/200;return i=Et*Vt(i),a=St*Vt(a),o=Ct*Vt(o),[Ut(3.1338561*a-1.6168667*i-.4906146*o),Ut(-.9787684*a+1.9161415*i+.033454*o),Ut(.0719453*a-.2289914*i+1.4052427*o),n]}function Ut(t){return(t=t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055)<0?0:t>1?1:t}function Vt(t){return t>It?t*t*t:Pt*(t-Lt)}function qt(t){if(\"transparent\"===(t=t.toLowerCase().trim()))return[0,0,0,0];const e=Yt[t];if(e){const[t,r,n]=e;return[t/255,r/255,n/255,1]}if(t.startsWith(\"#\")&&/^#(?:[0-9a-f]{3,4}|[0-9a-f]{6}|[0-9a-f]{8})$/.test(t)){const e=t.length<6?1:2;let r=1;return[Ht(t.slice(r,r+=e)),Ht(t.slice(r,r+=e)),Ht(t.slice(r,r+=e)),Ht(t.slice(r,r+e)||\"ff\")]}if(t.startsWith(\"rgb\")){const e=/^rgba?\\(\\s*([\\de.+-]+)(%)?(?:\\s+|\\s*(,)\\s*)([\\de.+-]+)(%)?(?:\\s+|\\s*(,)\\s*)([\\de.+-]+)(%)?(?:\\s*([,\\/])\\s*([\\de.+-]+)(%)?)?\\s*\\)$/,r=t.match(e);if(r){const[t,e,n,i,a,o,s,l,c,u,h,f]=r,p=[i||\" \",s||\" \",u].join(\"\");if(\"  \"===p||\"  /\"===p||\",,\"===p||\",,,\"===p){const t=[n,o,c].join(\"\"),r=\"%%%\"===t?100:\"\"===t?255:0;if(r){const t=[Zt(+e/r,0,1),Zt(+a/r,0,1),Zt(+l/r,0,1),h?Gt(+h,f):1];if(Wt(t))return t}}return}}const r=t.match(/^hsla?\\(\\s*([\\de.+-]+)(?:deg)?(?:\\s+|\\s*(,)\\s*)([\\de.+-]+)%(?:\\s+|\\s*(,)\\s*)([\\de.+-]+)%(?:\\s*([,\\/])\\s*([\\de.+-]+)(%)?)?\\s*\\)$/);if(r){const[t,e,n,i,a,o,s,l,c]=r,u=[n||\" \",a||\" \",s].join(\"\");if(\"  \"===u||\"  /\"===u||\",,\"===u||\",,,\"===u){const t=[+e,Zt(+i,0,100),Zt(+o,0,100),l?Gt(+l,c):1];if(Wt(t))return function([t,e,r,n]){function i(n){const i=(n+t/30)%12,a=e*Math.min(r,1-r);return r-a*Math.max(-1,Math.min(i-3,9-i,1))}return t=Rt(t),e/=100,r/=100,[i(0),i(8),i(4),n]}(t)}}}function Ht(t){return parseInt(t.padEnd(2,t),16)/255}function Gt(t,e){return Zt(e?t/100:t,0,1)}function Zt(t,e,r){return Math.min(Math.max(e,t),r)}function Wt(t){return!t.some(Number.isNaN)}const Yt={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]};class Xt{constructor(t,e,r,n=1,i=!0){this.r=t,this.g=e,this.b=r,this.a=n,i||(this.r*=n,this.g*=n,this.b*=n,n||this.overwriteGetter(\"rgb\",[t,e,r,n]))}static parse(t){if(t instanceof Xt)return t;if(\"string\"!=typeof t)return;const e=qt(t);return e?new Xt(...e,!1):void 0}get rgb(){const{r:t,g:e,b:r,a:n}=this,i=n||1/0;return this.overwriteGetter(\"rgb\",[t/i,e/i,r/i,n])}get hcl(){return this.overwriteGetter(\"hcl\",function(t){const[e,r,n,i]=Ft(t),a=Math.sqrt(r*r+n*n);return[Math.round(1e4*a)?Rt(Math.atan2(n,r)*Dt):NaN,a,e,i]}(this.rgb))}get lab(){return this.overwriteGetter(\"lab\",Ft(this.rgb))}overwriteGetter(t,e){return Object.defineProperty(this,t,{value:e}),e}toString(){const[t,e,r,n]=this.rgb;return`rgba(${[t,e,r].map((t=>Math.round(255*t))).join(\",\")},${n})`}}Xt.black=new Xt(0,0,0,1),Xt.white=new Xt(1,1,1,1),Xt.transparent=new Xt(0,0,0,0),Xt.red=new Xt(1,0,0,1);class $t{constructor(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})}compare(t,e){return this.collator.compare(t,e)}resolvedLocale(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale}}class Jt{constructor(t,e,r,n,i){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=i}}class Kt{constructor(t){this.sections=t}static fromString(t){return new Kt([new Jt(t,null,null,null,null)])}isEmpty(){return 0===this.sections.length||!this.sections.some((t=>0!==t.text.length||t.image&&0!==t.image.name.length))}static factory(t){return t instanceof Kt?t:Kt.fromString(t)}toString(){return 0===this.sections.length?\"\":this.sections.map((t=>t.text)).join(\"\")}}class Qt{constructor(t){this.values=t.slice()}static parse(t){if(t instanceof Qt)return t;if(\"number\"==typeof t)return new Qt([t,t,t,t]);if(Array.isArray(t)&&!(t.length<1||t.length>4)){for(const e of t)if(\"number\"!=typeof e)return;switch(t.length){case 1:t=[t[0],t[0],t[0],t[0]];break;case 2:t=[t[0],t[1],t[0],t[1]];break;case 3:t=[t[0],t[1],t[2],t[1]]}return new Qt(t)}}toString(){return JSON.stringify(this.values)}}const te=new Set([\"center\",\"left\",\"right\",\"top\",\"bottom\",\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"]);class ee{constructor(t){this.values=t.slice()}static parse(t){if(t instanceof ee)return t;if(Array.isArray(t)&&!(t.length<1)&&t.length%2==0){for(let e=0;e<t.length;e+=2){const r=t[e],n=t[e+1];if(\"string\"!=typeof r||!te.has(r))return;if(!Array.isArray(n)||2!==n.length||\"number\"!=typeof n[0]||\"number\"!=typeof n[1])return}return new ee(t)}}toString(){return JSON.stringify(this.values)}}class re{constructor(t){this.name=t.name,this.available=t.available}toString(){return this.name}static fromString(t){return t?new re({name:t,available:!1}):null}}function ne(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:`Invalid rgba value [${[t,e,r,n].join(\", \")}]: 'a' must be between 0 and 1.`:`Invalid rgba value [${(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")}]: 'r', 'g', and 'b' must be between 0 and 255.`}function ie(t){if(null===t||\"string\"==typeof t||\"boolean\"==typeof t||\"number\"==typeof t||t instanceof Xt||t instanceof $t||t instanceof Kt||t instanceof Qt||t instanceof ee||t instanceof re)return!0;if(Array.isArray(t)){for(const e of t)if(!ie(e))return!1;return!0}if(\"object\"==typeof t){for(const e in t)if(!ie(t[e]))return!1;return!0}return!1}function ae(t){if(null===t)return lt;if(\"string\"==typeof t)return ut;if(\"boolean\"==typeof t)return ht;if(\"number\"==typeof t)return ct;if(t instanceof Xt)return ft;if(t instanceof $t)return mt;if(t instanceof Kt)return gt;if(t instanceof Qt)return yt;if(t instanceof ee)return xt;if(t instanceof re)return vt;if(Array.isArray(t)){const e=t.length;let r;for(const e of t){const t=ae(e);if(r){if(r===t)continue;r=dt;break}r=t}return _t(r||dt,e)}return pt}function oe(t){const e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof Xt||t instanceof Kt||t instanceof Qt||t instanceof ee||t instanceof re?t.toString():JSON.stringify(t)}class se{constructor(t,e){this.type=t,this.value=e}static parse(t,e){if(2!==t.length)return e.error(`'literal' expression requires exactly one argument, but found ${t.length-1} instead.`);if(!ie(t[1]))return e.error(\"invalid value\");const r=t[1];let n=ae(r);const i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new se(n,r)}evaluate(){return this.value}eachChild(){}outputDefined(){return!0}}class le{constructor(t){this.name=\"ExpressionEvaluationError\",this.message=t}toJSON(){return this.message}}const ce={string:ut,number:ct,boolean:ht,object:pt};class ue{constructor(t,e){this.type=t,this.args=e}static parse(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");let r,n=1;const i=t[0];if(\"array\"===i){let i,a;if(t.length>2){const r=t[1];if(\"string\"!=typeof r||!(r in ce)||\"object\"===r)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);i=ce[r],n++}else i=dt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);a=t[2],n++}r=_t(i,a)}else{if(!ce[i])throw new Error(`Types doesn't contain name = ${i}`);r=ce[i]}const a=[];for(;n<t.length;n++){const r=e.parse(t[n],n,dt);if(!r)return null;a.push(r)}return new ue(r,a)}evaluate(t){for(let e=0;e<this.args.length;e++){const r=this.args[e].evaluate(t);if(!Tt(this.type,ae(r)))return r;if(e===this.args.length-1)throw new le(`Expected value to be of type ${bt(this.type)}, but found ${bt(ae(r))} instead.`)}throw new Error}eachChild(t){this.args.forEach(t)}outputDefined(){return this.args.every((t=>t.outputDefined()))}}const he={\"to-boolean\":ht,\"to-color\":ft,\"to-number\":ct,\"to-string\":ut};class fe{constructor(t,e){this.type=t,this.args=e}static parse(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");const r=t[0];if(!he[r])throw new Error(`Can't parse ${r} as it is not part of the known types`);if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");const n=he[r],i=[];for(let r=1;r<t.length;r++){const n=e.parse(t[r],r,dt);if(!n)return null;i.push(n)}return new fe(n,i)}evaluate(t){switch(this.type.kind){case\"boolean\":return Boolean(this.args[0].evaluate(t));case\"color\":{let e,r;for(const n of this.args){if(e=n.evaluate(t),r=null,e instanceof Xt)return e;if(\"string\"==typeof e){const r=t.parseColor(e);if(r)return r}else if(Array.isArray(e)&&(r=e.length<3||e.length>4?`Invalid rbga value ${JSON.stringify(e)}: expected an array containing either three or four numeric values.`:ne(e[0],e[1],e[2],e[3]),!r))return new Xt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new le(r||`Could not parse color from value '${\"string\"==typeof e?e:JSON.stringify(e)}'`)}case\"padding\":{let e;for(const r of this.args){e=r.evaluate(t);const n=Qt.parse(e);if(n)return n}throw new le(`Could not parse padding from value '${\"string\"==typeof e?e:JSON.stringify(e)}'`)}case\"variableAnchorOffsetCollection\":{let e;for(const r of this.args){e=r.evaluate(t);const n=ee.parse(e);if(n)return n}throw new le(`Could not parse variableAnchorOffsetCollection from value '${\"string\"==typeof e?e:JSON.stringify(e)}'`)}case\"number\":{let e=null;for(const r of this.args){if(e=r.evaluate(t),null===e)return 0;const n=Number(e);if(!isNaN(n))return n}throw new le(`Could not convert ${JSON.stringify(e)} to number.`)}case\"formatted\":return Kt.fromString(oe(this.args[0].evaluate(t)));case\"resolvedImage\":return re.fromString(oe(this.args[0].evaluate(t)));default:return oe(this.args[0].evaluate(t))}}eachChild(t){this.args.forEach(t)}outputDefined(){return this.args.every((t=>t.outputDefined()))}}const pe=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"];class de{constructor(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null}id(){return this.feature&&\"id\"in this.feature?this.feature.id:null}geometryType(){return this.feature?\"number\"==typeof this.feature.type?pe[this.feature.type]:this.feature.type:null}geometry(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null}canonicalID(){return this.canonical}properties(){return this.feature&&this.feature.properties||{}}parseColor(t){let e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Xt.parse(t)),e}}class me{constructor(t,e,r=[],n,i=new st,a=[]){this.registry=t,this.path=r,this.key=r.map((t=>`[${t}]`)).join(\"\"),this.scope=i,this.errors=a,this.expectedType=n,this._isConstant=e}parse(t,e,r,n,i={}){return e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)}_parse(t,e){function r(t,e,r){return\"assert\"===r?new ue(e,[t]):\"coerce\"===r?new fe(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');const n=t[0];if(\"string\"!=typeof n)return this.error(`Expression name must be a string, but found ${typeof n} instead. If you wanted a literal array, use [\"literal\", [...]].`,0),null;const i=this.registry[n];if(i){let n=i.parse(t,this);if(!n)return null;if(this.expectedType){const t=this.expectedType,i=n.type;if(\"string\"!==t.kind&&\"number\"!==t.kind&&\"boolean\"!==t.kind&&\"object\"!==t.kind&&\"array\"!==t.kind||\"value\"!==i.kind)if(\"color\"!==t.kind&&\"formatted\"!==t.kind&&\"resolvedImage\"!==t.kind||\"value\"!==i.kind&&\"string\"!==i.kind)if(\"padding\"!==t.kind||\"value\"!==i.kind&&\"number\"!==i.kind&&\"array\"!==i.kind)if(\"variableAnchorOffsetCollection\"!==t.kind||\"value\"!==i.kind&&\"array\"!==i.kind){if(this.checkSubtype(t,i))return null}else n=r(n,t,e.typeAnnotation||\"coerce\");else n=r(n,t,e.typeAnnotation||\"coerce\");else n=r(n,t,e.typeAnnotation||\"coerce\");else n=r(n,t,e.typeAnnotation||\"assert\")}if(!(n instanceof se)&&\"resolvedImage\"!==n.type.kind&&this._isConstant(n)){const t=new de;try{n=new se(n.type,n.evaluate(t))}catch(t){return this.error(t.message),null}}return n}return this.error(`Unknown expression \"${n}\". If you wanted a literal array, use [\"literal\", [...]].`,0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(`Expected an array, but found ${typeof t} instead.`)}concat(t,e,r){const n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new me(this.registry,this._isConstant,n,e||null,i,this.errors)}error(t,...e){const r=`${this.key}${e.map((t=>`[${t}]`)).join(\"\")}`;this.errors.push(new ot(r,t))}checkSubtype(t,e){const r=Tt(t,e);return r&&this.error(r),r}}class ge{constructor(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e}evaluate(t){return this.result.evaluate(t)}eachChild(t){for(const e of this.bindings)t(e[1]);t(this.result)}static parse(t,e){if(t.length<4)return e.error(`Expected at least 3 arguments, but found ${t.length-1} instead.`);const r=[];for(let n=1;n<t.length-1;n+=2){const i=t[n];if(\"string\"!=typeof i)return e.error(`Expected string, but found ${typeof i} instead.`,n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);const a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}const n=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return n?new ge(r,n):null}outputDefined(){return this.result.outputDefined()}}class ye{constructor(t,e){this.type=e.type,this.name=t,this.boundExpression=e}static parse(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");const r=t[1];return e.scope.has(r)?new ye(r,e.scope.get(r)):e.error(`Unknown variable \"${r}\". Make sure \"${r}\" has been bound in an enclosing \"let\" expression before using it.`,1)}evaluate(t){return this.boundExpression.evaluate(t)}eachChild(){}outputDefined(){return!1}}class ve{constructor(t,e,r){this.type=t,this.index=e,this.input=r}static parse(t,e){if(3!==t.length)return e.error(`Expected 2 arguments, but found ${t.length-1} instead.`);const r=e.parse(t[1],1,ct),n=e.parse(t[2],2,_t(e.expectedType||dt));if(!r||!n)return null;const i=n.type;return new ve(i.itemType,r,n)}evaluate(t){const e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new le(`Array index out of bounds: ${e} < 0.`);if(e>=r.length)throw new le(`Array index out of bounds: ${e} > ${r.length-1}.`);if(e!==Math.floor(e))throw new le(`Array index must be an integer, but found ${e} instead.`);return r[e]}eachChild(t){t(this.index),t(this.input)}outputDefined(){return!1}}class xe{constructor(t,e){this.type=ht,this.needle=t,this.haystack=e}static parse(t,e){if(3!==t.length)return e.error(`Expected 2 arguments, but found ${t.length-1} instead.`);const r=e.parse(t[1],1,dt),n=e.parse(t[2],2,dt);return r&&n?kt(r.type,[ht,ut,ct,lt,dt])?new xe(r,n):e.error(`Expected first argument to be of type boolean, string, number or null, but found ${bt(r.type)} instead`):null}evaluate(t){const e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!At(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new le(`Expected first argument to be of type boolean, string, number or null, but found ${bt(ae(e))} instead.`);if(!At(r,[\"string\",\"array\"]))throw new le(`Expected second argument to be of type array or string, but found ${bt(ae(r))} instead.`);return r.indexOf(e)>=0}eachChild(t){t(this.needle),t(this.haystack)}outputDefined(){return!0}}class _e{constructor(t,e,r){this.type=ct,this.needle=t,this.haystack=e,this.fromIndex=r}static parse(t,e){if(t.length<=2||t.length>=5)return e.error(`Expected 3 or 4 arguments, but found ${t.length-1} instead.`);const r=e.parse(t[1],1,dt),n=e.parse(t[2],2,dt);if(!r||!n)return null;if(!kt(r.type,[ht,ut,ct,lt,dt]))return e.error(`Expected first argument to be of type boolean, string, number or null, but found ${bt(r.type)} instead`);if(4===t.length){const i=e.parse(t[3],3,ct);return i?new _e(r,n,i):null}return new _e(r,n)}evaluate(t){const e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!At(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new le(`Expected first argument to be of type boolean, string, number or null, but found ${bt(ae(e))} instead.`);if(!At(r,[\"string\",\"array\"]))throw new le(`Expected second argument to be of type array or string, but found ${bt(ae(r))} instead.`);if(this.fromIndex){const n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)}eachChild(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)}outputDefined(){return!1}}class be{constructor(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a}static parse(t,e){if(t.length<5)return e.error(`Expected at least 4 arguments, but found only ${t.length-1}.`);if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");let r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);const i={},a=[];for(let o=2;o<t.length-1;o+=2){let s=t[o];const l=t[o+1];Array.isArray(s)||(s=[s]);const c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(const t of s){if(\"number\"!=typeof t&&\"string\"!=typeof t)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof t&&Math.abs(t)>Number.MAX_SAFE_INTEGER)return c.error(`Branch labels must be integers no larger than ${Number.MAX_SAFE_INTEGER}.`);if(\"number\"==typeof t&&Math.floor(t)!==t)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,ae(t)))return null}else r=ae(t);if(void 0!==i[String(t)])return c.error(\"Branch labels must be unique.\");i[String(t)]=a.length}const u=e.parse(l,o,n);if(!u)return null;n=n||u.type,a.push(u)}const o=e.parse(t[1],1,dt);if(!o)return null;const s=e.parse(t[t.length-1],t.length-1,n);return s?\"value\"!==o.type.kind&&e.concat(1).checkSubtype(r,o.type)?null:new be(r,n,o,i,a,s):null}evaluate(t){const e=this.input.evaluate(t);return(ae(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)}eachChild(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)}outputDefined(){return this.outputs.every((t=>t.outputDefined()))&&this.otherwise.outputDefined()}}class we{constructor(t,e,r){this.type=t,this.branches=e,this.otherwise=r}static parse(t,e){if(t.length<4)return e.error(`Expected at least 3 arguments, but found only ${t.length-1}.`);if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");let r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);const n=[];for(let i=1;i<t.length-1;i+=2){const a=e.parse(t[i],i,ht);if(!a)return null;const o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}const i=e.parse(t[t.length-1],t.length-1,r);if(!i)return null;if(!r)throw new Error(\"Can't infer output type\");return new we(r,n,i)}evaluate(t){for(const[e,r]of this.branches)if(e.evaluate(t))return r.evaluate(t);return this.otherwise.evaluate(t)}eachChild(t){for(const[e,r]of this.branches)t(e),t(r);t(this.otherwise)}outputDefined(){return this.branches.every((([t,e])=>e.outputDefined()))&&this.otherwise.outputDefined()}}class Te{constructor(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n}static parse(t,e){if(t.length<=2||t.length>=5)return e.error(`Expected 3 or 4 arguments, but found ${t.length-1} instead.`);const r=e.parse(t[1],1,dt),n=e.parse(t[2],2,ct);if(!r||!n)return null;if(!kt(r.type,[_t(dt),ut,dt]))return e.error(`Expected first argument to be of type array or string, but found ${bt(r.type)} instead`);if(4===t.length){const i=e.parse(t[3],3,ct);return i?new Te(r.type,r,n,i):null}return new Te(r.type,r,n)}evaluate(t){const e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!At(e,[\"string\",\"array\"]))throw new le(`Expected first argument to be of type array or string, but found ${bt(ae(e))} instead.`);if(this.endIndex){const n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)}eachChild(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)}outputDefined(){return!1}}function ke(t,e){const r=t.length-1;let n,i,a=0,o=r,s=0;for(;a<=o;)if(s=Math.floor((a+o)/2),n=t[s],i=t[s+1],n<=e){if(s===r||e<i)return s;a=s+1}else{if(!(n>e))throw new le(\"Input is not a number.\");o=s-1}return 0}class Ae{constructor(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(const[t,e]of r)this.labels.push(t),this.outputs.push(e)}static parse(t,e){if(t.length-1<4)return e.error(`Expected at least 4 arguments, but found only ${t.length-1}.`);if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");const r=e.parse(t[1],1,ct);if(!r)return null;const n=[];let i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(let r=1;r<t.length;r+=2){const a=1===r?-1/0:t[r],o=t[r+1],s=r,l=r+1;if(\"number\"!=typeof a)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',s);if(n.length&&n[n.length-1][0]>=a)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',s);const c=e.parse(o,l,i);if(!c)return null;i=i||c.type,n.push([a,c])}return new Ae(i,r,n)}evaluate(t){const e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);const n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);const i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[ke(e,n)].evaluate(t)}eachChild(t){t(this.input);for(const e of this.outputs)t(e)}outputDefined(){return this.outputs.every((t=>t.outputDefined()))}}function Me(t){return t&&t.__esModule&&Object.prototype.hasOwnProperty.call(t,\"default\")?t.default:t}var Se=Ee;function Ee(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=e,this.p2x=r,this.p2y=n}Ee.prototype={sampleCurveX:function(t){return((this.ax*t+this.bx)*t+this.cx)*t},sampleCurveY:function(t){return((this.ay*t+this.by)*t+this.cy)*t},sampleCurveDerivativeX:function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},solveCurveX:function(t,e){if(void 0===e&&(e=1e-6),t<0)return 0;if(t>1)return 1;for(var r=t,n=0;n<8;n++){var i=this.sampleCurveX(r)-t;if(Math.abs(i)<e)return r;var a=this.sampleCurveDerivativeX(r);if(Math.abs(a)<1e-6)break;r-=i/a}var o=0,s=1;for(r=t,n=0;n<20&&(i=this.sampleCurveX(r),!(Math.abs(i-t)<e));n++)t>i?o=r:s=r,r=.5*(s-o)+o;return r},solve:function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))}};var Ce=Me(Se);function Le(t,e,r){return t+r*(e-t)}function Ie(t,e,r){return t.map(((t,n)=>Le(t,e[n],r)))}const Pe={number:Le,color:function(t,e,r,n=\"rgb\"){switch(n){case\"rgb\":{const[n,i,a,o]=Ie(t.rgb,e.rgb,r);return new Xt(n,i,a,o,!1)}case\"hcl\":{const[n,i,a,o]=t.hcl,[s,l,c,u]=e.hcl;let h,f;if(isNaN(n)||isNaN(s))isNaN(n)?isNaN(s)?h=NaN:(h=s,1!==a&&0!==a||(f=l)):(h=n,1!==c&&0!==c||(f=i));else{let t=s-n;s>n&&t>180?t-=360:s<n&&n-s>180&&(t+=360),h=n+r*t}const[p,d,m,g]=function([t,e,r,n]){return t=isNaN(t)?0:t*Ot,jt([r,Math.cos(t)*e,Math.sin(t)*e,n])}([h,null!=f?f:Le(i,l,r),Le(a,c,r),Le(o,u,r)]);return new Xt(p,d,m,g,!1)}case\"lab\":{const[n,i,a,o]=jt(Ie(t.lab,e.lab,r));return new Xt(n,i,a,o,!1)}}},array:Ie,padding:function(t,e,r){return new Qt(Ie(t.values,e.values,r))},variableAnchorOffsetCollection:function(t,e,r){const n=t.values,i=e.values;if(n.length!==i.length)throw new le(`Cannot interpolate values of different length. from: ${t.toString()}, to: ${e.toString()}`);const a=[];for(let t=0;t<n.length;t+=2){if(n[t]!==i[t])throw new le(`Cannot interpolate values containing mismatched anchors. from[${t}]: ${n[t]}, to[${t}]: ${i[t]}`);a.push(n[t]);const[e,o]=n[t+1],[s,l]=i[t+1];a.push([Le(e,s,r),Le(o,l,r)])}return new ee(a)}};class ze{constructor(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(const[t,e]of i)this.labels.push(t),this.outputs.push(e)}static interpolationFactor(t,e,r,n){let i=0;if(\"exponential\"===t.name)i=Oe(e,t.base,r,n);else if(\"linear\"===t.name)i=Oe(e,1,r,n);else if(\"cubic-bezier\"===t.name){const a=t.controlPoints;i=new Ce(a[0],a[1],a[2],a[3]).solve(Oe(e,1,r,n))}return i}static parse(t,e){let[r,n,i,...a]=t;if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){const t=n[1];if(\"number\"!=typeof t)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:t}}else{if(\"cubic-bezier\"!==n[0])return e.error(`Unknown interpolation type ${String(n[0])}`,1,0);{const t=n.slice(1);if(4!==t.length||t.some((t=>\"number\"!=typeof t||t<0||t>1)))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:t}}}if(t.length-1<4)return e.error(`Expected at least 4 arguments, but found only ${t.length-1}.`);if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(i=e.parse(i,2,ct),!i)return null;const o=[];let s=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?s=ft:e.expectedType&&\"value\"!==e.expectedType.kind&&(s=e.expectedType);for(let t=0;t<a.length;t+=2){const r=a[t],n=a[t+1],i=t+3,l=t+4;if(\"number\"!=typeof r)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',i);if(o.length&&o[o.length-1][0]>=r)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',i);const c=e.parse(n,l,s);if(!c)return null;s=s||c.type,o.push([r,c])}return Mt(s,ct)||Mt(s,ft)||Mt(s,yt)||Mt(s,xt)||Mt(s,_t(ct))?new ze(s,r,n,i,o):e.error(`Type ${bt(s)} is not interpolatable.`)}evaluate(t){const e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);const n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);const i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);const a=ke(e,n),o=e[a],s=e[a+1],l=ze.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);switch(this.operator){case\"interpolate\":return Pe[this.type.kind](c,u,l);case\"interpolate-hcl\":return Pe.color(c,u,l,\"hcl\");case\"interpolate-lab\":return Pe.color(c,u,l,\"lab\")}}eachChild(t){t(this.input);for(const e of this.outputs)t(e)}outputDefined(){return this.outputs.every((t=>t.outputDefined()))}}function Oe(t,e,r,n){const i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}class De{constructor(t,e){this.type=t,this.args=e}static parse(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");let r=null;const n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);const i=[];for(const n of t.slice(1)){const t=e.parse(n,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!t)return null;r=r||t.type,i.push(t)}if(!r)throw new Error(\"No output type\");const a=n&&i.some((t=>Tt(n,t.type)));return new De(a?dt:r,i)}evaluate(t){let e,r=null,n=0;for(const i of this.args)if(n++,r=i.evaluate(t),r&&r instanceof re&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null!==r)break;return r}eachChild(t){this.args.forEach(t)}outputDefined(){return this.args.every((t=>t.outputDefined()))}}function Re(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function Fe(t,e,r,n){return 0===n.compare(e,r)}function Be(t,e,r){const n=\"==\"!==t&&\"!=\"!==t;return class i{constructor(t,e,r){this.type=ht,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}static parse(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");const r=t[0];let a=e.parse(t[1],1,dt);if(!a)return null;if(!Re(r,a.type))return e.concat(1).error(`\"${r}\" comparisons are not supported for type '${bt(a.type)}'.`);let o=e.parse(t[2],2,dt);if(!o)return null;if(!Re(r,o.type))return e.concat(2).error(`\"${r}\" comparisons are not supported for type '${bt(o.type)}'.`);if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(`Cannot compare types '${bt(a.type)}' and '${bt(o.type)}'.`);n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new ue(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new ue(a.type,[o])));let s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(s=e.parse(t[3],3,mt),!s)return null}return new i(a,o,s)}evaluate(i){const a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){const e=ae(a),r=ae(o);if(e.kind!==r.kind||\"string\"!==e.kind&&\"number\"!==e.kind)throw new le(`Expected arguments for \"${t}\" to be (string, string) or (number, number), but found (${e.kind}, ${r.kind}) instead.`)}if(this.collator&&!n&&this.hasUntypedArgument){const t=ae(a),r=ae(o);if(\"string\"!==t.kind||\"string\"!==r.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)}eachChild(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)}outputDefined(){return!0}}}const Ne=Be(\"==\",(function(t,e,r){return e===r}),Fe),je=Be(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!Fe(0,e,r,n)})),Ue=Be(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),Ve=Be(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),qe=Be(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),He=Be(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0}));class Ge{constructor(t,e,r){this.type=mt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e}static parse(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");const r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");const n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,ht);if(!n)return null;const i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,ht);if(!i)return null;let a=null;return r.locale&&(a=e.parse(r.locale,1,ut),!a)?null:new Ge(n,i,a)}evaluate(t){return new $t(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)}eachChild(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)}outputDefined(){return!1}}class Ze{constructor(t,e,r,n,i){this.type=ut,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i}static parse(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");const r=e.parse(t[1],1,ct);if(!r)return null;const n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");let i=null;if(n.locale&&(i=e.parse(n.locale,1,ut),!i))return null;let a=null;if(n.currency&&(a=e.parse(n.currency,1,ut),!a))return null;let o=null;if(n[\"min-fraction-digits\"]&&(o=e.parse(n[\"min-fraction-digits\"],1,ct),!o))return null;let s=null;return n[\"max-fraction-digits\"]&&(s=e.parse(n[\"max-fraction-digits\"],1,ct),!s)?null:new Ze(r,i,a,o,s)}evaluate(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))}eachChild(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)}outputDefined(){return!1}}class We{constructor(t){this.type=gt,this.sections=t}static parse(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");const r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");const n=[];let i=!1;for(let r=1;r<=t.length-1;++r){const a=t[r];if(i&&\"object\"==typeof a&&!Array.isArray(a)){i=!1;let t=null;if(a[\"font-scale\"]&&(t=e.parse(a[\"font-scale\"],1,ct),!t))return null;let r=null;if(a[\"text-font\"]&&(r=e.parse(a[\"text-font\"],1,_t(ut)),!r))return null;let o=null;if(a[\"text-color\"]&&(o=e.parse(a[\"text-color\"],1,ft),!o))return null;const s=n[n.length-1];s.scale=t,s.font=r,s.textColor=o}else{const a=e.parse(t[r],1,dt);if(!a)return null;const o=a.type.kind;if(\"string\"!==o&&\"value\"!==o&&\"null\"!==o&&\"resolvedImage\"!==o)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");i=!0,n.push({content:a,scale:null,font:null,textColor:null})}}return new We(n)}evaluate(t){return new Kt(this.sections.map((e=>{const r=e.content.evaluate(t);return ae(r)===vt?new Jt(\"\",r,null,null,null):new Jt(oe(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))}eachChild(t){for(const e of this.sections)t(e.content),e.scale&&t(e.scale),e.font&&t(e.font),e.textColor&&t(e.textColor)}outputDefined(){return!1}}class Ye{constructor(t){this.type=vt,this.input=t}static parse(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");const r=e.parse(t[1],1,ut);return r?new Ye(r):e.error(\"No image name provided.\")}evaluate(t){const e=this.input.evaluate(t),r=re.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r}eachChild(t){t(this.input)}outputDefined(){return!1}}class Xe{constructor(t){this.type=ct,this.input=t}static parse(t,e){if(2!==t.length)return e.error(`Expected 1 argument, but found ${t.length-1} instead.`);const r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(`Expected argument of type string or array, but found ${bt(r.type)} instead.`):new Xe(r):null}evaluate(t){const e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new le(`Expected value to be of type string or array, but found ${bt(ae(e))} instead.`)}eachChild(t){t(this.input)}outputDefined(){return!1}}const $e=8192;function Je(t,e){const r=(180+t[0])/360,n=(a=t[1],(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+a*Math.PI/360)))/360),i=Math.pow(2,e.z);var a;return[Math.round(r*i*$e),Math.round(n*i*$e)]}function Ke(t,e){const r=Math.pow(2,e.z),n=(t[0]/$e+e.x)/r,i=(t[1]/$e+e.y)/r;return[(o=n,360*o-180),(a=i,360/Math.PI*Math.atan(Math.exp((180-360*a)*Math.PI/180))-90)];var a,o}function Qe(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function tr(t,e){return!(t[0]<=e[0]||t[2]>=e[2]||t[1]<=e[1]||t[3]>=e[3])}function er(t,e,r){const n=t[0]-e[0],i=t[1]-e[1],a=t[0]-r[0],o=t[1]-r[1];return n*o-a*i==0&&n*a<=0&&i*o<=0}function rr(t,e,r,n){const i=[e[0]-t[0],e[1]-t[1]];return 0!=(a=[n[0]-r[0],n[1]-r[1]],o=i,a[0]*o[1]-a[1]*o[0])&&!(!lr(t,e,r,n)||!lr(r,n,t,e));var a,o}function nr(t,e,r){for(const n of r)for(let r=0;r<n.length-1;++r)if(rr(t,e,n[r],n[r+1]))return!0;return!1}function ir(t,e,r=!1){let n=!1;for(const s of e)for(let e=0;e<s.length-1;e++){if(er(t,s[e],s[e+1]))return r;i=t,a=s[e],o=s[e+1],a[1]>i[1]!=o[1]>i[1]&&i[0]<(o[0]-a[0])*(i[1]-a[1])/(o[1]-a[1])+a[0]&&(n=!n)}var i,a,o;return n}function ar(t,e){for(const r of e)if(ir(t,r))return!0;return!1}function or(t,e){for(const r of t)if(!ir(r,e))return!1;for(let r=0;r<t.length-1;++r)if(nr(t[r],t[r+1],e))return!1;return!0}function sr(t,e){for(const r of e)if(or(t,r))return!0;return!1}function lr(t,e,r,n){const i=t[0]-r[0],a=t[1]-r[1],o=e[0]-r[0],s=e[1]-r[1],l=n[0]-r[0],c=n[1]-r[1],u=i*c-l*a,h=o*c-l*s;return u>0&&h<0||u<0&&h>0}function cr(t,e,r){const n=[];for(let i=0;i<t.length;i++){const a=[];for(let n=0;n<t[i].length;n++){const o=Je(t[i][n],r);Qe(e,o),a.push(o)}n.push(a)}return n}function ur(t,e,r){const n=[];for(let i=0;i<t.length;i++){const a=cr(t[i],e,r);n.push(a)}return n}function hr(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){const e=.5*n;let i=t[0]-r[0]>e?-n:r[0]-t[0]>e?n:0;0===i&&(i=t[0]-r[2]>e?-n:r[2]-t[0]>e?n:0),t[0]+=i}Qe(e,t)}function fr(t,e,r,n){const i=Math.pow(2,n.z)*$e,a=[n.x*$e,n.y*$e],o=[];for(const n of t)for(const t of n){const n=[t.x+a[0],t.y+a[1]];hr(n,e,r,i),o.push(n)}return o}function pr(t,e,r,n){const i=Math.pow(2,n.z)*$e,a=[n.x*$e,n.y*$e],o=[];for(const r of t){const t=[];for(const n of r){const r=[n.x+a[0],n.y+a[1]];Qe(e,r),t.push(r)}o.push(t)}if(e[2]-e[0]<=i/2){(s=e)[0]=s[1]=1/0,s[2]=s[3]=-1/0;for(const t of o)for(const n of t)hr(n,e,r,i)}var s;return o}class dr{constructor(t,e){this.type=ht,this.geojson=t,this.geometries=e}static parse(t,e){if(2!==t.length)return e.error(`'within' expression requires exactly one argument, but found ${t.length-1} instead.`);if(ie(t[1])){const e=t[1];if(\"FeatureCollection\"===e.type){const t=[];for(const r of e.features){const{type:e,coordinates:n}=r.geometry;\"Polygon\"===e&&t.push(n),\"MultiPolygon\"===e&&t.push(...n)}if(t.length)return new dr(e,{type:\"MultiPolygon\",coordinates:t})}else if(\"Feature\"===e.type){const t=e.geometry.type;if(\"Polygon\"===t||\"MultiPolygon\"===t)return new dr(e,e.geometry)}else if(\"Polygon\"===e.type||\"MultiPolygon\"===e.type)return new dr(e,e)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")}evaluate(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){const r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){const a=cr(e.coordinates,n,i),o=fr(t.geometry(),r,n,i);if(!tr(r,n))return!1;for(const t of o)if(!ir(t,a))return!1}if(\"MultiPolygon\"===e.type){const a=ur(e.coordinates,n,i),o=fr(t.geometry(),r,n,i);if(!tr(r,n))return!1;for(const t of o)if(!ar(t,a))return!1}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){const r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){const a=cr(e.coordinates,n,i),o=pr(t.geometry(),r,n,i);if(!tr(r,n))return!1;for(const t of o)if(!or(t,a))return!1}if(\"MultiPolygon\"===e.type){const a=ur(e.coordinates,n,i),o=pr(t.geometry(),r,n,i);if(!tr(r,n))return!1;for(const t of o)if(!sr(t,a))return!1}return!0}(t,this.geometries)}return!1}eachChild(){}outputDefined(){return!0}}let mr=class{constructor(t=[],e=gr){if(this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(let t=(this.length>>1)-1;t>=0;t--)this._down(t)}push(t){this.data.push(t),this.length++,this._up(this.length-1)}pop(){if(0===this.length)return;const t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}peek(){return this.data[0]}_up(t){const{data:e,compare:r}=this,n=e[t];for(;t>0;){const i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n}_down(t){const{data:e,compare:r}=this,n=this.length>>1,i=e[t];for(;t<n;){let n=1+(t<<1),a=e[n];const o=n+1;if(o<this.length&&r(e[o],a)<0&&(n=o,a=e[o]),r(a,i)>=0)break;e[t]=a,t=n}e[t]=i}};function gr(t,e){return t<e?-1:t>e?1:0}function yr(t,e,r,n,i){vr(t,e,r,n||t.length-1,i||_r)}function vr(t,e,r,n,i){for(;n>r;){if(n-r>600){var a=n-r+1,o=e-r+1,s=Math.log(a),l=.5*Math.exp(2*s/3),c=.5*Math.sqrt(s*l*(a-l)/a)*(o-a/2<0?-1:1);vr(t,e,Math.max(r,Math.floor(e-o*l/a+c)),Math.min(n,Math.floor(e+(a-o)*l/a+c)),i)}var u=t[e],h=r,f=n;for(xr(t,r,e),i(t[n],u)>0&&xr(t,r,n);h<f;){for(xr(t,h,f),h++,f--;i(t[h],u)<0;)h++;for(;i(t[f],u)>0;)f--}0===i(t[r],u)?xr(t,r,f):xr(t,++f,n),f<=e&&(r=f+1),e<=f&&(n=f-1)}}function xr(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function _r(t,e){return t<e?-1:t>e?1:0}function br(t,e){if(t.length<=1)return[t];const r=[];let n,i;for(const e of t){const t=Tr(e);0!==t&&(e.area=Math.abs(t),void 0===i&&(i=t<0),i===t<0?(n&&r.push(n),n=[e]):n.push(e))}if(n&&r.push(n),e>1)for(let t=0;t<r.length;t++)r[t].length<=e||(yr(r[t],e,1,r[t].length-1,wr),r[t]=r[t].slice(0,e));return r}function wr(t,e){return e.area-t.area}function Tr(t){let e=0;for(let r,n,i=0,a=t.length,o=a-1;i<a;o=i++)r=t[i],n=t[o],e+=(n.x-r.x)*(r.y+n.y);return e}const kr=1/298.257223563,Ar=kr*(2-kr),Mr=Math.PI/180;class Sr{constructor(t){const e=6378.137*Mr*1e3,r=Math.cos(t*Mr),n=1/(1-Ar*(1-r*r)),i=Math.sqrt(n);this.kx=e*i*r,this.ky=e*i*n*(1-Ar)}distance(t,e){const r=this.wrap(t[0]-e[0])*this.kx,n=(t[1]-e[1])*this.ky;return Math.sqrt(r*r+n*n)}pointOnLine(t,e){let r,n,i,a,o=1/0;for(let s=0;s<t.length-1;s++){let l=t[s][0],c=t[s][1],u=this.wrap(t[s+1][0]-l)*this.kx,h=(t[s+1][1]-c)*this.ky,f=0;0===u&&0===h||(f=(this.wrap(e[0]-l)*this.kx*u+(e[1]-c)*this.ky*h)/(u*u+h*h),f>1?(l=t[s+1][0],c=t[s+1][1]):f>0&&(l+=u/this.kx*f,c+=h/this.ky*f)),u=this.wrap(e[0]-l)*this.kx,h=(e[1]-c)*this.ky;const p=u*u+h*h;p<o&&(o=p,r=l,n=c,i=s,a=f)}return{point:[r,n],index:i,t:Math.max(0,Math.min(1,a))}}wrap(t){for(;t<-180;)t+=360;for(;t>180;)t-=360;return t}}const Er=100,Cr=50;function Lr(t,e){return e[0]-t[0]}function Ir(t){return t[1]-t[0]+1}function Pr(t,e){return t[1]>=t[0]&&t[1]<e}function zr(t,e){if(t[0]>t[1])return[null,null];const r=Ir(t);if(e){if(2===r)return[t,null];const e=Math.floor(r/2);return[[t[0],t[0]+e],[t[0]+e,t[1]]]}if(1===r)return[t,null];const n=Math.floor(r/2)-1;return[[t[0],t[0]+n],[t[0]+n+1,t[1]]]}function Or(t,e){if(!Pr(e,t.length))return[1/0,1/0,-1/0,-1/0];const r=[1/0,1/0,-1/0,-1/0];for(let n=e[0];n<=e[1];++n)Qe(r,t[n]);return r}function Dr(t){const e=[1/0,1/0,-1/0,-1/0];for(const r of t)for(const t of r)Qe(e,t);return e}function Rr(t){return t[0]!==-1/0&&t[1]!==-1/0&&t[2]!==1/0&&t[3]!==1/0}function Fr(t,e,r){if(!Rr(t)||!Rr(e))return NaN;let n=0,i=0;return t[2]<e[0]&&(n=e[0]-t[2]),t[0]>e[2]&&(n=t[0]-e[2]),t[1]>e[3]&&(i=t[1]-e[3]),t[3]<e[1]&&(i=e[1]-t[3]),r.distance([0,0],[n,i])}function Br(t,e,r){const n=r.pointOnLine(e,t);return r.distance(t,n.point)}function Nr(t,e,r,n,i){const a=Math.min(Br(t,[r,n],i),Br(e,[r,n],i)),o=Math.min(Br(r,[t,e],i),Br(n,[t,e],i));return Math.min(a,o)}function jr(t,e,r,n,i){if(!Pr(e,t.length)||!Pr(n,r.length))return 1/0;let a=1/0;for(let o=e[0];o<e[1];++o){const e=t[o],s=t[o+1];for(let t=n[0];t<n[1];++t){const n=r[t],o=r[t+1];if(rr(e,s,n,o))return 0;a=Math.min(a,Nr(e,s,n,o,i))}}return a}function Ur(t,e,r,n,i){if(!Pr(e,t.length)||!Pr(n,r.length))return NaN;let a=1/0;for(let o=e[0];o<=e[1];++o)for(let e=n[0];e<=n[1];++e)if(a=Math.min(a,i.distance(t[o],r[e])),0===a)return a;return a}function Vr(t,e,r){if(ir(t,e,!0))return 0;let n=1/0;for(const i of e){const e=i[0],a=i[i.length-1];if(e!==a&&(n=Math.min(n,Br(t,[a,e],r)),0===n))return n;const o=r.pointOnLine(i,t);if(n=Math.min(n,r.distance(t,o.point)),0===n)return n}return n}function qr(t,e,r,n){if(!Pr(e,t.length))return NaN;for(let n=e[0];n<=e[1];++n)if(ir(t[n],r,!0))return 0;let i=1/0;for(let a=e[0];a<e[1];++a){const e=t[a],o=t[a+1];for(const t of r)for(let r=0,a=t.length,s=a-1;r<a;s=r++){const a=t[s],l=t[r];if(rr(e,o,a,l))return 0;i=Math.min(i,Nr(e,o,a,l,n))}}return i}function Hr(t,e){for(const r of t)for(const t of r)if(ir(t,e,!0))return!0;return!1}function Gr(t,e,r,n=1/0){const i=Dr(t),a=Dr(e);if(n!==1/0&&Fr(i,a,r)>=n)return n;if(tr(i,a)){if(Hr(t,e))return 0}else if(Hr(e,t))return 0;let o=1/0;for(const n of t)for(let t=0,i=n.length,a=i-1;t<i;a=t++){const i=n[a],s=n[t];for(const t of e)for(let e=0,n=t.length,a=n-1;e<n;a=e++){const n=t[a],l=t[e];if(rr(i,s,n,l))return 0;o=Math.min(o,Nr(i,s,n,l,r))}}return o}function Zr(t,e,r,n,i,a){if(!a)return;const o=Fr(Or(n,a),i,r);o<e&&t.push([o,a,[0,0]])}function Wr(t,e,r,n,i,a,o){if(!a||!o)return;const s=Fr(Or(n,a),Or(i,o),r);s<e&&t.push([s,a,o])}function Yr(t,e,r,n,i=1/0){let a=Math.min(n.distance(t[0],r[0][0]),i);if(0===a)return a;const o=new mr([[0,[0,t.length-1],[0,0]]],Lr),s=Dr(r);for(;o.length>0;){const i=o.pop();if(i[0]>=a)continue;const l=i[1],c=e?Cr:Er;if(Ir(l)<=c){if(!Pr(l,t.length))return NaN;if(e){const e=qr(t,l,r,n);if(isNaN(e)||0===e)return e;a=Math.min(a,e)}else for(let e=l[0];e<=l[1];++e){const i=Vr(t[e],r,n);if(a=Math.min(a,i),0===a)return 0}}else{const r=zr(l,e);Zr(o,a,n,t,s,r[0]),Zr(o,a,n,t,s,r[1])}}return a}function Xr(t,e,r,n,i,a=1/0){let o=Math.min(a,i.distance(t[0],r[0]));if(0===o)return o;const s=new mr([[0,[0,t.length-1],[0,r.length-1]]],Lr);for(;s.length>0;){const a=s.pop();if(a[0]>=o)continue;const l=a[1],c=a[2],u=e?Cr:Er,h=n?Cr:Er;if(Ir(l)<=u&&Ir(c)<=h){if(!Pr(l,t.length)&&Pr(c,r.length))return NaN;let a;if(e&&n)a=jr(t,l,r,c,i),o=Math.min(o,a);else if(e&&!n){const e=t.slice(l[0],l[1]+1);for(let t=c[0];t<=c[1];++t)if(a=Br(r[t],e,i),o=Math.min(o,a),0===o)return o}else if(!e&&n){const e=r.slice(c[0],c[1]+1);for(let r=l[0];r<=l[1];++r)if(a=Br(t[r],e,i),o=Math.min(o,a),0===o)return o}else a=Ur(t,l,r,c,i),o=Math.min(o,a)}else{const a=zr(l,e),u=zr(c,n);Wr(s,o,i,t,r,a[0],u[0]),Wr(s,o,i,t,r,a[0],u[1]),Wr(s,o,i,t,r,a[1],u[0]),Wr(s,o,i,t,r,a[1],u[1])}}return o}function $r(t){return\"MultiPolygon\"===t.type?t.coordinates.map((t=>({type:\"Polygon\",coordinates:t}))):\"MultiLineString\"===t.type?t.coordinates.map((t=>({type:\"LineString\",coordinates:t}))):\"MultiPoint\"===t.type?t.coordinates.map((t=>({type:\"Point\",coordinates:t}))):[t]}class Jr{constructor(t,e){this.type=ct,this.geojson=t,this.geometries=e}static parse(t,e){if(2!==t.length)return e.error(`'distance' expression requires exactly one argument, but found ${t.length-1} instead.`);if(ie(t[1])){const e=t[1];if(\"FeatureCollection\"===e.type)return new Jr(e,e.features.map((t=>$r(t.geometry))).flat());if(\"Feature\"===e.type)return new Jr(e,$r(e.geometry));if(\"type\"in e&&\"coordinates\"in e)return new Jr(e,$r(e))}return e.error(\"'distance' expression requires valid geojson object that contains polygon geometry type.\")}evaluate(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){const r=t.geometry(),n=r.flat().map((e=>Ke([e.x,e.y],t.canonical)));if(0===r.length)return NaN;const i=new Sr(n[0][1]);let a=1/0;for(const t of e){switch(t.type){case\"Point\":a=Math.min(a,Xr(n,!1,[t.coordinates],!1,i,a));break;case\"LineString\":a=Math.min(a,Xr(n,!1,t.coordinates,!0,i,a));break;case\"Polygon\":a=Math.min(a,Yr(n,!1,t.coordinates,i,a))}if(0===a)return a}return a}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){const r=t.geometry(),n=r.flat().map((e=>Ke([e.x,e.y],t.canonical)));if(0===r.length)return NaN;const i=new Sr(n[0][1]);let a=1/0;for(const t of e){switch(t.type){case\"Point\":a=Math.min(a,Xr(n,!0,[t.coordinates],!1,i,a));break;case\"LineString\":a=Math.min(a,Xr(n,!0,t.coordinates,!0,i,a));break;case\"Polygon\":a=Math.min(a,Yr(n,!0,t.coordinates,i,a))}if(0===a)return a}return a}(t,this.geometries);if(\"Polygon\"===t.geometryType())return function(t,e){const r=t.geometry();if(0===r.length||0===r[0].length)return NaN;const n=br(r,0).map((e=>e.map((e=>e.map((e=>Ke([e.x,e.y],t.canonical))))))),i=new Sr(n[0][0][0][1]);let a=1/0;for(const t of e)for(const e of n){switch(t.type){case\"Point\":a=Math.min(a,Yr([t.coordinates],!1,e,i,a));break;case\"LineString\":a=Math.min(a,Yr(t.coordinates,!0,e,i,a));break;case\"Polygon\":a=Math.min(a,Gr(e,t.coordinates,i,a))}if(0===a)return a}return a}(t,this.geometries)}return NaN}eachChild(){}outputDefined(){return!0}}const Kr={\"==\":Ne,\"!=\":je,\">\":Ve,\"<\":Ue,\">=\":He,\"<=\":qe,array:ue,at:ve,boolean:ue,case:we,coalesce:De,collator:Ge,format:We,image:Ye,in:xe,\"index-of\":_e,interpolate:ze,\"interpolate-hcl\":ze,\"interpolate-lab\":ze,length:Xe,let:ge,literal:se,match:be,number:ue,\"number-format\":Ze,object:ue,slice:Te,step:Ae,string:ue,\"to-boolean\":fe,\"to-color\":fe,\"to-number\":fe,\"to-string\":fe,var:ye,within:dr,distance:Jr};class Qr{constructor(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n}evaluate(t){return this._evaluate(t,this.args)}eachChild(t){this.args.forEach(t)}outputDefined(){return!1}static parse(t,e){const r=t[0],n=Qr.definitions[r];if(!n)return e.error(`Unknown expression \"${r}\". If you wanted a literal array, use [\"literal\", [...]].`,0);const i=Array.isArray(n)?n[0]:n.type,a=Array.isArray(n)?[[n[1],n[2]]]:n.overloads,o=a.filter((([e])=>!Array.isArray(e)||e.length===t.length-1));let s=null;for(const[n,a]of o){s=new me(e.registry,an,e.path,null,e.scope);const o=[];let l=!1;for(let e=1;e<t.length;e++){const r=t[e],i=Array.isArray(n)?n[e-1]:n.type,a=s.parse(r,1+o.length,i);if(!a){l=!0;break}o.push(a)}if(!l)if(Array.isArray(n)&&n.length!==o.length)s.error(`Expected ${n.length} arguments, but found ${o.length} instead.`);else{for(let t=0;t<o.length;t++){const e=Array.isArray(n)?n[t]:n.type,r=o[t];s.concat(t+1).checkSubtype(e,r.type)}if(0===s.errors.length)return new Qr(r,i,a,o)}}if(1===o.length)e.errors.push(...s.errors);else{const r=(o.length?o:a).map((([t])=>{return e=t,Array.isArray(e)?`(${e.map(bt).join(\", \")})`:`(${bt(e.type)}...)`;var e})).join(\" | \"),n=[];for(let r=1;r<t.length;r++){const i=e.parse(t[r],1+n.length);if(!i)return null;n.push(bt(i.type))}e.error(`Expected arguments of type ${r}, but found (${n.join(\", \")}) instead.`)}return null}static register(t,e){Qr.definitions=e;for(const r in e)t[r]=Qr}}function tn(t,[e,r,n,i]){e=e.evaluate(t),r=r.evaluate(t),n=n.evaluate(t);const a=i?i.evaluate(t):1,o=ne(e,r,n,a);if(o)throw new le(o);return new Xt(e/255,r/255,n/255,a,!1)}function en(t,e){return t in e}function rn(t,e){const r=e[t];return void 0===r?null:r}function nn(t){return{type:t}}function an(t){if(t instanceof ye)return an(t.boundExpression);if(t instanceof Qr&&\"error\"===t.name)return!1;if(t instanceof Ge)return!1;if(t instanceof dr)return!1;if(t instanceof Jr)return!1;const e=t instanceof fe||t instanceof ue;let r=!0;return t.eachChild((t=>{r=e?r&&an(t):r&&t instanceof se})),!!r&&on(t)&&ln(t,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}function on(t){if(t instanceof Qr){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof dr)return!1;if(t instanceof Jr)return!1;let e=!0;return t.eachChild((t=>{e&&!on(t)&&(e=!1)})),e}function sn(t){if(t instanceof Qr&&\"feature-state\"===t.name)return!1;let e=!0;return t.eachChild((t=>{e&&!sn(t)&&(e=!1)})),e}function ln(t,e){if(t instanceof Qr&&e.indexOf(t.name)>=0)return!1;let r=!0;return t.eachChild((t=>{r&&!ln(t,e)&&(r=!1)})),r}function cn(t){return{result:\"success\",value:t}}function un(t){return{result:\"error\",value:t}}function hn(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function fn(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function pn(t){return!!t.expression&&t.expression.interpolated}function dn(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function mn(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function gn(t){return t}function yn(t,e){const r=\"color\"===e.type,n=t.stops&&\"object\"==typeof t.stops[0][0],i=n||void 0!==t.property,a=n||!i,o=t.type||(pn(e)?\"exponential\":\"interval\");if(r||\"padding\"===e.type){const n=r?Xt.parse:Qt.parse;(t=at({},t)).stops&&(t.stops=t.stops.map((t=>[t[0],n(t[1])]))),t.default?t.default=n(t.default):t.default=n(e.default)}if(t.colorSpace&&(\"rgb\"!==(s=t.colorSpace)&&\"hcl\"!==s&&\"lab\"!==s))throw new Error(`Unknown color space: \"${t.colorSpace}\"`);var s;let l,c,u;if(\"exponential\"===o)l=bn;else if(\"interval\"===o)l=_n;else if(\"categorical\"===o){l=xn,c=Object.create(null);for(const e of t.stops)c[e[0]]=e[1];u=typeof t.stops[0][0]}else{if(\"identity\"!==o)throw new Error(`Unknown function type \"${o}\"`);l=wn}if(n){const r={},n=[];for(let e=0;e<t.stops.length;e++){const i=t.stops[e],a=i[0].zoom;void 0===r[a]&&(r[a]={zoom:a,type:t.type,property:t.property,default:t.default,stops:[]},n.push(a)),r[a].stops.push([i[0].value,i[1]])}const i=[];for(const t of n)i.push([r[t].zoom,yn(r[t],e)]);const a={name:\"linear\"};return{kind:\"composite\",interpolationType:a,interpolationFactor:ze.interpolationFactor.bind(void 0,a),zoomStops:i.map((t=>t[0])),evaluate({zoom:r},n){return bn({stops:i,base:t.base},e,r).evaluate(r,n)}}}if(a){const r=\"exponential\"===o?{name:\"exponential\",base:void 0!==t.base?t.base:1}:null;return{kind:\"camera\",interpolationType:r,interpolationFactor:ze.interpolationFactor.bind(void 0,r),zoomStops:t.stops.map((t=>t[0])),evaluate:({zoom:r})=>l(t,e,r,c,u)}}return{kind:\"source\",evaluate(r,n){const i=n&&n.properties?n.properties[t.property]:void 0;return void 0===i?vn(t.default,e.default):l(t,e,i,c,u)}}}function vn(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function xn(t,e,r,n,i){return vn(typeof r===i?n[r]:void 0,t.default,e.default)}function _n(t,e,r){if(\"number\"!==dn(r))return vn(t.default,e.default);const n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];const i=ke(t.stops.map((t=>t[0])),r);return t.stops[i][1]}function bn(t,e,r){const n=void 0!==t.base?t.base:1;if(\"number\"!==dn(r))return vn(t.default,e.default);const i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];const a=ke(t.stops.map((t=>t[0])),r),o=function(t,e,r,n){const i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Pe[e.type]||gn;return\"function\"==typeof s.evaluate?{evaluate(...e){const r=s.evaluate.apply(void 0,e),n=l.evaluate.apply(void 0,e);if(void 0!==r&&void 0!==n)return c(r,n,o,t.colorSpace)}}:c(s,l,o,t.colorSpace)}function wn(t,e,r){switch(e.type){case\"color\":r=Xt.parse(r);break;case\"formatted\":r=Kt.fromString(r.toString());break;case\"resolvedImage\":r=re.fromString(r.toString());break;case\"padding\":r=Qt.parse(r);break;default:dn(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0)}return vn(r,t.default,e.default)}Qr.register(Kr,{error:[{kind:\"error\"},[ut],(t,[e])=>{throw new le(e.evaluate(t))}],typeof:[ut,[dt],(t,[e])=>bt(ae(e.evaluate(t)))],\"to-rgba\":[_t(ct,4),[ft],(t,[e])=>{const[r,n,i,a]=e.evaluate(t).rgb;return[255*r,255*n,255*i,a]}],rgb:[ft,[ct,ct,ct],tn],rgba:[ft,[ct,ct,ct,ct],tn],has:{type:ht,overloads:[[[ut],(t,[e])=>en(e.evaluate(t),t.properties())],[[ut,pt],(t,[e,r])=>en(e.evaluate(t),r.evaluate(t))]]},get:{type:dt,overloads:[[[ut],(t,[e])=>rn(e.evaluate(t),t.properties())],[[ut,pt],(t,[e,r])=>rn(e.evaluate(t),r.evaluate(t))]]},\"feature-state\":[dt,[ut],(t,[e])=>rn(e.evaluate(t),t.featureState||{})],properties:[pt,[],t=>t.properties()],\"geometry-type\":[ut,[],t=>t.geometryType()],id:[dt,[],t=>t.id()],zoom:[ct,[],t=>t.globals.zoom],\"heatmap-density\":[ct,[],t=>t.globals.heatmapDensity||0],\"line-progress\":[ct,[],t=>t.globals.lineProgress||0],accumulated:[dt,[],t=>void 0===t.globals.accumulated?null:t.globals.accumulated],\"+\":[ct,nn(ct),(t,e)=>{let r=0;for(const n of e)r+=n.evaluate(t);return r}],\"*\":[ct,nn(ct),(t,e)=>{let r=1;for(const n of e)r*=n.evaluate(t);return r}],\"-\":{type:ct,overloads:[[[ct,ct],(t,[e,r])=>e.evaluate(t)-r.evaluate(t)],[[ct],(t,[e])=>-e.evaluate(t)]]},\"/\":[ct,[ct,ct],(t,[e,r])=>e.evaluate(t)/r.evaluate(t)],\"%\":[ct,[ct,ct],(t,[e,r])=>e.evaluate(t)%r.evaluate(t)],ln2:[ct,[],()=>Math.LN2],pi:[ct,[],()=>Math.PI],e:[ct,[],()=>Math.E],\"^\":[ct,[ct,ct],(t,[e,r])=>Math.pow(e.evaluate(t),r.evaluate(t))],sqrt:[ct,[ct],(t,[e])=>Math.sqrt(e.evaluate(t))],log10:[ct,[ct],(t,[e])=>Math.log(e.evaluate(t))/Math.LN10],ln:[ct,[ct],(t,[e])=>Math.log(e.evaluate(t))],log2:[ct,[ct],(t,[e])=>Math.log(e.evaluate(t))/Math.LN2],sin:[ct,[ct],(t,[e])=>Math.sin(e.evaluate(t))],cos:[ct,[ct],(t,[e])=>Math.cos(e.evaluate(t))],tan:[ct,[ct],(t,[e])=>Math.tan(e.evaluate(t))],asin:[ct,[ct],(t,[e])=>Math.asin(e.evaluate(t))],acos:[ct,[ct],(t,[e])=>Math.acos(e.evaluate(t))],atan:[ct,[ct],(t,[e])=>Math.atan(e.evaluate(t))],min:[ct,nn(ct),(t,e)=>Math.min(...e.map((e=>e.evaluate(t))))],max:[ct,nn(ct),(t,e)=>Math.max(...e.map((e=>e.evaluate(t))))],abs:[ct,[ct],(t,[e])=>Math.abs(e.evaluate(t))],round:[ct,[ct],(t,[e])=>{const r=e.evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[ct,[ct],(t,[e])=>Math.floor(e.evaluate(t))],ceil:[ct,[ct],(t,[e])=>Math.ceil(e.evaluate(t))],\"filter-==\":[ht,[ut,dt],(t,[e,r])=>t.properties()[e.value]===r.value],\"filter-id-==\":[ht,[dt],(t,[e])=>t.id()===e.value],\"filter-type-==\":[ht,[ut],(t,[e])=>t.geometryType()===e.value],\"filter-<\":[ht,[ut,dt],(t,[e,r])=>{const n=t.properties()[e.value],i=r.value;return typeof n==typeof i&&n<i}],\"filter-id-<\":[ht,[dt],(t,[e])=>{const r=t.id(),n=e.value;return typeof r==typeof n&&r<n}],\"filter->\":[ht,[ut,dt],(t,[e,r])=>{const n=t.properties()[e.value],i=r.value;return typeof n==typeof i&&n>i}],\"filter-id->\":[ht,[dt],(t,[e])=>{const r=t.id(),n=e.value;return typeof r==typeof n&&r>n}],\"filter-<=\":[ht,[ut,dt],(t,[e,r])=>{const n=t.properties()[e.value],i=r.value;return typeof n==typeof i&&n<=i}],\"filter-id-<=\":[ht,[dt],(t,[e])=>{const r=t.id(),n=e.value;return typeof r==typeof n&&r<=n}],\"filter->=\":[ht,[ut,dt],(t,[e,r])=>{const n=t.properties()[e.value],i=r.value;return typeof n==typeof i&&n>=i}],\"filter-id->=\":[ht,[dt],(t,[e])=>{const r=t.id(),n=e.value;return typeof r==typeof n&&r>=n}],\"filter-has\":[ht,[dt],(t,[e])=>e.value in t.properties()],\"filter-has-id\":[ht,[],t=>null!==t.id()&&void 0!==t.id()],\"filter-type-in\":[ht,[_t(ut)],(t,[e])=>e.value.indexOf(t.geometryType())>=0],\"filter-id-in\":[ht,[_t(dt)],(t,[e])=>e.value.indexOf(t.id())>=0],\"filter-in-small\":[ht,[ut,_t(dt)],(t,[e,r])=>r.value.indexOf(t.properties()[e.value])>=0],\"filter-in-large\":[ht,[ut,_t(dt)],(t,[e,r])=>function(t,e,r,n){for(;r<=n;){const i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[e.value],r.value,0,r.value.length-1)],all:{type:ht,overloads:[[[ht,ht],(t,[e,r])=>e.evaluate(t)&&r.evaluate(t)],[nn(ht),(t,e)=>{for(const r of e)if(!r.evaluate(t))return!1;return!0}]]},any:{type:ht,overloads:[[[ht,ht],(t,[e,r])=>e.evaluate(t)||r.evaluate(t)],[nn(ht),(t,e)=>{for(const r of e)if(r.evaluate(t))return!0;return!1}]]},\"!\":[ht,[ht],(t,[e])=>!e.evaluate(t)],\"is-supported-script\":[ht,[ut],(t,[e])=>{const r=t.globals&&t.globals.isSupportedScript;return!r||r(e.evaluate(t))}],upcase:[ut,[ut],(t,[e])=>e.evaluate(t).toUpperCase()],downcase:[ut,[ut],(t,[e])=>e.evaluate(t).toLowerCase()],concat:[ut,nn(dt),(t,e)=>e.map((e=>oe(e.evaluate(t)))).join(\"\")],\"resolved-locale\":[ut,[mt],(t,[e])=>e.evaluate(t).resolvedLocale()]});class Tn{constructor(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new de,this._defaultValue=e?\"color\"===(r=e).type&&mn(r.default)?new Xt(0,0,0,0):\"color\"===r.type?Xt.parse(r.default)||null:\"padding\"===r.type?Qt.parse(r.default)||null:\"variableAnchorOffsetCollection\"===r.type?ee.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null}evaluateWithoutErrorHandling(t,e,r,n,i,a){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a,this.expression.evaluate(this._evaluator)}evaluate(t,e,r,n,i,a){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a||null;try{const t=this.expression.evaluate(this._evaluator);if(null==t||\"number\"==typeof t&&t!=t)return this._defaultValue;if(this._enumValues&&!(t in this._enumValues))throw new le(`Expected value to be one of ${Object.keys(this._enumValues).map((t=>JSON.stringify(t))).join(\", \")}, but found ${JSON.stringify(t)} instead.`);return t}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}}}function kn(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Kr}function An(t,e){const r=new me(Kr,an,[],e?function(t){const e={color:ft,string:ut,number:ct,enum:ut,boolean:ht,formatted:gt,padding:yt,resolvedImage:vt,variableAnchorOffsetCollection:xt};return\"array\"===t.type?_t(e[t.value]||dt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?cn(new Tn(n,e)):un(r.errors)}class Mn{constructor(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!sn(e.expression)}evaluateWithoutErrorHandling(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)}evaluate(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)}}class Sn{constructor(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!sn(e.expression),this.interpolationType=n}evaluateWithoutErrorHandling(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)}evaluate(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)}interpolationFactor(t,e,r){return this.interpolationType?ze.interpolationFactor(this.interpolationType,t,e,r):0}}function En(t,e){const r=An(t,e);if(\"error\"===r.result)return r;const n=r.value.expression,i=on(n);if(!i&&!hn(e))return un([new ot(\"\",\"data expressions not supported\")]);const a=ln(n,[\"zoom\"]);if(!a&&!fn(e))return un([new ot(\"\",\"zoom expressions not supported\")]);const o=Ln(n);if(!o&&!a)return un([new ot(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')]);if(o instanceof ot)return un([o]);if(o instanceof ze&&!pn(e))return un([new ot(\"\",'\"interpolate\" expressions cannot be used with this property')]);if(!o)return cn(new Mn(i?\"constant\":\"source\",r.value));const s=o instanceof ze?o.interpolation:void 0;return cn(new Sn(i?\"camera\":\"composite\",r.value,o.labels,s))}class Cn{constructor(t,e){this._parameters=t,this._specification=e,at(this,yn(this._parameters,this._specification))}static deserialize(t){return new Cn(t._parameters,t._specification)}static serialize(t){return{_parameters:t._parameters,_specification:t._specification}}}function Ln(t){let e=null;if(t instanceof ge)e=Ln(t.result);else if(t instanceof De){for(const r of t.args)if(e=Ln(r),e)break}else(t instanceof Ae||t instanceof ze)&&t.input instanceof Qr&&\"zoom\"===t.input.name&&(e=t);return e instanceof ot||t.eachChild((t=>{const r=Ln(t);r instanceof ot?e=r:!e&&r?e=new ot(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):e&&r&&e!==r&&(e=new ot(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),e}function In(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(const e of t.slice(1))if(!In(e)&&\"boolean\"!=typeof e)return!1;return!0;default:return!0}}const Pn={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function zn(t){if(null==t)return{filter:()=>!0,needGeometry:!1};In(t)||(t=Rn(t));const e=An(t,Pn);if(\"error\"===e.result)throw new Error(e.value.map((t=>`${t.key}: ${t.message}`)).join(\", \"));return{filter:(t,r,n)=>e.value.evaluate(t,r,{},n),needGeometry:Dn(t)}}function On(t,e){return t<e?-1:t>e?1:0}function Dn(t){if(!Array.isArray(t))return!1;if(\"within\"===t[0]||\"distance\"===t[0])return!0;for(let e=1;e<t.length;e++)if(Dn(t[e]))return!0;return!1}function Rn(t){if(!t)return!0;const e=t[0];return t.length<=1?\"any\"!==e:\"==\"===e?Fn(t[1],t[2],\"==\"):\"!=\"===e?jn(Fn(t[1],t[2],\"==\")):\"<\"===e||\">\"===e||\"<=\"===e||\">=\"===e?Fn(t[1],t[2],e):\"any\"===e?(r=t.slice(1),[\"any\"].concat(r.map(Rn))):\"all\"===e?[\"all\"].concat(t.slice(1).map(Rn)):\"none\"===e?[\"all\"].concat(t.slice(1).map(Rn).map(jn)):\"in\"===e?Bn(t[1],t.slice(2)):\"!in\"===e?jn(Bn(t[1],t.slice(2))):\"has\"===e?Nn(t[1]):\"!has\"!==e||jn(Nn(t[1]));var r}function Fn(t,e,r){switch(t){case\"$type\":return[`filter-type-${r}`,e];case\"$id\":return[`filter-id-${r}`,e];default:return[`filter-${r}`,t,e]}}function Bn(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((t=>typeof t!=typeof e[0]))?[\"filter-in-large\",t,[\"literal\",e.sort(On)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Nn(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function jn(t){return[\"!\",t]}function Un(t){const e=typeof t;if(\"number\"===e||\"boolean\"===e||\"string\"===e||null==t)return JSON.stringify(t);if(Array.isArray(t)){let e=\"[\";for(const r of t)e+=`${Un(r)},`;return`${e}]`}const r=Object.keys(t).sort();let n=\"{\";for(let e=0;e<r.length;e++)n+=`${JSON.stringify(r[e])}:${Un(t[r[e]])},`;return`${n}}`}function Vn(t){let e=\"\";for(const r of W)e+=`/${Un(t[r])}`;return e}function qn(t){const e=t.key,r=t.value;return r?[new it(e,r,\"constants have been deprecated as of v8\")]:[]}function Hn(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function Gn(t){if(Array.isArray(t))return t.map(Gn);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){const e={};for(const r in t)e[r]=Gn(t[r]);return e}return Hn(t)}function Zn(t){const e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=t.validateSpec;let l=[];const c=dn(r);if(\"object\"!==c)return[new it(e,r,`object expected, ${c} found`)];for(const t in r){const c=t.split(\".\")[0],u=n[c]||n[\"*\"];let h;if(i[c])h=i[c];else if(n[c])h=s;else if(i[\"*\"])h=i[\"*\"];else{if(!n[\"*\"]){l.push(new it(e,r[t],`unknown property \"${t}\"`));continue}h=s}l=l.concat(h({key:(e?`${e}.`:e)+t,value:r[t],valueSpec:u,style:a,styleSpec:o,object:r,objectKey:t,validateSpec:s},r))}for(const t in n)i[t]||n[t].required&&void 0===n[t].default&&void 0===r[t]&&l.push(new it(e,r,`missing required property \"${t}\"`));return l}function Wn(t){const e=t.value,r=t.valueSpec,n=t.validateSpec,i=t.style,a=t.styleSpec,o=t.key,s=t.arrayElementValidator||n;if(\"array\"!==dn(e))return[new it(o,e,`array expected, ${dn(e)} found`)];if(r.length&&e.length!==r.length)return[new it(o,e,`array length ${r.length} expected, length ${e.length} found`)];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new it(o,e,`array length at least ${r[\"min-length\"]} expected, length ${e.length} found`)];let l={type:r.value,values:r.values};a.$version<7&&(l.function=r.function),\"object\"===dn(r.value)&&(l=r.value);let c=[];for(let r=0;r<e.length;r++)c=c.concat(s({array:e,arrayIndex:r,value:e[r],valueSpec:l,validateSpec:t.validateSpec,style:i,styleSpec:a,key:`${o}[${r}]`}));return c}function Yn(t){const e=t.key,r=t.value,n=t.valueSpec;let i=dn(r);return\"number\"===i&&r!=r&&(i=\"NaN\"),\"number\"!==i?[new it(e,r,`number expected, ${i} found`)]:\"minimum\"in n&&r<n.minimum?[new it(e,r,`${r} is less than the minimum value ${n.minimum}`)]:\"maximum\"in n&&r>n.maximum?[new it(e,r,`${r} is greater than the maximum value ${n.maximum}`)]:[]}function Xn(t){const e=t.valueSpec,r=Hn(t.value.type);let n,i,a,o={};const s=\"categorical\"!==r&&void 0===t.value.property,l=!s,c=\"array\"===dn(t.value.stops)&&\"array\"===dn(t.value.stops[0])&&\"object\"===dn(t.value.stops[0][0]),u=Zn({key:t.key,value:t.value,valueSpec:t.styleSpec.function,validateSpec:t.validateSpec,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===r)return[new it(t.key,t.value,'identity function may not have a \"stops\" property')];let e=[];const n=t.value;return e=e.concat(Wn({key:t.key,value:n,valueSpec:t.valueSpec,validateSpec:t.validateSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===dn(n)&&0===n.length&&e.push(new it(t.key,n,\"array must have at least one stop\")),e},default:function(t){return t.validateSpec({key:t.key,value:t.value,valueSpec:e,validateSpec:t.validateSpec,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===r&&s&&u.push(new it(t.key,t.value,'missing required property \"property\"')),\"identity\"===r||t.value.stops||u.push(new it(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===r&&t.valueSpec.expression&&!pn(t.valueSpec)&&u.push(new it(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!hn(t.valueSpec)?u.push(new it(t.key,t.value,\"property functions not supported\")):s&&!fn(t.valueSpec)&&u.push(new it(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==r&&!c||void 0!==t.value.property||u.push(new it(t.key,t.value,'\"property\" property is required')),u;function h(t){let r=[];const n=t.value,s=t.key;if(\"array\"!==dn(n))return[new it(s,n,`array expected, ${dn(n)} found`)];if(2!==n.length)return[new it(s,n,`array length 2 expected, length ${n.length} found`)];if(c){if(\"object\"!==dn(n[0]))return[new it(s,n,`object expected, ${dn(n[0])} found`)];if(void 0===n[0].zoom)return[new it(s,n,\"object stop key must have zoom\")];if(void 0===n[0].value)return[new it(s,n,\"object stop key must have value\")];if(a&&a>Hn(n[0].zoom))return[new it(s,n[0].zoom,\"stop zoom values must appear in ascending order\")];Hn(n[0].zoom)!==a&&(a=Hn(n[0].zoom),i=void 0,o={}),r=r.concat(Zn({key:`${s}[0]`,value:n[0],valueSpec:{zoom:{}},validateSpec:t.validateSpec,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Yn,value:f}}))}else r=r.concat(f({key:`${s}[0]`,value:n[0],valueSpec:{},validateSpec:t.validateSpec,style:t.style,styleSpec:t.styleSpec},n));return kn(Gn(n[1]))?r.concat([new it(`${s}[1]`,n[1],\"expressions are not allowed in function stops.\")]):r.concat(t.validateSpec({key:`${s}[1]`,value:n[1],valueSpec:e,validateSpec:t.validateSpec,style:t.style,styleSpec:t.styleSpec}))}function f(t,a){const s=dn(t.value),l=Hn(t.value),c=null!==t.value?t.value:a;if(n){if(s!==n)return[new it(t.key,c,`${s} stop domain type must match previous stop domain type ${n}`)]}else n=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new it(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==r){let n=`number expected, ${s} found`;return hn(e)&&void 0===r&&(n+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new it(t.key,c,n)]}return\"categorical\"!==r||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==r&&\"number\"===s&&void 0!==i&&l<i?[new it(t.key,c,\"stop domain values must appear in ascending order\")]:(i=l,\"categorical\"===r&&l in o?[new it(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new it(t.key,c,`integer expected, found ${l}`)]}}function $n(t){const e=(\"property\"===t.expressionContext?En:An)(Gn(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((e=>new it(`${t.key}${e.key}`,t.value,e.message)));const r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new it(t.key,t.value,`Invalid data expression for \"${t.propertyKey}\". Output values must be contained as literals within the expression.`)];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!sn(r))return[new it(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!sn(r))return[new it(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ln(r,[\"zoom\",\"feature-state\"]))return[new it(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!on(r))return[new it(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Jn(t){const e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Hn(r))&&i.push(new it(e,r,`expected one of [${n.values.join(\", \")}], ${JSON.stringify(r)} found`)):-1===Object.keys(n.values).indexOf(Hn(r))&&i.push(new it(e,r,`expected one of [${Object.keys(n.values).join(\", \")}], ${JSON.stringify(r)} found`)),i}function Kn(t){return In(Gn(t.value))?$n(at({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):Qn(t)}function Qn(t){const e=t.value,r=t.key;if(\"array\"!==dn(e))return[new it(r,e,`array expected, ${dn(e)} found`)];const n=t.styleSpec;let i,a=[];if(e.length<1)return[new it(r,e,\"filter array must have at least 1 element\")];switch(a=a.concat(Jn({key:`${r}[0]`,value:e[0],valueSpec:n.filter_operator,style:t.style,styleSpec:t.styleSpec})),Hn(e[0])){case\"<\":case\"<=\":case\">\":case\">=\":e.length>=2&&\"$type\"===Hn(e[1])&&a.push(new it(r,e,`\"$type\" cannot be use with operator \"${e[0]}\"`));case\"==\":case\"!=\":3!==e.length&&a.push(new it(r,e,`filter array for operator \"${e[0]}\" must have 3 elements`));case\"in\":case\"!in\":e.length>=2&&(i=dn(e[1]),\"string\"!==i&&a.push(new it(`${r}[1]`,e[1],`string expected, ${i} found`)));for(let o=2;o<e.length;o++)i=dn(e[o]),\"$type\"===Hn(e[1])?a=a.concat(Jn({key:`${r}[${o}]`,value:e[o],valueSpec:n.geometry_type,style:t.style,styleSpec:t.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&a.push(new it(`${r}[${o}]`,e[o],`string, number, or boolean expected, ${i} found`));break;case\"any\":case\"all\":case\"none\":for(let n=1;n<e.length;n++)a=a.concat(Qn({key:`${r}[${n}]`,value:e[n],style:t.style,styleSpec:t.styleSpec}));break;case\"has\":case\"!has\":i=dn(e[1]),2!==e.length?a.push(new it(r,e,`filter array for \"${e[0]}\" operator must have 2 elements`)):\"string\"!==i&&a.push(new it(`${r}[1]`,e[1],`string expected, ${i} found`))}return a}function ti(t,e){const r=t.key,n=t.validateSpec,i=t.style,a=t.styleSpec,o=t.value,s=t.objectKey,l=a[`${e}_${t.layerType}`];if(!l)return[];const c=s.match(/^(.*)-transition$/);if(\"paint\"===e&&c&&l[c[1]]&&l[c[1]].transition)return n({key:r,value:o,valueSpec:a.transition,style:i,styleSpec:a});const u=t.valueSpec||l[s];if(!u)return[new it(r,o,`unknown property \"${s}\"`)];let h;if(\"string\"===dn(o)&&hn(u)&&!u.tokens&&(h=/^{([^}]+)}$/.exec(o)))return[new it(r,o,`\"${s}\" does not support interpolation syntax\\nUse an identity property function instead: \\`{ \"type\": \"identity\", \"property\": ${JSON.stringify(h[1])} }\\`.`)];const f=[];return\"symbol\"===t.layerType&&(\"text-field\"===s&&i&&!i.glyphs&&f.push(new it(r,o,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===s&&mn(Gn(o))&&\"identity\"===Hn(o.type)&&f.push(new it(r,o,'\"text-font\" does not support identity functions'))),f.concat(n({key:t.key,value:o,valueSpec:u,style:i,styleSpec:a,expressionContext:\"property\",propertyType:e,propertyKey:s}))}function ei(t){return ti(t,\"paint\")}function ri(t){return ti(t,\"layout\")}function ni(t){let e=[];const r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new it(n,r,'either \"type\" or \"ref\" is required'));let o=Hn(r.type);const s=Hn(r.ref);if(r.id){const a=Hn(r.id);for(let o=0;o<t.arrayIndex;o++){const t=i.layers[o];Hn(t.id)===a&&e.push(new it(n,r.id,`duplicate layer id \"${r.id}\", previously used at line ${t.id.__line__}`))}}if(\"ref\"in r){let t;[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((t=>{t in r&&e.push(new it(n,r[t],`\"${t}\" is prohibited for ref layers`))})),i.layers.forEach((e=>{Hn(e.id)===s&&(t=e)})),t?t.ref?e.push(new it(n,r.ref,\"ref cannot reference another ref layer\")):o=Hn(t.type):e.push(new it(n,r.ref,`ref layer \"${s}\" not found`))}else if(\"background\"!==o)if(r.source){const t=i.sources&&i.sources[r.source],a=t&&Hn(t.type);t?\"vector\"===a&&\"raster\"===o?e.push(new it(n,r.source,`layer \"${r.id}\" requires a raster source`)):\"raster-dem\"!==a&&\"hillshade\"===o?e.push(new it(n,r.source,`layer \"${r.id}\" requires a raster-dem source`)):\"raster\"===a&&\"raster\"!==o?e.push(new it(n,r.source,`layer \"${r.id}\" requires a vector source`)):\"vector\"!==a||r[\"source-layer\"]?\"raster-dem\"===a&&\"hillshade\"!==o?e.push(new it(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==o||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===a&&t.lineMetrics||e.push(new it(n,r,`layer \"${r.id}\" specifies a line-gradient, which requires a GeoJSON source with \\`lineMetrics\\` enabled.`)):e.push(new it(n,r,`layer \"${r.id}\" must specify a \"source-layer\"`)):e.push(new it(n,r.source,`source \"${r.source}\" not found`))}else e.push(new it(n,r,'missing required property \"source\"'));return e=e.concat(Zn({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,validateSpec:t.validateSpec,objectElementValidators:{\"*\"(){return[]},type(){return t.validateSpec({key:`${n}.type`,value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,validateSpec:t.validateSpec,object:r,objectKey:\"type\"})},filter:Kn,layout(t){return Zn({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,validateSpec:t.validateSpec,objectElementValidators:{\"*\"(t){return ri(at({layerType:o},t))}}})},paint(t){return Zn({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,validateSpec:t.validateSpec,objectElementValidators:{\"*\"(t){return ei(at({layerType:o},t))}}})}}})),e}function ii(t){const e=t.value,r=t.key,n=dn(e);return\"string\"!==n?[new it(r,e,`string expected, ${n} found`)]:[]}const ai={promoteId:function({key:t,value:e}){if(\"string\"===dn(e))return ii({key:t,value:e});{const r=[];for(const n in e)r.push(...ii({key:`${t}.${n}`,value:e[n]}));return r}}};function oi(t){const e=t.value,r=t.key,n=t.styleSpec,i=t.style,a=t.validateSpec;if(!e.type)return[new it(r,e,'\"type\" is required')];const o=Hn(e.type);let s;switch(o){case\"vector\":case\"raster\":return s=Zn({key:r,value:e,valueSpec:n[`source_${o.replace(\"-\",\"_\")}`],style:t.style,styleSpec:n,objectElementValidators:ai,validateSpec:a}),s;case\"raster-dem\":return s=function(t){var e;const r=null!==(e=t.sourceName)&&void 0!==e?e:\"\",n=t.value,i=t.styleSpec,a=i.source_raster_dem,o=t.style;let s=[];const l=dn(n);if(void 0===n)return s;if(\"object\"!==l)return s.push(new it(\"source_raster_dem\",n,`object expected, ${l} found`)),s;const c=\"custom\"===Hn(n.encoding),u=[\"redFactor\",\"greenFactor\",\"blueFactor\",\"baseShift\"],h=t.value.encoding?`\"${t.value.encoding}\"`:\"Default\";for(const e in n)!c&&u.includes(e)?s.push(new it(e,n[e],`In \"${r}\": \"${e}\" is only valid when \"encoding\" is set to \"custom\". ${h} encoding found`)):a[e]?s=s.concat(t.validateSpec({key:e,value:n[e],valueSpec:a[e],validateSpec:t.validateSpec,style:o,styleSpec:i})):s.push(new it(e,n[e],`unknown property \"${e}\"`));return s}({sourceName:r,value:e,style:t.style,styleSpec:n,validateSpec:a}),s;case\"geojson\":if(s=Zn({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n,validateSpec:a,objectElementValidators:ai}),e.cluster)for(const t in e.clusterProperties){const[n,i]=e.clusterProperties[t],o=\"string\"==typeof n?[n,[\"accumulated\"],[\"get\",t]]:n;s.push(...$n({key:`${r}.${t}.map`,value:i,validateSpec:a,expressionContext:\"cluster-map\"})),s.push(...$n({key:`${r}.${t}.reduce`,value:o,validateSpec:a,expressionContext:\"cluster-reduce\"}))}return s;case\"video\":return Zn({key:r,value:e,valueSpec:n.source_video,style:i,validateSpec:a,styleSpec:n});case\"image\":return Zn({key:r,value:e,valueSpec:n.source_image,style:i,validateSpec:a,styleSpec:n});case\"canvas\":return[new it(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Jn({key:`${r}.type`,value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,validateSpec:a,styleSpec:n})}}function si(t){const e=t.value,r=t.styleSpec,n=r.light,i=t.style;let a=[];const o=dn(e);if(void 0===e)return a;if(\"object\"!==o)return a=a.concat([new it(\"light\",e,`object expected, ${o} found`)]),a;for(const o in e){const s=o.match(/^(.*)-transition$/);a=s&&n[s[1]]&&n[s[1]].transition?a.concat(t.validateSpec({key:o,value:e[o],valueSpec:r.transition,validateSpec:t.validateSpec,style:i,styleSpec:r})):n[o]?a.concat(t.validateSpec({key:o,value:e[o],valueSpec:n[o],validateSpec:t.validateSpec,style:i,styleSpec:r})):a.concat([new it(o,e[o],`unknown property \"${o}\"`)])}return a}function li(t){const e=t.value,r=t.styleSpec,n=r.sky,i=t.style,a=dn(e);if(void 0===e)return[];if(\"object\"!==a)return[new it(\"sky\",e,`object expected, ${a} found`)];let o=[];for(const a in e)o=n[a]?o.concat(t.validateSpec({key:a,value:e[a],valueSpec:n[a],style:i,styleSpec:r})):o.concat([new it(a,e[a],`unknown property \"${a}\"`)]);return o}function ci(t){const e=t.value,r=t.styleSpec,n=r.terrain,i=t.style;let a=[];const o=dn(e);if(void 0===e)return a;if(\"object\"!==o)return a=a.concat([new it(\"terrain\",e,`object expected, ${o} found`)]),a;for(const o in e)a=n[o]?a.concat(t.validateSpec({key:o,value:e[o],valueSpec:n[o],validateSpec:t.validateSpec,style:i,styleSpec:r})):a.concat([new it(o,e[o],`unknown property \"${o}\"`)]);return a}function ui(t){let e=[];const r=t.value,n=t.key;if(Array.isArray(r)){const i=[],a=[];for(const o in r){r[o].id&&i.includes(r[o].id)&&e.push(new it(n,r,`all the sprites' ids must be unique, but ${r[o].id} is duplicated`)),i.push(r[o].id),r[o].url&&a.includes(r[o].url)&&e.push(new it(n,r,`all the sprites' URLs must be unique, but ${r[o].url} is duplicated`)),a.push(r[o].url);const s={id:{type:\"string\",required:!0},url:{type:\"string\",required:!0}};e=e.concat(Zn({key:`${n}[${o}]`,value:r[o],valueSpec:s,validateSpec:t.validateSpec}))}return e}return ii({key:n,value:r})}const hi={\"*\"(){return[]},array:Wn,boolean:function(t){const e=t.value,r=t.key,n=dn(e);return\"boolean\"!==n?[new it(r,e,`boolean expected, ${n} found`)]:[]},number:Yn,color:function(t){const e=t.key,r=t.value,n=dn(r);return\"string\"!==n?[new it(e,r,`color expected, ${n} found`)]:Xt.parse(String(r))?[]:[new it(e,r,`color expected, \"${r}\" found`)]},constants:qn,enum:Jn,filter:Kn,function:Xn,layer:ni,object:Zn,source:oi,light:si,sky:li,terrain:ci,projection:function(t){const e=t.value,r=t.styleSpec,n=r.projection,i=t.style,a=dn(e);if(void 0===e)return[];if(\"object\"!==a)return[new it(\"projection\",e,`object expected, ${a} found`)];let o=[];for(const a in e)o=n[a]?o.concat(t.validateSpec({key:a,value:e[a],valueSpec:n[a],style:i,styleSpec:r})):o.concat([new it(a,e[a],`unknown property \"${a}\"`)]);return o},string:ii,formatted:function(t){return 0===ii(t).length?[]:$n(t)},resolvedImage:function(t){return 0===ii(t).length?[]:$n(t)},padding:function(t){const e=t.key,r=t.value;if(\"array\"===dn(r)){if(r.length<1||r.length>4)return[new it(e,r,`padding requires 1 to 4 values; ${r.length} values found`)];const n={type:\"number\"};let i=[];for(let a=0;a<r.length;a++)i=i.concat(t.validateSpec({key:`${e}[${a}]`,value:r[a],validateSpec:t.validateSpec,valueSpec:n}));return i}return Yn({key:e,value:r,valueSpec:{}})},variableAnchorOffsetCollection:function(t){const e=t.key,r=t.value,n=dn(r),i=t.styleSpec;if(\"array\"!==n||r.length<1||r.length%2!=0)return[new it(e,r,\"variableAnchorOffsetCollection requires a non-empty array of even length\")];let a=[];for(let n=0;n<r.length;n+=2)a=a.concat(Jn({key:`${e}[${n}]`,value:r[n],valueSpec:i.layout_symbol[\"text-anchor\"]})),a=a.concat(Wn({key:`${e}[${n+1}]`,value:r[n+1],valueSpec:{length:2,value:\"number\"},validateSpec:t.validateSpec,style:t.style,styleSpec:i}));return a},sprite:ui};function fi(t){const e=t.value,r=t.valueSpec,n=t.styleSpec;return t.validateSpec=fi,r.expression&&mn(Hn(e))?Xn(t):r.expression&&kn(Gn(e))?$n(t):r.type&&hi[r.type]?hi[r.type](t):Zn(at({},t,{valueSpec:r.type?n[r.type]:r}))}function pi(t){const e=t.value,r=t.key,n=ii(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new it(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new it(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function di(t,e=Z){let r=[];return r=r.concat(fi({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,validateSpec:fi,objectElementValidators:{glyphs:pi,\"*\"(){return[]}}})),t.constants&&(r=r.concat(qn({key:\"constants\",value:t.constants,style:t,styleSpec:e,validateSpec:fi}))),gi(r)}function mi(t){return function(e){return t({...e,validateSpec:fi})}}function gi(t){return[].concat(t).sort(((t,e)=>t.line-e.line))}function yi(t){return function(...e){return gi(t.apply(this,e))}}di.source=yi(mi(oi)),di.sprite=yi(mi(ui)),di.glyphs=yi(mi(pi)),di.light=yi(mi(si)),di.sky=yi(mi(li)),di.terrain=yi(mi(ci)),di.layer=yi(mi(ni)),di.filter=yi(mi(Kn)),di.paintProperty=yi(mi(ei)),di.layoutProperty=yi(mi(ri));const vi=di;vi.source;const xi=vi.light,_i=vi.sky;vi.terrain,vi.filter;const bi=vi.paintProperty,wi=vi.layoutProperty;function Ti(t,e){let r=!1;if(e&&e.length)for(const n of e)t.fire(new H(new Error(n.message))),r=!0;return r}class ki{constructor(t,e,r){const n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;const i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(let t=0;t<this.d*this.d;t++){const e=i[3+t],r=i[3+t+1];n.push(e===r?null:i.subarray(e,r))}const a=i[3+n.length],o=i[3+n.length+1];this.keys=i.subarray(a,o),this.bboxes=i.subarray(o),this.insert=this._insertReadonly}else{this.d=e+2*r;for(let t=0;t<this.d*this.d;t++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;const i=r/e*t;this.min=-i,this.max=t+i}insert(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++,void 0,void 0),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)}_insertReadonly(){throw new Error(\"Cannot insert into a GridIndex created from an ArrayBuffer.\")}_insertCell(t,e,r,n,i,a){this.cells[i].push(a)}query(t,e,r,n,i){const a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);{const a=[],o={};return this._forEachCell(t,e,r,n,this._queryCell,a,o,i),a}}_queryCell(t,e,r,n,i,a,o,s){const l=this.cells[i];if(null!==l){const i=this.keys,c=this.bboxes;for(let u=0;u<l.length;u++){const h=l[u];if(void 0===o[h]){const l=4*h;(s?s(c[l+0],c[l+1],c[l+2],c[l+3]):t<=c[l+2]&&e<=c[l+3]&&r>=c[l+0]&&n>=c[l+1])?(o[h]=!0,a.push(i[h])):o[h]=!1}}}}_forEachCell(t,e,r,n,i,a,o,s){const l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n);for(let f=l;f<=u;f++)for(let l=c;l<=h;l++){const c=this.d*l+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(l),this._convertFromCellCoord(f+1),this._convertFromCellCoord(l+1)))&&i.call(this,t,e,r,n,c,a,o,s))return}}_convertFromCellCoord(t){return(t-this.padding)/this.scale}_convertToCellCoord(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))}toArrayBuffer(){if(this.arrayBuffer)return this.arrayBuffer;const t=this.cells,e=3+this.cells.length+1+1;let r=0;for(let t=0;t<this.cells.length;t++)r+=this.cells[t].length;const n=new Int32Array(e+r+this.keys.length+this.bboxes.length);n[0]=this.extent,n[1]=this.n,n[2]=this.padding;let i=e;for(let e=0;e<t.length;e++){const r=t[e];n[3+e]=i,n.set(r,i),i+=r.length}return n[3+t.length]=i,n.set(this.keys,i),i+=this.keys.length,n[3+t.length+1]=i,n.set(this.bboxes,i),i+=this.bboxes.length,n.buffer}static serialize(t,e){const r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}}static deserialize(t){return new ki(t.buffer)}}const Ai={};function Mi(t,e,r={}){if(Ai[t])throw new Error(`${t} is already registered.`);Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),Ai[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}Mi(\"Object\",Object),Mi(\"TransferableGridIndex\",ki),Mi(\"Color\",Xt),Mi(\"Error\",Error),Mi(\"AJAXError\",F),Mi(\"ResolvedImage\",re),Mi(\"StylePropertyFunction\",Cn),Mi(\"StyleExpression\",Tn,{omit:[\"_evaluator\"]}),Mi(\"ZoomDependentExpression\",Sn),Mi(\"ZoomConstantExpression\",Mn),Mi(\"CompoundExpression\",Qr,{omit:[\"_evaluate\"]});for(const t in Kr)Kr[t]._classRegistryKey||Mi(`Expression_${t}`,Kr[t]);function Si(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function Ei(t){const e=t.constructor;return t.$name||e._classRegistryKey}function Ci(t){return!function(t){if(null===t||\"object\"!=typeof t)return!1;const e=Ei(t);return!(!e||\"Object\"===e)}(t)&&(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof Blob||t instanceof Error||Si(t)||S(t)||ArrayBuffer.isView(t)||t instanceof ImageData)}function Li(t,e){if(Ci(t)){if((Si(t)||S(t))&&e&&e.push(t),ArrayBuffer.isView(t)){const r=t;e&&e.push(r.buffer)}return t instanceof ImageData&&e&&e.push(t.data.buffer),t}if(Array.isArray(t)){const r=[];for(const n of t)r.push(Li(n,e));return r}if(\"object\"!=typeof t)throw new Error(\"can't serialize object of type \"+typeof t);const r=Ei(t);if(!r)throw new Error(`can't serialize object of unregistered class ${t.constructor.name}`);if(!Ai[r])throw new Error(`${r} is not registered.`);const{klass:n}=Ai[r],i=n.serialize?n.serialize(t,e):{};if(n.serialize){if(e&&i===e[e.length-1])throw new Error(\"statically serialized object won't survive transfer of $name property\")}else{for(const n in t){if(!t.hasOwnProperty(n))continue;if(Ai[r].omit.indexOf(n)>=0)continue;const a=t[n];i[n]=Ai[r].shallow.indexOf(n)>=0?a:Li(a,e)}t instanceof Error&&(i.message=t.message)}if(i.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==r&&(i.$name=r),i}function Ii(t){if(Ci(t))return t;if(Array.isArray(t))return t.map(Ii);if(\"object\"!=typeof t)throw new Error(\"can't deserialize object of type \"+typeof t);const e=Ei(t)||\"Object\";if(!Ai[e])throw new Error(`can't deserialize unregistered class ${e}`);const{klass:r}=Ai[e];if(!r)throw new Error(`can't deserialize unregistered class ${e}`);if(r.deserialize)return r.deserialize(t);const n=Object.create(r.prototype);for(const r of Object.keys(t)){if(\"$name\"===r)continue;const i=t[r];n[r]=Ai[e].shallow.indexOf(r)>=0?i:Ii(i)}return n}class Pi{constructor(){this.first=!0}update(t,e){const r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))}}const zi={\"Latin-1 Supplement\":t=>t>=128&&t<=255,Arabic:t=>t>=1536&&t<=1791,\"Arabic Supplement\":t=>t>=1872&&t<=1919,\"Arabic Extended-A\":t=>t>=2208&&t<=2303,\"Hangul Jamo\":t=>t>=4352&&t<=4607,\"Unified Canadian Aboriginal Syllabics\":t=>t>=5120&&t<=5759,Khmer:t=>t>=6016&&t<=6143,\"Unified Canadian Aboriginal Syllabics Extended\":t=>t>=6320&&t<=6399,\"General Punctuation\":t=>t>=8192&&t<=8303,\"Letterlike Symbols\":t=>t>=8448&&t<=8527,\"Number Forms\":t=>t>=8528&&t<=8591,\"Miscellaneous Technical\":t=>t>=8960&&t<=9215,\"Control Pictures\":t=>t>=9216&&t<=9279,\"Optical Character Recognition\":t=>t>=9280&&t<=9311,\"Enclosed Alphanumerics\":t=>t>=9312&&t<=9471,\"Geometric Shapes\":t=>t>=9632&&t<=9727,\"Miscellaneous Symbols\":t=>t>=9728&&t<=9983,\"Miscellaneous Symbols and Arrows\":t=>t>=11008&&t<=11263,\"CJK Radicals Supplement\":t=>t>=11904&&t<=12031,\"Kangxi Radicals\":t=>t>=12032&&t<=12255,\"Ideographic Description Characters\":t=>t>=12272&&t<=12287,\"CJK Symbols and Punctuation\":t=>t>=12288&&t<=12351,Hiragana:t=>t>=12352&&t<=12447,Katakana:t=>t>=12448&&t<=12543,Bopomofo:t=>t>=12544&&t<=12591,\"Hangul Compatibility Jamo\":t=>t>=12592&&t<=12687,Kanbun:t=>t>=12688&&t<=12703,\"Bopomofo Extended\":t=>t>=12704&&t<=12735,\"CJK Strokes\":t=>t>=12736&&t<=12783,\"Katakana Phonetic Extensions\":t=>t>=12784&&t<=12799,\"Enclosed CJK Letters and Months\":t=>t>=12800&&t<=13055,\"CJK Compatibility\":t=>t>=13056&&t<=13311,\"CJK Unified Ideographs Extension A\":t=>t>=13312&&t<=19903,\"Yijing Hexagram Symbols\":t=>t>=19904&&t<=19967,\"CJK Unified Ideographs\":t=>t>=19968&&t<=40959,\"Yi Syllables\":t=>t>=40960&&t<=42127,\"Yi Radicals\":t=>t>=42128&&t<=42191,\"Hangul Jamo Extended-A\":t=>t>=43360&&t<=43391,\"Hangul Syllables\":t=>t>=44032&&t<=55215,\"Hangul Jamo Extended-B\":t=>t>=55216&&t<=55295,\"Private Use Area\":t=>t>=57344&&t<=63743,\"CJK Compatibility Ideographs\":t=>t>=63744&&t<=64255,\"Arabic Presentation Forms-A\":t=>t>=64336&&t<=65023,\"Vertical Forms\":t=>t>=65040&&t<=65055,\"CJK Compatibility Forms\":t=>t>=65072&&t<=65103,\"Small Form Variants\":t=>t>=65104&&t<=65135,\"Arabic Presentation Forms-B\":t=>t>=65136&&t<=65279,\"Halfwidth and Fullwidth Forms\":t=>t>=65280&&t<=65519};function Oi(t){for(const e of t)if(Fi(e.charCodeAt(0)))return!0;return!1}function Di(t){for(const e of t)if(!Ri(e.charCodeAt(0)))return!1;return!0}function Ri(t){return!(zi.Arabic(t)||zi[\"Arabic Supplement\"](t)||zi[\"Arabic Extended-A\"](t)||zi[\"Arabic Presentation Forms-A\"](t)||zi[\"Arabic Presentation Forms-B\"](t))}function Fi(t){return!(746!==t&&747!==t&&(t<4352||!(zi[\"Bopomofo Extended\"](t)||zi.Bopomofo(t)||zi[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||zi[\"CJK Compatibility Ideographs\"](t)||zi[\"CJK Compatibility\"](t)||zi[\"CJK Radicals Supplement\"](t)||zi[\"CJK Strokes\"](t)||!(!zi[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||zi[\"CJK Unified Ideographs Extension A\"](t)||zi[\"CJK Unified Ideographs\"](t)||zi[\"Enclosed CJK Letters and Months\"](t)||zi[\"Hangul Compatibility Jamo\"](t)||zi[\"Hangul Jamo Extended-A\"](t)||zi[\"Hangul Jamo Extended-B\"](t)||zi[\"Hangul Jamo\"](t)||zi[\"Hangul Syllables\"](t)||zi.Hiragana(t)||zi[\"Ideographic Description Characters\"](t)||zi.Kanbun(t)||zi[\"Kangxi Radicals\"](t)||zi[\"Katakana Phonetic Extensions\"](t)||zi.Katakana(t)&&12540!==t||!(!zi[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!zi[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||zi[\"Unified Canadian Aboriginal Syllabics\"](t)||zi[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||zi[\"Vertical Forms\"](t)||zi[\"Yijing Hexagram Symbols\"](t)||zi[\"Yi Syllables\"](t)||zi[\"Yi Radicals\"](t))))}function Bi(t){return!(Fi(t)||function(t){return!!(zi[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||zi[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||zi[\"Letterlike Symbols\"](t)||zi[\"Number Forms\"](t)||zi[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||zi[\"Control Pictures\"](t)&&9251!==t||zi[\"Optical Character Recognition\"](t)||zi[\"Enclosed Alphanumerics\"](t)||zi[\"Geometric Shapes\"](t)||zi[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||zi[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||zi[\"CJK Symbols and Punctuation\"](t)||zi.Katakana(t)||zi[\"Private Use Area\"](t)||zi[\"CJK Compatibility Forms\"](t)||zi[\"Small Form Variants\"](t)||zi[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function Ni(t){return zi.Arabic(t)||zi[\"Arabic Supplement\"](t)||zi[\"Arabic Extended-A\"](t)||zi[\"Arabic Presentation Forms-A\"](t)||zi[\"Arabic Presentation Forms-B\"](t)}function ji(t){return t>=1424&&t<=2303||zi[\"Arabic Presentation Forms-A\"](t)||zi[\"Arabic Presentation Forms-B\"](t)}function Ui(t,e){return!(!e&&ji(t)||t>=2304&&t<=3583||t>=3840&&t<=4255||zi.Khmer(t))}function Vi(t){for(const e of t)if(ji(e.charCodeAt(0)))return!0;return!1}const qi=new class{constructor(){this.applyArabicShaping=null,this.processBidirectionalText=null,this.processStyledBidirectionalText=null,this.pluginStatus=\"unavailable\",this.pluginURL=null}setState(t){this.pluginStatus=t.pluginStatus,this.pluginURL=t.pluginURL}getState(){return{pluginStatus:this.pluginStatus,pluginURL:this.pluginURL}}setMethods(t){this.applyArabicShaping=t.applyArabicShaping,this.processBidirectionalText=t.processBidirectionalText,this.processStyledBidirectionalText=t.processStyledBidirectionalText}isParsed(){return null!=this.applyArabicShaping&&null!=this.processBidirectionalText&&null!=this.processStyledBidirectionalText}getPluginURL(){return this.pluginURL}getRTLTextPluginStatus(){return this.pluginStatus}};class Hi{constructor(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Pi,this.transition={})}isSupportedScript(t){return function(t,e){for(const r of t)if(!Ui(r.charCodeAt(0),e))return!1;return!0}(t,\"loaded\"===qi.getRTLTextPluginStatus())}crossFadingFactor(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)}getCrossfadeParameters(){const t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}}}class Gi{constructor(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(mn(t))return new Cn(t,e);if(kn(t)){const r=En(t,e);if(\"error\"===r.result)throw new Error(r.value.map((t=>`${t.key}: ${t.message}`)).join(\", \"));return r.value}{let r=t;return\"color\"===e.type&&\"string\"==typeof t?r=Xt.parse(t):\"padding\"!==e.type||\"number\"!=typeof t&&!Array.isArray(t)?\"variableAnchorOffsetCollection\"===e.type&&Array.isArray(t)&&(r=ee.parse(t)):r=Qt.parse(t),{kind:\"constant\",evaluate:()=>r}}}(void 0===e?t.specification.default:e,t.specification)}isDataDriven(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind}possiblyEvaluate(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)}}class Zi{constructor(t){this.property=t,this.value=new Gi(t,void 0)}transitioned(t,e){return new Yi(this.property,this.value,e,y({},t.transition,this.transition),t.now)}untransitioned(){return new Yi(this.property,this.value,null,{},0)}}class Wi{constructor(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)}getValue(t){return b(this._values[t].value.value)}setValue(t,e){Object.prototype.hasOwnProperty.call(this._values,t)||(this._values[t]=new Zi(this._values[t].property)),this._values[t].value=new Gi(this._values[t].property,null===e?void 0:b(e))}getTransition(t){return b(this._values[t].transition)}setTransition(t,e){Object.prototype.hasOwnProperty.call(this._values,t)||(this._values[t]=new Zi(this._values[t].property)),this._values[t].transition=b(e)||void 0}serialize(){const t={};for(const e of Object.keys(this._values)){const r=this.getValue(e);void 0!==r&&(t[e]=r);const n=this.getTransition(e);void 0!==n&&(t[`${e}-transition`]=n)}return t}transitioned(t,e){const r=new Xi(this._properties);for(const n of Object.keys(this._values))r._values[n]=this._values[n].transitioned(t,e._values[n]);return r}untransitioned(){const t=new Xi(this._properties);for(const e of Object.keys(this._values))t._values[e]=this._values[e].untransitioned();return t}}class Yi{constructor(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)}possiblyEvaluate(t,e,r){const n=t.now||0,i=this.value.possiblyEvaluate(t,e,r),a=this.prior;if(a){if(n>this.end)return this.prior=null,i;if(this.value.isDataDriven())return this.prior=null,i;if(n<this.begin)return a.possiblyEvaluate(t,e,r);{const o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(a.possiblyEvaluate(t,e,r),i,function(t){if(t<=0)return 0;if(t>=1)return 1;const e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}}return i}}class Xi{constructor(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)}possiblyEvaluate(t,e,r){const n=new Ki(this._properties);for(const i of Object.keys(this._values))n._values[i]=this._values[i].possiblyEvaluate(t,e,r);return n}hasTransition(){for(const t of Object.keys(this._values))if(this._values[t].prior)return!0;return!1}}class $i{constructor(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)}hasValue(t){return void 0!==this._values[t].value}getValue(t){return b(this._values[t].value)}setValue(t,e){this._values[t]=new Gi(this._values[t].property,null===e?void 0:b(e))}serialize(){const t={};for(const e of Object.keys(this._values)){const r=this.getValue(e);void 0!==r&&(t[e]=r)}return t}possiblyEvaluate(t,e,r){const n=new Ki(this._properties);for(const i of Object.keys(this._values))n._values[i]=this._values[i].possiblyEvaluate(t,e,r);return n}}class Ji{constructor(t,e,r){this.property=t,this.value=e,this.parameters=r}isConstant(){return\"constant\"===this.value.kind}constantOr(t){return\"constant\"===this.value.kind?this.value.value:t}evaluate(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)}}class Ki{constructor(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)}get(t){return this._values[t]}}class Qi{constructor(t){this.specification=t}possiblyEvaluate(t,e){if(t.isDataDriven())throw new Error(\"Value should not be data driven\");return t.expression.evaluate(e)}interpolate(t,e,r){const n=this.specification.type,i=Pe[n];return i?i(t,e,r):t}}class ta{constructor(t,e){this.specification=t,this.overrides=e}possiblyEvaluate(t,e,r,n){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Ji(this,{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)},e):new Ji(this,t.expression,e)}interpolate(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Ji(this,{kind:\"constant\",value:void 0},t.parameters);const n=this.specification.type,i=Pe[n];if(i){const n=i(t.value.value,e.value.value,r);return new Ji(this,{kind:\"constant\",value:n},t.parameters)}return t}evaluate(t,e,r,n,i,a){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,i,a)}}class ea extends ta{possiblyEvaluate(t,e,r,n){if(void 0===t.value)return new Ji(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){const i=t.expression.evaluate(e,null,{},r,n),a=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof i?i.name:i,o=this._calculate(a,a,a,e);return new Ji(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){const r=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Ji(this,{kind:\"constant\",value:r},e)}return new Ji(this,t.expression,e)}evaluate(t,e,r,n,i,a){if(\"source\"===t.kind){const o=t.evaluate(e,r,n,i,a);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value}_calculate(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}}interpolate(t){return t}}class ra{constructor(t){this.specification=t}possiblyEvaluate(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){const i=t.expression.evaluate(e,null,{},r,n);return this._calculate(i,i,i,e)}return this._calculate(t.expression.evaluate(new Hi(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Hi(Math.floor(e.zoom),e)),t.expression.evaluate(new Hi(Math.floor(e.zoom+1),e)),e)}}_calculate(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}}interpolate(t){return t}}class na{constructor(t){this.specification=t}possiblyEvaluate(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)}interpolate(){return!1}}class ia{constructor(t){this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[];for(const e in t){const r=t[e];r.specification.overridable&&this.overridableProperties.push(e);const n=this.defaultPropertyValues[e]=new Gi(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new Zi(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}}}Mi(\"DataDrivenProperty\",ta),Mi(\"DataConstantProperty\",Qi),Mi(\"CrossFadedDataDrivenProperty\",ea),Mi(\"CrossFadedProperty\",ra),Mi(\"ColorRampProperty\",na);const aa=\"-transition\";class oa extends G{constructor(t,e){if(super(),this.id=t.id,this.type=t.type,this._featureFilter={filter:()=>!0,needGeometry:!1},\"custom\"!==t.type&&(this.metadata=t.metadata,this.minzoom=t.minzoom,this.maxzoom=t.maxzoom,\"background\"!==t.type&&(this.source=t.source,this.sourceLayer=t[\"source-layer\"],this.filter=t.filter),e.layout&&(this._unevaluatedLayout=new $i(e.layout)),e.paint)){this._transitionablePaint=new Wi(e.paint);for(const e in t.paint)this.setPaintProperty(e,t.paint[e],{validate:!1});for(const e in t.layout)this.setLayoutProperty(e,t.layout[e],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new Ki(e.paint)}}getCrossfadeParameters(){return this._crossfadeParameters}getLayoutProperty(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)}setLayoutProperty(t,e,r={}){if(null!=e){const n=`layers.${this.id}.layout.${t}`;if(this._validate(wi,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e}getPaintProperty(t){return t.endsWith(aa)?this._transitionablePaint.getTransition(t.slice(0,-11)):this._transitionablePaint.getValue(t)}setPaintProperty(t,e,r={}){if(null!=e){const n=`layers.${this.id}.paint.${t}`;if(this._validate(bi,n,t,e,r))return!1}if(t.endsWith(aa))return this._transitionablePaint.setTransition(t.slice(0,-11),e||void 0),!1;{const r=this._transitionablePaint._values[t],n=\"cross-faded-data-driven\"===r.property.specification[\"property-type\"],i=r.value.isDataDriven(),a=r.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);const o=this._transitionablePaint._values[t].value;return o.isDataDriven()||i||n||this._handleOverridablePaintPropertyUpdate(t,a,o)}}_handleSpecialPaintPropertyUpdate(t){}_handleOverridablePaintPropertyUpdate(t,e,r){return!1}isHidden(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility}updateTransitions(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)}hasTransition(){return this._transitioningPaint.hasTransition()}recalculate(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)}serialize(){const t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),_(t,((t,e)=>!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)))}_validate(t,e,r,n,i={}){return(!i||!1!==i.validate)&&Ti(this,t.call(vi,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:Z,style:{glyphs:!0,sprite:!0}}))}is3D(){return!1}isTileClipped(){return!1}hasOffscreenPass(){return!1}resize(){}isStateDependent(){for(const t in this.paint._values){const e=this.paint.get(t);if(e instanceof Ji&&hn(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1}}const sa={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array};class la{constructor(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8}}class ca{constructor(){this.isTransferred=!1,this.capacity=-1,this.resize(0)}static serialize(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}}static deserialize(t){const e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e}_trim(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())}clear(){this.length=0}resize(t){this.reserve(t),this.length=t}reserve(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);const e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}}_refreshViews(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")}}function ua(t,e=1){let r=0,n=0;return{members:t.map((t=>{const i=(s=t.type,sa[s].BYTES_PER_ELEMENT),a=r=ha(r,Math.max(e,i)),o=t.components||1;var s;return n=Math.max(n,i),r+=i*o,{name:t.name,type:t.type,components:o,offset:a}})),size:ha(r,Math.max(n,e)),alignment:e}}function ha(t,e){return Math.ceil(t/e)*e}class fa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e){const r=this.length;return this.resize(r+1),this.emplace(r,t,e)}emplace(t,e,r){const n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t}}fa.prototype.bytesPerElement=4,Mi(\"StructArrayLayout2i4\",fa);class pa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e,r){const n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)}emplace(t,e,r,n){const i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t}}pa.prototype.bytesPerElement=6,Mi(\"StructArrayLayout3i6\",pa);class da extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e,r,n){const i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)}emplace(t,e,r,n,i){const a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t}}da.prototype.bytesPerElement=8,Mi(\"StructArrayLayout4i8\",da);class ma extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a){const o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)}emplace(t,e,r,n,i,a,o){const s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t}}ma.prototype.bytesPerElement=12,Mi(\"StructArrayLayout2i4i12\",ma);class ga extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a){const o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)}emplace(t,e,r,n,i,a,o){const s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t}}ga.prototype.bytesPerElement=8,Mi(\"StructArrayLayout2i4ub8\",ga);class ya extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)}emplaceBack(t,e){const r=this.length;return this.resize(r+1),this.emplace(r,t,e)}emplace(t,e,r){const n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t}}ya.prototype.bytesPerElement=8,Mi(\"StructArrayLayout2f8\",ya);class va extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a,o,s,l,c){const u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,i,a,o,s,l,c)}emplace(t,e,r,n,i,a,o,s,l,c,u){const h=10*t;return this.uint16[h+0]=e,this.uint16[h+1]=r,this.uint16[h+2]=n,this.uint16[h+3]=i,this.uint16[h+4]=a,this.uint16[h+5]=o,this.uint16[h+6]=s,this.uint16[h+7]=l,this.uint16[h+8]=c,this.uint16[h+9]=u,t}}va.prototype.bytesPerElement=20,Mi(\"StructArrayLayout10ui20\",va);class xa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a,o,s,l,c,u,h){const f=this.length;return this.resize(f+1),this.emplace(f,t,e,r,n,i,a,o,s,l,c,u,h)}emplace(t,e,r,n,i,a,o,s,l,c,u,h,f){const p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=i,this.uint16[p+4]=a,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=h,this.int16[p+11]=f,t}}xa.prototype.bytesPerElement=24,Mi(\"StructArrayLayout4i4ui4i24\",xa);class _a extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)}emplaceBack(t,e,r){const n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)}emplace(t,e,r,n){const i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t}}_a.prototype.bytesPerElement=12,Mi(\"StructArrayLayout3f12\",_a);class ba extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)}emplaceBack(t){const e=this.length;return this.resize(e+1),this.emplace(e,t)}emplace(t,e){const r=1*t;return this.uint32[r+0]=e,t}}ba.prototype.bytesPerElement=4,Mi(\"StructArrayLayout1ul4\",ba);class wa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a,o,s,l){const c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,i,a,o,s,l)}emplace(t,e,r,n,i,a,o,s,l,c){const u=10*t,h=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=i,this.int16[u+4]=a,this.int16[u+5]=o,this.uint32[h+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t}}wa.prototype.bytesPerElement=20,Mi(\"StructArrayLayout6i1ul2ui20\",wa);class Ta extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a){const o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)}emplace(t,e,r,n,i,a,o){const s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t}}Ta.prototype.bytesPerElement=12,Mi(\"StructArrayLayout2i2i2i12\",Ta);class ka extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i){const a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n,i)}emplace(t,e,r,n,i,a){const o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=i,this.int16[s+7]=a,t}}ka.prototype.bytesPerElement=16,Mi(\"StructArrayLayout2f1f2i16\",ka);class Aa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a){const o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)}emplace(t,e,r,n,i,a,o){const s=16*t,l=4*t,c=8*t;return this.uint8[s+0]=e,this.uint8[s+1]=r,this.float32[l+1]=n,this.float32[l+2]=i,this.int16[c+6]=a,this.int16[c+7]=o,t}}Aa.prototype.bytesPerElement=16,Mi(\"StructArrayLayout2ub2f2i16\",Aa);class Ma extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)}emplaceBack(t,e,r){const n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)}emplace(t,e,r,n){const i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t}}Ma.prototype.bytesPerElement=6,Mi(\"StructArrayLayout3ui6\",Ma);class Sa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g){const y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g)}emplace(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y){const v=24*t,x=12*t,_=48*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[x+2]=a,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[x+7]=h,this.float32[x+8]=f,this.uint8[_+36]=p,this.uint8[_+37]=d,this.uint8[_+38]=m,this.uint32[x+10]=g,this.int16[v+22]=y,t}}Sa.prototype.bytesPerElement=48,Mi(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",Sa);class Ea extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)}emplaceBack(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S){const E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S)}emplace(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,T,k,A,M,S,E){const C=32*t,L=16*t;return this.int16[C+0]=e,this.int16[C+1]=r,this.int16[C+2]=n,this.int16[C+3]=i,this.int16[C+4]=a,this.int16[C+5]=o,this.int16[C+6]=s,this.int16[C+7]=l,this.uint16[C+8]=c,this.uint16[C+9]=u,this.uint16[C+10]=h,this.uint16[C+11]=f,this.uint16[C+12]=p,this.uint16[C+13]=d,this.uint16[C+14]=m,this.uint16[C+15]=g,this.uint16[C+16]=y,this.uint16[C+17]=v,this.uint16[C+18]=x,this.uint16[C+19]=_,this.uint16[C+20]=b,this.uint16[C+21]=w,this.uint16[C+22]=T,this.uint32[L+12]=k,this.float32[L+13]=A,this.float32[L+14]=M,this.uint16[C+30]=S,this.uint16[C+31]=E,t}}Ea.prototype.bytesPerElement=64,Mi(\"StructArrayLayout8i15ui1ul2f2ui64\",Ea);class Ca extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)}emplaceBack(t){const e=this.length;return this.resize(e+1),this.emplace(e,t)}emplace(t,e){const r=1*t;return this.float32[r+0]=e,t}}Ca.prototype.bytesPerElement=4,Mi(\"StructArrayLayout1f4\",Ca);class La extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)}emplaceBack(t,e,r){const n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)}emplace(t,e,r,n){const i=6*t,a=3*t;return this.uint16[i+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,t}}La.prototype.bytesPerElement=12,Mi(\"StructArrayLayout1ui2f12\",La);class Ia extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)}emplaceBack(t,e,r){const n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)}emplace(t,e,r,n){const i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t}}Ia.prototype.bytesPerElement=8,Mi(\"StructArrayLayout1ul2ui8\",Ia);class Pa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)}emplaceBack(t,e){const r=this.length;return this.resize(r+1),this.emplace(r,t,e)}emplace(t,e,r){const n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t}}Pa.prototype.bytesPerElement=4,Mi(\"StructArrayLayout2ui4\",Pa);class za extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)}emplaceBack(t){const e=this.length;return this.resize(e+1),this.emplace(e,t)}emplace(t,e){const r=1*t;return this.uint16[r+0]=e,t}}za.prototype.bytesPerElement=2,Mi(\"StructArrayLayout1ui2\",za);class Oa extends ca{_refreshViews(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)}emplaceBack(t,e,r,n){const i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)}emplace(t,e,r,n,i){const a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t}}Oa.prototype.bytesPerElement=16,Mi(\"StructArrayLayout4f16\",Oa);class Da extends la{get anchorPointX(){return this._structArray.int16[this._pos2+0]}get anchorPointY(){return this._structArray.int16[this._pos2+1]}get x1(){return this._structArray.int16[this._pos2+2]}get y1(){return this._structArray.int16[this._pos2+3]}get x2(){return this._structArray.int16[this._pos2+4]}get y2(){return this._structArray.int16[this._pos2+5]}get featureIndex(){return this._structArray.uint32[this._pos4+3]}get sourceLayerIndex(){return this._structArray.uint16[this._pos2+8]}get bucketIndex(){return this._structArray.uint16[this._pos2+9]}get anchorPoint(){return new a(this.anchorPointX,this.anchorPointY)}}Da.prototype.size=20;class Ra extends wa{get(t){return new Da(this,t)}}Mi(\"CollisionBoxArray\",Ra);class Fa extends la{get anchorX(){return this._structArray.int16[this._pos2+0]}get anchorY(){return this._structArray.int16[this._pos2+1]}get glyphStartIndex(){return this._structArray.uint16[this._pos2+2]}get numGlyphs(){return this._structArray.uint16[this._pos2+3]}get vertexStartIndex(){return this._structArray.uint32[this._pos4+2]}get lineStartIndex(){return this._structArray.uint32[this._pos4+3]}get lineLength(){return this._structArray.uint32[this._pos4+4]}get segment(){return this._structArray.uint16[this._pos2+10]}get lowerSize(){return this._structArray.uint16[this._pos2+11]}get upperSize(){return this._structArray.uint16[this._pos2+12]}get lineOffsetX(){return this._structArray.float32[this._pos4+7]}get lineOffsetY(){return this._structArray.float32[this._pos4+8]}get writingMode(){return this._structArray.uint8[this._pos1+36]}get placedOrientation(){return this._structArray.uint8[this._pos1+37]}set placedOrientation(t){this._structArray.uint8[this._pos1+37]=t}get hidden(){return this._structArray.uint8[this._pos1+38]}set hidden(t){this._structArray.uint8[this._pos1+38]=t}get crossTileID(){return this._structArray.uint32[this._pos4+10]}set crossTileID(t){this._structArray.uint32[this._pos4+10]=t}get associatedIconIndex(){return this._structArray.int16[this._pos2+22]}}Fa.prototype.size=48;class Ba extends Sa{get(t){return new Fa(this,t)}}Mi(\"PlacedSymbolArray\",Ba);class Na extends la{get anchorX(){return this._structArray.int16[this._pos2+0]}get anchorY(){return this._structArray.int16[this._pos2+1]}get rightJustifiedTextSymbolIndex(){return this._structArray.int16[this._pos2+2]}get centerJustifiedTextSymbolIndex(){return this._structArray.int16[this._pos2+3]}get leftJustifiedTextSymbolIndex(){return this._structArray.int16[this._pos2+4]}get verticalPlacedTextSymbolIndex(){return this._structArray.int16[this._pos2+5]}get placedIconSymbolIndex(){return this._structArray.int16[this._pos2+6]}get verticalPlacedIconSymbolIndex(){return this._structArray.int16[this._pos2+7]}get key(){return this._structArray.uint16[this._pos2+8]}get textBoxStartIndex(){return this._structArray.uint16[this._pos2+9]}get textBoxEndIndex(){return this._structArray.uint16[this._pos2+10]}get verticalTextBoxStartIndex(){return this._structArray.uint16[this._pos2+11]}get verticalTextBoxEndIndex(){return this._structArray.uint16[this._pos2+12]}get iconBoxStartIndex(){return this._structArray.uint16[this._pos2+13]}get iconBoxEndIndex(){return this._structArray.uint16[this._pos2+14]}get verticalIconBoxStartIndex(){return this._structArray.uint16[this._pos2+15]}get verticalIconBoxEndIndex(){return this._structArray.uint16[this._pos2+16]}get featureIndex(){return this._structArray.uint16[this._pos2+17]}get numHorizontalGlyphVertices(){return this._structArray.uint16[this._pos2+18]}get numVerticalGlyphVertices(){return this._structArray.uint16[this._pos2+19]}get numIconVertices(){return this._structArray.uint16[this._pos2+20]}get numVerticalIconVertices(){return this._structArray.uint16[this._pos2+21]}get useRuntimeCollisionCircles(){return this._structArray.uint16[this._pos2+22]}get crossTileID(){return this._structArray.uint32[this._pos4+12]}set crossTileID(t){this._structArray.uint32[this._pos4+12]=t}get textBoxScale(){return this._structArray.float32[this._pos4+13]}get collisionCircleDiameter(){return this._structArray.float32[this._pos4+14]}get textAnchorOffsetStartIndex(){return this._structArray.uint16[this._pos2+30]}get textAnchorOffsetEndIndex(){return this._structArray.uint16[this._pos2+31]}}Na.prototype.size=64;class ja extends Ea{get(t){return new Na(this,t)}}Mi(\"SymbolInstanceArray\",ja);class Ua extends Ca{getoffsetX(t){return this.float32[1*t+0]}}Mi(\"GlyphOffsetArray\",Ua);class Va extends pa{getx(t){return this.int16[3*t+0]}gety(t){return this.int16[3*t+1]}gettileUnitDistanceFromAnchor(t){return this.int16[3*t+2]}}Mi(\"SymbolLineVertexArray\",Va);class qa extends la{get textAnchor(){return this._structArray.uint16[this._pos2+0]}get textOffset0(){return this._structArray.float32[this._pos4+1]}get textOffset1(){return this._structArray.float32[this._pos4+2]}}qa.prototype.size=12;class Ha extends La{get(t){return new qa(this,t)}}Mi(\"TextAnchorOffsetArray\",Ha);class Ga extends la{get featureIndex(){return this._structArray.uint32[this._pos4+0]}get sourceLayerIndex(){return this._structArray.uint16[this._pos2+2]}get bucketIndex(){return this._structArray.uint16[this._pos2+3]}}Ga.prototype.size=8;class Za extends Ia{get(t){return new Ga(this,t)}}Mi(\"FeatureIndexArray\",Za);class Wa extends fa{}class Ya extends fa{}class Xa extends fa{}class $a extends ma{}class Ja extends ga{}class Ka extends ya{}class Qa extends va{}class to extends xa{}class eo extends _a{}class ro extends ba{}class no extends Ta{}class io extends Aa{}class ao extends Ma{}class oo extends Pa{}const so=ua([{name:\"a_pos\",components:2,type:\"Int16\"}],4),{members:lo,size:co,alignment:uo}=so;class ho{constructor(t=[]){this.segments=t}prepareSegment(t,e,r,n){let i=this.segments[this.segments.length-1];return t>ho.MAX_VERTEX_ARRAY_LENGTH&&T(`Max vertices per segment is ${ho.MAX_VERTEX_ARRAY_LENGTH}: bucket requested ${t}`),(!i||i.vertexLength+t>ho.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i}get(){return this.segments}destroy(){for(const t of this.segments)for(const e in t.vaos)t.vaos[e].destroy()}static simpleSegment(t,e,r,n){return new ho([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])}}function fo(t,e){return 256*(t=m(Math.floor(t),0,255))+m(Math.floor(e),0,255)}ho.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,Mi(\"SegmentVector\",ho);const po=ua([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint16\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint16\"}]);var mo={exports:{}},go={exports:{}};!function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}(go);var yo=go.exports,vo={exports:{}};!function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}(vo);var xo=yo,_o=vo.exports;mo.exports=xo,mo.exports.murmur3=xo,mo.exports.murmur2=_o;var bo=r(mo.exports);class wo{constructor(){this.ids=[],this.positions=[],this.indexed=!1}add(t,e,r,n){this.ids.push(To(t)),this.positions.push(e,r,n)}getPositions(t){if(!this.indexed)throw new Error(\"Trying to get index, but feature positions are not indexed\");const e=To(t);let r=0,n=this.ids.length-1;for(;r<n;){const t=r+n>>1;this.ids[t]>=e?n=t:r=t+1}const i=[];for(;this.ids[r]===e;){const t=this.positions[3*r],e=this.positions[3*r+1],n=this.positions[3*r+2];i.push({index:t,start:e,end:n}),r++}return i}static serialize(t,e){const r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return ko(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}}static deserialize(t){const e=new wo;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e}}function To(t){const e=+t;return!isNaN(e)&&e<=Number.MAX_SAFE_INTEGER?e:bo(String(t))}function ko(t,e,r,n){for(;r<n;){const i=t[r+n>>1];let a=r-1,o=n+1;for(;;){do{a++}while(t[a]<i);do{o--}while(t[o]>i);if(a>=o)break;Ao(t,a,o),Ao(e,3*a,3*o),Ao(e,3*a+1,3*o+1),Ao(e,3*a+2,3*o+2)}o-r<n-o?(ko(t,e,r,o),r=o+1):(ko(t,e,o+1,n),n=o)}}function Ao(t,e,r){const n=t[e];t[e]=t[r],t[r]=n}Mi(\"FeaturePositionMap\",wo);class Mo{constructor(t,e){this.gl=t.gl,this.location=e}}class So extends Mo{constructor(t,e){super(t,e),this.current=0}set(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))}}class Eo extends Mo{constructor(t,e){super(t,e),this.current=[0,0,0,0]}set(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))}}class Co extends Mo{constructor(t,e){super(t,e),this.current=Xt.transparent}set(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))}}const Lo=new Float32Array(16);function Io(t){return[fo(255*t.r,255*t.g),fo(255*t.b,255*t.a)]}class Po{constructor(t,e,r){this.value=t,this.uniformNames=e.map((t=>`u_${t}`)),this.type=r}setUniform(t,e,r){t.set(r.constantOr(this.value))}getBinding(t,e,r){return\"color\"===this.type?new Co(t,e):new So(t,e)}}class zo{constructor(t,e){this.uniformNames=e.map((t=>`u_${t}`)),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1}setConstantPatternPositions(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr}setUniform(t,e,r,n){const i=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;i&&t.set(i)}getBinding(t,e,r){return\"u_pattern\"===r.substr(0,9)?new Eo(t,e):new So(t,e)}}class Oo{constructor(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((t=>({name:`a_${t}`,type:\"Float32\",components:\"color\"===r?2:1,offset:0}))),this.paintVertexArray=new n}populatePaintArray(t,e,r,n,i){const a=this.paintVertexArray.length,o=this.expression.evaluate(new Hi(0),e,{},n,[],i);this.paintVertexArray.resize(t),this._setPaintValue(a,t,o)}updatePaintArray(t,e,r,n){const i=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,i)}_setPaintValue(t,e,r){if(\"color\"===this.type){const n=Io(r);for(let r=t;r<e;r++)this.paintVertexArray.emplace(r,n[0],n[1])}else{for(let n=t;n<e;n++)this.paintVertexArray.emplace(n,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}}upload(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))}destroy(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()}}class Do{constructor(t,e,r,n,i,a){this.expression=t,this.uniformNames=e.map((t=>`u_${t}_t`)),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=0,this.paintVertexAttributes=e.map((t=>({name:`a_${t}`,type:\"Float32\",components:\"color\"===r?4:2,offset:0}))),this.paintVertexArray=new a}populatePaintArray(t,e,r,n,i){const a=this.expression.evaluate(new Hi(this.zoom),e,{},n,[],i),o=this.expression.evaluate(new Hi(this.zoom+1),e,{},n,[],i),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,a,o)}updatePaintArray(t,e,r,n){const i=this.expression.evaluate({zoom:this.zoom},r,n),a=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,i,a)}_setPaintValue(t,e,r,n){if(\"color\"===this.type){const i=Io(r),a=Io(n);for(let r=t;r<e;r++)this.paintVertexArray.emplace(r,i[0],i[1],a[0],a[1])}else{for(let i=t;i<e;i++)this.paintVertexArray.emplace(i,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}}upload(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))}destroy(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()}setUniform(t,e){const r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=m(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)}getBinding(t,e,r){return new So(t,e)}}class Ro{constructor(t,e,r,n,i,a){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=a,this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i}populatePaintArray(t,e,r){const n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)}updatePaintArray(t,e,r,n,i){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],i)}_setPaintValues(t,e,r,n){if(!n||!r)return;const{min:i,mid:a,max:o}=r,s=n[i],l=n[a],c=n[o];if(s&&l&&c)for(let r=t;r<e;r++)this.zoomInPaintVertexArray.emplace(r,l.tl[0],l.tl[1],l.br[0],l.br[1],s.tl[0],s.tl[1],s.br[0],s.br[1],l.pixelRatio,s.pixelRatio),this.zoomOutPaintVertexArray.emplace(r,l.tl[0],l.tl[1],l.br[0],l.br[1],c.tl[0],c.tl[1],c.br[0],c.br[1],l.pixelRatio,c.pixelRatio)}upload(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,po.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,po.members,this.expression.isStateDependent))}destroy(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()}}class Fo{constructor(t,e,r){this.binders={},this._buffers=[];const n=[];for(const i in t.paint._values){if(!r(i))continue;const a=t.paint.get(i);if(!(a instanceof Ji&&hn(a.property.specification)))continue;const o=No(i,t.type),s=a.value,l=a.property.specification.type,c=a.property.useIntegerZoom,u=a.property.specification[\"property-type\"],h=\"cross-faded\"===u||\"cross-faded-data-driven\"===u;if(\"constant\"===s.kind)this.binders[i]=h?new zo(s.value,o):new Po(s.value,o,l),n.push(`/u_${i}`);else if(\"source\"===s.kind||h){const r=jo(i,l,\"source\");this.binders[i]=h?new Ro(s,l,c,e,r,t.id):new Oo(s,o,l,r),n.push(`/a_${i}`)}else{const t=jo(i,l,\"composite\");this.binders[i]=new Do(s,o,l,c,e,t),n.push(`/z_${i}`)}}this.cacheKey=n.sort().join(\"\")}getMaxValue(t){const e=this.binders[t];return e instanceof Oo||e instanceof Do?e.maxValue:0}populatePaintArrays(t,e,r,n,i){for(const a in this.binders){const o=this.binders[a];(o instanceof Oo||o instanceof Do||o instanceof Ro)&&o.populatePaintArray(t,e,r,n,i)}}setConstantPatternPositions(t,e){for(const r in this.binders){const n=this.binders[r];n instanceof zo&&n.setConstantPatternPositions(t,e)}}updatePaintArrays(t,e,r,n,i){let a=!1;for(const o in t){const s=e.getPositions(o);for(const e of s){const s=r.feature(e.index);for(const r in this.binders){const l=this.binders[r];if((l instanceof Oo||l instanceof Do||l instanceof Ro)&&!0===l.expression.isStateDependent){const c=n.paint.get(r);l.expression=c.value,l.updatePaintArray(e.start,e.end,s,t[o],i),a=!0}}}}return a}defines(){const t=[];for(const e in this.binders){const r=this.binders[e];(r instanceof Po||r instanceof zo)&&t.push(...r.uniformNames.map((t=>`#define HAS_UNIFORM_${t}`)))}return t}getBinderAttributes(){const t=[];for(const e in this.binders){const r=this.binders[e];if(r instanceof Oo||r instanceof Do)for(let e=0;e<r.paintVertexAttributes.length;e++)t.push(r.paintVertexAttributes[e].name);else if(r instanceof Ro)for(let e=0;e<po.members.length;e++)t.push(po.members[e].name)}return t}getBinderUniforms(){const t=[];for(const e in this.binders){const r=this.binders[e];if(r instanceof Po||r instanceof zo||r instanceof Do)for(const e of r.uniformNames)t.push(e)}return t}getPaintVertexBuffers(){return this._buffers}getUniforms(t,e){const r=[];for(const n in this.binders){const i=this.binders[n];if(i instanceof Po||i instanceof zo||i instanceof Do)for(const a of i.uniformNames)if(e[a]){const o=i.getBinding(t,e[a],a);r.push({name:a,property:n,binding:o})}}return r}setUniforms(t,e,r,n){for(const{name:t,property:i,binding:a}of e)this.binders[i].setUniform(a,n,r.get(i),t)}updatePaintBuffers(t){this._buffers=[];for(const e in this.binders){const r=this.binders[e];if(t&&r instanceof Ro){const e=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;e&&this._buffers.push(e)}else(r instanceof Oo||r instanceof Do)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}}upload(t){for(const e in this.binders){const r=this.binders[e];(r instanceof Oo||r instanceof Do||r instanceof Ro)&&r.upload(t)}this.updatePaintBuffers()}destroy(){for(const t in this.binders){const e=this.binders[t];(e instanceof Oo||e instanceof Do||e instanceof Ro)&&e.destroy()}}}class Bo{constructor(t,e,r=(()=>!0)){this.programConfigurations={};for(const n of t)this.programConfigurations[n.id]=new Fo(n,e,r);this.needsUpload=!1,this._featureMap=new wo,this._bufferOffset=0}populatePaintArrays(t,e,r,n,i,a){for(const r in this.programConfigurations)this.programConfigurations[r].populatePaintArrays(t,e,n,i,a);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0}updatePaintArrays(t,e,r,n){for(const i of r)this.needsUpload=this.programConfigurations[i.id].updatePaintArrays(t,this._featureMap,e,i,n)||this.needsUpload}get(t){return this.programConfigurations[t]}upload(t){if(this.needsUpload){for(const e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}}destroy(){for(const t in this.programConfigurations)this.programConfigurations[t].destroy()}}function No(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(`${e}-`,\"\").replace(/-/g,\"_\")]}function jo(t,e,r){const n={color:{source:ya,composite:Oa},number:{source:Ca,composite:ya}},i=function(t){return{\"line-pattern\":{source:Qa,composite:Qa},\"fill-pattern\":{source:Qa,composite:Qa},\"fill-extrusion-pattern\":{source:Qa,composite:Qa}}[t]}(t);return i&&i[r]||n[e][r]}Mi(\"ConstantBinder\",Po),Mi(\"CrossFadedConstantBinder\",zo),Mi(\"SourceExpressionBinder\",Oo),Mi(\"CrossFadedCompositeBinder\",Ro),Mi(\"CompositeExpressionBinder\",Do),Mi(\"ProgramConfiguration\",Fo,{omit:[\"_buffers\"]}),Mi(\"ProgramConfigurationSet\",Bo);const Uo=8192,Vo=Math.pow(2,14)-1,qo=-Vo-1;function Ho(t){const e=Uo/t.extent,r=t.loadGeometry();for(let t=0;t<r.length;t++){const n=r[t];for(let t=0;t<n.length;t++){const r=n[t],i=Math.round(r.x*e),a=Math.round(r.y*e);r.x=m(i,qo,Vo),r.y=m(a,qo,Vo),(i<r.x||i>r.x+1||a<r.y||a>r.y+1)&&T(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}}return r}function Go(t,e){return{type:t.type,id:t.id,properties:t.properties,geometry:e?Ho(t):[]}}function Zo(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}class Wo{constructor(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((t=>t.id)),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Ya,this.indexArray=new ao,this.segments=new ho,this.programConfigurations=new Bo(t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((t=>t.isStateDependent())).map((t=>t.id))}populate(t,e,r){const n=this.layers[0],i=[];let a=null,o=!1;\"circle\"===n.type&&(a=n.layout.get(\"circle-sort-key\"),o=!a.isConstant());for(const{feature:e,id:n,index:s,sourceLayerIndex:l}of t){const t=this.layers[0]._featureFilter.needGeometry,c=Go(e,t);if(!this.layers[0]._featureFilter.filter(new Hi(this.zoom),c,r))continue;const u=o?a.evaluate(c,{},r):void 0,h={id:n,properties:e.properties,type:e.type,sourceLayerIndex:l,index:s,geometry:t?c.geometry:Ho(e),patterns:{},sortKey:u};i.push(h)}o&&i.sort(((t,e)=>t.sortKey-e.sortKey));for(const n of i){const{geometry:i,index:a,sourceLayerIndex:o}=n,s=t[a].feature;this.addFeature(n,i,a,r),e.featureIndex.insert(s,i,a,o,this.index)}}update(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)}isEmpty(){return 0===this.layoutVertexArray.length}uploadPending(){return!this.uploaded||this.programConfigurations.needsUpload}upload(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,lo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0}destroy(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())}addFeature(t,e,r,n){for(const r of e)for(const e of r){const r=e.x,n=e.y;if(r<0||r>=Uo||n<0||n>=Uo)continue;const i=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),a=i.vertexLength;Zo(this.layoutVertexArray,r,n,-1,-1),Zo(this.layoutVertexArray,r,n,1,-1),Zo(this.layoutVertexArray,r,n,1,1),Zo(this.layoutVertexArray,r,n,-1,1),this.indexArray.emplaceBack(a,a+1,a+2),this.indexArray.emplaceBack(a,a+3,a+2),i.vertexLength+=4,i.primitiveLength+=2}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)}}function Yo(t,e){for(let r=0;r<t.length;r++)if(ns(e,t[r]))return!0;for(let r=0;r<e.length;r++)if(ns(t,e[r]))return!0;return!!Ko(t,e)}function Xo(t,e,r){return!!ns(t,e)||!!ts(e,t,r)}function $o(t,e){if(1===t.length)return rs(e,t[0]);for(let r=0;r<e.length;r++){const n=e[r];for(let e=0;e<n.length;e++)if(ns(t,n[e]))return!0}for(let r=0;r<t.length;r++)if(rs(e,t[r]))return!0;for(let r=0;r<e.length;r++)if(Ko(t,e[r]))return!0;return!1}function Jo(t,e,r){if(t.length>1){if(Ko(t,e))return!0;for(let n=0;n<e.length;n++)if(ts(e[n],t,r))return!0}for(let n=0;n<t.length;n++)if(ts(t[n],e,r))return!0;return!1}function Ko(t,e){if(0===t.length||0===e.length)return!1;for(let r=0;r<t.length-1;r++){const n=t[r],i=t[r+1];for(let t=0;t<e.length-1;t++)if(Qo(n,i,e[t],e[t+1]))return!0}return!1}function Qo(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function ts(t,e,r){const n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(let r=1;r<e.length;r++)if(es(t,e[r-1],e[r])<n)return!0;return!1}function es(t,e,r){const n=e.distSqr(r);if(0===n)return t.distSqr(e);const i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function rs(t,e){let r,n,i,a=!1;for(let o=0;o<t.length;o++){r=t[o];for(let t=0,o=r.length-1;t<r.length;o=t++)n=r[t],i=r[o],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a)}return a}function ns(t,e){let r=!1;for(let n=0,i=t.length-1;n<t.length;i=n++){const a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function is(t,e,r){const n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;const a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function as(t,e,r){const n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function os(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function ss(t,e,r,n,i){if(!e[0]&&!e[1])return t;const o=a.convert(e)._mult(i);\"viewport\"===r&&o._rotate(-n);const s=[];for(let e=0;e<t.length;e++){const r=t[e];s.push(r.sub(o))}return s}let ls;Mi(\"CircleBucket\",Wo,{omit:[\"layers\"]});let cs;var us={get paint(){return cs=cs||new ia({\"circle-radius\":new ta(Z.paint_circle[\"circle-radius\"]),\"circle-color\":new ta(Z.paint_circle[\"circle-color\"]),\"circle-blur\":new ta(Z.paint_circle[\"circle-blur\"]),\"circle-opacity\":new ta(Z.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Qi(Z.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Qi(Z.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Qi(Z.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Qi(Z.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new ta(Z.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new ta(Z.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new ta(Z.paint_circle[\"circle-stroke-opacity\"])})},get layout(){return ls=ls||new ia({\"circle-sort-key\":new ta(Z.layout_circle[\"circle-sort-key\"])})}},hs=1e-6,fs=\"undefined\"!=typeof Float32Array?Float32Array:Array;function ps(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function ds(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],m=e[12],g=e[13],y=e[14],v=e[15],x=r[0],_=r[1],b=r[2],w=r[3];return t[0]=x*n+_*s+b*h+w*m,t[1]=x*i+_*l+b*f+w*g,t[2]=x*a+_*c+b*p+w*y,t[3]=x*o+_*u+b*d+w*v,x=r[4],_=r[5],b=r[6],w=r[7],t[4]=x*n+_*s+b*h+w*m,t[5]=x*i+_*l+b*f+w*g,t[6]=x*a+_*c+b*p+w*y,t[7]=x*o+_*u+b*d+w*v,x=r[8],_=r[9],b=r[10],w=r[11],t[8]=x*n+_*s+b*h+w*m,t[9]=x*i+_*l+b*f+w*g,t[10]=x*a+_*c+b*p+w*y,t[11]=x*o+_*u+b*d+w*v,x=r[12],_=r[13],b=r[14],w=r[15],t[12]=x*n+_*s+b*h+w*m,t[13]=x*i+_*l+b*f+w*g,t[14]=x*a+_*c+b*p+w*y,t[15]=x*o+_*u+b*d+w*v,t}Math.hypot||(Math.hypot=function(){for(var t=0,e=arguments.length;e--;)t+=arguments[e]*arguments[e];return Math.sqrt(t)});var ms=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t};var gs=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t};var ys=ds;function vs(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}var xs,_s=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t};xs=new fs(4),fs!=Float32Array&&(xs[0]=0,xs[1]=0,xs[2]=0,xs[3]=0);class bs extends oa{constructor(t){super(t,us)}createBucket(t){return new Wo(t)}queryRadius(t){const e=t;return as(\"circle-radius\",this,e)+as(\"circle-stroke-width\",this,e)+os(this.paint.get(\"circle-translate\"))}queryIntersectsFeature(t,e,r,n,i,a,o,s){const l=ss(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return t.map((t=>ws(t,e)))}(l,s),f=u?c*o:c;for(const t of n)for(const e of t){const t=u?e:ws(e,s);let r=f;const n=vs([],[e.x,e.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?r*=n[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(r*=a.cameraToCenterDistance/n[3]),Xo(h,t,r))return!0}return!1}}function ws(t,e){const r=vs([],[t.x,t.y,0,1],e);return new a(r[0]/r[3],r[1]/r[3])}class Ts extends Wo{}let ks;Mi(\"HeatmapBucket\",Ts,{omit:[\"layers\"]});var As={get paint(){return ks=ks||new ia({\"heatmap-radius\":new ta(Z.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new ta(Z.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Qi(Z.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new na(Z.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Qi(Z.paint_heatmap[\"heatmap-opacity\"])})}};function Ms(t,{width:e,height:r},n,i){if(i){if(i instanceof Uint8ClampedArray)i=new Uint8Array(i.buffer);else if(i.length!==e*r*n)throw new RangeError(`mismatched image size. expected: ${i.length} but got: ${e*r*n}`)}else i=new Uint8Array(e*r*n);return t.width=e,t.height=r,t.data=i,t}function Ss(t,{width:e,height:r},n){if(e===t.width&&r===t.height)return;const i=Ms({},{width:e,height:r},n);Es(t,i,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,e),height:Math.min(t.height,r)},n),t.width=e,t.height=r,t.data=i.data}function Es(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");const o=t.data,s=e.data;if(o===s)throw new Error(\"srcData equals dstData, so image is already copied\");for(let l=0;l<i.height;l++){const c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a;for(let t=0;t<i.width*a;t++)s[u+t]=o[c+t]}return e}class Cs{constructor(t,e){Ms(this,t,1,e)}resize(t){Ss(this,t,1)}clone(){return new Cs({width:this.width,height:this.height},new Uint8Array(this.data))}static copy(t,e,r,n,i){Es(t,e,r,n,i,1)}}class Ls{constructor(t,e){Ms(this,t,4,e)}resize(t){Ss(this,t,4)}replace(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t}clone(){return new Ls({width:this.width,height:this.height},new Uint8Array(this.data))}static copy(t,e,r,n,i){Es(t,e,r,n,i,4)}}function Is(t){const e={},r=t.resolution||256,n=t.clips?t.clips.length:1,i=t.image||new Ls({width:r,height:n});if(a=r,Math.log(a)/Math.LN2%1!=0)throw new Error(`width is not a power of 2 - ${r}`);var a;const o=(r,n,a)=>{e[t.evaluationKey]=a;const o=t.expression.evaluate(e);i.data[r+n+0]=Math.floor(255*o.r/o.a),i.data[r+n+1]=Math.floor(255*o.g/o.a),i.data[r+n+2]=Math.floor(255*o.b/o.a),i.data[r+n+3]=Math.floor(255*o.a)};if(t.clips)for(let e=0,i=0;e<n;++e,i+=4*r)for(let n=0,a=0;n<r;n++,a+=4){const s=n/(r-1),{start:l,end:c}=t.clips[e];o(i,a,l*(1-s)+c*s)}else for(let t=0,e=0;t<r;t++,e+=4)o(0,e,t/(r-1));return i}Mi(\"AlphaImage\",Cs),Mi(\"RGBAImage\",Ls);class Ps extends oa{createBucket(t){return new Ts(t)}constructor(t){super(t,As),this._updateColorRamp()}_handleSpecialPaintPropertyUpdate(t){\"heatmap-color\"===t&&this._updateColorRamp()}_updateColorRamp(){const t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Is({expression:t,evaluationKey:\"heatmapDensity\",image:this.colorRamp}),this.colorRampTexture=null}resize(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)}queryRadius(){return 0}queryIntersectsFeature(){return!1}hasOffscreenPass(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility}}let zs;var Os={get paint(){return zs=zs||new ia({\"hillshade-illumination-direction\":new Qi(Z.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Qi(Z.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Qi(Z.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Qi(Z.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Qi(Z.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Qi(Z.paint_hillshade[\"hillshade-accent-color\"])})}};class Ds extends oa{constructor(t){super(t,Os)}hasOffscreenPass(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility}}const Rs=ua([{name:\"a_pos\",components:2,type:\"Int16\"}],4),{members:Fs,size:Bs,alignment:Ns}=Rs;function js(t,e,r=2){const n=e&&e.length,i=n?e[0]*r:t.length;let a=Us(t,0,i,r,!0);const o=[];if(!a||a.next===a.prev)return o;let s,l,c;if(n&&(a=function(t,e,r,n){const i=[];for(let r=0,a=e.length;r<a;r++){const o=Us(t,e[r]*n,r<a-1?e[r+1]*n:t.length,n,!1);o===o.next&&(o.steiner=!0),i.push(Ks(o))}i.sort(Ys);for(let t=0;t<i.length;t++)r=Xs(i[t],r);return r}(t,e,a,r)),t.length>80*r){s=1/0,l=1/0;let e=-1/0,n=-1/0;for(let a=r;a<i;a+=r){const r=t[a],i=t[a+1];r<s&&(s=r),i<l&&(l=i),r>e&&(e=r),i>n&&(n=i)}c=Math.max(e-s,n-l),c=0!==c?32767/c:0}return qs(a,o,r,s,l,c,0),o}function Us(t,e,r,n,i){let a;if(i===function(t,e,r,n){let i=0;for(let a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}(t,e,r,n)>0)for(let i=e;i<r;i+=n)a=ll(i/n|0,t[i],t[i+1],a);else for(let i=r-n;i>=e;i-=n)a=ll(i/n|0,t[i],t[i+1],a);return a&&rl(a,a.next)&&(cl(a),a=a.next),a}function Vs(t,e){if(!t)return t;e||(e=t);let r,n=t;do{if(r=!1,n.steiner||!rl(n,n.next)&&0!==el(n.prev,n,n.next))n=n.next;else{if(cl(n),n=e=n.prev,n===n.next)break;r=!0}}while(r||n!==e);return e}function qs(t,e,r,n,i,a,o){if(!t)return;!o&&a&&function(t,e,r,n){let i=t;do{0===i.z&&(i.z=Js(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){let e,r=1;do{let n,i=t;t=null;let a=null;for(e=0;i;){e++;let o=i,s=0;for(let t=0;t<r&&(s++,o=o.nextZ,o);t++);let l=r;for(;s>0||l>0&&o;)0!==s&&(0===l||!o||i.z<=o.z)?(n=i,i=i.nextZ,s--):(n=o,o=o.nextZ,l--),a?a.nextZ=n:t=n,n.prevZ=a,a=n;i=o}a.nextZ=null,r*=2}while(e>1)}(i)}(t,n,i,a);let s=t;for(;t.prev!==t.next;){const l=t.prev,c=t.next;if(a?Gs(t,n,i,a):Hs(t))e.push(l.i,t.i,c.i),cl(t),t=c.next,s=c.next;else if((t=c)===s){o?1===o?qs(t=Zs(Vs(t),e),e,r,n,i,a,2):2===o&&Ws(t,e,r,n,i,a):qs(Vs(t),e,r,n,i,a,1);break}}}function Hs(t){const e=t.prev,r=t,n=t.next;if(el(e,r,n)>=0)return!1;const i=e.x,a=r.x,o=n.x,s=e.y,l=r.y,c=n.y,u=i<a?i<o?i:o:a<o?a:o,h=s<l?s<c?s:c:l<c?l:c,f=i>a?i>o?i:o:a>o?a:o,p=s>l?s>c?s:c:l>c?l:c;let d=n.next;for(;d!==e;){if(d.x>=u&&d.x<=f&&d.y>=h&&d.y<=p&&Qs(i,s,a,l,o,c,d.x,d.y)&&el(d.prev,d,d.next)>=0)return!1;d=d.next}return!0}function Gs(t,e,r,n){const i=t.prev,a=t,o=t.next;if(el(i,a,o)>=0)return!1;const s=i.x,l=a.x,c=o.x,u=i.y,h=a.y,f=o.y,p=s<l?s<c?s:c:l<c?l:c,d=u<h?u<f?u:f:h<f?h:f,m=s>l?s>c?s:c:l>c?l:c,g=u>h?u>f?u:f:h>f?h:f,y=Js(p,d,e,r,n),v=Js(m,g,e,r,n);let x=t.prevZ,_=t.nextZ;for(;x&&x.z>=y&&_&&_.z<=v;){if(x.x>=p&&x.x<=m&&x.y>=d&&x.y<=g&&x!==i&&x!==o&&Qs(s,u,l,h,c,f,x.x,x.y)&&el(x.prev,x,x.next)>=0)return!1;if(x=x.prevZ,_.x>=p&&_.x<=m&&_.y>=d&&_.y<=g&&_!==i&&_!==o&&Qs(s,u,l,h,c,f,_.x,_.y)&&el(_.prev,_,_.next)>=0)return!1;_=_.nextZ}for(;x&&x.z>=y;){if(x.x>=p&&x.x<=m&&x.y>=d&&x.y<=g&&x!==i&&x!==o&&Qs(s,u,l,h,c,f,x.x,x.y)&&el(x.prev,x,x.next)>=0)return!1;x=x.prevZ}for(;_&&_.z<=v;){if(_.x>=p&&_.x<=m&&_.y>=d&&_.y<=g&&_!==i&&_!==o&&Qs(s,u,l,h,c,f,_.x,_.y)&&el(_.prev,_,_.next)>=0)return!1;_=_.nextZ}return!0}function Zs(t,e){let r=t;do{const n=r.prev,i=r.next.next;!rl(n,i)&&nl(n,r,r.next,i)&&ol(n,i)&&ol(i,n)&&(e.push(n.i,r.i,i.i),cl(r),cl(r.next),r=t=i),r=r.next}while(r!==t);return Vs(r)}function Ws(t,e,r,n,i,a){let o=t;do{let t=o.next.next;for(;t!==o.prev;){if(o.i!==t.i&&tl(o,t)){let s=sl(o,t);return o=Vs(o,o.next),s=Vs(s,s.next),qs(o,e,r,n,i,a,0),void qs(s,e,r,n,i,a,0)}t=t.next}o=o.next}while(o!==t)}function Ys(t,e){return t.x-e.x}function Xs(t,e){const r=function(t,e){let r=e;const n=t.x,i=t.y;let a,o=-1/0;do{if(i<=r.y&&i>=r.next.y&&r.next.y!==r.y){const t=r.x+(i-r.y)*(r.next.x-r.x)/(r.next.y-r.y);if(t<=n&&t>o&&(o=t,a=r.x<r.next.x?r:r.next,t===n))return a}r=r.next}while(r!==e);if(!a)return null;const s=a,l=a.x,c=a.y;let u=1/0;r=a;do{if(n>=r.x&&r.x>=l&&n!==r.x&&Qs(i<c?n:o,i,l,c,i<c?o:n,i,r.x,r.y)){const e=Math.abs(i-r.y)/(n-r.x);ol(r,t)&&(e<u||e===u&&(r.x>a.x||r.x===a.x&&$s(a,r)))&&(a=r,u=e)}r=r.next}while(r!==s);return a}(t,e);if(!r)return e;const n=sl(r,t);return Vs(n,n.next),Vs(r,r.next)}function $s(t,e){return el(t.prev,t,e.prev)<0&&el(e.next,t,t.next)<0}function Js(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=(t-r)*i|0)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=(e-n)*i|0)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Ks(t){let e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function Qs(t,e,r,n,i,a,o,s){return(i-o)*(e-s)>=(t-o)*(a-s)&&(t-o)*(n-s)>=(r-o)*(e-s)&&(r-o)*(a-s)>=(i-o)*(n-s)}function tl(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){let r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&nl(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(ol(t,e)&&ol(e,t)&&function(t,e){let r=t,n=!1;const i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(el(t.prev,t,e.prev)||el(t,e.prev,e))||rl(t,e)&&el(t.prev,t,t.next)>0&&el(e.prev,e,e.next)>0)}function el(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function rl(t,e){return t.x===e.x&&t.y===e.y}function nl(t,e,r,n){const i=al(el(t,e,r)),a=al(el(t,e,n)),o=al(el(r,n,t)),s=al(el(r,n,e));return i!==a&&o!==s||!(0!==i||!il(t,r,e))||!(0!==a||!il(t,n,e))||!(0!==o||!il(r,t,n))||!(0!==s||!il(r,e,n))}function il(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function al(t){return t>0?1:t<0?-1:0}function ol(t,e){return el(t.prev,t,t.next)<0?el(t,e,t.next)>=0&&el(t,t.prev,e)>=0:el(t,e,t.prev)<0||el(t,t.next,e)<0}function sl(t,e){const r=ul(t.i,t.x,t.y),n=ul(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function ll(t,e,r,n){const i=ul(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function cl(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function ul(t,e,r){return{i:t,x:e,y:r,prev:null,next:null,z:0,prevZ:null,nextZ:null,steiner:!1}}function hl(t,e,r){const n=r.patternDependencies;let i=!1;for(const r of e){const e=r.paint.get(`${t}-pattern`);e.isConstant()||(i=!0);const a=e.constantOr(null);a&&(i=!0,n[a.to]=!0,n[a.from]=!0)}return i}function fl(t,e,r,n,i){const a=i.patternDependencies;for(const o of e){const e=o.paint.get(`${t}-pattern`).value;if(\"constant\"!==e.kind){let t=e.evaluate({zoom:n-1},r,{},i.availableImages),s=e.evaluate({zoom:n},r,{},i.availableImages),l=e.evaluate({zoom:n+1},r,{},i.availableImages);t=t&&t.name?t.name:t,s=s&&s.name?s.name:s,l=l&&l.name?l.name:l,a[t]=!0,a[s]=!0,a[l]=!0,r.patterns[o.id]={min:t,mid:s,max:l}}}return r}class pl{constructor(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((t=>t.id)),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Xa,this.indexArray=new ao,this.indexArray2=new oo,this.programConfigurations=new Bo(t.layers,t.zoom),this.segments=new ho,this.segments2=new ho,this.stateDependentLayerIds=this.layers.filter((t=>t.isStateDependent())).map((t=>t.id))}populate(t,e,r){this.hasPattern=hl(\"fill\",this.layers,e);const n=this.layers[0].layout.get(\"fill-sort-key\"),i=!n.isConstant(),a=[];for(const{feature:o,id:s,index:l,sourceLayerIndex:c}of t){const t=this.layers[0]._featureFilter.needGeometry,u=Go(o,t);if(!this.layers[0]._featureFilter.filter(new Hi(this.zoom),u,r))continue;const h=i?n.evaluate(u,{},r,e.availableImages):void 0,f={id:s,properties:o.properties,type:o.type,sourceLayerIndex:c,index:l,geometry:t?u.geometry:Ho(o),patterns:{},sortKey:h};a.push(f)}i&&a.sort(((t,e)=>t.sortKey-e.sortKey));for(const n of a){const{geometry:i,index:a,sourceLayerIndex:o}=n;if(this.hasPattern){const t=fl(\"fill\",this.layers,n,this.zoom,e);this.patternFeatures.push(t)}else this.addFeature(n,i,a,r,{});const s=t[a].feature;e.featureIndex.insert(s,i,a,o,this.index)}}update(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)}addFeatures(t,e,r){for(const t of this.patternFeatures)this.addFeature(t,t.geometry,t.index,e,r)}isEmpty(){return 0===this.layoutVertexArray.length}uploadPending(){return!this.uploaded||this.programConfigurations.needsUpload}upload(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Fs),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0}destroy(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())}addFeature(t,e,r,n,i){for(const t of br(e,500)){let e=0;for(const r of t)e+=r.length;const r=this.segments.prepareSegment(e,this.layoutVertexArray,this.indexArray),n=r.vertexLength,i=[],a=[];for(const e of t){if(0===e.length)continue;e!==t[0]&&a.push(i.length/2);const r=this.segments2.prepareSegment(e.length,this.layoutVertexArray,this.indexArray2),n=r.vertexLength;this.layoutVertexArray.emplaceBack(e[0].x,e[0].y),this.indexArray2.emplaceBack(n+e.length-1,n),i.push(e[0].x),i.push(e[0].y);for(let t=1;t<e.length;t++)this.layoutVertexArray.emplaceBack(e[t].x,e[t].y),this.indexArray2.emplaceBack(n+t-1,n+t),i.push(e[t].x),i.push(e[t].y);r.vertexLength+=e.length,r.primitiveLength+=e.length}const o=js(i,a);for(let t=0;t<o.length;t+=3)this.indexArray.emplaceBack(n+o[t],n+o[t+1],n+o[t+2]);r.vertexLength+=e,r.primitiveLength+=o.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)}}let dl;Mi(\"FillBucket\",pl,{omit:[\"layers\",\"patternFeatures\"]});let ml;var gl={get paint(){return ml=ml||new ia({\"fill-antialias\":new Qi(Z.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new ta(Z.paint_fill[\"fill-opacity\"]),\"fill-color\":new ta(Z.paint_fill[\"fill-color\"]),\"fill-outline-color\":new ta(Z.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Qi(Z.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Qi(Z.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new ea(Z.paint_fill[\"fill-pattern\"])})},get layout(){return dl=dl||new ia({\"fill-sort-key\":new ta(Z.layout_fill[\"fill-sort-key\"])})}};class yl extends oa{constructor(t){super(t,gl)}recalculate(t,e){super.recalculate(t,e);const r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])}createBucket(t){return new pl(t)}queryRadius(){return os(this.paint.get(\"fill-translate\"))}queryIntersectsFeature(t,e,r,n,i,a,o){return $o(ss(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)}isTileClipped(){return!0}}const vl=ua([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4),xl=ua([{name:\"a_centroid\",components:2,type:\"Int16\"}],4),{members:_l,size:bl,alignment:wl}=vl;var Tl={},kl=n,Al=Ml;function Ml(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Sl,this,e)}function Sl(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function El(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Ml.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Ml.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,i=0,a=0,o=0,s=[];t.pos<r;){if(i<=0){var l=t.readVarint();n=7&l,i=l>>3}if(i--,1===n||2===n)a+=t.readSVarint(),o+=t.readSVarint(),1===n&&(e&&s.push(e),e=[]),e.push(new kl(a,o));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&s.push(e),s},Ml.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Ml.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Ml.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=El(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Cl=Al,Ll=Il;function Il(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(Pl,this,e),this.length=this._features.length}function Pl(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}Il.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Cl(this._pbf,e,this.extent,this._keys,this._values)};var zl=Ll,Ol=function(t,e){this.layers=t.readFields(Dl,{},e)};function Dl(t,e,r){if(3===t){var n=new zl(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}Tl.VectorTile=Ol,Tl.VectorTileFeature=Al,Tl.VectorTileLayer=Ll;const Rl=Tl.VectorTileFeature.types,Fl=Math.pow(2,13);function Bl(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Fl)+o,i*Fl*2,a*Fl*2,Math.round(s))}class Nl{constructor(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((t=>t.id)),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new $a,this.centroidVertexArray=new Wa,this.indexArray=new ao,this.programConfigurations=new Bo(t.layers,t.zoom),this.segments=new ho,this.stateDependentLayerIds=this.layers.filter((t=>t.isStateDependent())).map((t=>t.id))}populate(t,e,r){this.features=[],this.hasPattern=hl(\"fill-extrusion\",this.layers,e);for(const{feature:n,id:i,index:a,sourceLayerIndex:o}of t){const t=this.layers[0]._featureFilter.needGeometry,s=Go(n,t);if(!this.layers[0]._featureFilter.filter(new Hi(this.zoom),s,r))continue;const l={id:i,sourceLayerIndex:o,index:a,geometry:t?s.geometry:Ho(n),properties:n.properties,type:n.type,patterns:{}};this.hasPattern?this.features.push(fl(\"fill-extrusion\",this.layers,l,this.zoom,e)):this.addFeature(l,l.geometry,a,r,{}),e.featureIndex.insert(n,l.geometry,a,o,this.index,!0)}}addFeatures(t,e,r){for(const t of this.features){const{geometry:n}=t;this.addFeature(t,n,t.index,e,r)}}update(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)}isEmpty(){return 0===this.layoutVertexArray.length&&0===this.centroidVertexArray.length}uploadPending(){return!this.uploaded||this.programConfigurations.needsUpload}upload(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,_l),this.centroidVertexBuffer=t.createVertexBuffer(this.centroidVertexArray,xl.members,!0),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0}destroy(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.centroidVertexBuffer.destroy())}addFeature(t,e,r,n,i){for(const r of br(e,500)){const e={x:0,y:0,vertexCount:0};let n=0;for(const t of r)n+=t.length;let i=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray);for(const t of r){if(0===t.length)continue;if(Ul(t))continue;let r=0;for(let n=0;n<t.length;n++){const a=t[n];if(n>=1){const o=t[n-1];if(!jl(a,o)){i.vertexLength+4>ho.MAX_VERTEX_ARRAY_LENGTH&&(i=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));const t=a.sub(o)._perp()._unit(),n=o.dist(a);r+n>32768&&(r=0),Bl(this.layoutVertexArray,a.x,a.y,t.x,t.y,0,0,r),Bl(this.layoutVertexArray,a.x,a.y,t.x,t.y,0,1,r),e.x+=2*a.x,e.y+=2*a.y,e.vertexCount+=2,r+=n,Bl(this.layoutVertexArray,o.x,o.y,t.x,t.y,0,0,r),Bl(this.layoutVertexArray,o.x,o.y,t.x,t.y,0,1,r),e.x+=2*o.x,e.y+=2*o.y,e.vertexCount+=2;const s=i.vertexLength;this.indexArray.emplaceBack(s,s+2,s+1),this.indexArray.emplaceBack(s+1,s+2,s+3),i.vertexLength+=4,i.primitiveLength+=2}}}}if(i.vertexLength+n>ho.MAX_VERTEX_ARRAY_LENGTH&&(i=this.segments.prepareSegment(n,this.layoutVertexArray,this.indexArray)),\"Polygon\"!==Rl[t.type])continue;const a=[],o=[],s=i.vertexLength;for(const t of r)if(0!==t.length){t!==r[0]&&o.push(a.length/2);for(let r=0;r<t.length;r++){const n=t[r];Bl(this.layoutVertexArray,n.x,n.y,0,0,1,1,0),e.x+=n.x,e.y+=n.y,e.vertexCount+=1,a.push(n.x),a.push(n.y)}}const l=js(a,o);for(let t=0;t<l.length;t+=3)this.indexArray.emplaceBack(s+l[t],s+l[t+2],s+l[t+1]);i.primitiveLength+=l.length/3,i.vertexLength+=n;for(let t=0;t<e.vertexCount;t++){const t=Math.floor(e.x/e.vertexCount),r=Math.floor(e.y/e.vertexCount);this.centroidVertexArray.emplaceBack(t,r)}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)}}function jl(t,e){return t.x===e.x&&(t.x<0||t.x>Uo)||t.y===e.y&&(t.y<0||t.y>Uo)}function Ul(t){return t.every((t=>t.x<0))||t.every((t=>t.x>Uo))||t.every((t=>t.y<0))||t.every((t=>t.y>Uo))}let Vl;Mi(\"FillExtrusionBucket\",Nl,{omit:[\"layers\",\"features\"]});var ql={get paint(){return Vl=Vl||new ia({\"fill-extrusion-opacity\":new Qi(Z[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new ta(Z[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Qi(Z[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Qi(Z[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new ea(Z[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new ta(Z[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new ta(Z[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Qi(Z[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})}};class Hl extends oa{constructor(t){super(t,ql)}createBucket(t){return new Nl(t)}queryRadius(){return os(this.paint.get(\"fill-extrusion-translate\"))}is3D(){return!0}queryIntersectsFeature(t,e,r,n,i,o,s,l){const c=ss(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){const i=[];for(const r of t){const t=[r.x,r.y,n,1];vs(t,t,e),i.push(new a(t[0]/t[3],t[1]/t[3]))}return i}(c,l,0,0),p=function(t,e,r,n){const i=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r;for(const e of t){const t=[],r=[];for(const i of e){const e=i.x,o=i.y,m=n[0]*e+n[4]*o+n[12],g=n[1]*e+n[5]*o+n[13],y=n[2]*e+n[6]*o+n[14],v=n[3]*e+n[7]*o+n[15],x=y+c,_=v+u,b=m+h,w=g+f,T=y+p,k=v+d,A=new a((m+s)/_,(g+l)/_);A.z=x/_,t.push(A);const M=new a(b/k,w/k);M.z=T/k,r.push(M)}i.push(t),o.push(r)}return[i,o]}(n,h,u,l);return function(t,e,r){let n=1/0;$o(r,e)&&(n=Zl(r,e[0]));for(let i=0;i<e.length;i++){const a=e[i],o=t[i];for(let t=0;t<a.length-1;t++){const e=a[t],i=a[t+1],s=o[t],l=[e,i,o[t+1],s,e];Yo(r,l)&&(n=Math.min(n,Zl(r,l)))}}return n!==1/0&&n}(p[0],p[1],f)}}function Gl(t,e){return t.x*e.x+t.y*e.y}function Zl(t,e){if(1===t.length){let r=0;const n=e[r++];let i;for(;!i||n.equals(i);)if(i=e[r++],!i)return 1/0;for(;r<e.length;r++){const a=e[r],o=t[0],s=i.sub(n),l=a.sub(n),c=o.sub(n),u=Gl(s,s),h=Gl(s,l),f=Gl(l,l),p=Gl(c,s),d=Gl(c,l),m=u*f-h*h,g=(f*p-h*d)/m,y=(u*d-h*p)/m,v=1-g-y,x=n.z*v+i.z*g+a.z*y;if(isFinite(x))return x}return 1/0}{let t=1/0;for(const r of e)t=Math.min(t,r.z);return t}}const Wl=ua([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4),{members:Yl,size:Xl,alignment:$l}=Wl,Jl=ua([{name:\"a_uv_x\",components:1,type:\"Float32\"},{name:\"a_split_index\",components:1,type:\"Float32\"}]),{members:Kl,size:Ql,alignment:tc}=Jl,ec=Tl.VectorTileFeature.types,rc=Math.cos(Math.PI/180*37.5),nc=Math.pow(2,14)/.5;class ic{constructor(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((t=>t.id)),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.lineClipsArray=[],this.gradients={},this.layers.forEach((t=>{this.gradients[t.id]={}})),this.layoutVertexArray=new Ja,this.layoutVertexArray2=new Ka,this.indexArray=new ao,this.programConfigurations=new Bo(t.layers,t.zoom),this.segments=new ho,this.maxLineLength=0,this.stateDependentLayerIds=this.layers.filter((t=>t.isStateDependent())).map((t=>t.id))}populate(t,e,r){this.hasPattern=hl(\"line\",this.layers,e);const n=this.layers[0].layout.get(\"line-sort-key\"),i=!n.isConstant(),a=[];for(const{feature:e,id:o,index:s,sourceLayerIndex:l}of t){const t=this.layers[0]._featureFilter.needGeometry,c=Go(e,t);if(!this.layers[0]._featureFilter.filter(new Hi(this.zoom),c,r))continue;const u=i?n.evaluate(c,{},r):void 0,h={id:o,properties:e.properties,type:e.type,sourceLayerIndex:l,index:s,geometry:t?c.geometry:Ho(e),patterns:{},sortKey:u};a.push(h)}i&&a.sort(((t,e)=>t.sortKey-e.sortKey));for(const n of a){const{geometry:i,index:a,sourceLayerIndex:o}=n;if(this.hasPattern){const t=fl(\"line\",this.layers,n,this.zoom,e);this.patternFeatures.push(t)}else this.addFeature(n,i,a,r,{});const s=t[a].feature;e.featureIndex.insert(s,i,a,o,this.index)}}update(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)}addFeatures(t,e,r){for(const t of this.patternFeatures)this.addFeature(t,t.geometry,t.index,e,r)}isEmpty(){return 0===this.layoutVertexArray.length}uploadPending(){return!this.uploaded||this.programConfigurations.needsUpload}upload(t){this.uploaded||(0!==this.layoutVertexArray2.length&&(this.layoutVertexBuffer2=t.createVertexBuffer(this.layoutVertexArray2,Kl)),this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Yl),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0}destroy(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())}lineFeatureClips(t){if(t.properties&&Object.prototype.hasOwnProperty.call(t.properties,\"mapbox_clip_start\")&&Object.prototype.hasOwnProperty.call(t.properties,\"mapbox_clip_end\"))return{start:+t.properties.mapbox_clip_start,end:+t.properties.mapbox_clip_end}}addFeature(t,e,r,n,i){const a=this.layers[0].layout,o=a.get(\"line-join\").evaluate(t,{}),s=a.get(\"line-cap\"),l=a.get(\"line-miter-limit\"),c=a.get(\"line-round-limit\");this.lineClips=this.lineFeatureClips(t);for(const r of e)this.addLine(r,t,o,s,l,c);this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)}addLine(t,e,r,n,i,a){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,this.lineClips){this.lineClipsArray.push(this.lineClips);for(let e=0;e<t.length-1;e++)this.totalDistance+=t[e].dist(t[e+1]);this.updateScaledDistance(),this.maxLineLength=Math.max(this.maxLineLength,this.totalDistance)}const o=\"Polygon\"===ec[e.type];let s=t.length;for(;s>=2&&t[s-1].equals(t[s-2]);)s--;let l=0;for(;l<s-1&&t[l].equals(t[l+1]);)l++;if(s<(o?3:2))return;\"bevel\"===r&&(i=1.05);const c=this.overscaling<=16?15*Uo/(512*this.overscaling):0,u=this.segments.prepareSegment(10*s,this.layoutVertexArray,this.indexArray);let h,f,p,d,m;this.e1=this.e2=-1,o&&(h=t[s-2],m=t[l].sub(h)._unit()._perp());for(let e=l;e<s;e++){if(p=e===s-1?o?t[l+1]:void 0:t[e+1],p&&t[e].equals(p))continue;m&&(d=m),h&&(f=h),h=t[e],m=p?p.sub(h)._unit()._perp():d,d=d||m;let g=d.add(m);0===g.x&&0===g.y||g._unit();const y=d.x*m.x+d.y*m.y,v=g.x*m.x+g.y*m.y,x=0!==v?1/v:1/0,_=2*Math.sqrt(2-2*v),b=v<rc&&f&&p,w=d.x*m.y-d.y*m.x>0;if(b&&e>l){const t=h.dist(f);if(t>2*c){const e=h.sub(h.sub(f)._mult(c/t)._round());this.updateDistance(f,e),this.addCurrentVertex(e,d,0,0,u),f=e}}const T=f&&p;let k=T?r:o?\"butt\":n;if(T&&\"round\"===k&&(x<a?k=\"miter\":x<=2&&(k=\"fakeround\")),\"miter\"===k&&x>i&&(k=\"bevel\"),\"bevel\"===k&&(x>2&&(k=\"flipbevel\"),x<i&&(k=\"miter\")),f&&this.updateDistance(f,h),\"miter\"===k)g._mult(x),this.addCurrentVertex(h,g,0,0,u);else if(\"flipbevel\"===k){if(x>100)g=m.mult(-1);else{const t=x*d.add(m).mag()/d.sub(m).mag();g._perp()._mult(t*(w?-1:1))}this.addCurrentVertex(h,g,0,0,u),this.addCurrentVertex(h,g.mult(-1),0,0,u)}else if(\"bevel\"===k||\"fakeround\"===k){const t=-Math.sqrt(x*x-1),e=w?t:0,r=w?0:t;if(f&&this.addCurrentVertex(h,d,e,r,u),\"fakeround\"===k){const t=Math.round(180*_/Math.PI/20);for(let e=1;e<t;e++){let r=e/t;if(.5!==r){const t=r-.5;r+=r*t*(r-1)*((1.0904+y*(y*(3.55645-1.43519*y)-3.2452))*t*t+(.848013+y*(.215638*y-1.06021)))}const n=m.sub(d)._mult(r)._add(d)._unit()._mult(w?-1:1);this.addHalfVertex(h,n.x,n.y,!1,w,0,u)}}p&&this.addCurrentVertex(h,m,-e,-r,u)}else if(\"butt\"===k)this.addCurrentVertex(h,g,0,0,u);else if(\"square\"===k){const t=f?1:-1;this.addCurrentVertex(h,g,t,t,u)}else\"round\"===k&&(f&&(this.addCurrentVertex(h,d,0,0,u),this.addCurrentVertex(h,d,1,1,u,!0)),p&&(this.addCurrentVertex(h,m,-1,-1,u,!0),this.addCurrentVertex(h,m,0,0,u)));if(b&&e<s-1){const t=h.dist(p);if(t>2*c){const e=h.add(p.sub(h)._mult(c/t)._round());this.updateDistance(h,e),this.addCurrentVertex(e,m,0,0,u),h=e}}}}addCurrentVertex(t,e,r,n,i,a=!1){const o=e.x+e.y*r,s=e.y-e.x*r,l=-e.x+e.y*n,c=-e.y-e.x*n;this.addHalfVertex(t,o,s,a,!1,r,i),this.addHalfVertex(t,l,c,a,!0,-n,i),this.distance>nc/2&&0===this.totalDistance&&(this.distance=0,this.updateScaledDistance(),this.addCurrentVertex(t,e,r,n,i,a))}addHalfVertex({x:t,y:e},r,n,i,a,o,s){const l=.5*(this.lineClips?this.scaledDistance*(nc-1):this.scaledDistance);if(this.layoutVertexArray.emplaceBack((t<<1)+(i?1:0),(e<<1)+(a?1:0),Math.round(63*r)+128,Math.round(63*n)+128,1+(0===o?0:o<0?-1:1)|(63&l)<<2,l>>6),this.lineClips){const t=(this.scaledDistance-this.lineClips.start)/(this.lineClips.end-this.lineClips.start);this.layoutVertexArray2.emplaceBack(t,this.lineClipsArray.length)}const c=s.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,c),s.primitiveLength++),a?this.e2=c:this.e1=c}updateScaledDistance(){this.scaledDistance=this.lineClips?this.lineClips.start+(this.lineClips.end-this.lineClips.start)*this.distance/this.totalDistance:this.distance}updateDistance(t,e){this.distance+=t.dist(e),this.updateScaledDistance()}}let ac;Mi(\"LineBucket\",ic,{omit:[\"layers\",\"patternFeatures\"]});let oc;var sc={get paint(){return oc=oc||new ia({\"line-opacity\":new ta(Z.paint_line[\"line-opacity\"]),\"line-color\":new ta(Z.paint_line[\"line-color\"]),\"line-translate\":new Qi(Z.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Qi(Z.paint_line[\"line-translate-anchor\"]),\"line-width\":new ta(Z.paint_line[\"line-width\"]),\"line-gap-width\":new ta(Z.paint_line[\"line-gap-width\"]),\"line-offset\":new ta(Z.paint_line[\"line-offset\"]),\"line-blur\":new ta(Z.paint_line[\"line-blur\"]),\"line-dasharray\":new ra(Z.paint_line[\"line-dasharray\"]),\"line-pattern\":new ea(Z.paint_line[\"line-pattern\"]),\"line-gradient\":new na(Z.paint_line[\"line-gradient\"])})},get layout(){return ac=ac||new ia({\"line-cap\":new Qi(Z.layout_line[\"line-cap\"]),\"line-join\":new ta(Z.layout_line[\"line-join\"]),\"line-miter-limit\":new Qi(Z.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Qi(Z.layout_line[\"line-round-limit\"]),\"line-sort-key\":new ta(Z.layout_line[\"line-sort-key\"])})}};class lc extends ta{possiblyEvaluate(t,e){return e=new Hi(Math.floor(e.zoom),{now:e.now,fadeDuration:e.fadeDuration,zoomHistory:e.zoomHistory,transition:e.transition}),super.possiblyEvaluate(t,e)}evaluate(t,e,r,n){return e=y({},e,{zoom:Math.floor(e.zoom)}),super.evaluate(t,e,r,n)}}let cc;class uc extends oa{constructor(t){super(t,sc),this.gradientVersion=0,cc||(cc=new lc(sc.paint.properties[\"line-width\"].specification),cc.useIntegerZoom=!0)}_handleSpecialPaintPropertyUpdate(t){if(\"line-gradient\"===t){const t=this.gradientExpression();!function(t){return void 0!==t._styleExpression}(t)?this.stepInterpolant=!1:this.stepInterpolant=t._styleExpression.expression instanceof Ae,this.gradientVersion=(this.gradientVersion+1)%Number.MAX_SAFE_INTEGER}}gradientExpression(){return this._transitionablePaint._values[\"line-gradient\"].value.expression}recalculate(t,e){super.recalculate(t,e),this.paint._values[\"line-floorwidth\"]=cc.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,t)}createBucket(t){return new ic(t)}queryRadius(t){const e=t,r=hc(as(\"line-width\",this,e),as(\"line-gap-width\",this,e)),n=as(\"line-offset\",this,e);return r/2+Math.abs(n)+os(this.paint.get(\"line-translate\"))}queryIntersectsFeature(t,e,r,n,i,o,s){const l=ss(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*hc(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){const r=[];for(let n=0;n<t.length;n++){const i=t[n],o=[];for(let t=0;t<i.length;t++){const r=i[t-1],n=i[t],s=i[t+1],l=0===t?new a(0,0):n.sub(r)._unit()._perp(),c=t===i.length-1?new a(0,0):s.sub(n)._unit()._perp(),u=l._add(c)._unit(),h=u.x*c.x+u.y*c.y;0!==h&&u._mult(1/h),o.push(u._mult(e)._add(n))}r.push(o)}return r}(n,u*s)),function(t,e,r){for(let n=0;n<e.length;n++){const i=e[n];if(t.length>=3)for(let e=0;e<i.length;e++)if(ns(t,i[e]))return!0;if(Jo(t,i,r))return!0}return!1}(l,n,c)}isTileClipped(){return!0}}function hc(t,e){return e>0?e+2*t:t}const fc=ua([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),pc=ua([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4);ua([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4);const dc=ua([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"},{name:\"a_box_real\",components:2,type:\"Int16\"}]);ua([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]);const mc=ua([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4),gc=ua([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);function yc(t,e,r){return t.sections.forEach((t=>{t.text=function(t,e,r){const n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),qi.applyArabicShaping&&(t=qi.applyArabicShaping(t)),t}(t.text,e,r)})),t}ua([{name:\"triangle\",components:3,type:\"Uint16\"}]),ua([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),ua([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"collisionCircleDiameter\"},{type:\"Uint16\",name:\"textAnchorOffsetStartIndex\"},{type:\"Uint16\",name:\"textAnchorOffsetEndIndex\"}]),ua([{type:\"Float32\",name:\"offsetX\"}]),ua([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]),ua([{type:\"Uint16\",name:\"textAnchor\"},{type:\"Float32\",components:2,name:\"textOffset\"}]);const vc={\"!\":\"\ufe15\",\"#\":\"\uff03\",$:\"\uff04\",\"%\":\"\uff05\",\"&\":\"\uff06\",\"(\":\"\ufe35\",\")\":\"\ufe36\",\"*\":\"\uff0a\",\"+\":\"\uff0b\",\",\":\"\ufe10\",\"-\":\"\ufe32\",\".\":\"\u30fb\",\"/\":\"\uff0f\",\":\":\"\ufe13\",\";\":\"\ufe14\",\"<\":\"\ufe3f\",\"=\":\"\uff1d\",\">\":\"\ufe40\",\"?\":\"\ufe16\",\"@\":\"\uff20\",\"[\":\"\ufe47\",\"\\\\\":\"\uff3c\",\"]\":\"\ufe48\",\"^\":\"\uff3e\",_:\"\ufe33\",\"`\":\"\uff40\",\"{\":\"\ufe37\",\"|\":\"\u2015\",\"}\":\"\ufe38\",\"~\":\"\uff5e\",\"\u00a2\":\"\uffe0\",\"\u00a3\":\"\uffe1\",\"\u00a5\":\"\uffe5\",\"\u00a6\":\"\uffe4\",\"\u00ac\":\"\uffe2\",\"\u00af\":\"\uffe3\",\"\u2013\":\"\ufe32\",\"\u2014\":\"\ufe31\",\"\u2018\":\"\ufe43\",\"\u2019\":\"\ufe44\",\"\u201c\":\"\ufe41\",\"\u201d\":\"\ufe42\",\"\u2026\":\"\ufe19\",\"\u2027\":\"\u30fb\",\"\u20a9\":\"\uffe6\",\"\u3001\":\"\ufe11\",\"\u3002\":\"\ufe12\",\"\u3008\":\"\ufe3f\",\"\u3009\":\"\ufe40\",\"\u300a\":\"\ufe3d\",\"\u300b\":\"\ufe3e\",\"\u300c\":\"\ufe41\",\"\u300d\":\"\ufe42\",\"\u300e\":\"\ufe43\",\"\u300f\":\"\ufe44\",\"\u3010\":\"\ufe3b\",\"\u3011\":\"\ufe3c\",\"\u3014\":\"\ufe39\",\"\u3015\":\"\ufe3a\",\"\u3016\":\"\ufe17\",\"\u3017\":\"\ufe18\",\"\uff01\":\"\ufe15\",\"\uff08\":\"\ufe35\",\"\uff09\":\"\ufe36\",\"\uff0c\":\"\ufe10\",\"\uff0d\":\"\ufe32\",\"\uff0e\":\"\u30fb\",\"\uff1a\":\"\ufe13\",\"\uff1b\":\"\ufe14\",\"\uff1c\":\"\ufe3f\",\"\uff1e\":\"\ufe40\",\"\uff1f\":\"\ufe16\",\"\uff3b\":\"\ufe47\",\"\uff3d\":\"\ufe48\",\"\uff3f\":\"\ufe33\",\"\uff5b\":\"\ufe37\",\"\uff5c\":\"\u2015\",\"\uff5d\":\"\ufe38\",\"\uff5f\":\"\ufe35\",\"\uff60\":\"\ufe36\",\"\uff61\":\"\ufe12\",\"\uff62\":\"\ufe41\",\"\uff63\":\"\ufe42\"};var xc=24,_c=wc,bc={read:function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},write:function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,m=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*m}};function wc(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}wc.Varint=0,wc.Fixed64=1,wc.Bytes=2,wc.Fixed32=5;var Tc=4294967296,kc=1/Tc,Ac=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf-8\");function Mc(t){return t.type===wc.Bytes?t.readVarint()+t.pos:t.pos+1}function Sc(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function Ec(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function Cc(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function Lc(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function Ic(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function Pc(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function zc(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function Oc(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function Dc(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function Rc(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function Fc(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function Bc(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function Nc(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function jc(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}wc.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=Bc(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=jc(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=Bc(this.buf,this.pos)+Bc(this.buf,this.pos+4)*Tc;return this.pos+=8,t},readSFixed64:function(){var t=Bc(this.buf,this.pos)+jc(this.buf,this.pos+4)*Tc;return this.pos+=8,t},readFloat:function(){var t=bc.read(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=bc.read(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return Sc(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return Sc(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return Sc(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return Sc(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return Sc(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return Sc(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&Ac?function(t,e,r){return Ac.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==wc.Bytes)return t.push(this.readVarint(e));var r=Mc(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==wc.Bytes)return t.push(this.readSVarint());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==wc.Bytes)return t.push(this.readBoolean());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==wc.Bytes)return t.push(this.readFloat());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==wc.Bytes)return t.push(this.readDouble());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==wc.Bytes)return t.push(this.readFixed32());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==wc.Bytes)return t.push(this.readSFixed32());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==wc.Bytes)return t.push(this.readFixed64());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==wc.Bytes)return t.push(this.readSFixed64());var e=Mc(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===wc.Varint)for(;this.buf[this.pos++]>127;);else if(e===wc.Bytes)this.pos=this.readVarint()+this.pos;else if(e===wc.Fixed32)this.pos+=4;else{if(e!==wc.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),Nc(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),Nc(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),Nc(this.buf,-1&t,this.pos),Nc(this.buf,Math.floor(t*kc),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),Nc(this.buf,-1&t,this.pos),Nc(this.buf,Math.floor(t*kc),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&Ec(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),bc.write(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),bc.write(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&Ec(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,wc.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,Cc,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,Lc,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,zc,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,Ic,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,Pc,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,Oc,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,Dc,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,Rc,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,Fc,e)},writeBytesField:function(t,e){this.writeTag(t,wc.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,wc.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,wc.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,wc.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,wc.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,wc.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,wc.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,wc.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,wc.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,wc.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var Uc=r(_c);const Vc=3;function qc(t,e,r){1===t&&r.readMessage(Hc,e)}function Hc(t,e,r){if(3===t){const{id:t,bitmap:n,width:i,height:a,left:o,top:s,advance:l}=r.readMessage(Gc,{});e.push({id:t,bitmap:new Cs({width:i+2*Vc,height:a+2*Vc},n),metrics:{width:i,height:a,left:o,top:s,advance:l}})}}function Gc(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}const Zc=Vc;function Wc(t){let e=0,r=0;for(const n of t)e+=n.w*n.h,r=Math.max(r,n.w);t.sort(((t,e)=>e.h-t.h));const n=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}];let i=0,a=0;for(const e of t)for(let t=n.length-1;t>=0;t--){const r=n[t];if(!(e.w>r.w||e.h>r.h)){if(e.x=r.x,e.y=r.y,a=Math.max(a,e.y+e.h),i=Math.max(i,e.x+e.w),e.w===r.w&&e.h===r.h){const e=n.pop();t<n.length&&(n[t]=e)}else e.h===r.h?(r.x+=e.w,r.w-=e.w):e.w===r.w?(r.y+=e.h,r.h-=e.h):(n.push({x:r.x+e.w,y:r.y,w:r.w-e.w,h:e.h}),r.y+=e.h,r.h-=e.h);break}}return{w:i,h:a,fill:e/(i*a)||0}}const Yc=1;class Xc{constructor(t,{pixelRatio:e,version:r,stretchX:n,stretchY:i,content:a,textFitWidth:o,textFitHeight:s}){this.paddedRect=t,this.pixelRatio=e,this.stretchX=n,this.stretchY=i,this.content=a,this.version=r,this.textFitWidth=o,this.textFitHeight=s}get tl(){return[this.paddedRect.x+Yc,this.paddedRect.y+Yc]}get br(){return[this.paddedRect.x+this.paddedRect.w-Yc,this.paddedRect.y+this.paddedRect.h-Yc]}get tlbr(){return this.tl.concat(this.br)}get displaySize(){return[(this.paddedRect.w-2*Yc)/this.pixelRatio,(this.paddedRect.h-2*Yc)/this.pixelRatio]}}class $c{constructor(t,e){const r={},n={};this.haveRenderCallbacks=[];const i=[];this.addImages(t,r,i),this.addImages(e,n,i);const{w:a,h:o}=Wc(i),s=new Ls({width:a||1,height:o||1});for(const e in t){const n=t[e],i=r[e].paddedRect;Ls.copy(n.data,s,{x:0,y:0},{x:i.x+Yc,y:i.y+Yc},n.data)}for(const t in e){const r=e[t],i=n[t].paddedRect,a=i.x+Yc,o=i.y+Yc,l=r.data.width,c=r.data.height;Ls.copy(r.data,s,{x:0,y:0},{x:a,y:o},r.data),Ls.copy(r.data,s,{x:0,y:c-1},{x:a,y:o-1},{width:l,height:1}),Ls.copy(r.data,s,{x:0,y:0},{x:a,y:o+c},{width:l,height:1}),Ls.copy(r.data,s,{x:l-1,y:0},{x:a-1,y:o},{width:1,height:c}),Ls.copy(r.data,s,{x:0,y:0},{x:a+l,y:o},{width:1,height:c})}this.image=s,this.iconPositions=r,this.patternPositions=n}addImages(t,e,r){for(const n in t){const i=t[n],a={x:0,y:0,w:i.data.width+2*Yc,h:i.data.height+2*Yc};r.push(a),e[n]=new Xc(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}}patchUpdatedImages(t,e){t.dispatchRenderCallbacks(this.haveRenderCallbacks);for(const r in t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)}patchUpdatedImage(t,e,r){if(!t||!e)return;if(t.version===e.version)return;t.version=e.version;const[n,i]=t.tl;r.update(e.data,void 0,{x:n,y:i})}}var Jc;Mi(\"ImagePosition\",Xc),Mi(\"ImageAtlas\",$c),t.ai=void 0,(Jc=t.ai||(t.ai={}))[Jc.none=0]=\"none\",Jc[Jc.horizontal=1]=\"horizontal\",Jc[Jc.vertical=2]=\"vertical\",Jc[Jc.horizontalOnly=3]=\"horizontalOnly\";const Kc=-17;class Qc{constructor(){this.scale=1,this.fontStack=\"\",this.imageName=null}static forText(t,e){const r=new Qc;return r.scale=t||1,r.fontStack=e,r}static forImage(t){const e=new Qc;return e.imageName=t,e}}class tu{constructor(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null}static fromFeature(t,e){const r=new tu;for(let n=0;n<t.sections.length;n++){const i=t.sections[n];i.image?r.addImageSection(i):r.addTextSection(i,e)}return r}length(){return this.text.length}getSection(t){return this.sections[this.sectionIndex[t]]}getSectionIndex(t){return this.sectionIndex[t]}getCharCode(t){return this.text.charCodeAt(t)}verticalizePunctuation(){this.text=function(t){let e=\"\";for(let r=0;r<t.length;r++){const n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&Bi(n)&&!vc[t[r+1]]||i&&Bi(i)&&!vc[t[r-1]]||!vc[t[r]]?e+=t[r]:e+=vc[t[r]]}return e}(this.text)}trim(){let t=0;for(let e=0;e<this.text.length&&ru[this.text.charCodeAt(e)];e++)t++;let e=this.text.length;for(let r=this.text.length-1;r>=0&&r>=t&&ru[this.text.charCodeAt(r)];r--)e--;this.text=this.text.substring(t,e),this.sectionIndex=this.sectionIndex.slice(t,e)}substring(t,e){const r=new tu;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r}toString(){return this.text}getMaxScale(){return this.sectionIndex.reduce(((t,e)=>Math.max(t,this.sections[e].scale)),0)}addTextSection(t,e){this.text+=t.text,this.sections.push(Qc.forText(t.scale,t.fontStack||e));const r=this.sections.length-1;for(let e=0;e<t.text.length;++e)this.sectionIndex.push(r)}addImageSection(t){const e=t.image?t.image.name:\"\";if(0===e.length)return void T(\"Can't add FormattedSection with an empty image.\");const r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(Qc.forImage(e)),this.sectionIndex.push(this.sections.length-1)):T(\"Reached maximum number of images 6401\")}getNextImageSectionCharCode(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)}}function eu(e,r,n,i,a,o,s,l,c,u,h,f,p,d,m){const g=tu.fromFeature(e,a);let y;f===t.ai.vertical&&g.verticalizePunctuation();const{processBidirectionalText:v,processStyledBidirectionalText:x}=qi;if(v&&1===g.sections.length){y=[];const t=v(g.toString(),uu(g,u,o,r,i,d));for(const e of t){const t=new tu;t.text=e,t.sections=g.sections;for(let r=0;r<e.length;r++)t.sectionIndex.push(0);y.push(t)}}else if(x){y=[];const t=x(g.text,g.sectionIndex,uu(g,u,o,r,i,d));for(const e of t){const t=new tu;t.text=e[0],t.sectionIndex=e[1],t.sections=g.sections,y.push(t)}}else y=function(t,e){const r=[],n=t.text;let i=0;for(const n of e)r.push(t.substring(i,n)),i=n;return i<n.length&&r.push(t.substring(i,n.length)),r}(g,uu(g,u,o,r,i,d));const _=[],b={positionedLines:_,text:g.toString(),top:h[1],bottom:h[1],left:h[0],right:h[0],writingMode:f,iconsInText:!1,verticalizable:!1};return function(e,r,n,i,a,o,s,l,c,u,h,f){let p=0,d=Kc,m=0,g=0;const y=\"right\"===l?1:\"left\"===l?0:.5;let v=0;for(const s of a){s.trim();const a=s.getMaxScale(),l=(a-1)*xc,x={positionedGlyphs:[],lineOffset:0};e.positionedLines[v]=x;const _=x.positionedGlyphs;let b=0;if(!s.length()){d+=o,++v;continue}for(let o=0;o<s.length();o++){const m=s.getSection(o),g=s.getSectionIndex(o),y=s.getCharCode(o);let v=0,x=null,w=null,T=null,k=xc;const A=!(c===t.ai.horizontal||!h&&!Fi(y)||h&&(ru[y]||Ni(y)));if(m.imageName){const t=i[m.imageName];if(!t)continue;T=m.imageName,e.iconsInText=e.iconsInText||!0,w=t.paddedRect;const r=t.displaySize;m.scale=m.scale*xc/f,x={width:r[0],height:r[1],left:Yc,top:-Zc,advance:A?r[1]:r[0]},v=l+(xc-r[1]*m.scale),k=x.advance;const n=A?r[0]*m.scale-xc*a:r[1]*m.scale-xc*a;n>0&&n>b&&(b=n)}else{const t=n[m.fontStack],e=t&&t[y];if(e&&e.rect)w=e.rect,x=e.metrics;else{const t=r[m.fontStack],e=t&&t[y];if(!e)continue;x=e.metrics}v=(a-m.scale)*xc}A?(e.verticalizable=!0,_.push({glyph:y,imageName:T,x:p,y:d+v,vertical:A,scale:m.scale,fontStack:m.fontStack,sectionIndex:g,metrics:x,rect:w}),p+=k*m.scale+u):(_.push({glyph:y,imageName:T,x:p,y:d+v,vertical:A,scale:m.scale,fontStack:m.fontStack,sectionIndex:g,metrics:x,rect:w}),p+=x.advance*m.scale+u)}if(0!==_.length){const t=p-u;m=Math.max(t,m),fu(_,0,_.length-1,y,b)}p=0;const w=o*a+b;x.lineOffset=Math.max(b,l),d+=w,g=Math.max(w,g),++v}const x=d-Kc,{horizontalAlign:_,verticalAlign:b}=hu(s);(function(t,e,r,n,i,a,o,s,l){const c=(e-r)*i;let u=0;u=a!==o?-s*n-Kc:(-n*l+.5)*o;for(const e of t)for(const t of e.positionedGlyphs)t.x+=c,t.y+=u})(e.positionedLines,y,_,b,m,g,o,x,a.length),e.top+=-b*x,e.bottom=e.top+x,e.left+=-_*m,e.right=e.left+m}(b,r,n,i,y,s,l,c,f,u,p,m),!function(t){for(const e of t)if(0!==e.positionedGlyphs.length)return!1;return!0}(_)&&b}const ru={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},nu={10:!0,32:!0,38:!0,41:!0,43:!0,45:!0,47:!0,173:!0,183:!0,8203:!0,8208:!0,8211:!0,8231:!0},iu={40:!0};function au(t,e,r,n,i,a){if(e.imageName){const t=n[e.imageName];return t?t.displaySize[0]*e.scale*xc/a+i:0}{const n=r[e.fontStack],a=n&&n[t];return a?a.metrics.advance*e.scale+i:0}}function ou(t,e,r,n){const i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function su(t,e,r){let n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function lu(t,e,r,n,i,a){let o=null,s=ou(e,r,i,a);for(const t of n){const n=ou(e-t.x,r,i,a)+t.badness;n<=s&&(o=t,s=n)}return{index:t,x:e,priorBreak:o,badness:s}}function cu(t){return t?cu(t.priorBreak).concat(t.index):[]}function uu(t,e,r,n,i,a){if(!t)return[];const o=[],s=function(t,e,r,n,i,a){let o=0;for(let r=0;r<t.length();r++){const s=t.getSection(r);o+=au(t.getCharCode(r),s,n,i,e,a)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,i,a),l=t.text.indexOf(\"\u200b\")>=0;let c=0;for(let r=0;r<t.length();r++){const h=t.getSection(r),f=t.getCharCode(r);if(ru[f]||(c+=au(f,h,n,i,e,a)),r<t.length()-1){const e=!((u=f)<11904||!(zi[\"Bopomofo Extended\"](u)||zi.Bopomofo(u)||zi[\"CJK Compatibility Forms\"](u)||zi[\"CJK Compatibility Ideographs\"](u)||zi[\"CJK Compatibility\"](u)||zi[\"CJK Radicals Supplement\"](u)||zi[\"CJK Strokes\"](u)||zi[\"CJK Symbols and Punctuation\"](u)||zi[\"CJK Unified Ideographs Extension A\"](u)||zi[\"CJK Unified Ideographs\"](u)||zi[\"Enclosed CJK Letters and Months\"](u)||zi[\"Halfwidth and Fullwidth Forms\"](u)||zi.Hiragana(u)||zi[\"Ideographic Description Characters\"](u)||zi[\"Kangxi Radicals\"](u)||zi[\"Katakana Phonetic Extensions\"](u)||zi.Katakana(u)||zi[\"Vertical Forms\"](u)||zi[\"Yi Radicals\"](u)||zi[\"Yi Syllables\"](u)));(nu[f]||e||h.imageName||r!==t.length()-2&&iu[t.getCharCode(r+1)])&&o.push(lu(r+1,c,s,o,su(f,t.getCharCode(r+1),e&&l),!1))}}var u;return cu(lu(t.length(),c,s,o,0,!0))}function hu(t){let e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function fu(t,e,r,n,i){if(!n&&!i)return;const a=t[r],o=a.metrics.advance*a.scale,s=(t[r].x+o)*n;for(let n=e;n<=r;n++)t[n].x-=s,t[n].y+=i}function pu(t,e,r){const{horizontalAlign:n,verticalAlign:i}=hu(r),a=e[0],o=e[1],s=a-t.displaySize[0]*n,l=s+t.displaySize[0],c=o-t.displaySize[1]*i;return{image:t,top:c,bottom:c+t.displaySize[1],left:s,right:l}}function du(t){var e,r;let n=t.left,i=t.top,a=t.right-n,o=t.bottom-i;const s=t.image.content[2]-t.image.content[0],l=t.image.content[3]-t.image.content[1],c=null!==(e=t.image.textFitWidth)&&void 0!==e?e:\"stretchOrShrink\",u=null!==(r=t.image.textFitHeight)&&void 0!==r?r:\"stretchOrShrink\",h=s/l;if(\"proportional\"===u){if(\"stretchOnly\"===c&&a/o<h||\"proportional\"===c){const t=Math.ceil(o*h);n*=t/a,a=t}}else if(\"proportional\"===c&&\"stretchOnly\"===u&&0!==h&&a/o>h){const t=Math.ceil(a/h);i*=t/o,o=t}return{x1:n,y1:i,x2:n+a,y2:i+o}}function mu(t,e,r,n,i,a){const o=t.image;let s;if(o.content){const t=o.content,e=o.pixelRatio||1;s=[t[0]/e,t[1]/e,o.displaySize[0]-t[2]/e,o.displaySize[1]-t[3]/e]}const l=e.left*a,c=e.right*a;let u,h,f,p;\"width\"===r||\"both\"===r?(p=i[0]+l-n[3],h=i[0]+c+n[1]):(p=i[0]+(l+c-o.displaySize[0])/2,h=p+o.displaySize[0]);const d=e.top*a,m=e.bottom*a;return\"height\"===r||\"both\"===r?(u=i[1]+d-n[0],f=i[1]+m+n[2]):(u=i[1]+(d+m-o.displaySize[1])/2,f=u+o.displaySize[1]),{image:o,top:u,right:h,bottom:f,left:p,collisionPadding:s}}const gu=255,yu=128,vu=gu*yu;function xu(t,e){const{expression:r}=e;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Hi(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};{const{zoomStops:e,interpolationType:n}=r;let i=0;for(;i<e.length&&e[i]<=t;)i++;i=Math.max(0,i-1);let a=i;for(;a<e.length&&e[a]<t+1;)a++;a=Math.min(e.length-1,a);const o=e[i],s=e[a];return\"composite\"===r.kind?{kind:\"composite\",minZoom:o,maxZoom:s,interpolationType:n}:{kind:\"camera\",minZoom:o,maxZoom:s,minSize:r.evaluate(new Hi(o)),maxSize:r.evaluate(new Hi(s)),interpolationType:n}}}function _u(t,e,r){let n=\"never\";const i=t.get(e);return i?n=i:t.get(r)&&(n=\"always\"),n}const bu=Tl.VectorTileFeature.types,wu=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Tu(t,e,r,n,i,a,o,s,l,c,u,h,f){const p=s?Math.min(vu,Math.round(s[0])):0,d=s?Math.min(vu,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,(p<<1)+(l?1:0),d,16*c,16*u,256*h,256*f)}function ku(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function Au(t){for(const e of t.sections)if(Vi(e.text))return!0;return!1}class Mu{constructor(t){this.layoutVertexArray=new to,this.indexArray=new ao,this.programConfigurations=t,this.segments=new ho,this.dynamicLayoutVertexArray=new eo,this.opacityVertexArray=new ro,this.hasVisibleVertices=!1,this.placedSymbolArray=new Ba}isEmpty(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length}upload(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,fc.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,pc.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,wu,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))}destroy(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())}}Mi(\"SymbolBuffers\",Mu);class Su{constructor(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new ho,this.collisionVertexArray=new io}upload(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,dc.members,!0)}destroy(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())}}Mi(\"CollisionBuffers\",Su);class Eu{constructor(e){this.collisionBoxArray=e.collisionBoxArray,this.zoom=e.zoom,this.overscaling=e.overscaling,this.layers=e.layers,this.layerIds=this.layers.map((t=>t.id)),this.index=e.index,this.pixelRatio=e.pixelRatio,this.sourceLayerIndex=e.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=ps([]),this.placementViewportMatrix=ps([]);const r=this.layers[0]._unevaluatedLayout._values;this.textSizeData=xu(this.zoom,r[\"text-size\"]),this.iconSizeData=xu(this.zoom,r[\"icon-size\"]);const n=this.layers[0].layout,i=n.get(\"symbol-sort-key\"),a=n.get(\"symbol-z-order\");this.canOverlap=\"never\"!==_u(n,\"text-overlap\",\"text-allow-overlap\")||\"never\"!==_u(n,\"icon-overlap\",\"icon-allow-overlap\")||n.get(\"text-ignore-placement\")||n.get(\"icon-ignore-placement\"),this.sortFeaturesByKey=\"viewport-y\"!==a&&!i.isConstant();const o=\"viewport-y\"===a||\"auto\"===a&&!this.sortFeaturesByKey;this.sortFeaturesByY=o&&this.canOverlap,\"point\"===n.get(\"symbol-placement\")&&(this.writingModes=n.get(\"text-writing-mode\").map((e=>t.ai[e]))),this.stateDependentLayerIds=this.layers.filter((t=>t.isStateDependent())).map((t=>t.id)),this.sourceID=e.sourceID}createArrays(){this.text=new Mu(new Bo(this.layers,this.zoom,(t=>/^text/.test(t)))),this.icon=new Mu(new Bo(this.layers,this.zoom,(t=>/^icon/.test(t)))),this.glyphOffsetArray=new Ua,this.lineVertexArray=new Va,this.symbolInstances=new ja,this.textAnchorOffsets=new Ha}calculateGlyphDependencies(t,e,r,n,i){for(let a=0;a<t.length;a++)if(e[t.charCodeAt(a)]=!0,(r||n)&&i){const r=vc[t.charAt(a)];r&&(e[r.charCodeAt(0)]=!0)}}populate(e,r,n){const i=this.layers[0],a=i.layout,o=a.get(\"text-font\"),s=a.get(\"text-field\"),l=a.get(\"icon-image\"),c=(\"constant\"!==s.value.kind||s.value.value instanceof Kt&&!s.value.value.isEmpty()||s.value.value.toString().length>0)&&(\"constant\"!==o.value.kind||o.value.value.length>0),u=\"constant\"!==l.value.kind||!!l.value.value||Object.keys(l.parameters).length>0,h=a.get(\"symbol-sort-key\");if(this.features=[],!c&&!u)return;const f=r.iconDependencies,p=r.glyphDependencies,d=r.availableImages,m=new Hi(this.zoom);for(const{feature:r,id:s,index:l,sourceLayerIndex:g}of e){const e=i._featureFilter.needGeometry,y=Go(r,e);if(!i._featureFilter.filter(m,y,n))continue;let v,x;if(e||(y.geometry=Ho(r)),c){const t=i.getValueAndResolveTokens(\"text-field\",y,n,d),e=Kt.factory(t),r=this.hasRTLText=this.hasRTLText||Au(e);(!r||\"unavailable\"===qi.getRTLTextPluginStatus()||r&&qi.isParsed())&&(v=yc(e,i,y))}if(u){const t=i.getValueAndResolveTokens(\"icon-image\",y,n,d);x=t instanceof re?t:re.fromString(t)}if(!v&&!x)continue;const _=this.sortFeaturesByKey?h.evaluate(y,{},n):void 0,b={id:s,text:v,icon:x,index:l,sourceLayerIndex:g,geometry:y.geometry,properties:r.properties,type:bu[r.type],sortKey:_};if(this.features.push(b),x&&(f[x.name]=!0),v){const e=o.evaluate(y,{},n).join(\",\"),r=\"viewport\"!==a.get(\"text-rotation-alignment\")&&\"point\"!==a.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(t.ai.vertical)>=0;for(const t of v.sections)if(t.image)f[t.image.name]=!0;else{const n=Oi(v.toString()),i=t.fontStack||e,a=p[i]=p[i]||{};this.calculateGlyphDependencies(t.text,a,r,this.allowVerticalPlacement,n)}}}\"line\"===a.get(\"symbol-placement\")&&(this.features=function(t){const e={},r={},n=[];let i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){const a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){const a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){const n=r?e[0][e[0].length-1]:e[0][0];return`${t}:${n.x}:${n.y}`}for(let c=0;c<t.length;c++){const u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(!f){a(c);continue}const p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){const t=s(p,d,h),i=o(p,d,n[t].geometry);delete e[p],delete r[d],r[l(f,n[i].geometry,!0)]=i,n[t].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}return n.filter((t=>t.geometry))}(this.features)),this.sortFeaturesByKey&&this.features.sort(((t,e)=>t.sortKey-e.sortKey))}update(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))}isEmpty(){return 0===this.symbolInstances.length&&!this.hasRTLText}uploadPending(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload}upload(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0}destroyDebugData(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()}destroy(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()}addToLineVertexArray(t,e){const r=this.lineVertexArray.length;if(void 0!==t.segment){let r=t.dist(e[t.segment+1]),n=t.dist(e[t.segment]);const i={};for(let n=t.segment+1;n<e.length;n++)i[n]={x:e[n].x,y:e[n].y,tileUnitDistanceFromAnchor:r},n<e.length-1&&(r+=e[n+1].dist(e[n]));for(let r=t.segment||0;r>=0;r--)i[r]={x:e[r].x,y:e[r].y,tileUnitDistanceFromAnchor:n},r>0&&(n+=e[r-1].dist(e[r]));for(let t=0;t<e.length;t++){const e=i[t];this.lineVertexArray.emplaceBack(e.x,e.y,e.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}}addSymbols(e,r,n,i,a,o,s,l,c,u,h,f){const p=e.indexArray,d=e.layoutVertexArray,m=e.segments.prepareSegment(4*r.length,d,p,this.canOverlap?o.sortKey:void 0),g=this.glyphOffsetArray.length,y=m.vertexLength,v=this.allowVerticalPlacement&&s===t.ai.vertical?Math.PI/2:0,x=o.text&&o.text.sections;for(let t=0;t<r.length;t++){const{tl:i,tr:a,bl:s,br:c,tex:u,pixelOffsetTL:h,pixelOffsetBR:g,minFontScaleX:y,minFontScaleY:_,glyphOffset:b,isSDF:w,sectionIndex:T}=r[t],k=m.vertexLength,A=b[1];Tu(d,l.x,l.y,i.x,A+i.y,u.x,u.y,n,w,h.x,h.y,y,_),Tu(d,l.x,l.y,a.x,A+a.y,u.x+u.w,u.y,n,w,g.x,h.y,y,_),Tu(d,l.x,l.y,s.x,A+s.y,u.x,u.y+u.h,n,w,h.x,g.y,y,_),Tu(d,l.x,l.y,c.x,A+c.y,u.x+u.w,u.y+u.h,n,w,g.x,g.y,y,_),ku(e.dynamicLayoutVertexArray,l,v),p.emplaceBack(k,k+1,k+2),p.emplaceBack(k+1,k+2,k+3),m.vertexLength+=4,m.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(b[0]),t!==r.length-1&&T===r[t+1].sectionIndex||e.programConfigurations.populatePaintArrays(d.length,o,o.index,{},f,x&&x[T])}e.placedSymbolArray.emplaceBack(l.x,l.y,g,this.glyphOffsetArray.length-g,y,c,u,l.segment,n?n[0]:0,n?n[1]:0,i[0],i[1],s,0,!1,0,h)}_addCollisionDebugVertex(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))}addCollisionDebugVertices(t,e,r,n,i,o,s){const l=i.segments.prepareSegment(4,i.layoutVertexArray,i.indexArray),c=l.vertexLength,u=i.layoutVertexArray,h=i.collisionVertexArray,f=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,h,o,f,p,new a(t,e)),this._addCollisionDebugVertex(u,h,o,f,p,new a(r,e)),this._addCollisionDebugVertex(u,h,o,f,p,new a(r,n)),this._addCollisionDebugVertex(u,h,o,f,p,new a(t,n)),l.vertexLength+=4;const d=i.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4}addDebugCollisionBoxes(t,e,r,n){for(let i=t;i<e;i++){const t=this.collisionBoxArray.get(i),e=t.x1,a=t.y1,o=t.x2,s=t.y2;this.addCollisionDebugVertices(e,a,o,s,n?this.textCollisionBox:this.iconCollisionBox,t.anchorPoint,r)}}generateCollisionDebugBuffers(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new Su(no,mc.members,oo),this.iconCollisionBox=new Su(no,mc.members,oo);for(let t=0;t<this.symbolInstances.length;t++){const e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}}_deserializeCollisionBoxesForSymbol(t,e,r,n,i,a,o,s,l){const c={};for(let n=e;n<r;n++){const e=t.get(n);c.textBox={x1:e.x1,y1:e.y1,x2:e.x2,y2:e.y2,anchorPointX:e.anchorPointX,anchorPointY:e.anchorPointY},c.textFeatureIndex=e.featureIndex;break}for(let e=n;e<i;e++){const r=t.get(e);c.verticalTextBox={x1:r.x1,y1:r.y1,x2:r.x2,y2:r.y2,anchorPointX:r.anchorPointX,anchorPointY:r.anchorPointY},c.verticalTextFeatureIndex=r.featureIndex;break}for(let e=a;e<o;e++){const r=t.get(e);c.iconBox={x1:r.x1,y1:r.y1,x2:r.x2,y2:r.y2,anchorPointX:r.anchorPointX,anchorPointY:r.anchorPointY},c.iconFeatureIndex=r.featureIndex;break}for(let e=s;e<l;e++){const r=t.get(e);c.verticalIconBox={x1:r.x1,y1:r.y1,x2:r.x2,y2:r.y2,anchorPointX:r.anchorPointX,anchorPointY:r.anchorPointY},c.verticalIconFeatureIndex=r.featureIndex;break}return c}deserializeCollisionBoxes(t){this.collisionArrays=[];for(let e=0;e<this.symbolInstances.length;e++){const r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}}hasTextData(){return this.text.segments.get().length>0}hasIconData(){return this.icon.segments.get().length>0}hasDebugData(){return this.textCollisionBox&&this.iconCollisionBox}hasTextCollisionBoxData(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0}hasIconCollisionBoxData(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0}addIndicesForPlacedSymbol(t,e){const r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs;for(let e=r.vertexStartIndex;e<n;e+=4)t.indexArray.emplaceBack(e,e+1,e+2),t.indexArray.emplaceBack(e+1,e+2,e+3)}getSortedSymbolIndexes(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;const e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[];for(let t=0;t<this.symbolInstances.length;++t){a.push(t);const o=this.symbolInstances.get(t);n.push(0|Math.round(e*o.anchorX+r*o.anchorY)),i.push(o.featureIndex)}return a.sort(((t,e)=>n[t]-n[e]||i[e]-i[t])),a}addToSortKeyRanges(t,e){const r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})}sortFeatures(t){if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(const t of this.symbolInstanceIndexes){const e=this.symbolInstances.get(t);this.featureSortOrder.push(e.featureIndex),[e.rightJustifiedTextSymbolIndex,e.centerJustifiedTextSymbolIndex,e.leftJustifiedTextSymbolIndex].forEach(((t,e,r)=>{t>=0&&r.indexOf(t)===e&&this.addIndicesForPlacedSymbol(this.text,t)})),e.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,e.verticalPlacedTextSymbolIndex),e.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,e.placedIconSymbolIndex),e.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,e.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}}}let Cu;Mi(\"SymbolBucket\",Eu,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Eu.MAX_GLYPHS=65535,Eu.addDynamicAttributes=ku;let Lu;var Iu={get paint(){return Lu=Lu||new ia({\"icon-opacity\":new ta(Z.paint_symbol[\"icon-opacity\"]),\"icon-color\":new ta(Z.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new ta(Z.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new ta(Z.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new ta(Z.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Qi(Z.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Qi(Z.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new ta(Z.paint_symbol[\"text-opacity\"]),\"text-color\":new ta(Z.paint_symbol[\"text-color\"],{runtimeType:ft,getOverride:t=>t.textColor,hasOverride:t=>!!t.textColor}),\"text-halo-color\":new ta(Z.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new ta(Z.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new ta(Z.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Qi(Z.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Qi(Z.paint_symbol[\"text-translate-anchor\"])})},get layout(){return Cu=Cu||new ia({\"symbol-placement\":new Qi(Z.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Qi(Z.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Qi(Z.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new ta(Z.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Qi(Z.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Qi(Z.layout_symbol[\"icon-allow-overlap\"]),\"icon-overlap\":new Qi(Z.layout_symbol[\"icon-overlap\"]),\"icon-ignore-placement\":new Qi(Z.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Qi(Z.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Qi(Z.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new ta(Z.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Qi(Z.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Qi(Z.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new ta(Z.layout_symbol[\"icon-image\"]),\"icon-rotate\":new ta(Z.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new ta(Z.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Qi(Z.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new ta(Z.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new ta(Z.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Qi(Z.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Qi(Z.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Qi(Z.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new ta(Z.layout_symbol[\"text-field\"]),\"text-font\":new ta(Z.layout_symbol[\"text-font\"]),\"text-size\":new ta(Z.layout_symbol[\"text-size\"]),\"text-max-width\":new ta(Z.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Qi(Z.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new ta(Z.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new ta(Z.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new ta(Z.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Qi(Z.layout_symbol[\"text-variable-anchor\"]),\"text-variable-anchor-offset\":new ta(Z.layout_symbol[\"text-variable-anchor-offset\"]),\"text-anchor\":new ta(Z.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Qi(Z.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new Qi(Z.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new ta(Z.layout_symbol[\"text-rotate\"]),\"text-padding\":new Qi(Z.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Qi(Z.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new ta(Z.layout_symbol[\"text-transform\"]),\"text-offset\":new ta(Z.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Qi(Z.layout_symbol[\"text-allow-overlap\"]),\"text-overlap\":new Qi(Z.layout_symbol[\"text-overlap\"]),\"text-ignore-placement\":new Qi(Z.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Qi(Z.layout_symbol[\"text-optional\"])})}};class Pu{constructor(t){if(void 0===t.property.overrides)throw new Error(\"overrides must be provided to instantiate FormatSectionOverride class\");this.type=t.property.overrides?t.property.overrides.runtimeType:lt,this.defaultValue=t}evaluate(t){if(t.formattedSection){const e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default}eachChild(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)}outputDefined(){return!1}serialize(){return null}}Mi(\"FormatSectionOverride\",Pu,{omit:[\"defaultValue\"]});class zu extends oa{constructor(t){super(t,Iu)}recalculate(t,e){if(super.recalculate(t,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=\"map\"===this.layout.get(\"text-rotation-alignment\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){const t=this.layout.get(\"text-writing-mode\");if(t){const e=[];for(const r of t)e.indexOf(r)<0&&e.push(r);this.layout._values[\"text-writing-mode\"]=e}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()}getValueAndResolveTokens(t,e,r,n){const i=this.layout.get(t).evaluate(e,{},r,n),a=this._unevaluatedLayout._values[t];return a.isDataDriven()||kn(a.value)||!i?i:function(t,e){return e.replace(/{([^{}]+)}/g,((e,r)=>t&&r in t?String(t[r]):\"\"))}(e.properties,i)}createBucket(t){return new Eu(t)}queryRadius(){return 0}queryIntersectsFeature(){throw new Error(\"Should take a different path in FeatureIndex\")}_setPaintOverrides(){for(const t of Iu.paint.overridableProperties){if(!zu.hasPaintOverride(this.layout,t))continue;const e=this.paint.get(t),r=new Pu(e),n=new Tn(r,e.property.specification);let i=null;i=\"constant\"===e.value.kind||\"source\"===e.value.kind?new Mn(\"source\",n):new Sn(\"composite\",n,e.value.zoomStops),this.paint._values[t]=new Ji(e.property,i,e.parameters)}}_handleOverridablePaintPropertyUpdate(t,e,r){return!(!this.layout||e.isDataDriven()||r.isDataDriven())&&zu.hasPaintOverride(this.layout,t)}static hasPaintOverride(t,e){const r=t.get(\"text-field\"),n=Iu.paint.properties[e];let i=!1;const a=t=>{for(const e of t)if(n.overrides&&n.overrides.hasOverride(e))return void(i=!0)};if(\"constant\"===r.value.kind&&r.value.value instanceof Kt)a(r.value.value.sections);else if(\"source\"===r.value.kind){const t=e=>{if(!i)if(e instanceof se&&ae(e.value)===gt){const t=e.value;a(t.sections)}else e instanceof We?a(e.sections):e.eachChild(t)},e=r.value;e._styleExpression&&t(e._styleExpression.expression)}return i}}let Ou;var Du={get paint(){return Ou=Ou||new ia({\"background-color\":new Qi(Z.paint_background[\"background-color\"]),\"background-pattern\":new ra(Z.paint_background[\"background-pattern\"]),\"background-opacity\":new Qi(Z.paint_background[\"background-opacity\"])})}};class Ru extends oa{constructor(t){super(t,Du)}}let Fu;var Bu={get paint(){return Fu=Fu||new ia({\"raster-opacity\":new Qi(Z.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Qi(Z.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Qi(Z.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Qi(Z.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Qi(Z.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Qi(Z.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Qi(Z.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Qi(Z.paint_raster[\"raster-fade-duration\"])})}};class Nu extends oa{constructor(t){super(t,Bu)}}class ju extends oa{constructor(t){super(t,{}),this.onAdd=t=>{this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},this.onRemove=t=>{this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},this.implementation=t}is3D(){return\"3d\"===this.implementation.renderingMode}hasOffscreenPass(){return void 0!==this.implementation.prerender}recalculate(){}updateTransitions(){}hasTransition(){return!1}serialize(){throw new Error(\"Custom layers cannot be serialized\")}}class Uu{constructor(t){this._methodToThrottle=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=()=>{this._triggered=!1,this._methodToThrottle()})}trigger(){this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((()=>{this._triggered=!1,this._methodToThrottle()}),0))}remove(){delete this._channel,this._methodToThrottle=()=>{}}}const Vu=6371008.8;class qu{constructor(t,e){if(isNaN(t)||isNaN(e))throw new Error(`Invalid LngLat object: (${t}, ${e})`);if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")}wrap(){return new qu(g(this.lng,-180,180),this.lat)}toArray(){return[this.lng,this.lat]}toString(){return`LngLat(${this.lng}, ${this.lat})`}distanceTo(t){const e=Math.PI/180,r=this.lat*e,n=t.lat*e,i=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return Vu*Math.acos(Math.min(i,1))}static convert(t){if(t instanceof qu)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new qu(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new qu(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")}}const Hu=2*Math.PI*Vu;function Gu(t){return Hu*Math.cos(t*Math.PI/180)}function Zu(t){return(180+t)/360}function Wu(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Yu(t,e){return t/Gu(e)}function Xu(t){const e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}class $u{constructor(t,e,r=0){this.x=+t,this.y=+e,this.z=+r}static fromLngLat(t,e=0){const r=qu.convert(t);return new $u(Zu(r.lng),Wu(r.lat),Yu(e,r.lat))}toLngLat(){return new qu(360*this.x-180,Xu(this.y))}toAltitude(){return t=this.z,e=this.y,t*Gu(Xu(e));var t,e}meterInMercatorCoordinateUnits(){return 1/Hu*(t=Xu(this.y),1/Math.cos(t*Math.PI/180));var t}}function Ju(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}class Ku{constructor(t,e,r){if(t<0||t>25||r<0||r>=Math.pow(2,t)||e<0||e>=Math.pow(2,t))throw new Error(`x=${e}, y=${r}, z=${t} outside of bounds. 0<=x<${Math.pow(2,t)}, 0<=y<${Math.pow(2,t)} 0<=z<=25 `);this.z=t,this.x=e,this.y=r,this.key=eh(0,t,t,e,r)}equals(t){return this.z===t.z&&this.x===t.x&&this.y===t.y}url(t,e,r){const n=(a=this.x,o=this.y,s=this.z,l=Ju(256*a,256*(o=Math.pow(2,s)-o-1),s),c=Ju(256*(a+1),256*(o+1),s),l[0]+\",\"+l[1]+\",\"+c[0]+\",\"+c[1]),i=function(t,e,r){let n,i=\"\";for(let a=t;a>0;a--)n=1<<a-1,i+=(e&n?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);var a,o,s,l,c;return t[(this.x+this.y)%t.length].replace(/{prefix}/g,(this.x%16).toString(16)+(this.y%16).toString(16)).replace(/{z}/g,String(this.z)).replace(/{x}/g,String(this.x)).replace(/{y}/g,String(\"tms\"===r?Math.pow(2,this.z)-this.y-1:this.y)).replace(/{ratio}/g,e>1?\"@2x\":\"\").replace(/{quadkey}/g,i).replace(/{bbox-epsg-3857}/g,n)}isChildOf(t){const e=this.z-t.z;return e>0&&t.x===this.x>>e&&t.y===this.y>>e}getTilePoint(t){const e=Math.pow(2,this.z);return new a((t.x*e-this.x)*Uo,(t.y*e-this.y)*Uo)}toString(){return`${this.z}/${this.x}/${this.y}`}}class Qu{constructor(t,e){this.wrap=t,this.canonical=e,this.key=eh(t,e.z,e.z,e.x,e.y)}}class th{constructor(t,e,r,n,i){if(t<r)throw new Error(`overscaledZ should be >= z; overscaledZ = ${t}; z = ${r}`);this.overscaledZ=t,this.wrap=e,this.canonical=new Ku(r,+n,+i),this.key=eh(e,t,r,n,i)}clone(){return new th(this.overscaledZ,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)}equals(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)}scaledTo(t){if(t>this.overscaledZ)throw new Error(`targetZ > this.overscaledZ; targetZ = ${t}; overscaledZ = ${this.overscaledZ}`);const e=this.canonical.z-t;return t>this.canonical.z?new th(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new th(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)}calculateScaledKey(t,e){if(t>this.overscaledZ)throw new Error(`targetZ > this.overscaledZ; targetZ = ${t}; overscaledZ = ${this.overscaledZ}`);const r=this.canonical.z-t;return t>this.canonical.z?eh(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):eh(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)}isChildOf(t){if(t.wrap!==this.wrap)return!1;const e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e}children(t){if(this.overscaledZ>=t)return[new th(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];const e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new th(e,this.wrap,e,r,n),new th(e,this.wrap,e,r+1,n),new th(e,this.wrap,e,r,n+1),new th(e,this.wrap,e,r+1,n+1)]}isLessThan(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))}wrapped(){return new th(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)}unwrapTo(t){return new th(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)}overscaleFactor(){return Math.pow(2,this.overscaledZ-this.canonical.z)}toUnwrapped(){return new Qu(this.wrap,this.canonical)}toString(){return`${this.overscaledZ}/${this.canonical.x}/${this.canonical.y}`}getTilePoint(t){return this.canonical.getTilePoint(new $u(t.x-this.wrap,t.y))}}function eh(t,e,r,n,i){(t*=2)<0&&(t=-1*t-1);const a=1<<r;return(a*a*t+a*i+n).toString(36)+r.toString(36)+e.toString(36)}Mi(\"CanonicalTileID\",Ku),Mi(\"OverscaledTileID\",th,{omit:[\"posMatrix\"]});class rh{constructor(t,e,r,n=1,i=1,a=1,o=0){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&![\"mapbox\",\"terrarium\",\"custom\"].includes(r))return void T(`\"${r}\" is not a valid encoding type. Valid types include \"mapbox\", \"terrarium\" and \"custom\".`);this.stride=e.height;const s=this.dim=e.height-2;switch(this.data=new Uint32Array(e.data.buffer),r){case\"terrarium\":this.redFactor=256,this.greenFactor=1,this.blueFactor=1/256,this.baseShift=32768;break;case\"custom\":this.redFactor=n,this.greenFactor=i,this.blueFactor=a,this.baseShift=o;break;default:this.redFactor=6553.6,this.greenFactor=25.6,this.blueFactor=.1,this.baseShift=1e4}for(let t=0;t<s;t++)this.data[this._idx(-1,t)]=this.data[this._idx(0,t)],this.data[this._idx(s,t)]=this.data[this._idx(s-1,t)],this.data[this._idx(t,-1)]=this.data[this._idx(t,0)],this.data[this._idx(t,s)]=this.data[this._idx(t,s-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(s,-1)]=this.data[this._idx(s-1,0)],this.data[this._idx(-1,s)]=this.data[this._idx(0,s-1)],this.data[this._idx(s,s)]=this.data[this._idx(s-1,s-1)],this.min=Number.MAX_SAFE_INTEGER,this.max=Number.MIN_SAFE_INTEGER;for(let t=0;t<s;t++)for(let e=0;e<s;e++){const r=this.get(t,e);r>this.max&&(this.max=r),r<this.min&&(this.min=r)}}get(t,e){const r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return this.unpack(r[n],r[n+1],r[n+2])}getUnpackVector(){return[this.redFactor,this.greenFactor,this.blueFactor,this.baseShift]}_idx(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)}unpack(t,e,r){return t*this.redFactor+e*this.greenFactor+r*this.blueFactor-this.baseShift}getPixels(){return new Ls({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))}backfillBorder(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");let n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}const s=-e*this.dim,l=-r*this.dim;for(let e=a;e<o;e++)for(let r=n;r<i;r++)this.data[this._idx(r,e)]=t.data[this._idx(r+s,e+l)]}}Mi(\"DEMData\",rh);class nh{constructor(t){this._stringToNumber={},this._numberToString=[];for(let e=0;e<t.length;e++){const r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}}encode(t){return this._stringToNumber[t]}decode(t){if(t>=this._numberToString.length)throw new Error(`Out of bounds. Index requested n=${t} can't be >= this._numberToString.length ${this._numberToString.length}`);return this._numberToString[t]}}class ih{constructor(t,e,r,n,i){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=i}get geometry(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry}set geometry(t){this._geometry=t}toJSON(){const t={geometry:this.geometry};for(const e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t}}class ah{constructor(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new ki(Uo,16,0),this.grid3D=new ki(Uo,16,0),this.featureIndexArray=new Za,this.promoteId=e}insert(t,e,r,n,i,a){const o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);const s=a?this.grid3D:this.grid;for(let t=0;t<e.length;t++){const r=e[t],n=[1/0,1/0,-1/0,-1/0];for(let t=0;t<r.length;t++){const e=r[t];n[0]=Math.min(n[0],e.x),n[1]=Math.min(n[1],e.y),n[2]=Math.max(n[2],e.x),n[3]=Math.max(n[3],e.y)}n[0]<Uo&&n[1]<Uo&&n[2]>=0&&n[3]>=0&&s.insert(o,n[0],n[1],n[2],n[3])}}loadVTLayers(){return this.vtLayers||(this.vtLayers=new Tl.VectorTile(new Uc(this.rawTileData)).layers,this.sourceLayerCoder=new nh(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers}query(t,e,r,n){this.loadVTLayers();const i=t.params||{},o=Uo/t.tileSize/t.scale,s=zn(i.filter),l=t.queryGeometry,c=t.queryPadding*o,u=sh(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=sh(t.cameraQueryGeometry),p=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,((e,r,n,i)=>function(t,e,r,n,i){for(const a of t)if(e<=a.x&&r<=a.y&&n>=a.x&&i>=a.y)return!0;const o=[new a(e,r),new a(e,i),new a(n,i),new a(n,r)];if(t.length>2)for(const e of o)if(ns(t,e))return!0;for(let e=0;e<t.length-1;e++)if(is(t[e],t[e+1],o))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,i+c)));for(const t of p)h.push(t);h.sort(lh);const d={};let m;for(let a=0;a<h.length;a++){const c=h[a];if(c===m)continue;m=c;const u=this.featureIndexArray.get(c);let f=null;this.loadMatchingFeature(d,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,i.layers,i.availableImages,e,r,n,((e,r,n)=>(f||(f=Ho(e)),r.queryIntersectsFeature(l,e,n,f,this.z,t.transform,o,t.pixelPosMatrix))))}return d}loadMatchingFeature(t,e,r,n,i,a,o,s,l,c,u){const h=this.bucketLayerIDs[e];if(a&&!function(t,e){for(let r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,h))return;const f=this.sourceLayerCoder.decode(r),p=this.vtLayers[f].feature(n);if(i.needGeometry){const t=Go(p,!0);if(!i.filter(new Hi(this.tileID.overscaledZ),t,this.tileID.canonical))return}else if(!i.filter(new Hi(this.tileID.overscaledZ),p))return;const d=this.getId(p,f);for(let e=0;e<h.length;e++){const r=h[e];if(a&&a.indexOf(r)<0)continue;const i=s[r];if(!i)continue;let f={};d&&c&&(f=c.getState(i.sourceLayer||\"_geojsonTileLayer\",d));const m=y({},l[r]);m.paint=oh(m.paint,i.paint,p,f,o),m.layout=oh(m.layout,i.layout,p,f,o);const g=!u||u(p,i,f);if(!g)continue;const v=new ih(p,this.z,this.x,this.y,d);v.layer=m;let x=t[r];void 0===x&&(x=t[r]=[]),x.push({featureIndex:n,feature:v,intersectionZ:g})}}lookupSymbolFeatures(t,e,r,n,i,a,o,s){const l={};this.loadVTLayers();const c=zn(i);for(const i of t)this.loadMatchingFeature(l,r,n,i,c,a,o,s,e);return l}hasLayer(t){for(const e of this.bucketLayerIDs)for(const r of e)if(t===r)return!0;return!1}getId(t,e){let r=t.id;if(this.promoteId){const n=\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e];r=t.properties[n],\"boolean\"==typeof r&&(r=Number(r))}return r}}function oh(t,e,r,n,i){return x(t,((t,a)=>{const o=e instanceof Ki?e.get(a):null;return o&&o.evaluate?o.evaluate(r,n,i):o}))}function sh(t){let e=1/0,r=1/0,n=-1/0,i=-1/0;for(const a of t)e=Math.min(e,a.x),r=Math.min(r,a.y),n=Math.max(n,a.x),i=Math.max(i,a.y);return{minX:e,minY:r,maxX:n,maxY:i}}function lh(t,e){return e-t}function ch(t,e,r,n,i){const o=[];for(let s=0;s<t.length;s++){const l=t[s];let c;for(let t=0;t<l.length-1;t++){let s=l[t],u=l[t+1];s.x<e&&u.x<e||(s.x<e?s=new a(e,s.y+(u.y-s.y)*((e-s.x)/(u.x-s.x)))._round():u.x<e&&(u=new a(e,s.y+(u.y-s.y)*((e-s.x)/(u.x-s.x)))._round()),s.y<r&&u.y<r||(s.y<r?s=new a(s.x+(u.x-s.x)*((r-s.y)/(u.y-s.y)),r)._round():u.y<r&&(u=new a(s.x+(u.x-s.x)*((r-s.y)/(u.y-s.y)),r)._round()),s.x>=n&&u.x>=n||(s.x>=n?s=new a(n,s.y+(u.y-s.y)*((n-s.x)/(u.x-s.x)))._round():u.x>=n&&(u=new a(n,s.y+(u.y-s.y)*((n-s.x)/(u.x-s.x)))._round()),s.y>=i&&u.y>=i||(s.y>=i?s=new a(s.x+(u.x-s.x)*((i-s.y)/(u.y-s.y)),i)._round():u.y>=i&&(u=new a(s.x+(u.x-s.x)*((i-s.y)/(u.y-s.y)),i)._round()),c&&s.equals(c[c.length-1])||(c=[s],o.push(c)),c.push(u)))))}}return o}Mi(\"FeatureIndex\",ah,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});class uh extends a{constructor(t,e,r,n){super(t,e),this.angle=r,void 0!==n&&(this.segment=n)}clone(){return new uh(this.x,this.y,this.angle,this.segment)}}function hh(t,e,r,n,i){if(void 0===e.segment||0===r)return!0;let a=e,o=e.segment+1,s=0;for(;s>-r/2;){if(o--,o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;const l=[];let c=0;for(;s<r/2;){const e=t[o-1],r=t[o],a=t[o+1];if(!a)return!1;let u=e.angleTo(r)-r.angleTo(a);for(u=Math.abs((u+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:u}),c+=u;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=r.dist(a)}return!0}function fh(t){let e=0;for(let r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function ph(t,e,r){return t?.6*e*r:0}function dh(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function mh(t,e,r,n,i,a){const o=ph(r,i,a),s=dh(r,n)*a;let l=0;const c=fh(t)/2;for(let r=0;r<t.length-1;r++){const n=t[r],i=t[r+1],a=n.dist(i);if(l+a>c){const u=(c-l)/a,h=Pe.number(n.x,i.x,u),f=Pe.number(n.y,i.y,u),p=new uh(h,f,i.angleTo(n),r);return p._round(),!o||hh(t,p,s,o,e)?p:void 0}l+=a}}function gh(t,e,r,n,i,a,o,s,l){const c=ph(n,a,o),u=dh(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),yh(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}function yh(t,e,r,n,i,a,o,s,l){const c=a/2,u=fh(t);let h=0,f=e-r,p=[];for(let e=0;e<t.length-1;e++){const o=t[e],s=t[e+1],d=o.dist(s),m=s.angleTo(o);for(;f+r<h+d;){f+=r;const g=(f-h)/d,y=Pe.number(o.x,s.x,g),v=Pe.number(o.y,s.y,g);if(y>=0&&y<l&&v>=0&&v<l&&f-c>=0&&f+c<=u){const r=new uh(y,v,m,e);r._round(),n&&!hh(t,r,a,n,i)||p.push(r)}}h+=d}return s||p.length||o||(p=yh(t,h/2,r,n,i,a,o,!0,l)),p}Mi(\"Anchor\",uh);const vh=Yc;function xh(t,e,r,n){const i=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2*vh,c=o.paddedRect.h-2*vh;let u={x1:t.left,y1:t.top,x2:t.right,y2:t.bottom};const h=o.stretchX||[[0,l]],f=o.stretchY||[[0,c]],p=(t,e)=>t+e[1]-e[0],d=h.reduce(p,0),m=f.reduce(p,0),g=l-d,y=c-m;let v=0,x=d,_=0,b=m,w=0,T=g,k=0,A=y;if(o.content&&n){const e=o.content,r=e[2]-e[0],n=e[3]-e[1];(o.textFitWidth||o.textFitHeight)&&(u=du(t)),v=_h(h,0,e[0]),_=_h(f,0,e[1]),x=_h(h,e[0],e[2]),b=_h(f,e[1],e[3]),w=e[0]-v,k=e[1]-_,T=r-x,A=n-b}const M=u.x1,S=u.y1,E=u.x2-M,C=u.y2-S,L=(t,n,i,l)=>{const c=wh(t.stretch-v,x,E,M),u=Th(t.fixed-w,T,t.stretch,d),h=wh(n.stretch-_,b,C,S),f=Th(n.fixed-k,A,n.stretch,m),p=wh(i.stretch-v,x,E,M),g=Th(i.fixed-w,T,i.stretch,d),y=wh(l.stretch-_,b,C,S),L=Th(l.fixed-k,A,l.stretch,m),I=new a(c,h),P=new a(p,h),z=new a(p,y),O=new a(c,y),D=new a(u/s,f/s),R=new a(g/s,L/s),F=e*Math.PI/180;if(F){const t=Math.sin(F),e=Math.cos(F),r=[e,-t,t,e];I._matMult(r),P._matMult(r),O._matMult(r),z._matMult(r)}const B=t.stretch+t.fixed,N=i.stretch+i.fixed,j=n.stretch+n.fixed,U=l.stretch+l.fixed;return{tl:I,tr:P,bl:O,br:z,tex:{x:o.paddedRect.x+vh+B,y:o.paddedRect.y+vh+j,w:N-B,h:U-j},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:D,pixelOffsetBR:R,minFontScaleX:T/s/E,minFontScaleY:A/s/C,isSDF:r}};if(n&&(o.stretchX||o.stretchY)){const t=bh(h,g,d),e=bh(f,y,m);for(let r=0;r<t.length-1;r++){const n=t[r],a=t[r+1];for(let t=0;t<e.length-1;t++){const r=e[t],o=e[t+1];i.push(L(n,r,a,o))}}}else i.push(L({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return i}function _h(t,e,r){let n=0;for(const i of t)n+=Math.max(e,Math.min(r,i[1]))-Math.max(e,Math.min(r,i[0]));return n}function bh(t,e,r){const n=[{fixed:-vh,stretch:0}];for(const[e,r]of t){const t=n[n.length-1];n.push({fixed:e-t.stretch,stretch:t.stretch}),n.push({fixed:e-t.stretch,stretch:t.stretch+(r-e)})}return n.push({fixed:e+vh,stretch:r}),n}function wh(t,e,r,n){return t/e*r+n}function Th(t,e,r,n){return t-e*r/n}class kh{constructor(t,e,r,n,i,o,s,l,c,u){var h;if(this.boxStartIndex=t.length,c){let t=o.top,e=o.bottom;const r=o.collisionPadding;r&&(t-=r[1],e+=r[3]);let n=e-t;n>0&&(n=Math.max(10,n),this.circleDiameter=n)}else{const c=(null===(h=o.image)||void 0===h?void 0:h.content)&&(o.image.textFitWidth||o.image.textFitHeight)?du(o):{x1:o.left,y1:o.top,x2:o.right,y2:o.bottom};c.y1=c.y1*s-l[0],c.y2=c.y2*s+l[2],c.x1=c.x1*s-l[3],c.x2=c.x2*s+l[1];const f=o.collisionPadding;if(f&&(c.x1-=f[0]*s,c.y1-=f[1]*s,c.x2+=f[2]*s,c.y2+=f[3]*s),u){const t=new a(c.x1,c.y1),e=new a(c.x2,c.y1),r=new a(c.x1,c.y2),n=new a(c.x2,c.y2),i=u*Math.PI/180;t._rotate(i),e._rotate(i),r._rotate(i),n._rotate(i),c.x1=Math.min(t.x,e.x,r.x,n.x),c.x2=Math.max(t.x,e.x,r.x,n.x),c.y1=Math.min(t.y,e.y,r.y,n.y),c.y2=Math.max(t.y,e.y,r.y,n.y)}t.emplaceBack(e.x,e.y,c.x1,c.y1,c.x2,c.y2,r,n,i)}this.boxEndIndex=t.length}}class Ah{constructor(t=[],e=((t,e)=>t<e?-1:t>e?1:0)){if(this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(let t=(this.length>>1)-1;t>=0;t--)this._down(t)}push(t){this.data.push(t),this._up(this.length++)}pop(){if(0===this.length)return;const t=this.data[0],e=this.data.pop();return--this.length>0&&(this.data[0]=e,this._down(0)),t}peek(){return this.data[0]}_up(t){const{data:e,compare:r}=this,n=e[t];for(;t>0;){const i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n}_down(t){const{data:e,compare:r}=this,n=this.length>>1,i=e[t];for(;t<n;){let n=1+(t<<1);const a=n+1;if(a<this.length&&r(e[a],e[n])<0&&(n=a),r(e[n],i)>=0)break;e[t]=e[n],t=n}e[t]=i}}function Mh(t,e=1,r=!1){let n=1/0,i=1/0,o=-1/0,s=-1/0;const l=t[0];for(let t=0;t<l.length;t++){const e=l[t];(!t||e.x<n)&&(n=e.x),(!t||e.y<i)&&(i=e.y),(!t||e.x>o)&&(o=e.x),(!t||e.y>s)&&(s=e.y)}const c=o-n,u=s-i,h=Math.min(c,u);let f=h/2;const p=new Ah([],Sh);if(0===h)return new a(n,i);for(let e=n;e<o;e+=h)for(let r=i;r<s;r+=h)p.push(new Eh(e+f,r+f,f,t));let d=function(t){let e=0,r=0,n=0;const i=t[0];for(let t=0,a=i.length,o=a-1;t<a;o=t++){const a=i[t],s=i[o],l=a.x*s.y-s.x*a.y;r+=(a.x+s.x)*l,n+=(a.y+s.y)*l,e+=3*l}return new Eh(r/e,n/e,0,t)}(t),m=p.length;for(;p.length;){const n=p.pop();(n.d>d.d||!d.d)&&(d=n,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*n.d)/1e4,m)),n.max-d.d<=e||(f=n.h/2,p.push(new Eh(n.p.x-f,n.p.y-f,f,t)),p.push(new Eh(n.p.x+f,n.p.y-f,f,t)),p.push(new Eh(n.p.x-f,n.p.y+f,f,t)),p.push(new Eh(n.p.x+f,n.p.y+f,f,t)),m+=4)}return r&&(console.log(`num probes: ${m}`),console.log(`best distance: ${d.d}`)),d.p}function Sh(t,e){return e.max-t.max}function Eh(t,e,r,n){this.p=new a(t,e),this.h=r,this.d=function(t,e){let r=!1,n=1/0;for(let i=0;i<e.length;i++){const a=e[i];for(let e=0,i=a.length,o=i-1;e<i;o=e++){const i=a[e],s=a[o];i.y>t.y!=s.y>t.y&&t.x<(s.x-i.x)*(t.y-i.y)/(s.y-i.y)+i.x&&(r=!r),n=Math.min(n,es(t,i,s))}}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}var Ch;t.ar=void 0,(Ch=t.ar||(t.ar={}))[Ch.center=1]=\"center\",Ch[Ch.left=2]=\"left\",Ch[Ch.right=3]=\"right\",Ch[Ch.top=4]=\"top\",Ch[Ch.bottom=5]=\"bottom\",Ch[Ch[\"top-left\"]=6]=\"top-left\",Ch[Ch[\"top-right\"]=7]=\"top-right\",Ch[Ch[\"bottom-left\"]=8]=\"bottom-left\",Ch[Ch[\"bottom-right\"]=9]=\"bottom-right\";const Lh=7,Ih=Number.POSITIVE_INFINITY;function Ph(t,e){return e[1]!==Ih?function(t,e,r){let n=0,i=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":i=r-Lh;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":i=-r+Lh}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,i]}(t,e[0],e[1]):function(t,e){let r=0,n=0;e<0&&(e=0);const i=e/Math.SQRT2;switch(t){case\"top-right\":case\"top-left\":n=i-Lh;break;case\"bottom-right\":case\"bottom-left\":n=-i+Lh;break;case\"bottom\":n=-e+Lh;break;case\"top\":n=e-Lh}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function zh(t,e,r){var n;const i=t.layout,a=null===(n=i.get(\"text-variable-anchor-offset\"))||void 0===n?void 0:n.evaluate(e,{},r);if(a){const t=a.values,e=[];for(let r=0;r<t.length;r+=2){const n=e[r]=t[r],i=t[r+1].map((t=>t*xc));n.startsWith(\"top\")?i[1]-=Lh:n.startsWith(\"bottom\")&&(i[1]+=Lh),e[r+1]=i}return new ee(e)}const o=i.get(\"text-variable-anchor\");if(o){let n;n=void 0!==t._unevaluatedLayout.getValue(\"text-radial-offset\")?[i.get(\"text-radial-offset\").evaluate(e,{},r)*xc,Ih]:i.get(\"text-offset\").evaluate(e,{},r).map((t=>t*xc));const a=[];for(const t of o)a.push(t,Ph(t,n));return new ee(a)}return null}function Oh(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Dh(e,r,n,i,a,o,s,l,c,u,h){let f=o.textMaxSize.evaluate(r,{});void 0===f&&(f=s);const p=e.layers[0].layout,d=p.get(\"icon-offset\").evaluate(r,{},h),m=Fh(n.horizontal),g=s/24,y=e.tilePixelRatio*g,v=e.tilePixelRatio*f/24,x=e.tilePixelRatio*l,_=e.tilePixelRatio*p.get(\"symbol-spacing\"),b=p.get(\"text-padding\")*e.tilePixelRatio,w=function(t,e,r,n=1){const i=t.get(\"icon-padding\").evaluate(e,{},r),a=i&&i.values;return[a[0]*n,a[1]*n,a[2]*n,a[3]*n]}(p,r,h,e.tilePixelRatio),k=p.get(\"text-max-angle\")/180*Math.PI,A=\"viewport\"!==p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),M=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=p.get(\"symbol-placement\"),E=_/2,C=p.get(\"icon-text-fit\");let L;i&&\"none\"!==C&&(e.allowVerticalPlacement&&n.vertical&&(L=mu(i,n.vertical,C,p.get(\"icon-text-fit-padding\"),d,g)),m&&(i=mu(i,m,C,p.get(\"icon-text-fit-padding\"),d,g)));const I=(l,f)=>{f.x<0||f.x>=Uo||f.y<0||f.y>=Uo||function(e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x,_,b,w,k,A,M){const S=e.addToLineVertexArray(r,n);let E,C,L,I,P=0,z=0,O=0,D=0,R=-1,F=-1;const B={};let N=bo(\"\");if(e.allowVerticalPlacement&&i.vertical){const t=l.layout.get(\"text-rotate\").evaluate(b,{},A)+90,e=i.vertical;L=new kh(c,r,u,h,f,e,p,d,m,t),s&&(I=new kh(c,r,u,h,f,s,y,v,m,t))}if(a){const n=l.layout.get(\"icon-rotate\").evaluate(b,{}),i=\"none\"!==l.layout.get(\"icon-text-fit\"),o=xh(a,n,k,i),p=s?xh(s,n,k,i):void 0;C=new kh(c,r,u,h,f,a,y,v,!1,n),P=4*o.length;const d=e.iconSizeData;let m=null;\"source\"===d.kind?(m=[yu*l.layout.get(\"icon-size\").evaluate(b,{})],m[0]>vu&&T(`${e.layerIds[0]}: Value for \"icon-size\" is >= ${gu}. Reduce your \"icon-size\".`)):\"composite\"===d.kind&&(m=[yu*w.compositeIconSizes[0].evaluate(b,{},A),yu*w.compositeIconSizes[1].evaluate(b,{},A)],(m[0]>vu||m[1]>vu)&&T(`${e.layerIds[0]}: Value for \"icon-size\" is >= ${gu}. Reduce your \"icon-size\".`)),e.addSymbols(e.icon,o,m,_,x,b,t.ai.none,r,S.lineStartIndex,S.lineLength,-1,A),R=e.icon.placedSymbolArray.length-1,p&&(z=4*p.length,e.addSymbols(e.icon,p,m,_,x,b,t.ai.vertical,r,S.lineStartIndex,S.lineLength,-1,A),F=e.icon.placedSymbolArray.length-1)}const j=Object.keys(i.horizontal);for(const n of j){const a=i.horizontal[n];if(!E){N=bo(a.text);const t=l.layout.get(\"text-rotate\").evaluate(b,{},A);E=new kh(c,r,u,h,f,a,p,d,m,t)}const s=1===a.positionedLines.length;if(O+=Rh(e,r,a,o,l,m,b,g,S,i.vertical?t.ai.horizontal:t.ai.horizontalOnly,s?j:[n],B,R,w,A),s)break}i.vertical&&(D+=Rh(e,r,i.vertical,o,l,m,b,g,S,t.ai.vertical,[\"vertical\"],B,F,w,A));const U=E?E.boxStartIndex:e.collisionBoxArray.length,V=E?E.boxEndIndex:e.collisionBoxArray.length,q=L?L.boxStartIndex:e.collisionBoxArray.length,H=L?L.boxEndIndex:e.collisionBoxArray.length,G=C?C.boxStartIndex:e.collisionBoxArray.length,Z=C?C.boxEndIndex:e.collisionBoxArray.length,W=I?I.boxStartIndex:e.collisionBoxArray.length,Y=I?I.boxEndIndex:e.collisionBoxArray.length;let X=-1;const $=(t,e)=>t&&t.circleDiameter?Math.max(t.circleDiameter,e):e;X=$(E,X),X=$(L,X),X=$(C,X),X=$(I,X);const J=X>-1?1:0;J&&(X*=M/xc),e.glyphOffsetArray.length>=Eu.MAX_GLYPHS&&T(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),void 0!==b.sortKey&&e.addToSortKeyRanges(e.symbolInstances.length,b.sortKey);const K=zh(l,b,A),[Q,tt]=function(e,r){const n=e.length,i=null==r?void 0:r.values;if((null==i?void 0:i.length)>0)for(let r=0;r<i.length;r+=2){const n=t.ar[i[r]],a=i[r+1];e.emplaceBack(n,a[0],a[1])}return[n,e.length]}(e.textAnchorOffsets,K);e.symbolInstances.emplaceBack(r.x,r.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,U,V,q,H,G,Z,W,Y,u,O,D,P,z,J,0,p,X,Q,tt)}(e,f,l,n,i,a,L,e.layers[0],e.collisionBoxArray,r.index,r.sourceLayerIndex,e.index,y,[b,b,b,b],A,c,x,w,M,d,r,o,u,h,s)};if(\"line\"===S)for(const t of ch(r.geometry,0,0,Uo,Uo)){const r=gh(t,_,k,n.vertical||m,i,24,v,e.overscaling,Uo);for(const n of r)m&&Bh(e,m.text,E,n)||I(t,n)}else if(\"line-center\"===S){for(const t of r.geometry)if(t.length>1){const e=mh(t,k,n.vertical||m,i,24,v);e&&I(t,e)}}else if(\"Polygon\"===r.type)for(const t of br(r.geometry,0)){const e=Mh(t,16);I(t[0],new uh(e.x,e.y,0))}else if(\"LineString\"===r.type)for(const t of r.geometry)I(t,new uh(t[0].x,t[0].y,0));else if(\"Point\"===r.type)for(const t of r.geometry)for(const e of t)I([e],new uh(e.x,e.y,0))}function Rh(t,e,r,n,i,o,s,l,c,u,h,f,p,d,m){const g=function(t,e,r,n,i,o,s,l){const c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[];for(const t of e.positionedLines)for(const n of t.positionedGlyphs){if(!n.rect)continue;const o=n.rect||{};let h=Zc+1,f=!0,p=1,d=0;const m=(i||l)&&n.vertical,g=n.metrics.advance*n.scale/2;if(l&&e.verticalizable){const e=(n.scale-1)*xc,r=(xc-n.metrics.width*n.scale)/2;d=t.lineOffset/2-(n.imageName?-r:e)}if(n.imageName){const t=s[n.imageName];f=t.sdf,p=t.pixelRatio,h=Yc/p}const y=i?[n.x+g,n.y]:[0,0];let v=i?[0,0]:[n.x+g+r[0],n.y+r[1]-d],x=[0,0];m&&(x=v,v=[0,0]);const _=n.metrics.isDoubleResolution?2:1,b=(n.metrics.left-h)*n.scale-g+v[0],w=(-n.metrics.top-h)*n.scale+v[1],T=b+o.w/_*n.scale/p,k=w+o.h/_*n.scale/p,A=new a(b,w),M=new a(T,w),S=new a(b,k),E=new a(T,k);if(m){const t=new a(-g,g-Kc),e=-Math.PI/2,r=xc/2-g,i=n.imageName?r:0,o=new a(5-Kc-r,-i),s=new a(...x);A._rotateAround(e,t)._add(o)._add(s),M._rotateAround(e,t)._add(o)._add(s),S._rotateAround(e,t)._add(o)._add(s),E._rotateAround(e,t)._add(o)._add(s)}if(c){const t=Math.sin(c),e=Math.cos(c),r=[e,-t,t,e];A._matMult(r),M._matMult(r),S._matMult(r),E._matMult(r)}const C=new a(0,0),L=new a(0,0),I=0,P=0;u.push({tl:A,tr:M,bl:S,br:E,tex:o,writingMode:e.writingMode,glyphOffset:y,sectionIndex:n.sectionIndex,isSDF:f,pixelOffsetTL:C,pixelOffsetBR:L,minFontScaleX:I,minFontScaleY:P})}return u}(0,r,l,i,o,s,n,t.allowVerticalPlacement),y=t.textSizeData;let v=null;\"source\"===y.kind?(v=[yu*i.layout.get(\"text-size\").evaluate(s,{})],v[0]>vu&&T(`${t.layerIds[0]}: Value for \"text-size\" is >= ${gu}. Reduce your \"text-size\".`)):\"composite\"===y.kind&&(v=[yu*d.compositeTextSizes[0].evaluate(s,{},m),yu*d.compositeTextSizes[1].evaluate(s,{},m)],(v[0]>vu||v[1]>vu)&&T(`${t.layerIds[0]}: Value for \"text-size\" is >= ${gu}. Reduce your \"text-size\".`)),t.addSymbols(t.text,g,v,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,m);for(const e of h)f[e]=t.text.placedSymbolArray.length-1;return 4*g.length}function Fh(t){for(const e in t)return t[e];return null}function Bh(t,e,r,n){const i=t.compareText;if(e in i){const t=i[e];for(let e=t.length-1;e>=0;e--)if(n.dist(t[e])<r)return!0}else i[e]=[];return i[e].push(n),!1}const Nh=[Int8Array,Uint8Array,Uint8ClampedArray,Int16Array,Uint16Array,Int32Array,Uint32Array,Float32Array,Float64Array];class jh{static from(t){if(!(t instanceof ArrayBuffer))throw new Error(\"Data must be an instance of ArrayBuffer.\");const[e,r]=new Uint8Array(t,0,2);if(219!==e)throw new Error(\"Data does not appear to be in a KDBush format.\");const n=r>>4;if(1!==n)throw new Error(`Got v${n} data when expected v1.`);const i=Nh[15&r];if(!i)throw new Error(\"Unrecognized array type.\");const[a]=new Uint16Array(t,2,1),[o]=new Uint32Array(t,4,1);return new jh(o,a,i,t)}constructor(t,e=64,r=Float64Array,n){if(isNaN(t)||t<0)throw new Error(`Unpexpected numItems value: ${t}.`);this.numItems=+t,this.nodeSize=Math.min(Math.max(+e,2),65535),this.ArrayType=r,this.IndexArrayType=t<65536?Uint16Array:Uint32Array;const i=Nh.indexOf(this.ArrayType),a=2*t*this.ArrayType.BYTES_PER_ELEMENT,o=t*this.IndexArrayType.BYTES_PER_ELEMENT,s=(8-o%8)%8;if(i<0)throw new Error(`Unexpected typed array class: ${r}.`);n&&n instanceof ArrayBuffer?(this.data=n,this.ids=new this.IndexArrayType(this.data,8,t),this.coords=new this.ArrayType(this.data,8+o+s,2*t),this._pos=2*t,this._finished=!0):(this.data=new ArrayBuffer(8+a+o+s),this.ids=new this.IndexArrayType(this.data,8,t),this.coords=new this.ArrayType(this.data,8+o+s,2*t),this._pos=0,this._finished=!1,new Uint8Array(this.data,0,2).set([219,16+i]),new Uint16Array(this.data,2,1)[0]=e,new Uint32Array(this.data,4,1)[0]=t)}add(t,e){const r=this._pos>>1;return this.ids[r]=r,this.coords[this._pos++]=t,this.coords[this._pos++]=e,r}finish(){const t=this._pos>>1;if(t!==this.numItems)throw new Error(`Added ${t} items when expected ${this.numItems}.`);return Uh(this.ids,this.coords,this.nodeSize,0,this.numItems-1,0),this._finished=!0,this}range(t,e,r,n){if(!this._finished)throw new Error(\"Data not yet indexed - call index.finish().\");const{ids:i,coords:a,nodeSize:o}=this,s=[0,i.length-1,0],l=[];for(;s.length;){const c=s.pop()||0,u=s.pop()||0,h=s.pop()||0;if(u-h<=o){for(let o=h;o<=u;o++){const s=a[2*o],c=a[2*o+1];s>=t&&s<=r&&c>=e&&c<=n&&l.push(i[o])}continue}const f=h+u>>1,p=a[2*f],d=a[2*f+1];p>=t&&p<=r&&d>=e&&d<=n&&l.push(i[f]),(0===c?t<=p:e<=d)&&(s.push(h),s.push(f-1),s.push(1-c)),(0===c?r>=p:n>=d)&&(s.push(f+1),s.push(u),s.push(1-c))}return l}within(t,e,r){if(!this._finished)throw new Error(\"Data not yet indexed - call index.finish().\");const{ids:n,coords:i,nodeSize:a}=this,o=[0,n.length-1,0],s=[],l=r*r;for(;o.length;){const c=o.pop()||0,u=o.pop()||0,h=o.pop()||0;if(u-h<=a){for(let r=h;r<=u;r++)Gh(i[2*r],i[2*r+1],t,e)<=l&&s.push(n[r]);continue}const f=h+u>>1,p=i[2*f],d=i[2*f+1];Gh(p,d,t,e)<=l&&s.push(n[f]),(0===c?t-r<=p:e-r<=d)&&(o.push(h),o.push(f-1),o.push(1-c)),(0===c?t+r>=p:e+r>=d)&&(o.push(f+1),o.push(u),o.push(1-c))}return s}}function Uh(t,e,r,n,i,a){if(i-n<=r)return;const o=n+i>>1;Vh(t,e,o,n,i,a),Uh(t,e,r,n,o-1,1-a),Uh(t,e,r,o+1,i,1-a)}function Vh(t,e,r,n,i,a){for(;i>n;){if(i-n>600){const o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);Vh(t,e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}const o=e[2*r+a];let s=n,l=i;for(qh(t,e,n,r),e[2*i+a]>o&&qh(t,e,n,i);s<l;){for(qh(t,e,s,l),s++,l--;e[2*s+a]<o;)s++;for(;e[2*l+a]>o;)l--}e[2*n+a]===o?qh(t,e,n,l):(l++,qh(t,e,l,i)),l<=r&&(n=l+1),r<=l&&(i=l-1)}}function qh(t,e,r,n){Hh(t,r,n),Hh(e,2*r,2*n),Hh(e,2*r+1,2*n+1)}function Hh(t,e,r){const n=t[e];t[e]=t[r],t[r]=n}function Gh(t,e,r,n){const i=t-r,a=e-n;return i*i+a*a}var Zh;t.bf=void 0,(Zh=t.bf||(t.bf={})).create=\"create\",Zh.load=\"load\",Zh.fullLoad=\"fullLoad\";let Wh=null,Yh=[];const Xh=1e3/60,$h=\"loadTime\",Jh=\"fullLoadTime\",Kh={mark(t){performance.mark(t)},frame(t){const e=t;if(null!=Wh){const t=e-Wh;Yh.push(t)}Wh=e},clearMetrics(){Wh=null,Yh=[],performance.clearMeasures($h),performance.clearMeasures(Jh);for(const e in t.bf)performance.clearMarks(t.bf[e])},getPerformanceMetrics(){performance.measure($h,t.bf.create,t.bf.load),performance.measure(Jh,t.bf.create,t.bf.fullLoad);const e=performance.getEntriesByName($h)[0].duration,r=performance.getEntriesByName(Jh)[0].duration,n=Yh.length,i=1/(Yh.reduce(((t,e)=>t+e),0)/n/1e3),a=Yh.filter((t=>t>Xh)).reduce(((t,e)=>t+(e-Xh)/Xh),0);return{loadTime:e,fullLoadTime:r,fps:i,percentDroppedFrames:a/(n+a)*100,totalFrames:n}}};t.$=class extends da{},t.A=fs,t.B=_i,t.C=function(t){if(null==M){const e=t.navigator?t.navigator.userAgent:null;M=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return M},t.D=Qi,t.E=G,t.F=class{constructor(t,e){this.target=t,this.mapId=e,this.resolveRejects={},this.tasks={},this.taskQueue=[],this.abortControllers={},this.messageHandlers={},this.invoker=new Uu((()=>this.process())),this.subscription=function(t,e,r,n){return t.addEventListener(e,r,n),{unsubscribe:()=>{t.removeEventListener(e,r,n)}}}(this.target,\"message\",(t=>this.receive(t)),!1),this.globalScope=A(self)?t:window}registerMessageHandler(t,e){this.messageHandlers[t]=e}sendAsync(t,e){return new Promise(((r,n)=>{const i=Math.round(1e18*Math.random()).toString(36).substring(0,10);this.resolveRejects[i]={resolve:r,reject:n},e&&e.signal.addEventListener(\"abort\",(()=>{delete this.resolveRejects[i];const e={id:i,type:\"<cancel>\",origin:location.origin,targetMapId:t.targetMapId,sourceMapId:this.mapId};this.target.postMessage(e)}),{once:!0});const a=[],o=Object.assign(Object.assign({},t),{id:i,sourceMapId:this.mapId,origin:location.origin,data:Li(t.data,a)});this.target.postMessage(o,{transfer:a})}))}receive(t){const e=t.data,r=e.id;if(!(\"file://\"!==e.origin&&\"file://\"!==location.origin&&\"resource://android\"!==e.origin&&\"resource://android\"!==location.origin&&e.origin!==location.origin||e.targetMapId&&this.mapId!==e.targetMapId)){if(\"<cancel>\"===e.type){delete this.tasks[r];const t=this.abortControllers[r];return delete this.abortControllers[r],void(t&&t.abort())}if(A(self)||e.mustQueue)return this.tasks[r]=e,this.taskQueue.push(r),void this.invoker.trigger();this.processTask(r,e)}}process(){if(0===this.taskQueue.length)return;const t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length>0&&this.invoker.trigger(),e&&this.processTask(t,e)}processTask(t,r){return e(this,void 0,void 0,(function*(){if(\"<response>\"===r.type){const e=this.resolveRejects[t];if(delete this.resolveRejects[t],!e)return;return void(r.error?e.reject(Ii(r.error)):e.resolve(Ii(r.data)))}if(!this.messageHandlers[r.type])return void this.completeTask(t,new Error(`Could not find a registered handler for ${r.type}, map ID: ${this.mapId}, available handlers: ${Object.keys(this.messageHandlers).join(\", \")}`));const e=Ii(r.data),n=new AbortController;this.abortControllers[t]=n;try{const i=yield this.messageHandlers[r.type](r.sourceMapId,e,n);this.completeTask(t,null,i)}catch(e){this.completeTask(t,e)}}))}completeTask(t,e,r){const n=[];delete this.abortControllers[t];const i={id:t,type:\"<response>\",sourceMapId:this.mapId,origin:location.origin,error:e?Li(e):null,data:Li(r,n)};this.target.postMessage(i,{transfer:n})}remove(){this.invoker.remove(),this.subscription.unsubscribe()}},t.G=R,t.H=function(){var t=new fs(16);return fs!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.I=Xc,t.J=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,m=r[0],g=r[1],y=r[2];return e===t?(t[12]=e[0]*m+e[4]*g+e[8]*y+e[12],t[13]=e[1]*m+e[5]*g+e[9]*y+e[13],t[14]=e[2]*m+e[6]*g+e[10]*y+e[14],t[15]=e[3]*m+e[7]*g+e[11]*y+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*m+s*g+h*y+e[12],t[13]=i*m+l*g+f*y+e[13],t[14]=a*m+c*g+p*y+e[14],t[15]=o*m+u*g+d*y+e[15]),t},t.K=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.L=ds,t.M=function(t,e){const r={};for(let n=0;n<e.length;n++){const i=e[n];i in t&&(r[i]=t[i])}return r},t.N=qu,t.O=Zu,t.P=a,t.Q=Wu,t.R=Ls,t.S=th,t.T=Wi,t.U=h,t.V=f,t.W=C,t.X=Uo,t.Y=ua,t.Z=$u,t._=e,t.a=O,t.a$=function(t,e){var r=t[0],n=t[1],i=t[2],a=t[3],o=t[4],s=t[5],l=t[6],c=t[7],u=t[8],h=t[9],f=t[10],p=t[11],d=t[12],m=t[13],g=t[14],y=t[15],v=e[0],x=e[1],_=e[2],b=e[3],w=e[4],T=e[5],k=e[6],A=e[7],M=e[8],S=e[9],E=e[10],C=e[11],L=e[12],I=e[13],P=e[14],z=e[15];return Math.abs(r-v)<=hs*Math.max(1,Math.abs(r),Math.abs(v))&&Math.abs(n-x)<=hs*Math.max(1,Math.abs(n),Math.abs(x))&&Math.abs(i-_)<=hs*Math.max(1,Math.abs(i),Math.abs(_))&&Math.abs(a-b)<=hs*Math.max(1,Math.abs(a),Math.abs(b))&&Math.abs(o-w)<=hs*Math.max(1,Math.abs(o),Math.abs(w))&&Math.abs(s-T)<=hs*Math.max(1,Math.abs(s),Math.abs(T))&&Math.abs(l-k)<=hs*Math.max(1,Math.abs(l),Math.abs(k))&&Math.abs(c-A)<=hs*Math.max(1,Math.abs(c),Math.abs(A))&&Math.abs(u-M)<=hs*Math.max(1,Math.abs(u),Math.abs(M))&&Math.abs(h-S)<=hs*Math.max(1,Math.abs(h),Math.abs(S))&&Math.abs(f-E)<=hs*Math.max(1,Math.abs(f),Math.abs(E))&&Math.abs(p-C)<=hs*Math.max(1,Math.abs(p),Math.abs(C))&&Math.abs(d-L)<=hs*Math.max(1,Math.abs(d),Math.abs(L))&&Math.abs(m-I)<=hs*Math.max(1,Math.abs(m),Math.abs(I))&&Math.abs(g-P)<=hs*Math.max(1,Math.abs(g),Math.abs(P))&&Math.abs(y-z)<=hs*Math.max(1,Math.abs(y),Math.abs(z))},t.a0=ho,t.a1=Ku,t.a2=it,t.a3=t=>{const e=window.document.createElement(\"video\");return e.muted=!0,new Promise((r=>{e.onloadstart=()=>{r(e)};for(const r of t){const t=window.document.createElement(\"source\");j(r)||(e.crossOrigin=\"Anonymous\"),t.src=r,e.appendChild(t)}}))},t.a4=function(){return v++},t.a5=Ra,t.a6=Eu,t.a7=zn,t.a8=Go,t.a9=Hi,t.aA=function(t){t=t.slice();const e=Object.create(null);for(let r=0;r<t.length;r++)e[t[r].id]=t[r];for(let r=0;r<t.length;r++)\"ref\"in t[r]&&(t[r]=Y(t[r],e[t[r].ref]));return t},t.aB=function(t){if(\"custom\"===t.type)return new ju(t);switch(t.type){case\"background\":return new Ru(t);case\"circle\":return new bs(t);case\"fill\":return new yl(t);case\"fill-extrusion\":return new Hl(t);case\"heatmap\":return new Ps(t);case\"hillshade\":return new Ds(t);case\"line\":return new uc(t);case\"raster\":return new Nu(t);case\"symbol\":return new zu(t)}},t.aC=b,t.aD=function(t,e){if(!t)return[{command:\"setStyle\",args:[e]}];let r=[];try{if(!X(t.version,e.version))return[{command:\"setStyle\",args:[e]}];X(t.center,e.center)||r.push({command:\"setCenter\",args:[e.center]}),X(t.zoom,e.zoom)||r.push({command:\"setZoom\",args:[e.zoom]}),X(t.bearing,e.bearing)||r.push({command:\"setBearing\",args:[e.bearing]}),X(t.pitch,e.pitch)||r.push({command:\"setPitch\",args:[e.pitch]}),X(t.sprite,e.sprite)||r.push({command:\"setSprite\",args:[e.sprite]}),X(t.glyphs,e.glyphs)||r.push({command:\"setGlyphs\",args:[e.glyphs]}),X(t.transition,e.transition)||r.push({command:\"setTransition\",args:[e.transition]}),X(t.light,e.light)||r.push({command:\"setLight\",args:[e.light]}),X(t.terrain,e.terrain)||r.push({command:\"setTerrain\",args:[e.terrain]}),X(t.sky,e.sky)||r.push({command:\"setSky\",args:[e.sky]}),X(t.projection,e.projection)||r.push({command:\"setProjection\",args:[e.projection]});const n={},i=[];!function(t,e,r,n){let i;for(i in e=e||{},t=t||{})Object.prototype.hasOwnProperty.call(t,i)&&(Object.prototype.hasOwnProperty.call(e,i)||K(i,r,n));for(i in e)Object.prototype.hasOwnProperty.call(e,i)&&(Object.prototype.hasOwnProperty.call(t,i)?X(t[i],e[i])||(\"geojson\"===t[i].type&&\"geojson\"===e[i].type&&tt(t,e,i)?$(r,{command:\"setGeoJSONSourceData\",args:[i,e[i].data]}):Q(i,e,r,n)):J(i,e,r))}(t.sources,e.sources,i,n);const a=[];t.layers&&t.layers.forEach((t=>{\"source\"in t&&n[t.source]?r.push({command:\"removeLayer\",args:[t.id]}):a.push(t)})),r=r.concat(i),function(t,e,r){e=e||[];const n=(t=t||[]).map(rt),i=e.map(rt),a=t.reduce(nt,{}),o=e.reduce(nt,{}),s=n.slice(),l=Object.create(null);let c,u,h,f,p;for(let t=0,e=0;t<n.length;t++)c=n[t],Object.prototype.hasOwnProperty.call(o,c)?e++:($(r,{command:\"removeLayer\",args:[c]}),s.splice(s.indexOf(c,e),1));for(let t=0,e=0;t<i.length;t++)c=i[i.length-1-t],s[s.length-1-t]!==c&&(Object.prototype.hasOwnProperty.call(a,c)?($(r,{command:\"removeLayer\",args:[c]}),s.splice(s.lastIndexOf(c,s.length-e),1)):e++,f=s[s.length-t],$(r,{command:\"addLayer\",args:[o[c],f]}),s.splice(s.length-t,0,c),l[c]=!0);for(let t=0;t<i.length;t++)if(c=i[t],u=a[c],h=o[c],!l[c]&&!X(u,h))if(X(u.source,h.source)&&X(u[\"source-layer\"],h[\"source-layer\"])&&X(u.type,h.type)){for(p in et(u.layout,h.layout,r,c,null,\"setLayoutProperty\"),et(u.paint,h.paint,r,c,null,\"setPaintProperty\"),X(u.filter,h.filter)||$(r,{command:\"setFilter\",args:[c,h.filter]}),X(u.minzoom,h.minzoom)&&X(u.maxzoom,h.maxzoom)||$(r,{command:\"setLayerZoomRange\",args:[c,h.minzoom,h.maxzoom]}),u)Object.prototype.hasOwnProperty.call(u,p)&&\"layout\"!==p&&\"paint\"!==p&&\"filter\"!==p&&\"metadata\"!==p&&\"minzoom\"!==p&&\"maxzoom\"!==p&&(0===p.indexOf(\"paint.\")?et(u[p],h[p],r,c,p.slice(6),\"setPaintProperty\"):X(u[p],h[p])||$(r,{command:\"setLayerProperty\",args:[c,p,h[p]]}));for(p in h)Object.prototype.hasOwnProperty.call(h,p)&&!Object.prototype.hasOwnProperty.call(u,p)&&\"layout\"!==p&&\"paint\"!==p&&\"filter\"!==p&&\"metadata\"!==p&&\"minzoom\"!==p&&\"maxzoom\"!==p&&(0===p.indexOf(\"paint.\")?et(u[p],h[p],r,c,p.slice(6),\"setPaintProperty\"):X(u[p],h[p])||$(r,{command:\"setLayerProperty\",args:[c,p,h[p]]}))}else $(r,{command:\"removeLayer\",args:[c]}),f=s[s.lastIndexOf(c)+1],$(r,{command:\"addLayer\",args:[h,f]})}(a,e.layers,r)}catch(t){console.warn(\"Unable to compute style diff:\",t),r=[{command:\"setStyle\",args:[e]}]}return r},t.aE=function(t){const e=[],r=t.id;return void 0===r&&e.push({message:`layers.${r}: missing required property \"id\"`}),void 0===t.render&&e.push({message:`layers.${r}: missing required method \"render\"`}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:`layers.${r}: property \"renderingMode\" must be either \"2d\" or \"3d\"`}),e},t.aF=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(let n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(const n in e)if(!t(e[n],r[n]))return!1;return!0}return e===r},t.aG=x,t.aH=_,t.aI=class extends Mo{constructor(t,e){super(t,e),this.current=0}set(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))}},t.aJ=So,t.aK=class extends Mo{constructor(t,e){super(t,e),this.current=Lo}set(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(let e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}}},t.aL=Eo,t.aM=Co,t.aN=Xt,t.aO=class extends Mo{constructor(t,e){super(t,e),this.current=[0,0,0]}set(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))}},t.aP=class extends Mo{constructor(t,e){super(t,e),this.current=[0,0]}set(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))}},t.aQ=gs,t.aR=ys,t.aS=class extends ka{},t.aT=gc,t.aU=class extends Ma{},t.aV=function(t){return t<=1?1:Math.pow(2,Math.ceil(Math.log(t)/Math.LN2))},t.aW=Is,t.aX=Wa,t.aY=ao,t.aZ=class extends za{},t.a_=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]&&t[3]===e[3]&&t[4]===e[4]&&t[5]===e[5]&&t[6]===e[6]&&t[7]===e[7]&&t[8]===e[8]&&t[9]===e[9]&&t[10]===e[10]&&t[11]===e[11]&&t[12]===e[12]&&t[13]===e[13]&&t[14]===e[14]&&t[15]===e[15]},t.aa=ih,t.ab=function(t){const e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,((t,r,n,i)=>{const a=n||i;return e[r]=!a||a.toLowerCase(),\"\"})),e[\"max-age\"]){const t=parseInt(e[\"max-age\"],10);isNaN(t)?delete e[\"max-age\"]:e[\"max-age\"]=t}return e},t.ac=function(t,e){const r=[];for(const n in t)n in e||r.push(n);return r},t.ad=m,t.ae=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.af=function(t){var e=new fs(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.ag=vs,t.ah=function(t,e){let r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){const{interpolationType:i,minZoom:a,maxZoom:o}=t,s=i?m(ze.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Pe.number(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}},t.aj=function(t,{uSize:e,uSizeT:r},{lowerSize:n,upperSize:i}){return\"source\"===t.kind?n/yu:\"composite\"===t.kind?Pe.number(n/yu,i/yu,r):e},t.ak=ku,t.al=function(t,e,r,n){const i=e.y-t.y,o=e.x-t.x,s=n.y-r.y,l=n.x-r.x,c=s*o-l*i;if(0===c)return null;const u=(l*(t.y-r.y)-s*(t.x-r.x))/c;return new a(t.x+u*o,t.y+u*i)},t.am=ch,t.an=Yo,t.ao=ps,t.ap=function(t){let e=1/0,r=1/0,n=-1/0,i=-1/0;for(const a of t)e=Math.min(e,a.x),r=Math.min(r,a.y),n=Math.max(n,a.x),i=Math.max(i,a.y);return[e,r,n,i]},t.aq=xc,t.as=_u,t.at=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],m=e[13],g=e[14],y=e[15],v=r*s-n*o,x=r*l-i*o,_=r*c-a*o,b=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*m-h*d,A=u*g-f*d,M=u*y-p*d,S=h*g-f*m,E=h*y-p*m,C=f*y-p*g,L=v*C-x*E+_*S+b*M-w*A+T*k;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(m*T-g*w+y*b)*L,t[3]=(f*w-h*T-p*b)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(g*_-d*T-y*x)*L,t[7]=(u*T-f*_+p*x)*L,t[8]=(o*E-s*M+c*k)*L,t[9]=(n*M-r*E-a*k)*L,t[10]=(d*w-m*_+y*v)*L,t[11]=(h*_-u*w-p*v)*L,t[12]=(s*A-o*S-l*k)*L,t[13]=(r*S-n*A+i*k)*L,t[14]=(m*x-d*b-g*v)*L,t[15]=(u*b-h*x+f*v)*L,t):null},t.au=Oh,t.av=hu,t.aw=jh,t.ax=function(){const t={},e=Z.$version;for(const r in Z.$root){const n=Z.$root[r];if(n.required){let i=null;i=\"version\"===r?e:\"array\"===n.type?[]:{},null!=i&&(t[r]=i)}}return t},t.ay=Pi,t.az=B,t.b=S,t.b0=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.b1=_s,t.b2=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.b3=g,t.b4=Qu,t.b5=Yu,t.b6=ms,t.b7=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.b8=p,t.b9=d,t.bA=function(t){return t.message===P},t.bB=An,t.bC=qi,t.ba=function(t){return t*Math.PI/180},t.bb=function(t,e){return t[0]=e[0],t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=e[1],t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=e[2],t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.bc=class extends pa{},t.bd=Vu,t.be=Kh,t.bg=F,t.bh=function(t,e){O.REGISTERED_PROTOCOLS[t]=e},t.bi=function(t){delete O.REGISTERED_PROTOCOLS[t]},t.bj=function(t,e){const r={};for(let n=0;n<t.length;n++){const i=e&&e[t[n].id]||Vn(t[n]);e&&(e[t[n].id]=i);let a=r[i];a||(a=r[i]=[]),a.push(t[n])}const n=[];for(const t in r)n.push(r[t]);return n},t.bk=Mi,t.bl=nh,t.bm=ah,t.bn=$c,t.bo=function(e){e.bucket.createArrays();const r=512*e.bucket.overscaling;e.bucket.tilePixelRatio=Uo/r,e.bucket.compareText={},e.bucket.iconsNeedLinear=!1;const n=e.bucket.layers[0],i=n.layout,a=n._unevaluatedLayout._values,o={layoutIconSize:a[\"icon-size\"].possiblyEvaluate(new Hi(e.bucket.zoom+1),e.canonical),layoutTextSize:a[\"text-size\"].possiblyEvaluate(new Hi(e.bucket.zoom+1),e.canonical),textMaxSize:a[\"text-size\"].possiblyEvaluate(new Hi(18))};if(\"composite\"===e.bucket.textSizeData.kind){const{minZoom:t,maxZoom:r}=e.bucket.textSizeData;o.compositeTextSizes=[a[\"text-size\"].possiblyEvaluate(new Hi(t),e.canonical),a[\"text-size\"].possiblyEvaluate(new Hi(r),e.canonical)]}if(\"composite\"===e.bucket.iconSizeData.kind){const{minZoom:t,maxZoom:r}=e.bucket.iconSizeData;o.compositeIconSizes=[a[\"icon-size\"].possiblyEvaluate(new Hi(t),e.canonical),a[\"icon-size\"].possiblyEvaluate(new Hi(r),e.canonical)]}const s=i.get(\"text-line-height\")*xc,l=\"viewport\"!==i.get(\"text-rotation-alignment\")&&\"point\"!==i.get(\"symbol-placement\"),c=i.get(\"text-keep-upright\"),u=i.get(\"text-size\");for(const r of e.bucket.features){const a=i.get(\"text-font\").evaluate(r,{},e.canonical).join(\",\"),h=u.evaluate(r,{},e.canonical),f=o.layoutTextSize.evaluate(r,{},e.canonical),p=o.layoutIconSize.evaluate(r,{},e.canonical),d={horizontal:{},vertical:void 0},m=r.text;let g,y=[0,0];if(m){const o=m.toString(),u=i.get(\"text-letter-spacing\").evaluate(r,{},e.canonical)*xc,p=Di(o)?u:0,g=i.get(\"text-anchor\").evaluate(r,{},e.canonical),v=zh(n,r,e.canonical);if(!v){const t=i.get(\"text-radial-offset\").evaluate(r,{},e.canonical);y=t?Ph(g,[t*xc,Ih]):i.get(\"text-offset\").evaluate(r,{},e.canonical).map((t=>t*xc))}let x=l?\"center\":i.get(\"text-justify\").evaluate(r,{},e.canonical);const _=\"point\"===i.get(\"symbol-placement\")?i.get(\"text-max-width\").evaluate(r,{},e.canonical)*xc:1/0,b=()=>{e.bucket.allowVerticalPlacement&&Oi(o)&&(d.vertical=eu(m,e.glyphMap,e.glyphPositions,e.imagePositions,a,_,s,g,\"left\",p,y,t.ai.vertical,!0,f,h))};if(!l&&v){const r=new Set;if(\"auto\"===x)for(let t=0;t<v.values.length;t+=2)r.add(Oh(v.values[t]));else r.add(x);let n=!1;for(const i of r)if(!d.horizontal[i])if(n)d.horizontal[i]=d.horizontal[0];else{const r=eu(m,e.glyphMap,e.glyphPositions,e.imagePositions,a,_,s,\"center\",i,p,y,t.ai.horizontal,!1,f,h);r&&(d.horizontal[i]=r,n=1===r.positionedLines.length)}b()}else{\"auto\"===x&&(x=Oh(g));const r=eu(m,e.glyphMap,e.glyphPositions,e.imagePositions,a,_,s,g,x,p,y,t.ai.horizontal,!1,f,h);r&&(d.horizontal[x]=r),b(),Oi(o)&&l&&c&&(d.vertical=eu(m,e.glyphMap,e.glyphPositions,e.imagePositions,a,_,s,g,x,p,y,t.ai.vertical,!1,f,h))}}let v=!1;if(r.icon&&r.icon.name){const t=e.imageMap[r.icon.name];t&&(g=pu(e.imagePositions[r.icon.name],i.get(\"icon-offset\").evaluate(r,{},e.canonical),i.get(\"icon-anchor\").evaluate(r,{},e.canonical)),v=!!t.sdf,void 0===e.bucket.sdfIcons?e.bucket.sdfIcons=v:e.bucket.sdfIcons!==v&&T(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(t.pixelRatio!==e.bucket.pixelRatio||0!==i.get(\"icon-rotate\").constantOr(1))&&(e.bucket.iconsNeedLinear=!0))}const x=Fh(d.horizontal)||d.vertical;e.bucket.iconsInText=!!x&&x.iconsInText,(x||g)&&Dh(e.bucket,r,d,g,e.imageMap,o,f,p,y,v,e.canonical)}e.showCollisionBoxes&&e.bucket.generateCollisionDebugBuffers()},t.bp=ic,t.bq=pl,t.br=Nl,t.bs=Tl,t.bt=Uc,t.bu=class{constructor(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},performance.mark(this._marks.start)}finish(){performance.mark(this._marks.end);let t=performance.getEntriesByName(this._marks.measure);return 0===t.length&&(performance.measure(this._marks.measure,this._marks.start,this._marks.end),t=performance.getEntriesByName(this._marks.measure),performance.clearMarks(this._marks.start),performance.clearMarks(this._marks.end),performance.clearMeasures(this._marks.measure)),t}},t.bv=function(t,r,n,i,a){return e(this,void 0,void 0,(function*(){if(f())try{return yield C(t,r,n,i,a)}catch(t){}return function(t,e,r,n,i){const a=t.width,o=t.height;L&&I||(L=new OffscreenCanvas(a,o),I=L.getContext(\"2d\",{willReadFrequently:!0})),L.width=a,L.height=o,I.drawImage(t,0,0,a,o);const s=I.getImageData(e,r,n,i);return I.clearRect(0,0,a,o),s.data}(t,r,n,i,a)}))},t.bw=rh,t.bx=r,t.by=n,t.bz=_c,t.c=z,t.d=t=>e(void 0,void 0,void 0,(function*(){if(0===t.byteLength)return createImageBitmap(new ImageData(1,1));const e=new Blob([new Uint8Array(t)],{type:\"image/png\"});try{return createImageBitmap(e)}catch(t){throw new Error(`Could not load image because of ${t.message}. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.`)}})),t.e=y,t.f=t=>new Promise(((e,r)=>{const n=new Image;n.onload=()=>{e(n),URL.revokeObjectURL(n.src),n.onload=null,window.requestAnimationFrame((()=>{n.src=E}))},n.onerror=()=>r(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"));const i=new Blob([new Uint8Array(t)],{type:\"image/png\"});n.src=t.byteLength?URL.createObjectURL(i):E})),t.g=D,t.h=(t,e)=>N(y(t,{type:\"json\"}),e),t.i=A,t.j=H,t.k=q,t.l=(t,e)=>N(y(t,{type:\"arrayBuffer\"}),e),t.m=N,t.n=function(t){return new Uc(t).readFields(qc,[])},t.o=Cs,t.p=Wc,t.q=ia,t.r=xi,t.s=j,t.t=Ti,t.u=zi,t.v=Z,t.w=T,t.x=vi,t.y=function([t,e,r]){return e+=90,e*=Math.PI/180,r*=Math.PI/180,{x:t*Math.cos(e)*Math.sin(r),y:t*Math.sin(e)*Math.sin(r),z:t*Math.cos(r)}},t.z=Pe})),r(\"worker\",0,(function(t){class e{constructor(t){this.keyCache={},t&&this.replace(t)}replace(t){this._layerConfigs={},this._layers={},this.update(t,[])}update(e,r){for(const r of e){this._layerConfigs[r.id]=r;const e=this._layers[r.id]=t.aB(r);e._featureFilter=t.a7(e.filter),this.keyCache[r.id]&&delete this.keyCache[r.id]}for(const t of r)delete this.keyCache[t],delete this._layerConfigs[t],delete this._layers[t];this.familiesBySource={};const n=t.bj(Object.values(this._layerConfigs),this.keyCache);for(const t of n){const e=t.map((t=>this._layers[t.id])),r=e[0];if(\"none\"===r.visibility)continue;const n=r.source||\"\";let i=this.familiesBySource[n];i||(i=this.familiesBySource[n]={});const a=r.sourceLayer||\"_geojsonTileLayer\";let o=i[a];o||(o=i[a]=[]),o.push(e)}}}class r{constructor(e){const r={},n=[];for(const t in e){const i=e[t],a=r[t]={};for(const t in i){const e=i[+t];if(!e||0===e.bitmap.width||0===e.bitmap.height)continue;const r={x:0,y:0,w:e.bitmap.width+2,h:e.bitmap.height+2};n.push(r),a[t]={rect:r,metrics:e.metrics}}}const{w:i,h:a}=t.p(n),o=new t.o({width:i||1,height:a||1});for(const n in e){const i=e[n];for(const e in i){const a=i[+e];if(!a||0===a.bitmap.width||0===a.bitmap.height)continue;const s=r[n][e].rect;t.o.copy(a.bitmap,o,{x:0,y:0},{x:s.x+1,y:s.y+1},a.bitmap)}}this.image=o,this.positions=r}}t.bk(\"GlyphAtlas\",r);class n{constructor(e){this.tileID=new t.S(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId,this.inFlightDependencies=[]}parse(e,n,a,o){return t._(this,void 0,void 0,(function*(){this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.a5;const s=new t.bl(Object.keys(e.layers).sort()),l=new t.bm(this.tileID,this.promoteId);l.bucketLayerIDs=[];const c={},u={featureIndex:l,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:a},h=n.familiesBySource[this.source];for(const r in h){const n=e.layers[r];if(!n)continue;1===n.version&&t.w(`Vector tile source \"${this.source}\" layer \"${r}\" does not use vector tile spec v2 and therefore may have some rendering errors.`);const o=s.encode(r),f=[];for(let t=0;t<n.length;t++){const e=n.feature(t),i=l.getId(e,r);f.push({feature:e,id:i,index:t,sourceLayerIndex:o})}for(const e of h[r]){const r=e[0];r.source!==this.source&&t.w(`layer.source = ${r.source} does not equal this.source = ${this.source}`),r.minzoom&&this.zoom<Math.floor(r.minzoom)||r.maxzoom&&this.zoom>=r.maxzoom||\"none\"!==r.visibility&&(i(e,this.zoom,a),(c[r.id]=r.createBucket({index:l.bucketLayerIDs.length,layers:e,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:o,sourceID:this.source})).populate(f,u,this.tileID.canonical),l.bucketLayerIDs.push(e.map((t=>t.id))))}}const f=t.aG(u.glyphDependencies,(t=>Object.keys(t).map(Number)));this.inFlightDependencies.forEach((t=>null==t?void 0:t.abort())),this.inFlightDependencies=[];let p=Promise.resolve({});if(Object.keys(f).length){const t=new AbortController;this.inFlightDependencies.push(t),p=o.sendAsync({type:\"GG\",data:{stacks:f,source:this.source,tileID:this.tileID,type:\"glyphs\"}},t)}const d=Object.keys(u.iconDependencies);let m=Promise.resolve({});if(d.length){const t=new AbortController;this.inFlightDependencies.push(t),m=o.sendAsync({type:\"GI\",data:{icons:d,source:this.source,tileID:this.tileID,type:\"icons\"}},t)}const g=Object.keys(u.patternDependencies);let y=Promise.resolve({});if(g.length){const t=new AbortController;this.inFlightDependencies.push(t),y=o.sendAsync({type:\"GI\",data:{icons:g,source:this.source,tileID:this.tileID,type:\"patterns\"}},t)}const[v,x,_]=yield Promise.all([p,m,y]),b=new r(v),w=new t.bn(x,_);for(const e in c){const r=c[e];r instanceof t.a6?(i(r.layers,this.zoom,a),t.bo({bucket:r,glyphMap:v,glyphPositions:b.positions,imageMap:x,imagePositions:w.iconPositions,showCollisionBoxes:this.showCollisionBoxes,canonical:this.tileID.canonical})):r.hasPattern&&(r instanceof t.bp||r instanceof t.bq||r instanceof t.br)&&(i(r.layers,this.zoom,a),r.addFeatures(u,this.tileID.canonical,w.patternPositions))}return this.status=\"done\",{buckets:Object.values(c).filter((t=>!t.isEmpty())),featureIndex:l,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:b.image,imageAtlas:w,glyphMap:this.returnDependencies?v:null,iconMap:this.returnDependencies?x:null,glyphPositions:this.returnDependencies?b.positions:null}}))}}function i(e,r,n){const i=new t.a9(r);for(const t of e)t.recalculate(i,n)}class a{constructor(t,e,r){this.actor=t,this.layerIndex=e,this.availableImages=r,this.fetching={},this.loading={},this.loaded={}}loadVectorTile(e,r){return t._(this,void 0,void 0,(function*(){const n=yield t.l(e.request,r);try{return{vectorTile:new t.bs.VectorTile(new t.bt(n.data)),rawData:n.data,cacheControl:n.cacheControl,expires:n.expires}}catch(t){const r=new Uint8Array(n.data),i=31===r[0]&&139===r[1];let a=`Unable to parse the tile at ${e.request.url}, `;throw a+=i?\"please make sure the data is not gzipped and that you have configured the relevant header in the server\":`got error: ${t.message}`,new Error(a)}}))}loadTile(e){return t._(this,void 0,void 0,(function*(){const r=e.uid,i=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.bu(e.request),a=new n(e);this.loading[r]=a;const o=new AbortController;a.abort=o;try{const n=yield this.loadVectorTile(e,o);if(delete this.loading[r],!n)return null;const s=n.rawData,l={};n.expires&&(l.expires=n.expires),n.cacheControl&&(l.cacheControl=n.cacheControl);const c={};if(i){const t=i.finish();t&&(c.resourceTiming=JSON.parse(JSON.stringify(t)))}a.vectorTile=n.vectorTile;const u=a.parse(n.vectorTile,this.layerIndex,this.availableImages,this.actor);this.loaded[r]=a,this.fetching[r]={rawTileData:s,cacheControl:l,resourceTiming:c};try{const e=yield u;return t.e({rawTileData:s.slice(0)},e,l,c)}finally{delete this.fetching[r]}}catch(t){throw delete this.loading[r],a.status=\"done\",this.loaded[r]=a,t}}))}reloadTile(e){return t._(this,void 0,void 0,(function*(){const r=e.uid;if(!this.loaded||!this.loaded[r])throw new Error(\"Should not be trying to reload a tile that was never loaded or has been removed\");const n=this.loaded[r];if(n.showCollisionBoxes=e.showCollisionBoxes,\"parsing\"===n.status){const e=yield n.parse(n.vectorTile,this.layerIndex,this.availableImages,this.actor);let i;if(this.fetching[r]){const{rawTileData:n,cacheControl:a,resourceTiming:o}=this.fetching[r];delete this.fetching[r],i=t.e({rawTileData:n.slice(0)},e,a,o)}else i=e;return i}if(\"done\"===n.status&&n.vectorTile)return n.parse(n.vectorTile,this.layerIndex,this.availableImages,this.actor)}))}abortTile(e){return t._(this,void 0,void 0,(function*(){const t=this.loading,r=e.uid;t&&t[r]&&t[r].abort&&(t[r].abort.abort(),delete t[r])}))}removeTile(e){return t._(this,void 0,void 0,(function*(){this.loaded&&this.loaded[e.uid]&&delete this.loaded[e.uid]}))}}class o{constructor(){this.loaded={}}loadTile(e){return t._(this,void 0,void 0,(function*(){const{uid:r,encoding:n,rawImageData:i,redFactor:a,greenFactor:o,blueFactor:s,baseShift:l}=e,c=i.width+2,u=i.height+2,h=t.b(i)?new t.R({width:c,height:u},yield t.bv(i,-1,-1,c,u)):i,f=new t.bw(r,h,n,a,o,s,l);return this.loaded=this.loaded||{},this.loaded[r]=f,f}))}removeTile(t){const e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]}}var s=function t(e,r){var n,i=e&&e.type;if(\"FeatureCollection\"===i)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===i)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===i)t(e.geometry,r);else if(\"Polygon\"===i)l(e.coordinates,r);else if(\"MultiPolygon\"===i)for(n=0;n<e.coordinates.length;n++)l(e.coordinates[n],r);return e};function l(t,e){if(0!==t.length){c(t[0],e);for(var r=1;r<t.length;r++)c(t[r],!e)}}function c(t,e){for(var r=0,n=0,i=0,a=t.length,o=a-1;i<a;o=i++){var s=(t[i][0]-t[o][0])*(t[o][1]+t[i][1]),l=r+s;n+=Math.abs(r)>=Math.abs(s)?r-l+s:s-l+r,r=l}r+n>=0!=!!e&&t.reverse()}var u=t.bx(s);const h=t.bs.VectorTileFeature.prototype.toGeoJSON;let f=class{constructor(e){this._feature=e,this.extent=t.X,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))}loadGeometry(){if(1===this._feature.type){const e=[];for(const r of this._feature.geometry)e.push([new t.P(r[0],r[1])]);return e}{const e=[];for(const r of this._feature.geometry){const n=[];for(const e of r)n.push(new t.P(e[0],e[1]));e.push(n)}return e}}toGeoJSON(t,e,r){return h.call(this,t,e,r)}},p=class{constructor(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.X,this.length=e.length,this._features=e}feature(t){return new f(this._features[t])}};var d={exports:{}},m=t.by,g=t.bs.VectorTileFeature,y=v;function v(t,e){this.options=e||{},this.features=t,this.length=t.length}function x(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}v.prototype.feature=function(t){return new x(this.features[t],this.options.extent)},x.prototype.loadGeometry=function(){var t=this.rawGeometry;this.geometry=[];for(var e=0;e<t.length;e++){for(var r=t[e],n=[],i=0;i<r.length;i++)n.push(new m(r[i][0],r[i][1]));this.geometry.push(n)}return this.geometry},x.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},x.prototype.toGeoJSON=g.prototype.toGeoJSON;var _=t.bz,b=y;function w(t){var e=new _;return function(t,e){for(var r in t.layers)e.writeMessage(3,T,t.layers[r])}(t,e),e.finish()}function T(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,k,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,C,a[r])}function k(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,A,t),e.writeVarintField(3,r.type),e.writeMessage(4,E,r)}function A(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=r.properties[s],c=a[s];if(null!==l){void 0===c&&(n.push(s),c=n.length-1,a[s]=c),e.writeVarint(c);var u=typeof l;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(l=JSON.stringify(l));var h=u+\":\"+l,f=o[h];void 0===f&&(i.push(l),f=i.length-1,o[h]=f),e.writeVarint(f)}}}function M(t,e){return(e<<3)+(7&t)}function S(t){return t<<1^t>>31}function E(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(M(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(M(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(S(f)),e.writeVarint(S(p)),i+=f,a+=p}3===n&&e.writeVarint(M(7,1))}}function C(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}d.exports=w,d.exports.fromVectorTileJs=w,d.exports.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new b(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return w({layers:r})},d.exports.GeoJSONWrapper=b;var L=d.exports,I=t.bx(L);const P={minZoom:0,maxZoom:16,minPoints:2,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:t=>t},z=Math.fround||(O=new Float32Array(1),t=>(O[0]=+t,O[0]));var O;const D=3,R=5,F=6;class B{constructor(t){this.options=Object.assign(Object.create(P),t),this.trees=new Array(this.options.maxZoom+1),this.stride=this.options.reduce?7:6,this.clusterProps=[]}load(t){const{log:e,minZoom:r,maxZoom:n}=this.options;e&&console.time(\"total time\");const i=`prepare ${t.length} points`;e&&console.time(i),this.points=t;const a=[];for(let e=0;e<t.length;e++){const r=t[e];if(!r.geometry)continue;const[n,i]=r.geometry.coordinates,o=z(U(n)),s=z(V(i));a.push(o,s,1/0,e,-1,1),this.options.reduce&&a.push(0)}let o=this.trees[n+1]=this._createTree(a);e&&console.timeEnd(i);for(let t=n;t>=r;t--){const r=+Date.now();o=this.trees[t]=this._createTree(this._cluster(o,t)),e&&console.log(\"z%d: %d clusters in %dms\",t,o.numItems,+Date.now()-r)}return e&&console.timeEnd(\"total time\"),this}getClusters(t,e){let r=((t[0]+180)%360+360)%360-180;const n=Math.max(-90,Math.min(90,t[1]));let i=180===t[2]?180:((t[2]+180)%360+360)%360-180;const a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){const t=this.getClusters([r,n,180,a],e),o=this.getClusters([-180,n,i,a],e);return t.concat(o)}const o=this.trees[this._limitZoom(e)],s=o.range(U(r),V(a),U(i),V(n)),l=o.data,c=[];for(const t of s){const e=this.stride*t;c.push(l[e+R]>1?N(l,e,this.clusterProps):this.points[l[e+D]])}return c}getChildren(t){const e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);const a=i.data;if(e*this.stride>=a.length)throw new Error(n);const o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=a[e*this.stride],l=a[e*this.stride+1],c=i.within(s,l,o),u=[];for(const e of c){const r=e*this.stride;a[r+4]===t&&u.push(a[r+R]>1?N(a,r,this.clusterProps):this.points[a[r+D]])}if(0===u.length)throw new Error(n);return u}getLeaves(t,e,r){e=e||10,r=r||0;const n=[];return this._appendLeaves(n,t,e,r,0),n}getTile(t,e,r){const n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),{extent:a,radius:o}=this.options,s=o/a,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.data,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.data,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.data,-1,r,i,u),u.features.length?u:null}getClusterExpansionZoom(t){let e=this._getOriginZoom(t)-1;for(;e<=this.options.maxZoom;){const r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e}_appendLeaves(t,e,r,n,i){const a=this.getChildren(e);for(const e of a){const a=e.properties;if(a&&a.cluster?i+a.point_count<=n?i+=a.point_count:i=this._appendLeaves(t,a.cluster_id,r,n,i):i<n?i++:t.push(e),t.length===r)break}return i}_createTree(e){const r=new t.aw(e.length/this.stride|0,this.options.nodeSize,Float32Array);for(let t=0;t<e.length;t+=this.stride)r.add(e[t],e[t+1]);return r.finish(),r.data=e,r}_addTileFeatures(t,e,r,n,i,a){for(const o of t){const t=o*this.stride,s=e[t+R]>1;let l,c,u;if(s)l=j(e,t,this.clusterProps),c=e[t],u=e[t+1];else{const r=this.points[e[t+D]];l=r.properties;const[n,i]=r.geometry.coordinates;c=U(n),u=V(i)}const h={type:1,geometry:[[Math.round(this.options.extent*(c*i-r)),Math.round(this.options.extent*(u*i-n))]],tags:l};let f;f=s||this.options.generateId?e[t+D]:this.points[e[t+D]].id,void 0!==f&&(h.id=f),a.features.push(h)}}_limitZoom(t){return Math.max(this.options.minZoom,Math.min(Math.floor(+t),this.options.maxZoom+1))}_cluster(t,e){const{radius:r,extent:n,reduce:i,minPoints:a}=this.options,o=r/(n*Math.pow(2,e)),s=t.data,l=[],c=this.stride;for(let r=0;r<s.length;r+=c){if(s[r+2]<=e)continue;s[r+2]=e;const n=s[r],u=s[r+1],h=t.within(s[r],s[r+1],o),f=s[r+R];let p=f;for(const t of h){const r=t*c;s[r+2]>e&&(p+=s[r+R])}if(p>f&&p>=a){let t,a=n*f,o=u*f,d=-1;const m=((r/c|0)<<5)+(e+1)+this.points.length;for(const n of h){const l=n*c;if(s[l+2]<=e)continue;s[l+2]=e;const u=s[l+R];a+=s[l]*u,o+=s[l+1]*u,s[l+4]=m,i&&(t||(t=this._map(s,r,!0),d=this.clusterProps.length,this.clusterProps.push(t)),i(t,this._map(s,l)))}s[r+4]=m,l.push(a/p,o/p,1/0,m,-1,p),i&&l.push(d)}else{for(let t=0;t<c;t++)l.push(s[r+t]);if(p>1)for(const t of h){const r=t*c;if(!(s[r+2]<=e)){s[r+2]=e;for(let t=0;t<c;t++)l.push(s[r+t])}}}}return l}_getOriginId(t){return t-this.points.length>>5}_getOriginZoom(t){return(t-this.points.length)%32}_map(t,e,r){if(t[e+R]>1){const n=this.clusterProps[t[e+F]];return r?Object.assign({},n):n}const n=this.points[t[e+D]].properties,i=this.options.map(n);return r&&i===n?Object.assign({},i):i}}function N(t,e,r){return{type:\"Feature\",id:t[e+D],properties:j(t,e,r),geometry:{type:\"Point\",coordinates:[(n=t[e],360*(n-.5)),q(t[e+1])]}};var n}function j(t,e,r){const n=t[e+R],i=n>=1e4?`${Math.round(n/1e3)}k`:n>=1e3?Math.round(n/100)/10+\"k\":n,a=t[e+F],o=-1===a?{}:Object.assign({},r[a]);return Object.assign(o,{cluster:!0,cluster_id:t[e+D],point_count:n,point_count_abbreviated:i})}function U(t){return t/360+.5}function V(t){const e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function q(t){const e=(180-360*t)*Math.PI/180;return 360*Math.atan(Math.exp(e))/Math.PI-90}function H(t,e,r,n){let i=n;const a=e+(r-e>>1);let o,s=r-e;const l=t[e],c=t[e+1],u=t[r],h=t[r+1];for(let n=e+3;n<r;n+=3){const e=G(t[n],t[n+1],l,c,u,h);if(e>i)o=n,i=e;else if(e===i){const t=Math.abs(n-a);t<s&&(o=n,s=t)}}i>n&&(o-e>3&&H(t,e,o,n),t[o+2]=i,r-o>3&&H(t,o,r,n))}function G(t,e,r,n,i,a){let o=i-r,s=a-n;if(0!==o||0!==s){const l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return o=t-r,s=e-n,o*o+s*s}function Z(t,e,r,n){const i={id:null==t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};if(\"Point\"===e||\"MultiPoint\"===e||\"LineString\"===e)W(i,r);else if(\"Polygon\"===e)W(i,r[0]);else if(\"MultiLineString\"===e)for(const t of r)W(i,t);else if(\"MultiPolygon\"===e)for(const t of r)W(i,t[0]);return i}function W(t,e){for(let r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function Y(t,e,r,n){if(!e.geometry)return;const i=e.geometry.coordinates;if(i&&0===i.length)return;const a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2);let s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)X(i,s);else if(\"MultiPoint\"===a)for(const t of i)X(t,s);else if(\"LineString\"===a)$(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(const r of i)s=[],$(r,s,o,!1),t.push(Z(l,\"LineString\",s,e.properties));return}J(i,s,o,!1)}else if(\"Polygon\"===a)J(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(const i of e.geometry.geometries)Y(t,{id:l,geometry:i,properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(const t of i){const e=[];J(t,e,o,!0),s.push(e)}}t.push(Z(l,a,s,e.properties))}function X(t,e){e.push(K(t[0]),Q(t[1]),0)}function $(t,e,r,n){let i,a,o=0;for(let r=0;r<t.length;r++){const s=K(t[r][0]),l=Q(t[r][1]);e.push(s,l,0),r>0&&(o+=n?(i*l-s*a)/2:Math.sqrt(Math.pow(s-i,2)+Math.pow(l-a,2))),i=s,a=l}const s=e.length-3;e[2]=1,H(e,0,s,r),e[s+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function J(t,e,r,n){for(let i=0;i<t.length;i++){const a=[];$(t[i],a,r,n),e.push(a)}}function K(t){return t/360+.5}function Q(t){const e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function tt(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;const l=[];for(const e of t){const t=e.geometry;let a=e.type;const o=0===i?e.minX:e.minY,c=0===i?e.maxX:e.maxY;if(o>=r&&c<n){l.push(e);continue}if(c<r||o>=n)continue;let u=[];if(\"Point\"===a||\"MultiPoint\"===a)et(t,u,r,n,i);else if(\"LineString\"===a)rt(t,u,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===a)it(t,u,r,n,i,!1);else if(\"Polygon\"===a)it(t,u,r,n,i,!0);else if(\"MultiPolygon\"===a)for(const e of t){const t=[];it(e,t,r,n,i,!0),t.length&&u.push(t)}if(u.length){if(s.lineMetrics&&\"LineString\"===a){for(const t of u)l.push(Z(e.id,a,t,e.tags));continue}\"LineString\"!==a&&\"MultiLineString\"!==a||(1===u.length?(a=\"LineString\",u=u[0]):a=\"MultiLineString\"),\"Point\"!==a&&\"MultiPoint\"!==a||(a=3===u.length?\"Point\":\"MultiPoint\"),l.push(Z(e.id,a,u,e.tags))}}return l.length?l:null}function et(t,e,r,n,i){for(let a=0;a<t.length;a+=3){const o=t[a+i];o>=r&&o<=n&&at(e,t[a],t[a+1],t[a+2])}}function rt(t,e,r,n,i,a,o){let s=nt(t);const l=0===i?ot:st;let c,u,h=t.start;for(let f=0;f<t.length-3;f+=3){const p=t[f],d=t[f+1],m=t[f+2],g=t[f+3],y=t[f+4],v=0===i?p:d,x=0===i?g:y;let _=!1;o&&(c=Math.sqrt(Math.pow(p-g,2)+Math.pow(d-y,2))),v<r?x>r&&(u=l(s,p,d,g,y,r),o&&(s.start=h+c*u)):v>n?x<n&&(u=l(s,p,d,g,y,n),o&&(s.start=h+c*u)):at(s,p,d,m),x<r&&v>=r&&(u=l(s,p,d,g,y,r),_=!0),x>n&&v<=n&&(u=l(s,p,d,g,y,n),_=!0),!a&&_&&(o&&(s.end=h+c*u),e.push(s),s=nt(t)),o&&(h+=c)}let f=t.length-3;const p=t[f],d=t[f+1],m=t[f+2],g=0===i?p:d;g>=r&&g<=n&&at(s,p,d,m),f=s.length-3,a&&f>=3&&(s[f]!==s[0]||s[f+1]!==s[1])&&at(s,s[0],s[1],s[2]),s.length&&e.push(s)}function nt(t){const e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function it(t,e,r,n,i,a){for(const o of t)rt(o,e,r,n,i,a,!1)}function at(t,e,r,n){t.push(e,r,n)}function ot(t,e,r,n,i,a){const o=(a-e)/(n-e);return at(t,a,r+(i-r)*o,1),o}function st(t,e,r,n,i,a){const o=(a-r)/(i-r);return at(t,e+(n-e)*o,a,1),o}function lt(t,e){const r=[];for(let n=0;n<t.length;n++){const i=t[n],a=i.type;let o;if(\"Point\"===a||\"MultiPoint\"===a||\"LineString\"===a)o=ct(i.geometry,e);else if(\"MultiLineString\"===a||\"Polygon\"===a){o=[];for(const t of i.geometry)o.push(ct(t,e))}else if(\"MultiPolygon\"===a){o=[];for(const t of i.geometry){const r=[];for(const n of t)r.push(ct(n,e));o.push(r)}}r.push(Z(i.id,a,o,i.tags))}return r}function ct(t,e){const r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(let n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function ut(t,e){if(t.transformed)return t;const r=1<<t.z,n=t.x,i=t.y;for(const a of t.features){const t=a.geometry,o=a.type;if(a.geometry=[],1===o)for(let o=0;o<t.length;o+=2)a.geometry.push(ht(t[o],t[o+1],e,r,n,i));else for(let o=0;o<t.length;o++){const s=[];for(let a=0;a<t[o].length;a+=2)s.push(ht(t[o][a],t[o][a+1],e,r,n,i));a.geometry.push(s)}}return t.transformed=!0,t}function ht(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function ft(t,e,r,n,i){const a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:t.length,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0};for(const e of t)pt(o,e,a,i);return o}function pt(t,e,r,n){const i=e.geometry,a=e.type,o=[];if(t.minX=Math.min(t.minX,e.minX),t.minY=Math.min(t.minY,e.minY),t.maxX=Math.max(t.maxX,e.maxX),t.maxY=Math.max(t.maxY,e.maxY),\"Point\"===a||\"MultiPoint\"===a)for(let e=0;e<i.length;e+=3)o.push(i[e],i[e+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)dt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(let e=0;e<i.length;e++)dt(o,i[e],t,r,\"Polygon\"===a,0===e);else if(\"MultiPolygon\"===a)for(let e=0;e<i.length;e++){const n=i[e];for(let e=0;e<n.length;e++)dt(o,n[e],t,r,!0,0===e)}if(o.length){let r=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){r={};for(const t in e.tags)r[t]=e.tags[t];r.mapbox_clip_start=i.start/i.size,r.mapbox_clip_end=i.end/i.size}const s={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:r};null!==e.id&&(s.id=e.id),t.features.push(s)}}function dt(t,e,r,n,i,a){const o=n*n;if(n>0&&e.size<(i?o:n))return void(r.numPoints+=e.length/3);const s=[];for(let t=0;t<e.length;t+=3)(0===n||e[t+2]>o)&&(r.numSimplified++,s.push(e[t],e[t+1])),r.numPoints++;i&&function(t,e){let r=0;for(let e=0,n=t.length,i=n-2;e<n;i=e,e+=2)r+=(t[e]-t[i])*(t[e+1]+t[i+1]);if(r>0===e)for(let e=0,r=t.length;e<r/2;e+=2){const n=t[e],i=t[e+1];t[e]=t[r-2-e],t[e+1]=t[r-1-e],t[r-2-e]=n,t[r-1-e]=i}}(s,a),t.push(s)}const mt={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0};class gt{constructor(t,e){const r=(e=this.options=function(t,e){for(const r in e)t[r]=e[r];return t}(Object.create(mt),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");let n=function(t,e){const r=[];if(\"FeatureCollection\"===t.type)for(let n=0;n<t.features.length;n++)Y(r,t.features[n],e,n);else\"Feature\"===t.type?Y(r,t,e):Y(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),n=function(t,e){const r=e.buffer/e.extent;let n=t;const i=tt(t,1,-1-r,r,0,-1,2,e),a=tt(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=tt(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=lt(i,1).concat(n)),a&&(n=n.concat(lt(a,-1)))),n}(n,e),n.length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}splitTile(t,e,r,n,i,a,o){const s=[t,e,r,n],l=this.options,c=l.debug;for(;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();const u=1<<e,h=yt(e,r,n);let f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=ft(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));const t=`z${e}`;this.stats[t]=(this.stats[t]||0)+1,this.total++}if(f.source=t,null==i){if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue}else{if(e===l.maxZoom||e===i)continue;if(null!=i){const t=i-e;if(r!==a>>t||n!==o>>t)continue}}if(f.source=null,0===t.length)continue;c>1&&console.time(\"clipping\");const p=.5*l.buffer/l.extent,d=.5-p,m=.5+p,g=1+p;let y=null,v=null,x=null,_=null,b=tt(t,u,r-p,r+m,0,f.minX,f.maxX,l),w=tt(t,u,r+d,r+g,0,f.minX,f.maxX,l);t=null,b&&(y=tt(b,u,n-p,n+m,1,f.minY,f.maxY,l),v=tt(b,u,n+d,n+g,1,f.minY,f.maxY,l),b=null),w&&(x=tt(w,u,n-p,n+m,1,f.minY,f.maxY,l),_=tt(w,u,n+d,n+g,1,f.minY,f.maxY,l),w=null),c>1&&console.timeEnd(\"clipping\"),s.push(y||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(x||[],e+1,2*r+1,2*n),s.push(_||[],e+1,2*r+1,2*n+1)}}getTile(t,e,r){t=+t,e=+e,r=+r;const n=this.options,{extent:i,debug:a}=n;if(t<0||t>24)return null;const o=1<<t,s=yt(t,e=e+o&o-1,r);if(this.tiles[s])return ut(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);let l,c=t,u=e,h=r;for(;!l&&c>0;)c--,u>>=1,h>>=1,l=this.tiles[yt(c,u,h)];return l&&l.source?(a>1&&(console.log(\"found parent tile z%d-%d-%d\",c,u,h),console.time(\"drilling down\")),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?ut(this.tiles[s],i):null):null}}function yt(t,e,r){return 32*((1<<t)*r+e)+t}function vt(t,e){return e?t.properties[e]:t.id}function xt(t,e){if(null==t)return!0;if(\"Feature\"===t.type)return null!=vt(t,e);if(\"FeatureCollection\"===t.type){const r=new Set;for(const n of t.features){const t=vt(n,e);if(null==t)return!1;if(r.has(t))return!1;r.add(t)}return!0}return!1}function _t(t,e){const r=new Map;if(null==t);else if(\"Feature\"===t.type)r.set(vt(t,e),t);else for(const n of t.features)r.set(vt(n,e),n);return r}class bt extends a{constructor(){super(...arguments),this._dataUpdateable=new Map}loadVectorTile(e,r){return t._(this,void 0,void 0,(function*(){const t=e.tileID.canonical;if(!this._geoJSONIndex)throw new Error(\"Unable to parse the data into a cluster or geojson\");const r=this._geoJSONIndex.getTile(t.z,t.x,t.y);if(!r)return null;const n=new p(r.features);let i=I(n);return 0===i.byteOffset&&i.byteLength===i.buffer.byteLength||(i=new Uint8Array(i)),{vectorTile:n,rawData:i.buffer}}))}loadData(e){return t._(this,void 0,void 0,(function*(){var r;null===(r=this._pendingRequest)||void 0===r||r.abort();const n=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.bu(e.request);this._pendingRequest=new AbortController;try{this._pendingData=this.loadAndProcessGeoJSON(e,this._pendingRequest),this._geoJSONIndex=e.cluster?new B(function({superclusterOptions:e,clusterProperties:r}){if(!r||!e)return e;const n={},i={},a={accumulated:null,zoom:0},o={properties:null},s=Object.keys(r);for(const e of s){const[a,o]=r[e],s=t.bB(o),l=t.bB(\"string\"==typeof a?[a,[\"accumulated\"],[\"get\",e]]:a);n[e]=s.value,i[e]=l.value}return e.map=t=>{o.properties=t;const e={};for(const t of s)e[t]=n[t].evaluate(a,o);return e},e.reduce=(t,e)=>{o.properties=e;for(const e of s)a.accumulated=t[e],t[e]=i[e].evaluate(a,o)},e}(e)).load((yield this._pendingData).features):(i=yield this._pendingData,a=e.geojsonVtOptions,new gt(i,a)),this.loaded={};const r={};if(n){const t=n.finish();t&&(r.resourceTiming={},r.resourceTiming[e.source]=JSON.parse(JSON.stringify(t)))}return r}catch(e){if(delete this._pendingRequest,t.bA(e))return{abandoned:!0};throw e}var i,a}))}getData(){return t._(this,void 0,void 0,(function*(){return this._pendingData}))}reloadTile(t){const e=this.loaded,r=t.uid;return e&&e[r]?super.reloadTile(t):this.loadTile(t)}loadAndProcessGeoJSON(e,r){return t._(this,void 0,void 0,(function*(){let n=yield this.loadGeoJSON(e,r);if(delete this._pendingRequest,\"object\"!=typeof n)throw new Error(`Input data given to '${e.source}' is not a valid GeoJSON object.`);if(u(n,!0),e.filter){const r=t.bB(e.filter,{type:\"boolean\",\"property-type\":\"data-driven\",overridable:!1,transition:!1});if(\"error\"===r.result)throw new Error(r.value.map((t=>`${t.key}: ${t.message}`)).join(\", \"));const i=n.features.filter((t=>r.value.evaluate({zoom:0},t)));n={type:\"FeatureCollection\",features:i}}return n}))}loadGeoJSON(e,r){return t._(this,void 0,void 0,(function*(){const{promoteId:n}=e;if(e.request){const i=yield t.h(e.request,r);return this._dataUpdateable=xt(i.data,n)?_t(i.data,n):void 0,i.data}if(\"string\"==typeof e.data)try{const t=JSON.parse(e.data);return this._dataUpdateable=xt(t,n)?_t(t,n):void 0,t}catch(t){throw new Error(`Input data given to '${e.source}' is not a valid GeoJSON object.`)}if(!e.dataDiff)throw new Error(`Input data given to '${e.source}' is not a valid GeoJSON object.`);if(!this._dataUpdateable)throw new Error(`Cannot update existing geojson data in ${e.source}`);return function(t,e,r){var n,i,a,o;if(e.removeAll&&t.clear(),e.remove)for(const r of e.remove)t.delete(r);if(e.add)for(const n of e.add){const e=vt(n,r);null!=e&&t.set(e,n)}if(e.update)for(const r of e.update){let e=t.get(r.id);if(null==e)continue;const s=r.newGeometry||r.removeAllProperties,l=!r.removeAllProperties&&((null===(n=r.removeProperties)||void 0===n?void 0:n.length)>0||(null===(i=r.addOrUpdateProperties)||void 0===i?void 0:i.length)>0);if((s||l)&&(e=Object.assign({},e),t.set(r.id,e),l&&(e.properties=Object.assign({},e.properties))),r.newGeometry&&(e.geometry=r.newGeometry),r.removeAllProperties)e.properties={};else if((null===(a=r.removeProperties)||void 0===a?void 0:a.length)>0)for(const t of r.removeProperties)Object.prototype.hasOwnProperty.call(e.properties,t)&&delete e.properties[t];if((null===(o=r.addOrUpdateProperties)||void 0===o?void 0:o.length)>0)for(const{key:t,value:n}of r.addOrUpdateProperties)e.properties[t]=n}}(this._dataUpdateable,e.dataDiff,n),{type:\"FeatureCollection\",features:Array.from(this._dataUpdateable.values())}}))}removeSource(e){return t._(this,void 0,void 0,(function*(){this._pendingRequest&&this._pendingRequest.abort()}))}getClusterExpansionZoom(t){return this._geoJSONIndex.getClusterExpansionZoom(t.clusterId)}getClusterChildren(t){return this._geoJSONIndex.getChildren(t.clusterId)}getClusterLeaves(t){return this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset)}}class wt{constructor(e){this.self=e,this.actor=new t.F(e),this.layerIndexes={},this.availableImages={},this.workerSources={},this.demWorkerSources={},this.externalWorkerSourceTypes={},this.self.registerWorkerSource=(t,e)=>{if(this.externalWorkerSourceTypes[t])throw new Error(`Worker source with name \"${t}\" already registered.`);this.externalWorkerSourceTypes[t]=e},this.self.addProtocol=t.bh,this.self.removeProtocol=t.bi,this.self.registerRTLTextPlugin=e=>{if(t.bC.isParsed())throw new Error(\"RTL text plugin already registered.\");t.bC.setMethods(e)},this.actor.registerMessageHandler(\"LDT\",((t,e)=>this._getDEMWorkerSource(t,e.source).loadTile(e))),this.actor.registerMessageHandler(\"RDT\",((e,r)=>t._(this,void 0,void 0,(function*(){this._getDEMWorkerSource(e,r.source).removeTile(r)})))),this.actor.registerMessageHandler(\"GCEZ\",((e,r)=>t._(this,void 0,void 0,(function*(){return this._getWorkerSource(e,r.type,r.source).getClusterExpansionZoom(r)})))),this.actor.registerMessageHandler(\"GCC\",((e,r)=>t._(this,void 0,void 0,(function*(){return this._getWorkerSource(e,r.type,r.source).getClusterChildren(r)})))),this.actor.registerMessageHandler(\"GCL\",((e,r)=>t._(this,void 0,void 0,(function*(){return this._getWorkerSource(e,r.type,r.source).getClusterLeaves(r)})))),this.actor.registerMessageHandler(\"LD\",((t,e)=>this._getWorkerSource(t,e.type,e.source).loadData(e))),this.actor.registerMessageHandler(\"GD\",((t,e)=>this._getWorkerSource(t,e.type,e.source).getData())),this.actor.registerMessageHandler(\"LT\",((t,e)=>this._getWorkerSource(t,e.type,e.source).loadTile(e))),this.actor.registerMessageHandler(\"RT\",((t,e)=>this._getWorkerSource(t,e.type,e.source).reloadTile(e))),this.actor.registerMessageHandler(\"AT\",((t,e)=>this._getWorkerSource(t,e.type,e.source).abortTile(e))),this.actor.registerMessageHandler(\"RMT\",((t,e)=>this._getWorkerSource(t,e.type,e.source).removeTile(e))),this.actor.registerMessageHandler(\"RS\",((e,r)=>t._(this,void 0,void 0,(function*(){if(!this.workerSources[e]||!this.workerSources[e][r.type]||!this.workerSources[e][r.type][r.source])return;const t=this.workerSources[e][r.type][r.source];delete this.workerSources[e][r.type][r.source],void 0!==t.removeSource&&t.removeSource(r)})))),this.actor.registerMessageHandler(\"RM\",(e=>t._(this,void 0,void 0,(function*(){delete this.layerIndexes[e],delete this.availableImages[e],delete this.workerSources[e],delete this.demWorkerSources[e]})))),this.actor.registerMessageHandler(\"SR\",((e,r)=>t._(this,void 0,void 0,(function*(){this.referrer=r})))),this.actor.registerMessageHandler(\"SRPS\",((t,e)=>this._syncRTLPluginState(t,e))),this.actor.registerMessageHandler(\"IS\",((e,r)=>t._(this,void 0,void 0,(function*(){this.self.importScripts(r)})))),this.actor.registerMessageHandler(\"SI\",((t,e)=>this._setImages(t,e))),this.actor.registerMessageHandler(\"UL\",((e,r)=>t._(this,void 0,void 0,(function*(){this._getLayerIndex(e).update(r.layers,r.removedIds)})))),this.actor.registerMessageHandler(\"SL\",((e,r)=>t._(this,void 0,void 0,(function*(){this._getLayerIndex(e).replace(r)}))))}_setImages(e,r){return t._(this,void 0,void 0,(function*(){this.availableImages[e]=r;for(const t in this.workerSources[e]){const n=this.workerSources[e][t];for(const t in n)n[t].availableImages=r}}))}_syncRTLPluginState(e,r){return t._(this,void 0,void 0,(function*(){if(t.bC.isParsed())return t.bC.getState();if(\"loading\"!==r.pluginStatus)return t.bC.setState(r),r;const e=r.pluginURL;if(this.self.importScripts(e),t.bC.isParsed()){const r={pluginStatus:\"loaded\",pluginURL:e};return t.bC.setState(r),r}throw t.bC.setState({pluginStatus:\"error\",pluginURL:\"\"}),new Error(`RTL Text Plugin failed to import scripts from ${e}`)}))}_getAvailableImages(t){let e=this.availableImages[t];return e||(e=[]),e}_getLayerIndex(t){let r=this.layerIndexes[t];return r||(r=this.layerIndexes[t]=new e),r}_getWorkerSource(t,e,r){if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){const n={sendAsync:(e,r)=>(e.targetMapId=t,this.actor.sendAsync(e,r))};switch(e){case\"vector\":this.workerSources[t][e][r]=new a(n,this._getLayerIndex(t),this._getAvailableImages(t));break;case\"geojson\":this.workerSources[t][e][r]=new bt(n,this._getLayerIndex(t),this._getAvailableImages(t));break;default:this.workerSources[t][e][r]=new this.externalWorkerSourceTypes[e](n,this._getLayerIndex(t),this._getAvailableImages(t))}}return this.workerSources[t][e][r]}_getDEMWorkerSource(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new o),this.demWorkerSources[t][e]}}return t.i(self)&&(self.worker=new wt(self)),wt})),r(\"index\",0,(function(t,e){var r=\"4.5.2\";let n,i;const a={now:\"undefined\"!=typeof performance&&performance&&performance.now?performance.now.bind(performance):Date.now.bind(Date),frameAsync(t){return new Promise(((r,n)=>{const i=requestAnimationFrame(r);t.signal.addEventListener(\"abort\",(()=>{cancelAnimationFrame(i),n(e.c())}))}))},getImageData(t,e=0){return this.getImageCanvasContext(t).getImageData(-e,-e,t.width+2*e,t.height+2*e)},getImageCanvasContext(t){const e=window.document.createElement(\"canvas\"),r=e.getContext(\"2d\",{willReadFrequently:!0});if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r},resolveURL(t){return n||(n=document.createElement(\"a\")),n.href=t,n.href},hardwareConcurrency:\"undefined\"!=typeof navigator&&navigator.hardwareConcurrency||4,get prefersReducedMotion(){return!!matchMedia&&(null==i&&(i=matchMedia(\"(prefers-reduced-motion: reduce)\")),i.matches)}};class o{static testProp(t){if(!o.docStyle)return t[0];for(let e=0;e<t.length;e++)if(t[e]in o.docStyle)return t[e];return t[0]}static create(t,e,r){const n=window.document.createElement(t);return void 0!==e&&(n.className=e),r&&r.appendChild(n),n}static createNS(t,e){return window.document.createElementNS(t,e)}static disableDrag(){o.docStyle&&o.selectProp&&(o.userSelect=o.docStyle[o.selectProp],o.docStyle[o.selectProp]=\"none\")}static enableDrag(){o.docStyle&&o.selectProp&&(o.docStyle[o.selectProp]=o.userSelect)}static setTransform(t,e){t.style[o.transformProp]=e}static addEventListener(t,e,r,n={}){\"passive\"in n?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)}static removeEventListener(t,e,r,n={}){\"passive\"in n?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)}static suppressClickInternal(t){t.preventDefault(),t.stopPropagation(),window.removeEventListener(\"click\",o.suppressClickInternal,!0)}static suppressClick(){window.addEventListener(\"click\",o.suppressClickInternal,!0),window.setTimeout((()=>{window.removeEventListener(\"click\",o.suppressClickInternal,!0)}),0)}static getScale(t){const e=t.getBoundingClientRect();return{x:e.width/t.offsetWidth||1,y:e.height/t.offsetHeight||1,boundingClientRect:e}}static getPoint(t,r,n){const i=r.boundingClientRect;return new e.P((n.clientX-i.left)/r.x-t.clientLeft,(n.clientY-i.top)/r.y-t.clientTop)}static mousePos(t,e){const r=o.getScale(t);return o.getPoint(t,r,e)}static touchPos(t,e){const r=[],n=o.getScale(t);for(let i=0;i<e.length;i++)r.push(o.getPoint(t,n,e[i]));return r}static mouseButton(t){return t.button}static remove(t){t.parentNode&&t.parentNode.removeChild(t)}}o.docStyle=\"undefined\"!=typeof window&&window.document&&window.document.documentElement.style,o.selectProp=o.testProp([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]),o.transformProp=o.testProp([\"transform\",\"WebkitTransform\"]);const s={supported:!1,testSupport:function(t){!u&&c&&(h?f(t):l=t)}};let l,c,u=!1,h=!1;function f(t){const e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,c),t.isContextLost())return;s.supported=!0}catch(t){}t.deleteTexture(e),u=!0}var p;\"undefined\"!=typeof document&&(c=document.createElement(\"img\"),c.onload=()=>{l&&f(l),l=null,h=!0},c.onerror=()=>{u=!0,l=null},c.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\"),function(t){let r,n,i,a;t.resetRequestQueue=()=>{r=[],n=0,i=0,a={}},t.addThrottleControl=t=>{const e=i++;return a[e]=t,e},t.removeThrottleControl=t=>{delete a[t],l()};t.getImage=(t,n,i=!0)=>new Promise(((a,o)=>{s.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),e.e(t,{type:\"image\"});const c={abortController:n,requestParameters:t,supportImageRefresh:i,state:\"queued\",onError:t=>{o(t)},onSuccess:t=>{a(t)}};r.push(c),l()}));const o=t=>e._(this,void 0,void 0,(function*(){t.state=\"running\";const{requestParameters:r,supportImageRefresh:i,onError:a,onSuccess:o,abortController:s}=t,u=!1===i&&!e.i(self)&&!e.g(r.url)&&(!r.headers||Object.keys(r.headers).reduce(((t,e)=>t&&\"accept\"===e),!0));n++;const h=u?c(r,s):e.m(r,s);try{const r=yield h;delete t.abortController,t.state=\"completed\",r.data instanceof HTMLImageElement||e.b(r.data)?o(r):r.data&&o({data:yield(f=r.data,\"function\"==typeof createImageBitmap?e.d(f):e.f(f)),cacheControl:r.cacheControl,expires:r.expires})}catch(e){delete t.abortController,a(e)}finally{n--,l()}var f})),l=()=>{const t=(()=>{for(const t of Object.keys(a))if(a[t]())return!0;return!1})()?e.a.MAX_PARALLEL_IMAGE_REQUESTS_PER_FRAME:e.a.MAX_PARALLEL_IMAGE_REQUESTS;for(let e=n;e<t&&r.length>0;e++){const t=r.shift();t.abortController.signal.aborted?e--:o(t)}},c=(t,r)=>new Promise(((n,i)=>{const a=new Image,o=t.url,s=t.credentials;s&&\"include\"===s?a.crossOrigin=\"use-credentials\":(s&&\"same-origin\"===s||!e.s(o))&&(a.crossOrigin=\"anonymous\"),r.signal.addEventListener(\"abort\",(()=>{a.src=\"\",i(e.c())})),a.fetchPriority=\"high\",a.onload=()=>{a.onerror=a.onload=null,n({data:a})},a.onerror=()=>{a.onerror=a.onload=null,r.signal.aborted||i(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))},a.src=o}))}(p||(p={})),p.resetRequestQueue();class d{constructor(t){this._transformRequestFn=t}transformRequest(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}}setTransformRequest(t){this._transformRequestFn=t}}function m(t){var r=new e.A(3);return r[0]=t[0],r[1]=t[1],r[2]=t[2],r}var g,y=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t};g=new e.A(3),e.A!=Float32Array&&(g[0]=0,g[1]=0,g[2]=0);var v=function(t){var e=t[0],r=t[1];return e*e+r*r};function x(t){const e=[];if(\"string\"==typeof t)e.push({id:\"default\",url:t});else if(t&&t.length>0){const r=[];for(const{id:n,url:i}of t){const t=`${n}${i}`;-1===r.indexOf(t)&&(r.push(t),e.push({id:n,url:i}))}}return e}function _(t,e,r){const n=t.split(\"?\");return n[0]+=`${e}${r}`,n.join(\"?\")}function b(t,r,n,i){return e._(this,void 0,void 0,(function*(){const o=x(t),s=n>1?\"@2x\":\"\",l={},c={};for(const{id:t,url:n}of o){const a=r.transformRequest(_(n,s,\".json\"),\"SpriteJSON\");l[t]=e.h(a,i);const o=r.transformRequest(_(n,s,\".png\"),\"SpriteImage\");c[t]=p.getImage(o,i)}return yield Promise.all([...Object.values(l),...Object.values(c)]),function(t,r){return e._(this,void 0,void 0,(function*(){const e={};for(const n in t){e[n]={};const i=a.getImageCanvasContext((yield r[n]).data),o=(yield t[n]).data;for(const t in o){const{width:r,height:a,x:s,y:l,sdf:c,pixelRatio:u,stretchX:h,stretchY:f,content:p,textFitWidth:d,textFitHeight:m}=o[t],g={width:r,height:a,x:s,y:l,context:i};e[n][t]={data:null,pixelRatio:u,sdf:c,stretchX:h,stretchY:f,content:p,textFitWidth:d,textFitHeight:m,spriteData:g}}}return e}))}(l,c)}))}!function(){var t=new e.A(2);e.A!=Float32Array&&(t[0]=0,t[1]=0)}();class w{constructor(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)}update(t,r,n){const{width:i,height:a}=t,o=!(this.size&&this.size[0]===i&&this.size[1]===a||n),{context:s}=this,{gl:l}=s;if(this.useMipmap=Boolean(r&&r.useMipmap),l.bindTexture(l.TEXTURE_2D,this.texture),s.pixelStoreUnpackFlipY.set(!1),s.pixelStoreUnpack.set(1),s.pixelStoreUnpackPremultiplyAlpha.set(this.format===l.RGBA&&(!r||!1!==r.premultiply)),o)this.size=[i,a],t instanceof HTMLImageElement||t instanceof HTMLCanvasElement||t instanceof HTMLVideoElement||t instanceof ImageData||e.b(t)?l.texImage2D(l.TEXTURE_2D,0,this.format,this.format,l.UNSIGNED_BYTE,t):l.texImage2D(l.TEXTURE_2D,0,this.format,i,a,0,this.format,l.UNSIGNED_BYTE,t.data);else{const{x:r,y:o}=n||{x:0,y:0};t instanceof HTMLImageElement||t instanceof HTMLCanvasElement||t instanceof HTMLVideoElement||t instanceof ImageData||e.b(t)?l.texSubImage2D(l.TEXTURE_2D,0,r,o,l.RGBA,l.UNSIGNED_BYTE,t):l.texSubImage2D(l.TEXTURE_2D,0,r,o,i,a,l.RGBA,l.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&l.generateMipmap(l.TEXTURE_2D)}bind(t,e,r){const{context:n}=this,{gl:i}=n;i.bindTexture(i.TEXTURE_2D,this.texture),r!==i.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=i.LINEAR),t!==this.filter&&(i.texParameteri(i.TEXTURE_2D,i.TEXTURE_MAG_FILTER,t),i.texParameteri(i.TEXTURE_2D,i.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(i.texParameteri(i.TEXTURE_2D,i.TEXTURE_WRAP_S,e),i.texParameteri(i.TEXTURE_2D,i.TEXTURE_WRAP_T,e),this.wrap=e)}isSizePowerOfTwo(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0}destroy(){const{gl:t}=this.context;t.deleteTexture(this.texture),this.texture=null}}function T(t){const{userImage:e}=t;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}class k extends e.E{constructor(){super(),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new e.R({width:1,height:1}),this.dirty=!0}isLoaded(){return this.loaded}setLoaded(t){if(this.loaded!==t&&(this.loaded=t,t)){for(const{ids:t,promiseResolve:e}of this.requestors)e(this._getImagesForIds(t));this.requestors=[]}}getImage(t){const r=this.images[t];if(r&&!r.data&&r.spriteData){const t=r.spriteData;r.data=new e.R({width:t.width,height:t.height},t.context.getImageData(t.x,t.y,t.width,t.height).data),r.spriteData=null}return r}addImage(t,e){if(this.images[t])throw new Error(`Image id ${t} already exist, use updateImage instead`);this._validate(t,e)&&(this.images[t]=e)}_validate(t,r){let n=!0;const i=r.data||r.spriteData;return this._validateStretch(r.stretchX,i&&i.width)||(this.fire(new e.j(new Error(`Image \"${t}\" has invalid \"stretchX\" value`))),n=!1),this._validateStretch(r.stretchY,i&&i.height)||(this.fire(new e.j(new Error(`Image \"${t}\" has invalid \"stretchY\" value`))),n=!1),this._validateContent(r.content,r)||(this.fire(new e.j(new Error(`Image \"${t}\" has invalid \"content\" value`))),n=!1),n}_validateStretch(t,e){if(!t)return!0;let r=0;for(const n of t){if(n[0]<r||n[1]<n[0]||e<n[1])return!1;r=n[1]}return!0}_validateContent(t,e){if(!t)return!0;if(4!==t.length)return!1;const r=e.spriteData,n=r&&r.width||e.data.width,i=r&&r.height||e.data.height;return!(t[0]<0||n<t[0]||t[1]<0||i<t[1]||t[2]<0||n<t[2]||t[3]<0||i<t[3]||t[2]<t[0]||t[3]<t[1])}updateImage(t,e,r=!0){const n=this.getImage(t);if(r&&(n.data.width!==e.data.width||n.data.height!==e.data.height))throw new Error(`size mismatch between old image (${n.data.width}x${n.data.height}) and new image (${e.data.width}x${e.data.height}).`);e.version=n.version+1,this.images[t]=e,this.updatedImages[t]=!0}removeImage(t){const e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()}listImages(){return Object.keys(this.images)}getImages(t){return new Promise(((e,r)=>{let n=!0;if(!this.isLoaded())for(const e of t)this.images[e]||(n=!1);this.isLoaded()||n?e(this._getImagesForIds(t)):this.requestors.push({ids:t,promiseResolve:e})}))}_getImagesForIds(t){const r={};for(const n of t){let t=this.getImage(n);t||(this.fire(new e.k(\"styleimagemissing\",{id:n})),t=this.getImage(n)),t?r[n]={data:t.data.clone(),pixelRatio:t.pixelRatio,sdf:t.sdf,version:t.version,stretchX:t.stretchX,stretchY:t.stretchY,content:t.content,textFitWidth:t.textFitWidth,textFitHeight:t.textFitHeight,hasRenderCallback:Boolean(t.userImage&&t.userImage.render)}:e.w(`Image \"${n}\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.`)}return r}getPixelSize(){const{width:t,height:e}=this.atlasImage;return{width:t,height:e}}getPattern(t){const r=this.patterns[t],n=this.getImage(t);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{const r={w:n.data.width+2,h:n.data.height+2,x:0,y:0},i=new e.I(r,n);this.patterns[t]={bin:r,position:i}}return this._updatePatternAtlas(),this.patterns[t].position}bind(t){const e=t.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new w(t,this.atlasImage,e.RGBA),this.atlasTexture.bind(e.LINEAR,e.CLAMP_TO_EDGE)}_updatePatternAtlas(){const t=[];for(const e in this.patterns)t.push(this.patterns[e].bin);const{w:r,h:n}=e.p(t),i=this.atlasImage;i.resize({width:r||1,height:n||1});for(const t in this.patterns){const{bin:r}=this.patterns[t],n=r.x+1,a=r.y+1,o=this.getImage(t).data,s=o.width,l=o.height;e.R.copy(o,i,{x:0,y:0},{x:n,y:a},{width:s,height:l}),e.R.copy(o,i,{x:0,y:l-1},{x:n,y:a-1},{width:s,height:1}),e.R.copy(o,i,{x:0,y:0},{x:n,y:a+l},{width:s,height:1}),e.R.copy(o,i,{x:s-1,y:0},{x:n-1,y:a},{width:1,height:l}),e.R.copy(o,i,{x:0,y:0},{x:n+s,y:a},{width:1,height:l})}this.dirty=!0}beginFrame(){this.callbackDispatchedThisFrame={}}dispatchRenderCallbacks(t){for(const r of t){if(this.callbackDispatchedThisFrame[r])continue;this.callbackDispatchedThisFrame[r]=!0;const t=this.getImage(r);t||e.w(`Image with ID: \"${r}\" was not found`),T(t)&&this.updateImage(r,t)}}}const A=1e20;function M(t,e,r,n,i,a,o,s,l){for(let c=e;c<e+n;c++)S(t,r*a+c,a,i,o,s,l);for(let c=r;c<r+i;c++)S(t,c*a+e,1,n,o,s,l)}function S(t,e,r,n,i,a,o){a[0]=0,o[0]=-A,o[1]=A,i[0]=t[e];for(let s=1,l=0,c=0;s<n;s++){i[s]=t[e+s*r];const n=s*s;do{const t=a[l];c=(i[s]-i[t]+n-t*t)/(s-t)/2}while(c<=o[l]&&--l>-1);l++,a[l]=s,o[l]=c,o[l+1]=A}for(let s=0,l=0;s<n;s++){for(;o[l+1]<s;)l++;const n=a[l],c=s-n;t[e+s*r]=i[n]+c*c}}class E{constructor(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}}setURL(t){this.url=t}getGlyphs(t){return e._(this,void 0,void 0,(function*(){const e=[];for(const r in t)for(const n of t[r])e.push(this._getAndCacheGlyphsPromise(r,n));const r=yield Promise.all(e),n={};for(const{stack:t,id:e,glyph:i}of r)n[t]||(n[t]={}),n[t][e]=i&&{id:i.id,bitmap:i.bitmap.clone(),metrics:i.metrics};return n}))}_getAndCacheGlyphsPromise(t,r){return e._(this,void 0,void 0,(function*(){let e=this.entries[t];e||(e=this.entries[t]={glyphs:{},requests:{},ranges:{}});let n=e.glyphs[r];if(void 0!==n)return{stack:t,id:r,glyph:n};if(n=this._tinySDF(e,t,r),n)return e.glyphs[r]=n,{stack:t,id:r,glyph:n};const i=Math.floor(r/256);if(256*i>65535)throw new Error(\"glyphs > 65535 not supported\");if(e.ranges[i])return{stack:t,id:r,glyph:n};if(!this.url)throw new Error(\"glyphsUrl is not set\");if(!e.requests[i]){const r=E.loadGlyphRange(t,i,this.url,this.requestManager);e.requests[i]=r}const a=yield e.requests[i];for(const t in a)this._doesCharSupportLocalGlyph(+t)||(e.glyphs[+t]=a[+t]);return e.ranges[i]=!0,{stack:t,id:r,glyph:a[r]||null}}))}_doesCharSupportLocalGlyph(t){return!!this.localIdeographFontFamily&&(e.u[\"CJK Unified Ideographs\"](t)||e.u[\"Hangul Syllables\"](t)||e.u.Hiragana(t)||e.u.Katakana(t))}_tinySDF(t,r,n){const i=this.localIdeographFontFamily;if(!i)return;if(!this._doesCharSupportLocalGlyph(n))return;let a=t.tinySDF;if(!a){let e=\"400\";/bold/i.test(r)?e=\"900\":/medium/i.test(r)?e=\"500\":/light/i.test(r)&&(e=\"200\"),a=t.tinySDF=new E.TinySDF({fontSize:48,buffer:6,radius:16,cutoff:.25,fontFamily:i,fontWeight:e})}const o=a.draw(String.fromCharCode(n));return{id:n,bitmap:new e.o({width:o.width||60,height:o.height||60},o.data),metrics:{width:o.glyphWidth/2||24,height:o.glyphHeight/2||24,left:o.glyphLeft/2+.5||0,top:o.glyphTop/2-27.5||-8,advance:o.glyphAdvance/2||24,isDoubleResolution:!0}}}}E.loadGlyphRange=function(t,r,n,i){return e._(this,void 0,void 0,(function*(){const a=256*r,o=a+255,s=i.transformRequest(n.replace(\"{fontstack}\",t).replace(\"{range}\",`${a}-${o}`),\"Glyphs\"),l=yield e.l(s,new AbortController);if(!l||!l.data)throw new Error(`Could not load glyph range. range: ${r}, ${a}-${o}`);const c={};for(const t of e.n(l.data))c[t.id]=t;return c}))},E.TinySDF=class{constructor({fontSize:t=24,buffer:e=3,radius:r=8,cutoff:n=.25,fontFamily:i=\"sans-serif\",fontWeight:a=\"normal\",fontStyle:o=\"normal\"}={}){this.buffer=e,this.cutoff=n,this.radius=r;const s=this.size=t+4*e,l=this._createCanvas(s),c=this.ctx=l.getContext(\"2d\",{willReadFrequently:!0});c.font=`${o} ${a} ${t}px ${i}`,c.textBaseline=\"alphabetic\",c.textAlign=\"left\",c.fillStyle=\"black\",this.gridOuter=new Float64Array(s*s),this.gridInner=new Float64Array(s*s),this.f=new Float64Array(s),this.z=new Float64Array(s+1),this.v=new Uint16Array(s)}_createCanvas(t){const e=document.createElement(\"canvas\");return e.width=e.height=t,e}draw(t){const{width:e,actualBoundingBoxAscent:r,actualBoundingBoxDescent:n,actualBoundingBoxLeft:i,actualBoundingBoxRight:a}=this.ctx.measureText(t),o=Math.ceil(r),s=Math.max(0,Math.min(this.size-this.buffer,Math.ceil(a-i))),l=Math.min(this.size-this.buffer,o+Math.ceil(n)),c=s+2*this.buffer,u=l+2*this.buffer,h=Math.max(c*u,0),f=new Uint8ClampedArray(h),p={data:f,width:c,height:u,glyphWidth:s,glyphHeight:l,glyphTop:o,glyphLeft:0,glyphAdvance:e};if(0===s||0===l)return p;const{ctx:d,buffer:m,gridInner:g,gridOuter:y}=this;d.clearRect(m,m,s,l),d.fillText(t,m,m+o);const v=d.getImageData(m,m,s,l);y.fill(A,0,h),g.fill(0,0,h);for(let t=0;t<l;t++)for(let e=0;e<s;e++){const r=v.data[4*(t*s+e)+3]/255;if(0===r)continue;const n=(t+m)*c+e+m;if(1===r)y[n]=0,g[n]=A;else{const t=.5-r;y[n]=t>0?t*t:0,g[n]=t<0?t*t:0}}M(y,0,0,c,u,c,this.f,this.v,this.z),M(g,m,m,s,l,c,this.f,this.v,this.z);for(let t=0;t<h;t++){const e=Math.sqrt(y[t])-Math.sqrt(g[t]);f[t]=Math.round(255-255*(e/this.radius+this.cutoff))}return p}};class C{constructor(){this.specification=e.v.light.position}possiblyEvaluate(t,r){return e.y(t.expression.evaluate(r))}interpolate(t,r,n){return{x:e.z.number(t.x,r.x,n),y:e.z.number(t.y,r.y,n),z:e.z.number(t.z,r.z,n)}}}const L=\"-transition\";let I;class P extends e.E{constructor(t){super(),I=I||new e.q({anchor:new e.D(e.v.light.anchor),position:new C,color:new e.D(e.v.light.color),intensity:new e.D(e.v.light.intensity)}),this._transitionable=new e.T(I),this.setLight(t),this._transitioning=this._transitionable.untransitioned()}getLight(){return this._transitionable.serialize()}setLight(t,r={}){if(!this._validate(e.r,t,r))for(const e in t){const r=t[e];e.endsWith(L)?this._transitionable.setTransition(e.slice(0,-11),r):this._transitionable.setValue(e,r)}}updateTransitions(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)}hasTransition(){return this._transitioning.hasTransition()}recalculate(t){this.properties=this._transitioning.possiblyEvaluate(t)}_validate(t,r,n){return(!n||!1!==n.validate)&&e.t(this,t.call(e.x,{value:r,style:{glyphs:!0,sprite:!0},styleSpec:e.v}))}}const z=new e.q({\"sky-color\":new e.D(e.v.sky[\"sky-color\"]),\"horizon-color\":new e.D(e.v.sky[\"horizon-color\"]),\"fog-color\":new e.D(e.v.sky[\"fog-color\"]),\"fog-ground-blend\":new e.D(e.v.sky[\"fog-ground-blend\"]),\"horizon-fog-blend\":new e.D(e.v.sky[\"horizon-fog-blend\"]),\"sky-horizon-blend\":new e.D(e.v.sky[\"sky-horizon-blend\"]),\"atmosphere-blend\":new e.D(e.v.sky[\"atmosphere-blend\"])}),O=\"-transition\";class D extends e.E{constructor(t){super(),this._transitionable=new e.T(z),this.setSky(t),this._transitioning=this._transitionable.untransitioned()}setSky(t,r={}){if(!this._validate(e.B,t,r))for(const e in t){const r=t[e];e.endsWith(O)?this._transitionable.setTransition(e.slice(0,-11),r):this._transitionable.setValue(e,r)}}getSky(){return this._transitionable.serialize()}updateTransitions(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)}hasTransition(){return this._transitioning.hasTransition()}recalculate(t){this.properties=this._transitioning.possiblyEvaluate(t)}_validate(t,r,n={}){return!1!==(null==n?void 0:n.validate)&&e.t(this,t.call(e.x,e.e({value:r,style:{glyphs:!0,sprite:!0},styleSpec:e.v})))}calculateFogBlendOpacity(t){return t<60?0:t<70?(t-60)/10:1}}class R{constructor(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}}getDash(t,e){const r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]}getDashRanges(t,e,r){const n=[];let i=t.length%2==1?-t[t.length-1]*r:0,a=t[0]*r,o=!0;n.push({left:i,right:a,isDash:o,zeroLength:0===t[0]});let s=t[0];for(let e=1;e<t.length;e++){o=!o;const l=t[e];i=s*r,s+=l,a=s*r,n.push({left:i,right:a,isDash:o,zeroLength:0===l})}return n}addRoundDash(t,e,r){const n=e/2;for(let e=-r;e<=r;e++){const i=this.nextRow+r+e,a=this.width*i;let o=0,s=t[o];for(let i=0;i<this.width;i++){i/s.right>1&&(s=t[++o]);const l=Math.abs(i-s.left),c=Math.abs(i-s.right),u=Math.min(l,c);let h;const f=e/r*(n+1);if(s.isDash){const t=n-Math.abs(f);h=Math.sqrt(u*u+t*t)}else h=n-Math.sqrt(u*u+f*f);this.data[a+i]=Math.max(0,Math.min(255,h+128))}}}addRegularDash(t){for(let e=t.length-1;e>=0;--e){const r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}const e=t[0],r=t[t.length-1];e.isDash===r.isDash&&(e.left=r.left-this.width,r.right=e.right+this.width);const n=this.width*this.nextRow;let i=0,a=t[i];for(let e=0;e<this.width;e++){e/a.right>1&&(a=t[++i]);const r=Math.abs(e-a.left),o=Math.abs(e-a.right),s=Math.min(r,o),l=a.isDash?s:-s;this.data[n+e]=Math.max(0,Math.min(255,l+128))}}addDash(t,r){const n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return e.w(\"LineAtlas out of space\"),null;let a=0;for(let e=0;e<t.length;e++)a+=t[e];if(0!==a){const e=this.width/a,i=this.getDashRanges(t,this.width,e);r?this.addRoundDash(i,e,n):this.addRegularDash(i)}const o={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,o}bind(t){const e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))}}const F=\"maplibre_preloaded_worker_pool\";class B{constructor(){this.active={}}acquire(t){if(!this.workers)for(this.workers=[];this.workers.length<B.workerCount;)this.workers.push(new Worker(e.a.WORKER_URL));return this.active[t]=!0,this.workers.slice()}release(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((t=>{t.terminate()})),this.workers=null)}isPreloaded(){return!!this.active[F]}numActive(){return Object.keys(this.active).length}}const N=Math.floor(a.hardwareConcurrency/2);let j,U;function V(){return j||(j=new B),j}B.workerCount=e.C(globalThis)?Math.max(Math.min(N,3),1):1;class q{constructor(t,r){this.workerPool=t,this.actors=[],this.currentActor=0,this.id=r;const n=this.workerPool.acquire(r);for(let t=0;t<n.length;t++){const i=n[t],a=new e.F(i,r);a.name=`Worker ${t}`,this.actors.push(a)}if(!this.actors.length)throw new Error(\"No actors found\")}broadcast(t,e){const r=[];for(const n of this.actors)r.push(n.sendAsync({type:t,data:e}));return Promise.all(r)}getActor(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]}remove(t=!0){this.actors.forEach((t=>{t.remove()})),this.actors=[],t&&this.workerPool.release(this.id)}registerMessageHandler(t,e){for(const r of this.actors)r.registerMessageHandler(t,e)}}function H(){return U||(U=new q(V(),e.G),U.registerMessageHandler(\"GR\",((t,r,n)=>e.m(r,n)))),U}function G(t,r){const n=e.H();return e.J(n,n,[1,1,0]),e.K(n,n,[.5*t.width,.5*t.height,1]),e.L(n,n,t.calculatePosMatrix(r.toUnwrapped()))}function Z(t,e,r,n,i,a){const o=function(t,e,r){if(t)for(const n of t){const t=e[n];if(t&&t.source===r&&\"fill-extrusion\"===t.type)return!0}else for(const t in e){const n=e[t];if(n.source===r&&\"fill-extrusion\"===n.type)return!0}return!1}(i&&i.layers,e,t.id),s=a.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(W);const c=[];for(const n of l)c.push({wrappedTileID:n.tileID.wrapped().key,queryResults:n.tile.queryRenderedFeatures(e,r,t._state,n.queryGeometry,n.cameraQueryGeometry,n.scale,i,a,s,G(t.transform,n.tileID))});const u=function(t){const e={},r={};for(const n of t){const t=n.queryResults,i=n.wrappedTileID,a=r[i]=r[i]||{};for(const r in t){const n=t[r],i=a[r]=a[r]||{},o=e[r]=e[r]||[];for(const t of n)i[t.featureIndex]||(i[t.featureIndex]=!0,o.push(t))}}return e}(c);for(const e in u)u[e].forEach((e=>{const r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return u}function W(t,e){const r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}function Y(t,r,n){return e._(this,void 0,void 0,(function*(){let i=t;if(t.url?i=(yield e.h(r.transformRequest(t.url,\"Source\"),n)).data:yield a.frameAsync(n),!i)return null;const o=e.M(e.e(i,t),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);return\"vector_layers\"in i&&i.vector_layers&&(o.vectorLayerIds=i.vector_layers.map((t=>t.id))),o}))}class X{constructor(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):Array.isArray(t)&&(4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1])))}setNorthEast(t){return this._ne=t instanceof e.N?new e.N(t.lng,t.lat):e.N.convert(t),this}setSouthWest(t){return this._sw=t instanceof e.N?new e.N(t.lng,t.lat):e.N.convert(t),this}extend(t){const r=this._sw,n=this._ne;let i,a;if(t instanceof e.N)i=t,a=t;else{if(!(t instanceof X)){if(Array.isArray(t)){if(4===t.length||t.every(Array.isArray)){const e=t;return this.extend(X.convert(e))}{const r=t;return this.extend(e.N.convert(r))}}return t&&(\"lng\"in t||\"lon\"in t)&&\"lat\"in t?this.extend(e.N.convert(t)):this}if(i=t._sw,a=t._ne,!i||!a)return this}return r||n?(r.lng=Math.min(i.lng,r.lng),r.lat=Math.min(i.lat,r.lat),n.lng=Math.max(a.lng,n.lng),n.lat=Math.max(a.lat,n.lat)):(this._sw=new e.N(i.lng,i.lat),this._ne=new e.N(a.lng,a.lat)),this}getCenter(){return new e.N((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)}getSouthWest(){return this._sw}getNorthEast(){return this._ne}getNorthWest(){return new e.N(this.getWest(),this.getNorth())}getSouthEast(){return new e.N(this.getEast(),this.getSouth())}getWest(){return this._sw.lng}getSouth(){return this._sw.lat}getEast(){return this._ne.lng}getNorth(){return this._ne.lat}toArray(){return[this._sw.toArray(),this._ne.toArray()]}toString(){return`LngLatBounds(${this._sw.toString()}, ${this._ne.toString()})`}isEmpty(){return!(this._sw&&this._ne)}contains(t){const{lng:r,lat:n}=e.N.convert(t),i=this._sw.lat<=n&&n<=this._ne.lat;let a=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(a=this._sw.lng>=r&&r>=this._ne.lng),i&&a}static convert(t){return t instanceof X?t:t?new X(t):t}static fromLngLat(t,r=0){const n=360*r/40075017,i=n/Math.cos(Math.PI/180*t.lat);return new X(new e.N(t.lng-i,t.lat-n),new e.N(t.lng+i,t.lat+n))}}class ${constructor(t,e,r){this.bounds=X.convert(this.validateBounds(t)),this.minzoom=e||0,this.maxzoom=r||24}validateBounds(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]}contains(t){const r=Math.pow(2,t.z),n=Math.floor(e.O(this.bounds.getWest())*r),i=Math.floor(e.Q(this.bounds.getNorth())*r),a=Math.ceil(e.O(this.bounds.getEast())*r),o=Math.ceil(e.Q(this.bounds.getSouth())*r);return t.x>=n&&t.x<a&&t.y>=i&&t.y<o}}class J extends e.E{constructor(t,r,n,i){if(super(),this.id=t,this.dispatcher=n,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,e.e(this,e.M(r,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=e.e({type:\"vector\"},r),this._collectResourceTiming=r.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(i)}load(){return e._(this,void 0,void 0,(function*(){this._loaded=!1,this.fire(new e.k(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=new AbortController;try{const t=yield Y(this._options,this.map._requestManager,this._tileJSONRequest);this._tileJSONRequest=null,this._loaded=!0,this.map.style.sourceCaches[this.id].clearTiles(),t&&(e.e(this,t),t.bounds&&(this.tileBounds=new $(t.bounds,this.minzoom,this.maxzoom)),this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}catch(t){this._tileJSONRequest=null,this.fire(new e.j(t))}}))}loaded(){return this._loaded}hasTile(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)}onAdd(t){this.map=t,this.load()}setSourceProperty(t){this._tileJSONRequest&&this._tileJSONRequest.abort(),t(),this.load()}setTiles(t){return this.setSourceProperty((()=>{this._options.tiles=t})),this}setUrl(t){return this.setSourceProperty((()=>{this.url=t,this._options.url=t})),this}onRemove(){this._tileJSONRequest&&(this._tileJSONRequest.abort(),this._tileJSONRequest=null)}serialize(){return e.e({},this._options)}loadTile(t){return e._(this,void 0,void 0,(function*(){const e=t.tileID.canonical.url(this.tiles,this.map.getPixelRatio(),this.scheme),r={request:this.map._requestManager.transformRequest(e,\"Tile\"),uid:t.uid,tileID:t.tileID,zoom:t.tileID.overscaledZ,tileSize:this.tileSize*t.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:this.map.getPixelRatio(),showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};r.request.collectResourceTiming=this._collectResourceTiming;let n=\"RT\";if(t.actor&&\"expired\"!==t.state){if(\"loading\"===t.state)return new Promise(((e,r)=>{t.reloadPromise={resolve:e,reject:r}}))}else t.actor=this.dispatcher.getActor(),n=\"LT\";t.abortController=new AbortController;try{const e=yield t.actor.sendAsync({type:n,data:r},t.abortController);if(delete t.abortController,t.aborted)return;this._afterTileLoadWorkerResponse(t,e)}catch(e){if(delete t.abortController,t.aborted)return;if(e&&404!==e.status)throw e;this._afterTileLoadWorkerResponse(t,null)}}))}_afterTileLoadWorkerResponse(t,e){if(e&&e.resourceTiming&&(t.resourceTiming=e.resourceTiming),e&&this.map._refreshExpiredTiles&&t.setExpiryData(e),t.loadVectorData(e,this.map.painter),t.reloadPromise){const e=t.reloadPromise;t.reloadPromise=null,this.loadTile(t).then(e.resolve).catch(e.reject)}}abortTile(t){return e._(this,void 0,void 0,(function*(){t.abortController&&(t.abortController.abort(),delete t.abortController),t.actor&&(yield t.actor.sendAsync({type:\"AT\",data:{uid:t.uid,type:this.type,source:this.id}}))}))}unloadTile(t){return e._(this,void 0,void 0,(function*(){t.unloadVectorData(),t.actor&&(yield t.actor.sendAsync({type:\"RMT\",data:{uid:t.uid,type:this.type,source:this.id}}))}))}hasTransition(){return!1}}class K extends e.E{constructor(t,r,n,i){super(),this.id=t,this.dispatcher=n,this.setEventedParent(i),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=e.e({type:\"raster\"},r),e.e(this,e.M(r,[\"url\",\"scheme\",\"tileSize\"]))}load(){return e._(this,void 0,void 0,(function*(){this._loaded=!1,this.fire(new e.k(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=new AbortController;try{const t=yield Y(this._options,this.map._requestManager,this._tileJSONRequest);this._tileJSONRequest=null,this._loaded=!0,t&&(e.e(this,t),t.bounds&&(this.tileBounds=new $(t.bounds,this.minzoom,this.maxzoom)),this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}catch(t){this._tileJSONRequest=null,this.fire(new e.j(t))}}))}loaded(){return this._loaded}onAdd(t){this.map=t,this.load()}onRemove(){this._tileJSONRequest&&(this._tileJSONRequest.abort(),this._tileJSONRequest=null)}setSourceProperty(t){this._tileJSONRequest&&(this._tileJSONRequest.abort(),this._tileJSONRequest=null),t(),this.load()}setTiles(t){return this.setSourceProperty((()=>{this._options.tiles=t})),this}setUrl(t){return this.setSourceProperty((()=>{this.url=t,this._options.url=t})),this}serialize(){return e.e({},this._options)}hasTile(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)}loadTile(t){return e._(this,void 0,void 0,(function*(){const e=t.tileID.canonical.url(this.tiles,this.map.getPixelRatio(),this.scheme);t.abortController=new AbortController;try{const r=yield p.getImage(this.map._requestManager.transformRequest(e,\"Tile\"),t.abortController,this.map._refreshExpiredTiles);if(delete t.abortController,t.aborted)return void(t.state=\"unloaded\");if(r&&r.data){this.map._refreshExpiredTiles&&r.cacheControl&&r.expires&&t.setExpiryData({cacheControl:r.cacheControl,expires:r.expires});const e=this.map.painter.context,n=e.gl,i=r.data;t.texture=this.map.painter.getTileTexture(i.width),t.texture?t.texture.update(i,{useMipmap:!0}):(t.texture=new w(e,i,n.RGBA,{useMipmap:!0}),t.texture.bind(n.LINEAR,n.CLAMP_TO_EDGE,n.LINEAR_MIPMAP_NEAREST)),t.state=\"loaded\"}}catch(e){if(delete t.abortController,t.aborted)t.state=\"unloaded\";else if(e)throw t.state=\"errored\",e}}))}abortTile(t){return e._(this,void 0,void 0,(function*(){t.abortController&&(t.abortController.abort(),delete t.abortController)}))}unloadTile(t){return e._(this,void 0,void 0,(function*(){t.texture&&this.map.painter.saveTileTexture(t.texture)}))}hasTransition(){return!1}}class Q extends K{constructor(t,r,n,i){super(t,r,n,i),this.type=\"raster-dem\",this.maxzoom=22,this._options=e.e({type:\"raster-dem\"},r),this.encoding=r.encoding||\"mapbox\",this.redFactor=r.redFactor,this.greenFactor=r.greenFactor,this.blueFactor=r.blueFactor,this.baseShift=r.baseShift}loadTile(t){return e._(this,void 0,void 0,(function*(){const r=t.tileID.canonical.url(this.tiles,this.map.getPixelRatio(),this.scheme),n=this.map._requestManager.transformRequest(r,\"Tile\");t.neighboringTiles=this._getNeighboringTiles(t.tileID),t.abortController=new AbortController;try{const r=yield p.getImage(n,t.abortController,this.map._refreshExpiredTiles);if(delete t.abortController,t.aborted)return void(t.state=\"unloaded\");if(r&&r.data){const n=r.data;this.map._refreshExpiredTiles&&r.cacheControl&&r.expires&&t.setExpiryData({cacheControl:r.cacheControl,expires:r.expires});const i=e.b(n)&&e.U()?n:yield this.readImageNow(n),a={type:this.type,uid:t.uid,source:this.id,rawImageData:i,encoding:this.encoding,redFactor:this.redFactor,greenFactor:this.greenFactor,blueFactor:this.blueFactor,baseShift:this.baseShift};if(!t.actor||\"expired\"===t.state){t.actor=this.dispatcher.getActor();const e=yield t.actor.sendAsync({type:\"LDT\",data:a});t.dem=e,t.needsHillshadePrepare=!0,t.needsTerrainPrepare=!0,t.state=\"loaded\"}}}catch(e){if(delete t.abortController,t.aborted)t.state=\"unloaded\";else if(e)throw t.state=\"errored\",e}}))}readImageNow(t){return e._(this,void 0,void 0,(function*(){if(\"undefined\"!=typeof VideoFrame&&e.V()){const r=t.width+2,n=t.height+2;try{return new e.R({width:r,height:n},yield e.W(t,-1,-1,r,n))}catch(t){}}return a.getImageData(t,1)}))}_getNeighboringTiles(t){const r=t.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?t.wrap-1:t.wrap,o=(r.x+1+n)%n,s=r.x+1===n?t.wrap+1:t.wrap,l={};return l[new e.S(t.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new e.S(t.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new e.S(t.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new e.S(t.overscaledZ,t.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new e.S(t.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new e.S(t.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new e.S(t.overscaledZ,t.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new e.S(t.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l}unloadTile(t){return e._(this,void 0,void 0,(function*(){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&(yield t.actor.sendAsync({type:\"RDT\",data:{type:this.type,uid:t.uid,source:this.id}}))}))}}class tt extends e.E{constructor(t,r,n,i){super(),this.id=t,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._pendingLoads=0,this.actor=n.getActor(),this.setEventedParent(i),this._data=r.data,this._options=e.e({},r),this._collectResourceTiming=r.collectResourceTiming,void 0!==r.maxzoom&&(this.maxzoom=r.maxzoom),r.type&&(this.type=r.type),r.attribution&&(this.attribution=r.attribution),this.promoteId=r.promoteId;const a=e.X/this.tileSize;this.workerOptions=e.e({source:this.id,cluster:r.cluster||!1,geojsonVtOptions:{buffer:(void 0!==r.buffer?r.buffer:128)*a,tolerance:(void 0!==r.tolerance?r.tolerance:.375)*a,extent:e.X,maxZoom:this.maxzoom,lineMetrics:r.lineMetrics||!1,generateId:r.generateId||!1},superclusterOptions:{maxZoom:void 0!==r.clusterMaxZoom?r.clusterMaxZoom:this.maxzoom-1,minPoints:Math.max(2,r.clusterMinPoints||2),extent:e.X,radius:(r.clusterRadius||50)*a,log:!1,generateId:r.generateId||!1},clusterProperties:r.clusterProperties,filter:r.filter},r.workerOptions),\"string\"==typeof this.promoteId&&(this.workerOptions.promoteId=this.promoteId)}load(){return e._(this,void 0,void 0,(function*(){yield this._updateWorkerData()}))}onAdd(t){this.map=t,this.load()}setData(t){return this._data=t,this._updateWorkerData(),this}updateData(t){return this._updateWorkerData(t),this}getData(){return e._(this,void 0,void 0,(function*(){const t=e.e({type:this.type},this.workerOptions);return this.actor.sendAsync({type:\"GD\",data:t})}))}setClusterOptions(t){return this.workerOptions.cluster=t.cluster,t&&(void 0!==t.clusterRadius&&(this.workerOptions.superclusterOptions.radius=t.clusterRadius),void 0!==t.clusterMaxZoom&&(this.workerOptions.superclusterOptions.maxZoom=t.clusterMaxZoom)),this._updateWorkerData(),this}getClusterExpansionZoom(t){return this.actor.sendAsync({type:\"GCEZ\",data:{type:this.type,clusterId:t,source:this.id}})}getClusterChildren(t){return this.actor.sendAsync({type:\"GCC\",data:{type:this.type,clusterId:t,source:this.id}})}getClusterLeaves(t,e,r){return this.actor.sendAsync({type:\"GCL\",data:{type:this.type,source:this.id,clusterId:t,limit:e,offset:r}})}_updateWorkerData(t){return e._(this,void 0,void 0,(function*(){const r=e.e({type:this.type},this.workerOptions);t?r.dataDiff=t:\"string\"==typeof this._data?(r.request=this.map._requestManager.transformRequest(a.resolveURL(this._data),\"Source\"),r.request.collectResourceTiming=this._collectResourceTiming):r.data=JSON.stringify(this._data),this._pendingLoads++,this.fire(new e.k(\"dataloading\",{dataType:\"source\"}));try{const t=yield this.actor.sendAsync({type:\"LD\",data:r});if(this._pendingLoads--,this._removed||t.abandoned)return void this.fire(new e.k(\"dataabort\",{dataType:\"source\"}));let n=null;t.resourceTiming&&t.resourceTiming[this.id]&&(n=t.resourceTiming[this.id].slice(0));const i={dataType:\"source\"};this._collectResourceTiming&&n&&n.length>0&&e.e(i,{resourceTiming:n}),this.fire(new e.k(\"data\",Object.assign(Object.assign({},i),{sourceDataType:\"metadata\"}))),this.fire(new e.k(\"data\",Object.assign(Object.assign({},i),{sourceDataType:\"content\"})))}catch(t){if(this._pendingLoads--,this._removed)return void this.fire(new e.k(\"dataabort\",{dataType:\"source\"}));this.fire(new e.j(t))}}))}loaded(){return 0===this._pendingLoads}loadTile(t){return e._(this,void 0,void 0,(function*(){const e=t.actor?\"RT\":\"LT\";t.actor=this.actor;const r={type:this.type,uid:t.uid,tileID:t.tileID,zoom:t.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:this.map.getPixelRatio(),showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};t.abortController=new AbortController;const n=yield this.actor.sendAsync({type:e,data:r},t.abortController);delete t.abortController,t.unloadVectorData(),t.aborted||t.loadVectorData(n,this.map.painter,\"RT\"===e)}))}abortTile(t){return e._(this,void 0,void 0,(function*(){t.abortController&&(t.abortController.abort(),delete t.abortController),t.aborted=!0}))}unloadTile(t){return e._(this,void 0,void 0,(function*(){t.unloadVectorData(),yield this.actor.sendAsync({type:\"RMT\",data:{uid:t.uid,type:this.type,source:this.id}})}))}onRemove(){this._removed=!0,this.actor.sendAsync({type:\"RS\",data:{type:this.type,source:this.id}})}serialize(){return e.e({},this._options,{type:this.type,data:this._data})}hasTransition(){return!1}}var et=e.Y([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]);class rt extends e.E{constructor(t,e,r,n){super(),this.id=t,this.dispatcher=r,this.coordinates=e.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(n),this.options=e}load(t){return e._(this,void 0,void 0,(function*(){this._loaded=!1,this.fire(new e.k(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,this._request=new AbortController;try{const e=yield p.getImage(this.map._requestManager.transformRequest(this.url,\"Image\"),this._request);this._request=null,this._loaded=!0,e&&e.data&&(this.image=e.data,t&&(this.coordinates=t),this._finishLoading())}catch(t){this._request=null,this._loaded=!0,this.fire(new e.j(t))}}))}loaded(){return this._loaded}updateImage(t){return t.url?(this._request&&(this._request.abort(),this._request=null),this.options.url=t.url,this.load(t.coordinates).finally((()=>{this.texture=null})),this):this}_finishLoading(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))}onAdd(t){this.map=t,this.load()}onRemove(){this._request&&(this._request.abort(),this._request=null)}setCoordinates(t){this.coordinates=t;const r=t.map(e.Z.fromLngLat);this.tileID=function(t){let r=1/0,n=1/0,i=-1/0,a=-1/0;for(const e of t)r=Math.min(r,e.x),n=Math.min(n,e.y),i=Math.max(i,e.x),a=Math.max(a,e.y);const o=i-r,s=a-n,l=Math.max(o,s),c=Math.max(0,Math.floor(-Math.log(l)/Math.LN2)),u=Math.pow(2,c);return new e.a1(c,Math.floor((r+i)/2*u),Math.floor((n+a)/2*u))}(r),this.minzoom=this.maxzoom=this.tileID.z;const n=r.map((t=>this.tileID.getTilePoint(t)._round()));return this._boundsArray=new e.$,this._boundsArray.emplaceBack(n[0].x,n[0].y,0,0),this._boundsArray.emplaceBack(n[1].x,n[1].y,e.X,0),this._boundsArray.emplaceBack(n[3].x,n[3].y,0,e.X),this._boundsArray.emplaceBack(n[2].x,n[2].y,e.X,e.X),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this}prepare(){if(0===Object.keys(this.tiles).length||!this.image)return;const t=this.map.painter.context,r=t.gl;this.boundsBuffer||(this.boundsBuffer=t.createVertexBuffer(this._boundsArray,et.members)),this.boundsSegments||(this.boundsSegments=e.a0.simpleSegment(0,0,4,2)),this.texture||(this.texture=new w(t,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE));let n=!1;for(const t in this.tiles){const e=this.tiles[t];\"loaded\"!==e.state&&(e.state=\"loaded\",e.texture=this.texture,n=!0)}n&&this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"idle\",sourceId:this.id}))}loadTile(t){return e._(this,void 0,void 0,(function*(){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={}):t.state=\"errored\"}))}serialize(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}}hasTransition(){return!1}}class nt extends rt{constructor(t,e,r,n){super(t,e,r,n),this.roundZoom=!0,this.type=\"video\",this.options=e}load(){return e._(this,void 0,void 0,(function*(){this._loaded=!1;const t=this.options;this.urls=[];for(const e of t.urls)this.urls.push(this.map._requestManager.transformRequest(e,\"Source\").url);try{const t=yield e.a3(this.urls);if(this._loaded=!0,!t)return;this.video=t,this.video.loop=!0,this.video.addEventListener(\"playing\",(()=>{this.map.triggerRepaint()})),this.map&&this.video.play(),this._finishLoading()}catch(t){this.fire(new e.j(t))}}))}pause(){this.video&&this.video.pause()}play(){this.video&&this.video.play()}seek(t){if(this.video){const r=this.video.seekable;t<r.start(0)||t>r.end(0)?this.fire(new e.j(new e.a2(`sources.${this.id}`,null,`Playback for this video can be set only between the ${r.start(0)} and ${r.end(0)}-second mark.`))):this.video.currentTime=t}}getVideo(){return this.video}onAdd(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))}prepare(){if(0===Object.keys(this.tiles).length||this.video.readyState<2)return;const t=this.map.painter.context,r=t.gl;this.boundsBuffer||(this.boundsBuffer=t.createVertexBuffer(this._boundsArray,et.members)),this.boundsSegments||(this.boundsSegments=e.a0.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new w(t,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE));let n=!1;for(const t in this.tiles){const e=this.tiles[t];\"loaded\"!==e.state&&(e.state=\"loaded\",e.texture=this.texture,n=!0)}n&&this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"idle\",sourceId:this.id}))}serialize(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}}hasTransition(){return this.video&&!this.video.paused}}class it extends rt{constructor(t,r,n,i){super(t,r,n,i),r.coordinates?Array.isArray(r.coordinates)&&4===r.coordinates.length&&!r.coordinates.some((t=>!Array.isArray(t)||2!==t.length||t.some((t=>\"number\"!=typeof t))))||this.fire(new e.j(new e.a2(`sources.${t}`,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new e.j(new e.a2(`sources.${t}`,null,'missing required property \"coordinates\"'))),r.animate&&\"boolean\"!=typeof r.animate&&this.fire(new e.j(new e.a2(`sources.${t}`,null,'optional \"animate\" property must be a boolean value'))),r.canvas?\"string\"==typeof r.canvas||r.canvas instanceof HTMLCanvasElement||this.fire(new e.j(new e.a2(`sources.${t}`,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new e.j(new e.a2(`sources.${t}`,null,'missing required property \"canvas\"'))),this.options=r,this.animate=void 0===r.animate||r.animate}load(){return e._(this,void 0,void 0,(function*(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof HTMLCanvasElement?this.options.canvas:document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new e.j(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())}))}getCanvas(){return this.canvas}onAdd(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()}onRemove(){this.pause()}prepare(){let t=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,t=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,t=!0),this._hasInvalidDimensions())return;if(0===Object.keys(this.tiles).length)return;const r=this.map.painter.context,n=r.gl;this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,et.members)),this.boundsSegments||(this.boundsSegments=e.a0.simpleSegment(0,0,4,2)),this.texture?(t||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new w(r,this.canvas,n.RGBA,{premultiply:!0});let i=!1;for(const t in this.tiles){const e=this.tiles[t];\"loaded\"!==e.state&&(e.state=\"loaded\",e.texture=this.texture,i=!0)}i&&this.fire(new e.k(\"data\",{dataType:\"source\",sourceDataType:\"idle\",sourceId:this.id}))}serialize(){return{type:\"canvas\",coordinates:this.coordinates}}hasTransition(){return this._playing}_hasInvalidDimensions(){for(const t of[this.canvas.width,this.canvas.height])if(isNaN(t)||t<=0)return!0;return!1}}const at={},ot=t=>{switch(t){case\"geojson\":return tt;case\"image\":return rt;case\"raster\":return K;case\"raster-dem\":return Q;case\"vector\":return J;case\"video\":return nt;case\"canvas\":return it}return at[t]};const st=\"RTLPluginLoaded\";class lt extends e.E{constructor(){super(...arguments),this.status=\"unavailable\",this.url=null,this.dispatcher=H()}_syncState(t){return this.status=t,this.dispatcher.broadcast(\"SRPS\",{pluginStatus:t,pluginURL:this.url}).catch((t=>{throw this.status=\"error\",t}))}getRTLTextPluginStatus(){return this.status}clearRTLTextPlugin(){this.status=\"unavailable\",this.url=null}setRTLTextPlugin(t){return e._(this,arguments,void 0,(function*(t,e=!1){if(this.url)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");if(this.url=a.resolveURL(t),!this.url)throw new Error(`requested url ${t} is invalid`);if(\"unavailable\"===this.status){if(!e)return this._requestImport();this.status=\"deferred\",this._syncState(this.status)}else if(\"requested\"===this.status)return this._requestImport()}))}_requestImport(){return e._(this,void 0,void 0,(function*(){yield this._syncState(\"loading\"),this.status=\"loaded\",this.fire(new e.k(st))}))}lazyLoad(){\"unavailable\"===this.status?this.status=\"requested\":\"deferred\"===this.status&&this._requestImport()}}let ct=null;function ut(){return ct||(ct=new lt),ct}class ht{constructor(t,r){this.timeAdded=0,this.fadeEndTime=0,this.tileID=t,this.uid=e.a4(),this.uses=0,this.tileSize=r,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.rtt=[],this.rttCoords={},this.expiredRequestCount=0,this.state=\"loading\"}registerFadeDuration(t){const e=t+this.timeAdded;e<this.fadeEndTime||(this.fadeEndTime=e)}wasRequested(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state}clearTextures(t){this.demTexture&&t.saveTileTexture(this.demTexture),this.demTexture=null}loadVectorData(t,r,n){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){const r={};if(!e)return r;for(const n of t){const t=n.layerIds.map((t=>e.getLayer(t))).filter(Boolean);if(0!==t.length){n.layers=t,n.stateDependentLayerIds&&(n.stateDependentLayers=n.stateDependentLayerIds.map((e=>t.filter((t=>t.id===e))[0])));for(const e of t)r[e.id]=n}}return r}(t.buckets,r.style),this.hasSymbolBuckets=!1;for(const t in this.buckets){const r=this.buckets[t];if(r instanceof e.a6){if(this.hasSymbolBuckets=!0,!n)break;r.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(const t in this.buckets){const r=this.buckets[t];if(r instanceof e.a6&&r.hasRTLText){this.hasRTLText=!0,ut().lazyLoad();break}}this.queryPadding=0;for(const t in this.buckets){const e=this.buckets[t];this.queryPadding=Math.max(this.queryPadding,r.style.getLayer(t).queryRadius(e))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new e.a5}unloadVectorData(){for(const t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"}getBucket(t){return this.buckets[t.id]}upload(t){for(const e in this.buckets){const r=this.buckets[e];r.uploadPending()&&r.upload(t)}const e=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new w(t,this.imageAtlas.image,e.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new w(t,this.glyphAtlasImage,e.ALPHA),this.glyphAtlasImage=null)}prepare(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)}queryRenderedFeatures(t,e,r,n,i,a,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:i,scale:a,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}}querySourceFeatures(t,r){const n=this.latestFeatureIndex;if(!n||!n.rawTileData)return;const i=n.loadVTLayers(),a=r&&r.sourceLayer?r.sourceLayer:\"\",o=i._geojsonTileLayer||i[a];if(!o)return;const s=e.a7(r&&r.filter),{z:l,x:c,y:u}=this.tileID.canonical,h={z:l,x:c,y:u};for(let r=0;r<o.length;r++){const i=o.feature(r);if(s.needGeometry){const t=e.a8(i,!0);if(!s.filter(new e.a9(this.tileID.overscaledZ),t,this.tileID.canonical))continue}else if(!s.filter(new e.a9(this.tileID.overscaledZ),i))continue;const f=n.getId(i,a),p=new e.aa(i,l,c,u,f);p.tile=h,t.push(p)}}hasData(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state}patternsLoaded(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length}setExpiryData(t){const r=this.expirationTime;if(t.cacheControl){const r=e.ab(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){const t=Date.now();let e=!1;if(this.expirationTime>t)e=!1;else if(r)if(this.expirationTime<r)e=!0;else{const n=this.expirationTime-r;n?this.expirationTime=t+Math.max(n,3e4):e=!0}else e=!0;e?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}}getExpiryTimeout(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)}setFeatureState(t,e){if(!this.latestFeatureIndex||!this.latestFeatureIndex.rawTileData||0===Object.keys(t).length)return;const r=this.latestFeatureIndex.loadVTLayers();for(const n in this.buckets){if(!e.style.hasLayer(n))continue;const i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];if(!o||!s||0===Object.keys(s).length)continue;i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});const l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(i)))}}holdingForFade(){return void 0!==this.symbolFadeHoldUntil}symbolFadeFinished(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<a.now()}clearFadeHold(){this.symbolFadeHoldUntil=void 0}setHoldDuration(t){this.symbolFadeHoldUntil=a.now()+t}setDependencies(t,e){const r={};for(const t of e)r[t]=!0;this.dependencies[t]=r}hasDependency(t,e){for(const r of t){const t=this.dependencies[r];if(t)for(const r of e)if(t[r])return!0}return!1}}class ft{constructor(t,e){this.max=t,this.onRemove=e,this.reset()}reset(){for(const t in this.data)for(const e of this.data[t])e.timeout&&clearTimeout(e.timeout),this.onRemove(e.value);return this.data={},this.order=[],this}add(t,e,r){const n=t.wrapped().key;void 0===this.data[n]&&(this.data[n]=[]);const i={value:e,timeout:void 0};if(void 0!==r&&(i.timeout=setTimeout((()=>{this.remove(t,i)}),r)),this.data[n].push(i),this.order.push(n),this.order.length>this.max){const t=this._getAndRemoveByKey(this.order[0]);t&&this.onRemove(t)}return this}has(t){return t.wrapped().key in this.data}getAndRemove(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null}_getAndRemoveByKey(t){const e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value}getByKey(t){const e=this.data[t];return e?e[0].value:null}get(t){return this.has(t)?this.data[t.wrapped().key][0].value:null}remove(t,e){if(!this.has(t))return this;const r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this}setMaxSize(t){for(this.max=t;this.order.length>this.max;){const t=this._getAndRemoveByKey(this.order[0]);t&&this.onRemove(t)}return this}filter(t){const e=[];for(const r in this.data)for(const n of this.data[r])t(n.value)||e.push(n);for(const t of e)this.remove(t.value.tileID,t)}}class pt{constructor(){this.state={},this.stateChanges={},this.deletedStates={}}updateState(t,r,n){const i=String(r);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][i]=this.stateChanges[t][i]||{},e.e(this.stateChanges[t][i],n),null===this.deletedStates[t]){this.deletedStates[t]={};for(const e in this.state[t])e!==i&&(this.deletedStates[t][e]=null)}else if(this.deletedStates[t]&&null===this.deletedStates[t][i]){this.deletedStates[t][i]={};for(const e in this.state[t][i])n[e]||(this.deletedStates[t][i][e]=null)}else for(const e in n)this.deletedStates[t]&&this.deletedStates[t][i]&&null===this.deletedStates[t][i][e]&&delete this.deletedStates[t][i][e]}removeFeatureState(t,e,r){if(null===this.deletedStates[t])return;const n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}getState(t,r){const n=String(r),i=this.state[t]||{},a=this.stateChanges[t]||{},o=e.e({},i[n],a[n]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){const e=this.deletedStates[t][r];if(null===e)return{};for(const t in e)delete o[t]}return o}initializeTileState(t,e){t.setFeatureState(this.state,e)}coalesceChanges(t,r){const n={};for(const t in this.stateChanges){this.state[t]=this.state[t]||{};const r={};for(const n in this.stateChanges[t])this.state[t][n]||(this.state[t][n]={}),e.e(this.state[t][n],this.stateChanges[t][n]),r[n]=this.state[t][n];n[t]=r}for(const t in this.deletedStates){this.state[t]=this.state[t]||{};const r={};if(null===this.deletedStates[t])for(const e in this.state[t])r[e]={},this.state[t][e]={};else for(const e in this.deletedStates[t]){if(null===this.deletedStates[t][e])this.state[t][e]={};else for(const r of Object.keys(this.deletedStates[t][e]))delete this.state[t][e][r];r[e]=this.state[t][e]}n[t]=n[t]||{},e.e(n[t],r)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(n).length)for(const e in t)t[e].setFeatureState(n,r)}}class dt extends e.E{constructor(t,e,r){super(),this.id=t,this.dispatcher=r,this.on(\"data\",(t=>this._dataHandler(t))),this.on(\"dataloading\",(()=>{this._sourceErrored=!1})),this.on(\"error\",(()=>{this._sourceErrored=this._source.loaded()})),this._source=((t,e,r,n)=>{const i=new(ot(e.type))(t,e,r,n);if(i.id!==t)throw new Error(`Expected Source id to be ${t} instead of ${i.id}`);return i})(t,e,r,this),this._tiles={},this._cache=new ft(0,(t=>this._unloadTile(t))),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._maxTileCacheZoomLevels=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new pt,this._didEmitContent=!1,this._updated=!1}onAdd(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._maxTileCacheZoomLevels=t?t._maxTileCacheZoomLevels:null,this._source&&this._source.onAdd&&this._source.onAdd(t)}onRemove(t){this.clearTiles(),this._source&&this._source.onRemove&&this._source.onRemove(t)}loaded(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;if(!(void 0===this.used&&void 0===this.usedForTerrain||this.used||this.usedForTerrain))return!0;if(!this._updated)return!1;for(const t in this._tiles){const e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0}getSource(){return this._source}pause(){this._paused=!0}resume(){if(!this._paused)return;const t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform,this.terrain)}_loadTile(t,r,n){return e._(this,void 0,void 0,(function*(){try{yield this._source.loadTile(t),this._tileLoaded(t,r,n)}catch(r){t.state=\"errored\",404!==r.status?this._source.fire(new e.j(r,{tile:t})):this.update(this.transform,this.terrain)}}))}_unloadTile(t){this._source.unloadTile&&this._source.unloadTile(t)}_abortTile(t){this._source.abortTile&&this._source.abortTile(t),this._source.fire(new e.k(\"dataabort\",{tile:t,coord:t.tileID,dataType:\"source\"}))}serialize(){return this._source.serialize()}prepare(t){this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null);for(const e in this._tiles){const r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}}getIds(){return Object.values(this._tiles).map((t=>t.tileID)).sort(mt).map((t=>t.key))}getRenderableIds(t){const r=[];for(const e in this._tiles)this._isIdRenderable(e,t)&&r.push(this._tiles[e]);return t?r.sort(((t,r)=>{const n=t.tileID,i=r.tileID,a=new e.P(n.canonical.x,n.canonical.y)._rotate(this.transform.angle),o=new e.P(i.canonical.x,i.canonical.y)._rotate(this.transform.angle);return n.overscaledZ-i.overscaledZ||o.y-a.y||o.x-a.x})).map((t=>t.tileID.key)):r.map((t=>t.tileID)).sort(mt).map((t=>t.key))}hasRenderableParent(t){const e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)}_isIdRenderable(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())}reload(){if(this._paused)this._shouldReloadOnResume=!0;else{this._cache.reset();for(const t in this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")}}_reloadTile(t,r){return e._(this,void 0,void 0,(function*(){const e=this._tiles[t];e&&(\"loading\"!==e.state&&(e.state=r),yield this._loadTile(e,t,r))}))}_tileLoaded(t,r,n){t.timeAdded=a.now(),\"expired\"===n&&(t.refreshedUponExpiration=!0),this._setTileReloadTimer(r,t),\"raster-dem\"===this.getSource().type&&t.dem&&this._backfillDEM(t),this._state.initializeTileState(t,this.map?this.map.painter:null),t.aborted||this._source.fire(new e.k(\"data\",{dataType:\"source\",tile:t,coord:t.tileID}))}_backfillDEM(t){const e=this.getRenderableIds();for(let n=0;n<e.length;n++){const i=e[n];if(t.neighboringTiles&&t.neighboringTiles[i]){const e=this.getTileByID(i);r(t,e),r(e,t)}}function r(t,e){t.needsHillshadePrepare=!0,t.needsTerrainPrepare=!0;let r=e.tileID.canonical.x-t.tileID.canonical.x;const n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}}getTile(t){return this.getTileByID(t.key)}getTileByID(t){return this._tiles[t]}_retainLoadedChildren(t,e,r,n){for(const i in this._tiles){let a=this._tiles[i];if(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)continue;let o=a.tileID;for(;a&&a.tileID.overscaledZ>e+1;){const t=a.tileID.scaledTo(a.tileID.overscaledZ-1);a=this._tiles[t.key],a&&a.hasData()&&(o=t)}let s=o;for(;s.overscaledZ>e;)if(s=s.scaledTo(s.overscaledZ-1),t[s.key]){n[o.key]=o;break}}}findLoadedParent(t,e){if(t.key in this._loadedParentTiles){const r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(let r=t.overscaledZ-1;r>=e;r--){const e=t.scaledTo(r),n=this._getLoadedTile(e);if(n)return n}}findLoadedSibling(t){return this._getLoadedTile(t)}_getLoadedTile(t){const e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)}updateCacheSize(t){const r=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),n=null===this._maxTileCacheZoomLevels?e.a.MAX_TILE_CACHE_ZOOM_LEVELS:this._maxTileCacheZoomLevels,i=Math.floor(r*n),a=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,i):i;this._cache.setMaxSize(a)}handleWrapJump(t){const e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){const t={};for(const e in this._tiles){const n=this._tiles[e];n.tileID=n.tileID.unwrapTo(n.tileID.wrap+r),t[n.tileID.key]=n}this._tiles=t;for(const t in this._timers)clearTimeout(this._timers[t]),delete this._timers[t];for(const t in this._tiles){const e=this._tiles[t];this._setTileReloadTimer(t,e)}}}_updateCoveredAndRetainedTiles(t,e,r,n,i,o){const s={},l={},c=Object.keys(t),u=a.now();for(const r of c){const n=t[r],i=this._tiles[r];if(!i||0!==i.fadeEndTime&&i.fadeEndTime<=u)continue;const a=this.findLoadedParent(n,e),o=this.findLoadedSibling(n),c=a||o||null;c&&(this._addTile(c.tileID),s[c.tileID.key]=c.tileID),l[r]=n}this._retainLoadedChildren(l,n,r,t);for(const e in s)t[e]||(this._coveredTiles[e]=!0,t[e]=s[e]);if(o){const e={},r={};for(const t of i)this._tiles[t.key].hasData()?e[t.key]=t:r[t.key]=t;for(const n in r){const i=r[n].children(this._source.maxzoom);this._tiles[i[0].key]&&this._tiles[i[1].key]&&this._tiles[i[2].key]&&this._tiles[i[3].key]&&(e[i[0].key]=t[i[0].key]=i[0],e[i[1].key]=t[i[1].key]=i[1],e[i[2].key]=t[i[2].key]=i[2],e[i[3].key]=t[i[3].key]=i[3],delete r[n])}for(const n in r){const i=r[n],a=this.findLoadedParent(i,this._source.minzoom),o=this.findLoadedSibling(i),s=a||o||null;if(s){e[s.tileID.key]=t[s.tileID.key]=s.tileID;for(const t in e)e[t].isChildOf(s.tileID)&&delete e[t]}}for(const t in this._tiles)e[t]||(this._coveredTiles[t]=!0)}}update(t,r){if(!this._sourceLoaded||this._paused)return;let n;this.transform=t,this.terrain=r,this.updateCacheSize(t),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used||this.usedForTerrain?this._source.tileID?n=t.getVisibleUnwrappedCoordinates(this._source.tileID).map((t=>new e.S(t.canonical.z,t.wrap,t.canonical.z,t.canonical.x,t.canonical.y))):(n=t.coveringTiles({tileSize:this.usedForTerrain?this.tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:!this.usedForTerrain&&this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled,terrain:r}),this._source.hasTile&&(n=n.filter((t=>this._source.hasTile(t))))):n=[];const i=t.coveringZoomLevel(this._source),a=Math.max(i-dt.maxOverzooming,this._source.minzoom),o=Math.max(i+dt.maxUnderzooming,this._source.minzoom);if(this.usedForTerrain){const t={};for(const e of n)if(e.canonical.z>this._source.minzoom){const r=e.scaledTo(e.canonical.z-1);t[r.key]=r;const n=e.scaledTo(Math.max(this._source.minzoom,Math.min(e.canonical.z,5)));t[n.key]=n}n=n.concat(Object.values(t))}const s=0===n.length&&!this._updated&&this._didEmitContent;this._updated=!0,s&&this.fire(new e.k(\"data\",{sourceDataType:\"idle\",dataType:\"source\",sourceId:this.id}));const l=this._updateRetainedTiles(n,i);gt(this._source.type)&&this._updateCoveredAndRetainedTiles(l,a,o,i,n,r);for(const t in l)this._tiles[t].clearFadeHold();const c=e.ac(this._tiles,l);for(const t of c){const e=this._tiles[t];e.hasSymbolBuckets&&!e.holdingForFade()?e.setHoldDuration(this.map._fadeDuration):e.hasSymbolBuckets&&!e.symbolFadeFinished()||this._removeTile(t)}this._updateLoadedParentTileCache(),this._updateLoadedSiblingTileCache()}releaseSymbolFadeTiles(){for(const t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)}_updateRetainedTiles(t,e){var r;const n={},i={},a=Math.max(e-dt.maxOverzooming,this._source.minzoom),o=Math.max(e+dt.maxUnderzooming,this._source.minzoom),s={};for(const r of t){const t=this._addTile(r);n[r.key]=r,t.hasData()||e<this._source.maxzoom&&(s[r.key]=r)}this._retainLoadedChildren(s,e,o,n);for(const o of t){let t=this._tiles[o.key];if(t.hasData())continue;if(e+1>this._source.maxzoom){const t=o.children(this._source.maxzoom)[0],e=this.getTile(t);if(e&&e.hasData()){n[t.key]=t;continue}}else{const t=o.children(this._source.maxzoom);if(n[t[0].key]&&n[t[1].key]&&n[t[2].key]&&n[t[3].key])continue}let s=t.wasRequested();for(let e=o.overscaledZ-1;e>=a;--e){const a=o.scaledTo(e);if(i[a.key])break;if(i[a.key]=!0,t=this.getTile(a),!t&&s&&(t=this._addTile(a)),t){const e=t.hasData();if((e||!(null===(r=this.map)||void 0===r?void 0:r.cancelPendingTileRequestsWhileZooming)||s)&&(n[a.key]=a),s=t.wasRequested(),e)break}}}return n}_updateLoadedParentTileCache(){this._loadedParentTiles={};for(const t in this._tiles){const e=[];let r,n=this._tiles[t].tileID;for(;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);const t=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(t),r)break;n=t}for(const t of e)this._loadedParentTiles[t]=r}}_updateLoadedSiblingTileCache(){this._loadedSiblingTiles={};for(const t in this._tiles){const e=this._tiles[t].tileID,r=this._getLoadedTile(e);this._loadedSiblingTiles[e.key]=r}}_addTile(t){let r=this._tiles[t.key];if(r)return r;r=this._cache.getAndRemove(t),r&&(this._setTileReloadTimer(t.key,r),r.tileID=t,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[t.key]&&(clearTimeout(this._cacheTimers[t.key]),delete this._cacheTimers[t.key],this._setTileReloadTimer(t.key,r)));const n=r;return r||(r=new ht(t,this._source.tileSize*t.overscaleFactor()),this._loadTile(r,t.key,r.state)),r.uses++,this._tiles[t.key]=r,n||this._source.fire(new e.k(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r}_setTileReloadTimer(t,e){t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);const r=e.getExpiryTimeout();r&&(this._timers[t]=setTimeout((()=>{this._reloadTile(t,\"expired\"),delete this._timers[t]}),r))}_removeTile(t){const e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))}_dataHandler(t){const e=t.sourceDataType;\"source\"===t.dataType&&\"metadata\"===e&&(this._sourceLoaded=!0),this._sourceLoaded&&!this._paused&&\"source\"===t.dataType&&\"content\"===e&&(this.reload(),this.transform&&this.update(this.transform,this.terrain),this._didEmitContent=!0)}clearTiles(){this._shouldReloadOnResume=!1,this._paused=!1;for(const t in this._tiles)this._removeTile(t);this._cache.reset()}tilesIn(t,r,n){const i=[],a=this.transform;if(!a)return i;const o=n?a.getCameraQueryGeometry(t):t,s=t.map((t=>a.pointCoordinate(t,this.terrain))),l=o.map((t=>a.pointCoordinate(t,this.terrain))),c=this.getIds();let u=1/0,h=1/0,f=-1/0,p=-1/0;for(const t of l)u=Math.min(u,t.x),h=Math.min(h,t.y),f=Math.max(f,t.x),p=Math.max(p,t.y);for(let t=0;t<c.length;t++){const n=this._tiles[c[t]];if(n.holdingForFade())continue;const o=n.tileID,d=Math.pow(2,a.zoom-n.tileID.overscaledZ),m=r*n.queryPadding*e.X/n.tileSize/d,g=[o.getTilePoint(new e.Z(u,h)),o.getTilePoint(new e.Z(f,p))];if(g[0].x-m<e.X&&g[0].y-m<e.X&&g[1].x+m>=0&&g[1].y+m>=0){const t=s.map((t=>o.getTilePoint(t))),e=l.map((t=>o.getTilePoint(t)));i.push({tile:n,tileID:o,queryGeometry:t,cameraQueryGeometry:e,scale:d})}}return i}getVisibleCoordinates(t){const e=this.getRenderableIds(t).map((t=>this._tiles[t].tileID));for(const t of e)t.posMatrix=this.transform.calculatePosMatrix(t.toUnwrapped());return e}hasTransition(){if(this._source.hasTransition())return!0;if(gt(this._source.type)){const t=a.now();for(const e in this._tiles)if(this._tiles[e].fadeEndTime>=t)return!0}return!1}setFeatureState(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)}removeFeatureState(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)}getFeatureState(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)}setDependencies(t,e,r){const n=this._tiles[t];n&&n.setDependencies(e,r)}reloadTilesForDependencies(t,e){for(const r in this._tiles)this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\");this._cache.filter((r=>!r.hasDependency(t,e)))}}function mt(t,e){const r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function gt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}dt.maxOverzooming=10,dt.maxUnderzooming=3;class yt{constructor(t,e){this.reset(t,e)}reset(t,e){this.points=t||[],this._distances=[0];for(let t=1;t<this.points.length;t++)this._distances[t]=this._distances[t-1]+this.points[t].dist(this.points[t-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding}lerp(t){if(1===this.points.length)return this.points[0];t=e.ad(t,0,1);let r=1,n=this._distances[r];const i=t*this.paddedLength+this.padding;for(;n<i&&r<this._distances.length;)n=this._distances[++r];const a=r-1,o=this._distances[a],s=n-o,l=s>0?(i-o)/s:0;return this.points[a].mult(1-l).add(this.points[r].mult(l))}}function vt(t,e){let r=!0;return\"always\"===t||\"never\"!==t&&\"never\"!==e||(r=!1),r}class xt{constructor(t,e,r){const n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(let t=0;t<this.xCellCount*this.yCellCount;t++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0}keysLength(){return this.boxKeys.length+this.circleKeys.length}insert(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)}insertCircle(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)}_insertBoxCell(t,e,r,n,i,a){this.boxCells[i].push(a)}_insertCircleCell(t,e,r,n,i,a){this.circleCells[i].push(a)}_query(t,e,r,n,i,a,o){if(r<0||t>this.width||n<0||e>this.height)return[];const s=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return[{key:null,x1:t,y1:e,x2:r,y2:n}];for(let t=0;t<this.boxKeys.length;t++)s.push({key:this.boxKeys[t],x1:this.bboxes[4*t],y1:this.bboxes[4*t+1],x2:this.bboxes[4*t+2],y2:this.bboxes[4*t+3]});for(let t=0;t<this.circleKeys.length;t++){const e=this.circles[3*t],r=this.circles[3*t+1],n=this.circles[3*t+2];s.push({key:this.circleKeys[t],x1:e-n,y1:r-n,x2:e+n,y2:r+n})}}else{const l={hitTest:i,overlapMode:a,seenUids:{box:{},circle:{}}};this._forEachCell(t,e,r,n,this._queryCell,s,l,o)}return s}query(t,e,r,n){return this._query(t,e,r,n,!1,null)}hitTest(t,e,r,n,i,a){return this._query(t,e,r,n,!0,i,a).length>0}hitTestCircle(t,e,r,n,i){const a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!1;const c=[],u={hitTest:!0,overlapMode:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),c.length>0}_queryCell(t,e,r,n,i,a,o,s){const{seenUids:l,hitTest:c,overlapMode:u}=o,h=this.boxCells[i];if(null!==h){const i=this.bboxes;for(const o of h)if(!l.box[o]){l.box[o]=!0;const h=4*o,f=this.boxKeys[o];if(t<=i[h+2]&&e<=i[h+3]&&r>=i[h+0]&&n>=i[h+1]&&(!s||s(f))&&(!c||!vt(u,f.overlapMode))&&(a.push({key:f,x1:i[h],y1:i[h+1],x2:i[h+2],y2:i[h+3]}),c))return!0}}const f=this.circleCells[i];if(null!==f){const i=this.circles;for(const o of f)if(!l.circle[o]){l.circle[o]=!0;const h=3*o,f=this.circleKeys[o];if(this._circleAndRectCollide(i[h],i[h+1],i[h+2],t,e,r,n)&&(!s||s(f))&&(!c||!vt(u,f.overlapMode))){const t=i[h],e=i[h+1],r=i[h+2];if(a.push({key:f,x1:t-r,y1:e-r,x2:t+r,y2:e+r}),c)return!0}}}return!1}_queryCellCircle(t,e,r,n,i,a,o,s){const{circle:l,seenUids:c,overlapMode:u}=o,h=this.boxCells[i];if(null!==h){const t=this.bboxes;for(const e of h)if(!c.box[e]){c.box[e]=!0;const r=4*e,n=this.boxKeys[e];if(this._circleAndRectCollide(l.x,l.y,l.radius,t[r+0],t[r+1],t[r+2],t[r+3])&&(!s||s(n))&&!vt(u,n.overlapMode))return a.push(!0),!0}}const f=this.circleCells[i];if(null!==f){const t=this.circles;for(const e of f)if(!c.circle[e]){c.circle[e]=!0;const r=3*e,n=this.circleKeys[e];if(this._circlesCollide(t[r],t[r+1],t[r+2],l.x,l.y,l.radius)&&(!s||s(n))&&!vt(u,n.overlapMode))return a.push(!0),!0}}}_forEachCell(t,e,r,n,i,a,o,s){const l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n);for(let f=l;f<=u;f++)for(let l=c;l<=h;l++){const c=this.xCellCount*l+f;if(i.call(this,t,e,r,n,c,a,o,s))return}}_convertToXCellCoord(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))}_convertToYCellCoord(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))}_circlesCollide(t,e,r,n,i,a){const o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s}_circleAndRectCollide(t,e,r,n,i,a,o){const s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;const c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;const h=l-s,f=u-c;return h*h+f*f<=r*r}}function _t(t,r,n,i,a){const o=e.H();return r?(e.K(o,o,[1/a,1/a,1]),n||e.ae(o,o,i.angle)):e.L(o,i.labelPlaneMatrix,t),o}function bt(t,r,n,i,a){if(r){const r=e.af(t);return e.K(r,r,[a,a,1]),n||e.ae(r,r,-i.angle),r}return i.glCoordMatrix}function wt(t,r,n){let i;n?(i=[t.x,t.y,n(t.x,t.y),1],e.ag(i,i,r)):(i=[t.x,t.y,0,1],function(t,e,r){const n=e[0],i=e[1];t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15]}(i,i,r));const a=i[3];return{point:new e.P(i[0]/a,i[1]/a),signedDistanceFromCamera:a,isOccluded:!1}}function Tt(t,e){return.5+t/e*.5}function kt(t,e){return t.x>=-e[0]&&t.x<=e[0]&&t.y>=-e[1]&&t.y<=e[1]}function At(t,r,n,i,a,o,s,l,c,u,h,f,p,d,m){const g=i?t.textSizeData:t.iconSizeData,y=e.ah(g,n.transform.zoom),v=[256/n.width*2+1,256/n.height*2+1],x=i?t.text.dynamicLayoutVertexArray:t.icon.dynamicLayoutVertexArray;x.clear();const _=t.lineVertexArray,b=i?t.text.placedSymbolArray:t.icon.placedSymbolArray,w=n.transform.width/n.transform.height;let T=!1;for(let i=0;i<b.length;i++){const k=b.get(i);if(k.hidden||k.writingMode===e.ai.vertical&&!T){Rt(k.numGlyphs,x);continue}T=!1;const A=wt(new e.P(k.anchorX,k.anchorY),r,m);if(!kt(A.point,v)){Rt(k.numGlyphs,x);continue}const M=A.signedDistanceFromCamera,S=Tt(n.transform.cameraToCenterDistance,M),E=e.aj(g,y,k),C=s?E/S:E*S,L={getElevation:m,labelPlaneMatrix:a,lineVertexArray:_,pitchWithMap:s,projectionCache:{projections:{},offsets:{},cachedAnchorPoint:void 0,anyProjectionOccluded:!1},projection:u,tileAnchorPoint:new e.P(k.anchorX,k.anchorY),unwrappedTileID:h,width:f,height:p,translation:d},I=Et(L,k,C,!1,l,r,o,t.glyphOffsetArray,x,w,c);T=I.useVertical,(I.notEnoughRoom||T||I.needsFlipping&&Et(L,k,C,!0,l,r,o,t.glyphOffsetArray,x,w,c).notEnoughRoom)&&Rt(k.numGlyphs,x)}i?t.text.dynamicLayoutVertexBuffer.updateData(x):t.icon.dynamicLayoutVertexBuffer.updateData(x)}function Mt(t,e,r,n,i,a,o,s){const l=a.glyphStartIndex+a.numGlyphs,c=a.lineStartIndex,u=a.lineStartIndex+a.lineLength,h=e.getoffsetX(a.glyphStartIndex),f=e.getoffsetX(l-1),p=Ot(t*h,r,n,i,a.segment,c,u,s,o);if(!p)return null;const d=Ot(t*f,r,n,i,a.segment,c,u,s,o);return d?s.projectionCache.anyProjectionOccluded?null:{first:p,last:d}:null}function St(t,r,n,i){return t===e.ai.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(t===e.ai.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function Et(t,r,n,i,a,o,s,l,c,u,h){const f=n/24,p=r.lineOffsetX*f,d=r.lineOffsetY*f;let m;if(r.numGlyphs>1){const e=r.glyphStartIndex+r.numGlyphs,n=r.lineStartIndex,o=r.lineStartIndex+r.lineLength,c=Mt(f,l,p,d,i,r,h,t);if(!c)return{notEnoughRoom:!0};const g=wt(c.first.point,s,t.getElevation).point,y=wt(c.last.point,s,t.getElevation).point;if(a&&!i){const t=St(r.writingMode,g,y,u);if(t)return t}m=[c.first];for(let a=r.glyphStartIndex+1;a<e-1;a++)m.push(Ot(f*l.getoffsetX(a),p,d,i,r.segment,n,o,t,h));m.push(c.last)}else{if(a&&!i){const n=wt(t.tileAnchorPoint,o,t.getElevation).point,i=r.lineStartIndex+r.segment+1,a=new e.P(t.lineVertexArray.getx(i),t.lineVertexArray.gety(i)),s=wt(a,o,t.getElevation),l=s.signedDistanceFromCamera>0?s.point:function(t,e,r,n,i,a){return Ct(t,e,r,n,i,a)}(t.tileAnchorPoint,a,n,1,o,t),c=St(r.writingMode,n,l,u);if(c)return c}const n=Ot(f*l.getoffsetX(r.glyphStartIndex),p,d,i,r.segment,r.lineStartIndex,r.lineStartIndex+r.lineLength,t,h);if(!n||t.projectionCache.anyProjectionOccluded)return{notEnoughRoom:!0};m=[n]}for(const t of m)e.ak(c,t.point,t.angle);return{}}function Ct(t,e,r,n,i,a){const o=t.add(t.sub(e)._unit()),s=void 0!==i?wt(o,i,a.getElevation).point:It(o.x,o.y,a).point,l=r.sub(s);return r.add(l._mult(n/l.mag()))}function Lt(t,r,n){const i=r.projectionCache;if(i.projections[t])return i.projections[t];const a=new e.P(r.lineVertexArray.getx(t),r.lineVertexArray.gety(t)),o=It(a.x,a.y,r);if(o.signedDistanceFromCamera>0)return i.projections[t]=o.point,i.anyProjectionOccluded=i.anyProjectionOccluded||o.isOccluded,o.point;const s=t-n.direction,l=0===n.distanceFromAnchor?r.tileAnchorPoint:new e.P(r.lineVertexArray.getx(s),r.lineVertexArray.gety(s)),c=n.absOffsetX-n.distanceFromAnchor+1;return function(t,e,r,n,i){return Ct(t,e,r,n,void 0,i)}(l,a,n.previousVertex,c,r)}function It(t,r,n){const i=t+n.translation[0],a=r+n.translation[1];let o;return!n.pitchWithMap&&n.projection.useSpecialProjectionForSymbols?(o=n.projection.projectTileCoordinates(i,a,n.unwrappedTileID,n.getElevation),o.point.x=(.5*o.point.x+.5)*n.width,o.point.y=(.5*-o.point.y+.5)*n.height):(o=wt(new e.P(i,a),n.labelPlaneMatrix,n.getElevation),o.isOccluded=!1),o}function Pt(t,e,r){return t._unit()._perp()._mult(e*r)}function zt(t,r,n,i,a,o,s,l,c){if(l.projectionCache.offsets[t])return l.projectionCache.offsets[t];const u=n.add(r);if(t+c.direction<i||t+c.direction>=a)return l.projectionCache.offsets[t]=u,u;const h=Lt(t+c.direction,l,c),f=Pt(h.sub(n),s,c.direction),p=n.add(f),d=h.add(f);return l.projectionCache.offsets[t]=e.al(o,u,p,d)||u,l.projectionCache.offsets[t]}function Ot(t,e,r,n,i,a,o,s,l){const c=n?t-e:t+e;let u=c>0?1:-1,h=0;n&&(u*=-1,h=Math.PI),u<0&&(h+=Math.PI);let f,p=u>0?a+i:a+i+1;s.projectionCache.cachedAnchorPoint?f=s.projectionCache.cachedAnchorPoint:(f=It(s.tileAnchorPoint.x,s.tileAnchorPoint.y,s).point,s.projectionCache.cachedAnchorPoint=f);let d,m,g=f,y=f,v=0,x=0;const _=Math.abs(c),b=[];let w;for(;v+x<=_;){if(p+=u,p<a||p>=o)return null;v+=x,y=g,m=d;const t={absOffsetX:_,direction:u,distanceFromAnchor:v,previousVertex:y};if(g=Lt(p,s,t),0===r)b.push(y),w=g.sub(y);else{let e;const n=g.sub(y);e=0===n.mag()?Pt(Lt(p+u,s,t).sub(g),r,u):Pt(n,r,u),m||(m=y.add(e)),d=zt(p,e,g,a,o,m,r,s,t),b.push(m),w=d.sub(m)}x=w.mag()}const T=(_-v)/x,k=w._mult(T)._add(m||y),A=h+Math.atan2(g.y-y.y,g.x-y.x);return b.push(k),{point:k,angle:l?A:0,path:b}}const Dt=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function Rt(t,e){for(let r=0;r<t;r++){const t=e.length;e.resize(t+4),e.float32.set(Dt,3*t)}}const Ft=100;class Bt{constructor(t,e,r=new xt(t.width+200,t.height+200,25),n=new xt(t.width+200,t.height+200,25)){this.transform=t,this.mapProjection=e,this.grid=r,this.ignoredGrid=n,this.pitchFactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+Ft,this.screenBottomBoundary=t.height+Ft,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200,this.perspectiveRatioCutoff=.6}placeCollisionBox(t,e,r,n,i,a,o,s,l,c,u){const h=t.anchorPointX+s[0],f=t.anchorPointY+s[1],p=this.projectAndGetPerspectiveRatio(n,h,f,i,c),d=this._projectCollisionBox(t,r,n,i,a,o,s,p,c,u),[m,g,y,v]=d.box;return this.mapProjection.useSpecialProjectionForSymbols&&(a?d.allPointsOccluded:this.mapProjection.isOccluded(h,f,i))||p.perspectiveRatio<this.perspectiveRatioCutoff||!this.isInsideGrid(m,g,y,v)||\"always\"!==e&&this.grid.hitTest(m,g,y,v,e,l)?{box:[m,g,y,v],placeable:!1,offscreen:!1}:{box:[m,g,y,v],placeable:!0,offscreen:this.isOffscreen(m,g,y,v)}}placeCollisionCircles(t,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g){const y=[],v=new e.P(r.anchorX,r.anchorY),x=this.getPerspectiveRatio(o,v.x,v.y,s,g),_=(h?a/x:a*x)/e.aq,b=r.lineOffsetX*_,w=r.lineOffsetY*_,T={getElevation:g,labelPlaneMatrix:l,lineVertexArray:n,pitchWithMap:h,projectionCache:{projections:{},offsets:{},cachedAnchorPoint:void 0,anyProjectionOccluded:!1},projection:this.mapProjection,tileAnchorPoint:v,unwrappedTileID:s,width:this.transform.width,height:this.transform.height,translation:m},k=Mt(_,i,b,w,!1,r,!1,T);let A=!1,M=!1,S=!0;if(k){const r=.5*p*x+d,n=new e.P(-100,-100),i=new e.P(this.screenRightBoundary,this.screenBottomBoundary),a=new yt,o=k.first,s=k.last;let l=[];for(let t=o.path.length-1;t>=1;t--)l.push(o.path[t]);for(let t=1;t<s.path.length;t++)l.push(s.path[t]);const h=2.5*r;if(c){const t=this.projectPathToScreenSpace(l,T,c);l=t.some((t=>t.signedDistanceFromCamera<=0))?[]:t.map((t=>t.point))}let m=[];if(l.length>0){const t=l[0].clone(),r=l[0].clone();for(let e=1;e<l.length;e++)t.x=Math.min(t.x,l[e].x),t.y=Math.min(t.y,l[e].y),r.x=Math.max(r.x,l[e].x),r.y=Math.max(r.y,l[e].y);m=t.x>=n.x&&r.x<=i.x&&t.y>=n.y&&r.y<=i.y?[l]:r.x<n.x||t.x>i.x||r.y<n.y||t.y>i.y?[]:e.am([l],n.x,n.y,i.x,i.y)}for(const e of m){a.reset(e,.25*r);let n=0;n=a.length<=.5*r?1:Math.ceil(a.paddedLength/h)+1;for(let e=0;e<n;e++){const i=e/Math.max(n-1,1),o=a.lerp(i),s=o.x+Ft,l=o.y+Ft;y.push(s,l,r,0);const c=s-r,h=l-r,p=s+r,d=l+r;if(S=S&&this.isOffscreen(c,h,p,d),M=M||this.isInsideGrid(c,h,p,d),\"always\"!==t&&this.grid.hitTestCircle(s,l,r,t,f)&&(A=!0,!u))return{circles:[],offscreen:!1,collisionDetected:A}}}}return{circles:!u&&A||!M||x<this.perspectiveRatioCutoff?[]:y,offscreen:S,collisionDetected:A}}projectPathToScreenSpace(t,e,r){return t.map((t=>wt(t,r,e.getElevation)))}queryRenderedSymbols(t){if(0===t.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};const r=[];let n=1/0,i=1/0,a=-1/0,o=-1/0;for(const s of t){const t=new e.P(s.x+Ft,s.y+Ft);n=Math.min(n,t.x),i=Math.min(i,t.y),a=Math.max(a,t.x),o=Math.max(o,t.y),r.push(t)}const s=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o)),l={},c={};for(const t of s){const n=t.key;if(void 0===l[n.bucketInstanceId]&&(l[n.bucketInstanceId]={}),l[n.bucketInstanceId][n.featureIndex])continue;const i=[new e.P(t.x1,t.y1),new e.P(t.x2,t.y1),new e.P(t.x2,t.y2),new e.P(t.x1,t.y2)];e.an(r,i)&&(l[n.bucketInstanceId][n.featureIndex]=!0,void 0===c[n.bucketInstanceId]&&(c[n.bucketInstanceId]=[]),c[n.bucketInstanceId].push(n.featureIndex))}return c}insertCollisionBox(t,e,r,n,i,a){const o={bucketInstanceId:n,featureIndex:i,collisionGroupID:a,overlapMode:e};(r?this.ignoredGrid:this.grid).insert(o,t[0],t[1],t[2],t[3])}insertCollisionCircles(t,e,r,n,i,a){const o=r?this.ignoredGrid:this.grid,s={bucketInstanceId:n,featureIndex:i,collisionGroupID:a,overlapMode:e};for(let e=0;e<t.length;e+=4)o.insertCircle(s,t[e],t[e+1],t[e+2])}projectAndGetPerspectiveRatio(t,r,n,i,a){const o=this.mapProjection.useSpecialProjectionForSymbols?this.mapProjection.projectTileCoordinates(r,n,i,a):wt(new e.P(r,n),t,a);return{point:new e.P((o.point.x+1)/2*this.transform.width+Ft,(1-o.point.y)/2*this.transform.height+Ft),perspectiveRatio:.5+this.transform.cameraToCenterDistance/o.signedDistanceFromCamera*.5,isOccluded:o.isOccluded,signedDistanceFromCamera:o.signedDistanceFromCamera}}getPerspectiveRatio(t,r,n,i,a){const o=this.mapProjection.useSpecialProjectionForSymbols?this.mapProjection.projectTileCoordinates(r,n,i,a):wt(new e.P(r,n),t,a);return.5+this.transform.cameraToCenterDistance/o.signedDistanceFromCamera*.5}isOffscreen(t,e,r,n){return r<Ft||t>=this.screenRightBoundary||n<Ft||e>this.screenBottomBoundary}isInsideGrid(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary}getViewportMatrix(){const t=e.ao([]);return e.J(t,t,[-100,-100,0]),t}_projectCollisionBox(t,r,n,i,a,o,s,l,c,u){const h=r*l.perspectiveRatio;let f=new e.P(1,0),p=new e.P(0,1);const d=new e.P(t.anchorPointX+s[0],t.anchorPointY+s[1]);if(o&&!a){const t=this.projectAndGetPerspectiveRatio(n,d.x+1,d.y,i,c).point.sub(l.point).unit(),r=Math.atan(t.y/t.x)+(t.x<0?Math.PI:0),a=Math.sin(r),o=Math.cos(r);f=new e.P(o,a),p=new e.P(-a,o)}else if(!o&&a){const t=-this.transform.angle,r=Math.sin(t),n=Math.cos(t);f=new e.P(n,r),p=new e.P(-r,n)}let m=l.point,g=h;if(a){m=d;const t=this.transform.zoom-Math.floor(this.transform.zoom);if(g=Math.pow(2,-t),g*=this.mapProjection.getPitchedTextCorrection(this.transform,d,i),!u){const t=l.signedDistanceFromCamera/this.transform.cameraToCenterDistance;g*=e.ad(.5+.5*t,0,4)}}u&&(m=m.add(f.mult(u.x*g)).add(p.mult(u.y*g)));const y=t.x1*g,v=t.x2*g,x=(y+v)/2,_=t.y1*g,b=t.y2*g,w=(_+b)/2,T=[{offsetX:y,offsetY:_},{offsetX:x,offsetY:_},{offsetX:v,offsetY:_},{offsetX:v,offsetY:w},{offsetX:v,offsetY:b},{offsetX:x,offsetY:b},{offsetX:y,offsetY:b},{offsetX:y,offsetY:w}];let k=[];for(const{offsetX:t,offsetY:r}of T)k.push(new e.P(m.x+f.x*t+p.x*r,m.y+f.y*t+p.y*r));let A=!1;if(a){const t=k.map((t=>this.projectAndGetPerspectiveRatio(n,t.x,t.y,i,c)));A=t.some((t=>!t.isOccluded)),k=t.map((t=>t.point))}else A=!0;return{box:e.ap(k),allPointsOccluded:!A}}}function Nt(t,r,n){return r*(e.X/(t.tileSize*Math.pow(2,n-t.tileID.overscaledZ)))}class jt{constructor(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r}isHidden(){return 0===this.opacity&&!this.placed}}class Ut{constructor(t,e,r,n,i){this.text=new jt(t?t.text:null,e,r,i),this.icon=new jt(t?t.icon:null,e,n,i)}isHidden(){return this.text.isHidden()&&this.icon.isHidden()}}class Vt{constructor(t,e,r){this.text=t,this.icon=e,this.skipFade=r}}class qt{constructor(){this.invProjMatrix=e.H(),this.viewportMatrix=e.H(),this.circles=[]}}class Ht{constructor(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i}}class Gt{constructor(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}}get(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){const e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:t=>t.collisionGroupID===e}}return this.collisionGroups[t]}}function Zt(t,r,n,i,a){const{horizontalAlign:o,verticalAlign:s}=e.av(t),l=-(o-.5)*r,c=-(s-.5)*n;return new e.P(l+i[0]*a,c+i[1]*a)}class Wt{constructor(t,e,r,n,i,a){this.transform=t.clone(),this.terrain=r,this.collisionIndex=new Bt(this.transform,e),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=n,this.retainedQueryData={},this.collisionGroups=new Gt(i),this.collisionCircleArrays={},this.collisionBoxArrays=new Map,this.prevPlacement=a,a&&(a.prevPlacement=void 0),this.placedOrientations={}}_getTerrainElevationFunc(t){const e=this.terrain;return e?(r,n)=>e.getElevation(t,r,n):null}getBucketParts(t,r,n,i){const a=n.getBucket(r),o=n.latestFeatureIndex;if(!a||!o||r.id!==a.layerIds[0])return;const s=n.collisionBoxArray,l=a.layers[0].layout,c=a.layers[0].paint,u=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),h=n.tileSize/e.X,f=n.tileID.toUnwrapped(),p=this.transform.calculatePosMatrix(f),d=\"map\"===l.get(\"text-pitch-alignment\"),m=\"map\"===l.get(\"text-rotation-alignment\"),g=Nt(n,1,this.transform.zoom),y=this.collisionIndex.mapProjection.translatePosition(this.transform,n,c.get(\"text-translate\"),c.get(\"text-translate-anchor\")),v=this.collisionIndex.mapProjection.translatePosition(this.transform,n,c.get(\"icon-translate\"),c.get(\"icon-translate-anchor\")),x=_t(p,d,m,this.transform,g);let _=null;if(d){const t=bt(p,d,m,this.transform,g);_=e.L([],this.transform.labelPlaneMatrix,t)}this.retainedQueryData[a.bucketInstanceId]=new Ht(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,n.tileID);const b={bucket:a,layout:l,translationText:y,translationIcon:v,posMatrix:p,unwrappedTileID:f,textLabelPlaneMatrix:x,labelToScreenMatrix:_,scale:u,textPixelRatio:h,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:e.ah(a.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(a.sourceID)};if(i)for(const e of a.sortKeyRanges){const{sortKey:r,symbolInstanceStart:n,symbolInstanceEnd:i}=e;t.push({sortKey:r,symbolInstanceStart:n,symbolInstanceEnd:i,parameters:b})}else t.push({symbolInstanceStart:0,symbolInstanceEnd:a.symbolInstances.length,parameters:b})}attemptAnchorPlacement(t,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y,v,x){const _=e.ar[t.textAnchor],b=[t.textOffset0,t.textOffset1],w=Zt(_,n,i,b,a),T=this.collisionIndex.placeCollisionBox(r,f,l,c,u,s,o,g,h.predicate,x,w);if((!v||this.collisionIndex.placeCollisionBox(v,f,l,c,u,s,o,y,h.predicate,x,w).placeable)&&T.placeable){let t;if(this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(t=this.prevPlacement.variableOffsets[p.crossTileID].anchor),0===p.crossTileID)throw new Error(\"symbolInstance.crossTileID can't be 0\");return this.variableOffsets[p.crossTileID]={textOffset:b,width:n,height:i,anchor:_,textBoxScale:a,prevAnchor:t},this.markUsedJustification(d,_,p,m),d.allowVerticalPlacement&&(this.markUsedOrientation(d,m,p),this.placedOrientations[p.crossTileID]=m),{shift:w,placedGlyphBoxes:T}}}placeLayerBucketPart(t,r,n){const{bucket:i,layout:a,translationText:o,translationIcon:s,posMatrix:l,unwrappedTileID:c,textLabelPlaneMatrix:u,labelToScreenMatrix:h,textPixelRatio:f,holdingForFade:p,collisionBoxArray:d,partiallyEvaluatedTextSize:m,collisionGroup:g}=t.parameters,y=a.get(\"text-optional\"),v=a.get(\"icon-optional\"),x=e.as(a,\"text-overlap\",\"text-allow-overlap\"),_=\"always\"===x,b=e.as(a,\"icon-overlap\",\"icon-allow-overlap\"),w=\"always\"===b,T=\"map\"===a.get(\"text-rotation-alignment\"),k=\"map\"===a.get(\"text-pitch-alignment\"),A=\"none\"!==a.get(\"icon-text-fit\"),M=\"viewport-y\"===a.get(\"symbol-z-order\"),S=_&&(w||!i.hasIconData()||v),E=w&&(_||!i.hasTextData()||y);!i.collisionArrays&&d&&i.deserializeCollisionBoxes(d);const C=this.retainedQueryData[i.bucketInstanceId].tileID,L=this._getTerrainElevationFunc(C),I=(t,d,w)=>{var M,C;if(r[t.crossTileID])return;if(p)return void(this.placements[t.crossTileID]=new Vt(!1,!1,!1));let I=!1,P=!1,z=!0,O=null,D={box:null,placeable:!1,offscreen:null},R={box:null,placeable:!1,offscreen:null},F=null,B=null,N=null,j=0,U=0,V=0;d.textFeatureIndex?j=d.textFeatureIndex:t.useRuntimeCollisionCircles&&(j=t.featureIndex),d.verticalTextFeatureIndex&&(U=d.verticalTextFeatureIndex);const q=d.textBox;if(q){const r=r=>{let n=e.ai.horizontal;if(i.allowVerticalPlacement&&!r&&this.prevPlacement){const e=this.prevPlacement.placedOrientations[t.crossTileID];e&&(this.placedOrientations[t.crossTileID]=e,n=e,this.markUsedOrientation(i,n,t))}return n},a=(r,n)=>{if(i.allowVerticalPlacement&&t.numVerticalGlyphVertices>0&&d.verticalTextBox){for(const t of i.writingModes)if(t===e.ai.vertical?(D=n(),R=D):D=r(),D&&D.placeable)break}else D=r()},u=t.textAnchorOffsetStartIndex,h=t.textAnchorOffsetEndIndex;if(h===u){const n=(e,r)=>{const n=this.collisionIndex.placeCollisionBox(e,x,f,l,c,k,T,o,g.predicate,L);return n&&n.placeable&&(this.markUsedOrientation(i,r,t),this.placedOrientations[t.crossTileID]=r),n};a((()=>n(q,e.ai.horizontal)),(()=>{const r=d.verticalTextBox;return i.allowVerticalPlacement&&t.numVerticalGlyphVertices>0&&r?n(r,e.ai.vertical):{box:null,offscreen:null}})),r(D&&D.placeable)}else{let p=e.ar[null===(C=null===(M=this.prevPlacement)||void 0===M?void 0:M.variableOffsets[t.crossTileID])||void 0===C?void 0:C.anchor];const m=(r,a,d)=>{const m=r.x2-r.x1,y=r.y2-r.y1,v=t.textBoxScale,_=A&&\"never\"===b?a:null;let w=null,M=\"never\"===x?1:2,S=\"never\";p&&M++;for(let e=0;e<M;e++){for(let e=u;e<h;e++){const n=i.textAnchorOffsets.get(e);if(p&&n.textAnchor!==p)continue;const a=this.attemptAnchorPlacement(n,r,m,y,v,T,k,f,l,c,g,S,t,i,d,o,s,_,L);if(a&&(w=a.placedGlyphBoxes,w&&w.placeable))return I=!0,O=a.shift,w}p?p=null:S=x}return n&&!w&&(w={box:this.collisionIndex.placeCollisionBox(q,\"always\",f,l,c,k,T,o,g.predicate,L,new e.P(0,0)).box,offscreen:!1,placeable:!1}),w};a((()=>m(q,d.iconBox,e.ai.horizontal)),(()=>{const r=d.verticalTextBox,n=D&&D.placeable;return i.allowVerticalPlacement&&!n&&t.numVerticalGlyphVertices>0&&r?m(r,d.verticalIconBox,e.ai.vertical):{box:null,occluded:!0,offscreen:null}})),D&&(I=D.placeable,z=D.offscreen);const y=r(D&&D.placeable);if(!I&&this.prevPlacement){const e=this.prevPlacement.variableOffsets[t.crossTileID];e&&(this.variableOffsets[t.crossTileID]=e,this.markUsedJustification(i,e.anchor,t,y))}}}if(F=D,I=F&&F.placeable,z=F&&F.offscreen,t.useRuntimeCollisionCircles){const r=i.text.placedSymbolArray.get(t.centerJustifiedTextSymbolIndex),s=e.aj(i.textSizeData,m,r),f=a.get(\"text-padding\"),p=t.collisionCircleDiameter;B=this.collisionIndex.placeCollisionCircles(x,r,i.lineVertexArray,i.glyphOffsetArray,s,l,c,u,h,n,k,g.predicate,p,f,o,L),B.circles.length&&B.collisionDetected&&!n&&e.w(\"Collisions detected, but collision boxes are not shown\"),I=_||B.circles.length>0&&!B.collisionDetected,z=z&&B.offscreen}if(d.iconFeatureIndex&&(V=d.iconFeatureIndex),d.iconBox){const t=t=>this.collisionIndex.placeCollisionBox(t,b,f,l,c,k,T,s,g.predicate,L,A&&O?O:void 0);R&&R.placeable&&d.verticalIconBox?(N=t(d.verticalIconBox),P=N.placeable):(N=t(d.iconBox),P=N.placeable),z=z&&N.offscreen}const H=y||0===t.numHorizontalGlyphVertices&&0===t.numVerticalGlyphVertices,G=v||0===t.numIconVertices;H||G?G?H||(P=P&&I):I=P&&I:P=I=P&&I;const Z=I&&F.placeable,W=P&&N.placeable;if(Z&&(R&&R.placeable&&U?this.collisionIndex.insertCollisionBox(F.box,x,a.get(\"text-ignore-placement\"),i.bucketInstanceId,U,g.ID):this.collisionIndex.insertCollisionBox(F.box,x,a.get(\"text-ignore-placement\"),i.bucketInstanceId,j,g.ID)),W&&this.collisionIndex.insertCollisionBox(N.box,b,a.get(\"icon-ignore-placement\"),i.bucketInstanceId,V,g.ID),B&&I&&this.collisionIndex.insertCollisionCircles(B.circles,x,a.get(\"text-ignore-placement\"),i.bucketInstanceId,j,g.ID),n&&this.storeCollisionData(i.bucketInstanceId,w,d,F,N,B),0===t.crossTileID)throw new Error(\"symbolInstance.crossTileID can't be 0\");if(0===i.bucketInstanceId)throw new Error(\"bucket.bucketInstanceId can't be 0\");this.placements[t.crossTileID]=new Vt(I||S,P||E,z||i.justReloaded),r[t.crossTileID]=!0};if(M){if(0!==t.symbolInstanceStart)throw new Error(\"bucket.bucketInstanceId should be 0\");const e=i.getSortedSymbolIndexes(this.transform.angle);for(let t=e.length-1;t>=0;--t){const r=e[t];I(i.symbolInstances.get(r),i.collisionArrays[r],r)}}else for(let e=t.symbolInstanceStart;e<t.symbolInstanceEnd;e++)I(i.symbolInstances.get(e),i.collisionArrays[e],e);if(n&&i.bucketInstanceId in this.collisionCircleArrays){const t=this.collisionCircleArrays[i.bucketInstanceId];e.at(t.invProjMatrix,l),t.viewportMatrix=this.collisionIndex.getViewportMatrix()}i.justReloaded=!1}storeCollisionData(t,e,r,n,i,a){if(r.textBox||r.iconBox){let a,o;this.collisionBoxArrays.has(t)?a=this.collisionBoxArrays.get(t):(a=new Map,this.collisionBoxArrays.set(t,a)),a.has(e)?o=a.get(e):(o={text:null,icon:null},a.set(e,o)),r.textBox&&(o.text=n.box),r.iconBox&&(o.icon=i.box)}if(a){let e=this.collisionCircleArrays[t];void 0===e&&(e=this.collisionCircleArrays[t]=new qt);for(let t=0;t<a.circles.length;t+=4)e.circles.push(a.circles[t+0]),e.circles.push(a.circles[t+1]),e.circles.push(a.circles[t+2]),e.circles.push(a.collisionDetected?1:0)}}markUsedJustification(t,r,n,i){const a={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex};let o;o=i===e.ai.vertical?n.verticalPlacedTextSymbolIndex:a[e.au(r)];const s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];for(const e of s)e>=0&&(t.text.placedSymbolArray.get(e).crossTileID=o>=0&&e!==o?0:n.crossTileID)}markUsedOrientation(t,r,n){const i=r===e.ai.horizontal||r===e.ai.horizontalOnly?r:0,a=r===e.ai.vertical?r:0,o=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];for(const e of o)t.text.placedSymbolArray.get(e).placedOrientation=i;n.verticalPlacedTextSymbolIndex&&(t.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=a)}commit(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;const e=this.prevPlacement;let r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;const n=e?e.symbolFadeChange(t):1,i=e?e.opacities:{},a=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(const t in this.placements){const e=this.placements[t],a=i[t];a?(this.opacities[t]=new Ut(a,n,e.text,e.icon),r=r||e.text!==a.text.placed||e.icon!==a.icon.placed):(this.opacities[t]=new Ut(null,n,e.text,e.icon,e.skipFade),r=r||e.text||e.icon)}for(const t in i){const e=i[t];if(!this.opacities[t]){const i=new Ut(e,n,!1,!1);i.isHidden()||(this.opacities[t]=i,r=r||e.text.placed||e.icon.placed)}}for(const t in a)this.variableOffsets[t]||!this.opacities[t]||this.opacities[t].isHidden()||(this.variableOffsets[t]=a[t]);for(const t in o)this.placedOrientations[t]||!this.opacities[t]||this.opacities[t].isHidden()||(this.placedOrientations[t]=o[t]);if(e&&void 0===e.lastPlacementChangeTime)throw new Error(\"Last placement time for previous placement is not defined\");r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)}updateLayerOpacities(t,e){const r={};for(const n of e){const e=n.getBucket(t);e&&n.latestFeatureIndex&&t.id===e.layerIds[0]&&this.updateBucketOpacities(e,n.tileID,r,n.collisionBoxArray)}}updateBucketOpacities(t,r,n,i){t.hasTextData()&&(t.text.opacityVertexArray.clear(),t.text.hasVisibleVertices=!1),t.hasIconData()&&(t.icon.opacityVertexArray.clear(),t.icon.hasVisibleVertices=!1),t.hasIconCollisionBoxData()&&t.iconCollisionBox.collisionVertexArray.clear(),t.hasTextCollisionBoxData()&&t.textCollisionBox.collisionVertexArray.clear();const a=t.layers[0],o=a.layout,s=new Ut(null,0,!1,!1,!0),l=o.get(\"text-allow-overlap\"),c=o.get(\"icon-allow-overlap\"),u=a._unevaluatedLayout.hasValue(\"text-variable-anchor\")||a._unevaluatedLayout.hasValue(\"text-variable-anchor-offset\"),h=\"map\"===o.get(\"text-rotation-alignment\"),f=\"map\"===o.get(\"text-pitch-alignment\"),p=\"none\"!==o.get(\"icon-text-fit\"),d=new Ut(null,0,l&&(c||!t.hasIconData()||o.get(\"icon-optional\")),c&&(l||!t.hasTextData()||o.get(\"text-optional\")),!0);!t.collisionArrays&&i&&(t.hasIconCollisionBoxData()||t.hasTextCollisionBoxData())&&t.deserializeCollisionBoxes(i);const m=(t,e,r)=>{for(let n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r);t.hasVisibleVertices=t.hasVisibleVertices||r!==ne},g=this.collisionBoxArrays.get(t.bucketInstanceId);for(let r=0;r<t.symbolInstances.length;r++){const i=t.symbolInstances.get(r),{numHorizontalGlyphVertices:a,numVerticalGlyphVertices:o,crossTileID:l}=i,c=n[l];let y=this.opacities[l];c?y=s:y||(y=d,this.opacities[l]=y),n[l]=!0;const v=a>0||o>0,x=i.numIconVertices>0,_=this.placedOrientations[i.crossTileID],b=_===e.ai.vertical,w=_===e.ai.horizontal||_===e.ai.horizontalOnly;if(v){const e=re(y.text),r=b?ne:e;m(t.text,a,r);const n=w?ne:e;m(t.text,o,n);const s=y.text.isHidden();[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach((e=>{e>=0&&(t.text.placedSymbolArray.get(e).hidden=s||b?1:0)})),i.verticalPlacedTextSymbolIndex>=0&&(t.text.placedSymbolArray.get(i.verticalPlacedTextSymbolIndex).hidden=s||w?1:0);const l=this.variableOffsets[i.crossTileID];l&&this.markUsedJustification(t,l.anchor,i,_);const c=this.placedOrientations[i.crossTileID];c&&(this.markUsedJustification(t,\"left\",i,c),this.markUsedOrientation(t,c,i))}if(x){const e=re(y.icon),r=!(p&&i.verticalPlacedIconSymbolIndex&&b);if(i.placedIconSymbolIndex>=0){const n=r?e:ne;m(t.icon,i.numIconVertices,n),t.icon.placedSymbolArray.get(i.placedIconSymbolIndex).hidden=y.icon.isHidden()}if(i.verticalPlacedIconSymbolIndex>=0){const n=r?ne:e;m(t.icon,i.numVerticalIconVertices,n),t.icon.placedSymbolArray.get(i.verticalPlacedIconSymbolIndex).hidden=y.icon.isHidden()}}const T=g&&g.has(r)?g.get(r):{text:null,icon:null};if(t.hasIconCollisionBoxData()||t.hasTextCollisionBoxData()){const n=t.collisionArrays[r];if(n){let r=new e.P(0,0);if(n.textBox||n.verticalTextBox){let e=!0;if(u){const t=this.variableOffsets[l];t?(r=Zt(t.anchor,t.width,t.height,t.textOffset,t.textBoxScale),h&&r._rotate(f?this.transform.angle:-this.transform.angle)):e=!1}if(n.textBox||n.verticalTextBox){let i;n.textBox&&(i=b),n.verticalTextBox&&(i=w),Yt(t.textCollisionBox.collisionVertexArray,y.text.placed,!e||i,T.text,r.x,r.y)}}if(n.iconBox||n.verticalIconBox){const e=Boolean(!w&&n.verticalIconBox);let i;n.iconBox&&(i=e),n.verticalIconBox&&(i=!e),Yt(t.iconCollisionBox.collisionVertexArray,y.icon.placed,i,T.icon,p?r.x:0,p?r.y:0)}}}}if(t.sortFeatures(this.transform.angle),this.retainedQueryData[t.bucketInstanceId]&&(this.retainedQueryData[t.bucketInstanceId].featureSortOrder=t.featureSortOrder),t.hasTextData()&&t.text.opacityVertexBuffer&&t.text.opacityVertexBuffer.updateData(t.text.opacityVertexArray),t.hasIconData()&&t.icon.opacityVertexBuffer&&t.icon.opacityVertexBuffer.updateData(t.icon.opacityVertexArray),t.hasIconCollisionBoxData()&&t.iconCollisionBox.collisionVertexBuffer&&t.iconCollisionBox.collisionVertexBuffer.updateData(t.iconCollisionBox.collisionVertexArray),t.hasTextCollisionBoxData()&&t.textCollisionBox.collisionVertexBuffer&&t.textCollisionBox.collisionVertexBuffer.updateData(t.textCollisionBox.collisionVertexArray),t.text.opacityVertexArray.length!==t.text.layoutVertexArray.length/4)throw new Error(`bucket.text.opacityVertexArray.length (= ${t.text.opacityVertexArray.length}) !== bucket.text.layoutVertexArray.length (= ${t.text.layoutVertexArray.length}) / 4`);if(t.icon.opacityVertexArray.length!==t.icon.layoutVertexArray.length/4)throw new Error(`bucket.icon.opacityVertexArray.length (= ${t.icon.opacityVertexArray.length}) !== bucket.icon.layoutVertexArray.length (= ${t.icon.layoutVertexArray.length}) / 4`);if(t.bucketInstanceId in this.collisionCircleArrays){const e=this.collisionCircleArrays[t.bucketInstanceId];t.placementInvProjMatrix=e.invProjMatrix,t.placementViewportMatrix=e.viewportMatrix,t.collisionCircleArray=e.circles,delete this.collisionCircleArrays[t.bucketInstanceId]}}symbolFadeChange(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment}zoomAdjustment(t){return Math.max(0,(this.transform.zoom-t)/1.5)}hasTransitions(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration}stillRecent(t,e){const r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t}setStale(){this.stale=!0}}function Yt(t,e,r,n,i,a){n&&0!==n.length||(n=[0,0,0,0]);const o=n[0]-Ft,s=n[1]-Ft,l=n[2]-Ft,c=n[3]-Ft;t.emplaceBack(e?1:0,r?1:0,i||0,a||0,o,s),t.emplaceBack(e?1:0,r?1:0,i||0,a||0,l,s),t.emplaceBack(e?1:0,r?1:0,i||0,a||0,l,c),t.emplaceBack(e?1:0,r?1:0,i||0,a||0,o,c)}const Xt=Math.pow(2,25),$t=Math.pow(2,24),Jt=Math.pow(2,17),Kt=Math.pow(2,16),Qt=Math.pow(2,9),te=Math.pow(2,8),ee=Math.pow(2,1);function re(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;const e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Xt+e*$t+r*Jt+e*Kt+r*Qt+e*te+r*ee+e}const ne=0;function ie(){return{isOccluded(t,e,r){return!1},getPitchedTextCorrection(t,e,r){return 1},get useSpecialProjectionForSymbols(){return!1},projectTileCoordinates(t,e,r,n){throw new Error(\"Not implemented.\")},translatePosition(t,e,r,n){return function(t,e,r,n,i=!1){if(!r[0]&&!r[1])return[0,0];const a=i?\"map\"===n?t.angle:0:\"viewport\"===n?-t.angle:0;if(a){const t=Math.sin(a),e=Math.cos(a);r=[r[0]*e-r[1]*t,r[0]*t+r[1]*e]}return[i?r[0]:Nt(e,r[0],t.zoom),i?r[1]:Nt(e,r[1],t.zoom)]}(t,e,r,n)},getCircleRadiusCorrection(t){return 1}}}class ae{constructor(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&!t.layout.get(\"symbol-sort-key\").isConstant(),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]}continuePlacement(t,e,r,n,i){const a=this._bucketParts;for(;this._currentTileIndex<t.length;){const r=t[this._currentTileIndex];if(e.getBucketParts(a,n,r,this._sortAcrossTiles),this._currentTileIndex++,i())return!0}for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,a.sort(((t,e)=>t.sortKey-e.sortKey)));this._currentPartIndex<a.length;){const t=a[this._currentPartIndex];if(e.placeLayerBucketPart(t,this._seenCrossTileIDs,r),this._currentPartIndex++,i())return!0}return!1}}class oe{constructor(t,e,r,n,i,a,o,s){this.placement=new Wt(t,ie(),e,a,o,s),this._currentPlacementIndex=r.length-1,this._forceFullPlacement=n,this._showCollisionBoxes=i,this._done=!1}isDone(){return this._done}continuePlacement(t,e,r){const n=a.now(),i=()=>!this._forceFullPlacement&&a.now()-n>2;for(;this._currentPlacementIndex>=0;){const n=e[t[this._currentPlacementIndex]],a=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===n.type&&(!n.minzoom||n.minzoom<=a)&&(!n.maxzoom||n.maxzoom>a)){if(this._inProgressLayer||(this._inProgressLayer=new ae(n)),this._inProgressLayer.continuePlacement(r[n.source],this.placement,this._showCollisionBoxes,n,i))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0}commit(t){return this.placement.commit(t),this.placement}}const se=512/e.X/2;class le{constructor(t,r,n){this.tileID=t,this.bucketInstanceId=n,this._symbolsByKey={};const i=new Map;for(let t=0;t<r.length;t++){const e=r.get(t),n=e.key,a=i.get(n);a?a.push(e):i.set(n,[e])}for(const[t,r]of i){const n={positions:r.map((t=>({x:Math.floor(t.anchorX*se),y:Math.floor(t.anchorY*se)}))),crossTileIDs:r.map((t=>t.crossTileID))};if(n.positions.length>128){const t=new e.aw(n.positions.length,16,Uint16Array);for(const{x:e,y:r}of n.positions)t.add(e,r);t.finish(),delete n.positions,n.index=t}this._symbolsByKey[t]=n}}getScaledCoordinates(t,r){const{x:n,y:i,z:a}=this.tileID.canonical,{x:o,y:s,z:l}=r.canonical,c=l-a,u=se/Math.pow(2,c),h=(o*e.X+t.anchorX)*u,f=(s*e.X+t.anchorY)*u,p=n*e.X*se,d=i*e.X*se;return{x:Math.floor(h-p),y:Math.floor(f-d)}}findMatches(t,e,r){const n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z);for(let i=0;i<t.length;i++){const a=t.get(i);if(a.crossTileID)continue;const o=this._symbolsByKey[a.key];if(!o)continue;const s=this.getScaledCoordinates(a,e);if(o.index){const t=o.index.range(s.x-n,s.y-n,s.x+n,s.y+n).sort();for(const e of t){const t=o.crossTileIDs[e];if(!r[t]){r[t]=!0,a.crossTileID=t;break}}}else if(o.positions)for(let t=0;t<o.positions.length;t++){const e=o.positions[t],i=o.crossTileIDs[t];if(Math.abs(e.x-s.x)<=n&&Math.abs(e.y-s.y)<=n&&!r[i]){r[i]=!0,a.crossTileID=i;break}}}}getCrossTileIDsLists(){return Object.values(this._symbolsByKey).map((({crossTileIDs:t})=>t))}}class ce{constructor(){this.maxCrossTileID=0}generate(){return++this.maxCrossTileID}}class ue{constructor(){this.indexes={},this.usedCrossTileIDs={},this.lng=0}handleWrapJump(t){const e=Math.round((t-this.lng)/360);if(0!==e)for(const t in this.indexes){const r=this.indexes[t],n={};for(const t in r){const i=r[t];i.tileID=i.tileID.unwrapTo(i.tileID.wrap+e),n[i.tileID.key]=i}this.indexes[t]=n}this.lng=t}addBucket(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(let t=0;t<e.symbolInstances.length;t++)e.symbolInstances.get(t).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});const n=this.usedCrossTileIDs[t.overscaledZ];for(const r in this.indexes){const i=this.indexes[r];if(Number(r)>t.overscaledZ)for(const r in i){const a=i[r];a.tileID.isChildOf(t)&&a.findMatches(e.symbolInstances,t,n)}else{const a=i[t.scaledTo(Number(r)).key];a&&a.findMatches(e.symbolInstances,t,n)}}for(let t=0;t<e.symbolInstances.length;t++){const i=e.symbolInstances.get(t);i.crossTileID||(i.crossTileID=r.generate(),n[i.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new le(t,e.symbolInstances,e.bucketInstanceId),!0}removeBucketCrossTileIDs(t,e){for(const r of e.getCrossTileIDsLists())for(const e of r)delete this.usedCrossTileIDs[t][e]}removeStaleBuckets(t){let e=!1;for(const r in this.indexes){const n=this.indexes[r];for(const i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e}}class he{constructor(){this.layerIndexes={},this.crossTileIDs=new ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}}addLayer(t,e,r){let n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new ue);let i=!1;const a={};n.handleWrapJump(r);for(const r of e){const e=r.getBucket(t);e&&t.id===e.layerIds[0]&&(e.bucketInstanceId||(e.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(r.tileID,e,this.crossTileIDs)&&(i=!0),a[e.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i}pruneUnusedLayers(t){const e={};t.forEach((t=>{e[t]=!0}));for(const t in this.layerIndexes)e[t]||delete this.layerIndexes[t]}}const fe=(t,r)=>e.t(t,r&&r.filter((t=>\"source.canvas\"!==t.identifier))),pe=e.ax();class de extends e.E{constructor(t,r={}){super(),this._rtlPluginLoaded=()=>{for(const t in this.sourceCaches){const e=this.sourceCaches[t].getSource().type;\"vector\"!==e&&\"geojson\"!==e||this.sourceCaches[t].reload()}},this.map=t,this.dispatcher=new q(V(),t._getMapId()),this.dispatcher.registerMessageHandler(\"GG\",((t,e)=>this.getGlyphs(t,e))),this.dispatcher.registerMessageHandler(\"GI\",((t,e)=>this.getImages(t,e))),this.imageManager=new k,this.imageManager.setEventedParent(this),this.glyphManager=new E(t._requestManager,r.localIdeographFontFamily),this.lineAtlas=new R(256,512),this.crossTileSymbolIndex=new he,this._spritesImagesIds={},this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new e.ay,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"SR\",e.az()),ut().on(st,this._rtlPluginLoaded),this.on(\"data\",(t=>{if(\"source\"!==t.dataType||\"metadata\"!==t.sourceDataType)return;const e=this.sourceCaches[t.sourceId];if(!e)return;const r=e.getSource();if(r&&r.vectorLayerIds)for(const t in this._layers){const e=this._layers[t];e.source===r.id&&this._validateLayer(e)}}))}loadURL(t,r={},n){this.fire(new e.k(\"dataloading\",{dataType:\"style\"})),r.validate=\"boolean\"!=typeof r.validate||r.validate;const i=this.map._requestManager.transformRequest(t,\"Style\");this._loadStyleRequest=new AbortController;const a=this._loadStyleRequest;e.h(i,this._loadStyleRequest).then((t=>{this._loadStyleRequest=null,this._load(t.data,r,n)})).catch((t=>{this._loadStyleRequest=null,t&&!a.signal.aborted&&this.fire(new e.j(t))}))}loadJSON(t,r={},n){this.fire(new e.k(\"dataloading\",{dataType:\"style\"})),this._frameRequest=new AbortController,a.frameAsync(this._frameRequest).then((()=>{this._frameRequest=null,r.validate=!1!==r.validate,this._load(t,r,n)})).catch((()=>{}))}loadEmpty(){this.fire(new e.k(\"dataloading\",{dataType:\"style\"})),this._load(pe,{validate:!1})}_load(t,r,n){var i;const a=r.transformStyle?r.transformStyle(n,t):t;if(!r.validate||!fe(this,e.x(a))){this._loaded=!0,this.stylesheet=a;for(const t in a.sources)this.addSource(t,a.sources[t],{validate:!1});a.sprite?this._loadSprite(a.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(a.glyphs),this._createLayers(),this.light=new P(this.stylesheet.light),this.sky=new D(this.stylesheet.sky),this.map.setTerrain(null!==(i=this.stylesheet.terrain)&&void 0!==i?i:null),this.fire(new e.k(\"data\",{dataType:\"style\"})),this.fire(new e.k(\"style.load\"))}}_createLayers(){const t=e.aA(this.stylesheet.layers);this.dispatcher.broadcast(\"SL\",t),this._order=t.map((t=>t.id)),this._layers={},this._serializedLayers=null;for(const r of t){const t=e.aB(r);t.setEventedParent(this,{layer:{id:r.id}}),this._layers[r.id]=t}}_loadSprite(t,r=!1,n=void 0){let i;this.imageManager.setLoaded(!1),this._spriteRequest=new AbortController,b(t,this.map._requestManager,this.map.getPixelRatio(),this._spriteRequest).then((t=>{if(this._spriteRequest=null,t)for(const e in t){this._spritesImagesIds[e]=[];const n=this._spritesImagesIds[e]?this._spritesImagesIds[e].filter((e=>!(e in t))):[];for(const t of n)this.imageManager.removeImage(t),this._changedImages[t]=!0;for(const n in t[e]){const i=\"default\"===e?n:`${e}:${n}`;this._spritesImagesIds[e].push(i),i in this.imageManager.images?this.imageManager.updateImage(i,t[e][n],!1):this.imageManager.addImage(i,t[e][n]),r&&(this._changedImages[i]=!0)}}})).catch((t=>{this._spriteRequest=null,i=t,this.fire(new e.j(i))})).finally((()=>{this.imageManager.setLoaded(!0),this._availableImages=this.imageManager.listImages(),r&&(this._changed=!0),this.dispatcher.broadcast(\"SI\",this._availableImages),this.fire(new e.k(\"data\",{dataType:\"style\"})),n&&n(i)}))}_unloadSprite(){for(const t of Object.values(this._spritesImagesIds).flat())this.imageManager.removeImage(t),this._changedImages[t]=!0;this._spritesImagesIds={},this._availableImages=this.imageManager.listImages(),this._changed=!0,this.dispatcher.broadcast(\"SI\",this._availableImages),this.fire(new e.k(\"data\",{dataType:\"style\"}))}_validateLayer(t){const r=this.sourceCaches[t.source];if(!r)return;const n=t.sourceLayer;if(!n)return;const i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new e.j(new Error(`Source layer \"${n}\" does not exist on source \"${i.id}\" as specified by style layer \"${t.id}\".`)))}loaded(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(const t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()}_serializeByIds(t){const e=this._serializedAllLayers();if(!t||0===t.length)return Object.values(e);const r=[];for(const n of t)e[n]&&r.push(e[n]);return r}_serializedAllLayers(){let t=this._serializedLayers;if(t)return t;t=this._serializedLayers={};const e=Object.keys(this._layers);for(const r of e){const e=this._layers[r];\"custom\"!==e.type&&(t[r]=e.serialize())}return t}hasTransitions(){if(this.light&&this.light.hasTransition())return!0;if(this.sky&&this.sky.hasTransition())return!0;for(const t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(const t in this._layers)if(this._layers[t].hasTransition())return!0;return!1}_checkLoaded(){if(!this._loaded)throw new Error(\"Style is not done loading.\")}update(t){if(!this._loaded)return;const r=this._changed;if(r){const e=Object.keys(this._updatedLayers),r=Object.keys(this._removedLayers);(e.length||r.length)&&this._updateWorkerLayers(e,r);for(const t in this._updatedSources){const e=this._updatedSources[t];if(\"reload\"===e)this._reloadSource(t);else{if(\"clear\"!==e)throw new Error(`Invalid action ${e}`);this._clearSource(t)}}this._updateTilesForChangedImages(),this._updateTilesForChangedGlyphs();for(const e in this._updatedPaintProps)this._layers[e].updateTransitions(t);this.light.updateTransitions(t),this.sky.updateTransitions(t),this._resetUpdates()}const n={};for(const t in this.sourceCaches){const e=this.sourceCaches[t];n[t]=e.used,e.used=!1}for(const e of this._order){const r=this._layers[e];r.recalculate(t,this._availableImages),!r.isHidden(t.zoom)&&r.source&&(this.sourceCaches[r.source].used=!0)}for(const t in n){const r=this.sourceCaches[t];!!n[t]!=!!r.used&&r.fire(new e.k(\"data\",{sourceDataType:\"visibility\",dataType:\"source\",sourceId:t}))}this.light.recalculate(t),this.sky.recalculate(t),this.z=t.zoom,r&&this.fire(new e.k(\"data\",{dataType:\"style\"}))}_updateTilesForChangedImages(){const t=Object.keys(this._changedImages);if(t.length){for(const e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}}_updateTilesForChangedGlyphs(){if(this._glyphsDidChange){for(const t in this.sourceCaches)this.sourceCaches[t].reloadTilesForDependencies([\"glyphs\"],[\"\"]);this._glyphsDidChange=!1}}_updateWorkerLayers(t,e){this.dispatcher.broadcast(\"UL\",{layers:this._serializeByIds(t),removedIds:e})}_resetUpdates(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={},this._glyphsDidChange=!1}setState(t,r={}){var n;this._checkLoaded();const i=this.serialize();if(t=r.transformStyle?r.transformStyle(i,t):t,(null===(n=r.validate)||void 0===n||n)&&fe(this,e.x(t)))return!1;(t=e.aC(t)).layers=e.aA(t.layers);const a=e.aD(i,t),o=this._getOperationsToPerform(a);if(o.unimplemented.length>0)throw new Error(`Unimplemented: ${o.unimplemented.join(\", \")}.`);if(0===o.operations.length)return!1;for(const t of o.operations)t();return this.stylesheet=t,this._serializedLayers=null,!0}_getOperationsToPerform(t){const e=[],r=[];for(const n of t)switch(n.command){case\"setCenter\":case\"setZoom\":case\"setBearing\":case\"setPitch\":continue;case\"addLayer\":e.push((()=>this.addLayer.apply(this,n.args)));break;case\"removeLayer\":e.push((()=>this.removeLayer.apply(this,n.args)));break;case\"setPaintProperty\":e.push((()=>this.setPaintProperty.apply(this,n.args)));break;case\"setLayoutProperty\":e.push((()=>this.setLayoutProperty.apply(this,n.args)));break;case\"setFilter\":e.push((()=>this.setFilter.apply(this,n.args)));break;case\"addSource\":e.push((()=>this.addSource.apply(this,n.args)));break;case\"removeSource\":e.push((()=>this.removeSource.apply(this,n.args)));break;case\"setLayerZoomRange\":e.push((()=>this.setLayerZoomRange.apply(this,n.args)));break;case\"setLight\":e.push((()=>this.setLight.apply(this,n.args)));break;case\"setGeoJSONSourceData\":e.push((()=>this.setGeoJSONSourceData.apply(this,n.args)));break;case\"setGlyphs\":e.push((()=>this.setGlyphs.apply(this,n.args)));break;case\"setSprite\":e.push((()=>this.setSprite.apply(this,n.args)));break;case\"setSky\":e.push((()=>this.setSky.apply(this,n.args)));break;case\"setTerrain\":e.push((()=>this.map.setTerrain.apply(this,n.args)));break;case\"setTransition\":e.push((()=>{}));break;default:r.push(n.command)}return{operations:e,unimplemented:r}}addImage(t,r){if(this.getImage(t))return this.fire(new e.j(new Error(`An image named \"${t}\" already exists.`)));this.imageManager.addImage(t,r),this._afterImageUpdated(t)}updateImage(t,e){this.imageManager.updateImage(t,e)}getImage(t){return this.imageManager.getImage(t)}removeImage(t){if(!this.getImage(t))return this.fire(new e.j(new Error(`An image named \"${t}\" does not exist.`)));this.imageManager.removeImage(t),this._afterImageUpdated(t)}_afterImageUpdated(t){this._availableImages=this.imageManager.listImages(),this._changedImages[t]=!0,this._changed=!0,this.dispatcher.broadcast(\"SI\",this._availableImages),this.fire(new e.k(\"data\",{dataType:\"style\"}))}listImages(){return this._checkLoaded(),this.imageManager.listImages()}addSource(t,r,n={}){if(this._checkLoaded(),void 0!==this.sourceCaches[t])throw new Error(`Source \"${t}\" already exists.`);if(!r.type)throw new Error(`The type property must be defined, but only the following properties were given: ${Object.keys(r).join(\", \")}.`);if([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(e.x.source,`sources.${t}`,r,null,n))return;this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);const i=this.sourceCaches[t]=new dt(t,r,this.dispatcher);i.style=this,i.setEventedParent(this,(()=>({isSourceLoaded:i.loaded(),source:i.serialize(),sourceId:t}))),i.onAdd(this.map),this._changed=!0}removeSource(t){if(this._checkLoaded(),void 0===this.sourceCaches[t])throw new Error(\"There is no source with this ID\");for(const r in this._layers)if(this._layers[r].source===t)return this.fire(new e.j(new Error(`Source \"${t}\" cannot be removed while layer \"${r}\" is using it.`)));const r=this.sourceCaches[t];delete this.sourceCaches[t],delete this._updatedSources[t],r.fire(new e.k(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:t})),r.setEventedParent(null),r.onRemove(this.map),this._changed=!0}setGeoJSONSourceData(t,e){if(this._checkLoaded(),void 0===this.sourceCaches[t])throw new Error(`There is no source with this ID=${t}`);const r=this.sourceCaches[t].getSource();if(\"geojson\"!==r.type)throw new Error(`geojsonSource.type is ${r.type}, which is !== 'geojson`);r.setData(e),this._changed=!0}getSource(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()}addLayer(t,r,n={}){this._checkLoaded();const i=t.id;if(this.getLayer(i))return void this.fire(new e.j(new Error(`Layer \"${i}\" already exists on this map.`)));let a;if(\"custom\"===t.type){if(fe(this,e.aE(t)))return;a=e.aB(t)}else{if(\"source\"in t&&\"object\"==typeof t.source&&(this.addSource(i,t.source),t=e.aC(t),t=e.e(t,{source:i})),this._validate(e.x.layer,`layers.${i}`,t,{arrayIndex:-1},n))return;a=e.aB(t),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}const o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new e.j(new Error(`Cannot add layer \"${i}\" before non-existing layer \"${r}\".`)));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){const t=this._removedLayers[i];delete this._removedLayers[i],t.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}moveLayer(t,r){if(this._checkLoaded(),this._changed=!0,!this._layers[t])return void this.fire(new e.j(new Error(`The layer '${t}' does not exist in the map's style and cannot be moved.`)));if(t===r)return;const n=this._order.indexOf(t);this._order.splice(n,1);const i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new e.j(new Error(`Cannot move layer \"${t}\" before non-existing layer \"${r}\".`))):(this._order.splice(i,0,t),this._layerOrderChanged=!0)}removeLayer(t){this._checkLoaded();const r=this._layers[t];if(!r)return void this.fire(new e.j(new Error(`Cannot remove non-existing layer \"${t}\".`)));r.setEventedParent(null);const n=this._order.indexOf(t);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[t]=r,delete this._layers[t],this._serializedLayers&&delete this._serializedLayers[t],delete this._updatedLayers[t],delete this._updatedPaintProps[t],r.onRemove&&r.onRemove(this.map)}getLayer(t){return this._layers[t]}getLayersOrder(){return[...this._order]}hasLayer(t){return t in this._layers}setLayerZoomRange(t,r,n){this._checkLoaded();const i=this.getLayer(t);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new e.j(new Error(`Cannot set the zoom range of non-existing layer \"${t}\".`)))}setFilter(t,r,n={}){this._checkLoaded();const i=this.getLayer(t);if(i){if(!e.aF(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(e.x.filter,`layers.${i.id}.filter`,r,null,n)||(i.filter=e.aC(r),this._updateLayer(i)))}else this.fire(new e.j(new Error(`Cannot filter non-existing layer \"${t}\".`)))}getFilter(t){return e.aC(this.getLayer(t).filter)}setLayoutProperty(t,r,n,i={}){this._checkLoaded();const a=this.getLayer(t);a?e.aF(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new e.j(new Error(`Cannot style non-existing layer \"${t}\".`)))}getLayoutProperty(t,r){const n=this.getLayer(t);if(n)return n.getLayoutProperty(r);this.fire(new e.j(new Error(`Cannot get style of non-existing layer \"${t}\".`)))}setPaintProperty(t,r,n,i={}){this._checkLoaded();const a=this.getLayer(t);a?e.aF(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[t]=!0,this._serializedLayers=null):this.fire(new e.j(new Error(`Cannot style non-existing layer \"${t}\".`)))}getPaintProperty(t,e){return this.getLayer(t).getPaintProperty(e)}setFeatureState(t,r){this._checkLoaded();const n=t.source,i=t.sourceLayer,a=this.sourceCaches[n];if(void 0===a)return void this.fire(new e.j(new Error(`The source '${n}' does not exist in the map's style.`)));const o=a.getSource().type;\"geojson\"===o&&i?this.fire(new e.j(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||i?(void 0===t.id&&this.fire(new e.j(new Error(\"The feature id parameter must be provided.\"))),a.setFeatureState(i,t.id,r)):this.fire(new e.j(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}removeFeatureState(t,r){this._checkLoaded();const n=t.source,i=this.sourceCaches[n];if(void 0===i)return void this.fire(new e.j(new Error(`The source '${n}' does not exist in the map's style.`)));const a=i.getSource().type,o=\"vector\"===a?t.sourceLayer:void 0;\"vector\"!==a||o?r&&\"string\"!=typeof t.id&&\"number\"!=typeof t.id?this.fire(new e.j(new Error(\"A feature id is required to remove its specific state property.\"))):i.removeFeatureState(o,t.id,r):this.fire(new e.j(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}getFeatureState(t){this._checkLoaded();const r=t.source,n=t.sourceLayer,i=this.sourceCaches[r];if(void 0!==i)return\"vector\"!==i.getSource().type||n?(void 0===t.id&&this.fire(new e.j(new Error(\"The feature id parameter must be provided.\"))),i.getFeatureState(n,t.id)):void this.fire(new e.j(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));this.fire(new e.j(new Error(`The source '${r}' does not exist in the map's style.`)))}getTransition(){return e.e({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)}serialize(){if(!this._loaded)return;const t=e.aG(this.sourceCaches,(t=>t.serialize())),r=this._serializeByIds(this._order),n=this.map.getTerrain()||void 0,i=this.stylesheet;return e.aH({version:i.version,name:i.name,metadata:i.metadata,light:i.light,sky:i.sky,center:i.center,zoom:i.zoom,bearing:i.bearing,pitch:i.pitch,sprite:i.sprite,glyphs:i.glyphs,transition:i.transition,sources:t,layers:r,terrain:n},(t=>void 0!==t))}_updateLayer(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._serializedLayers=null,this._changed=!0}_flattenAndSortRenderedFeatures(t){const e=t=>\"fill-extrusion\"===this._layers[t].type,r={},n=[];for(let i=this._order.length-1;i>=0;i--){const a=this._order[i];if(e(a)){r[a]=i;for(const e of t){const t=e[a];if(t)for(const e of t)n.push(e)}}}n.sort(((t,e)=>e.intersectionZ-t.intersectionZ));const i=[];for(let a=this._order.length-1;a>=0;a--){const o=this._order[a];if(e(o))for(let t=n.length-1;t>=0;t--){const e=n[t].feature;if(r[e.layer.id]<a)break;i.push(e),n.pop()}else for(const e of t){const t=e[o];if(t)for(const e of t)i.push(e.feature)}}return i}queryRenderedFeatures(t,r,n){r&&r.filter&&this._validate(e.x.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);const i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new e.j(new Error(\"parameters.layers must be an Array.\"))),[];for(const t of r.layers){const r=this._layers[t];if(!r)return this.fire(new e.j(new Error(`The layer '${t}' does not exist in the map's style and cannot be queried for features.`))),[];i[r.source]=!0}}const a=[];r.availableImages=this._availableImages;const o=this._serializedAllLayers();for(const e in this.sourceCaches)r.layers&&!i[e]||a.push(Z(this.sourceCaches[e],this._layers,o,t,r,n));return this.placement&&a.push(function(t,e,r,n,i,a,o){const s={},l=a.queryRenderedSymbols(n),c=[];for(const t of Object.keys(l).map(Number))c.push(o[t]);c.sort(W);for(const r of c){const n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,i.filter,i.layers,i.availableImages,t);for(const t in n){const e=s[t]=s[t]||[],i=n[t];i.sort(((t,e)=>{const n=r.featureSortOrder;if(n){const r=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-r}return e.featureIndex-t.featureIndex}));for(const t of i)e.push(t)}}for(const e in s)s[e].forEach((n=>{const i=n.feature,a=t[e],o=r[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o}));return s}(this._layers,o,this.sourceCaches,t,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(a)}querySourceFeatures(t,r){r&&r.filter&&this._validate(e.x.filter,\"querySourceFeatures.filter\",r.filter,null,r);const n=this.sourceCaches[t];return n?function(t,e){const r=t.getRenderableIds().map((e=>t.getTileByID(e))),n=[],i={};for(let t=0;t<r.length;t++){const a=r[t],o=a.tileID.canonical.key;i[o]||(i[o]=!0,a.querySourceFeatures(n,e))}return n}(n,r):[]}getLight(){return this.light.getLight()}setLight(t,r={}){this._checkLoaded();const n=this.light.getLight();let i=!1;for(const r in t)if(!e.aF(t[r],n[r])){i=!0;break}if(!i)return;const o={now:a.now(),transition:e.e({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(t,r),this.light.updateTransitions(o)}getSky(){var t;return null===(t=this.stylesheet)||void 0===t?void 0:t.sky}setSky(t,r={}){const n=this.sky.getSky();let i=!1;t||n&&(i=!0);for(const r in t)if(!e.aF(t[r],n[r])){i=!0;break}if(!i)return;const o={now:a.now(),transition:e.e({duration:300,delay:0},this.stylesheet.transition)};this.stylesheet.sky=t,this.sky.setSky(t,r),this.sky.updateTransitions(o)}_validate(t,r,n,i,a={}){return(!a||!1!==a.validate)&&fe(this,t.call(e.x,e.e({key:r,style:this.serialize(),value:n,styleSpec:e.v},i)))}_remove(t=!0){this._frameRequest&&(this._frameRequest.abort(),this._frameRequest=null),this._loadStyleRequest&&(this._loadStyleRequest.abort(),this._loadStyleRequest=null),this._spriteRequest&&(this._spriteRequest.abort(),this._spriteRequest=null),ut().off(st,this._rtlPluginLoaded);for(const t in this._layers)this._layers[t].setEventedParent(null);for(const t in this.sourceCaches){const e=this.sourceCaches[t];e.setEventedParent(null),e.onRemove(this.map)}this.imageManager.setEventedParent(null),this.setEventedParent(null),t&&this.dispatcher.broadcast(\"RM\",void 0),this.dispatcher.remove(t)}_clearSource(t){this.sourceCaches[t].clearTiles()}_reloadSource(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()}_updateSources(t){for(const e in this.sourceCaches)this.sourceCaches[e].update(t,this.map.terrain)}_generateCollisionBoxes(){for(const t in this.sourceCaches)this._reloadSource(t)}_updatePlacement(t,e,r,n,i=!1){let o=!1,s=!1;const l={};for(const e of this._order){const r=this._layers[e];if(\"symbol\"!==r.type)continue;if(!l[r.source]){const t=this.sourceCaches[r.source];l[r.source]=t.getRenderableIds(!0).map((e=>t.getTileByID(e))).sort(((t,e)=>e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)))}const n=this.crossTileSymbolIndex.addLayer(r,l[r.source],t.center.lng);o=o||n}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((i=i||this._layerOrderChanged||0===r)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(a.now(),t.zoom))&&(this.pauseablePlacement=new oe(t,this.map.terrain,this._order,i,e,r,n,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(a.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(const t of this._order){const e=this._layers[t];\"symbol\"===e.type&&this.placement.updateLayerOpacities(e,l[e.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(a.now())}_releaseSymbolFadeTiles(){for(const t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()}getImages(t,r){return e._(this,void 0,void 0,(function*(){const t=yield this.imageManager.getImages(r.icons);this._updateTilesForChangedImages();const e=this.sourceCaches[r.source];return e&&e.setDependencies(r.tileID.key,r.type,r.icons),t}))}getGlyphs(t,r){return e._(this,void 0,void 0,(function*(){const t=yield this.glyphManager.getGlyphs(r.stacks),e=this.sourceCaches[r.source];return e&&e.setDependencies(r.tileID.key,r.type,[\"\"]),t}))}getGlyphsUrl(){return this.stylesheet.glyphs||null}setGlyphs(t,r={}){this._checkLoaded(),t&&this._validate(e.x.glyphs,\"glyphs\",t,null,r)||(this._glyphsDidChange=!0,this.stylesheet.glyphs=t,this.glyphManager.entries={},this.glyphManager.setURL(t))}addSprite(t,r,n={},i){this._checkLoaded();const a=[{id:t,url:r}],o=[...x(this.stylesheet.sprite),...a];this._validate(e.x.sprite,\"sprite\",o,null,n)||(this.stylesheet.sprite=o,this._loadSprite(a,!0,i))}removeSprite(t){this._checkLoaded();const r=x(this.stylesheet.sprite);if(r.find((e=>e.id===t))){if(this._spritesImagesIds[t])for(const e of this._spritesImagesIds[t])this.imageManager.removeImage(e),this._changedImages[e]=!0;r.splice(r.findIndex((e=>e.id===t)),1),this.stylesheet.sprite=r.length>0?r:void 0,delete this._spritesImagesIds[t],this._availableImages=this.imageManager.listImages(),this._changed=!0,this.dispatcher.broadcast(\"SI\",this._availableImages),this.fire(new e.k(\"data\",{dataType:\"style\"}))}else this.fire(new e.j(new Error(`Sprite \"${t}\" doesn't exists on this map.`)))}getSprite(){return x(this.stylesheet.sprite)}setSprite(t,r={},n){this._checkLoaded(),t&&this._validate(e.x.sprite,\"sprite\",t,null,r)||(this.stylesheet.sprite=t,t?this._loadSprite(t,!0,n):(this._unloadSprite(),n&&n(null)))}}var me=e.Y([{name:\"a_pos\",type:\"Int16\",components:2}]);const ge={prelude:ye(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\n\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\\n#ifdef TERRAIN3D\\nuniform sampler2D u_terrain;uniform float u_terrain_dim;uniform mat4 u_terrain_matrix;uniform vec4 u_terrain_unpack;uniform float u_terrain_exaggeration;uniform highp sampler2D u_depth;\\n#endif\\nconst highp vec4 bitSh=vec4(256.*256.*256.,256.*256.,256.,1.);const highp vec4 bitShifts=vec4(1.)/bitSh;highp float unpack(highp vec4 color) {return dot(color,bitShifts);}highp float depthOpacity(vec3 frag) {\\n#ifdef TERRAIN3D\\nhighp float d=unpack(texture2D(u_depth,frag.xy*0.5+0.5))+0.0001-frag.z;return 1.0-max(0.0,min(1.0,-d*500.0));\\n#else\\nreturn 1.0;\\n#endif\\n}float calculate_visibility(vec4 pos) {\\n#ifdef TERRAIN3D\\nvec3 frag=pos.xyz/pos.w;highp float d=depthOpacity(frag);if (d > 0.95) return 1.0;return (d+depthOpacity(frag+vec3(0.0,0.01,0.0)))/2.0;\\n#else\\nreturn 1.0;\\n#endif\\n}float ele(vec2 pos) {\\n#ifdef TERRAIN3D\\nvec4 rgb=(texture2D(u_terrain,pos)*255.0)*u_terrain_unpack;return rgb.r+rgb.g+rgb.b-u_terrain_unpack.a;\\n#else\\nreturn 0.0;\\n#endif\\n}float get_elevation(vec2 pos) {\\n#ifdef TERRAIN3D\\nvec2 coord=(u_terrain_matrix*vec4(pos,0.0,1.0)).xy*u_terrain_dim+1.0;vec2 f=fract(coord);vec2 c=(floor(coord)+0.5)/(u_terrain_dim+2.0);float d=1.0/(u_terrain_dim+2.0);float tl=ele(c);float tr=ele(c+vec2(d,0.0));float bl=ele(c+vec2(0.0,d));float br=ele(c+vec2(d,d));float elevation=mix(mix(tl,tr,f.x),mix(bl,br,f.x),f.y);return elevation*u_terrain_exaggeration;\\n#else\\nreturn 0.0;\\n#endif\\n}\"),background:ye(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),backgroundPattern:ye(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),circle:ye(\"varying vec3 v_data;varying float v_visibility;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=v_visibility*opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;varying float v_visibility;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);float ele=get_elevation(circle_center);v_visibility=calculate_visibility(u_matrix*vec4(circle_center,ele,1.0));if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,ele,1);} else {gl_Position=u_matrix*vec4(circle_center,ele,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),clippingMask:ye(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),heatmap:ye(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),heatmapTexture:ye(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),collisionBox:ye(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_anchor_pos;attribute vec2 a_placed;attribute vec2 a_box_real;uniform mat4 u_matrix;uniform vec2 u_pixel_extrude_scale;varying float v_placed;varying float v_notUsed;vec4 projectTileWithElevation(vec2 posInTile,float elevation) {return u_matrix*vec4(posInTile,elevation,1.0);}void main() {gl_Position=projectTileWithElevation(a_anchor_pos,get_elevation(a_anchor_pos));gl_Position.xy=((a_box_real+0.5)*u_pixel_extrude_scale*2.0-1.0)*vec2(1.0,-1.0)*gl_Position.w;if (gl_Position.z/gl_Position.w < 1.1) {gl_Position.z=0.5;}v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),collisionCircle:ye(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),debug:ye(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,get_elevation(a_pos),1);}\"),fill:ye(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),fillOutline:ye(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),fillOutlinePattern:ye(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),fillPattern:ye(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),fillExtrusion:ye(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;\\n#ifdef TERRAIN3D\\nattribute vec2 a_centroid;\\n#endif\\nvarying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;\\n#ifdef TERRAIN3D\\nfloat height_terrain3d_offset=get_elevation(a_centroid);float base_terrain3d_offset=height_terrain3d_offset-(base > 0.0 ? 0.0 : 10.0);\\n#else\\nfloat height_terrain3d_offset=0.0;float base_terrain3d_offset=0.0;\\n#endif\\nbase=max(0.0,base)+base_terrain3d_offset;height=max(0.0,height)+height_terrain3d_offset;float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),fillExtrusionPattern:ye(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;\\n#ifdef TERRAIN3D\\nattribute vec2 a_centroid;\\n#endif\\nvarying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;\\n#ifdef TERRAIN3D\\nfloat height_terrain3d_offset=get_elevation(a_centroid);float base_terrain3d_offset=height_terrain3d_offset-(base > 0.0 ? 0.0 : 10.0);\\n#else\\nfloat height_terrain3d_offset=0.0;float base_terrain3d_offset=0.0;\\n#endif\\nbase=max(0.0,base)+base_terrain3d_offset;height=max(0.0,height)+height_terrain3d_offset;float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),hillshadePrepare:ye(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggerationFactor=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;float exaggeration=u_zoom < 15.0 ? (u_zoom-15.0)*exaggerationFactor : 0.0;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/pow(2.0,exaggeration+(19.2562-u_zoom));gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),hillshade:ye(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),line:ye(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;\\n#ifdef TERRAIN3D\\nv_gamma_scale=1.0;\\n#else\\nfloat extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;\\n#endif\\nv_width2=vec2(outset,inset);}\"),lineGradient:ye(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp vec2 v_uv;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,v_uv);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;attribute float a_uv_x;attribute float a_split_index;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;uniform float u_image_height;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp vec2 v_uv;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;highp float texel_height=1.0/u_image_height;highp float half_texel_height=0.5*texel_height;v_uv=vec2(a_uv_x,a_split_index*texel_height-half_texel_height);vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;\\n#ifdef TERRAIN3D\\nv_gamma_scale=1.0;\\n#else\\nfloat extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;\\n#endif\\nv_width2=vec2(outset,inset);}\"),linePattern:ye(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;\\n#ifdef TERRAIN3D\\nv_gamma_scale=1.0;\\n#else\\nfloat extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;\\n#endif\\nv_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),lineSDF:ye(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;\\n#ifdef TERRAIN3D\\nv_gamma_scale=1.0;\\n#else\\nfloat extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;\\n#endif\\nv_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),raster:ye(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),symbolIcon:ye(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;uniform bool u_is_along_line;uniform bool u_is_variable_anchor;uniform vec2 u_translation;uniform float u_pitched_scale;varying vec2 v_tex;varying float v_fade_opacity;vec4 projectTileWithElevation(vec2 posInTile,float elevation) {return u_matrix*vec4(posInTile,elevation,1.0);}\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;float ele=get_elevation(a_pos);highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec2 translated_a_pos=a_pos+u_translation;vec4 projectedPoint=projectTileWithElevation(translated_a_pos,ele);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=projectTileWithElevation(translated_a_pos+vec2(1,0),ele);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos;if (u_is_along_line || u_is_variable_anchor) {projected_pos=vec4(a_projected_pos.xy,ele,1.0);} else if (u_pitch_with_map) {projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy+u_translation,ele,1.0);} else {projected_pos=u_label_plane_matrix*projectTileWithElevation(a_projected_pos.xy+u_translation,ele);}float z=float(u_pitch_with_map)*projected_pos.z/projected_pos.w;float projectionScaling=1.0;vec4 finalPos=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0)*projectionScaling,z,1.0);if(u_pitch_with_map) {finalPos=projectTileWithElevation(finalPos.xy,finalPos.z);}gl_Position=finalPos;v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float visibility=calculate_visibility(projectedPoint);v_fade_opacity=max(0.0,min(visibility,fade_opacity[0]+fade_change));}\"),symbolSDF:ye(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float inner_edge=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);inner_edge=inner_edge+gamma*gamma_scale;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(inner_edge-gamma_scaled,inner_edge+gamma_scaled,dist);if (u_is_halo) {lowp float halo_edge=(6.0-halo_width/fontScale)/SDF_PX;alpha=min(smoothstep(halo_edge-gamma_scaled,halo_edge+gamma_scaled,dist),1.0-alpha);}gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform bool u_is_along_line;uniform bool u_is_variable_anchor;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_translation;uniform float u_pitched_scale;varying vec2 v_data0;varying vec3 v_data1;vec4 projectTileWithElevation(vec2 posInTile,float elevation) {return u_matrix*vec4(posInTile,elevation,1.0);}\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;float ele=get_elevation(a_pos);highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec2 translated_a_pos=a_pos+u_translation;vec4 projectedPoint=projectTileWithElevation(translated_a_pos,ele);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=projectTileWithElevation(translated_a_pos+vec2(1,0),ele);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos;if (u_is_along_line || u_is_variable_anchor) {projected_pos=vec4(a_projected_pos.xy,ele,1.0);} else if (u_pitch_with_map) {projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy+u_translation,ele,1.0);} else {projected_pos=u_label_plane_matrix*projectTileWithElevation(a_projected_pos.xy+u_translation,ele);}float z=float(u_pitch_with_map)*projected_pos.z/projected_pos.w;float projectionScaling=1.0;vec4 finalPos=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset)*projectionScaling,z,1.0);if(u_pitch_with_map) {finalPos=projectTileWithElevation(finalPos.xy,finalPos.z);}float gamma_scale=finalPos.w;gl_Position=finalPos;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float visibility=calculate_visibility(projectedPoint);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(visibility,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),symbolTextAndIcon:ye(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;uniform bool u_is_along_line;uniform bool u_is_variable_anchor;uniform vec2 u_translation;uniform float u_pitched_scale;varying vec4 v_data0;varying vec4 v_data1;vec4 projectTileWithElevation(vec2 posInTile,float elevation) {return u_matrix*vec4(posInTile,elevation,1.0);}\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;float ele=get_elevation(a_pos);highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec2 translated_a_pos=a_pos+u_translation;vec4 projectedPoint=projectTileWithElevation(translated_a_pos,ele);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=projectTileWithElevation(translated_a_pos+vec2(1,0),ele);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos;if (u_is_along_line || u_is_variable_anchor) {projected_pos=vec4(a_projected_pos.xy,ele,1.0);} else if (u_pitch_with_map) {projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy+u_translation,ele,1.0);} else {projected_pos=u_label_plane_matrix*projectTileWithElevation(a_projected_pos.xy+u_translation,ele);}float z=float(u_pitch_with_map)*projected_pos.z/projected_pos.w;float projectionScaling=1.0;vec4 finalPos=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale)*projectionScaling,z,1.0);if(u_pitch_with_map) {finalPos=projectTileWithElevation(finalPos.xy,finalPos.z);}float gamma_scale=finalPos.w;gl_Position=finalPos;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float visibility=calculate_visibility(projectedPoint);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(visibility,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\"),terrain:ye(\"uniform sampler2D u_texture;uniform vec4 u_fog_color;uniform vec4 u_horizon_color;uniform float u_fog_ground_blend;uniform float u_fog_ground_blend_opacity;uniform float u_horizon_fog_blend;varying vec2 v_texture_pos;varying float v_fog_depth;const float gamma=2.2;vec4 gammaToLinear(vec4 color) {return pow(color,vec4(gamma));}vec4 linearToGamma(vec4 color) {return pow(color,vec4(1.0/gamma));}void main() {vec4 surface_color=texture2D(u_texture,v_texture_pos);if (v_fog_depth > u_fog_ground_blend) {vec4 surface_color_linear=gammaToLinear(surface_color);float blend_color=smoothstep(0.0,1.0,max((v_fog_depth-u_horizon_fog_blend)/(1.0-u_horizon_fog_blend),0.0));vec4 fog_horizon_color_linear=mix(gammaToLinear(u_fog_color),gammaToLinear(u_horizon_color),blend_color);float factor_fog=max(v_fog_depth-u_fog_ground_blend,0.0)/(1.0-u_fog_ground_blend);gl_FragColor=linearToGamma(mix(surface_color_linear,fog_horizon_color_linear,pow(factor_fog,2.0)*u_fog_ground_blend_opacity));} else {gl_FragColor=surface_color;}}\",\"attribute vec3 a_pos3d;uniform mat4 u_matrix;uniform mat4 u_fog_matrix;uniform float u_ele_delta;varying vec2 v_texture_pos;varying float v_fog_depth;void main() {float ele=get_elevation(a_pos3d.xy);float ele_delta=a_pos3d.z==1.0 ? u_ele_delta : 0.0;v_texture_pos=a_pos3d.xy/8192.0;gl_Position=u_matrix*vec4(a_pos3d.xy,ele-ele_delta,1.0);vec4 pos=u_fog_matrix*vec4(a_pos3d.xy,ele,1.0);v_fog_depth=pos.z/pos.w*0.5+0.5;}\"),terrainDepth:ye(\"varying float v_depth;const highp vec4 bitSh=vec4(256.*256.*256.,256.*256.,256.,1.);const highp vec4 bitMsk=vec4(0.,vec3(1./256.0));highp vec4 pack(highp float value) {highp vec4 comp=fract(value*bitSh);comp-=comp.xxyz*bitMsk;return comp;}void main() {gl_FragColor=pack(v_depth);}\",\"attribute vec3 a_pos3d;uniform mat4 u_matrix;uniform float u_ele_delta;varying float v_depth;void main() {float ele=get_elevation(a_pos3d.xy);float ele_delta=a_pos3d.z==1.0 ? u_ele_delta : 0.0;gl_Position=u_matrix*vec4(a_pos3d.xy,ele-ele_delta,1.0);v_depth=gl_Position.z/gl_Position.w;}\"),terrainCoords:ye(\"precision mediump float;uniform sampler2D u_texture;uniform float u_terrain_coords_id;varying vec2 v_texture_pos;void main() {vec4 rgba=texture2D(u_texture,v_texture_pos);gl_FragColor=vec4(rgba.r,rgba.g,rgba.b,u_terrain_coords_id);}\",\"attribute vec3 a_pos3d;uniform mat4 u_matrix;uniform float u_ele_delta;varying vec2 v_texture_pos;void main() {float ele=get_elevation(a_pos3d.xy);float ele_delta=a_pos3d.z==1.0 ? u_ele_delta : 0.0;v_texture_pos=a_pos3d.xy/8192.0;gl_Position=u_matrix*vec4(a_pos3d.xy,ele-ele_delta,1.0);}\"),sky:ye(\"uniform vec4 u_sky_color;uniform vec4 u_horizon_color;uniform float u_horizon;uniform float u_sky_horizon_blend;void main() {float y=gl_FragCoord.y;if (y > u_horizon) {float blend=y-u_horizon;if (blend < u_sky_horizon_blend) {gl_FragColor=mix(u_sky_color,u_horizon_color,pow(1.0-blend/u_sky_horizon_blend,2.0));} else {gl_FragColor=u_sky_color;}}}\",\"attribute vec2 a_pos;void main() {gl_Position=vec4(a_pos,1.0,1.0);}\")};function ye(t,e){const r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n=e.match(/attribute ([\\w]+) ([\\w]+)/g),i=t.match(/uniform ([\\w]+) ([\\w]+)([\\s]*)([\\w]*)/g),a=e.match(/uniform ([\\w]+) ([\\w]+)([\\s]*)([\\w]*)/g),o=a?a.concat(i):i,s={};return{fragmentSource:t=t.replace(r,((t,e,r,n,i)=>(s[i]=!0,\"define\"===e?`\\n#ifndef HAS_UNIFORM_u_${i}\\nvarying ${r} ${n} ${i};\\n#else\\nuniform ${r} ${n} u_${i};\\n#endif\\n`:`\\n#ifdef HAS_UNIFORM_u_${i}\\n    ${r} ${n} ${i} = u_${i};\\n#endif\\n`))),vertexSource:e=e.replace(r,((t,e,r,n,i)=>{const a=\"float\"===n?\"vec2\":\"vec4\",o=i.match(/color/)?\"color\":a;return s[i]?\"define\"===e?`\\n#ifndef HAS_UNIFORM_u_${i}\\nuniform lowp float u_${i}_t;\\nattribute ${r} ${a} a_${i};\\nvarying ${r} ${n} ${i};\\n#else\\nuniform ${r} ${n} u_${i};\\n#endif\\n`:\"vec4\"===o?`\\n#ifndef HAS_UNIFORM_u_${i}\\n    ${i} = a_${i};\\n#else\\n    ${r} ${n} ${i} = u_${i};\\n#endif\\n`:`\\n#ifndef HAS_UNIFORM_u_${i}\\n    ${i} = unpack_mix_${o}(a_${i}, u_${i}_t);\\n#else\\n    ${r} ${n} ${i} = u_${i};\\n#endif\\n`:\"define\"===e?`\\n#ifndef HAS_UNIFORM_u_${i}\\nuniform lowp float u_${i}_t;\\nattribute ${r} ${a} a_${i};\\n#else\\nuniform ${r} ${n} u_${i};\\n#endif\\n`:\"vec4\"===o?`\\n#ifndef HAS_UNIFORM_u_${i}\\n    ${r} ${n} ${i} = a_${i};\\n#else\\n    ${r} ${n} ${i} = u_${i};\\n#endif\\n`:`\\n#ifndef HAS_UNIFORM_u_${i}\\n    ${r} ${n} ${i} = unpack_mix_${o}(a_${i}, u_${i}_t);\\n#else\\n    ${r} ${n} ${i} = u_${i};\\n#endif\\n`})),staticAttributes:n,staticUniforms:o}}class ve{constructor(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null}bind(t,e,r,n,i,a,o,s,l){this.context=t;let c=this.boundPaintVertexBuffers.length!==n.length;for(let t=0;!c&&t<n.length;t++)this.boundPaintVertexBuffers[t]!==n[t]&&(c=!0);!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||c||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s||this.boundDynamicVertexBuffer3!==l?this.freshBind(e,r,n,i,a,o,s,l):(t.bindVertexArray.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind(),l&&l.bind())}freshBind(t,e,r,n,i,a,o,s){const l=t.numAttributes,c=this.context,u=c.gl;this.vao&&this.destroy(),this.vao=c.createVertexArray(),c.bindVertexArray.set(this.vao),this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o,this.boundDynamicVertexBuffer3=s,e.enableAttributes(u,t);for(const e of r)e.enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),s&&s.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(const e of r)e.bind(),e.setVertexAttribPointers(u,t,i);a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),s&&(s.bind(),s.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l}destroy(){this.vao&&(this.context.deleteVertexArray(this.vao),this.vao=null)}}const xe=(t,r,n,i,a)=>({u_matrix:t,u_texture:0,u_ele_delta:r,u_fog_matrix:n,u_fog_color:i?i.properties.get(\"fog-color\"):e.aN.white,u_fog_ground_blend:i?i.properties.get(\"fog-ground-blend\"):1,u_fog_ground_blend_opacity:i?i.calculateFogBlendOpacity(a):0,u_horizon_color:i?i.properties.get(\"horizon-color\"):e.aN.white,u_horizon_fog_blend:i?i.properties.get(\"horizon-fog-blend\"):1});function _e(t){const e=[];for(let r=0;r<t.length;r++){if(null===t[r])continue;const n=t[r].split(\" \");e.push(n.pop())}return e}class be{constructor(t,r,n,i,a,o){const s=t.gl;this.program=s.createProgram();const l=_e(r.staticAttributes),c=n?n.getBinderAttributes():[],u=l.concat(c),h=ge.prelude.staticUniforms?_e(ge.prelude.staticUniforms):[],f=r.staticUniforms?_e(r.staticUniforms):[],p=n?n.getBinderUniforms():[],d=h.concat(f).concat(p),m=[];for(const t of d)m.indexOf(t)<0&&m.push(t);const g=n?n.defines():[];a&&g.push(\"#define OVERDRAW_INSPECTOR;\"),o&&g.push(\"#define TERRAIN3D;\");const y=g.concat(ge.prelude.fragmentSource,r.fragmentSource).join(\"\\n\"),v=g.concat(ge.prelude.vertexSource,r.vertexSource).join(\"\\n\"),x=s.createShader(s.FRAGMENT_SHADER);if(s.isContextLost())return void(this.failedToCreate=!0);if(s.shaderSource(x,y),s.compileShader(x),!s.getShaderParameter(x,s.COMPILE_STATUS))throw new Error(`Could not compile fragment shader: ${s.getShaderInfoLog(x)}`);s.attachShader(this.program,x);const _=s.createShader(s.VERTEX_SHADER);if(s.isContextLost())return void(this.failedToCreate=!0);if(s.shaderSource(_,v),s.compileShader(_),!s.getShaderParameter(_,s.COMPILE_STATUS))throw new Error(`Could not compile vertex shader: ${s.getShaderInfoLog(_)}`);s.attachShader(this.program,_),this.attributes={};const b={};this.numAttributes=u.length;for(let t=0;t<this.numAttributes;t++)u[t]&&(s.bindAttribLocation(this.program,t,u[t]),this.attributes[u[t]]=t);if(s.linkProgram(this.program),!s.getProgramParameter(this.program,s.LINK_STATUS))throw new Error(`Program failed to link: ${s.getProgramInfoLog(this.program)}`);s.deleteShader(_),s.deleteShader(x);for(let t=0;t<m.length;t++){const e=m[t];if(e&&!b[e]){const t=s.getUniformLocation(this.program,e);t&&(b[e]=t)}}this.fixedUniforms=i(t,b),this.terrainUniforms=((t,r)=>({u_depth:new e.aI(t,r.u_depth),u_terrain:new e.aI(t,r.u_terrain),u_terrain_dim:new e.aJ(t,r.u_terrain_dim),u_terrain_matrix:new e.aK(t,r.u_terrain_matrix),u_terrain_unpack:new e.aL(t,r.u_terrain_unpack),u_terrain_exaggeration:new e.aJ(t,r.u_terrain_exaggeration)}))(t,b),this.binderUniforms=n?n.getUniforms(t,b):[]}draw(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,m,g,y){const v=t.gl;if(this.failedToCreate)return;if(t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),s){t.activeTexture.set(v.TEXTURE2),v.bindTexture(v.TEXTURE_2D,s.depthTexture),t.activeTexture.set(v.TEXTURE3),v.bindTexture(v.TEXTURE_2D,s.texture);for(const t in this.terrainUniforms)this.terrainUniforms[t].set(s[t])}for(const t in this.fixedUniforms)this.fixedUniforms[t].set(o[t]);d&&d.setUniforms(t,this.binderUniforms,f,{zoom:p});let x=0;switch(e){case v.LINES:x=2;break;case v.TRIANGLES:x=3;break;case v.LINE_STRIP:x=1}for(const r of h.get()){const n=r.vaos||(r.vaos={});(n[l]||(n[l]=new ve)).bind(t,this,c,d?d.getPaintVertexBuffers():[],u,r.vertexOffset,m,g,y),v.drawElements(e,r.primitiveLength*x,v.UNSIGNED_SHORT,r.primitiveOffset*x*2)}}}function we(t,e,r){const n=1/Nt(r,1,e.transform.tileZoom),i=Math.pow(2,r.tileID.overscaledZ),a=r.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(r.tileID.canonical.x+r.tileID.wrap*i),s=a*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}const Te=(t,r,n,i)=>{const a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=function(){var t=new e.A(9);return e.A!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}();\"viewport\"===a.properties.get(\"anchor\")&&function(t,e){var r=Math.sin(e),n=Math.cos(e);t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1}(l,-r.transform.angle),function(t,e,r){var n=e[0],i=e[1],a=e[2];t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8]}(s,s,l);const c=a.properties.get(\"color\");return{u_matrix:t,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},ke=(t,r,n,i,a,o,s)=>e.e(Te(t,r,n,i),we(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8}),Ae=t=>({u_matrix:t}),Me=(t,r,n,i)=>e.e(Ae(t),we(n,r,i)),Se=(t,e)=>({u_matrix:t,u_world:e}),Ee=(t,r,n,i,a)=>e.e(Me(t,r,n,i),{u_world:a}),Ce=(t,e,r,n)=>{const i=t.transform;let a,o;if(\"map\"===n.paint.get(\"circle-pitch-alignment\")){const t=Nt(r,1,i.zoom);a=!0,o=[t,t]}else a=!1,o=i.pixelsToGLUnits;return{u_camera_to_center_distance:i.cameraToCenterDistance,u_scale_with_map:+(\"map\"===n.paint.get(\"circle-pitch-scale\")),u_matrix:t.translatePosMatrix(e.posMatrix,r,n.paint.get(\"circle-translate\"),n.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.pixelRatio,u_extrude_scale:o}},Le=(t,e)=>({u_matrix:e,u_pixel_extrude_scale:[1/t.width,1/t.height]}),Ie=(t,e,r)=>({u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}),Pe=(t,e,r=1)=>({u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}),ze=t=>({u_matrix:t}),Oe=(t,e,r,n)=>({u_matrix:t,u_extrude_scale:Nt(e,1,r),u_intensity:n}),De=(t,r,n,i)=>{const a=e.H();e.aQ(a,0,t.width,t.height,0,0,1);const o=t.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}},Re=(t,e,r,n)=>{const i=r.paint.get(\"hillshade-shadow-color\"),a=r.paint.get(\"hillshade-highlight-color\"),o=r.paint.get(\"hillshade-accent-color\");let s=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(s-=t.transform.angle);const l=!t.options.moving;return{u_matrix:n?n.posMatrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),l),u_image:0,u_latrange:Be(0,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),s],u_shadow:i,u_highlight:a,u_accent:o}},Fe=(t,r)=>{const n=r.stride,i=e.H();return e.aQ(i,0,e.X,-e.X,0,0,1),e.J(i,i,[0,-e.X,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:t.overscaledZ,u_unpack:r.getUnpackVector()}};function Be(t,r){const n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new e.Z(0,i/n).toLngLat().lat,new e.Z(0,(i+1)/n).toLngLat().lat]}const Ne=(t,e,r,n)=>{const i=t.transform;return{u_matrix:He(t,e,r,n),u_ratio:1/Nt(e,1,i.zoom),u_device_pixel_ratio:t.pixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},je=(t,r,n,i,a)=>e.e(Ne(t,r,n,a),{u_image:0,u_image_height:i}),Ue=(t,e,r,n,i)=>{const a=t.transform,o=qe(e,a);return{u_matrix:He(t,e,r,i),u_texsize:e.imageAtlasTexture.size,u_ratio:1/Nt(e,1,a.zoom),u_device_pixel_ratio:t.pixelRatio,u_image:0,u_scale:[o,n.fromScale,n.toScale],u_fade:n.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Ve=(t,r,n,i,a,o)=>{const s=t.transform,l=t.lineAtlas,c=qe(r,s),u=\"round\"===n.layout.get(\"line-cap\"),h=l.getDash(i.from,u),f=l.getDash(i.to,u),p=h.width*a.fromScale,d=f.width*a.toScale;return e.e(Ne(t,r,n,o),{u_patternscale_a:[c/p,-h.height/2],u_patternscale_b:[c/d,-f.height/2],u_sdfgamma:l.width/(256*Math.min(p,d)*t.pixelRatio)/2,u_image:0,u_tex_y_a:h.y,u_tex_y_b:f.y,u_mix:a.t})};function qe(t,e){return 1/Nt(t,1,e.tileZoom)}function He(t,e,r,n){return t.translatePosMatrix(n?n.posMatrix:e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}const Ge=(t,e,r,n,i)=>{return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:Ze(i.paint.get(\"raster-hue-rotate\"))};var a,o};function Ze(t){t*=Math.PI/180;const e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}const We=(t,e,r,n,i,a,o,s,l,c,u,h,f,p)=>{const d=o.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:d.cameraToCenterDistance,u_pitch:d.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:d.width/d.height,u_fade_change:o.options.fadeDuration?o.symbolFadeChange:1,u_matrix:s,u_label_plane_matrix:l,u_coord_matrix:c,u_is_text:+h,u_pitch_with_map:+n,u_is_along_line:i,u_is_variable_anchor:a,u_texsize:f,u_texture:0,u_translation:u,u_pitched_scale:p}},Ye=(t,r,n,i,a,o,s,l,c,u,h,f,p,d,m)=>{const g=s.transform;return e.e(We(t,r,n,i,a,o,s,l,c,u,h,f,p,m),{u_gamma_scale:i?Math.cos(g._pitch)*g.cameraToCenterDistance:1,u_device_pixel_ratio:s.pixelRatio,u_is_halo:+d})},Xe=(t,r,n,i,a,o,s,l,c,u,h,f,p,d)=>e.e(Ye(t,r,n,i,a,o,s,l,c,u,h,!0,f,!0,d),{u_texsize_icon:p,u_texture_icon:1}),$e=(t,e,r)=>({u_matrix:t,u_opacity:e,u_color:r}),Je=(t,r,n,i,a,o)=>e.e(function(t,e,r,n){const i=r.imageManager.getPattern(t.from.toString()),a=r.imageManager.getPattern(t.to.toString()),{width:o,height:s}=r.imageManager.getPixelSize(),l=Math.pow(2,n.tileID.overscaledZ),c=n.tileSize*Math.pow(2,r.transform.tileZoom)/l,u=c*(n.tileID.canonical.x+n.tileID.wrap*l),h=c*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[o,s],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/Nt(n,1,r.transform.tileZoom),u_pixel_coord_upper:[u>>16,h>>16],u_pixel_coord_lower:[65535&u,65535&h]}}(i,o,n,a),{u_matrix:t,u_opacity:r}),Ke={fillExtrusion:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_lightpos:new e.aO(t,r.u_lightpos),u_lightintensity:new e.aJ(t,r.u_lightintensity),u_lightcolor:new e.aO(t,r.u_lightcolor),u_vertical_gradient:new e.aJ(t,r.u_vertical_gradient),u_opacity:new e.aJ(t,r.u_opacity)}),fillExtrusionPattern:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_lightpos:new e.aO(t,r.u_lightpos),u_lightintensity:new e.aJ(t,r.u_lightintensity),u_lightcolor:new e.aO(t,r.u_lightcolor),u_vertical_gradient:new e.aJ(t,r.u_vertical_gradient),u_height_factor:new e.aJ(t,r.u_height_factor),u_image:new e.aI(t,r.u_image),u_texsize:new e.aP(t,r.u_texsize),u_pixel_coord_upper:new e.aP(t,r.u_pixel_coord_upper),u_pixel_coord_lower:new e.aP(t,r.u_pixel_coord_lower),u_scale:new e.aO(t,r.u_scale),u_fade:new e.aJ(t,r.u_fade),u_opacity:new e.aJ(t,r.u_opacity)}),fill:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix)}),fillPattern:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_image:new e.aI(t,r.u_image),u_texsize:new e.aP(t,r.u_texsize),u_pixel_coord_upper:new e.aP(t,r.u_pixel_coord_upper),u_pixel_coord_lower:new e.aP(t,r.u_pixel_coord_lower),u_scale:new e.aO(t,r.u_scale),u_fade:new e.aJ(t,r.u_fade)}),fillOutline:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_world:new e.aP(t,r.u_world)}),fillOutlinePattern:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_world:new e.aP(t,r.u_world),u_image:new e.aI(t,r.u_image),u_texsize:new e.aP(t,r.u_texsize),u_pixel_coord_upper:new e.aP(t,r.u_pixel_coord_upper),u_pixel_coord_lower:new e.aP(t,r.u_pixel_coord_lower),u_scale:new e.aO(t,r.u_scale),u_fade:new e.aJ(t,r.u_fade)}),circle:(t,r)=>({u_camera_to_center_distance:new e.aJ(t,r.u_camera_to_center_distance),u_scale_with_map:new e.aI(t,r.u_scale_with_map),u_pitch_with_map:new e.aI(t,r.u_pitch_with_map),u_extrude_scale:new e.aP(t,r.u_extrude_scale),u_device_pixel_ratio:new e.aJ(t,r.u_device_pixel_ratio),u_matrix:new e.aK(t,r.u_matrix)}),collisionBox:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_pixel_extrude_scale:new e.aP(t,r.u_pixel_extrude_scale)}),collisionCircle:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_inv_matrix:new e.aK(t,r.u_inv_matrix),u_camera_to_center_distance:new e.aJ(t,r.u_camera_to_center_distance),u_viewport_size:new e.aP(t,r.u_viewport_size)}),debug:(t,r)=>({u_color:new e.aM(t,r.u_color),u_matrix:new e.aK(t,r.u_matrix),u_overlay:new e.aI(t,r.u_overlay),u_overlay_scale:new e.aJ(t,r.u_overlay_scale)}),clippingMask:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix)}),heatmap:(t,r)=>({u_extrude_scale:new e.aJ(t,r.u_extrude_scale),u_intensity:new e.aJ(t,r.u_intensity),u_matrix:new e.aK(t,r.u_matrix)}),heatmapTexture:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_world:new e.aP(t,r.u_world),u_image:new e.aI(t,r.u_image),u_color_ramp:new e.aI(t,r.u_color_ramp),u_opacity:new e.aJ(t,r.u_opacity)}),hillshade:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_image:new e.aI(t,r.u_image),u_latrange:new e.aP(t,r.u_latrange),u_light:new e.aP(t,r.u_light),u_shadow:new e.aM(t,r.u_shadow),u_highlight:new e.aM(t,r.u_highlight),u_accent:new e.aM(t,r.u_accent)}),hillshadePrepare:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_image:new e.aI(t,r.u_image),u_dimension:new e.aP(t,r.u_dimension),u_zoom:new e.aJ(t,r.u_zoom),u_unpack:new e.aL(t,r.u_unpack)}),line:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_ratio:new e.aJ(t,r.u_ratio),u_device_pixel_ratio:new e.aJ(t,r.u_device_pixel_ratio),u_units_to_pixels:new e.aP(t,r.u_units_to_pixels)}),lineGradient:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_ratio:new e.aJ(t,r.u_ratio),u_device_pixel_ratio:new e.aJ(t,r.u_device_pixel_ratio),u_units_to_pixels:new e.aP(t,r.u_units_to_pixels),u_image:new e.aI(t,r.u_image),u_image_height:new e.aJ(t,r.u_image_height)}),linePattern:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_texsize:new e.aP(t,r.u_texsize),u_ratio:new e.aJ(t,r.u_ratio),u_device_pixel_ratio:new e.aJ(t,r.u_device_pixel_ratio),u_image:new e.aI(t,r.u_image),u_units_to_pixels:new e.aP(t,r.u_units_to_pixels),u_scale:new e.aO(t,r.u_scale),u_fade:new e.aJ(t,r.u_fade)}),lineSDF:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_ratio:new e.aJ(t,r.u_ratio),u_device_pixel_ratio:new e.aJ(t,r.u_device_pixel_ratio),u_units_to_pixels:new e.aP(t,r.u_units_to_pixels),u_patternscale_a:new e.aP(t,r.u_patternscale_a),u_patternscale_b:new e.aP(t,r.u_patternscale_b),u_sdfgamma:new e.aJ(t,r.u_sdfgamma),u_image:new e.aI(t,r.u_image),u_tex_y_a:new e.aJ(t,r.u_tex_y_a),u_tex_y_b:new e.aJ(t,r.u_tex_y_b),u_mix:new e.aJ(t,r.u_mix)}),raster:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_tl_parent:new e.aP(t,r.u_tl_parent),u_scale_parent:new e.aJ(t,r.u_scale_parent),u_buffer_scale:new e.aJ(t,r.u_buffer_scale),u_fade_t:new e.aJ(t,r.u_fade_t),u_opacity:new e.aJ(t,r.u_opacity),u_image0:new e.aI(t,r.u_image0),u_image1:new e.aI(t,r.u_image1),u_brightness_low:new e.aJ(t,r.u_brightness_low),u_brightness_high:new e.aJ(t,r.u_brightness_high),u_saturation_factor:new e.aJ(t,r.u_saturation_factor),u_contrast_factor:new e.aJ(t,r.u_contrast_factor),u_spin_weights:new e.aO(t,r.u_spin_weights)}),symbolIcon:(t,r)=>({u_is_size_zoom_constant:new e.aI(t,r.u_is_size_zoom_constant),u_is_size_feature_constant:new e.aI(t,r.u_is_size_feature_constant),u_size_t:new e.aJ(t,r.u_size_t),u_size:new e.aJ(t,r.u_size),u_camera_to_center_distance:new e.aJ(t,r.u_camera_to_center_distance),u_pitch:new e.aJ(t,r.u_pitch),u_rotate_symbol:new e.aI(t,r.u_rotate_symbol),u_aspect_ratio:new e.aJ(t,r.u_aspect_ratio),u_fade_change:new e.aJ(t,r.u_fade_change),u_matrix:new e.aK(t,r.u_matrix),u_label_plane_matrix:new e.aK(t,r.u_label_plane_matrix),u_coord_matrix:new e.aK(t,r.u_coord_matrix),u_is_text:new e.aI(t,r.u_is_text),u_pitch_with_map:new e.aI(t,r.u_pitch_with_map),u_is_along_line:new e.aI(t,r.u_is_along_line),u_is_variable_anchor:new e.aI(t,r.u_is_variable_anchor),u_texsize:new e.aP(t,r.u_texsize),u_texture:new e.aI(t,r.u_texture),u_translation:new e.aP(t,r.u_translation),u_pitched_scale:new e.aJ(t,r.u_pitched_scale)}),symbolSDF:(t,r)=>({u_is_size_zoom_constant:new e.aI(t,r.u_is_size_zoom_constant),u_is_size_feature_constant:new e.aI(t,r.u_is_size_feature_constant),u_size_t:new e.aJ(t,r.u_size_t),u_size:new e.aJ(t,r.u_size),u_camera_to_center_distance:new e.aJ(t,r.u_camera_to_center_distance),u_pitch:new e.aJ(t,r.u_pitch),u_rotate_symbol:new e.aI(t,r.u_rotate_symbol),u_aspect_ratio:new e.aJ(t,r.u_aspect_ratio),u_fade_change:new e.aJ(t,r.u_fade_change),u_matrix:new e.aK(t,r.u_matrix),u_label_plane_matrix:new e.aK(t,r.u_label_plane_matrix),u_coord_matrix:new e.aK(t,r.u_coord_matrix),u_is_text:new e.aI(t,r.u_is_text),u_pitch_with_map:new e.aI(t,r.u_pitch_with_map),u_is_along_line:new e.aI(t,r.u_is_along_line),u_is_variable_anchor:new e.aI(t,r.u_is_variable_anchor),u_texsize:new e.aP(t,r.u_texsize),u_texture:new e.aI(t,r.u_texture),u_gamma_scale:new e.aJ(t,r.u_gamma_scale),u_device_pixel_ratio:new e.aJ(t,r.u_device_pixel_ratio),u_is_halo:new e.aI(t,r.u_is_halo),u_translation:new e.aP(t,r.u_translation),u_pitched_scale:new e.aJ(t,r.u_pitched_scale)}),symbolTextAndIcon:(t,r)=>({u_is_size_zoom_constant:new e.aI(t,r.u_is_size_zoom_constant),u_is_size_feature_constant:new e.aI(t,r.u_is_size_feature_constant),u_size_t:new e.aJ(t,r.u_size_t),u_size:new e.aJ(t,r.u_size),u_camera_to_center_distance:new e.aJ(t,r.u_camera_to_center_distance),u_pitch:new e.aJ(t,r.u_pitch),u_rotate_symbol:new e.aI(t,r.u_rotate_symbol),u_aspect_ratio:new e.aJ(t,r.u_aspect_ratio),u_fade_change:new e.aJ(t,r.u_fade_change),u_matrix:new e.aK(t,r.u_matrix),u_label_plane_matrix:new e.aK(t,r.u_label_plane_matrix),u_coord_matrix:new e.aK(t,r.u_coord_matrix),u_is_text:new e.aI(t,r.u_is_text),u_pitch_with_map:new e.aI(t,r.u_pitch_with_map),u_is_along_line:new e.aI(t,r.u_is_along_line),u_is_variable_anchor:new e.aI(t,r.u_is_variable_anchor),u_texsize:new e.aP(t,r.u_texsize),u_texsize_icon:new e.aP(t,r.u_texsize_icon),u_texture:new e.aI(t,r.u_texture),u_texture_icon:new e.aI(t,r.u_texture_icon),u_gamma_scale:new e.aJ(t,r.u_gamma_scale),u_device_pixel_ratio:new e.aJ(t,r.u_device_pixel_ratio),u_is_halo:new e.aI(t,r.u_is_halo),u_translation:new e.aP(t,r.u_translation),u_pitched_scale:new e.aJ(t,r.u_pitched_scale)}),background:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_opacity:new e.aJ(t,r.u_opacity),u_color:new e.aM(t,r.u_color)}),backgroundPattern:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_opacity:new e.aJ(t,r.u_opacity),u_image:new e.aI(t,r.u_image),u_pattern_tl_a:new e.aP(t,r.u_pattern_tl_a),u_pattern_br_a:new e.aP(t,r.u_pattern_br_a),u_pattern_tl_b:new e.aP(t,r.u_pattern_tl_b),u_pattern_br_b:new e.aP(t,r.u_pattern_br_b),u_texsize:new e.aP(t,r.u_texsize),u_mix:new e.aJ(t,r.u_mix),u_pattern_size_a:new e.aP(t,r.u_pattern_size_a),u_pattern_size_b:new e.aP(t,r.u_pattern_size_b),u_scale_a:new e.aJ(t,r.u_scale_a),u_scale_b:new e.aJ(t,r.u_scale_b),u_pixel_coord_upper:new e.aP(t,r.u_pixel_coord_upper),u_pixel_coord_lower:new e.aP(t,r.u_pixel_coord_lower),u_tile_units_to_pixels:new e.aJ(t,r.u_tile_units_to_pixels)}),terrain:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_texture:new e.aI(t,r.u_texture),u_ele_delta:new e.aJ(t,r.u_ele_delta),u_fog_matrix:new e.aK(t,r.u_fog_matrix),u_fog_color:new e.aM(t,r.u_fog_color),u_fog_ground_blend:new e.aJ(t,r.u_fog_ground_blend),u_fog_ground_blend_opacity:new e.aJ(t,r.u_fog_ground_blend_opacity),u_horizon_color:new e.aM(t,r.u_horizon_color),u_horizon_fog_blend:new e.aJ(t,r.u_horizon_fog_blend)}),terrainDepth:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_ele_delta:new e.aJ(t,r.u_ele_delta)}),terrainCoords:(t,r)=>({u_matrix:new e.aK(t,r.u_matrix),u_texture:new e.aI(t,r.u_texture),u_terrain_coords_id:new e.aJ(t,r.u_terrain_coords_id),u_ele_delta:new e.aJ(t,r.u_ele_delta)}),sky:(t,r)=>({u_sky_color:new e.aM(t,r.u_sky_color),u_horizon_color:new e.aM(t,r.u_horizon_color),u_horizon:new e.aJ(t,r.u_horizon),u_sky_horizon_blend:new e.aJ(t,r.u_sky_horizon_blend)})};class Qe{constructor(t,e,r){this.context=t;const n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer}bind(){this.context.bindElementBuffer.set(this.buffer)}updateData(t){const e=this.context.gl;if(!this.dynamicDraw)throw new Error(\"Attempted to update data while not in dynamic mode.\");this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)}destroy(){const t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)}}const tr={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"};class er{constructor(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;const i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer}bind(){this.context.bindVertexBuffer.set(this.buffer)}updateData(t){if(t.length!==this.length)throw new Error(`Length of new data is ${t.length}, which doesn't match current length of ${this.length}`);const e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)}enableAttributes(t,e){for(let r=0;r<this.attributes.length;r++){const n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}}setVertexAttribPointers(t,e,r){for(let n=0;n<this.attributes.length;n++){const i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[tr[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}}destroy(){const t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)}}const rr=new WeakMap;function nr(t){var e;if(rr.has(t))return rr.get(t);{const r=null===(e=t.getParameter(t.VERSION))||void 0===e?void 0:e.startsWith(\"WebGL 2.0\");return rr.set(t,r),r}}class ir{constructor(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1}get(){return this.current}set(t){}getDefault(){return this.default}setDefault(){this.set(this.default)}}class ar extends ir{getDefault(){return e.aN.transparent}set(t){const e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)}}class or extends ir{getDefault(){return 1}set(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)}}class sr extends ir{getDefault(){return 0}set(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)}}class lr extends ir{getDefault(){return[!0,!0,!0,!0]}set(t){const e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)}}class cr extends ir{getDefault(){return!0}set(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)}}class ur extends ir{getDefault(){return 255}set(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)}}class hr extends ir{getDefault(){return{func:this.gl.ALWAYS,ref:0,mask:255}}set(t){const e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)}}class fr extends ir{getDefault(){const t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]}set(t){const e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)}}class pr extends ir{getDefault(){return!1}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}}class dr extends ir{getDefault(){return[0,1]}set(t){const e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)}}class mr extends ir{getDefault(){return!1}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}}class gr extends ir{getDefault(){return this.gl.LESS}set(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)}}class yr extends ir{getDefault(){return!1}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}}class vr extends ir{getDefault(){const t=this.gl;return[t.ONE,t.ZERO]}set(t){const e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)}}class xr extends ir{getDefault(){return e.aN.transparent}set(t){const e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)}}class _r extends ir{getDefault(){return this.gl.FUNC_ADD}set(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)}}class br extends ir{getDefault(){return!1}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}}class wr extends ir{getDefault(){return this.gl.BACK}set(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)}}class Tr extends ir{getDefault(){return this.gl.CCW}set(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)}}class kr extends ir{getDefault(){return null}set(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)}}class Ar extends ir{getDefault(){return this.gl.TEXTURE0}set(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)}}class Mr extends ir{getDefault(){const t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]}set(t){const e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)}}class Sr extends ir{getDefault(){return null}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}}class Er extends ir{getDefault(){return null}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}}class Cr extends ir{getDefault(){return null}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}}class Lr extends ir{getDefault(){return null}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}}class Ir extends ir{getDefault(){return null}set(t){const e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1}}class Pr extends ir{getDefault(){return null}set(t){var e;if(t===this.current&&!this.dirty)return;const r=this.gl;nr(r)?r.bindVertexArray(t):null===(e=r.getExtension(\"OES_vertex_array_object\"))||void 0===e||e.bindVertexArrayOES(t),this.current=t,this.dirty=!1}}class zr extends ir{getDefault(){return 4}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}}class Or extends ir{getDefault(){return!1}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}}class Dr extends ir{getDefault(){return!1}set(t){if(t===this.current&&!this.dirty)return;const e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}}class Rr extends ir{constructor(t,e){super(t),this.context=t,this.parent=e}getDefault(){return null}}class Fr extends Rr{setDirty(){this.dirty=!0}set(t){if(t===this.current&&!this.dirty)return;this.context.bindFramebuffer.set(this.parent);const e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}}class Br extends Rr{set(t){if(t===this.current&&!this.dirty)return;this.context.bindFramebuffer.set(this.parent);const e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}}class Nr extends Rr{set(t){if(t===this.current&&!this.dirty)return;this.context.bindFramebuffer.set(this.parent);const e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_STENCIL_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}}class jr{constructor(t,e,r,n,i){this.context=t,this.width=e,this.height=r;const a=t.gl,o=this.framebuffer=a.createFramebuffer();if(this.colorAttachment=new Fr(t,o),n)this.depthAttachment=i?new Nr(t,o):new Br(t,o);else if(i)throw new Error(\"Stencil cannot be set without depth\");if(a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE)throw new Error(\"Framebuffer is not complete\")}destroy(){const t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){const e=this.depthAttachment.get();e&&t.deleteRenderbuffer(e)}t.deleteFramebuffer(this.framebuffer)}}class Ur{constructor(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r}}Ur.Replace=[1,0],Ur.disabled=new Ur(Ur.Replace,e.aN.transparent,[!1,!1,!1,!1]),Ur.unblended=new Ur(Ur.Replace,e.aN.transparent,[!0,!0,!0,!0]),Ur.alphaBlended=new Ur([1,771],e.aN.transparent,[!0,!0,!0,!0]);class Vr{constructor(t){var e,r;if(this.gl=t,this.clearColor=new ar(this),this.clearDepth=new or(this),this.clearStencil=new sr(this),this.colorMask=new lr(this),this.depthMask=new cr(this),this.stencilMask=new ur(this),this.stencilFunc=new hr(this),this.stencilOp=new fr(this),this.stencilTest=new pr(this),this.depthRange=new dr(this),this.depthTest=new mr(this),this.depthFunc=new gr(this),this.blend=new yr(this),this.blendFunc=new vr(this),this.blendColor=new xr(this),this.blendEquation=new _r(this),this.cullFace=new br(this),this.cullFaceSide=new wr(this),this.frontFace=new Tr(this),this.program=new kr(this),this.activeTexture=new Ar(this),this.viewport=new Mr(this),this.bindFramebuffer=new Sr(this),this.bindRenderbuffer=new Er(this),this.bindTexture=new Cr(this),this.bindVertexBuffer=new Lr(this),this.bindElementBuffer=new Ir(this),this.bindVertexArray=new Pr(this),this.pixelStoreUnpack=new zr(this),this.pixelStoreUnpackPremultiplyAlpha=new Or(this),this.pixelStoreUnpackFlipY=new Dr(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.maxTextureSize=t.getParameter(t.MAX_TEXTURE_SIZE),nr(t)){this.HALF_FLOAT=t.HALF_FLOAT;const n=t.getExtension(\"EXT_color_buffer_half_float\");this.RGBA16F=null!==(e=t.RGBA16F)&&void 0!==e?e:null==n?void 0:n.RGBA16F_EXT,this.RGB16F=null!==(r=t.RGB16F)&&void 0!==r?r:null==n?void 0:n.RGB16F_EXT,t.getExtension(\"EXT_color_buffer_float\")}else{t.getExtension(\"EXT_color_buffer_half_float\"),t.getExtension(\"OES_texture_half_float_linear\");const e=t.getExtension(\"OES_texture_half_float\");this.HALF_FLOAT=null==e?void 0:e.HALF_FLOAT_OES}}setDefault(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()}setDirty(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.bindVertexArray.dirty=!0,this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0}createIndexBuffer(t,e){return new Qe(this,t,e)}createVertexBuffer(t,e,r){return new er(this,t,e,r)}createRenderbuffer(t,e,r){const n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i}createFramebuffer(t,e,r,n){return new jr(this,t,e,r,n)}clear({color:t,depth:e,stencil:r}){const n=this.gl;let i=0;t&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(t),this.colorMask.set([!0,!0,!0,!0])),void 0!==e&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(e),this.depthMask.set(!0)),void 0!==r&&(i|=n.STENCIL_BUFFER_BIT,this.clearStencil.set(r),this.stencilMask.set(255)),n.clear(i)}setCullFace(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))}setDepthMode(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)}setStencilMode(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)}setColorMode(t){e.aF(t.blendFunction,Ur.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(t.blendFunction),this.blendColor.set(t.blendColor)),this.colorMask.set(t.mask)}createVertexArray(){var t;return nr(this.gl)?this.gl.createVertexArray():null===(t=this.gl.getExtension(\"OES_vertex_array_object\"))||void 0===t?void 0:t.createVertexArrayOES()}deleteVertexArray(t){var e;return nr(this.gl)?this.gl.deleteVertexArray(t):null===(e=this.gl.getExtension(\"OES_vertex_array_object\"))||void 0===e?void 0:e.deleteVertexArrayOES(t)}unbindVAO(){this.bindVertexArray.set(null)}}class qr{constructor(t,e,r){this.func=t,this.mask=e,this.range=r}}qr.ReadOnly=!1,qr.ReadWrite=!0,qr.disabled=new qr(519,qr.ReadOnly,[0,1]);const Hr=7680;class Gr{constructor(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a}}Gr.disabled=new Gr({func:519,mask:0},0,0,Hr,Hr,Hr);class Zr{constructor(t,e,r){this.enable=t,this.mode=e,this.frontFace=r}}let Wr;function Yr(t,r,n,i,a){const o=t.context,s=o.gl,l=t.useProgram(\"collisionBox\"),c=[];let u=0,h=0;for(let f=0;f<i.length;f++){const p=i[f],d=r.getTile(p).getBucket(n);if(!d)continue;const m=a?d.textCollisionBox:d.iconCollisionBox,g=d.collisionCircleArray;if(g.length>0){const r=e.H();e.aR(r,d.placementInvProjMatrix,t.transform.glCoordMatrix),e.aR(r,r,d.placementViewportMatrix),c.push({circleArray:g,circleOffset:h,transform:p.posMatrix,invTransform:r,coord:p}),u+=g.length/4,h=u}m&&l.draw(o,s.LINES,qr.disabled,Gr.disabled,t.colorModeForRenderPass(),Zr.disabled,Le(t.transform,p.posMatrix),t.style.map.terrain&&t.style.map.terrain.getTerrainData(p),n.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,null,t.transform.zoom,null,null,m.collisionVertexBuffer)}if(!a||!c.length)return;const f=t.useProgram(\"collisionCircle\"),p=new e.aS;p.resize(4*u),p._trim();let d=0;for(const t of c)for(let e=0;e<t.circleArray.length/4;e++){const r=4*e,n=t.circleArray[r+0],i=t.circleArray[r+1],a=t.circleArray[r+2],o=t.circleArray[r+3];p.emplace(d++,n,i,a,o,0),p.emplace(d++,n,i,a,o,1),p.emplace(d++,n,i,a,o,2),p.emplace(d++,n,i,a,o,3)}(!Wr||Wr.length<2*u)&&(Wr=function(t){const r=2*t,n=new e.aU;n.resize(r),n._trim();for(let t=0;t<r;t++){const e=6*t;n.uint16[e+0]=4*t+0,n.uint16[e+1]=4*t+1,n.uint16[e+2]=4*t+2,n.uint16[e+3]=4*t+2,n.uint16[e+4]=4*t+3,n.uint16[e+5]=4*t+0}return n}(u));const m=o.createIndexBuffer(Wr,!0),g=o.createVertexBuffer(p,e.aT.members,!0);for(const r of c){const i=Ie(r.transform,r.invTransform,t.transform);f.draw(o,s.TRIANGLES,qr.disabled,Gr.disabled,t.colorModeForRenderPass(),Zr.disabled,i,t.style.map.terrain&&t.style.map.terrain.getTerrainData(r.coord),n.id,g,m,e.a0.simpleSegment(0,2*r.circleOffset,r.circleArray.length,r.circleArray.length/2),null,t.transform.zoom,null,null,null)}g.destroy(),m.destroy()}Zr.disabled=new Zr(!1,1029,2305),Zr.backCCW=new Zr(!0,1029,2305);const Xr=e.ao(new Float32Array(16));function $r(t,r,n,i,a){if(\"translucent\"!==t.renderPass)return;const o=Gr.disabled,s=t.colorModeForRenderPass();(n._unevaluatedLayout.hasValue(\"text-variable-anchor\")||n._unevaluatedLayout.hasValue(\"text-variable-anchor-offset\"))&&function(t,r,n,i,a,o,s,l,c){const u=r.transform,h=ie(),f=\"map\"===a,p=\"map\"===o;for(const a of t){const t=i.getTile(a),o=t.getBucket(n);if(!o||!o.text||!o.text.segments.get().length)continue;const d=o.textSizeData,m=e.ah(d,u.zoom),g=Nt(t,1,r.transform.zoom),y=_t(a.posMatrix,p,f,r.transform,g),v=\"none\"!==n.layout.get(\"icon-text-fit\")&&o.hasIconData();if(m){const e=Math.pow(2,u.zoom-t.tileID.overscaledZ),n=r.style.map.terrain?(t,e)=>r.style.map.terrain.getElevation(a,t,e):null,i=h.translatePosition(u,t,s,l);Qr(o,f,p,c,u,y,a.posMatrix,e,m,v,h,i,a.toUnwrapped(),n)}}}(i,t,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),a),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&en(t,r,n,i,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&en(t,r,n,i,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(Yr(t,r,n,i,!0),Yr(t,r,n,i,!1))}function Jr(t,r,n,i,a,o){const{horizontalAlign:s,verticalAlign:l}=e.av(t),c=-(s-.5)*r,u=-(l-.5)*n;return new e.P((c/a+i[0])*o,(u/a+i[1])*o)}function Kr(t,r,n,i,a,o){const s=r.tileAnchorPoint.add(new e.P(r.translation[0],r.translation[1]));if(r.pitchWithMap){let t=i.mult(o);return n||(t=t.rotate(-a)),wt(s.add(t),r.labelPlaneMatrix,r.getElevation).point}if(n){const e=It(r.tileAnchorPoint.x+1,r.tileAnchorPoint.y,r).point.sub(t),n=Math.atan(e.y/e.x)+(e.x<0?Math.PI:0);return t.add(i.rotate(n))}return t.add(i)}function Qr(t,r,n,i,a,o,s,l,c,u,h,f,p,d){const m=t.text.placedSymbolArray,g=t.text.dynamicLayoutVertexArray,y=t.icon.dynamicLayoutVertexArray,v={};g.clear();for(let y=0;y<m.length;y++){const x=m.get(y),_=t.allowVerticalPlacement&&!x.placedOrientation,b=x.hidden||!x.crossTileID||_?null:i[x.crossTileID];if(b){const i=new e.P(x.anchorX,x.anchorY),m={getElevation:d,width:a.width,height:a.height,labelPlaneMatrix:o,lineVertexArray:null,pitchWithMap:n,projection:h,projectionCache:null,tileAnchorPoint:i,translation:f,unwrappedTileID:p},y=n?wt(i,s,d):It(i.x,i.y,m),_=Tt(a.cameraToCenterDistance,y.signedDistanceFromCamera);let w=e.aj(t.textSizeData,c,x)*_/e.aq;n&&(w*=t.tilePixelRatio/l);const{width:T,height:k,anchor:A,textOffset:M,textBoxScale:S}=b,E=Jr(A,T,k,M,S,w),C=h.getPitchedTextCorrection(a,i.add(new e.P(f[0],f[1])),p),L=Kr(y.point,m,r,E,a.angle,C),I=t.allowVerticalPlacement&&x.placedOrientation===e.ai.vertical?Math.PI/2:0;for(let t=0;t<x.numGlyphs;t++)e.ak(g,L,I);u&&x.associatedIconIndex>=0&&(v[x.associatedIconIndex]={shiftedAnchor:L,angle:I})}else Rt(x.numGlyphs,g)}if(u){y.clear();const r=t.icon.placedSymbolArray;for(let t=0;t<r.length;t++){const n=r.get(t);if(n.hidden)Rt(n.numGlyphs,y);else{const r=v[t];if(r)for(let t=0;t<n.numGlyphs;t++)e.ak(y,r.shiftedAnchor,r.angle);else Rt(n.numGlyphs,y)}}t.icon.dynamicLayoutVertexBuffer.updateData(y)}t.text.dynamicLayoutVertexBuffer.updateData(g)}function tn(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function en(t,r,n,i,a,o,s,l,c,u,h,f){const p=t.context,d=p.gl,m=t.transform,g=ie(),y=\"map\"===l,v=\"map\"===c,x=\"viewport\"!==l&&\"point\"!==n.layout.get(\"symbol-placement\"),_=y&&!v&&!x,b=!v&&x,w=!n.layout.get(\"symbol-sort-key\").isConstant();let T=!1;const k=t.depthModeForSublayer(0,qr.ReadOnly),A=n._unevaluatedLayout.hasValue(\"text-variable-anchor\")||n._unevaluatedLayout.hasValue(\"text-variable-anchor-offset\"),M=[],S=g.getCircleRadiusCorrection(m);for(const l of i){const i=r.getTile(l),c=i.getBucket(n);if(!c)continue;const h=a?c.text:c.icon;if(!h||!h.segments.get().length||!h.hasVisibleVertices)continue;const f=h.programConfigurations.get(n.id),p=a||c.sdfIcons,k=a?c.textSizeData:c.iconSizeData,E=v||0!==m.pitch,C=t.useProgram(tn(p,a,c),f),L=e.ah(k,m.zoom),I=t.style.map.terrain&&t.style.map.terrain.getTerrainData(l);let P,z,O,D,R=[0,0],F=null;if(a){if(z=i.glyphAtlasTexture,O=d.LINEAR,P=i.glyphAtlasTexture.size,c.iconsInText){R=i.imageAtlasTexture.size,F=i.imageAtlasTexture;const e=\"composite\"===k.kind||\"camera\"===k.kind;D=E||t.options.rotating||t.options.zooming||e?d.LINEAR:d.NEAREST}}else{const e=1!==n.layout.get(\"icon-size\").constantOr(0)||c.iconsNeedLinear;z=i.imageAtlasTexture,O=p||t.options.rotating||t.options.zooming||e||E?d.LINEAR:d.NEAREST,P=i.imageAtlasTexture.size}const B=Nt(i,1,t.transform.zoom),N=b?l.posMatrix:Xr,j=_t(N,v,y,t.transform,B),U=bt(N,v,y,t.transform,B),V=bt(l.posMatrix,v,y,t.transform,B),q=g.translatePosition(t.transform,i,o,s),H=A&&c.hasTextData(),G=\"none\"!==n.layout.get(\"icon-text-fit\")&&H&&c.hasIconData();if(x){const e=t.style.map.terrain?(e,r)=>t.style.map.terrain.getElevation(l,e,r):null,r=\"map\"===n.layout.get(\"text-rotation-alignment\");At(c,l.posMatrix,t,a,j,V,v,u,r,g,l.toUnwrapped(),m.width,m.height,q,e)}const Z=l.posMatrix,W=a&&A||G,Y=x||W?Xr:j,X=U,$=p&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1);let J;J=p?c.iconsInText?Xe(k.kind,L,_,v,x,W,t,Z,Y,X,q,P,R,S):Ye(k.kind,L,_,v,x,W,t,Z,Y,X,q,a,P,!0,S):We(k.kind,L,_,v,x,W,t,Z,Y,X,q,a,P,S);const K={program:C,buffers:h,uniformValues:J,atlasTexture:z,atlasTextureIcon:F,atlasInterpolation:O,atlasInterpolationIcon:D,isSDF:p,hasHalo:$};if(w&&c.canOverlap){T=!0;const t=h.segments.get();for(const r of t)M.push({segments:new e.a0([r]),sortKey:r.sortKey,state:K,terrainData:I})}else M.push({segments:h.segments,sortKey:0,state:K,terrainData:I})}T&&M.sort(((t,e)=>t.sortKey-e.sortKey));for(const e of M){const r=e.state;if(p.activeTexture.set(d.TEXTURE0),r.atlasTexture.bind(r.atlasInterpolation,d.CLAMP_TO_EDGE),r.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),r.atlasTextureIcon&&r.atlasTextureIcon.bind(r.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),r.isSDF){const i=r.uniformValues;r.hasHalo&&(i.u_is_halo=1,rn(r.buffers,e.segments,n,t,r.program,k,h,f,i,e.terrainData)),i.u_is_halo=0}rn(r.buffers,e.segments,n,t,r.program,k,h,f,r.uniformValues,e.terrainData)}}function rn(t,e,r,n,i,a,o,s,l,c){const u=n.context,h=u.gl;i.draw(u,h.TRIANGLES,a,o,s,Zr.disabled,l,c,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function nn(t,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===t.renderPass){const a=t.context,o=a.gl,s=Gr.disabled,l=new Ur([o.ONE,o.ONE],e.aN.transparent,[!0,!0,!0,!0]);(function(t,e,r){const n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);let i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{const a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1,!1),function(t,e,r,n){var i,a;const o=t.gl,s=null!==(i=t.HALF_FLOAT)&&void 0!==i?i:o.UNSIGNED_BYTE,l=null!==(a=t.RGBA16F)&&void 0!==a?a:o.RGBA;o.texImage2D(o.TEXTURE_2D,0,l,e.width/4,e.height/4,0,o.RGBA,s,null),n.colorAttachment.set(r)}(t,e,a,i)}})(a,t,n),a.clear({color:e.aN.transparent});for(let e=0;e<i.length;e++){const c=i[e];if(r.hasRenderableParent(c))continue;const u=r.getTile(c),h=u.getBucket(n);if(!h)continue;const f=h.programConfigurations.get(n.id),p=t.useProgram(\"heatmap\",f),{zoom:d}=t.transform;p.draw(a,o.TRIANGLES,qr.disabled,s,l,Zr.disabled,Oe(c.posMatrix,u,d,n.paint.get(\"heatmap-intensity\")),null,n.id,h.layoutVertexBuffer,h.indexBuffer,h.segments,n.paint,t.transform.zoom,f)}a.viewport.set([0,0,t.width,t.height])}else\"translucent\"===t.renderPass&&(t.context.setColorMode(t.colorModeForRenderPass()),function(t,e){const r=t.context,n=r.gl,i=e.heatmapFbo;if(!i)return;r.activeTexture.set(n.TEXTURE0),n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),r.activeTexture.set(n.TEXTURE1);let a=e.colorRampTexture;a||(a=e.colorRampTexture=new w(r,e.colorRamp,n.RGBA)),a.bind(n.LINEAR,n.CLAMP_TO_EDGE),t.useProgram(\"heatmapTexture\").draw(r,n.TRIANGLES,qr.disabled,Gr.disabled,t.colorModeForRenderPass(),Zr.disabled,De(t,e,0,1),null,e.id,t.viewportBuffer,t.quadTriangleIndexBuffer,t.viewportSegments,e.paint,t.transform.zoom)}(t,n))}function an(t,e,r,n,i){if(!r||!n||!n.imageAtlas)return;const a=n.imageAtlas.patternPositions;let o=a[r.to.toString()],s=a[r.from.toString()];if(!o&&s&&(o=s),!s&&o&&(s=o),!o||!s){const t=i.getPaintProperty(e);o=a[t],s=a[t]}o&&s&&t.setConstantPatternPositions(o,s)}function on(t,e,r,n,i,a,o){const s=t.context.gl,l=\"fill-pattern\",c=r.paint.get(l),u=c&&c.constantOr(1),h=r.getCrossfadeParameters();let f,p,d,m,g;o?(p=u&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",f=s.LINES):(p=u?\"fillPattern\":\"fill\",f=s.TRIANGLES);const y=c.constantOr(null);for(const c of n){const n=e.getTile(c);if(u&&!n.patternsLoaded())continue;const v=n.getBucket(r);if(!v)continue;const x=v.programConfigurations.get(r.id),_=t.useProgram(p,x),b=t.style.map.terrain&&t.style.map.terrain.getTerrainData(c);u&&(t.context.activeTexture.set(s.TEXTURE0),n.imageAtlasTexture.bind(s.LINEAR,s.CLAMP_TO_EDGE),x.updatePaintBuffers(h)),an(x,l,y,n,r);const w=b?c:null,T=w?w.posMatrix:c.posMatrix,k=t.translatePosMatrix(T,n,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){m=v.indexBuffer2,g=v.segments2;const e=[s.drawingBufferWidth,s.drawingBufferHeight];d=\"fillOutlinePattern\"===p&&u?Ee(k,t,h,n,e):Se(k,e)}else m=v.indexBuffer,g=v.segments,d=u?Me(k,t,h,n):Ae(k);_.draw(t.context,f,i,t.stencilModeForClipping(c),a,Zr.disabled,d,b,r.id,v.layoutVertexBuffer,m,g,r.paint,t.transform.zoom,x)}}function sn(t,e,r,n,i,a,o){const s=t.context,l=s.gl,c=\"fill-extrusion-pattern\",u=r.paint.get(c),h=u.constantOr(1),f=r.getCrossfadeParameters(),p=r.paint.get(\"fill-extrusion-opacity\"),d=u.constantOr(null);for(const u of n){const n=e.getTile(u),m=n.getBucket(r);if(!m)continue;const g=t.style.map.terrain&&t.style.map.terrain.getTerrainData(u),y=m.programConfigurations.get(r.id),v=t.useProgram(h?\"fillExtrusionPattern\":\"fillExtrusion\",y);h&&(t.context.activeTexture.set(l.TEXTURE0),n.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePaintBuffers(f)),an(y,c,d,n,r);const x=t.translatePosMatrix(u.posMatrix,n,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),_=r.paint.get(\"fill-extrusion-vertical-gradient\"),b=h?ke(x,t,_,p,u,f,n):Te(x,t,_,p);v.draw(s,s.gl.TRIANGLES,i,a,o,Zr.backCCW,b,g,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y,t.style.map.terrain&&m.centroidVertexBuffer)}}function ln(t,e,r,n,i,a,o){const s=t.context,l=s.gl,c=r.fbo;if(!c)return;const u=t.useProgram(\"hillshade\"),h=t.style.map.terrain&&t.style.map.terrain.getTerrainData(e);s.activeTexture.set(l.TEXTURE0),l.bindTexture(l.TEXTURE_2D,c.colorAttachment.get());const f=h?e:null;u.draw(s,l.TRIANGLES,i,a,o,Zr.disabled,Re(t,r,n,f),h,n.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}function cn(t,e,r,n,i,a){const o=t.context,s=o.gl,l=e.dem;if(l&&l.data){const c=l.dim,u=l.stride,h=l.getPixels();if(o.activeTexture.set(s.TEXTURE1),o.pixelStoreUnpackPremultiplyAlpha.set(!1),e.demTexture=e.demTexture||t.getTileTexture(u),e.demTexture){const t=e.demTexture;t.update(h,{premultiply:!1}),t.bind(s.NEAREST,s.CLAMP_TO_EDGE)}else e.demTexture=new w(o,h,s.RGBA,{premultiply:!1}),e.demTexture.bind(s.NEAREST,s.CLAMP_TO_EDGE);o.activeTexture.set(s.TEXTURE0);let f=e.fbo;if(!f){const t=new w(o,{width:c,height:c,data:null},s.RGBA);t.bind(s.LINEAR,s.CLAMP_TO_EDGE),f=e.fbo=o.createFramebuffer(c,c,!0,!1),f.colorAttachment.set(t.texture)}o.bindFramebuffer.set(f.framebuffer),o.viewport.set([0,0,c,c]),t.useProgram(\"hillshadePrepare\").draw(o,s.TRIANGLES,n,i,a,Zr.disabled,Fe(e.tileID,l),null,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments),e.needsHillshadePrepare=!1}}function un(t,r,n,i,o,s){const l=i.paint.get(\"raster-fade-duration\");if(!s&&l>0){const i=a.now(),s=(i-t.timeAdded)/l,c=r?(i-r.timeAdded)/l:-1,u=n.getSource(),h=o.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(t.tileID.overscaledZ-h),p=f&&t.refreshedUponExpiration?1:e.ad(f?s:1-c,0,1);return t.refreshedUponExpiration&&s>=1&&(t.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}const hn=new e.aN(1,0,0,1),fn=new e.aN(0,1,0,1),pn=new e.aN(0,0,1,1),dn=new e.aN(1,0,1,1),mn=new e.aN(0,1,1,1);function gn(t){const e=t.transform.padding;yn(t,t.transform.height-(e.top||0),3,hn),yn(t,e.bottom||0,3,fn),vn(t,e.left||0,3,pn),vn(t,t.transform.width-(e.right||0),3,dn);const r=t.transform.centerPoint;!function(t,e,r,n){const i=20,a=2;xn(t,e-a/2,r-i/2,a,i,n),xn(t,e-i/2,r-a/2,i,a,n)}(t,r.x,t.transform.height-r.y,mn)}function yn(t,e,r,n){xn(t,0,e+r/2,t.transform.width,r,n)}function vn(t,e,r,n){xn(t,e-r/2,0,r,t.transform.height,n)}function xn(t,e,r,n,i,a){const o=t.context,s=o.gl;s.enable(s.SCISSOR_TEST),s.scissor(e*t.pixelRatio,r*t.pixelRatio,n*t.pixelRatio,i*t.pixelRatio),o.clear({color:a}),s.disable(s.SCISSOR_TEST)}function _n(t,r,n){const i=t.context,a=i.gl,o=n.posMatrix,s=t.useProgram(\"debug\"),l=qr.disabled,c=Gr.disabled,u=t.colorModeForRenderPass(),h=\"$debug\",f=t.style.map.terrain&&t.style.map.terrain.getTerrainData(n);i.activeTexture.set(a.TEXTURE0);const p=r.getTileByID(n.key).latestRawTileData,d=p&&p.byteLength||0,m=Math.floor(d/1024),g=r.getTile(n).tileSize,y=512/Math.min(g,512)*(n.overscaledZ/t.transform.zoom)*.5;let v=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(v+=` => ${n.overscaledZ}`),function(t,e){t.initDebugOverlayCanvas();const r=t.debugOverlayCanvas,n=t.context.gl,i=t.debugOverlayCanvas.getContext(\"2d\");i.clearRect(0,0,r.width,r.height),i.shadowColor=\"white\",i.shadowBlur=2,i.lineWidth=1.5,i.strokeStyle=\"white\",i.textBaseline=\"top\",i.font=\"bold 36px Open Sans, sans-serif\",i.fillText(e,5,5),i.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(t,`${v} ${m}kB`),s.draw(i,a.TRIANGLES,l,c,Ur.alphaBlended,Zr.disabled,Pe(o,e.aN.transparent,y),null,h,t.debugBuffer,t.quadTriangleIndexBuffer,t.debugSegments),s.draw(i,a.LINE_STRIP,l,c,u,Zr.disabled,Pe(o,e.aN.red),f,h,t.debugBuffer,t.tileBorderIndexBuffer,t.debugSegments)}function bn(t,e,r){const n=t.context,i=n.gl,a=t.colorModeForRenderPass(),o=new qr(i.LEQUAL,qr.ReadWrite,t.depthRangeFor3D),s=t.useProgram(\"terrain\"),l=e.getTerrainMesh();n.bindFramebuffer.set(null),n.viewport.set([0,0,t.width,t.height]);for(const c of r){const r=t.renderToTexture.getTexture(c),u=e.getTerrainData(c.tileID);n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,r.texture);const h=t.transform.calculatePosMatrix(c.tileID.toUnwrapped()),f=e.getMeshFrameDelta(t.transform.zoom),p=t.transform.calculateFogMatrix(c.tileID.toUnwrapped()),d=xe(h,f,p,t.style.sky,t.transform.pitch);s.draw(n,i.TRIANGLES,o,Gr.disabled,a,Zr.backCCW,d,u,\"terrain\",l.vertexBuffer,l.indexBuffer,l.segments)}}class wn{constructor(t,e,r){this.vertexBuffer=t,this.indexBuffer=e,this.segments=r}destroy(){this.vertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.vertexBuffer=null,this.indexBuffer=null,this.segments=null}}class Tn{constructor(t,r){this.context=new Vr(t),this.transform=r,this._tileTextures={},this.terrainFacilitator={dirty:!0,matrix:e.ao(new Float64Array(16)),renderTime:0},this.setup(),this.numSublayers=dt.maxUnderzooming+dt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new he}resize(t,e,r){if(this.width=Math.floor(t*r),this.height=Math.floor(e*r),this.pixelRatio=r,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(const t of this.style._order)this.style._layers[t].resize()}setup(){const t=this.context,r=new e.aX;r.emplaceBack(0,0),r.emplaceBack(e.X,0),r.emplaceBack(0,e.X),r.emplaceBack(e.X,e.X),this.tileExtentBuffer=t.createVertexBuffer(r,me.members),this.tileExtentSegments=e.a0.simpleSegment(0,0,4,2);const n=new e.aX;n.emplaceBack(0,0),n.emplaceBack(e.X,0),n.emplaceBack(0,e.X),n.emplaceBack(e.X,e.X),this.debugBuffer=t.createVertexBuffer(n,me.members),this.debugSegments=e.a0.simpleSegment(0,0,4,5);const i=new e.$;i.emplaceBack(0,0,0,0),i.emplaceBack(e.X,0,e.X,0),i.emplaceBack(0,e.X,0,e.X),i.emplaceBack(e.X,e.X,e.X,e.X),this.rasterBoundsBuffer=t.createVertexBuffer(i,et.members),this.rasterBoundsSegments=e.a0.simpleSegment(0,0,4,2);const a=new e.aX;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=t.createVertexBuffer(a,me.members),this.viewportSegments=e.a0.simpleSegment(0,0,4,2);const o=new e.aZ;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=t.createIndexBuffer(o);const s=new e.aY;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=t.createIndexBuffer(s);const l=this.context.gl;this.stencilClearMode=new Gr({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)}clearStencil(){const t=this.context,r=t.gl;this.nextStencilID=1,this.currentStencilSource=void 0;const n=e.H();e.aQ(n,0,this.width,this.height,0,0,1),e.K(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(t,r.TRIANGLES,qr.disabled,this.stencilClearMode,Ur.disabled,Zr.disabled,ze(n),null,\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)}_renderTileClippingMasks(t,e){if(this.currentStencilSource===t.source||!t.isTileClipped()||!e||!e.length)return;this.currentStencilSource=t.source;const r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Ur.disabled),r.setDepthMode(qr.disabled);const i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(const t of e){const e=this._tileClippingMaskIDs[t.key]=this.nextStencilID++,a=this.style.map.terrain&&this.style.map.terrain.getTerrainData(t);i.draw(r,n.TRIANGLES,qr.disabled,new Gr({func:n.ALWAYS,mask:0},e,255,n.KEEP,n.KEEP,n.REPLACE),Ur.disabled,Zr.disabled,ze(t.posMatrix),a,\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}stencilModeFor3D(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();const t=this.nextStencilID++,e=this.context.gl;return new Gr({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)}stencilModeForClipping(t){const e=this.context.gl;return new Gr({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)}stencilConfigForOverlap(t){const e=this.context.gl,r=t.sort(((t,e)=>e.overscaledZ-t.overscaledZ)),n=r[r.length-1].overscaledZ,i=r[0].overscaledZ-n+1;if(i>1){this.currentStencilSource=void 0,this.nextStencilID+i>256&&this.clearStencil();const t={};for(let r=0;r<i;r++)t[r+n]=new Gr({func:e.GEQUAL,mask:255},r+this.nextStencilID,255,e.KEEP,e.KEEP,e.REPLACE);return this.nextStencilID+=i,[t,r]}return[{[n]:Gr.disabled},r]}colorModeForRenderPass(){const t=this.context.gl;if(this._showOverdrawInspector){const r=1/8;return new Ur([t.CONSTANT_COLOR,t.ONE],new e.aN(r,r,r,0),[!0,!0,!0,!0])}return\"opaque\"===this.renderPass?Ur.unblended:Ur.alphaBlended}depthModeForSublayer(t,e,r){if(!this.opaquePassEnabledForLayer())return qr.disabled;const n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new qr(r||this.context.gl.LEQUAL,e,[n,n])}opaquePassEnabledForLayer(){return this.currentLayer<this.opaquePassCutoff}render(t,r){var n;this.style=t,this.options=r,this.lineAtlas=t.lineAtlas,this.imageManager=t.imageManager,this.glyphManager=t.glyphManager,this.symbolFadeChange=t.placement.symbolFadeChange(a.now()),this.imageManager.beginFrame();const i=this.style._order,o=this.style.sourceCaches,s={},l={},c={};for(const t in o){const e=o[t];e.used&&e.prepare(this.context),s[t]=e.getVisibleCoordinates(),l[t]=s[t].slice().reverse(),c[t]=e.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(let t=0;t<i.length;t++){const e=i[t];if(this.style._layers[e].is3D()){this.opaquePassCutoff=t;break}}this.maybeDrawDepthAndCoords(!1),this.renderToTexture&&(this.renderToTexture.prepareForRender(this.style,this.transform.zoom),this.opaquePassCutoff=0),this.renderPass=\"offscreen\";for(const t of i){const e=this.style._layers[t];if(!e.hasOffscreenPass()||e.isHidden(this.transform.zoom))continue;const r=l[e.source];(\"custom\"===e.type||r.length)&&this.renderLayer(this,o[e.source],e,r)}if(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?e.aN.black:e.aN.transparent,depth:1}),this.clearStencil(),(null===(n=this.style.stylesheet)||void 0===n?void 0:n.sky)&&function(t,r){const n=t.context,i=n.gl,a=((t,e,r)=>({u_sky_color:t.properties.get(\"sky-color\"),u_horizon_color:t.properties.get(\"horizon-color\"),u_horizon:(e.height/2+e.getHorizon())*r,u_sky_horizon_blend:t.properties.get(\"sky-horizon-blend\")*e.height/2*r}))(r,t.style.map.transform,t.pixelRatio),o=new qr(i.LEQUAL,qr.ReadWrite,[0,1]),s=Gr.disabled,l=t.colorModeForRenderPass(),c=t.useProgram(\"sky\");if(!r.mesh){const t=new e.aX;t.emplaceBack(-1,-1),t.emplaceBack(1,-1),t.emplaceBack(1,1),t.emplaceBack(-1,1);const i=new e.aY;i.emplaceBack(0,1,2),i.emplaceBack(0,2,3),r.mesh=new wn(n.createVertexBuffer(t,me.members),n.createIndexBuffer(i),e.a0.simpleSegment(0,0,t.length,i.length))}c.draw(n,i.TRIANGLES,o,s,l,Zr.disabled,a,void 0,\"sky\",r.mesh.vertexBuffer,r.mesh.indexBuffer,r.mesh.segments)}(this,this.style.sky),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(t._order.length+2)*this.numSublayers*this.depthEpsilon],!this.renderToTexture)for(this.renderPass=\"opaque\",this.currentLayer=i.length-1;this.currentLayer>=0;this.currentLayer--){const t=this.style._layers[i[this.currentLayer]],e=o[t.source],r=s[t.source];this._renderTileClippingMasks(t,r),this.renderLayer(this,e,t,r)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<i.length;this.currentLayer++){const t=this.style._layers[i[this.currentLayer]],e=o[t.source];if(this.renderToTexture&&this.renderToTexture.renderLayer(t))continue;const r=(\"symbol\"===t.type?c:l)[t.source];this._renderTileClippingMasks(t,s[t.source]),this.renderLayer(this,e,t,r)}if(this.options.showTileBoundaries){const t=function(t,e){let r=null;const n=Object.values(t._layers).flatMap((r=>r.source&&!r.isHidden(e)?[t.sourceCaches[r.source]]:[])),i=n.filter((t=>\"vector\"===t.getSource().type)),a=n.filter((t=>\"vector\"!==t.getSource().type)),o=t=>{(!r||r.getSource().maxzoom<t.getSource().maxzoom)&&(r=t)};return i.forEach((t=>o(t))),r||a.forEach((t=>o(t))),r}(this.style,this.transform.zoom);t&&function(t,e,r){for(let n=0;n<r.length;n++)_n(t,e,r[n])}(this,t,t.getVisibleCoordinates())}this.options.showPadding&&gn(this),this.context.setDefault()}maybeDrawDepthAndCoords(t){if(!this.style||!this.style.map||!this.style.map.terrain)return;const r=this.terrainFacilitator.matrix,n=this.transform.modelViewProjectionMatrix;let i=this.terrainFacilitator.dirty;i||(i=t?!e.a_(r,n):!e.a$(r,n)),i||(i=this.style.map.terrain.sourceCache.tilesAfterTime(this.terrainFacilitator.renderTime).length>0),i&&(e.b0(r,n),this.terrainFacilitator.renderTime=Date.now(),this.terrainFacilitator.dirty=!1,function(t,r){const n=t.context,i=n.gl,a=Ur.unblended,o=new qr(i.LEQUAL,qr.ReadWrite,[0,1]),s=r.getTerrainMesh(),l=r.sourceCache.getRenderableTiles(),c=t.useProgram(\"terrainDepth\");n.bindFramebuffer.set(r.getFramebuffer(\"depth\").framebuffer),n.viewport.set([0,0,t.width/devicePixelRatio,t.height/devicePixelRatio]),n.clear({color:e.aN.transparent,depth:1});for(const e of l){const l=r.getTerrainData(e.tileID),u={u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped()),u_ele_delta:r.getMeshFrameDelta(t.transform.zoom)};c.draw(n,i.TRIANGLES,o,Gr.disabled,a,Zr.backCCW,u,l,\"terrain\",s.vertexBuffer,s.indexBuffer,s.segments)}n.bindFramebuffer.set(null),n.viewport.set([0,0,t.width,t.height])}(this,this.style.map.terrain),function(t,r){const n=t.context,i=n.gl,a=Ur.unblended,o=new qr(i.LEQUAL,qr.ReadWrite,[0,1]),s=r.getTerrainMesh(),l=r.getCoordsTexture(),c=r.sourceCache.getRenderableTiles(),u=t.useProgram(\"terrainCoords\");n.bindFramebuffer.set(r.getFramebuffer(\"coords\").framebuffer),n.viewport.set([0,0,t.width/devicePixelRatio,t.height/devicePixelRatio]),n.clear({color:e.aN.transparent,depth:1}),r.coordsIndex=[];for(const e of c){const c=r.getTerrainData(e.tileID);n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,l.texture);const h={u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped()),u_terrain_coords_id:(255-r.coordsIndex.length)/255,u_texture:0,u_ele_delta:r.getMeshFrameDelta(t.transform.zoom)};u.draw(n,i.TRIANGLES,o,Gr.disabled,a,Zr.backCCW,h,c,\"terrain\",s.vertexBuffer,s.indexBuffer,s.segments),r.coordsIndex.push(e.tileID.key)}n.bindFramebuffer.set(null),n.viewport.set([0,0,t.width,t.height])}(this,this.style.map.terrain))}renderLayer(t,r,n,i){if(!n.isHidden(this.transform.zoom)&&(\"background\"===n.type||\"custom\"===n.type||(i||[]).length))switch(this.id=n.id,n.type){case\"symbol\":$r(t,r,n,i,this.style.placement.variableOffsets);break;case\"circle\":!function(t,r,n,i){if(\"translucent\"!==t.renderPass)return;const a=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=!n.layout.get(\"circle-sort-key\").isConstant();if(0===a.constantOr(1)&&(0===o.constantOr(1)||0===s.constantOr(1)))return;const c=t.context,u=c.gl,h=t.depthModeForSublayer(0,qr.ReadOnly),f=Gr.disabled,p=t.colorModeForRenderPass(),d=[];for(let a=0;a<i.length;a++){const o=i[a],s=r.getTile(o),c=s.getBucket(n);if(!c)continue;const u=c.programConfigurations.get(n.id),h=t.useProgram(\"circle\",u),f=c.layoutVertexBuffer,p=c.indexBuffer,m=t.style.map.terrain&&t.style.map.terrain.getTerrainData(o),g={programConfiguration:u,program:h,layoutVertexBuffer:f,indexBuffer:p,uniformValues:Ce(t,o,s,n),terrainData:m};if(l){const t=c.segments.get();for(const r of t)d.push({segments:new e.a0([r]),sortKey:r.sortKey,state:g})}else d.push({segments:c.segments,sortKey:0,state:g})}l&&d.sort(((t,e)=>t.sortKey-e.sortKey));for(const e of d){const{programConfiguration:r,program:i,layoutVertexBuffer:a,indexBuffer:o,uniformValues:s,terrainData:l}=e.state,d=e.segments;i.draw(c,u.TRIANGLES,h,f,p,Zr.disabled,s,l,n.id,a,o,d,n.paint,t.transform.zoom,r)}}(t,r,n,i);break;case\"heatmap\":nn(t,r,n,i);break;case\"line\":!function(t,r,n,i){if(\"translucent\"!==t.renderPass)return;const a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0===a.constantOr(1)||0===o.constantOr(1))return;const s=t.depthModeForSublayer(0,qr.ReadOnly),l=t.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=h?\"linePattern\":c?\"lineSDF\":f?\"lineGradient\":\"line\",m=t.context,g=m.gl;let y=!0;for(const a of i){const i=r.getTile(a);if(h&&!i.patternsLoaded())continue;const o=i.getBucket(n);if(!o)continue;const v=o.programConfigurations.get(n.id),x=t.context.program.get(),_=t.useProgram(d,v),b=y||_.program!==x,T=t.style.map.terrain&&t.style.map.terrain.getTerrainData(a),k=u.constantOr(null);if(k&&i.imageAtlas){const t=i.imageAtlas,e=t.patternPositions[k.to.toString()],r=t.patternPositions[k.from.toString()];e&&r&&v.setConstantPatternPositions(e,r)}const A=T?a:null,M=h?Ue(t,i,n,p,A):c?Ve(t,i,n,c,p,A):f?je(t,i,n,o.lineClipsArray.length,A):Ne(t,i,n,A);if(h)m.activeTexture.set(g.TEXTURE0),i.imageAtlasTexture.bind(g.LINEAR,g.CLAMP_TO_EDGE),v.updatePaintBuffers(p);else if(c&&(b||t.lineAtlas.dirty))m.activeTexture.set(g.TEXTURE0),t.lineAtlas.bind(m);else if(f){const i=o.gradients[n.id];let s=i.texture;if(n.gradientVersion!==i.version){let l=256;if(n.stepInterpolant){const n=r.getSource().maxzoom,i=a.canonical.z===n?Math.ceil(1<<t.transform.maxZoom-a.canonical.z):1,s=o.maxLineLength/e.X*1024*i;l=e.ad(e.aV(s),256,m.maxTextureSize)}i.gradient=e.aW({expression:n.gradientExpression(),evaluationKey:\"lineProgress\",resolution:l,image:i.gradient||void 0,clips:o.lineClipsArray}),i.texture?i.texture.update(i.gradient):i.texture=new w(m,i.gradient,g.RGBA),i.version=n.gradientVersion,s=i.texture}m.activeTexture.set(g.TEXTURE0),s.bind(n.stepInterpolant?g.NEAREST:g.LINEAR,g.CLAMP_TO_EDGE)}_.draw(m,g.TRIANGLES,s,t.stencilModeForClipping(a),l,Zr.disabled,M,T,n.id,o.layoutVertexBuffer,o.indexBuffer,o.segments,n.paint,t.transform.zoom,v,o.layoutVertexBuffer2),y=!1}}(t,r,n,i);break;case\"fill\":!function(t,r,n,i){const a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0===o.constantOr(1))return;const s=t.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=t.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(e.aN.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(t.renderPass===c){const e=t.depthModeForSublayer(1,\"opaque\"===t.renderPass?qr.ReadWrite:qr.ReadOnly);on(t,r,n,i,e,s,!1)}if(\"translucent\"===t.renderPass&&n.paint.get(\"fill-antialias\")){const e=t.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,qr.ReadOnly);on(t,r,n,i,e,s,!0)}}(t,r,n,i);break;case\"fill-extrusion\":!function(t,e,r,n){const i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){const a=new qr(t.context.gl.LEQUAL,qr.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))sn(t,e,r,n,a,Gr.disabled,Ur.disabled),sn(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{const i=t.colorModeForRenderPass();sn(t,e,r,n,a,Gr.disabled,i)}}}(t,r,n,i);break;case\"hillshade\":!function(t,e,r,n){if(\"offscreen\"!==t.renderPass&&\"translucent\"!==t.renderPass)return;const i=t.context,a=t.depthModeForSublayer(0,qr.ReadOnly),o=t.colorModeForRenderPass(),[s,l]=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n];for(const n of l){const i=e.getTile(n);void 0!==i.needsHillshadePrepare&&i.needsHillshadePrepare&&\"offscreen\"===t.renderPass?cn(t,i,r,a,Gr.disabled,o):\"translucent\"===t.renderPass&&ln(t,n,i,r,a,s[n.overscaledZ],o)}i.viewport.set([0,0,t.width,t.height])}(t,r,n,i);break;case\"raster\":!function(t,e,r,n){if(\"translucent\"!==t.renderPass)return;if(0===r.paint.get(\"raster-opacity\"))return;if(!n.length)return;const i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),[c,u]=o instanceof rt?[{},n]:t.stencilConfigForOverlap(n),h=u[u.length-1].overscaledZ,f=!t.options.moving;for(const n of u){const u=t.depthModeForSublayer(n.overscaledZ-h,1===r.paint.get(\"raster-opacity\")?qr.ReadWrite:qr.ReadOnly,a.LESS),p=e.getTile(n);p.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));const d=e.findLoadedParent(n,0),m=e.findLoadedSibling(n),g=un(p,d||m||null,e,r,t.transform,t.style.map.terrain);let y,v;const x=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),p.texture.bind(x,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),d?(d.texture.bind(x,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),y=Math.pow(2,d.tileID.overscaledZ-p.tileID.overscaledZ),v=[p.tileID.canonical.x*y%1,p.tileID.canonical.y*y%1]):p.texture.bind(x,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),p.texture.useMipmap&&i.extTextureFilterAnisotropic&&t.transform.pitch>20&&a.texParameterf(a.TEXTURE_2D,i.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,i.extTextureFilterAnisotropicMax);const _=t.style.map.terrain&&t.style.map.terrain.getTerrainData(n),b=_?n:null,w=b?b.posMatrix:t.transform.calculatePosMatrix(n.toUnwrapped(),f),T=Ge(w,v||[0,0],y||1,g,r);o instanceof rt?s.draw(i,a.TRIANGLES,u,Gr.disabled,l,Zr.disabled,T,_,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(i,a.TRIANGLES,u,c[n.overscaledZ],l,Zr.disabled,T,_,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}(t,r,n,i);break;case\"background\":!function(t,e,r,n){const i=r.paint.get(\"background-color\"),a=r.paint.get(\"background-opacity\");if(0===a)return;const o=t.context,s=o.gl,l=t.transform,c=l.tileSize,u=r.paint.get(\"background-pattern\");if(t.isPatternMissing(u))return;const h=!u&&1===i.a&&1===a&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass!==h)return;const f=Gr.disabled,p=t.depthModeForSublayer(0,\"opaque\"===h?qr.ReadWrite:qr.ReadOnly),d=t.colorModeForRenderPass(),m=t.useProgram(u?\"backgroundPattern\":\"background\"),g=n||l.coveringTiles({tileSize:c,terrain:t.style.map.terrain});u&&(o.activeTexture.set(s.TEXTURE0),t.imageManager.bind(t.context));const y=r.getCrossfadeParameters();for(const e of g){const l=n?e.posMatrix:t.transform.calculatePosMatrix(e.toUnwrapped()),h=u?Je(l,a,t,u,{tileID:e,tileSize:c},y):$e(l,a,i),g=t.style.map.terrain&&t.style.map.terrain.getTerrainData(e);m.draw(o,s.TRIANGLES,p,f,d,Zr.disabled,h,g,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}(t,0,n,i);break;case\"custom\":!function(t,e,r){const n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){const e=i.prerender;e&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),e.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(Gr.disabled);const e=\"3d\"===i.renderingMode?new qr(t.context.gl.LEQUAL,qr.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,qr.ReadOnly);n.setDepthMode(e),i.render(n.gl,t.transform.customLayerMatrix(),{farZ:t.transform.farZ,nearZ:t.transform.nearZ,fov:t.transform._fov,modelViewProjectionMatrix:t.transform.modelViewProjectionMatrix,projectionMatrix:t.transform.projectionMatrix}),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}(t,0,n)}}translatePosMatrix(t,r,n,i,a){if(!n[0]&&!n[1])return t;const o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){const t=Math.sin(o),e=Math.cos(o);n=[n[0]*e-n[1]*t,n[0]*t+n[1]*e]}const s=[a?n[0]:Nt(r,n[0],this.transform.zoom),a?n[1]:Nt(r,n[1],this.transform.zoom),0],l=new Float32Array(16);return e.J(l,t,s),l}saveTileTexture(t){const e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]}getTileTexture(t){const e=this._tileTextures[t];return e&&e.length>0?e.pop():null}isPatternMissing(t){if(!t)return!1;if(!t.from||!t.to)return!0;const e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r}useProgram(t,e){this.cache=this.cache||{};const r=t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\")+(this.style.map.terrain?\"/terrain\":\"\");return this.cache[r]||(this.cache[r]=new be(this.context,ge[t],e,Ke[t],this._showOverdrawInspector,this.style.map.terrain)),this.cache[r]}setCustomLayerDefaults(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()}setBaseState(){const t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)}initDebugOverlayCanvas(){if(null==this.debugOverlayCanvas){this.debugOverlayCanvas=document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512;const t=this.context.gl;this.debugOverlayTexture=new w(this.context,this.debugOverlayCanvas,t.RGBA)}}destroy(){this.debugOverlayTexture&&this.debugOverlayTexture.destroy()}overLimit(){const{drawingBufferWidth:t,drawingBufferHeight:e}=this.context.gl;return this.width!==t||this.height!==e}}class kn{constructor(t,e){this.points=t,this.planes=e}static fromInvProjectionMatrix(t,r,n){const i=Math.pow(2,n),a=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((n=>{const a=1/(n=e.ag([],n,t))[3]/r*i;return e.b1(n,n,[a,a,1/n[3],a])})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((t=>{const e=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a)),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a,t}([],function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}([],y([],a[t[0]],a[t[1]]),y([],a[t[2]],a[t[1]]))),r=(n=e,i=a[t[1]],-(n[0]*i[0]+n[1]*i[1]+n[2]*i[2]));var n,i;return e.concat(r)}));return new kn(a,o)}}class An{constructor(t,e){this.min=t,this.max=e,this.center=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}([],function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}([],this.min,this.max),.5)}quadrant(t){const e=[t%2==0,t<2],r=m(this.min),n=m(this.max);for(let t=0;t<e.length;t++)r[t]=e[t]?this.min[t]:this.center[t],n[t]=e[t]?this.center[t]:this.max[t];return n[2]=this.max[2],new An(r,n)}distanceX(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]}distanceY(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]}intersects(t){const r=[[this.min[0],this.min[1],this.min[2],1],[this.max[0],this.min[1],this.min[2],1],[this.max[0],this.max[1],this.min[2],1],[this.min[0],this.max[1],this.min[2],1],[this.min[0],this.min[1],this.max[2],1],[this.max[0],this.min[1],this.max[2],1],[this.max[0],this.max[1],this.max[2],1],[this.min[0],this.max[1],this.max[2],1]];let n=!0;for(let i=0;i<t.planes.length;i++){const a=t.planes[i];let o=0;for(let t=0;t<r.length;t++)e.b2(a,r[t])>=0&&o++;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(let e=0;e<3;e++){let r=Number.MAX_VALUE,n=-Number.MAX_VALUE;for(let i=0;i<t.points.length;i++){const a=t.points[i][e]-this.min[e];r=Math.min(r,a),n=Math.max(n,a)}if(n<0||r>this.max[e]-this.min[e])return 0}return 1}}class Mn{constructor(t=0,e=0,r=0,n=0){if(isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n}interpolate(t,r,n){return null!=r.top&&null!=t.top&&(this.top=e.z.number(t.top,r.top,n)),null!=r.bottom&&null!=t.bottom&&(this.bottom=e.z.number(t.bottom,r.bottom,n)),null!=r.left&&null!=t.left&&(this.left=e.z.number(t.left,r.left,n)),null!=r.right&&null!=t.right&&(this.right=e.z.number(t.right,r.right,n)),this}getCenter(t,r){const n=e.ad((this.left+t-this.right)/2,0,t),i=e.ad((this.top+r-this.bottom)/2,0,r);return new e.P(n,i)}equals(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right}clone(){return new Mn(this.top,this.bottom,this.left,this.right)}toJSON(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}}}const Sn=85.051129;class En{constructor(t,r,n,i,a){this.tileSize=512,this._renderWorldCopies=void 0===a||!!a,this._minZoom=t||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==i?60:i,this.setMaxBounds(),this.width=0,this.height=0,this._center=new e.N(0,0),this._elevation=0,this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new Mn,this._posMatrixCache={},this._alignedPosMatrixCache={},this._fogMatrixCache={},this.minElevationForCurrentTile=0}clone(){const t=new En(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.apply(this),t}apply(t){this.tileSize=t.tileSize,this.latRange=t.latRange,this.width=t.width,this.height=t.height,this._center=t._center,this._elevation=t._elevation,this.minElevationForCurrentTile=t.minElevationForCurrentTile,this.zoom=t.zoom,this.angle=t.angle,this._fov=t._fov,this._pitch=t._pitch,this._unmodified=t._unmodified,this._edgeInsets=t._edgeInsets.clone(),this._calcMatrices()}get minZoom(){return this._minZoom}set minZoom(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))}get maxZoom(){return this._maxZoom}set maxZoom(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))}get minPitch(){return this._minPitch}set minPitch(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))}get maxPitch(){return this._maxPitch}set maxPitch(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))}get renderWorldCopies(){return this._renderWorldCopies}set renderWorldCopies(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t}get worldSize(){return this.tileSize*this.scale}get centerOffset(){return this.centerPoint._sub(this.size._div(2))}get size(){return new e.P(this.width,this.height)}get bearing(){return-this.angle/Math.PI*180}set bearing(t){const r=-e.b3(t,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=function(){var t=new e.A(4);return e.A!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t}(),function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l}(this.rotationMatrix,this.rotationMatrix,this.angle))}get pitch(){return this._pitch/Math.PI*180}set pitch(t){const r=e.ad(t,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())}get fov(){return this._fov/Math.PI*180}set fov(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())}get zoom(){return this._zoom}set zoom(t){const e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.tileZoom=Math.max(0,Math.floor(e)),this.scale=this.zoomScale(e),this._constrain(),this._calcMatrices())}get center(){return this._center}set center(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())}get elevation(){return this._elevation}set elevation(t){t!==this._elevation&&(this._elevation=t,this._constrain(),this._calcMatrices())}get padding(){return this._edgeInsets.toJSON()}set padding(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())}get centerPoint(){return this._edgeInsets.getCenter(this.width,this.height)}isPaddingEqual(t){return this._edgeInsets.equals(t)}interpolatePadding(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()}coveringZoomLevel(t){const e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)}getVisibleUnwrappedCoordinates(t){const r=[new e.b4(0,t)];if(this._renderWorldCopies){const n=this.pointCoordinate(new e.P(0,0)),i=this.pointCoordinate(new e.P(this.width,0)),a=this.pointCoordinate(new e.P(this.width,this.height)),o=this.pointCoordinate(new e.P(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=1;for(let n=s-c;n<=l+c;n++)0!==n&&r.push(new e.b4(n,t))}return r}coveringTiles(t){var r,n;let i=this.coveringZoomLevel(t);const a=i;if(void 0!==t.minzoom&&i<t.minzoom)return[];void 0!==t.maxzoom&&i>t.maxzoom&&(i=t.maxzoom);const o=this.pointCoordinate(this.getCameraPoint()),s=e.Z.fromLngLat(this.center),l=Math.pow(2,i),c=[l*o.x,l*o.y,0],u=[l*s.x,l*s.y,0],h=kn.fromInvProjectionMatrix(this.invModelViewProjectionMatrix,this.worldSize,i);let f=t.minzoom||0;!t.terrain&&this.pitch<=60&&this._edgeInsets.top<.1&&(f=i);const p=t.terrain?2/Math.min(this.tileSize,t.tileSize)*this.tileSize:3,d=t=>({aabb:new An([t*l,0,0],[(t+1)*l,l,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}),m=[],g=[],y=i,x=t.reparseOverscaled?a:i;if(this._renderWorldCopies)for(let t=1;t<=3;t++)m.push(d(-t)),m.push(d(t));for(m.push(d(0));m.length>0;){const i=m.pop(),a=i.x,o=i.y;let s=i.fullyVisible;if(!s){const t=i.aabb.intersects(h);if(0===t)continue;s=2===t}const l=t.terrain?c:u,d=i.aabb.distanceX(l),_=i.aabb.distanceY(l),b=Math.max(Math.abs(d),Math.abs(_)),w=p+(1<<y-i.zoom)-2;if(i.zoom===y||b>w&&i.zoom>=f){const t=y-i.zoom,r=c[0]-.5-(a<<t),n=c[1]-.5-(o<<t);g.push({tileID:new e.S(i.zoom===y?x:i.zoom,i.wrap,i.zoom,a,o),distanceSq:v([u[0]-.5-a,u[1]-.5-o]),tileDistanceToCamera:Math.sqrt(r*r+n*n)})}else for(let l=0;l<4;l++){const c=(a<<1)+l%2,u=(o<<1)+(l>>1),h=i.zoom+1;let f=i.aabb.quadrant(l);if(t.terrain){const a=new e.S(h,i.wrap,h,c,u),o=t.terrain.getMinMaxElevation(a),s=null!==(r=o.minElevation)&&void 0!==r?r:this.elevation,l=null!==(n=o.maxElevation)&&void 0!==n?n:this.elevation;f=new An([f.min[0],f.min[1],s],[f.max[0],f.max[1],l])}m.push({aabb:f,zoom:h,x:c,y:u,wrap:i.wrap,fullyVisible:s})}}return g.sort(((t,e)=>t.distanceSq-e.distanceSq)).map((t=>t.tileID))}resize(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()}get unmodified(){return this._unmodified}zoomScale(t){return Math.pow(2,t)}scaleZoom(t){return Math.log(t)/Math.LN2}project(t){const r=e.ad(t.lat,-85.051129,Sn);return new e.P(e.O(t.lng)*this.worldSize,e.Q(r)*this.worldSize)}unproject(t){return new e.Z(t.x/this.worldSize,t.y/this.worldSize).toLngLat()}get point(){return this.project(this.center)}getCameraPosition(){return{lngLat:this.pointLocation(this.getCameraPoint()),altitude:Math.cos(this._pitch)*this.cameraToCenterDistance/this._pixelPerMeter+this.elevation}}recalculateZoom(t){const r=this.elevation,n=Math.cos(this._pitch)*this.cameraToCenterDistance/this._pixelPerMeter,i=this.pointLocation(this.centerPoint,t),a=t.getElevationForLngLatZoom(i,this.tileZoom);if(!(this.elevation-a))return;const o=n+r-a,s=Math.cos(this._pitch)*this.cameraToCenterDistance/o/e.b5(1,i.lat)/this.tileSize,l=this.scaleZoom(s);this._elevation=a,this._center=i,this.zoom=l}setLocationAtPoint(t,r){const n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(t),o=new e.Z(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())}locationPoint(t,e){return e?this.coordinatePoint(this.locationCoordinate(t),e.getElevationForLngLatZoom(t,this.tileZoom),this.pixelMatrix3D):this.coordinatePoint(this.locationCoordinate(t))}pointLocation(t,e){return this.coordinateLocation(this.pointCoordinate(t,e))}locationCoordinate(t){return e.Z.fromLngLat(t)}coordinateLocation(t){return t&&t.toLngLat()}pointCoordinate(t,r){if(r){const e=r.pointCoordinate(t);if(null!=e)return e}const n=[t.x,t.y,0,1],i=[t.x,t.y,1,1];e.ag(n,n,this.pixelMatrixInverse),e.ag(i,i,this.pixelMatrixInverse);const a=n[3],o=i[3],s=n[0]/a,l=i[0]/o,c=n[1]/a,u=i[1]/o,h=n[2]/a,f=i[2]/o,p=h===f?0:(0-h)/(f-h);return new e.Z(e.z.number(s,l,p)/this.worldSize,e.z.number(c,u,p)/this.worldSize)}coordinatePoint(t,r=0,n=this.pixelMatrix){const i=[t.x*this.worldSize,t.y*this.worldSize,r,1];return e.ag(i,i,n),new e.P(i[0]/i[3],i[1]/i[3])}getBounds(){const t=Math.max(0,this.height/2-this.getHorizon());return(new X).extend(this.pointLocation(new e.P(0,t))).extend(this.pointLocation(new e.P(this.width,t))).extend(this.pointLocation(new e.P(this.width,this.height))).extend(this.pointLocation(new e.P(0,this.height)))}getMaxBounds(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new X([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null}getHorizon(){return Math.tan(Math.PI/2-this._pitch)*this.cameraToCenterDistance*.85}setMaxBounds(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-85.051129,Sn])}calculateTileMatrix(t){const r=t.canonical,n=this.worldSize/this.zoomScale(r.z),i=r.x+Math.pow(2,r.z)*t.wrap,a=e.ao(new Float64Array(16));return e.J(a,a,[i*n,r.y*n,0]),e.K(a,a,[n/e.X,n/e.X,1]),a}calculatePosMatrix(t,r=!1){const n=t.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];const a=this.calculateTileMatrix(t);return e.L(a,r?this.alignedModelViewProjectionMatrix:this.modelViewProjectionMatrix,a),i[n]=new Float32Array(a),i[n]}calculateFogMatrix(t){const r=t.key,n=this._fogMatrixCache;if(n[r])return n[r];const i=this.calculateTileMatrix(t);return e.L(i,this.fogMatrix,i),n[r]=new Float32Array(i),n[r]}customLayerMatrix(){return this.mercatorMatrix.slice()}getConstrained(t,r){r=e.ad(+r,this.minZoom,this.maxZoom);const n={center:new e.N(t.lng,t.lat),zoom:r};let i=this.lngRange;if(!this._renderWorldCopies&&null===i){const t=180-1e-10;i=[-t,t]}const a=this.tileSize*this.zoomScale(n.zoom);let o=0,s=a,l=0,c=a,u=0,h=0;const{x:f,y:p}=this.size;if(this.latRange){const t=this.latRange;o=e.Q(t[1])*a,s=e.Q(t[0])*a,s-o<p&&(u=p/(s-o))}i&&(l=e.b3(e.O(i[0])*a,0,a),c=e.b3(e.O(i[1])*a,0,a),c<l&&(c+=a),c-l<f&&(h=f/(c-l)));const{x:d,y:m}=this.project.call({worldSize:a},t);let g,y;const v=Math.max(h||0,u||0);if(v){const t=new e.P(h?(c+l)/2:d,u?(s+o)/2:m);return n.center=this.unproject.call({worldSize:a},t).wrap(),n.zoom+=this.scaleZoom(v),n}if(this.latRange){const t=p/2;m-t<o&&(y=o+t),m+t>s&&(y=s-t)}if(i){const t=(l+c)/2;let r=d;this._renderWorldCopies&&(r=e.b3(d,t-a/2,t+a/2));const n=f/2;r-n<l&&(g=l+n),r+n>c&&(g=c-n)}if(void 0!==g||void 0!==y){const t=new e.P(null!=g?g:d,null!=y?y:m);n.center=this.unproject.call({worldSize:a},t).wrap()}return n}_constrain(){if(!this.center||!this.width||!this.height||this._constraining)return;this._constraining=!0;const t=this._unmodified,{center:e,zoom:r}=this.getConstrained(this.center,this.zoom);this.center=e,this.zoom=r,this._unmodified=t,this._constraining=!1}_calcMatrices(){if(!this.height)return;const t=this._fov/2,r=this.centerOffset,n=this.point.x,i=this.point.y;this.cameraToCenterDistance=.5/Math.tan(t)*this.height,this._pixelPerMeter=e.b5(1,this.center.lat)*this.worldSize;let a=e.ao(new Float64Array(16));e.K(a,a,[this.width/2,-this.height/2,1]),e.J(a,a,[1,-1,0]),this.labelPlaneMatrix=a,a=e.ao(new Float64Array(16)),e.K(a,a,[1,-1,1]),e.J(a,a,[-1,-1,0]),e.K(a,a,[2/this.width,2/this.height,1]),this.glCoordMatrix=a;const o=this.cameraToCenterDistance+this._elevation*this._pixelPerMeter/Math.cos(this._pitch),s=Math.min(this.elevation,this.minElevationForCurrentTile),l=o-s*this._pixelPerMeter/Math.cos(this._pitch),c=s<0?l:o,u=Math.PI/2+this._pitch,h=this._fov*(.5+r.y/this.height),f=Math.sin(h)*c/Math.sin(e.ad(Math.PI-u-h,.01,Math.PI-.01)),p=this.getHorizon(),d=2*Math.atan(p/this.cameraToCenterDistance)*(.5+r.y/(2*p)),m=Math.sin(d)*c/Math.sin(e.ad(Math.PI-u-d,.01,Math.PI-.01)),g=Math.min(f,m);this.farZ=1.01*(Math.cos(Math.PI/2-this._pitch)*g+c),this.nearZ=this.height/50,a=new Float64Array(16),e.b6(a,this._fov,this.width/this.height,this.nearZ,this.farZ),a[8]=2*-r.x/this.width,a[9]=2*r.y/this.height,this.projectionMatrix=e.af(a),e.K(a,a,[1,-1,1]),e.J(a,a,[0,0,-this.cameraToCenterDistance]),e.b7(a,a,this._pitch),e.ae(a,a,this.angle),e.J(a,a,[-n,-i,0]),this.mercatorMatrix=e.K([],a,[this.worldSize,this.worldSize,this.worldSize]),e.K(a,a,[1,1,this._pixelPerMeter]),this.pixelMatrix=e.L(new Float64Array(16),this.labelPlaneMatrix,a),e.J(a,a,[0,0,-this.elevation]),this.modelViewProjectionMatrix=a,this.invModelViewProjectionMatrix=e.at([],a),this.fogMatrix=new Float64Array(16),e.b6(this.fogMatrix,this._fov,this.width/this.height,o,this.farZ),this.fogMatrix[8]=2*-r.x/this.width,this.fogMatrix[9]=2*r.y/this.height,e.K(this.fogMatrix,this.fogMatrix,[1,-1,1]),e.J(this.fogMatrix,this.fogMatrix,[0,0,-this.cameraToCenterDistance]),e.b7(this.fogMatrix,this.fogMatrix,this._pitch),e.ae(this.fogMatrix,this.fogMatrix,this.angle),e.J(this.fogMatrix,this.fogMatrix,[-n,-i,0]),e.K(this.fogMatrix,this.fogMatrix,[1,1,this._pixelPerMeter]),e.J(this.fogMatrix,this.fogMatrix,[0,0,-this.elevation]),this.pixelMatrix3D=e.L(new Float64Array(16),this.labelPlaneMatrix,a);const y=this.width%2/2,v=this.height%2/2,x=Math.cos(this.angle),_=Math.sin(this.angle),b=n-Math.round(n)+x*y+_*v,w=i-Math.round(i)+x*v+_*y,T=new Float64Array(a);if(e.J(T,T,[b>.5?b-1:b,w>.5?w-1:w,0]),this.alignedModelViewProjectionMatrix=T,a=e.at(new Float64Array(16),this.pixelMatrix),!a)throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=a,this._posMatrixCache={},this._alignedPosMatrixCache={},this._fogMatrixCache={}}maxPitchScaleFactor(){if(!this.pixelMatrixInverse)return 1;const t=this.pointCoordinate(new e.P(0,0)),r=[t.x*this.worldSize,t.y*this.worldSize,0,1];return e.ag(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance}getCameraPoint(){const t=this._pitch,r=Math.tan(t)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new e.P(0,r))}getCameraQueryGeometry(t){const r=this.getCameraPoint();if(1===t.length)return[t[0],r];{let n=r.x,i=r.y,a=r.x,o=r.y;for(const e of t)n=Math.min(n,e.x),i=Math.min(i,e.y),a=Math.max(a,e.x),o=Math.max(o,e.y);return[new e.P(n,i),new e.P(a,i),new e.P(a,o),new e.P(n,o),new e.P(n,i)]}}lngLatToCameraDepth(t,r){const n=this.locationCoordinate(t),i=[n.x*this.worldSize,n.y*this.worldSize,r,1];return e.ag(i,i,this.modelViewProjectionMatrix),i[2]/i[3]}}function Cn(t,e){let r,n=!1,i=null,a=null;const o=()=>{i=null,n&&(t.apply(a,r),i=setTimeout(o,e),n=!1)};return(...t)=>(n=!0,a=this,r=t,i||o(),i)}class Ln{constructor(t){this._getCurrentHash=()=>{const t=window.location.hash.replace(\"#\",\"\");if(this._hashName){let e;return t.split(\"&\").map((t=>t.split(\"=\"))).forEach((t=>{t[0]===this._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")}return t.split(\"/\")},this._onHashChange=()=>{const t=this._getCurrentHash();if(t.length>=3&&!t.some((t=>isNaN(t)))){const e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},this._updateHashUnthrottled=()=>{const t=window.location.href.replace(/(#.+)?$/,this.getHashString());window.history.replaceState(window.history.state,null,t)},this._removeHash=()=>{const t=this._getCurrentHash();if(0===t.length)return;const e=t.join(\"/\");let r=e;r.split(\"&\").length>0&&(r=r.split(\"&\")[0]),this._hashName&&(r=`${this._hashName}=${e}`);let n=window.location.hash.replace(r,\"\");n.startsWith(\"#&\")?n=n.slice(0,1)+n.slice(2):\"#\"===n&&(n=\"\");let i=window.location.href.replace(/(#.+)?$/,n);i=i.replace(\"&&\",\"&\"),window.history.replaceState(window.history.state,null,i)},this._updateHash=Cn(this._updateHashUnthrottled,300),this._hashName=t&&encodeURIComponent(t)}addTo(t){return this._map=t,addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this}remove(){return removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),this._removeHash(),delete this._map,this}getHashString(t){const e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch();let c=\"\";if(c+=t?`/${a}/${o}/${r}`:`${r}/${o}/${a}`,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=`/${Math.round(l)}`),this._hashName){const t=this._hashName;let e=!1;const r=window.location.hash.slice(1).split(\"&\").map((r=>{const n=r.split(\"=\")[0];return n===t?(e=!0,`${n}=${c}`):r})).filter((t=>t));return e||r.push(`${t}=${c}`),`#${r.join(\"&\")}`}return`#${c}`}}const In={linearity:.3,easing:e.b8(0,0,.3,1)},Pn=e.e({deceleration:2500,maxSpeed:1400},In),zn=e.e({deceleration:20,maxSpeed:1400},In),On=e.e({deceleration:1e3,maxSpeed:360},In),Dn=e.e({deceleration:1e3,maxSpeed:90},In);class Rn{constructor(t){this._map=t,this.clear()}clear(){this._inertiaBuffer=[]}record(t){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:a.now(),settings:t})}_drainInertiaBuffer(){const t=this._inertiaBuffer,e=a.now();for(;t.length>0&&e-t[0].time>160;)t.shift()}_onMoveEnd(t){if(this._drainInertiaBuffer(),this._inertiaBuffer.length<2)return;const r={zoom:0,bearing:0,pitch:0,pan:new e.P(0,0),pinchAround:void 0,around:void 0};for(const{settings:t}of this._inertiaBuffer)r.zoom+=t.zoomDelta||0,r.bearing+=t.bearingDelta||0,r.pitch+=t.pitchDelta||0,t.panDelta&&r.pan._add(t.panDelta),t.around&&(r.around=t.around),t.pinchAround&&(r.pinchAround=t.pinchAround);const n=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,i={};if(r.pan.mag()){const a=Bn(r.pan.mag(),n,e.e({},Pn,t||{}));i.offset=r.pan.mult(a.amount/r.pan.mag()),i.center=this._map.transform.center,Fn(i,a)}if(r.zoom){const t=Bn(r.zoom,n,zn);i.zoom=this._map.transform.zoom+t.amount,Fn(i,t)}if(r.bearing){const t=Bn(r.bearing,n,On);i.bearing=this._map.transform.bearing+e.ad(t.amount,-179,179),Fn(i,t)}if(r.pitch){const t=Bn(r.pitch,n,Dn);i.pitch=this._map.transform.pitch+t.amount,Fn(i,t)}if(i.zoom||i.bearing){const t=void 0===r.pinchAround?r.around:r.pinchAround;i.around=t?this._map.unproject(t):this._map.getCenter()}return this.clear(),e.e(i,{noMoveStart:!0})}}function Fn(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function Bn(t,r,n){const{maxSpeed:i,linearity:a,deceleration:o}=n,s=e.ad(t*a/(r/1e3),-i,i),l=Math.abs(s)/(o*a);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}class Nn extends e.k{preventDefault(){this._defaultPrevented=!0}get defaultPrevented(){return this._defaultPrevented}constructor(t,r,n,i={}){const a=o.mousePos(r.getCanvas(),n),s=r.unproject(a);super(t,e.e({point:a,lngLat:s,originalEvent:n},i)),this._defaultPrevented=!1,this.target=r}}class jn extends e.k{preventDefault(){this._defaultPrevented=!0}get defaultPrevented(){return this._defaultPrevented}constructor(t,r,n){const i=\"touchend\"===t?n.changedTouches:n.touches,a=o.touchPos(r.getCanvasContainer(),i),s=a.map((t=>r.unproject(t))),l=a.reduce(((t,e,r,n)=>t.add(e.div(n.length))),new e.P(0,0));super(t,{points:a,point:l,lngLats:s,lngLat:r.unproject(l),originalEvent:n}),this._defaultPrevented=!1}}class Un extends e.k{preventDefault(){this._defaultPrevented=!0}get defaultPrevented(){return this._defaultPrevented}constructor(t,e,r){super(t,{originalEvent:r}),this._defaultPrevented=!1}}class Vn{constructor(t,e){this._map=t,this._clickTolerance=e.clickTolerance}reset(){delete this._mousedownPos}wheel(t){return this._firePreventable(new Un(t.type,this._map,t))}mousedown(t,e){return this._mousedownPos=e,this._firePreventable(new Nn(t.type,this._map,t))}mouseup(t){this._map.fire(new Nn(t.type,this._map,t))}click(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new Nn(t.type,this._map,t))}dblclick(t){return this._firePreventable(new Nn(t.type,this._map,t))}mouseover(t){this._map.fire(new Nn(t.type,this._map,t))}mouseout(t){this._map.fire(new Nn(t.type,this._map,t))}touchstart(t){return this._firePreventable(new jn(t.type,this._map,t))}touchmove(t){this._map.fire(new jn(t.type,this._map,t))}touchend(t){this._map.fire(new jn(t.type,this._map,t))}touchcancel(t){this._map.fire(new jn(t.type,this._map,t))}_firePreventable(t){if(this._map.fire(t),t.defaultPrevented)return{}}isEnabled(){return!0}isActive(){return!1}enable(){}disable(){}}class qn{constructor(t){this._map=t}reset(){this._delayContextMenu=!1,this._ignoreContextMenu=!0,delete this._contextMenuEvent}mousemove(t){this._map.fire(new Nn(t.type,this._map,t))}mousedown(){this._delayContextMenu=!0,this._ignoreContextMenu=!1}mouseup(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new Nn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)}contextmenu(t){this._delayContextMenu?this._contextMenuEvent=t:this._ignoreContextMenu||this._map.fire(new Nn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()}isEnabled(){return!0}isActive(){return!1}enable(){}disable(){}}class Hn{constructor(t){this._map=t}get transform(){return this._map._requestedCameraState||this._map.transform}get center(){return{lng:this.transform.center.lng,lat:this.transform.center.lat}}get zoom(){return this.transform.zoom}get pitch(){return this.transform.pitch}get bearing(){return this.transform.bearing}unproject(t){return this.transform.pointLocation(e.P.convert(t),this._map.terrain)}}class Gn{constructor(t,e){this._map=t,this._tr=new Hn(t),this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1}isEnabled(){return!!this._enabled}isActive(){return!!this._active}enable(){this.isEnabled()||(this._enabled=!0)}disable(){this.isEnabled()&&(this._enabled=!1)}mousedown(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(o.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)}mousemoveWindow(t,e){if(!this._active)return;const r=e;if(this._lastPos.equals(r)||!this._box&&r.dist(this._startPos)<this._clickTolerance)return;const n=this._startPos;this._lastPos=r,this._box||(this._box=o.create(\"div\",\"maplibregl-boxzoom\",this._container),this._container.classList.add(\"maplibregl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));const i=Math.min(n.x,r.x),a=Math.max(n.x,r.x),s=Math.min(n.y,r.y),l=Math.max(n.y,r.y);o.setTransform(this._box,`translate(${i}px,${s}px)`),this._box.style.width=a-i+\"px\",this._box.style.height=l-s+\"px\"}mouseupWindow(t,r){if(!this._active)return;if(0!==t.button)return;const n=this._startPos,i=r;if(this.reset(),o.suppressClick(),n.x!==i.x||n.y!==i.y)return this._map.fire(new e.k(\"boxzoomend\",{originalEvent:t})),{cameraAnimation:t=>t.fitScreenCoordinates(n,i,this._tr.bearing,{linear:!0})};this._fireEvent(\"boxzoomcancel\",t)}keydown(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))}reset(){this._active=!1,this._container.classList.remove(\"maplibregl-crosshair\"),this._box&&(o.remove(this._box),this._box=null),o.enableDrag(),delete this._startPos,delete this._lastPos}_fireEvent(t,r){return this._map.fire(new e.k(t,{originalEvent:r}))}}function Zn(t,e){if(t.length!==e.length)throw new Error(`The number of touches and points are not equal - touches ${t.length}, points ${e.length}`);const r={};for(let n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}class Wn{constructor(t){this.reset(),this.numTouches=t.numTouches}reset(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1}touchstart(t,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=t.timeStamp),n.length===this.numTouches&&(this.centroid=function(t){const r=new e.P(0,0);for(const e of t)r._add(e);return r.div(t.length)}(r),this.touches=Zn(n,r)))}touchmove(t,e,r){if(this.aborted||!this.centroid)return;const n=Zn(r,e);for(const t in this.touches){const e=this.touches[t],r=n[t];(!r||r.dist(e)>30)&&(this.aborted=!0)}}touchend(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){const t=!this.aborted&&this.centroid;if(this.reset(),t)return t}}}class Yn{constructor(t){this.singleTap=new Wn(t),this.numTaps=t.numTaps,this.reset()}reset(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()}touchstart(t,e,r){this.singleTap.touchstart(t,e,r)}touchmove(t,e,r){this.singleTap.touchmove(t,e,r)}touchend(t,e,r){const n=this.singleTap.touchend(t,e,r);if(n){const e=t.timeStamp-this.lastTime<500,r=!this.lastTap||this.lastTap.dist(n)<30;if(e&&r||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}}}class Xn{constructor(t){this._tr=new Hn(t),this._zoomIn=new Yn({numTouches:1,numTaps:2}),this._zoomOut=new Yn({numTouches:2,numTaps:1}),this.reset()}reset(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()}touchstart(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)}touchmove(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)}touchend(t,e,r){const n=this._zoomIn.touchend(t,e,r),i=this._zoomOut.touchend(t,e,r),a=this._tr;return n?(this._active=!0,t.preventDefault(),setTimeout((()=>this.reset()),0),{cameraAnimation:e=>e.easeTo({duration:300,zoom:a.zoom+1,around:a.unproject(n)},{originalEvent:t})}):i?(this._active=!0,t.preventDefault(),setTimeout((()=>this.reset()),0),{cameraAnimation:e=>e.easeTo({duration:300,zoom:a.zoom-1,around:a.unproject(i)},{originalEvent:t})}):void 0}touchcancel(){this.reset()}enable(){this._enabled=!0}disable(){this._enabled=!1,this.reset()}isEnabled(){return this._enabled}isActive(){return this._active}}class $n{constructor(t){this._enabled=!!t.enable,this._moveStateManager=t.moveStateManager,this._clickTolerance=t.clickTolerance||1,this._moveFunction=t.move,this._activateOnStart=!!t.activateOnStart,t.assignEvents(this),this.reset()}reset(t){this._active=!1,this._moved=!1,delete this._lastPoint,this._moveStateManager.endMove(t)}_move(...t){const e=this._moveFunction(...t);if(e.bearingDelta||e.pitchDelta||e.around||e.panDelta)return this._active=!0,e}dragStart(t,e){this.isEnabled()&&!this._lastPoint&&this._moveStateManager.isValidStartEvent(t)&&(this._moveStateManager.startMove(t),this._lastPoint=e.length?e[0]:e,this._activateOnStart&&this._lastPoint&&(this._active=!0))}dragMove(t,e){if(!this.isEnabled())return;const r=this._lastPoint;if(!r)return;if(t.preventDefault(),!this._moveStateManager.isValidMoveEvent(t))return void this.reset(t);const n=e.length?e[0]:e;return!this._moved&&n.dist(r)<this._clickTolerance?void 0:(this._moved=!0,this._lastPoint=n,this._move(r,n))}dragEnd(t){this.isEnabled()&&this._lastPoint&&this._moveStateManager.isValidEndEvent(t)&&(this._moved&&o.suppressClick(),this.reset(t))}enable(){this._enabled=!0}disable(){this._enabled=!1,this.reset()}isEnabled(){return this._enabled}isActive(){return this._active}getClickTolerance(){return this._clickTolerance}}const Jn={0:1,2:2};class Kn{constructor(t){this._correctEvent=t.checkCorrectEvent}startMove(t){const e=o.mouseButton(t);this._eventButton=e}endMove(t){delete this._eventButton}isValidStartEvent(t){return this._correctEvent(t)}isValidMoveEvent(t){return!function(t,e){const r=Jn[e];return void 0===t.buttons||(t.buttons&r)!==r}(t,this._eventButton)}isValidEndEvent(t){return o.mouseButton(t)===this._eventButton}}class Qn{constructor(){this._firstTouch=void 0}_isOneFingerTouch(t){return 1===t.targetTouches.length}_isSameTouchEvent(t){return t.targetTouches[0].identifier===this._firstTouch}startMove(t){const e=t.targetTouches[0].identifier;this._firstTouch=e}endMove(t){delete this._firstTouch}isValidStartEvent(t){return this._isOneFingerTouch(t)}isValidMoveEvent(t){return this._isOneFingerTouch(t)&&this._isSameTouchEvent(t)}isValidEndEvent(t){return this._isOneFingerTouch(t)&&this._isSameTouchEvent(t)}}const ti=t=>{t.mousedown=t.dragStart,t.mousemoveWindow=t.dragMove,t.mouseup=t.dragEnd,t.contextmenu=t=>{t.preventDefault()}},ei=({enable:t,clickTolerance:e,bearingDegreesPerPixelMoved:r=.8})=>{const n=new Kn({checkCorrectEvent:t=>0===o.mouseButton(t)&&t.ctrlKey||2===o.mouseButton(t)});return new $n({clickTolerance:e,move:(t,e)=>({bearingDelta:(e.x-t.x)*r}),moveStateManager:n,enable:t,assignEvents:ti})},ri=({enable:t,clickTolerance:e,pitchDegreesPerPixelMoved:r=-.5})=>{const n=new Kn({checkCorrectEvent:t=>0===o.mouseButton(t)&&t.ctrlKey||2===o.mouseButton(t)});return new $n({clickTolerance:e,move:(t,e)=>({pitchDelta:(e.y-t.y)*r}),moveStateManager:n,enable:t,assignEvents:ti})};class ni{constructor(t,e){this._clickTolerance=t.clickTolerance||1,this._map=e,this.reset()}reset(){this._active=!1,this._touches={},this._sum=new e.P(0,0)}_shouldBePrevented(t){return t<(this._map.cooperativeGestures.isEnabled()?2:1)}touchstart(t,e,r){return this._calculateTransform(t,e,r)}touchmove(t,e,r){if(this._active){if(!this._shouldBePrevented(r.length))return t.preventDefault(),this._calculateTransform(t,e,r);this._map.cooperativeGestures.notifyGestureBlocked(\"touch_pan\",t)}}touchend(t,e,r){this._calculateTransform(t,e,r),this._active&&this._shouldBePrevented(r.length)&&this.reset()}touchcancel(){this.reset()}_calculateTransform(t,r,n){n.length>0&&(this._active=!0);const i=Zn(n,r),a=new e.P(0,0),o=new e.P(0,0);let s=0;for(const t in i){const e=i[t],r=this._touches[t];r&&(a._add(e),o._add(e.sub(r)),s++,i[t]=e)}if(this._touches=i,this._shouldBePrevented(s)||!o.mag())return;const l=o.div(s);return this._sum._add(l),this._sum.mag()<this._clickTolerance?void 0:{around:a.div(s),panDelta:l}}enable(){this._enabled=!0}disable(){this._enabled=!1,this.reset()}isEnabled(){return this._enabled}isActive(){return this._active}}class ii{constructor(){this.reset()}reset(){this._active=!1,delete this._firstTwoTouches}touchstart(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))}touchmove(t,e,r){if(!this._firstTwoTouches)return;t.preventDefault();const[n,i]=this._firstTwoTouches,a=ai(r,e,n),o=ai(r,e,i);if(!a||!o)return;const s=this._aroundCenter?null:a.add(o).div(2);return this._move([a,o],s,t)}touchend(t,e,r){if(!this._firstTwoTouches)return;const[n,i]=this._firstTwoTouches,a=ai(r,e,n),s=ai(r,e,i);a&&s||(this._active&&o.suppressClick(),this.reset())}touchcancel(){this.reset()}enable(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around}disable(){this._enabled=!1,this.reset()}isEnabled(){return!!this._enabled}isActive(){return!!this._active}}function ai(t,e,r){for(let n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}function oi(t,e){return Math.log(t/e)/Math.LN2}class si extends ii{reset(){super.reset(),delete this._distance,delete this._startDistance}_start(t){this._startDistance=this._distance=t[0].dist(t[1])}_move(t,e){const r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs(oi(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:oi(this._distance,r),pinchAround:e}}}function li(t,e){return 180*t.angleWith(e)/Math.PI}class ci extends ii{reset(){super.reset(),delete this._minDiameter,delete this._startVector,delete this._vector}_start(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])}_move(t,e,r){const n=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:li(this._vector,n),pinchAround:e}}_isBelowThreshold(t){this._minDiameter=Math.min(this._minDiameter,t.mag());const e=25/(Math.PI*this._minDiameter)*360,r=li(t,this._startVector);return Math.abs(r)<e}}function ui(t){return Math.abs(t.y)>Math.abs(t.x)}class hi extends ii{constructor(t){super(),this._currentTouchCount=0,this._map=t}reset(){super.reset(),this._valid=void 0,delete this._firstMove,delete this._lastPoints}touchstart(t,e,r){super.touchstart(t,e,r),this._currentTouchCount=r.length}_start(t){this._lastPoints=t,ui(t[0].sub(t[1]))&&(this._valid=!1)}_move(t,e,r){if(this._map.cooperativeGestures.isEnabled()&&this._currentTouchCount<3)return;const n=t[0].sub(this._lastPoints[0]),i=t[1].sub(this._lastPoints[1]);return this._valid=this.gestureBeginsVertically(n,i,r.timeStamp),this._valid?(this._lastPoints=t,this._active=!0,{pitchDelta:(n.y+i.y)/2*-.5}):void 0}gestureBeginsVertically(t,e,r){if(void 0!==this._valid)return this._valid;const n=t.mag()>=2,i=e.mag()>=2;if(!n&&!i)return;if(!n||!i)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;const a=t.y>0==e.y>0;return ui(t)&&ui(e)&&a}}const fi={panStep:100,bearingStep:15,pitchStep:10};class pi{constructor(t){this._tr=new Hn(t);const e=fi;this._panStep=e.panStep,this._bearingStep=e.bearingStep,this._pitchStep=e.pitchStep,this._rotationDisabled=!1}reset(){this._active=!1}keydown(t){if(t.altKey||t.ctrlKey||t.metaKey)return;let e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(t.preventDefault(),a=1);break;default:return}return this._rotationDisabled&&(r=0,n=0),{cameraAnimation:o=>{const s=this._tr;o.easeTo({duration:300,easeId:\"keyboardHandler\",easing:di,zoom:e?Math.round(s.zoom)+e*(t.shiftKey?2:1):s.zoom,bearing:s.bearing+r*this._bearingStep,pitch:s.pitch+n*this._pitchStep,offset:[-i*this._panStep,-a*this._panStep],center:s.center},{originalEvent:t})}}}enable(){this._enabled=!0}disable(){this._enabled=!1,this.reset()}isEnabled(){return this._enabled}isActive(){return this._active}disableRotation(){this._rotationDisabled=!0}enableRotation(){this._rotationDisabled=!1}}function di(t){return t*(2-t)}const mi=4.000244140625;class gi{constructor(t,e){this._onTimeout=t=>{this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},this._map=t,this._tr=new Hn(t),this._triggerRenderFrame=e,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=.0022222222222222222}setZoomRate(t){this._defaultZoomRate=t}setWheelZoomRate(t){this._wheelZoomRate=t}isEnabled(){return!!this._enabled}isActive(){return!!this._active||void 0!==this._finishTimeout}isZooming(){return!!this._zooming}enable(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)}disable(){this.isEnabled()&&(this._enabled=!1)}_shouldBePrevented(t){return!!this._map.cooperativeGestures.isEnabled()&&!(t.ctrlKey||this._map.cooperativeGestures.isBypassed(t))}wheel(t){if(!this.isEnabled())return;if(this._shouldBePrevented(t))return void this._map.cooperativeGestures.notifyGestureBlocked(\"wheel_zoom\",t);let e=t.deltaMode===WheelEvent.DOM_DELTA_LINE?40*t.deltaY:t.deltaY;const r=a.now(),n=r-(this._lastWheelEventTime||0);this._lastWheelEventTime=r,0!==e&&e%mi==0?this._type=\"wheel\":0!==e&&Math.abs(e)<4?this._type=\"trackpad\":n>400?(this._type=null,this._lastValue=e,this._timeout=setTimeout(this._onTimeout,40,t)):this._type||(this._type=Math.abs(n*e)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,e+=this._lastValue)),t.shiftKey&&e&&(e/=4),this._type&&(this._lastWheelEvent=t,this._delta-=e,this._active||this._start(t)),t.preventDefault()}_start(t){if(!this._delta)return;this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);const r=o.mousePos(this._map.getCanvas(),t),n=this._tr;r.y>n.transform.height/2-n.transform.getHorizon()?this._around=e.N.convert(this._aroundCenter?n.center:n.unproject(r)):this._around=e.N.convert(n.center),this._aroundPoint=n.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._triggerRenderFrame())}renderFrame(){if(!this._frameId)return;if(this._frameId=null,!this.isActive())return;const t=this._tr.transform;if(0!==this._delta){const e=\"wheel\"===this._type&&Math.abs(this._delta)>mi?this._wheelZoomRate:this._defaultZoomRate;let r=2/(1+Math.exp(-Math.abs(this._delta*e)));this._delta<0&&0!==r&&(r=1/r);const n=\"number\"==typeof this._targetZoom?t.zoomScale(this._targetZoom):t.scale;this._targetZoom=Math.min(t.maxZoom,Math.max(t.minZoom,t.scaleZoom(n*r))),\"wheel\"===this._type&&(this._startZoom=t.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}const r=\"number\"==typeof this._targetZoom?this._targetZoom:t.zoom,n=this._startZoom,i=this._easing;let o,s=!1;const l=a.now()-this._lastWheelEventTime;if(\"wheel\"===this._type&&n&&i&&l){const t=Math.min(l/200,1),a=i(t);o=e.z.number(n,r,a),t<1?this._frameId||(this._frameId=!0):s=!0}else o=r,s=!0;return this._active=!0,s&&(this._active=!1,this._finishTimeout=setTimeout((()=>{this._zooming=!1,this._triggerRenderFrame(),delete this._targetZoom,delete this._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!s,zoomDelta:o-t.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}_smoothOutEasing(t){let r=e.b9;if(this._prevEase){const t=this._prevEase,n=(a.now()-t.start)/t.duration,i=t.easing(n+.01)-t.easing(n),o=.27/Math.sqrt(i*i+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=e.b8(o,s,.25,1)}return this._prevEase={start:a.now(),duration:t,easing:r},r}reset(){this._active=!1,this._zooming=!1,delete this._targetZoom,this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout)}}class yi{constructor(t,e){this._clickZoom=t,this._tapZoom=e}enable(){this._clickZoom.enable(),this._tapZoom.enable()}disable(){this._clickZoom.disable(),this._tapZoom.disable()}isEnabled(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()}isActive(){return this._clickZoom.isActive()||this._tapZoom.isActive()}}class vi{constructor(t){this._tr=new Hn(t),this.reset()}reset(){this._active=!1}dblclick(t,e){return t.preventDefault(),{cameraAnimation:r=>{r.easeTo({duration:300,zoom:this._tr.zoom+(t.shiftKey?-1:1),around:this._tr.unproject(e)},{originalEvent:t})}}}enable(){this._enabled=!0}disable(){this._enabled=!1,this.reset()}isEnabled(){return this._enabled}isActive(){return this._active}}class xi{constructor(){this._tap=new Yn({numTouches:1,numTaps:1}),this.reset()}reset(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,delete this._tapPoint,this._tap.reset()}touchstart(t,e,r){if(!this._swipePoint)if(this._tapTime){const n=e[0],i=t.timeStamp-this._tapTime<500,a=this._tapPoint.dist(n)<30;i&&a?r.length>0&&(this._swipePoint=n,this._swipeTouch=r[0].identifier):this.reset()}else this._tap.touchstart(t,e,r)}touchmove(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;const n=e[0],i=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:i/128}}}else this._tap.touchmove(t,e,r)}touchend(t,e,r){if(this._tapTime)this._swipePoint&&0===r.length&&this.reset();else{const n=this._tap.touchend(t,e,r);n&&(this._tapTime=t.timeStamp,this._tapPoint=n)}}touchcancel(){this.reset()}enable(){this._enabled=!0}disable(){this._enabled=!1,this.reset()}isEnabled(){return this._enabled}isActive(){return this._active}}class _i{constructor(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r}enable(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"maplibregl-touch-drag-pan\")}disable(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"maplibregl-touch-drag-pan\")}isEnabled(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()}isActive(){return this._mousePan.isActive()||this._touchPan.isActive()}}class bi{constructor(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r}enable(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()}disable(){this._mouseRotate.disable(),this._mousePitch.disable()}isEnabled(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())}isActive(){return this._mouseRotate.isActive()||this._mousePitch.isActive()}}class wi{constructor(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0}enable(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"maplibregl-touch-zoom-rotate\")}disable(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"maplibregl-touch-zoom-rotate\")}isEnabled(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()}isActive(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()}disableRotation(){this._rotationDisabled=!0,this._touchRotate.disable()}enableRotation(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()}}class Ti{constructor(t,e){this._bypassKey=-1!==navigator.userAgent.indexOf(\"Mac\")?\"metaKey\":\"ctrlKey\",this._map=t,this._options=e,this._enabled=!1}isActive(){return!1}reset(){}_setupUI(){if(this._container)return;const t=this._map.getCanvasContainer();t.classList.add(\"maplibregl-cooperative-gestures\"),this._container=o.create(\"div\",\"maplibregl-cooperative-gesture-screen\",t);let e=this._map._getUIString(\"CooperativeGesturesHandler.WindowsHelpText\");\"metaKey\"===this._bypassKey&&(e=this._map._getUIString(\"CooperativeGesturesHandler.MacHelpText\"));const r=this._map._getUIString(\"CooperativeGesturesHandler.MobileHelpText\"),n=document.createElement(\"div\");n.className=\"maplibregl-desktop-message\",n.textContent=e,this._container.appendChild(n);const i=document.createElement(\"div\");i.className=\"maplibregl-mobile-message\",i.textContent=r,this._container.appendChild(i),this._container.setAttribute(\"aria-hidden\",\"true\")}_destroyUI(){this._container&&(o.remove(this._container),this._map.getCanvasContainer().classList.remove(\"maplibregl-cooperative-gestures\")),delete this._container}enable(){this._setupUI(),this._enabled=!0}disable(){this._enabled=!1,this._destroyUI()}isEnabled(){return this._enabled}isBypassed(t){return t[this._bypassKey]}notifyGestureBlocked(t,r){this._enabled&&(this._map.fire(new e.k(\"cooperativegestureprevented\",{gestureType:t,originalEvent:r})),this._container.classList.add(\"maplibregl-show\"),setTimeout((()=>{this._container.classList.remove(\"maplibregl-show\")}),100))}}const ki=t=>t.zoom||t.drag||t.pitch||t.rotate;class Ai extends e.k{}function Mi(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}class Si{constructor(t,e){this.handleWindowEvent=t=>{this.handleEvent(t,`${t.type}Window`)},this.handleEvent=(t,e)=>{if(\"blur\"===t.type)return void this.stop(!0);this._updatingCamera=!0;const r=\"renderFrame\"===t.type?void 0:t,n={needsRenderFrame:!1},i={},a={},s=t.touches,l=s?this._getMapTouches(s):void 0,c=l?o.touchPos(this._map.getCanvas(),l):o.mousePos(this._map.getCanvas(),t);for(const{handlerName:o,handler:s,allowed:u}of this._handlers){if(!s.isEnabled())continue;let h;this._blockedByActive(a,u,o)?s.reset():s[e||t.type]&&(h=s[e||t.type](t,c,l),this.mergeHandlerResult(n,i,h,o,r),h&&h.needsRenderFrame&&this._triggerRenderFrame()),(h||s.isActive())&&(a[o]=s)}const u={};for(const t in this._previousActiveHandlers)a[t]||(u[t]=r);this._previousActiveHandlers=a,(Object.keys(u).length||Mi(n))&&(this._changes.push([n,i,u]),this._triggerRenderFrame()),(Object.keys(a).length||Mi(n))&&this._map._stop(!0),this._updatingCamera=!1;const{cameraAnimation:h}=n;h&&(this._inertia.clear(),this._fireEvents({},{},!0),this._changes=[],h(this._map))},this._map=t,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new Rn(t),this._bearingSnap=e.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(e);const r=this._el;this._listeners=[[r,\"touchstart\",{passive:!0}],[r,\"touchmove\",{passive:!1}],[r,\"touchend\",void 0],[r,\"touchcancel\",void 0],[r,\"mousedown\",void 0],[r,\"mousemove\",void 0],[r,\"mouseup\",void 0],[document,\"mousemove\",{capture:!0}],[document,\"mouseup\",void 0],[r,\"mouseover\",void 0],[r,\"mouseout\",void 0],[r,\"dblclick\",void 0],[r,\"click\",void 0],[r,\"keydown\",{capture:!1}],[r,\"keyup\",void 0],[r,\"wheel\",{passive:!1}],[r,\"contextmenu\",void 0],[window,\"blur\",void 0]];for(const[t,e,r]of this._listeners)o.addEventListener(t,e,t===document?this.handleWindowEvent:this.handleEvent,r)}destroy(){for(const[t,e,r]of this._listeners)o.removeEventListener(t,e,t===document?this.handleWindowEvent:this.handleEvent,r)}_addDefaultHandlers(t){const e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Vn(e,t));const n=e.boxZoom=new Gn(e,t);this._add(\"boxZoom\",n),t.interactive&&t.boxZoom&&n.enable();const i=e.cooperativeGestures=new Ti(e,t.cooperativeGestures);this._add(\"cooperativeGestures\",i),t.cooperativeGestures&&i.enable();const a=new Xn(e),s=new vi(e);e.doubleClickZoom=new yi(s,a),this._add(\"tapZoom\",a),this._add(\"clickZoom\",s),t.interactive&&t.doubleClickZoom&&e.doubleClickZoom.enable();const l=new xi;this._add(\"tapDragZoom\",l);const c=e.touchPitch=new hi(e);this._add(\"touchPitch\",c),t.interactive&&t.touchPitch&&e.touchPitch.enable(t.touchPitch);const u=ei(t),h=ri(t);e.dragRotate=new bi(t,u,h),this._add(\"mouseRotate\",u,[\"mousePitch\"]),this._add(\"mousePitch\",h,[\"mouseRotate\"]),t.interactive&&t.dragRotate&&e.dragRotate.enable();const f=(({enable:t,clickTolerance:e})=>{const r=new Kn({checkCorrectEvent:t=>0===o.mouseButton(t)&&!t.ctrlKey});return new $n({clickTolerance:e,move:(t,e)=>({around:e,panDelta:e.sub(t)}),activateOnStart:!0,moveStateManager:r,enable:t,assignEvents:ti})})(t),p=new ni(t,e);e.dragPan=new _i(r,f,p),this._add(\"mousePan\",f),this._add(\"touchPan\",p,[\"touchZoom\",\"touchRotate\"]),t.interactive&&t.dragPan&&e.dragPan.enable(t.dragPan);const d=new ci,m=new si;e.touchZoomRotate=new wi(r,m,d,l),this._add(\"touchRotate\",d,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",m,[\"touchPan\",\"touchRotate\"]),t.interactive&&t.touchZoomRotate&&e.touchZoomRotate.enable(t.touchZoomRotate);const g=e.scrollZoom=new gi(e,(()=>this._triggerRenderFrame()));this._add(\"scrollZoom\",g,[\"mousePan\"]),t.interactive&&t.scrollZoom&&e.scrollZoom.enable(t.scrollZoom);const y=e.keyboard=new pi(e);this._add(\"keyboard\",y),t.interactive&&t.keyboard&&e.keyboard.enable(),this._add(\"blockableMapEvent\",new qn(e))}_add(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e}stop(t){if(!this._updatingCamera){for(const{handler:t}of this._handlers)t.reset();this._inertia.clear(),this._fireEvents({},{},t),this._changes=[]}}isActive(){for(const{handler:t}of this._handlers)if(t.isActive())return!0;return!1}isZooming(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()}isRotating(){return!!this._eventsInProgress.rotate}isMoving(){return Boolean(ki(this._eventsInProgress))||this.isZooming()}_blockedByActive(t,e,r){for(const n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1}_getMapTouches(t){const e=[];for(const r of t){const t=r.target;this._el.contains(t)&&e.push(r)}return e}mergeHandlerResult(t,r,n,i,a){if(!n)return;e.e(t,n);const o={handlerName:i,originalEvent:n.originalEvent||a};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}_applyChanges(){const t={},r={},n={};for(const[i,a,o]of this._changes)i.panDelta&&(t.panDelta=(t.panDelta||new e.P(0,0))._add(i.panDelta)),i.zoomDelta&&(t.zoomDelta=(t.zoomDelta||0)+i.zoomDelta),i.bearingDelta&&(t.bearingDelta=(t.bearingDelta||0)+i.bearingDelta),i.pitchDelta&&(t.pitchDelta=(t.pitchDelta||0)+i.pitchDelta),void 0!==i.around&&(t.around=i.around),void 0!==i.pinchAround&&(t.pinchAround=i.pinchAround),i.noInertia&&(t.noInertia=i.noInertia),e.e(r,a),e.e(n,o);this._updateMapTransform(t,r,n),this._changes=[]}_updateMapTransform(t,e,r){const n=this._map,i=n._getTransformForUpdate(),a=n.terrain;if(!(Mi(t)||a&&this._terrainMovement))return this._fireEvents(e,r,!0);let{panDelta:o,zoomDelta:s,bearingDelta:l,pitchDelta:c,around:u,pinchAround:h}=t;void 0!==h&&(u=h),n._stop(!0),u=u||n.transform.centerPoint;const f=i.pointLocation(o?u.sub(o):u);l&&(i.bearing+=l),c&&(i.pitch+=c),s&&(i.zoom+=s),a?this._terrainMovement||!e.drag&&!e.zoom?e.drag&&this._terrainMovement?i.center=i.pointLocation(i.centerPoint.sub(o)):i.setLocationAtPoint(f,u):(this._terrainMovement=!0,this._map._elevationFreeze=!0,i.setLocationAtPoint(f,u)):i.setLocationAtPoint(f,u),n._applyUpdatedTransform(i),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r,!0)}_fireEvents(t,r,n){const i=ki(this._eventsInProgress),o=ki(t),s={};for(const e in t){const{originalEvent:r}=t[e];this._eventsInProgress[e]||(s[`${e}start`]=r),this._eventsInProgress[e]=t[e]}!i&&o&&this._fireEvent(\"movestart\",o.originalEvent);for(const t in s)this._fireEvent(t,s[t]);o&&this._fireEvent(\"move\",o.originalEvent);for(const e in t){const{originalEvent:r}=t[e];this._fireEvent(e,r)}const l={};let c;for(const t in this._eventsInProgress){const{handlerName:e,originalEvent:n}=this._eventsInProgress[t];this._handlersById[e].isActive()||(delete this._eventsInProgress[t],c=r[e]||n,l[`${t}end`]=c)}for(const t in l)this._fireEvent(t,l[t]);const u=ki(this._eventsInProgress),h=(i||o)&&!u;if(h&&this._terrainMovement){this._map._elevationFreeze=!1,this._terrainMovement=!1;const t=this._map._getTransformForUpdate();t.recalculateZoom(this._map.terrain),this._map._applyUpdatedTransform(t)}if(n&&h){this._updatingCamera=!0;const t=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),r=t=>0!==t&&-this._bearingSnap<t&&t<this._bearingSnap;!t||!t.essential&&a.prefersReducedMotion?(this._map.fire(new e.k(\"moveend\",{originalEvent:c})),r(this._map.getBearing())&&this._map.resetNorth()):(r(t.bearing||this._map.getBearing())&&(t.bearing=0),t.freezeElevation=!0,this._map.easeTo(t,{originalEvent:c})),this._updatingCamera=!1}}_fireEvent(t,r){this._map.fire(new e.k(t,r?{originalEvent:r}:{}))}_requestFrame(){return this._map.triggerRepaint(),this._map._renderTaskQueue.add((t=>{delete this._frameId,this.handleEvent(new Ai(\"renderFrame\",{timeStamp:t})),this._applyChanges()}))}_triggerRenderFrame(){void 0===this._frameId&&(this._frameId=this._requestFrame())}}class Ei extends e.E{constructor(t,e){super(),this._renderFrameCallback=()=>{const t=Math.min((a.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(t)),t<1&&this._easeFrameId?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},this._moving=!1,this._zooming=!1,this.transform=t,this._bearingSnap=e.bearingSnap,this.on(\"moveend\",(()=>{delete this._requestedCameraState}))}getCenter(){return new e.N(this.transform.center.lng,this.transform.center.lat)}setCenter(t,e){return this.jumpTo({center:t},e)}panBy(t,r,n){return t=e.P.convert(t).mult(-1),this.panTo(this.transform.center,e.e({offset:t},r),n)}panTo(t,r,n){return this.easeTo(e.e({center:t},r),n)}getZoom(){return this.transform.zoom}setZoom(t,e){return this.jumpTo({zoom:t},e),this}zoomTo(t,r,n){return this.easeTo(e.e({zoom:t},r),n)}zoomIn(t,e){return this.zoomTo(this.getZoom()+1,t,e),this}zoomOut(t,e){return this.zoomTo(this.getZoom()-1,t,e),this}getBearing(){return this.transform.bearing}setBearing(t,e){return this.jumpTo({bearing:t},e),this}getPadding(){return this.transform.padding}setPadding(t,e){return this.jumpTo({padding:t},e),this}rotateTo(t,r,n){return this.easeTo(e.e({bearing:t},r),n)}resetNorth(t,r){return this.rotateTo(0,e.e({duration:1e3},t),r),this}resetNorthPitch(t,r){return this.easeTo(e.e({bearing:0,pitch:0,duration:1e3},t),r),this}snapToNorth(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this}getPitch(){return this.transform.pitch}setPitch(t,e){return this.jumpTo({pitch:t},e),this}cameraForBounds(t,e){t=X.convert(t);const r=e&&e.bearing||0;return this._cameraForBoxAndBearing(t.getNorthWest(),t.getSouthEast(),r,e)}_cameraForBoxAndBearing(t,r,n,i){const a={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(i=e.e({padding:a,offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){const t=i.padding;i.padding={top:t,bottom:t,right:t,left:t}}i.padding=e.e(a,i.padding);const o=this.transform,s=o.padding,l=new X(t,r),c=o.project(l.getNorthWest()),u=o.project(l.getNorthEast()),h=o.project(l.getSouthEast()),f=o.project(l.getSouthWest()),p=e.ba(-n),d=c.rotate(p),m=u.rotate(p),g=h.rotate(p),y=f.rotate(p),v=new e.P(Math.max(d.x,m.x,y.x,g.x),Math.max(d.y,m.y,y.y,g.y)),x=new e.P(Math.min(d.x,m.x,y.x,g.x),Math.min(d.y,m.y,y.y,g.y)),_=v.sub(x),b=(o.width-(s.left+s.right+i.padding.left+i.padding.right))/_.x,w=(o.height-(s.top+s.bottom+i.padding.top+i.padding.bottom))/_.y;if(w<0||b<0)return void e.w(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\");const T=Math.min(o.scaleZoom(o.scale*Math.min(b,w)),i.maxZoom),k=e.P.convert(i.offset),A=(i.padding.left-i.padding.right)/2,M=(i.padding.top-i.padding.bottom)/2,S=new e.P(A,M).rotate(e.ba(n)),E=k.add(S).mult(o.scale/o.zoomScale(T));return{center:o.unproject(c.add(h).div(2).sub(E)),zoom:T,bearing:n}}fitBounds(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)}fitScreenCoordinates(t,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(e.P.convert(t)),this.transform.pointLocation(e.P.convert(r)),n,i),i,a)}_fitInternal(t,r,n){return t?(delete(r=e.e(t,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this}jumpTo(t,r){this.stop();const n=this._getTransformForUpdate();let i=!1,a=!1,o=!1;return\"zoom\"in t&&n.zoom!==+t.zoom&&(i=!0,n.zoom=+t.zoom),void 0!==t.center&&(n.center=e.N.convert(t.center)),\"bearing\"in t&&n.bearing!==+t.bearing&&(a=!0,n.bearing=+t.bearing),\"pitch\"in t&&n.pitch!==+t.pitch&&(o=!0,n.pitch=+t.pitch),null==t.padding||n.isPaddingEqual(t.padding)||(n.padding=t.padding),this._applyUpdatedTransform(n),this.fire(new e.k(\"movestart\",r)).fire(new e.k(\"move\",r)),i&&this.fire(new e.k(\"zoomstart\",r)).fire(new e.k(\"zoom\",r)).fire(new e.k(\"zoomend\",r)),a&&this.fire(new e.k(\"rotatestart\",r)).fire(new e.k(\"rotate\",r)).fire(new e.k(\"rotateend\",r)),o&&this.fire(new e.k(\"pitchstart\",r)).fire(new e.k(\"pitch\",r)).fire(new e.k(\"pitchend\",r)),this.fire(new e.k(\"moveend\",r))}calculateCameraOptionsFromTo(t,r,n,i=0){const a=e.Z.fromLngLat(t,r),o=e.Z.fromLngLat(n,i),s=o.x-a.x,l=o.y-a.y,c=o.z-a.z,u=Math.hypot(s,l,c);if(0===u)throw new Error(\"Can't calculate camera options with same From and To\");const h=Math.hypot(s,l),f=this.transform.scaleZoom(this.transform.cameraToCenterDistance/u/this.transform.tileSize),p=180*Math.atan2(s,-l)/Math.PI;let d=180*Math.acos(h/u)/Math.PI;return d=c<0?90-d:90+d,{center:o.toLngLat(),zoom:f,pitch:d,bearing:p}}easeTo(t,r){var n;this._stop(!1,t.easeId),(!1===(t=e.e({offset:[0,0],duration:500,easing:e.b9},t)).animate||!t.essential&&a.prefersReducedMotion)&&(t.duration=0);const i=this._getTransformForUpdate(),o=i.zoom,s=i.bearing,l=i.pitch,c=i.padding,u=\"bearing\"in t?this._normalizeBearing(t.bearing,s):s,h=\"pitch\"in t?+t.pitch:l,f=\"padding\"in t?t.padding:i.padding,p=e.P.convert(t.offset);let d=i.centerPoint.add(p);const m=i.pointLocation(d),{center:g,zoom:y}=i.getConstrained(e.N.convert(t.center||m),null!==(n=t.zoom)&&void 0!==n?n:o);this._normalizeCenter(g,i);const v=i.project(m),x=i.project(g).sub(v),_=i.zoomScale(y-o);let b,w;t.around&&(b=e.N.convert(t.around),w=i.locationPoint(b));const T={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||y!==o,this._rotating=this._rotating||s!==u,this._pitching=this._pitching||h!==l,this._padding=!i.isPaddingEqual(f),this._easeId=t.easeId,this._prepareEase(r,t.noMoveStart,T),this.terrain&&this._prepareElevation(g),this._ease((n=>{if(this._zooming&&(i.zoom=e.z.number(o,y,n)),this._rotating&&(i.bearing=e.z.number(s,u,n)),this._pitching&&(i.pitch=e.z.number(l,h,n)),this._padding&&(i.interpolatePadding(c,f,n),d=i.centerPoint.add(p)),this.terrain&&!t.freezeElevation&&this._updateElevation(n),b)i.setLocationAtPoint(b,w);else{const t=i.zoomScale(i.zoom-o),e=y>o?Math.min(2,_):Math.max(.5,_),r=Math.pow(e,1-n),a=i.unproject(v.add(x.mult(n*r)).mult(t));i.setLocationAtPoint(i.renderWorldCopies?a.wrap():a,d)}this._applyUpdatedTransform(i),this._fireMoveEvents(r)}),(e=>{this.terrain&&t.freezeElevation&&this._finalizeElevation(),this._afterEase(r,e)}),t),this}_prepareEase(t,r,n={}){this._moving=!0,r||n.moving||this.fire(new e.k(\"movestart\",t)),this._zooming&&!n.zooming&&this.fire(new e.k(\"zoomstart\",t)),this._rotating&&!n.rotating&&this.fire(new e.k(\"rotatestart\",t)),this._pitching&&!n.pitching&&this.fire(new e.k(\"pitchstart\",t))}_prepareElevation(t){this._elevationCenter=t,this._elevationStart=this.transform.elevation,this._elevationTarget=this.terrain.getElevationForLngLatZoom(t,this.transform.tileZoom),this._elevationFreeze=!0}_updateElevation(t){this.transform.minElevationForCurrentTile=this.terrain.getMinTileElevationForLngLatZoom(this._elevationCenter,this.transform.tileZoom);const r=this.terrain.getElevationForLngLatZoom(this._elevationCenter,this.transform.tileZoom);if(t<1&&r!==this._elevationTarget){const e=this._elevationTarget-this._elevationStart,n=(r-(e*t+this._elevationStart))/(1-t);this._elevationStart+=t*(e-n),this._elevationTarget=r}this.transform.elevation=e.z.number(this._elevationStart,this._elevationTarget,t)}_finalizeElevation(){this._elevationFreeze=!1,this.transform.recalculateZoom(this.terrain)}_getTransformForUpdate(){return this.transformCameraUpdate||this.terrain?(this._requestedCameraState||(this._requestedCameraState=this.transform.clone()),this._requestedCameraState):this.transform}_elevateCameraIfInsideTerrain(t){const e=t.getCameraPosition(),r=this.terrain.getElevationForLngLatZoom(e.lngLat,t.zoom);if(e.altitude<r){const n=this.calculateCameraOptionsFromTo(e.lngLat,r,t.center,t.elevation);return{pitch:n.pitch,zoom:n.zoom}}return{}}_applyUpdatedTransform(t){const e=[];if(this.terrain&&e.push((t=>this._elevateCameraIfInsideTerrain(t))),this.transformCameraUpdate&&e.push((t=>this.transformCameraUpdate(t))),!e.length)return;const r=t.clone();for(const t of e){const e=r.clone(),{center:n,zoom:i,pitch:a,bearing:o,elevation:s}=t(e);n&&(e.center=n),void 0!==i&&(e.zoom=i),void 0!==a&&(e.pitch=a),void 0!==o&&(e.bearing=o),void 0!==s&&(e.elevation=s),r.apply(e)}this.transform.apply(r)}_fireMoveEvents(t){this.fire(new e.k(\"move\",t)),this._zooming&&this.fire(new e.k(\"zoom\",t)),this._rotating&&this.fire(new e.k(\"rotate\",t)),this._pitching&&this.fire(new e.k(\"pitch\",t))}_afterEase(t,r){if(this._easeId&&r&&this._easeId===r)return;delete this._easeId;const n=this._zooming,i=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new e.k(\"zoomend\",t)),i&&this.fire(new e.k(\"rotateend\",t)),a&&this.fire(new e.k(\"pitchend\",t)),this.fire(new e.k(\"moveend\",t))}flyTo(t,r){var n;if(!t.essential&&a.prefersReducedMotion){const n=e.M(t,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(n,r)}this.stop(),t=e.e({offset:[0,0],speed:1.2,curve:1.42,easing:e.b9},t);const i=this._getTransformForUpdate(),o=i.zoom,s=i.bearing,l=i.pitch,c=i.padding,u=\"bearing\"in t?this._normalizeBearing(t.bearing,s):s,h=\"pitch\"in t?+t.pitch:l,f=\"padding\"in t?t.padding:i.padding,p=e.P.convert(t.offset);let d=i.centerPoint.add(p);const m=i.pointLocation(d),{center:g,zoom:y}=i.getConstrained(e.N.convert(t.center||m),null!==(n=t.zoom)&&void 0!==n?n:o);this._normalizeCenter(g,i);const v=i.zoomScale(y-o),x=i.project(m),_=i.project(g).sub(x);let b=t.curve;const w=Math.max(i.width,i.height),T=w/v,k=_.mag();if(\"minZoom\"in t){const r=e.ad(Math.min(t.minZoom,o,y),i.minZoom,i.maxZoom),n=w/i.zoomScale(r-o);b=Math.sqrt(n/k*2)}const A=b*b;function M(t){const e=(T*T-w*w+(t?-1:1)*A*A*k*k)/(2*(t?T:w)*A*k);return Math.log(Math.sqrt(e*e+1)-e)}function S(t){return(Math.exp(t)-Math.exp(-t))/2}function E(t){return(Math.exp(t)+Math.exp(-t))/2}const C=M(!1);let L=function(t){return E(C)/E(C+b*t)},I=function(t){return w*((E(C)*(S(e=C+b*t)/E(e))-S(C))/A)/k;var e},P=(M(!0)-C)/b;if(Math.abs(k)<1e-6||!isFinite(P)){if(Math.abs(w-T)<1e-6)return this.easeTo(t,r);const e=T<w?-1:1;P=Math.abs(Math.log(T/w))/b,I=()=>0,L=t=>Math.exp(e*b*t)}if(\"duration\"in t)t.duration=+t.duration;else{const e=\"screenSpeed\"in t?+t.screenSpeed/b:+t.speed;t.duration=1e3*P/e}return t.maxDuration&&t.duration>t.maxDuration&&(t.duration=0),this._zooming=!0,this._rotating=s!==u,this._pitching=h!==l,this._padding=!i.isPaddingEqual(f),this._prepareEase(r,!1),this.terrain&&this._prepareElevation(g),this._ease((n=>{const a=n*P,m=1/L(a);i.zoom=1===n?y:o+i.scaleZoom(m),this._rotating&&(i.bearing=e.z.number(s,u,n)),this._pitching&&(i.pitch=e.z.number(l,h,n)),this._padding&&(i.interpolatePadding(c,f,n),d=i.centerPoint.add(p)),this.terrain&&!t.freezeElevation&&this._updateElevation(n);const v=1===n?g:i.unproject(x.add(_.mult(I(a))).mult(m));i.setLocationAtPoint(i.renderWorldCopies?v.wrap():v,d),this._applyUpdatedTransform(i),this._fireMoveEvents(r)}),(()=>{this.terrain&&t.freezeElevation&&this._finalizeElevation(),this._afterEase(r)}),t),this}isEasing(){return!!this._easeFrameId}stop(){return this._stop()}_stop(t,e){var r;if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){const t=this._onEaseEnd;delete this._onEaseEnd,t.call(this,e)}return t||null===(r=this.handlers)||void 0===r||r.stop(!1),this}_ease(t,e,r){!1===r.animate||0===r.duration?(t(1),e()):(this._easeStart=a.now(),this._easeOptions=r,this._onEaseFrame=t,this._onEaseEnd=e,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))}_normalizeBearing(t,r){t=e.b3(t,-180,180);const n=Math.abs(t-r);return Math.abs(t-360-r)<n&&(t-=360),Math.abs(t+360-r)<n&&(t+=360),t}_normalizeCenter(t,e){if(!e.renderWorldCopies||e.lngRange)return;const r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}queryTerrainElevation(t){return this.terrain?this.terrain.getElevationForLngLatZoom(e.N.convert(t),this.transform.tileZoom)-this.transform.elevation:null}}const Ci={compact:!0,customAttribution:'<a href=\"https://maplibre.org/\" target=\"_blank\">MapLibre</a>'};class Li{constructor(t=Ci){this._toggleAttribution=()=>{this._container.classList.contains(\"maplibregl-compact\")&&(this._container.classList.contains(\"maplibregl-compact-show\")?(this._container.setAttribute(\"open\",\"\"),this._container.classList.remove(\"maplibregl-compact-show\")):(this._container.classList.add(\"maplibregl-compact-show\"),this._container.removeAttribute(\"open\")))},this._updateData=t=>{!t||\"metadata\"!==t.sourceDataType&&\"visibility\"!==t.sourceDataType&&\"style\"!==t.dataType&&\"terrain\"!==t.type||this._updateAttributions()},this._updateCompact=()=>{this._map.getCanvasContainer().offsetWidth<=640||this._compact?!1===this._compact?this._container.setAttribute(\"open\",\"\"):this._container.classList.contains(\"maplibregl-compact\")||this._container.classList.contains(\"maplibregl-attrib-empty\")||(this._container.setAttribute(\"open\",\"\"),this._container.classList.add(\"maplibregl-compact\",\"maplibregl-compact-show\")):(this._container.setAttribute(\"open\",\"\"),this._container.classList.contains(\"maplibregl-compact\")&&this._container.classList.remove(\"maplibregl-compact\",\"maplibregl-compact-show\"))},this._updateCompactMinimize=()=>{this._container.classList.contains(\"maplibregl-compact\")&&this._container.classList.contains(\"maplibregl-compact-show\")&&this._container.classList.remove(\"maplibregl-compact-show\")},this.options=t}getDefaultPosition(){return\"bottom-right\"}onAdd(t){return this._map=t,this._compact=this.options.compact,this._container=o.create(\"details\",\"maplibregl-ctrl maplibregl-ctrl-attrib\"),this._compactButton=o.create(\"summary\",\"maplibregl-ctrl-attrib-button\",this._container),this._compactButton.addEventListener(\"click\",this._toggleAttribution),this._setElementTitle(this._compactButton,\"ToggleAttribution\"),this._innerContainer=o.create(\"div\",\"maplibregl-ctrl-attrib-inner\",this._container),this._updateAttributions(),this._updateCompact(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"terrain\",this._updateData),this._map.on(\"resize\",this._updateCompact),this._map.on(\"drag\",this._updateCompactMinimize),this._container}onRemove(){o.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"terrain\",this._updateData),this._map.off(\"resize\",this._updateCompact),this._map.off(\"drag\",this._updateCompactMinimize),this._map=void 0,this._compact=void 0,this._attribHTML=void 0}_setElementTitle(t,e){const r=this._map._getUIString(`AttributionControl.${e}`);t.title=r,t.setAttribute(\"aria-label\",r)}_updateAttributions(){if(!this._map.style)return;let t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((t=>\"string\"!=typeof t?\"\":t))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){const t=this._map.style.stylesheet;this.styleOwner=t.owner,this.styleId=t.id}const e=this._map.style.sourceCaches;for(const r in e){const n=e[r];if(n.used||n.usedForTerrain){const e=n.getSource();e.attribution&&t.indexOf(e.attribution)<0&&t.push(e.attribution)}}t=t.filter((t=>String(t).trim())),t.sort(((t,e)=>t.length-e.length)),t=t.filter(((e,r)=>{for(let n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}));const r=t.join(\" | \");r!==this._attribHTML&&(this._attribHTML=r,t.length?(this._innerContainer.innerHTML=r,this._container.classList.remove(\"maplibregl-attrib-empty\")):this._container.classList.add(\"maplibregl-attrib-empty\"),this._updateCompact(),this._editLink=null)}}class Ii{constructor(t={}){this._updateCompact=()=>{const t=this._container.children;if(t.length){const e=t[0];this._map.getCanvasContainer().offsetWidth<=640||this._compact?!1!==this._compact&&e.classList.add(\"maplibregl-compact\"):e.classList.remove(\"maplibregl-compact\")}},this.options=t}getDefaultPosition(){return\"bottom-left\"}onAdd(t){this._map=t,this._compact=this.options&&this.options.compact,this._container=o.create(\"div\",\"maplibregl-ctrl\");const e=o.create(\"a\",\"maplibregl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://maplibre.org/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"block\",this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container}onRemove(){o.remove(this._container),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._compact=void 0}}class Pi{constructor(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1}add(t){const e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e}remove(t){const e=this._currentlyRunning,r=e?this._queue.concat(e):this._queue;for(const e of r)if(e.id===t)return void(e.cancelled=!0)}run(t=0){if(this._currentlyRunning)throw new Error(\"Attempting to run(), but is already running.\");const e=this._currentlyRunning=this._queue;this._queue=[];for(const r of e)if(!r.cancelled&&(r.callback(t),this._cleared))break;this._cleared=!1,this._currentlyRunning=!1}clear(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]}}var zi=e.Y([{name:\"a_pos3d\",type:\"Int16\",components:3}]);class Oi extends e.E{constructor(t){super(),this.sourceCache=t,this._tiles={},this._renderableTilesKeys=[],this._sourceTileCache={},this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.deltaZoom=1,t.usedForTerrain=!0,t.tileSize=this.tileSize*2**this.deltaZoom}destruct(){this.sourceCache.usedForTerrain=!1,this.sourceCache.tileSize=null}update(t,r){this.sourceCache.update(t,r),this._renderableTilesKeys=[];const n={};for(const i of t.coveringTiles({tileSize:this.tileSize,minzoom:this.minzoom,maxzoom:this.maxzoom,reparseOverscaled:!1,terrain:r}))n[i.key]=!0,this._renderableTilesKeys.push(i.key),this._tiles[i.key]||(i.posMatrix=new Float64Array(16),e.aQ(i.posMatrix,0,e.X,0,e.X,0,1),this._tiles[i.key]=new ht(i,this.tileSize));for(const t in this._tiles)n[t]||delete this._tiles[t]}freeRtt(t){for(const e in this._tiles){const r=this._tiles[e];(!t||r.tileID.equals(t)||r.tileID.isChildOf(t)||t.isChildOf(r.tileID))&&(r.rtt=[])}}getRenderableTiles(){return this._renderableTilesKeys.map((t=>this.getTileByID(t)))}getTileByID(t){return this._tiles[t]}getTerrainCoords(t){const r={};for(const n of this._renderableTilesKeys){const i=this._tiles[n].tileID;if(i.canonical.equals(t.canonical)){const i=t.clone();i.posMatrix=new Float64Array(16),e.aQ(i.posMatrix,0,e.X,0,e.X,0,1),r[n]=i}else if(i.canonical.isChildOf(t.canonical)){const a=t.clone();a.posMatrix=new Float64Array(16);const o=i.canonical.z-t.canonical.z,s=i.canonical.x-(i.canonical.x>>o<<o),l=i.canonical.y-(i.canonical.y>>o<<o),c=e.X>>o;e.aQ(a.posMatrix,0,c,0,c,0,1),e.J(a.posMatrix,a.posMatrix,[-s*c,-l*c,0]),r[n]=a}else if(t.canonical.isChildOf(i.canonical)){const a=t.clone();a.posMatrix=new Float64Array(16);const o=t.canonical.z-i.canonical.z,s=t.canonical.x-(t.canonical.x>>o<<o),l=t.canonical.y-(t.canonical.y>>o<<o),c=e.X>>o;e.aQ(a.posMatrix,0,e.X,0,e.X,0,1),e.J(a.posMatrix,a.posMatrix,[s*c,l*c,0]),e.K(a.posMatrix,a.posMatrix,[1/2**o,1/2**o,0]),r[n]=a}}return r}getSourceTile(t,e){const r=this.sourceCache._source;let n=t.overscaledZ-this.deltaZoom;if(n>r.maxzoom&&(n=r.maxzoom),n<r.minzoom)return null;this._sourceTileCache[t.key]||(this._sourceTileCache[t.key]=t.scaledTo(n).key);let i=this.sourceCache.getTileByID(this._sourceTileCache[t.key]);if((!i||!i.dem)&&e)for(;n>=r.minzoom&&(!i||!i.dem);)i=this.sourceCache.getTileByID(t.scaledTo(n--).key);return i}tilesAfterTime(t=Date.now()){return Object.values(this._tiles).filter((e=>e.timeAdded>=t))}}class Di{constructor(t,e,r){this.painter=t,this.sourceCache=new Oi(e),this.options=r,this.exaggeration=\"number\"==typeof r.exaggeration?r.exaggeration:1,this.qualityFactor=2,this.meshSize=128,this._demMatrixCache={},this.coordsIndex=[],this._coordsTextureSize=1024}getDEMElevation(t,r,n,i=e.X){var a;if(!(r>=0&&r<i&&n>=0&&n<i))return 0;const o=this.getTerrainData(t),s=null===(a=o.tile)||void 0===a?void 0:a.dem;if(!s)return 0;const l=function(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t}([],[r/i*e.X,n/i*e.X],o.u_terrain_matrix),c=[l[0]*s.dim,l[1]*s.dim],u=Math.floor(c[0]),h=Math.floor(c[1]),f=c[0]-u,p=c[1]-h;return s.get(u,h)*(1-f)*(1-p)+s.get(u+1,h)*f*(1-p)+s.get(u,h+1)*(1-f)*p+s.get(u+1,h+1)*f*p}getElevationForLngLatZoom(t,r){const{tileID:n,mercatorX:i,mercatorY:a}=this._getOverscaledTileIDFromLngLatZoom(t,r);return this.getElevation(n,i%e.X,a%e.X,e.X)}getElevation(t,r,n,i=e.X){return this.getDEMElevation(t,r,n,i)*this.exaggeration}getTerrainData(t){if(!this._emptyDemTexture){const t=this.painter.context,r=new e.R({width:1,height:1},new Uint8Array(4));this._emptyDepthTexture=new w(t,r,t.gl.RGBA,{premultiply:!1}),this._emptyDemUnpack=[0,0,0,0],this._emptyDemTexture=new w(t,new e.R({width:1,height:1}),t.gl.RGBA,{premultiply:!1}),this._emptyDemTexture.bind(t.gl.NEAREST,t.gl.CLAMP_TO_EDGE),this._emptyDemMatrix=e.ao([])}const r=this.sourceCache.getSourceTile(t,!0);if(r&&r.dem&&(!r.demTexture||r.needsTerrainPrepare)){const t=this.painter.context;r.demTexture=this.painter.getTileTexture(r.dem.stride),r.demTexture?r.demTexture.update(r.dem.getPixels(),{premultiply:!1}):r.demTexture=new w(t,r.dem.getPixels(),t.gl.RGBA,{premultiply:!1}),r.demTexture.bind(t.gl.NEAREST,t.gl.CLAMP_TO_EDGE),r.needsTerrainPrepare=!1}const n=r&&r+r.tileID.key+t.key;if(n&&!this._demMatrixCache[n]){const n=this.sourceCache.sourceCache._source.maxzoom;let i=t.canonical.z-r.tileID.canonical.z;t.overscaledZ>t.canonical.z&&(t.canonical.z>=n?i=t.canonical.z-n:e.w(\"cannot calculate elevation if elevation maxzoom > source.maxzoom\"));const a=t.canonical.x-(t.canonical.x>>i<<i),o=t.canonical.y-(t.canonical.y>>i<<i),s=e.bb(new Float64Array(16),[1/(e.X<<i),1/(e.X<<i),0]);e.J(s,s,[a*e.X,o*e.X,0]),this._demMatrixCache[t.key]={matrix:s,coord:t}}return{u_depth:2,u_terrain:3,u_terrain_dim:r&&r.dem&&r.dem.dim||1,u_terrain_matrix:n?this._demMatrixCache[t.key].matrix:this._emptyDemMatrix,u_terrain_unpack:r&&r.dem&&r.dem.getUnpackVector()||this._emptyDemUnpack,u_terrain_exaggeration:this.exaggeration,texture:(r&&r.demTexture||this._emptyDemTexture).texture,depthTexture:(this._fboDepthTexture||this._emptyDepthTexture).texture,tile:r}}getFramebuffer(t){const e=this.painter,r=e.width/devicePixelRatio,n=e.height/devicePixelRatio;return!this._fbo||this._fbo.width===r&&this._fbo.height===n||(this._fbo.destroy(),this._fboCoordsTexture.destroy(),this._fboDepthTexture.destroy(),delete this._fbo,delete this._fboDepthTexture,delete this._fboCoordsTexture),this._fboCoordsTexture||(this._fboCoordsTexture=new w(e.context,{width:r,height:n,data:null},e.context.gl.RGBA,{premultiply:!1}),this._fboCoordsTexture.bind(e.context.gl.NEAREST,e.context.gl.CLAMP_TO_EDGE)),this._fboDepthTexture||(this._fboDepthTexture=new w(e.context,{width:r,height:n,data:null},e.context.gl.RGBA,{premultiply:!1}),this._fboDepthTexture.bind(e.context.gl.NEAREST,e.context.gl.CLAMP_TO_EDGE)),this._fbo||(this._fbo=e.context.createFramebuffer(r,n,!0,!1),this._fbo.depthAttachment.set(e.context.createRenderbuffer(e.context.gl.DEPTH_COMPONENT16,r,n))),this._fbo.colorAttachment.set(\"coords\"===t?this._fboCoordsTexture.texture:this._fboDepthTexture.texture),this._fbo}getCoordsTexture(){const t=this.painter.context;if(this._coordsTexture)return this._coordsTexture;const r=new Uint8Array(this._coordsTextureSize*this._coordsTextureSize*4);for(let t=0,e=0;t<this._coordsTextureSize;t++)for(let n=0;n<this._coordsTextureSize;n++,e+=4)r[e+0]=255&n,r[e+1]=255&t,r[e+2]=n>>8<<4|t>>8,r[e+3]=0;const n=new e.R({width:this._coordsTextureSize,height:this._coordsTextureSize},new Uint8Array(r.buffer)),i=new w(t,n,t.gl.RGBA,{premultiply:!1});return i.bind(t.gl.NEAREST,t.gl.CLAMP_TO_EDGE),this._coordsTexture=i,i}pointCoordinate(t){this.painter.maybeDrawDepthAndCoords(!0);const r=new Uint8Array(4),n=this.painter.context,i=n.gl,a=Math.round(t.x*this.painter.pixelRatio/devicePixelRatio),o=Math.round(t.y*this.painter.pixelRatio/devicePixelRatio),s=Math.round(this.painter.height/devicePixelRatio);n.bindFramebuffer.set(this.getFramebuffer(\"coords\").framebuffer),i.readPixels(a,s-o-1,1,1,i.RGBA,i.UNSIGNED_BYTE,r),n.bindFramebuffer.set(null);const l=r[0]+(r[2]>>4<<8),c=r[1]+((15&r[2])<<8),u=this.coordsIndex[255-r[3]],h=u&&this.sourceCache.getTileByID(u);if(!h)return null;const f=this._coordsTextureSize,p=(1<<h.tileID.canonical.z)*f;return new e.Z((h.tileID.canonical.x*f+l)/p+h.tileID.wrap,(h.tileID.canonical.y*f+c)/p,this.getElevation(h.tileID,l,c,f))}depthAtPoint(t){const e=new Uint8Array(4),r=this.painter.context,n=r.gl;return r.bindFramebuffer.set(this.getFramebuffer(\"depth\").framebuffer),n.readPixels(t.x,this.painter.height/devicePixelRatio-t.y-1,1,1,n.RGBA,n.UNSIGNED_BYTE,e),r.bindFramebuffer.set(null),(e[0]/16777216+e[1]/65536+e[2]/256+e[3])/256}getTerrainMesh(){if(this._mesh)return this._mesh;const t=this.painter.context,r=new e.bc,n=new e.aY,i=this.meshSize,a=e.X/i,o=i*i;for(let t=0;t<=i;t++)for(let e=0;e<=i;e++)r.emplaceBack(e*a,t*a,0);for(let t=0;t<o;t+=i+1)for(let e=0;e<i;e++)n.emplaceBack(e+t,i+e+t+1,i+e+t+2),n.emplaceBack(e+t,i+e+t+2,e+t+1);const s=r.length,l=s+2*(i+1);for(const t of[0,1])for(let n=0;n<=i;n++)for(const i of[0,1])r.emplaceBack(n*a,t*e.X,i);for(let t=0;t<2*i;t+=2)n.emplaceBack(l+t,l+t+1,l+t+3),n.emplaceBack(l+t,l+t+3,l+t+2),n.emplaceBack(s+t,s+t+3,s+t+1),n.emplaceBack(s+t,s+t+2,s+t+3);const c=r.length,u=c+2*(i+1);for(const t of[0,1])for(let n=0;n<=i;n++)for(const i of[0,1])r.emplaceBack(t*e.X,n*a,i);for(let t=0;t<2*i;t+=2)n.emplaceBack(c+t,c+t+1,c+t+3),n.emplaceBack(c+t,c+t+3,c+t+2),n.emplaceBack(u+t,u+t+3,u+t+1),n.emplaceBack(u+t,u+t+2,u+t+3);return this._mesh=new wn(t.createVertexBuffer(r,zi.members),t.createIndexBuffer(n),e.a0.simpleSegment(0,0,r.length,n.length)),this._mesh}getMeshFrameDelta(t){return 2*Math.PI*e.bd/Math.pow(2,t)/5}getMinTileElevationForLngLatZoom(t,e){var r;const{tileID:n}=this._getOverscaledTileIDFromLngLatZoom(t,e);return null!==(r=this.getMinMaxElevation(n).minElevation)&&void 0!==r?r:0}getMinMaxElevation(t){const e=this.getTerrainData(t).tile,r={minElevation:null,maxElevation:null};return e&&e.dem&&(r.minElevation=e.dem.min*this.exaggeration,r.maxElevation=e.dem.max*this.exaggeration),r}_getOverscaledTileIDFromLngLatZoom(t,r){const n=e.Z.fromLngLat(t.wrap()),i=(1<<r)*e.X,a=n.x*i,o=n.y*i,s=Math.floor(a/e.X),l=Math.floor(o/e.X);return{tileID:new e.S(r,0,r,s,l),mercatorX:a,mercatorY:o}}}class Ri{constructor(t,e,r){this._context=t,this._size=e,this._tileSize=r,this._objects=[],this._recentlyUsed=[],this._stamp=0}destruct(){for(const t of this._objects)t.texture.destroy(),t.fbo.destroy()}_createObject(t){const e=this._context.createFramebuffer(this._tileSize,this._tileSize,!0,!0),r=new w(this._context,{width:this._tileSize,height:this._tileSize,data:null},this._context.gl.RGBA);return r.bind(this._context.gl.LINEAR,this._context.gl.CLAMP_TO_EDGE),e.depthAttachment.set(this._context.createRenderbuffer(this._context.gl.DEPTH_STENCIL,this._tileSize,this._tileSize)),e.colorAttachment.set(r.texture),{id:t,fbo:e,texture:r,stamp:-1,inUse:!1}}getObjectForId(t){return this._objects[t]}useObject(t){t.inUse=!0,this._recentlyUsed=this._recentlyUsed.filter((e=>t.id!==e)),this._recentlyUsed.push(t.id)}stampObject(t){t.stamp=++this._stamp}getOrCreateFreeObject(){for(const t of this._recentlyUsed)if(!this._objects[t].inUse)return this._objects[t];if(this._objects.length>=this._size)throw new Error(\"No free RenderPool available, call freeAllObjects() required!\");const t=this._createObject(this._objects.length);return this._objects.push(t),t}freeObject(t){t.inUse=!1}freeAllObjects(){for(const t of this._objects)this.freeObject(t)}isFull(){return!(this._objects.length<this._size)&&!1===this._objects.some((t=>!t.inUse))}}const Fi={background:!0,fill:!0,line:!0,raster:!0,hillshade:!0};class Bi{constructor(t,e){this.painter=t,this.terrain=e,this.pool=new Ri(t.context,30,e.sourceCache.tileSize*e.qualityFactor)}destruct(){this.pool.destruct()}getTexture(t){return this.pool.getObjectForId(t.rtt[this._stacks.length-1].id).texture}prepareForRender(t,e){this._stacks=[],this._prevType=null,this._rttTiles=[],this._renderableTiles=this.terrain.sourceCache.getRenderableTiles(),this._renderableLayerIds=t._order.filter((r=>!t._layers[r].isHidden(e))),this._coordsDescendingInv={};for(const e in t.sourceCaches){this._coordsDescendingInv[e]={};const r=t.sourceCaches[e].getVisibleCoordinates();for(const t of r){const r=this.terrain.sourceCache.getTerrainCoords(t);for(const t in r)this._coordsDescendingInv[e][t]||(this._coordsDescendingInv[e][t]=[]),this._coordsDescendingInv[e][t].push(r[t])}}this._coordsDescendingInvStr={};for(const e of t._order){const r=t._layers[e],n=r.source;if(Fi[r.type]&&!this._coordsDescendingInvStr[n]){this._coordsDescendingInvStr[n]={};for(const t in this._coordsDescendingInv[n])this._coordsDescendingInvStr[n][t]=this._coordsDescendingInv[n][t].map((t=>t.key)).sort().join()}}for(const t of this._renderableTiles)for(const e in this._coordsDescendingInvStr){const r=this._coordsDescendingInvStr[e][t.tileID.key];r&&r!==t.rttCoords[e]&&(t.rtt=[])}}renderLayer(t){if(t.isHidden(this.painter.transform.zoom))return!1;const r=t.type,n=this.painter,i=this._renderableLayerIds[this._renderableLayerIds.length-1]===t.id;if(Fi[r]&&(this._prevType&&Fi[this._prevType]||this._stacks.push([]),this._prevType=r,this._stacks[this._stacks.length-1].push(t.id),!i))return!0;if(Fi[this._prevType]||Fi[r]&&i){this._prevType=r;const t=this._stacks.length-1,i=this._stacks[t]||[];for(const r of this._renderableTiles){if(this.pool.isFull()&&(bn(this.painter,this.terrain,this._rttTiles),this._rttTiles=[],this.pool.freeAllObjects()),this._rttTiles.push(r),r.rtt[t]){const e=this.pool.getObjectForId(r.rtt[t].id);if(e.stamp===r.rtt[t].stamp){this.pool.useObject(e);continue}}const a=this.pool.getOrCreateFreeObject();this.pool.useObject(a),this.pool.stampObject(a),r.rtt[t]={id:a.id,stamp:a.stamp},n.context.bindFramebuffer.set(a.fbo.framebuffer),n.context.clear({color:e.aN.transparent,stencil:0}),n.currentStencilSource=void 0;for(let t=0;t<i.length;t++){const e=n.style._layers[i[t]],o=e.source?this._coordsDescendingInv[e.source][r.tileID.key]:[r.tileID];n.context.viewport.set([0,0,a.fbo.width,a.fbo.height]),n._renderTileClippingMasks(e,o),n.renderLayer(n,n.style.sourceCaches[e.source],e,o),e.source&&(r.rttCoords[e.source]=this._coordsDescendingInvStr[e.source][r.tileID.key])}}return bn(this.painter,this.terrain,this._rttTiles),this._rttTiles=[],this.pool.freeAllObjects(),Fi[r]}return!1}}const Ni={\"AttributionControl.ToggleAttribution\":\"Toggle attribution\",\"AttributionControl.MapFeedback\":\"Map feedback\",\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"MapLibre logo\",\"Map.Title\":\"Map\",\"Marker.Title\":\"Map marker\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"Popup.Close\":\"Close popup\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\",\"TerrainControl.Enable\":\"Enable terrain\",\"TerrainControl.Disable\":\"Disable terrain\",\"CooperativeGesturesHandler.WindowsHelpText\":\"Use Ctrl + scroll to zoom the map\",\"CooperativeGesturesHandler.MacHelpText\":\"Use \u2318 + scroll to zoom the map\",\"CooperativeGesturesHandler.MobileHelpText\":\"Use two fingers to move the map\"},ji=r,Ui={hash:!1,interactive:!0,bearingSnap:7,attributionControl:Ci,maplibreLogo:!1,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,refreshExpiredTiles:!0,scrollZoom:!0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:60,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,cooperativeGestures:!1,trackResize:!0,center:[0,0],zoom:0,bearing:0,pitch:0,renderWorldCopies:!0,maxTileCacheSize:null,maxTileCacheZoomLevels:e.a.MAX_TILE_CACHE_ZOOM_LEVELS,transformRequest:null,transformCameraUpdate:null,fadeDuration:300,crossSourceCollisions:!0,clickTolerance:3,localIdeographFontFamily:\"sans-serif\",pitchWithRotate:!0,validateStyle:!0,maxCanvasSize:[4096,4096],cancelPendingTileRequestsWhileZooming:!0};const Vi=t=>{t.touchstart=t.dragStart,t.touchmoveWindow=t.dragMove,t.touchend=t.dragEnd},qi={showCompass:!0,showZoom:!0,visualizePitch:!1};class Hi{constructor(t,r,n=!1){this.mousedown=t=>{this.startMouse(e.e({},t,{ctrlKey:!0,preventDefault:()=>t.preventDefault()}),o.mousePos(this.element,t)),o.addEventListener(window,\"mousemove\",this.mousemove),o.addEventListener(window,\"mouseup\",this.mouseup)},this.mousemove=t=>{this.moveMouse(t,o.mousePos(this.element,t))},this.mouseup=t=>{this.mouseRotate.dragEnd(t),this.mousePitch&&this.mousePitch.dragEnd(t),this.offTemp()},this.touchstart=t=>{1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=o.touchPos(this.element,t.targetTouches)[0],this.startTouch(t,this._startPos),o.addEventListener(window,\"touchmove\",this.touchmove,{passive:!1}),o.addEventListener(window,\"touchend\",this.touchend))},this.touchmove=t=>{1!==t.targetTouches.length?this.reset():(this._lastPos=o.touchPos(this.element,t.targetTouches)[0],this.moveTouch(t,this._lastPos))},this.touchend=t=>{0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),delete this._startPos,delete this._lastPos,this.offTemp()},this.reset=()=>{this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),this.touchRotate.reset(),this.touchPitch&&this.touchPitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()},this._clickTolerance=10;const i=t.dragRotate._mouseRotate.getClickTolerance(),a=t.dragRotate._mousePitch.getClickTolerance();this.element=r,this.mouseRotate=ei({clickTolerance:i,enable:!0}),this.touchRotate=(({enable:t,clickTolerance:e,bearingDegreesPerPixelMoved:r=.8})=>{const n=new Qn;return new $n({clickTolerance:e,move:(t,e)=>({bearingDelta:(e.x-t.x)*r}),moveStateManager:n,enable:t,assignEvents:Vi})})({clickTolerance:i,enable:!0}),this.map=t,n&&(this.mousePitch=ri({clickTolerance:a,enable:!0}),this.touchPitch=(({enable:t,clickTolerance:e,pitchDegreesPerPixelMoved:r=-.5})=>{const n=new Qn;return new $n({clickTolerance:e,move:(t,e)=>({pitchDelta:(e.y-t.y)*r}),moveStateManager:n,enable:t,assignEvents:Vi})})({clickTolerance:a,enable:!0})),o.addEventListener(r,\"mousedown\",this.mousedown),o.addEventListener(r,\"touchstart\",this.touchstart,{passive:!1}),o.addEventListener(r,\"touchcancel\",this.reset)}startMouse(t,e){this.mouseRotate.dragStart(t,e),this.mousePitch&&this.mousePitch.dragStart(t,e),o.disableDrag()}startTouch(t,e){this.touchRotate.dragStart(t,e),this.touchPitch&&this.touchPitch.dragStart(t,e),o.disableDrag()}moveMouse(t,e){const r=this.map,{bearingDelta:n}=this.mouseRotate.dragMove(t,e)||{};if(n&&r.setBearing(r.getBearing()+n),this.mousePitch){const{pitchDelta:n}=this.mousePitch.dragMove(t,e)||{};n&&r.setPitch(r.getPitch()+n)}}moveTouch(t,e){const r=this.map,{bearingDelta:n}=this.touchRotate.dragMove(t,e)||{};if(n&&r.setBearing(r.getBearing()+n),this.touchPitch){const{pitchDelta:n}=this.touchPitch.dragMove(t,e)||{};n&&r.setPitch(r.getPitch()+n)}}off(){const t=this.element;o.removeEventListener(t,\"mousedown\",this.mousedown),o.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),o.removeEventListener(window,\"touchmove\",this.touchmove,{passive:!1}),o.removeEventListener(window,\"touchend\",this.touchend),o.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()}offTemp(){o.enableDrag(),o.removeEventListener(window,\"mousemove\",this.mousemove),o.removeEventListener(window,\"mouseup\",this.mouseup),o.removeEventListener(window,\"touchmove\",this.touchmove,{passive:!1}),o.removeEventListener(window,\"touchend\",this.touchend)}}let Gi;function Zi(t,r,n){const i=new e.N(t.lng,t.lat);if(t=new e.N(t.lng,t.lat),r){const i=new e.N(t.lng-360,t.lat),a=new e.N(t.lng+360,t.lat),o=n.locationPoint(t).distSqr(r);n.locationPoint(i).distSqr(r)<o?t=i:n.locationPoint(a).distSqr(r)<o&&(t=a)}for(;Math.abs(t.lng-n.center.lng)>180;){const e=n.locationPoint(t);if(e.x>=0&&e.y>=0&&e.x<=n.width&&e.y<=n.height)break;t.lng>n.center.lng?t.lng-=360:t.lng+=360}return t.lng!==i.lng&&n.locationPoint(t).y>n.height/2-n.getHorizon()?t:i}const Wi={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Yi(t,e,r){const n=t.classList;for(const t in Wi)n.remove(`maplibregl-${r}-anchor-${t}`);n.add(`maplibregl-${r}-anchor-${e}`)}class Xi extends e.E{constructor(t){if(super(),this._onKeyPress=t=>{const e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},this._onMapClick=t=>{const e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},this._update=t=>{var e;if(!this._map)return;const r=this._map.loaded()&&!this._map.isMoving();(\"terrain\"===(null==t?void 0:t.type)||\"render\"===(null==t?void 0:t.type)&&!r)&&this._map.once(\"render\",this._update),this._map.transform.renderWorldCopies?this._lngLat=Zi(this._lngLat,this._flatPos,this._map.transform):this._lngLat=null===(e=this._lngLat)||void 0===e?void 0:e.wrap(),this._flatPos=this._pos=this._map.project(this._lngLat)._add(this._offset),this._map.terrain&&(this._flatPos=this._map.transform.locationPoint(this._lngLat)._add(this._offset));let n=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?n=`rotateZ(${this._rotation}deg)`:\"map\"===this._rotationAlignment&&(n=`rotateZ(${this._rotation-this._map.getBearing()}deg)`);let i=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?i=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(i=`rotateX(${this._map.getPitch()}deg)`),this._subpixelPositioning||t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),o.setTransform(this._element,`${Wi[this._anchor]} translate(${this._pos.x}px, ${this._pos.y}px) ${i} ${n}`),a.frameAsync(new AbortController).then((()=>{this._updateOpacity(t&&\"moveend\"===t.type)})).catch((()=>{}))},this._onMove=t=>{if(!this._isDragging){const e=this._clickTolerance||this._map._clickTolerance;this._isDragging=t.point.dist(this._pointerdownPos)>=e}this._isDragging&&(this._pos=t.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new e.k(\"dragstart\"))),this.fire(new e.k(\"drag\")))},this._onUp=()=>{this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._pointerdownPos=null,this._isDragging=!1,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new e.k(\"dragend\")),this._state=\"inactive\"},this._addDragHandler=t=>{this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._pointerdownPos=t.point,this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},this._anchor=t&&t.anchor||\"center\",this._color=t&&t.color||\"#3FB1CE\",this._scale=t&&t.scale||1,this._draggable=t&&t.draggable||!1,this._clickTolerance=t&&t.clickTolerance||0,this._subpixelPositioning=t&&t.subpixelPositioning||!1,this._isDragging=!1,this._state=\"inactive\",this._rotation=t&&t.rotation||0,this._rotationAlignment=t&&t.rotationAlignment||\"auto\",this._pitchAlignment=t&&t.pitchAlignment&&\"auto\"!==t.pitchAlignment?t.pitchAlignment:this._rotationAlignment,this.setOpacity(),this.setOpacity(null==t?void 0:t.opacity,null==t?void 0:t.opacityWhenCovered),t&&t.element)this._element=t.element,this._offset=e.P.convert(t&&t.offset||[0,0]);else{this._defaultMarker=!0,this._element=o.create(\"div\");const r=o.createNS(\"http://www.w3.org/2000/svg\",\"svg\"),n=41,i=27;r.setAttributeNS(null,\"display\",\"block\"),r.setAttributeNS(null,\"height\",`${n}px`),r.setAttributeNS(null,\"width\",`${i}px`),r.setAttributeNS(null,\"viewBox\",`0 0 ${i} ${n}`);const a=o.createNS(\"http://www.w3.org/2000/svg\",\"g\");a.setAttributeNS(null,\"stroke\",\"none\"),a.setAttributeNS(null,\"stroke-width\",\"1\"),a.setAttributeNS(null,\"fill\",\"none\"),a.setAttributeNS(null,\"fill-rule\",\"evenodd\");const s=o.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");const l=o.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");const c=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];for(const t of c){const e=o.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");e.setAttributeNS(null,\"opacity\",\"0.04\"),e.setAttributeNS(null,\"cx\",\"10.5\"),e.setAttributeNS(null,\"cy\",\"5.80029008\"),e.setAttributeNS(null,\"rx\",t.rx),e.setAttributeNS(null,\"ry\",t.ry),l.appendChild(e)}const u=o.createNS(\"http://www.w3.org/2000/svg\",\"g\");u.setAttributeNS(null,\"fill\",this._color);const h=o.createNS(\"http://www.w3.org/2000/svg\",\"path\");h.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),u.appendChild(h);const f=o.createNS(\"http://www.w3.org/2000/svg\",\"g\");f.setAttributeNS(null,\"opacity\",\"0.25\"),f.setAttributeNS(null,\"fill\",\"#000000\");const p=o.createNS(\"http://www.w3.org/2000/svg\",\"path\");p.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),f.appendChild(p);const d=o.createNS(\"http://www.w3.org/2000/svg\",\"g\");d.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),d.setAttributeNS(null,\"fill\",\"#FFFFFF\");const m=o.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");const g=o.createNS(\"http://www.w3.org/2000/svg\",\"circle\");g.setAttributeNS(null,\"fill\",\"#000000\"),g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"cx\",\"5.5\"),g.setAttributeNS(null,\"cy\",\"5.5\"),g.setAttributeNS(null,\"r\",\"5.4999962\");const y=o.createNS(\"http://www.w3.org/2000/svg\",\"circle\");y.setAttributeNS(null,\"fill\",\"#FFFFFF\"),y.setAttributeNS(null,\"cx\",\"5.5\"),y.setAttributeNS(null,\"cy\",\"5.5\"),y.setAttributeNS(null,\"r\",\"5.4999962\"),m.appendChild(g),m.appendChild(y),s.appendChild(l),s.appendChild(u),s.appendChild(f),s.appendChild(d),s.appendChild(m),r.appendChild(s),r.setAttributeNS(null,\"height\",n*this._scale+\"px\"),r.setAttributeNS(null,\"width\",i*this._scale+\"px\"),this._element.appendChild(r),this._offset=e.P.convert(t&&t.offset||[0,-14])}if(this._element.classList.add(\"maplibregl-marker\"),this._element.addEventListener(\"dragstart\",(t=>{t.preventDefault()})),this._element.addEventListener(\"mousedown\",(t=>{t.preventDefault()})),Yi(this._element,this._anchor,\"marker\"),t&&t.className)for(const e of t.className.split(\" \"))this._element.classList.add(e);this._popup=null}addTo(t){return this.remove(),this._map=t,this._element.setAttribute(\"aria-label\",t._getUIString(\"Marker.Title\")),t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),t.on(\"terrain\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this}remove(){return this._opacityTimeout&&(clearTimeout(this._opacityTimeout),delete this._opacityTimeout),this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"terrain\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),o.remove(this._element),this._popup&&this._popup.remove(),this}getLngLat(){return this._lngLat}setLngLat(t){return this._lngLat=e.N.convert(t),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this}getElement(){return this._element}setPopup(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){const e=38.1,r=13.5,n=Math.abs(r)/Math.SQRT2;t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-e],\"bottom-left\":[n,-1*(e-r+n)],\"bottom-right\":[-n,-1*(e-r+n)],left:[r,-1*(e-r)],right:[-r,-1*(e-r)]}:this._offset}this._popup=t,this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this}setSubpixelPositioning(t){return this._subpixelPositioning=t,this}getPopup(){return this._popup}togglePopup(){const t=this._popup;return this._element.style.opacity===this._opacityWhenCovered?this:t?(t.isOpen()?t.remove():(t.setLngLat(this._lngLat),t.addTo(this._map)),this):this}_updateOpacity(t=!1){var r,n;if(!(null===(r=this._map)||void 0===r?void 0:r.terrain))return void(this._element.style.opacity!==this._opacity&&(this._element.style.opacity=this._opacity));if(t)this._opacityTimeout=null;else{if(this._opacityTimeout)return;this._opacityTimeout=setTimeout((()=>{this._opacityTimeout=null}),100)}const i=this._map,a=i.terrain.depthAtPoint(this._pos),o=i.terrain.getElevationForLngLatZoom(this._lngLat,i.transform.tileZoom);if(i.transform.lngLatToCameraDepth(this._lngLat,o)-a<.006)return void(this._element.style.opacity=this._opacity);const s=-this._offset.y/i.transform._pixelPerMeter,l=Math.sin(i.getPitch()*Math.PI/180)*s,c=i.terrain.depthAtPoint(new e.P(this._pos.x,this._pos.y-this._offset.y)),u=i.transform.lngLatToCameraDepth(this._lngLat,o+l)-c>.006;(null===(n=this._popup)||void 0===n?void 0:n.isOpen())&&u&&this._popup.remove(),this._element.style.opacity=u?this._opacityWhenCovered:this._opacity}getOffset(){return this._offset}setOffset(t){return this._offset=e.P.convert(t),this._update(),this}addClassName(t){this._element.classList.add(t)}removeClassName(t){this._element.classList.remove(t)}toggleClassName(t){return this._element.classList.toggle(t)}setDraggable(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this}isDraggable(){return this._draggable}setRotation(t){return this._rotation=t||0,this._update(),this}getRotation(){return this._rotation}setRotationAlignment(t){return this._rotationAlignment=t||\"auto\",this._update(),this}getRotationAlignment(){return this._rotationAlignment}setPitchAlignment(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this}getPitchAlignment(){return this._pitchAlignment}setOpacity(t,e){return void 0===t&&void 0===e&&(this._opacity=\"1\",this._opacityWhenCovered=\"0.2\"),void 0!==t&&(this._opacity=t),void 0!==e&&(this._opacityWhenCovered=e),this._map&&this._updateOpacity(!0),this}}const $i={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0};let Ji=0,Ki=!1;class Qi extends e.E{constructor(t){super(),this._onSuccess=t=>{if(this._map){if(this._isOutOfMapMaxBounds(t))return this._setErrorState(),this.fire(new e.k(\"outofmaxbounds\",t)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=t,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-background\");break;default:throw new Error(`Unexpected watchState ${this._watchState}`)}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(t),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(t),this.options.showUserLocation&&this._dotElement.classList.remove(\"maplibregl-user-location-dot-stale\"),this.fire(new e.k(\"geolocate\",t)),this._finish()}},this._updateCamera=t=>{const r=new e.N(t.coords.longitude,t.coords.latitude),n=t.coords.accuracy,i=this._map.getBearing(),a=e.e({bearing:i},this.options.fitBoundsOptions),o=X.fromLngLat(r,n);this._map.fitBounds(o,a,{geolocateSource:!0})},this._updateMarker=t=>{if(t){const r=new e.N(t.coords.longitude,t.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=t.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},this._onZoom=()=>{this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},this._onError=t=>{if(this._map){if(this.options.trackUserLocation)if(1===t.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;const t=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=t,this._geolocateButton.setAttribute(\"aria-label\",t),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===t.code&&Ki)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"maplibregl-user-location-dot-stale\"),this.fire(new e.k(\"error\",t)),this._finish()}},this._finish=()=>{this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},this._setupUI=()=>{this._map&&(this._container.addEventListener(\"contextmenu\",(t=>t.preventDefault())),this._geolocateButton=o.create(\"button\",\"maplibregl-ctrl-geolocate\",this._container),o.create(\"span\",\"maplibregl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",\"true\"),this._geolocateButton.type=\"button\",this._geolocateButton.disabled=!0)},this._finishSetupUI=t=>{if(this._map){if(!1===t){e.w(\"Geolocation support is not available so the GeolocateControl will be disabled.\");const t=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=t,this._geolocateButton.setAttribute(\"aria-label\",t)}else{const t=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.disabled=!1,this._geolocateButton.title=t,this._geolocateButton.setAttribute(\"aria-label\",t)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=o.create(\"div\",\"maplibregl-user-location-dot\"),this._userLocationDotMarker=new Xi({element:this._dotElement}),this._circleElement=o.create(\"div\",\"maplibregl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Xi({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",(()=>this.trigger())),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(t=>{const r=t.originalEvent&&\"resize\"===t.originalEvent.type;t.geolocateSource||\"ACTIVE_LOCK\"!==this._watchState||r||(this._watchState=\"BACKGROUND\",this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active\"),this.fire(new e.k(\"trackuserlocationend\")),this.fire(new e.k(\"userlocationlostfocus\")))}))}},this.options=e.e({},$i,t)}onAdd(t){return this._map=t,this._container=o.create(\"div\",\"maplibregl-ctrl maplibregl-ctrl-group\"),this._setupUI(),function(){return e._(this,arguments,void 0,(function*(t=!1){if(void 0!==Gi&&!t)return Gi;if(void 0===window.navigator.permissions)return Gi=!!window.navigator.geolocation,Gi;try{const t=yield window.navigator.permissions.query({name:\"geolocation\"});Gi=\"denied\"!==t.state}catch(t){Gi=!!window.navigator.geolocation}return Gi}))}().then((t=>this._finishSetupUI(t))),this._container}onRemove(){void 0!==this._geolocationWatchID&&(window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),o.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Ji=0,Ki=!1}_isOutOfMapMaxBounds(t){const e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())}_setErrorState(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-waiting\");break;case\"ACTIVE_ERROR\":break;default:throw new Error(`Unexpected watchState ${this._watchState}`)}}_updateCircleRadius(){const t=this._map.getBounds(),e=t.getSouthEast(),r=t.getNorthEast(),n=e.distanceTo(r),i=this._map._container.clientHeight,a=Math.ceil(this._accuracy/(n/i)*2);this._circleElement.style.width=`${a}px`,this._circleElement.style.height=`${a}px`}trigger(){if(!this._setup)return e.w(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new e.k(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Ji--,Ki=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-background-error\"),this.fire(new e.k(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new e.k(\"trackuserlocationstart\")),this.fire(new e.k(\"userlocationfocus\"));break;default:throw new Error(`Unexpected watchState ${this._watchState}`)}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-active\");break;case\"OFF\":break;default:throw new Error(`Unexpected watchState ${this._watchState}`)}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){let t;this._geolocateButton.classList.add(\"maplibregl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),Ji++,Ji>1?(t={maximumAge:6e5,timeout:0},Ki=!0):(t=this.options.positionOptions,Ki=!1),this._geolocationWatchID=window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,t)}}else window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0}_clearWatch(){window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"maplibregl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)}}const ta={maxWidth:100,unit:\"metric\"};function ea(t,e,r){const n=r&&r.maxWidth||100,i=t._container.clientHeight/2,a=t.unproject([0,i]),o=t.unproject([n,i]),s=a.distanceTo(o);if(r&&\"imperial\"===r.unit){const r=3.2808*s;r>5280?ra(e,n,r/5280,t._getUIString(\"ScaleControl.Miles\")):ra(e,n,r,t._getUIString(\"ScaleControl.Feet\"))}else r&&\"nautical\"===r.unit?ra(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\")):s>=1e3?ra(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):ra(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function ra(t,e,r,n){const i=function(t){const e=Math.pow(10,`${Math.floor(t)}`.length-1);let r=t/e;return r=r>=10?10:r>=5?5:r>=3?3:r>=2?2:r>=1?1:function(t){const e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(r),e*r}(r),a=i/r;t.style.width=e*a+\"px\",t.innerHTML=`${i}&nbsp;${n}`}class na extends e.E{constructor(t={}){super(),this._onFullscreenChange=()=>{var t;let e=window.document.fullscreenElement||window.document.mozFullScreenElement||window.document.webkitFullscreenElement||window.document.msFullscreenElement;for(;null===(t=null==e?void 0:e.shadowRoot)||void 0===t?void 0:t.fullscreenElement;)e=e.shadowRoot.fullscreenElement;e===this._container!==this._fullscreen&&this._handleFullscreenChange()},this._onClickFullscreen=()=>{this._isFullscreen()?this._exitFullscreen():this._requestFullscreen()},this._fullscreen=!1,t&&t.container&&(t.container instanceof HTMLElement?this._container=t.container:e.w(\"Full screen control 'container' must be a DOM element.\")),\"onfullscreenchange\"in document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in document&&(this._fullscreenchange=\"MSFullscreenChange\")}onAdd(t){return this._map=t,this._container||(this._container=this._map.getContainer()),this._controlContainer=o.create(\"div\",\"maplibregl-ctrl maplibregl-ctrl-group\"),this._setupUI(),this._controlContainer}onRemove(){o.remove(this._controlContainer),this._map=null,window.document.removeEventListener(this._fullscreenchange,this._onFullscreenChange)}_setupUI(){const t=this._fullscreenButton=o.create(\"button\",\"maplibregl-ctrl-fullscreen\",this._controlContainer);o.create(\"span\",\"maplibregl-ctrl-icon\",t).setAttribute(\"aria-hidden\",\"true\"),t.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),window.document.addEventListener(this._fullscreenchange,this._onFullscreenChange)}_updateTitle(){const t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t}_getTitle(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")}_isFullscreen(){return this._fullscreen}_handleFullscreenChange(){this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"maplibregl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"maplibregl-ctrl-fullscreen\"),this._updateTitle(),this._fullscreen?(this.fire(new e.k(\"fullscreenstart\")),this._prevCooperativeGesturesEnabled=this._map.cooperativeGestures.isEnabled(),this._map.cooperativeGestures.disable()):(this.fire(new e.k(\"fullscreenend\")),this._prevCooperativeGesturesEnabled&&this._map.cooperativeGestures.enable())}_exitFullscreen(){window.document.exitFullscreen?window.document.exitFullscreen():window.document.mozCancelFullScreen?window.document.mozCancelFullScreen():window.document.msExitFullscreen?window.document.msExitFullscreen():window.document.webkitCancelFullScreen?window.document.webkitCancelFullScreen():this._togglePseudoFullScreen()}_requestFullscreen(){this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen?this._container.webkitRequestFullscreen():this._togglePseudoFullScreen()}_togglePseudoFullScreen(){this._container.classList.toggle(\"maplibregl-pseudo-fullscreen\"),this._handleFullscreenChange(),this._map.resize()}}const ia={closeButton:!0,closeOnClick:!0,focusAfterOpen:!0,className:\"\",maxWidth:\"240px\",subpixelPositioning:!1},aa=[\"a[href]\",\"[tabindex]:not([tabindex='-1'])\",\"[contenteditable]:not([contenteditable='false'])\",\"button:not([disabled])\",\"input:not([disabled])\",\"select:not([disabled])\",\"textarea:not([disabled])\"].join(\", \");class oa extends e.E{constructor(t){super(),this.remove=()=>(this._content&&o.remove(this._content),this._container&&(o.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),this._map._canvasContainer.classList.remove(\"maplibregl-track-pointer\"),delete this._map,this.fire(new e.k(\"close\"))),this),this._onMouseUp=t=>{this._update(t.point)},this._onMouseMove=t=>{this._update(t.point)},this._onDrag=t=>{this._update(t.point)},this._update=t=>{var e;const r=this._lngLat||this._trackPointer;if(!this._map||!r||!this._content)return;if(!this._container){if(this._container=o.create(\"div\",\"maplibregl-popup\",this._map.getContainer()),this._tip=o.create(\"div\",\"maplibregl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className)for(const t of this.options.className.split(\" \"))this._container.classList.add(t);this._closeButton&&this._closeButton.setAttribute(\"aria-label\",this._map._getUIString(\"Popup.Close\")),this._trackPointer&&this._container.classList.add(\"maplibregl-popup-track-pointer\")}if(this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer?this._lngLat=Zi(this._lngLat,this._flatPos,this._map.transform):this._lngLat=null===(e=this._lngLat)||void 0===e?void 0:e.wrap(),this._trackPointer&&!t)return;const n=this._flatPos=this._pos=this._trackPointer&&t?t:this._map.project(this._lngLat);this._map.terrain&&(this._flatPos=this._trackPointer&&t?t:this._map.transform.locationPoint(this._lngLat));let i=this.options.anchor;const a=sa(this.options.offset);if(!i){const t=this._container.offsetWidth,e=this._container.offsetHeight;let r;r=n.y+a.bottom.y<e?[\"top\"]:n.y>this._map.transform.height-e?[\"bottom\"]:[],n.x<t/2?r.push(\"left\"):n.x>this._map.transform.width-t/2&&r.push(\"right\"),i=0===r.length?\"bottom\":r.join(\"-\")}let s=n.add(a[i]);this.options.subpixelPositioning||(s=s.round()),o.setTransform(this._container,`${Wi[i]} translate(${s.x}px,${s.y}px)`),Yi(this._container,i,\"popup\")},this._onClose=()=>{this.remove()},this.options=e.e(Object.create(ia),t)}addTo(t){return this._map&&this.remove(),this._map=t,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._focusFirstElement(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"maplibregl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"maplibregl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new e.k(\"open\")),this}isOpen(){return!!this._map}getLngLat(){return this._lngLat}setLngLat(t){return this._lngLat=e.N.convert(t),this._pos=null,this._flatPos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"maplibregl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"maplibregl-track-pointer\")),this}trackPointer(){return this._trackPointer=!0,this._pos=null,this._flatPos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"maplibregl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"maplibregl-track-pointer\")),this}getElement(){return this._container}setText(t){return this.setDOMContent(document.createTextNode(t))}setHTML(t){const e=document.createDocumentFragment(),r=document.createElement(\"body\");let n;for(r.innerHTML=t;n=r.firstChild,n;)e.appendChild(n);return this.setDOMContent(e)}getMaxWidth(){var t;return null===(t=this._container)||void 0===t?void 0:t.style.maxWidth}setMaxWidth(t){return this.options.maxWidth=t,this._update(),this}setDOMContent(t){if(this._content)for(;this._content.hasChildNodes();)this._content.firstChild&&this._content.removeChild(this._content.firstChild);else this._content=o.create(\"div\",\"maplibregl-popup-content\",this._container);return this._content.appendChild(t),this._createCloseButton(),this._update(),this._focusFirstElement(),this}addClassName(t){return this._container&&this._container.classList.add(t),this}removeClassName(t){return this._container&&this._container.classList.remove(t),this}setOffset(t){return this.options.offset=t,this._update(),this}toggleClassName(t){if(this._container)return this._container.classList.toggle(t)}setSubpixelPositioning(t){this.options.subpixelPositioning=t}_createCloseButton(){this.options.closeButton&&(this._closeButton=o.create(\"button\",\"maplibregl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))}_focusFirstElement(){if(!this.options.focusAfterOpen||!this._container)return;const t=this._container.querySelector(aa);t&&t.focus()}}function sa(t){if(t){if(\"number\"==typeof t){const r=Math.round(Math.abs(t)/Math.SQRT2);return{center:new e.P(0,0),top:new e.P(0,t),\"top-left\":new e.P(r,r),\"top-right\":new e.P(-r,r),bottom:new e.P(0,-t),\"bottom-left\":new e.P(r,-r),\"bottom-right\":new e.P(-r,-r),left:new e.P(t,0),right:new e.P(-t,0)}}if(t instanceof e.P||Array.isArray(t)){const r=e.P.convert(t);return{center:r,top:r,\"top-left\":r,\"top-right\":r,bottom:r,\"bottom-left\":r,\"bottom-right\":r,left:r,right:r}}return{center:e.P.convert(t.center||[0,0]),top:e.P.convert(t.top||[0,0]),\"top-left\":e.P.convert(t[\"top-left\"]||[0,0]),\"top-right\":e.P.convert(t[\"top-right\"]||[0,0]),bottom:e.P.convert(t.bottom||[0,0]),\"bottom-left\":e.P.convert(t[\"bottom-left\"]||[0,0]),\"bottom-right\":e.P.convert(t[\"bottom-right\"]||[0,0]),left:e.P.convert(t.left||[0,0]),right:e.P.convert(t.right||[0,0])}}return sa(new e.P(0,0))}const la=r;t.AJAXError=e.bg,t.Evented=e.E,t.LngLat=e.N,t.MercatorCoordinate=e.Z,t.Point=e.P,t.addProtocol=e.bh,t.config=e.a,t.removeProtocol=e.bi,t.AttributionControl=Li,t.BoxZoomHandler=Gn,t.CanvasSource=it,t.CooperativeGesturesHandler=Ti,t.DoubleClickZoomHandler=yi,t.DragPanHandler=_i,t.DragRotateHandler=bi,t.EdgeInsets=Mn,t.FullscreenControl=na,t.GeoJSONSource=tt,t.GeolocateControl=Qi,t.Hash=Ln,t.ImageSource=rt,t.KeyboardHandler=pi,t.LngLatBounds=X,t.LogoControl=Ii,t.Map=class extends Ei{constructor(t){e.be.mark(e.bf.create);const r=Object.assign(Object.assign({},Ui),t);if(null!=r.minZoom&&null!=r.maxZoom&&r.minZoom>r.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=r.minPitch&&null!=r.maxPitch&&r.minPitch>r.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=r.minPitch&&r.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=r.maxPitch&&r.maxPitch>85)throw new Error(\"maxPitch must be less than or equal to 85\");if(super(new En(r.minZoom,r.maxZoom,r.minPitch,r.maxPitch,r.renderWorldCopies),{bearingSnap:r.bearingSnap}),this._idleTriggered=!1,this._crossFadingFactor=1,this._renderTaskQueue=new Pi,this._controls=[],this._mapId=e.a4(),this._contextLost=t=>{t.preventDefault(),this._frameRequest&&(this._frameRequest.abort(),this._frameRequest=null),this.fire(new e.k(\"webglcontextlost\",{originalEvent:t}))},this._contextRestored=t=>{this._setupPainter(),this.resize(),this._update(),this.fire(new e.k(\"webglcontextrestored\",{originalEvent:t}))},this._onMapScroll=t=>{if(t.target===this._container)return this._container.scrollTop=0,this._container.scrollLeft=0,!1},this._onWindowOnline=()=>{this._update()},this._interactive=r.interactive,this._maxTileCacheSize=r.maxTileCacheSize,this._maxTileCacheZoomLevels=r.maxTileCacheZoomLevels,this._failIfMajorPerformanceCaveat=!0===r.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=!0===r.preserveDrawingBuffer,this._antialias=!0===r.antialias,this._trackResize=!0===r.trackResize,this._bearingSnap=r.bearingSnap,this._refreshExpiredTiles=!0===r.refreshExpiredTiles,this._fadeDuration=r.fadeDuration,this._crossSourceCollisions=!0===r.crossSourceCollisions,this._collectResourceTiming=!0===r.collectResourceTiming,this._locale=Object.assign(Object.assign({},Ni),r.locale),this._clickTolerance=r.clickTolerance,this._overridePixelRatio=r.pixelRatio,this._maxCanvasSize=r.maxCanvasSize,this.transformCameraUpdate=r.transformCameraUpdate,this.cancelPendingTileRequestsWhileZooming=!0===r.cancelPendingTileRequestsWhileZooming,this._imageQueueHandle=p.addThrottleControl((()=>this.isMoving())),this._requestManager=new d(r.transformRequest),\"string\"==typeof r.container){if(this._container=document.getElementById(r.container),!this._container)throw new Error(`Container '${r.container}' not found.`)}else{if(!(r.container instanceof HTMLElement))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=r.container}if(r.maxBounds&&this.setMaxBounds(r.maxBounds),this._setupContainer(),this._setupPainter(),this.on(\"move\",(()=>this._update(!1))).on(\"moveend\",(()=>this._update(!1))).on(\"zoom\",(()=>this._update(!0))).on(\"terrain\",(()=>{this.painter.terrainFacilitator.dirty=!0,this._update(!0)})).once(\"idle\",(()=>{this._idleTriggered=!0})),\"undefined\"!=typeof window){addEventListener(\"online\",this._onWindowOnline,!1);let t=!1;const e=Cn((t=>{this._trackResize&&!this._removed&&this.resize(t)._update()}),50);this._resizeObserver=new ResizeObserver((r=>{t?e(r):t=!0})),this._resizeObserver.observe(this._container)}this.handlers=new Si(this,r);const n=\"string\"==typeof r.hash&&r.hash||void 0;this._hash=r.hash&&new Ln(n).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:r.center,zoom:r.zoom,bearing:r.bearing,pitch:r.pitch}),r.bounds&&(this.resize(),this.fitBounds(r.bounds,e.e({},r.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=r.localIdeographFontFamily,this._validateStyle=r.validateStyle,r.style&&this.setStyle(r.style,{localIdeographFontFamily:r.localIdeographFontFamily}),r.attributionControl&&this.addControl(new Li(\"boolean\"==typeof r.attributionControl?void 0:r.attributionControl)),r.maplibreLogo&&this.addControl(new Ii,r.logoPosition),this.on(\"style.load\",(()=>{this.transform.unmodified&&this.jumpTo(this.style.stylesheet)})),this.on(\"data\",(t=>{this._update(\"style\"===t.dataType),this.fire(new e.k(`${t.dataType}data`,t))})),this.on(\"dataloading\",(t=>{this.fire(new e.k(`${t.dataType}dataloading`,t))})),this.on(\"dataabort\",(t=>{this.fire(new e.k(\"sourcedataabort\",t))}))}_getMapId(){return this._mapId}addControl(t,r){if(void 0===r&&(r=t.getDefaultPosition?t.getDefaultPosition():\"top-right\"),!t||!t.onAdd)return this.fire(new e.j(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));const n=t.onAdd(this);this._controls.push(t);const i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this}removeControl(t){if(!t||!t.onRemove)return this.fire(new e.j(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));const r=this._controls.indexOf(t);return r>-1&&this._controls.splice(r,1),t.onRemove(this),this}hasControl(t){return this._controls.indexOf(t)>-1}calculateCameraOptionsFromTo(t,e,r,n){return null==n&&this.terrain&&(n=this.terrain.getElevationForLngLatZoom(r,this.transform.tileZoom)),super.calculateCameraOptionsFromTo(t,e,r,n)}resize(t){var r;const n=this._containerDimensions(),i=n[0],a=n[1],o=this._getClampedPixelRatio(i,a);if(this._resizeCanvas(i,a,o),this.painter.resize(i,a,o),this.painter.overLimit()){const t=this.painter.context.gl;this._maxCanvasSize=[t.drawingBufferWidth,t.drawingBufferHeight];const e=this._getClampedPixelRatio(i,a);this._resizeCanvas(i,a,e),this.painter.resize(i,a,e)}this.transform.resize(i,a),null===(r=this._requestedCameraState)||void 0===r||r.resize(i,a);const s=!this._moving;return s&&(this.stop(),this.fire(new e.k(\"movestart\",t)).fire(new e.k(\"move\",t))),this.fire(new e.k(\"resize\",t)),s&&this.fire(new e.k(\"moveend\",t)),this}_getClampedPixelRatio(t,e){const{0:r,1:n}=this._maxCanvasSize,i=this.getPixelRatio(),a=t*i,o=e*i,s=a>r?r/a:1,l=o>n?n/o:1;return Math.min(s,l)*i}getPixelRatio(){var t;return null!==(t=this._overridePixelRatio)&&void 0!==t?t:devicePixelRatio}setPixelRatio(t){this._overridePixelRatio=t,this.resize()}getBounds(){return this.transform.getBounds()}getMaxBounds(){return this.transform.getMaxBounds()}setMaxBounds(t){return this.transform.setMaxBounds(X.convert(t)),this._update()}setMinZoom(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")}getMinZoom(){return this.transform.minZoom}setMaxZoom(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")}getMaxZoom(){return this.transform.maxZoom}setMinPitch(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")}getMinPitch(){return this.transform.minPitch}setMaxPitch(t){if((t=null==t?60:t)>85)throw new Error(\"maxPitch must be less than or equal to 85\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")}getMaxPitch(){return this.transform.maxPitch}getRenderWorldCopies(){return this.transform.renderWorldCopies}setRenderWorldCopies(t){return this.transform.renderWorldCopies=t,this._update()}project(t){return this.transform.locationPoint(e.N.convert(t),this.style&&this.terrain)}unproject(t){return this.transform.pointLocation(e.P.convert(t),this.terrain)}isMoving(){var t;return this._moving||(null===(t=this.handlers)||void 0===t?void 0:t.isMoving())}isZooming(){var t;return this._zooming||(null===(t=this.handlers)||void 0===t?void 0:t.isZooming())}isRotating(){var t;return this._rotating||(null===(t=this.handlers)||void 0===t?void 0:t.isRotating())}_createDelegatedListener(t,e,r){if(\"mouseenter\"===t||\"mouseover\"===t){let n=!1;const i=i=>{const a=this.getLayer(e)?this.queryRenderedFeatures(i.point,{layers:[e]}):[];a.length?n||(n=!0,r.call(this,new Nn(t,this,i.originalEvent,{features:a}))):n=!1};return{layer:e,listener:r,delegates:{mousemove:i,mouseout:()=>{n=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){let n=!1;const i=i=>{(this.getLayer(e)?this.queryRenderedFeatures(i.point,{layers:[e]}):[]).length?n=!0:n&&(n=!1,r.call(this,new Nn(t,this,i.originalEvent)))},a=e=>{n&&(n=!1,r.call(this,new Nn(t,this,e.originalEvent)))};return{layer:e,listener:r,delegates:{mousemove:i,mouseout:a}}}{const n=t=>{const n=this.getLayer(e)?this.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(this,t),delete t.features)};return{layer:e,listener:r,delegates:{[t]:n}}}}on(t,e,r){if(void 0===r)return super.on(t,e);const n=this._createDelegatedListener(t,e,r);this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(n);for(const t in n.delegates)this.on(t,n.delegates[t]);return this}once(t,e,r){if(void 0===r)return super.once(t,e);const n=this._createDelegatedListener(t,e,r);for(const t in n.delegates)this.once(t,n.delegates[t]);return this}off(t,e,r){if(void 0===r)return super.off(t,e);return this._delegatedListeners&&this._delegatedListeners[t]&&(n=>{const i=n[t];for(let t=0;t<i.length;t++){const n=i[t];if(n.layer===e&&n.listener===r){for(const t in n.delegates)this.off(t,n.delegates[t]);return i.splice(t,1),this}}})(this._delegatedListeners),this}queryRenderedFeatures(t,r){if(!this.style)return[];let n;const i=t instanceof e.P||Array.isArray(t),a=i?t:[[0,0],[this.transform.width,this.transform.height]];if(r=r||(i?{}:t)||{},a instanceof e.P||\"number\"==typeof a[0])n=[e.P.convert(a)];else{const t=e.P.convert(a[0]),r=e.P.convert(a[1]);n=[t,new e.P(r.x,t.y),r,new e.P(t.x,r.y),t]}return this.style.queryRenderedFeatures(n,r,this.transform)}querySourceFeatures(t,e){return this.style.querySourceFeatures(t,e)}setStyle(t,r){return!1!==(r=e.e({},{localIdeographFontFamily:this._localIdeographFontFamily,validate:this._validateStyle},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&t?(this._diffStyle(t,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(t,r))}setTransformRequest(t){return this._requestManager.setTransformRequest(t),this}_getUIString(t){const e=this._locale[t];if(null==e)throw new Error(`Missing UI string '${t}'`);return e}_updateStyle(t,e){if(e.transformStyle&&this.style&&!this.style._loaded)return void this.style.once(\"style.load\",(()=>this._updateStyle(t,e)));const r=this.style&&e.transformStyle?this.style.serialize():void 0;return this.style&&(this.style.setEventedParent(null),this.style._remove(!t)),t?(this.style=new de(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t,e,r):this.style.loadJSON(t,e,r),this):(delete this.style,this)}_lazyInitEmptyStyle(){this.style||(this.style=new de(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())}_diffStyle(t,r){if(\"string\"==typeof t){const n=t,i=this._requestManager.transformRequest(n,\"Style\");e.h(i,new AbortController).then((t=>{this._updateDiff(t.data,r)})).catch((t=>{t&&this.fire(new e.j(t))}))}else\"object\"==typeof t&&this._updateDiff(t,r)}_updateDiff(t,r){try{this.style.setState(t,r)&&this._update(!0)}catch(n){e.w(`Unable to perform style diff: ${n.message||n.error||n}.  Rebuilding the style from scratch.`),this._updateStyle(t,r)}}getStyle(){if(this.style)return this.style.serialize()}isStyleLoaded(){return this.style?this.style.loaded():e.w(\"There is no style added to the map.\")}addSource(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)}isSourceLoaded(t){const r=this.style&&this.style.sourceCaches[t];if(void 0!==r)return r.loaded();this.fire(new e.j(new Error(`There is no source with ID '${t}'`)))}setTerrain(t){if(this.style._checkLoaded(),this._terrainDataCallback&&this.style.off(\"data\",this._terrainDataCallback),t){const r=this.style.sourceCaches[t.source];if(!r)throw new Error(`cannot load terrain, because there exists no source with ID: ${t.source}`);null===this.terrain&&r.reload();for(const r in this.style._layers){const n=this.style._layers[r];\"hillshade\"===n.type&&n.source===t.source&&e.w(\"You are using the same source for a hillshade layer and for 3D terrain. Please consider using two separate sources to improve rendering quality.\")}this.terrain=new Di(this.painter,r,t),this.painter.renderToTexture=new Bi(this.painter,this.terrain),this.transform.minElevationForCurrentTile=this.terrain.getMinTileElevationForLngLatZoom(this.transform.center,this.transform.tileZoom),this.transform.elevation=this.terrain.getElevationForLngLatZoom(this.transform.center,this.transform.tileZoom),this._terrainDataCallback=e=>{\"style\"===e.dataType?this.terrain.sourceCache.freeRtt():\"source\"===e.dataType&&e.tile&&(e.sourceId!==t.source||this._elevationFreeze||(this.transform.minElevationForCurrentTile=this.terrain.getMinTileElevationForLngLatZoom(this.transform.center,this.transform.tileZoom),this.transform.elevation=this.terrain.getElevationForLngLatZoom(this.transform.center,this.transform.tileZoom)),this.terrain.sourceCache.freeRtt(e.tile.tileID))},this.style.on(\"data\",this._terrainDataCallback)}else this.terrain&&this.terrain.sourceCache.destruct(),this.terrain=null,this.painter.renderToTexture&&this.painter.renderToTexture.destruct(),this.painter.renderToTexture=null,this.transform.minElevationForCurrentTile=0,this.transform.elevation=0;return this.fire(new e.k(\"terrain\",{terrain:t})),this}getTerrain(){var t,e;return null!==(e=null===(t=this.terrain)||void 0===t?void 0:t.options)&&void 0!==e?e:null}areTilesLoaded(){const t=this.style&&this.style.sourceCaches;for(const e in t){const r=t[e]._tiles;for(const t in r){const e=r[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}}return!0}removeSource(t){return this.style.removeSource(t),this._update(!0)}getSource(t){return this.style.getSource(t)}addImage(t,r,n={}){const{pixelRatio:i=1,sdf:o=!1,stretchX:s,stretchY:l,content:c,textFitWidth:u,textFitHeight:h}=n;this._lazyInitEmptyStyle();if(!(r instanceof HTMLImageElement||e.b(r))){if(void 0===r.width||void 0===r.height)return this.fire(new e.j(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));{const{width:n,height:a,data:f}=r,p=r;return this.style.addImage(t,{data:new e.R({width:n,height:a},new Uint8Array(f)),pixelRatio:i,stretchX:s,stretchY:l,content:c,textFitWidth:u,textFitHeight:h,sdf:o,version:0,userImage:p}),p.onAdd&&p.onAdd(this,t),this}}{const{width:n,height:f,data:p}=a.getImageData(r);this.style.addImage(t,{data:new e.R({width:n,height:f},p),pixelRatio:i,stretchX:s,stretchY:l,content:c,textFitWidth:u,textFitHeight:h,sdf:o,version:0})}}updateImage(t,r){const n=this.style.getImage(t);if(!n)return this.fire(new e.j(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));const i=r instanceof HTMLImageElement||e.b(r)?a.getImageData(r):r,{width:o,height:s,data:l}=i;if(void 0===o||void 0===s)return this.fire(new e.j(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(o!==n.data.width||s!==n.data.height)return this.fire(new e.j(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));const c=!(r instanceof HTMLImageElement||e.b(r));return n.data.replace(l,c),this.style.updateImage(t,n),this}getImage(t){return this.style.getImage(t)}hasImage(t){return t?!!this.style.getImage(t):(this.fire(new e.j(new Error(\"Missing required image id\"))),!1)}removeImage(t){this.style.removeImage(t)}loadImage(t){return p.getImage(this._requestManager.transformRequest(t,\"Image\"),new AbortController)}listImages(){return this.style.listImages()}addLayer(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)}moveLayer(t,e){return this.style.moveLayer(t,e),this._update(!0)}removeLayer(t){return this.style.removeLayer(t),this._update(!0)}getLayer(t){return this.style.getLayer(t)}getLayersOrder(){return this.style.getLayersOrder()}setLayerZoomRange(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)}setFilter(t,e,r={}){return this.style.setFilter(t,e,r),this._update(!0)}getFilter(t){return this.style.getFilter(t)}setPaintProperty(t,e,r,n={}){return this.style.setPaintProperty(t,e,r,n),this._update(!0)}getPaintProperty(t,e){return this.style.getPaintProperty(t,e)}setLayoutProperty(t,e,r,n={}){return this.style.setLayoutProperty(t,e,r,n),this._update(!0)}getLayoutProperty(t,e){return this.style.getLayoutProperty(t,e)}setGlyphs(t,e={}){return this._lazyInitEmptyStyle(),this.style.setGlyphs(t,e),this._update(!0)}getGlyphs(){return this.style.getGlyphsUrl()}addSprite(t,e,r={}){return this._lazyInitEmptyStyle(),this.style.addSprite(t,e,r,(t=>{t||this._update(!0)})),this}removeSprite(t){return this._lazyInitEmptyStyle(),this.style.removeSprite(t),this._update(!0)}getSprite(){return this.style.getSprite()}setSprite(t,e={}){return this._lazyInitEmptyStyle(),this.style.setSprite(t,e,(t=>{t||this._update(!0)})),this}setLight(t,e={}){return this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)}getLight(){return this.style.getLight()}setSky(t){return this._lazyInitEmptyStyle(),this.style.setSky(t),this._update(!0)}getSky(){return this.style.getSky()}setFeatureState(t,e){return this.style.setFeatureState(t,e),this._update()}removeFeatureState(t,e){return this.style.removeFeatureState(t,e),this._update()}getFeatureState(t){return this.style.getFeatureState(t)}getContainer(){return this._container}getCanvasContainer(){return this._canvasContainer}getCanvas(){return this._canvas}_containerDimensions(){let t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]}_setupContainer(){const t=this._container;t.classList.add(\"maplibregl-map\");const e=this._canvasContainer=o.create(\"div\",\"maplibregl-canvas-container\",t);this._interactive&&e.classList.add(\"maplibregl-interactive\"),this._canvas=o.create(\"canvas\",\"maplibregl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",this._interactive?\"0\":\"-1\"),this._canvas.setAttribute(\"aria-label\",this._getUIString(\"Map.Title\")),this._canvas.setAttribute(\"role\",\"region\");const r=this._containerDimensions(),n=this._getClampedPixelRatio(r[0],r[1]);this._resizeCanvas(r[0],r[1],n);const i=this._controlContainer=o.create(\"div\",\"maplibregl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((t=>{a[t]=o.create(\"div\",`maplibregl-ctrl-${t} `,i)})),this._container.addEventListener(\"scroll\",this._onMapScroll,!1)}_resizeCanvas(t,e,r){this._canvas.width=Math.floor(r*t),this._canvas.height=Math.floor(r*e),this._canvas.style.width=`${t}px`,this._canvas.style.height=`${e}px`}_setupPainter(){const t={alpha:!0,stencil:!0,depth:!0,failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1};let e=null;this._canvas.addEventListener(\"webglcontextcreationerror\",(r=>{e={requestedAttributes:t},r&&(e.statusMessage=r.statusMessage,e.type=r.type)}),{once:!0});const r=this._canvas.getContext(\"webgl2\",t)||this._canvas.getContext(\"webgl\",t);if(!r){const t=\"Failed to initialize WebGL\";throw e?(e.message=t,new Error(JSON.stringify(e))):new Error(t)}this.painter=new Tn(r,this.transform),s.testSupport(r)}loaded(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()}_update(t){return this.style&&this.style._loaded?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this}_requestRenderFrame(t){return this._update(),this._renderTaskQueue.add(t)}_cancelRenderFrame(t){this._renderTaskQueue.remove(t)}_render(t){const r=this._idleTriggered?this._fadeDuration:0;if(this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(t),this._removed)return;let n=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;const t=this.transform.zoom,i=a.now();this.style.zoomHistory.update(t,i);const o=new e.a9(t,{now:i,fadeDuration:r,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),s=o.crossFadingFactor();1===s&&s===this._crossFadingFactor||(n=!0,this._crossFadingFactor=s),this.style.update(o)}this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this.terrain?(this.terrain.sourceCache.update(this.transform,this.terrain),this.transform.minElevationForCurrentTile=this.terrain.getMinTileElevationForLngLatZoom(this.transform.center,this.transform.tileZoom),this._elevationFreeze||(this.transform.elevation=this.terrain.getElevationForLngLatZoom(this.transform.center,this.transform.tileZoom))):(this.transform.minElevationForCurrentTile=0,this.transform.elevation=0),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,r,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:r,showPadding:this.showPadding}),this.fire(new e.k(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,e.be.mark(e.bf.load),this.fire(new e.k(\"load\"))),this.style&&(this.style.hasTransitions()||n)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles();const i=this._sourcesDirty||this._styleDirty||this._placementDirty;return i||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new e.k(\"idle\")),!this._loaded||this._fullyLoaded||i||(this._fullyLoaded=!0,e.be.mark(e.bf.fullLoad)),this}redraw(){return this.style&&(this._frameRequest&&(this._frameRequest.abort(),this._frameRequest=null),this._render(0)),this}remove(){var t;this._hash&&this._hash.remove();for(const t of this._controls)t.onRemove(this);this._controls=[],this._frameRequest&&(this._frameRequest.abort(),this._frameRequest=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),\"undefined\"!=typeof window&&removeEventListener(\"online\",this._onWindowOnline,!1),p.removeThrottleControl(this._imageQueueHandle),null===(t=this._resizeObserver)||void 0===t||t.disconnect();const r=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");(null==r?void 0:r.loseContext)&&r.loseContext(),this._canvas.removeEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.removeEventListener(\"webglcontextlost\",this._contextLost,!1),o.remove(this._canvasContainer),o.remove(this._controlContainer),this._container.classList.remove(\"maplibregl-map\"),e.be.clearMetrics(),this._removed=!0,this.fire(new e.k(\"remove\"))}triggerRepaint(){this.style&&!this._frameRequest&&(this._frameRequest=new AbortController,a.frameAsync(this._frameRequest).then((t=>{e.be.frame(t),this._frameRequest=null,this._render(t)})).catch((()=>{})))}get showTileBoundaries(){return!!this._showTileBoundaries}set showTileBoundaries(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())}get showPadding(){return!!this._showPadding}set showPadding(t){this._showPadding!==t&&(this._showPadding=t,this._update())}get showCollisionBoxes(){return!!this._showCollisionBoxes}set showCollisionBoxes(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())}get showOverdrawInspector(){return!!this._showOverdrawInspector}set showOverdrawInspector(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())}get repaint(){return!!this._repaint}set repaint(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())}get vertices(){return!!this._vertices}set vertices(t){this._vertices=t,this._update()}get version(){return ji}getCameraTargetElevation(){return this.transform.elevation}},t.MapMouseEvent=Nn,t.MapTouchEvent=jn,t.MapWheelEvent=Un,t.Marker=Xi,t.NavigationControl=class{constructor(t){this._updateZoomButtons=()=>{const t=this._map.getZoom(),e=t===this._map.getMaxZoom(),r=t===this._map.getMinZoom();this._zoomInButton.disabled=e,this._zoomOutButton.disabled=r,this._zoomInButton.setAttribute(\"aria-disabled\",e.toString()),this._zoomOutButton.setAttribute(\"aria-disabled\",r.toString())},this._rotateCompassArrow=()=>{const t=this.options.visualizePitch?`scale(${1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)}) rotateX(${this._map.transform.pitch}deg) rotateZ(${this._map.transform.angle*(180/Math.PI)}deg)`:`rotate(${this._map.transform.angle*(180/Math.PI)}deg)`;this._compassIcon.style.transform=t},this._setButtonTitle=(t,e)=>{const r=this._map._getUIString(`NavigationControl.${e}`);t.title=r,t.setAttribute(\"aria-label\",r)},this.options=e.e({},qi,t),this._container=o.create(\"div\",\"maplibregl-ctrl maplibregl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(t=>t.preventDefault())),this.options.showZoom&&(this._zoomInButton=this._createButton(\"maplibregl-ctrl-zoom-in\",(t=>this._map.zoomIn({},{originalEvent:t}))),o.create(\"span\",\"maplibregl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",\"true\"),this._zoomOutButton=this._createButton(\"maplibregl-ctrl-zoom-out\",(t=>this._map.zoomOut({},{originalEvent:t}))),o.create(\"span\",\"maplibregl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",\"true\")),this.options.showCompass&&(this._compass=this._createButton(\"maplibregl-ctrl-compass\",(t=>{this.options.visualizePitch?this._map.resetNorthPitch({},{originalEvent:t}):this._map.resetNorth({},{originalEvent:t})})),this._compassIcon=o.create(\"span\",\"maplibregl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",\"true\"))}onAdd(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Hi(this._map,this._compass,this.options.visualizePitch)),this._container}onRemove(){o.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map}_createButton(t,e){const r=o.create(\"button\",t,this._container);return r.type=\"button\",r.addEventListener(\"click\",e),r}},t.Popup=oa,t.RasterDEMTileSource=Q,t.RasterTileSource=K,t.ScaleControl=class{constructor(t){this._onMove=()=>{ea(this._map,this._container,this.options)},this.setUnit=t=>{this.options.unit=t,ea(this._map,this._container,this.options)},this.options=Object.assign(Object.assign({},ta),t)}getDefaultPosition(){return\"bottom-left\"}onAdd(t){return this._map=t,this._container=o.create(\"div\",\"maplibregl-ctrl maplibregl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container}onRemove(){o.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0}},t.ScrollZoomHandler=gi,t.Style=de,t.TerrainControl=class{constructor(t){this._toggleTerrain=()=>{this._map.getTerrain()?this._map.setTerrain(null):this._map.setTerrain(this.options),this._updateTerrainIcon()},this._updateTerrainIcon=()=>{this._terrainButton.classList.remove(\"maplibregl-ctrl-terrain\"),this._terrainButton.classList.remove(\"maplibregl-ctrl-terrain-enabled\"),this._map.terrain?(this._terrainButton.classList.add(\"maplibregl-ctrl-terrain-enabled\"),this._terrainButton.title=this._map._getUIString(\"TerrainControl.Disable\")):(this._terrainButton.classList.add(\"maplibregl-ctrl-terrain\"),this._terrainButton.title=this._map._getUIString(\"TerrainControl.Enable\"))},this.options=t}onAdd(t){return this._map=t,this._container=o.create(\"div\",\"maplibregl-ctrl maplibregl-ctrl-group\"),this._terrainButton=o.create(\"button\",\"maplibregl-ctrl-terrain\",this._container),o.create(\"span\",\"maplibregl-ctrl-icon\",this._terrainButton).setAttribute(\"aria-hidden\",\"true\"),this._terrainButton.type=\"button\",this._terrainButton.addEventListener(\"click\",this._toggleTerrain),this._updateTerrainIcon(),this._map.on(\"terrain\",this._updateTerrainIcon),this._container}onRemove(){o.remove(this._container),this._map.off(\"terrain\",this._updateTerrainIcon),this._map=void 0}},t.TwoFingersTouchPitchHandler=hi,t.TwoFingersTouchRotateHandler=ci,t.TwoFingersTouchZoomHandler=si,t.TwoFingersTouchZoomRotateHandler=wi,t.VectorTileSource=J,t.VideoSource=nt,t.addSourceType=(t,r)=>e._(void 0,void 0,void 0,(function*(){if(ot(t))throw new Error(`A source type called \"${t}\" already exists.`);((t,e)=>{at[t]=e})(t,r)})),t.clearPrewarmedResources=function(){const t=j;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(F),j=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},t.getMaxParallelImageRequests=function(){return e.a.MAX_PARALLEL_IMAGE_REQUESTS},t.getRTLTextPluginStatus=function(){return ut().getRTLTextPluginStatus()},t.getVersion=function(){return la},t.getWorkerCount=function(){return B.workerCount},t.getWorkerUrl=function(){return e.a.WORKER_URL},t.importScriptInWorkers=function(t){return H().broadcast(\"IS\",t)},t.prewarm=function(){V().acquire(F)},t.setMaxParallelImageRequests=function(t){e.a.MAX_PARALLEL_IMAGE_REQUESTS=t},t.setRTLTextPlugin=function(t,e){return ut().setRTLTextPlugin(t,e)},t.setWorkerCount=function(t){B.workerCount=t},t.setWorkerUrl=function(t){e.a.WORKER_URL=t}})),t}()},88640:function(t,e,r){\"use strict\";function n(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function i(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function a(){}r.d(e,{GW:function(){return K},Dj:function(){return H}});var o=.7,s=1/o,l=\"\\\\s*([+-]?\\\\d+)\\\\s*\",c=\"\\\\s*([+-]?(?:\\\\d*\\\\.)?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",u=\"\\\\s*([+-]?(?:\\\\d*\\\\.)?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",h=/^#([0-9a-f]{3,8})$/,f=new RegExp(\"^rgb\\\\(\".concat(l,\",\").concat(l,\",\").concat(l,\"\\\\)$\")),p=new RegExp(\"^rgb\\\\(\".concat(u,\",\").concat(u,\",\").concat(u,\"\\\\)$\")),d=new RegExp(\"^rgba\\\\(\".concat(l,\",\").concat(l,\",\").concat(l,\",\").concat(c,\"\\\\)$\")),m=new RegExp(\"^rgba\\\\(\".concat(u,\",\").concat(u,\",\").concat(u,\",\").concat(c,\"\\\\)$\")),g=new RegExp(\"^hsl\\\\(\".concat(c,\",\").concat(u,\",\").concat(u,\"\\\\)$\")),y=new RegExp(\"^hsla\\\\(\".concat(c,\",\").concat(u,\",\").concat(u,\",\").concat(c,\"\\\\)$\")),v={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function x(){return this.rgb().formatHex()}function _(){return this.rgb().formatRgb()}function b(t){var e,r;return t=(t+\"\").trim().toLowerCase(),(e=h.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?w(e):3===r?new A(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?T(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?T(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=f.exec(t))?new A(e[1],e[2],e[3],1):(e=p.exec(t))?new A(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=d.exec(t))?T(e[1],e[2],e[3],e[4]):(e=m.exec(t))?T(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=g.exec(t))?I(e[1],e[2]/100,e[3]/100,1):(e=y.exec(t))?I(e[1],e[2]/100,e[3]/100,e[4]):v.hasOwnProperty(t)?w(v[t]):\"transparent\"===t?new A(NaN,NaN,NaN,0):null}function w(t){return new A(t>>16&255,t>>8&255,255&t,1)}function T(t,e,r,n){return n<=0&&(t=e=r=NaN),new A(t,e,r,n)}function k(t,e,r,n){return 1===arguments.length?((i=t)instanceof a||(i=b(i)),i?new A((i=i.rgb()).r,i.g,i.b,i.opacity):new A):new A(t,e,r,null==n?1:n);var i}function A(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function M(){return\"#\".concat(L(this.r)).concat(L(this.g)).concat(L(this.b))}function S(){var t=E(this.opacity);return\"\".concat(1===t?\"rgb(\":\"rgba(\").concat(C(this.r),\", \").concat(C(this.g),\", \").concat(C(this.b)).concat(1===t?\")\":\", \".concat(t,\")\"))}function E(t){return isNaN(t)?1:Math.max(0,Math.min(1,t))}function C(t){return Math.max(0,Math.min(255,Math.round(t)||0))}function L(t){return((t=C(t))<16?\"0\":\"\")+t.toString(16)}function I(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new z(t,e,r,n)}function P(t){if(t instanceof z)return new z(t.h,t.s,t.l,t.opacity);if(t instanceof a||(t=b(t)),!t)return new z;if(t instanceof z)return t;var e=(t=t.rgb()).r/255,r=t.g/255,n=t.b/255,i=Math.min(e,r,n),o=Math.max(e,r,n),s=NaN,l=o-i,c=(o+i)/2;return l?(s=e===o?(r-n)/l+6*(r<n):r===o?(n-e)/l+2:(e-r)/l+4,l/=c<.5?o+i:2-o-i,s*=60):l=c>0&&c<1?0:s,new z(s,l,c,t.opacity)}function z(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function O(t){return(t=(t||0)%360)<0?t+360:t}function D(t){return Math.max(0,Math.min(1,t||0))}function R(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}function F(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}n(a,b,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:x,formatHex:x,formatHex8:function(){return this.rgb().formatHex8()},formatHsl:function(){return P(this).formatHsl()},formatRgb:_,toString:_}),n(A,k,i(a,{brighter:function(t){return t=null==t?s:Math.pow(s,t),new A(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?o:Math.pow(o,t),new A(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},clamp:function(){return new A(C(this.r),C(this.g),C(this.b),E(this.opacity))},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:M,formatHex:M,formatHex8:function(){return\"#\".concat(L(this.r)).concat(L(this.g)).concat(L(this.b)).concat(L(255*(isNaN(this.opacity)?1:this.opacity)))},formatRgb:S,toString:S})),n(z,(function(t,e,r,n){return 1===arguments.length?P(t):new z(t,e,r,null==n?1:n)}),i(a,{brighter:function(t){return t=null==t?s:Math.pow(s,t),new z(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?o:Math.pow(o,t),new z(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new A(R(t>=240?t-240:t+120,i,n),R(t,i,n),R(t<120?t+240:t-120,i,n),this.opacity)},clamp:function(){return new z(O(this.h),D(this.s),D(this.l),E(this.opacity))},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=E(this.opacity);return\"\".concat(1===t?\"hsl(\":\"hsla(\").concat(O(this.h),\", \").concat(100*D(this.s),\"%, \").concat(100*D(this.l),\"%\").concat(1===t?\")\":\", \".concat(t,\")\"))}}));var B=function(t){return function(){return t}};function N(t,e){var r=e-t;return r?function(t,e){return function(r){return t+r*e}}(t,r):B(isNaN(t)?e:t)}var j=function t(e){var r=function(t){return 1==(t=+t)?N:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):B(isNaN(e)?r:e)}}(e);function n(t,e){var n=r((t=k(t)).r,(e=k(e)).r),i=r(t.g,e.g),a=r(t.b,e.b),o=N(t.opacity,e.opacity);return function(e){return t.r=n(e),t.g=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}}return n.gamma=t,n}(1);function U(t){return function(e){var r,n,i=e.length,a=new Array(i),o=new Array(i),s=new Array(i);for(r=0;r<i;++r)n=k(e[r]),a[r]=n.r||0,o[r]=n.g||0,s[r]=n.b||0;return a=t(a),o=t(o),s=t(s),n.opacity=1,function(t){return n.r=a(t),n.g=o(t),n.b=s(t),n+\"\"}}}function V(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=K(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function q(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function H(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function G(t){return G=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},G(t)}function Z(t,e){var r,n={},i={};for(r in null!==t&&\"object\"===G(t)||(t={}),null!==e&&\"object\"===G(e)||(e={}),e)r in t?n[r]=K(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}U((function(t){var e=t.length-1;return function(r){var n=r<=0?r=0:r>=1?(r=1,e-1):Math.floor(r*e),i=t[n],a=t[n+1],o=n>0?t[n-1]:2*i-a,s=n<e-1?t[n+2]:2*a-i;return F((r-n/e)*e,o,i,a,s)}})),U((function(t){var e=t.length;return function(r){var n=Math.floor(((r%=1)<0?++r:r)*e),i=t[(n+e-1)%e],a=t[n%e],o=t[(n+1)%e],s=t[(n+2)%e];return F((r-n/e)*e,i,a,o,s)}}));var W=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Y=new RegExp(W.source,\"g\");function X(t,e){var r,n,i,a=W.lastIndex=Y.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=W.exec(t))&&(n=Y.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:H(r,n)})),a=Y.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function $(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,i=e.slice();return function(a){for(r=0;r<n;++r)i[r]=t[r]*(1-a)+e[r]*a;return i}}function J(t){return J=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t},J(t)}function K(t,e){var r,n,i=J(e);return null==e||\"boolean\"===i?B(e):(\"number\"===i?H:\"string\"===i?(r=b(e))?(e=r,j):X:e instanceof b?j:e instanceof Date?q:(n=e,!ArrayBuffer.isView(n)||n instanceof DataView?Array.isArray(e)?V:\"function\"!=typeof e.valueOf&&\"function\"!=typeof e.toString||isNaN(e)?Z:H:$))(t,e)}},23648:function(t){\"use strict\";t.exports=JSON.parse('[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]')},2362:function(t){\"use strict\";t.exports=JSON.parse('[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]')},87486:function(t){\"use strict\";t.exports=JSON.parse('[\"normal\",\"italic\",\"oblique\"]')},99803:function(t){\"use strict\";t.exports=JSON.parse('[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]')},54324:function(t){\"use strict\";t.exports=JSON.parse('[\"inherit\",\"initial\",\"unset\"]')},94316:function(t){\"use strict\";t.exports=JSON.parse('[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]')},37071:function(t){\"use strict\";t.exports=JSON.parse('{\"version\":8,\"name\":\"orto\",\"metadata\":{\"maputnik:renderer\":\"mlgljs\"},\"center\":[1.537786,41.837539],\"zoom\":12,\"bearing\":0,\"pitch\":0,\"light\":{\"anchor\":\"viewport\",\"color\":\"white\",\"intensity\":0.4,\"position\":[1.15,45,30]},\"sources\":{\"ortoEsri\":{\"type\":\"raster\",\"tiles\":[\"https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}\"],\"tileSize\":256,\"maxzoom\":18,\"attribution\":\"ESRI &copy; <a href=\\'http://www.esri.com\\'>ESRI</a>\"},\"ortoInstaMaps\":{\"type\":\"raster\",\"tiles\":[\"https://tilemaps.icgc.cat/mapfactory/wmts/orto_8_12/CAT3857/{z}/{x}/{y}.png\"],\"tileSize\":256,\"maxzoom\":13},\"ortoICGC\":{\"type\":\"raster\",\"tiles\":[\"https://geoserveis.icgc.cat/icc_mapesmultibase/noutm/wmts/orto/GRID3857/{z}/{x}/{y}.jpeg\"],\"tileSize\":256,\"minzoom\":13.1,\"maxzoom\":20},\"openmaptiles\":{\"type\":\"vector\",\"url\":\"https://geoserveis.icgc.cat/contextmaps/basemap.json\"}},\"sprite\":\"https://geoserveis.icgc.cat/contextmaps/sprites/sprite@1\",\"glyphs\":\"https://geoserveis.icgc.cat/contextmaps/glyphs/{fontstack}/{range}.pbf\",\"layers\":[{\"id\":\"background\",\"type\":\"background\",\"paint\":{\"background-color\":\"#F4F9F4\"}},{\"id\":\"ortoEsri\",\"type\":\"raster\",\"source\":\"ortoEsri\",\"maxzoom\":16,\"layout\":{\"visibility\":\"visible\"}},{\"id\":\"ortoICGC\",\"type\":\"raster\",\"source\":\"ortoICGC\",\"minzoom\":13.1,\"maxzoom\":19,\"layout\":{\"visibility\":\"visible\"}},{\"id\":\"ortoInstaMaps\",\"type\":\"raster\",\"source\":\"ortoInstaMaps\",\"maxzoom\":13,\"layout\":{\"visibility\":\"visible\"}},{\"id\":\"waterway_tunnel\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"waterway\",\"minzoom\":14,\"filter\":[\"all\",[\"in\",\"class\",\"river\",\"stream\",\"canal\"],[\"==\",\"brunnel\",\"tunnel\"]],\"layout\":{\"line-cap\":\"round\"},\"paint\":{\"line-color\":\"#a0c8f0\",\"line-width\":{\"base\":1.3,\"stops\":[[13,0.5],[20,6]]},\"line-dasharray\":[2,4]}},{\"id\":\"waterway-other\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849382550.77\"},\"source\":\"openmaptiles\",\"source-layer\":\"waterway\",\"filter\":[\"!in\",\"class\",\"canal\",\"river\",\"stream\"],\"layout\":{\"line-cap\":\"round\"},\"paint\":{\"line-color\":\"#a0c8f0\",\"line-width\":{\"base\":1.3,\"stops\":[[13,0.5],[20,2]]}}},{\"id\":\"waterway-stream-canal\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849382550.77\"},\"source\":\"openmaptiles\",\"source-layer\":\"waterway\",\"filter\":[\"all\",[\"in\",\"class\",\"canal\",\"stream\"],[\"!=\",\"brunnel\",\"tunnel\"]],\"layout\":{\"line-cap\":\"round\"},\"paint\":{\"line-color\":\"#a0c8f0\",\"line-width\":{\"base\":1.3,\"stops\":[[13,0.5],[20,6]]}}},{\"id\":\"waterway-river\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849382550.77\"},\"source\":\"openmaptiles\",\"source-layer\":\"waterway\",\"filter\":[\"all\",[\"==\",\"class\",\"river\"],[\"!=\",\"brunnel\",\"tunnel\"]],\"layout\":{\"line-cap\":\"round\"},\"paint\":{\"line-color\":\"#a0c8f0\",\"line-width\":{\"base\":1.2,\"stops\":[[10,0.8],[20,4]]},\"line-opacity\":0.5}},{\"id\":\"water-offset\",\"type\":\"fill\",\"metadata\":{\"mapbox:group\":\"1444849382550.77\"},\"source\":\"openmaptiles\",\"source-layer\":\"water\",\"maxzoom\":8,\"filter\":[\"==\",\"$type\",\"Polygon\"],\"layout\":{\"visibility\":\"visible\"},\"paint\":{\"fill-opacity\":0,\"fill-color\":\"#a0c8f0\",\"fill-translate\":{\"base\":1,\"stops\":[[6,[2,0]],[8,[0,0]]]}}},{\"id\":\"water\",\"type\":\"fill\",\"metadata\":{\"mapbox:group\":\"1444849382550.77\"},\"source\":\"openmaptiles\",\"source-layer\":\"water\",\"layout\":{\"visibility\":\"visible\"},\"paint\":{\"fill-color\":\"hsl(210, 67%, 85%)\",\"fill-opacity\":0}},{\"id\":\"water-pattern\",\"type\":\"fill\",\"metadata\":{\"mapbox:group\":\"1444849382550.77\"},\"source\":\"openmaptiles\",\"source-layer\":\"water\",\"layout\":{\"visibility\":\"visible\"},\"paint\":{\"fill-translate\":[0,2.5],\"fill-pattern\":\"wave\",\"fill-opacity\":1}},{\"id\":\"landcover-ice-shelf\",\"type\":\"fill\",\"metadata\":{\"mapbox:group\":\"1444849382550.77\"},\"source\":\"openmaptiles\",\"source-layer\":\"landcover\",\"filter\":[\"==\",\"subclass\",\"ice_shelf\"],\"layout\":{\"visibility\":\"visible\"},\"paint\":{\"fill-color\":\"#fff\",\"fill-opacity\":{\"base\":1,\"stops\":[[0,0.9],[10,0.3]]}}},{\"id\":\"tunnel-service-track-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"service\",\"track\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#cfcdca\",\"line-dasharray\":[0.5,0.25],\"line-width\":{\"base\":1.2,\"stops\":[[15,1],[16,4],[20,11]]}}},{\"id\":\"tunnel-minor-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"==\",\"class\",\"minor\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#cfcdca\",\"line-opacity\":{\"stops\":[[12,0],[12.5,1]]},\"line-width\":{\"base\":1.2,\"stops\":[[12,0.5],[13,1],[14,4],[20,15]]}}},{\"id\":\"tunnel-secondary-tertiary-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"secondary\",\"tertiary\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":1,\"line-width\":{\"base\":1.2,\"stops\":[[8,1.5],[20,17]]}}},{\"id\":\"tunnel-trunk-primary-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"primary\",\"trunk\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-width\":{\"base\":1.2,\"stops\":[[5,0.4],[6,0.6],[7,1.5],[20,22]]},\"line-opacity\":0.7}},{\"id\":\"tunnel-motorway-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"==\",\"class\",\"motorway\"]],\"layout\":{\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-dasharray\":[0.5,0.25],\"line-width\":{\"base\":1.2,\"stops\":[[5,0.4],[6,0.6],[7,1.5],[20,22]]},\"line-opacity\":0.5}},{\"id\":\"tunnel-path\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"==\",\"class\",\"path\"]]],\"paint\":{\"line-color\":\"#cba\",\"line-dasharray\":[1.5,0.75],\"line-width\":{\"base\":1.2,\"stops\":[[15,1.2],[20,4]]}}},{\"id\":\"tunnel-service-track\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"service\",\"track\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fff\",\"line-width\":{\"base\":1.2,\"stops\":[[15.5,0],[16,2],[20,7.5]]}}},{\"id\":\"tunnel-minor\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"==\",\"class\",\"minor_road\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fff\",\"line-opacity\":1,\"line-width\":{\"base\":1.2,\"stops\":[[13.5,0],[14,2.5],[20,11.5]]}}},{\"id\":\"tunnel-secondary-tertiary\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"secondary\",\"tertiary\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fff4c6\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,10]]}}},{\"id\":\"tunnel-trunk-primary\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"primary\",\"trunk\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fff4c6\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,18]]},\"line-opacity\":0.5}},{\"id\":\"tunnel-motorway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"==\",\"class\",\"motorway\"]],\"layout\":{\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#ffdaa6\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,18]]},\"line-opacity\":0.5}},{\"id\":\"tunnel-railway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849354174.1904\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"tunnel\"],[\"==\",\"class\",\"rail\"]],\"paint\":{\"line-color\":\"#bbb\",\"line-width\":{\"base\":1.4,\"stops\":[[14,0.4],[15,0.75],[20,2]]},\"line-dasharray\":[2,2]}},{\"id\":\"ferry\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"in\",\"class\",\"ferry\"]],\"layout\":{\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"rgba(108, 159, 182, 1)\",\"line-width\":1.1,\"line-dasharray\":[2,2]}},{\"id\":\"aeroway-taxiway-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"aeroway\",\"minzoom\":12,\"filter\":[\"all\",[\"in\",\"class\",\"taxiway\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"rgba(153, 153, 153, 1)\",\"line-width\":{\"base\":1.5,\"stops\":[[11,2],[17,12]]},\"line-opacity\":1}},{\"id\":\"aeroway-runway-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"aeroway\",\"minzoom\":12,\"filter\":[\"all\",[\"in\",\"class\",\"runway\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"rgba(153, 153, 153, 1)\",\"line-width\":{\"base\":1.5,\"stops\":[[11,5],[17,55]]},\"line-opacity\":1}},{\"id\":\"aeroway-taxiway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"aeroway\",\"minzoom\":4,\"filter\":[\"all\",[\"in\",\"class\",\"taxiway\"],[\"==\",\"$type\",\"LineString\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"rgba(255, 255, 255, 1)\",\"line-width\":{\"base\":1.5,\"stops\":[[11,1],[17,10]]},\"line-opacity\":{\"base\":1,\"stops\":[[11,0],[12,1]]}}},{\"id\":\"aeroway-runway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"aeroway\",\"minzoom\":4,\"filter\":[\"all\",[\"in\",\"class\",\"runway\"],[\"==\",\"$type\",\"LineString\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"rgba(255, 255, 255, 1)\",\"line-width\":{\"base\":1.5,\"stops\":[[11,4],[17,50]]},\"line-opacity\":{\"base\":1,\"stops\":[[11,0],[12,1]]}}},{\"id\":\"highway-motorway-link-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":12,\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"==\",\"class\",\"motorway_link\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":1,\"line-width\":{\"base\":1.2,\"stops\":[[12,1],[13,3],[14,4],[20,15]]}}},{\"id\":\"highway-link-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":13,\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"primary_link\",\"secondary_link\",\"tertiary_link\",\"trunk_link\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":1,\"line-width\":{\"base\":1.2,\"stops\":[[12,1],[13,3],[14,4],[20,15]]}}},{\"id\":\"highway-minor-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!=\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"minor\",\"service\",\"track\"]]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#cfcdca\",\"line-opacity\":{\"stops\":[[12,0],[12.5,0]]},\"line-width\":{\"base\":1.2,\"stops\":[[12,0.5],[13,1],[14,4],[20,15]]}}},{\"id\":\"highway-secondary-tertiary-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"secondary\",\"tertiary\"]],\"layout\":{\"line-cap\":\"butt\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":0.5,\"line-width\":{\"base\":1.2,\"stops\":[[8,1.5],[20,17]]}}},{\"id\":\"highway-primary-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":5,\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"primary\"]],\"layout\":{\"line-cap\":\"butt\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":{\"stops\":[[7,0],[8,0.6]]},\"line-width\":{\"base\":1.2,\"stops\":[[7,0],[8,0.6],[9,1.5],[20,22]]}}},{\"id\":\"highway-trunk-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":5,\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"trunk\"]],\"layout\":{\"line-cap\":\"butt\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":{\"stops\":[[5,0],[6,0.5]]},\"line-width\":{\"base\":1.2,\"stops\":[[5,0],[6,0.6],[7,1.5],[20,22]]}}},{\"id\":\"highway-motorway-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":4,\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"==\",\"class\",\"motorway\"]],\"layout\":{\"line-cap\":\"butt\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-width\":{\"base\":1.2,\"stops\":[[4,0],[5,0.4],[6,0.6],[7,1.5],[20,22]]},\"line-opacity\":{\"stops\":[[4,0],[5,0.5]]}}},{\"id\":\"highway-path\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"==\",\"class\",\"path\"]]],\"paint\":{\"line-color\":\"#cba\",\"line-dasharray\":[1.5,0.75],\"line-width\":{\"base\":1.2,\"stops\":[[15,1.2],[20,4]]}}},{\"id\":\"highway-motorway-link\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":12,\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"==\",\"class\",\"motorway_link\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fc8\",\"line-width\":{\"base\":1.2,\"stops\":[[12.5,0],[13,1.5],[14,2.5],[20,11.5]]}}},{\"id\":\"highway-link\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":13,\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"primary_link\",\"secondary_link\",\"tertiary_link\",\"trunk_link\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#fea\",\"line-width\":{\"base\":1.2,\"stops\":[[12.5,0],[13,1.5],[14,2.5],[20,11.5]]}}},{\"id\":\"highway-minor\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!=\",\"brunnel\",\"tunnel\"],[\"in\",\"class\",\"minor\",\"service\",\"track\"]]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fff\",\"line-opacity\":0.5,\"line-width\":{\"base\":1.2,\"stops\":[[13.5,0],[14,2.5],[20,11.5]]}}},{\"id\":\"highway-secondary-tertiary\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"secondary\",\"tertiary\"]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#fea\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[8,0.5],[20,13]]},\"line-opacity\":0.5}},{\"id\":\"highway-primary\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"primary\"]]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#fea\",\"line-width\":{\"base\":1.2,\"stops\":[[8.5,0],[9,0.5],[20,18]]},\"line-opacity\":0}},{\"id\":\"highway-trunk\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"in\",\"class\",\"trunk\"]]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#fea\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,18]]},\"line-opacity\":0.5}},{\"id\":\"highway-motorway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":5,\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"==\",\"class\",\"motorway\"]]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\",\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"#fc8\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,18]]},\"line-opacity\":0.5}},{\"id\":\"railway-transit\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"==\",\"class\",\"transit\"],[\"!in\",\"brunnel\",\"tunnel\"]]],\"layout\":{\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"hsla(0, 0%, 73%, 0.77)\",\"line-width\":{\"base\":1.4,\"stops\":[[14,0.4],[20,1]]}}},{\"id\":\"railway-transit-hatching\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"==\",\"class\",\"transit\"],[\"!in\",\"brunnel\",\"tunnel\"]]],\"layout\":{\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"hsla(0, 0%, 73%, 0.68)\",\"line-dasharray\":[0.2,8],\"line-width\":{\"base\":1.4,\"stops\":[[14.5,0],[15,2],[20,6]]}}},{\"id\":\"railway-service\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"==\",\"class\",\"rail\"],[\"has\",\"service\"]]],\"paint\":{\"line-color\":\"hsla(0, 0%, 73%, 0.77)\",\"line-width\":{\"base\":1.4,\"stops\":[[14,0.4],[20,1]]}}},{\"id\":\"railway-service-hatching\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"==\",\"class\",\"rail\"],[\"has\",\"service\"]]],\"layout\":{\"visibility\":\"visible\"},\"paint\":{\"line-color\":\"hsla(0, 0%, 73%, 0.68)\",\"line-dasharray\":[0.2,8],\"line-width\":{\"base\":1.4,\"stops\":[[14.5,0],[15,2],[20,6]]}}},{\"id\":\"railway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!has\",\"service\"],[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"==\",\"class\",\"rail\"]]],\"paint\":{\"line-color\":\"#bbb\",\"line-width\":{\"base\":1.4,\"stops\":[[14,0.4],[15,0.75],[20,2]]}}},{\"id\":\"railway-hatching\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849345966.4436\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"!has\",\"service\"],[\"!in\",\"brunnel\",\"bridge\",\"tunnel\"],[\"==\",\"class\",\"rail\"]]],\"paint\":{\"line-color\":\"#bbb\",\"line-dasharray\":[0.2,8],\"line-width\":{\"base\":1.4,\"stops\":[[14.5,0],[15,3],[20,8]]}}},{\"id\":\"bridge-motorway-link-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"motorway_link\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":1,\"line-width\":{\"base\":1.2,\"stops\":[[12,1],[13,3],[14,4],[20,15]]}}},{\"id\":\"bridge-link-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"in\",\"class\",\"primary_link\",\"secondary_link\",\"tertiary_link\",\"trunk_link\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":1,\"line-width\":{\"base\":1.2,\"stops\":[[12,1],[13,3],[14,4],[20,15]]}}},{\"id\":\"bridge-secondary-tertiary-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"in\",\"class\",\"secondary\",\"tertiary\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-opacity\":1,\"line-width\":{\"base\":1.2,\"stops\":[[8,1.5],[20,28]]}}},{\"id\":\"bridge-trunk-primary-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"in\",\"class\",\"primary\",\"trunk\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"hsl(28, 76%, 67%)\",\"line-width\":{\"base\":1.2,\"stops\":[[5,0.4],[6,0.6],[7,1.5],[20,26]]}}},{\"id\":\"bridge-motorway-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"motorway\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#e9ac77\",\"line-width\":{\"base\":1.2,\"stops\":[[5,0.4],[6,0.6],[7,1.5],[20,22]]},\"line-opacity\":0.5}},{\"id\":\"bridge-path-casing\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"path\"]]],\"paint\":{\"line-color\":\"#f8f4f0\",\"line-width\":{\"base\":1.2,\"stops\":[[15,1.2],[20,18]]}}},{\"id\":\"bridge-path\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"path\"]]],\"paint\":{\"line-color\":\"#cba\",\"line-width\":{\"base\":1.2,\"stops\":[[15,1.2],[20,4]]},\"line-dasharray\":[1.5,0.75]}},{\"id\":\"bridge-motorway-link\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"motorway_link\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fc8\",\"line-width\":{\"base\":1.2,\"stops\":[[12.5,0],[13,1.5],[14,2.5],[20,11.5]]}}},{\"id\":\"bridge-link\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"in\",\"class\",\"primary_link\",\"secondary_link\",\"tertiary_link\",\"trunk_link\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fea\",\"line-width\":{\"base\":1.2,\"stops\":[[12.5,0],[13,1.5],[14,2.5],[20,11.5]]}}},{\"id\":\"bridge-secondary-tertiary\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"in\",\"class\",\"secondary\",\"tertiary\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fea\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,20]]}}},{\"id\":\"bridge-trunk-primary\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"in\",\"class\",\"primary\",\"trunk\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fea\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,18]]}}},{\"id\":\"bridge-motorway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"motorway\"]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#fc8\",\"line-width\":{\"base\":1.2,\"stops\":[[6.5,0],[7,0.5],[20,18]]},\"line-opacity\":0.5}},{\"id\":\"bridge-railway\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"rail\"]],\"paint\":{\"line-color\":\"#bbb\",\"line-width\":{\"base\":1.4,\"stops\":[[14,0.4],[15,0.75],[20,2]]}}},{\"id\":\"bridge-railway-hatching\",\"type\":\"line\",\"metadata\":{\"mapbox:group\":\"1444849334699.1902\"},\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"filter\":[\"all\",[\"==\",\"brunnel\",\"bridge\"],[\"==\",\"class\",\"rail\"]],\"paint\":{\"line-color\":\"#bbb\",\"line-dasharray\":[0.2,8],\"line-width\":{\"base\":1.4,\"stops\":[[14.5,0],[15,3],[20,8]]}}},{\"id\":\"cablecar\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":13,\"filter\":[\"==\",\"class\",\"cable_car\"],\"layout\":{\"visibility\":\"visible\",\"line-cap\":\"round\"},\"paint\":{\"line-color\":\"hsl(0, 0%, 70%)\",\"line-width\":{\"base\":1,\"stops\":[[11,1],[19,2.5]]}}},{\"id\":\"cablecar-dash\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":13,\"filter\":[\"==\",\"class\",\"cable_car\"],\"layout\":{\"visibility\":\"visible\",\"line-cap\":\"round\"},\"paint\":{\"line-color\":\"hsl(0, 0%, 70%)\",\"line-width\":{\"base\":1,\"stops\":[[11,3],[19,5.5]]},\"line-dasharray\":[2,3]}},{\"id\":\"boundary-land-level-4\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"boundary\",\"filter\":[\"all\",[\">=\",\"admin_level\",4],[\"<=\",\"admin_level\",8],[\"!=\",\"maritime\",1]],\"layout\":{\"line-join\":\"round\"},\"paint\":{\"line-color\":\"#9e9cab\",\"line-dasharray\":[3,1,1,1],\"line-width\":{\"base\":1.4,\"stops\":[[4,0.4],[5,1],[12,3]]},\"line-opacity\":0.6}},{\"id\":\"boundary-land-level-2\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"boundary\",\"filter\":[\"all\",[\"==\",\"admin_level\",2],[\"!=\",\"maritime\",1],[\"!=\",\"disputed\",1]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\"},\"paint\":{\"line-color\":\"hsl(248, 7%, 66%)\",\"line-width\":{\"base\":1,\"stops\":[[0,0.6],[4,1.4],[5,2],[12,2]]}}},{\"id\":\"boundary-land-disputed\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"boundary\",\"filter\":[\"all\",[\"!=\",\"maritime\",1],[\"==\",\"disputed\",1]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\"},\"paint\":{\"line-color\":\"hsl(248, 7%, 70%)\",\"line-dasharray\":[1,3],\"line-width\":{\"base\":1,\"stops\":[[0,0.6],[4,1.4],[5,2],[12,8]]}}},{\"id\":\"boundary-water\",\"type\":\"line\",\"source\":\"openmaptiles\",\"source-layer\":\"boundary\",\"filter\":[\"all\",[\"in\",\"admin_level\",2,4],[\"==\",\"maritime\",1]],\"layout\":{\"line-cap\":\"round\",\"line-join\":\"round\"},\"paint\":{\"line-color\":\"rgba(154, 189, 214, 1)\",\"line-width\":{\"base\":1,\"stops\":[[0,0.6],[4,1],[5,1],[12,1]]},\"line-opacity\":{\"stops\":[[6,0],[10,0]]}}},{\"id\":\"waterway-name\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"waterway\",\"minzoom\":13,\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"has\",\"name\"]],\"layout\":{\"text-font\":[\"Noto Sans Italic\"],\"text-size\":14,\"text-field\":\"{name:latin} {name:nonlatin}\",\"text-max-width\":5,\"text-rotation-alignment\":\"map\",\"symbol-placement\":\"line\",\"text-letter-spacing\":0.2,\"symbol-spacing\":350},\"paint\":{\"text-color\":\"#74aee9\",\"text-halo-width\":1.5,\"text-halo-color\":\"rgba(255,255,255,0.7)\"}},{\"id\":\"water-name-lakeline\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"water_name\",\"filter\":[\"==\",\"$type\",\"LineString\"],\"layout\":{\"text-font\":[\"Noto Sans Italic\"],\"text-size\":14,\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-max-width\":5,\"text-rotation-alignment\":\"map\",\"symbol-placement\":\"line\",\"symbol-spacing\":350,\"text-letter-spacing\":0.2},\"paint\":{\"text-color\":\"#74aee9\",\"text-halo-width\":1.5,\"text-halo-color\":\"rgba(255,255,255,0.7)\"}},{\"id\":\"water-name-ocean\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"water_name\",\"filter\":[\"all\",[\"==\",\"$type\",\"Point\"],[\"==\",\"class\",\"ocean\"]],\"layout\":{\"text-font\":[\"Noto Sans Italic\"],\"text-size\":14,\"text-field\":\"{name:latin}\",\"text-max-width\":5,\"text-rotation-alignment\":\"map\",\"symbol-placement\":\"point\",\"symbol-spacing\":350,\"text-letter-spacing\":0.2},\"paint\":{\"text-color\":\"#74aee9\",\"text-halo-width\":1.5,\"text-halo-color\":\"rgba(255,255,255,0.7)\"}},{\"id\":\"water-name-other\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"water_name\",\"filter\":[\"all\",[\"==\",\"$type\",\"Point\"],[\"!in\",\"class\",\"ocean\"]],\"layout\":{\"text-font\":[\"Noto Sans Italic\"],\"text-size\":{\"stops\":[[0,10],[6,14]]},\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-max-width\":5,\"text-rotation-alignment\":\"map\",\"symbol-placement\":\"point\",\"symbol-spacing\":350,\"text-letter-spacing\":0.2,\"visibility\":\"visible\"},\"paint\":{\"text-color\":\"#74aee9\",\"text-halo-width\":1.5,\"text-halo-color\":\"rgba(255,255,255,0.7)\"}},{\"id\":\"poi-level-3\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"poi\",\"minzoom\":16,\"filter\":[\"all\",[\"==\",\"$type\",\"Point\"],[\">=\",\"rank\",25]],\"layout\":{\"text-padding\":2,\"text-font\":[\"Noto Sans Regular\"],\"text-anchor\":\"top\",\"icon-image\":\"{class}_11\",\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-offset\":[0,0.6],\"text-size\":12,\"text-max-width\":9},\"paint\":{\"text-halo-blur\":0.5,\"text-color\":\"#666\",\"text-halo-width\":1,\"text-halo-color\":\"#ffffff\"}},{\"id\":\"poi-level-2\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"poi\",\"minzoom\":15,\"filter\":[\"all\",[\"==\",\"$type\",\"Point\"],[\"<=\",\"rank\",24],[\">=\",\"rank\",15]],\"layout\":{\"text-padding\":2,\"text-font\":[\"Noto Sans Regular\"],\"text-anchor\":\"top\",\"icon-image\":\"{class}_11\",\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-offset\":[0,0.6],\"text-size\":12,\"text-max-width\":9},\"paint\":{\"text-halo-blur\":0.5,\"text-color\":\"#666\",\"text-halo-width\":1,\"text-halo-color\":\"#ffffff\"}},{\"id\":\"poi-level-1\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"poi\",\"minzoom\":14,\"filter\":[\"all\",[\"==\",\"$type\",\"Point\"],[\"<=\",\"rank\",14],[\"has\",\"name\"]],\"layout\":{\"text-padding\":2,\"text-font\":[\"Noto Sans Regular\"],\"text-anchor\":\"top\",\"icon-image\":\"{class}_11\",\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-offset\":[0,0.6],\"text-size\":11,\"text-max-width\":9},\"paint\":{\"text-halo-blur\":0.5,\"text-color\":\"rgba(191, 228, 172, 1)\",\"text-halo-width\":1,\"text-halo-color\":\"rgba(30, 29, 29, 1)\"}},{\"id\":\"poi-railway\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"poi\",\"minzoom\":13,\"filter\":[\"all\",[\"==\",\"$type\",\"Point\"],[\"has\",\"name\"],[\"==\",\"class\",\"railway\"],[\"==\",\"subclass\",\"station\"]],\"layout\":{\"text-padding\":2,\"text-font\":[\"Noto Sans Regular\"],\"text-anchor\":\"top\",\"icon-image\":\"{class}_11\",\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-offset\":[0,0.6],\"text-size\":12,\"text-max-width\":9,\"icon-optional\":false,\"icon-ignore-placement\":false,\"icon-allow-overlap\":false,\"text-ignore-placement\":false,\"text-allow-overlap\":false,\"text-optional\":true},\"paint\":{\"text-halo-blur\":0.5,\"text-color\":\"#666\",\"text-halo-width\":1,\"text-halo-color\":\"#ffffff\"}},{\"id\":\"road_oneway\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":15,\"filter\":[\"all\",[\"==\",\"oneway\",1],[\"in\",\"class\",\"motorway\",\"trunk\",\"primary\",\"secondary\",\"tertiary\",\"minor\",\"service\"]],\"layout\":{\"symbol-placement\":\"line\",\"icon-image\":\"oneway\",\"symbol-spacing\":75,\"icon-padding\":2,\"icon-rotation-alignment\":\"map\",\"icon-rotate\":90,\"icon-size\":{\"stops\":[[15,0.5],[19,1]]}},\"paint\":{\"icon-opacity\":0.5}},{\"id\":\"road_oneway_opposite\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation\",\"minzoom\":15,\"filter\":[\"all\",[\"==\",\"oneway\",-1],[\"in\",\"class\",\"motorway\",\"trunk\",\"primary\",\"secondary\",\"tertiary\",\"minor\",\"service\"]],\"layout\":{\"symbol-placement\":\"line\",\"icon-image\":\"oneway\",\"symbol-spacing\":75,\"icon-padding\":2,\"icon-rotation-alignment\":\"map\",\"icon-rotate\":-90,\"icon-size\":{\"stops\":[[15,0.5],[19,1]]}},\"paint\":{\"icon-opacity\":0.5}},{\"id\":\"highway-name-path\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation_name\",\"minzoom\":15.5,\"filter\":[\"==\",\"class\",\"path\"],\"layout\":{\"text-size\":{\"base\":1,\"stops\":[[13,12],[14,13]]},\"text-font\":[\"Noto Sans Regular\"],\"text-field\":\"{name:latin} {name:nonlatin}\",\"symbol-placement\":\"line\",\"text-rotation-alignment\":\"map\"},\"paint\":{\"text-halo-color\":\"#f8f4f0\",\"text-color\":\"hsl(30, 23%, 62%)\",\"text-halo-width\":0.5}},{\"id\":\"highway-name-minor\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation_name\",\"minzoom\":15,\"filter\":[\"all\",[\"==\",\"$type\",\"LineString\"],[\"in\",\"class\",\"minor\",\"service\",\"track\"]],\"layout\":{\"text-size\":{\"base\":1,\"stops\":[[13,12],[14,13]]},\"text-font\":[\"Noto Sans Regular\"],\"text-field\":\"{name:latin} {name:nonlatin}\",\"symbol-placement\":\"line\",\"text-rotation-alignment\":\"map\"},\"paint\":{\"text-halo-blur\":0.5,\"text-color\":\"#765\",\"text-halo-width\":1}},{\"id\":\"highway-name-major\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation_name\",\"minzoom\":12.2,\"filter\":[\"in\",\"class\",\"primary\",\"secondary\",\"tertiary\",\"trunk\"],\"layout\":{\"text-size\":{\"base\":1,\"stops\":[[13,12],[14,13]]},\"text-font\":[\"Noto Sans Regular\"],\"text-field\":\"{name:latin} {name:nonlatin}\",\"symbol-placement\":\"line\",\"text-rotation-alignment\":\"map\"},\"paint\":{\"text-halo-blur\":0.5,\"text-color\":\"#765\",\"text-halo-width\":1}},{\"id\":\"highway-shield\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation_name\",\"minzoom\":8,\"filter\":[\"all\",[\"<=\",\"ref_length\",6],[\"==\",\"$type\",\"LineString\"],[\"!in\",\"network\",\"us-interstate\",\"us-highway\",\"us-state\"]],\"layout\":{\"text-size\":10,\"icon-image\":\"road_{ref_length}\",\"icon-rotation-alignment\":\"viewport\",\"symbol-spacing\":200,\"text-font\":[\"Noto Sans Regular\"],\"symbol-placement\":{\"base\":1,\"stops\":[[10,\"point\"],[11,\"line\"]]},\"text-rotation-alignment\":\"viewport\",\"icon-size\":1,\"text-field\":\"{ref}\"},\"paint\":{\"text-opacity\":1,\"text-color\":\"rgba(20, 19, 19, 1)\",\"text-halo-color\":\"rgba(230, 221, 221, 0)\",\"text-halo-width\":2,\"icon-color\":\"rgba(183, 18, 18, 1)\",\"icon-opacity\":0.3,\"icon-halo-color\":\"rgba(183, 55, 55, 0)\"}},{\"id\":\"highway-shield-us-interstate\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation_name\",\"minzoom\":7,\"filter\":[\"all\",[\"<=\",\"ref_length\",6],[\"==\",\"$type\",\"LineString\"],[\"in\",\"network\",\"us-interstate\"]],\"layout\":{\"text-size\":10,\"icon-image\":\"{network}_{ref_length}\",\"icon-rotation-alignment\":\"viewport\",\"symbol-spacing\":200,\"text-font\":[\"Noto Sans Regular\"],\"symbol-placement\":{\"base\":1,\"stops\":[[7,\"point\"],[7,\"line\"],[8,\"line\"]]},\"text-rotation-alignment\":\"viewport\",\"icon-size\":1,\"text-field\":\"{ref}\"},\"paint\":{\"text-color\":\"rgba(0, 0, 0, 1)\"}},{\"id\":\"highway-shield-us-other\",\"type\":\"symbol\",\"source\":\"openmaptiles\",\"source-layer\":\"transportation_name\",\"minzoom\":9,\"filter\":[\"all\",[\"<=\",\"ref_length\",6],[\"==\",\"$type\",\"LineString\"],[\"in\",\"network\",\"us-highway\",\"us-state\"]],\"layout\":{\"text-size\":10,\"icon-image\":\"{network}_{ref_length}\",\"icon-rotation-alignment\":\"viewport\",\"symbol-spacing\":200,\"text-font\":[\"Noto Sans Regular\"],\"symbol-placement\":{\"base\":1,\"stops\":[[10,\"point\"],[11,\"line\"]]},\"text-rotation-alignment\":\"viewport\",\"icon-size\":1,\"text-field\":\"{ref}\"},\"paint\":{\"text-color\":\"rgba(0, 0, 0, 1)\"}},{\"id\":\"place-other\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"minzoom\":12,\"filter\":[\"!in\",\"class\",\"city\",\"town\",\"village\",\"country\",\"continent\"],\"layout\":{\"text-letter-spacing\":0.1,\"text-size\":{\"base\":1.2,\"stops\":[[12,10],[15,14]]},\"text-font\":[\"Noto Sans Bold\"],\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-transform\":\"uppercase\",\"text-max-width\":9,\"visibility\":\"visible\"},\"paint\":{\"text-color\":\"rgba(255,255,255,1)\",\"text-halo-width\":1.2,\"text-halo-color\":\"rgba(57, 28, 28, 1)\"}},{\"id\":\"place-village\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"minzoom\":10,\"filter\":[\"==\",\"class\",\"village\"],\"layout\":{\"text-font\":[\"Noto Sans Regular\"],\"text-size\":{\"base\":1.2,\"stops\":[[10,12],[15,16]]},\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-max-width\":8,\"visibility\":\"visible\"},\"paint\":{\"text-color\":\"rgba(255, 255, 255, 1)\",\"text-halo-width\":1.2,\"text-halo-color\":\"rgba(10, 9, 9, 0.8)\"}},{\"id\":\"place-town\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"filter\":[\"==\",\"class\",\"town\"],\"layout\":{\"text-font\":[\"Noto Sans Regular\"],\"text-size\":{\"base\":1.2,\"stops\":[[10,14],[15,24]]},\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-max-width\":8,\"visibility\":\"visible\"},\"paint\":{\"text-color\":\"rgba(255, 255, 255, 1)\",\"text-halo-width\":1.2,\"text-halo-color\":\"rgba(22, 22, 22, 0.8)\"}},{\"id\":\"place-city\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"filter\":[\"all\",[\"!=\",\"capital\",2],[\"==\",\"class\",\"city\"]],\"layout\":{\"text-font\":[\"Noto Sans Regular\"],\"text-size\":{\"base\":1.2,\"stops\":[[7,14],[11,24]]},\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-max-width\":8,\"visibility\":\"visible\"},\"paint\":{\"text-color\":\"rgba(0, 0, 0, 1)\",\"text-halo-width\":1.2,\"text-halo-color\":\"rgba(255,255,255,0.8)\"}},{\"id\":\"place-city-capital\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"filter\":[\"all\",[\"==\",\"capital\",2],[\"==\",\"class\",\"city\"]],\"layout\":{\"text-font\":[\"Noto Sans Regular\"],\"text-size\":{\"base\":1.2,\"stops\":[[7,14],[11,24]]},\"text-field\":\"{name:latin}\\\\n{name:nonlatin}\",\"text-max-width\":8,\"icon-image\":\"star_11\",\"text-offset\":[0.4,0],\"icon-size\":0.8,\"text-anchor\":\"left\",\"visibility\":\"visible\"},\"paint\":{\"text-color\":\"#333\",\"text-halo-width\":1.2,\"text-halo-color\":\"rgba(255,255,255,0.8)\"}},{\"id\":\"place-country-other\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"filter\":[\"all\",[\"==\",\"class\",\"country\"],[\">=\",\"rank\",3],[\"!has\",\"iso_a2\"]],\"layout\":{\"text-font\":[\"Noto Sans Italic\"],\"text-field\":\"{name:latin}\",\"text-size\":{\"stops\":[[3,11],[7,17]]},\"text-transform\":\"uppercase\",\"text-max-width\":6.25,\"visibility\":\"visible\"},\"paint\":{\"text-halo-blur\":1,\"text-color\":\"#334\",\"text-halo-width\":2,\"text-halo-color\":\"rgba(255,255,255,0.8)\"}},{\"id\":\"place-country-3\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"filter\":[\"all\",[\"==\",\"class\",\"country\"],[\">=\",\"rank\",3],[\"has\",\"iso_a2\"]],\"layout\":{\"text-font\":[\"Noto Sans Bold\"],\"text-field\":\"{name:latin}\",\"text-size\":{\"stops\":[[3,11],[7,17]]},\"text-transform\":\"uppercase\",\"text-max-width\":6.25,\"visibility\":\"visible\"},\"paint\":{\"text-halo-blur\":1,\"text-color\":\"#334\",\"text-halo-width\":2,\"text-halo-color\":\"rgba(255,255,255,0.8)\"}},{\"id\":\"place-country-2\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"filter\":[\"all\",[\"==\",\"class\",\"country\"],[\"==\",\"rank\",2],[\"has\",\"iso_a2\"]],\"layout\":{\"text-font\":[\"Noto Sans Bold\"],\"text-field\":\"{name:latin}\",\"text-size\":{\"stops\":[[2,11],[5,17]]},\"text-transform\":\"uppercase\",\"text-max-width\":6.25,\"visibility\":\"visible\"},\"paint\":{\"text-halo-blur\":1,\"text-color\":\"#334\",\"text-halo-width\":2,\"text-halo-color\":\"rgba(255,255,255,0.8)\"}},{\"id\":\"place-country-1\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"filter\":[\"all\",[\"==\",\"class\",\"country\"],[\"==\",\"rank\",1],[\"has\",\"iso_a2\"]],\"layout\":{\"text-font\":[\"Noto Sans Bold\"],\"text-field\":\"{name:latin}\",\"text-size\":{\"stops\":[[1,11],[4,17]]},\"text-transform\":\"uppercase\",\"text-max-width\":6.25,\"visibility\":\"visible\"},\"paint\":{\"text-halo-blur\":1,\"text-color\":\"#334\",\"text-halo-width\":2,\"text-halo-color\":\"rgba(255,255,255,0.8)\"}},{\"id\":\"place-continent\",\"type\":\"symbol\",\"metadata\":{\"mapbox:group\":\"1444849242106.713\"},\"source\":\"openmaptiles\",\"source-layer\":\"place\",\"maxzoom\":1,\"filter\":[\"==\",\"class\",\"continent\"],\"layout\":{\"text-font\":[\"Noto Sans Bold\"],\"text-field\":\"{name:latin}\",\"text-size\":14,\"text-max-width\":6.25,\"text-transform\":\"uppercase\",\"visibility\":\"visible\"},\"paint\":{\"text-halo-blur\":1,\"text-color\":\"#334\",\"text-halo-width\":2,\"text-halo-color\":\"rgba(255,255,255,0.8)\"}}],\"id\":\"qebnlkra6\"}')},51962:function(t){\"use strict\";t.exports=JSON.parse('{\"version\":8,\"name\":\"orto\",\"metadata\":{},\"center\":[1.537786,41.837539],\"zoom\":12,\"bearing\":0,\"pitch\":0,\"light\":{\"anchor\":\"viewport\",\"color\":\"white\",\"intensity\":0.4,\"position\":[1.15,45,30]},\"sources\":{\"ortoEsri\":{\"type\":\"raster\",\"tiles\":[\"https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}\"],\"tileSize\":256,\"maxzoom\":18,\"attribution\":\"ESRI &copy; <a href=\\'http://www.esri.com\\'>ESRI</a>\"},\"ortoInstaMaps\":{\"type\":\"raster\",\"tiles\":[\"https://tilemaps.icgc.cat/mapfactory/wmts/orto_8_12/CAT3857/{z}/{x}/{y}.png\"],\"tileSize\":256,\"maxzoom\":13},\"ortoICGC\":{\"type\":\"raster\",\"tiles\":[\"https://geoserveis.icgc.cat/icc_mapesmultibase/noutm/wmts/orto/GRID3857/{z}/{x}/{y}.jpeg\"],\"tileSize\":256,\"minzoom\":13.1,\"maxzoom\":20},\"openmaptiles\":{\"type\":\"vector\",\"url\":\"https://geoserveis.icgc.cat/contextmaps/basemap.json\"}},\"sprite\":\"https://geoserveis.icgc.cat/contextmaps/sprites/sprite@1\",\"glyphs\":\"https://geoserveis.icgc.cat/contextmaps/glyphs/{fontstack}/{range}.pbf\",\"layers\":[{\"id\":\"background\",\"type\":\"background\",\"paint\":{\"background-color\":\"#F4F9F4\"}},{\"id\":\"ortoEsri\",\"type\":\"raster\",\"source\":\"ortoEsri\",\"maxzoom\":16,\"layout\":{\"visibility\":\"visible\"}},{\"id\":\"ortoICGC\",\"type\":\"raster\",\"source\":\"ortoICGC\",\"minzoom\":13.1,\"maxzoom\":19,\"layout\":{\"visibility\":\"visible\"}},{\"id\":\"ortoInstaMaps\",\"type\":\"raster\",\"source\":\"ortoInstaMaps\",\"maxzoom\":13,\"layout\":{\"visibility\":\"visible\"}}]}')}},e={};function r(n){var i=e[n];if(void 0!==i)return i.exports;var a=e[n]={id:n,exports:{}};return t[n].call(a.exports,a,a.exports,r),a.exports}return r.m=t,r.n=function(t){var e=t&&t.__esModule?function(){return t.default}:function(){return t};return r.d(e,{a:e}),e},r.d=function(t,e){for(var n in e)r.o(e,n)&&!r.o(t,n)&&Object.defineProperty(t,n,{enumerable:!0,get:e[n]})},r.g=function(){if(\"object\"==typeof globalThis)return globalThis;try{return this||new Function(\"return this\")()}catch(t){if(\"object\"==typeof window)return window}}(),r.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},r.r=function(t){\"undefined\"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:\"Module\"}),Object.defineProperty(t,\"__esModule\",{value:!0})},r.b=document.baseURI||self.location.href,r.nc=void 0,r(20260)}()}));\n", "        });\n", "        require(['plotly'], function(Plotly) {\n", "            window._Plotly = Plotly;\n", "        });\n", "        }\n", "        </script>\n", "        "]}, "metadata": {}, "output_type": "display_data"}, {"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"hovertemplate": "midpoint=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "", "marker": {"color": "lightsalmon", "symbol": "circle"}, "mode": "markers", "name": "", "showlegend": false, "type": "scattergl", "x": [4275, 4534, 4536, 4536, 4538, 4539, 4540, 4540, 4541, 4548, 66954, 66956, 66959, 68326, 104749, 104750, 104789, 104800, 104805, 135569, 135570, 135573, 463523, 637134, 709085, 709106, 785868, 1190816, 1190855, 1194218, 1212426, 1215344, 24682162, 8561, 71244, 9091, 9085, 9088, 9089, 9090, 9091, 9091, 9092, 9094, 9096, 9091, 9094, 9096, 9097, 9097, 9100, 9097, 9110, 109299, 109302, 109303, 109304, 109304, 109305, 109305, 109306, 109307, 109307, 109308, 109308, 109309, 109312, 133924, 133928, 133930, 133931, 171719, 135890, 171721, 171722, 136664, 173088, 137849, 173680, 209499, 209500, 209501, 209502, 209503, 209505, 209506, 209510, 209511, 209521, 209529, 209529, 209531, 209533, 209535, 209536, 209537, 209538, 209538, 209539, 209502, 209503, 209504, 209506, 209506, 209507, 209514, 209521, 209535, 209536, 209537, 209538, 209539, 209539, 209539, 209540, 209540, 209541, 209508, 209541, 209542, 209510, 209542, 209511, 209543, 209544, 209544, 209544, 209545, 209545, 209521, 209549, 209549, 209550, 209552, 209559, 209560, 209568, 209568, 209570, 209571, 209573, 209574, 209574, 209575, 209576, 209576, 209576, 209577, 209577, 209578, 209579, 209579, 209580, 209580, 209581, 209581, 209582, 209582, 209583, 209583, 209584, 209584, 209585, 209585, 209587, 209588, 209588, 209589, 209589, 209590, 209591, 209592, 209593, 209593, 209594, 209594, 209595, 209595, 209596, 209596, 209597, 209598, 209602, 209602, 209604, 209605, 209609, 209612, 209614, 209615, 209579, 209580, 209580, 209581, 209582, 209585, 209585, 209586, 209589, 209589, 209590, 209591, 209594, 209594, 209596, 209614, 209615, 209580, 209581, 209581, 209582, 209582, 209585, 209586, 209588, 209589, 209590, 209590, 209591, 209594, 209594, 209615, 209581, 209582, 209582, 209587, 209590, 209590, 209591, 209592, 209597, 209598, 209582, 209583, 209583, 209584, 209585, 209585, 209586, 209587, 209587, 209588, 209589, 209590, 209591, 209591, 209592, 209594, 209595, 209597, 209597, 209599, 209599, 209600, 209602, 209604, 209605, 209583, 209584, 209588, 209591, 209591, 209596, 209584, 209586, 209591, 209592, 209592, 209593, 209586, 209588, 209588, 209589, 209591, 209592, 209592, 209593, 209594, 209597, 209592, 209606, 209588, 209593, 209593, 209594, 209592, 209593, 209594, 209594, 209594, 209595, 209599, 209602, 209607, 209610, 209613, 209620, 209596, 209595, 209596, 209597, 209592, 209594, 209595, 209596, 209599, 209601, 209604, 209595, 209596, 209596, 209597, 209598, 209601, 209603, 209596, 209596, 209597, 209598, 209598, 209599, 209600, 209603, 209624, 209599, 209624, 209599, 209600, 209601, 209602, 209603, 209603, 209604, 209604, 209605, 209606, 209607, 209608, 209612, 209613, 209614, 209617, 209617, 209621, 209622, 209625, 209600, 209601, 209601, 209602, 209603, 209604, 209604, 209605, 209606, 209606, 209607, 209607, 209608, 209612, 209613, 209614, 209614, 209615, 209615, 209617, 209618, 209623, 209625, 209602, 209602, 209603, 209604, 209604, 209605, 209605, 209606, 209607, 209607, 209608, 209608, 209609, 209610, 209611, 209612, 209613, 209613, 209614, 209615, 209616, 209617, 209621, 209624, 209625, 209626, 209607, 209603, 209604, 209604, 209605, 209605, 209606, 209606, 209607, 209608, 209608, 209609, 209609, 209610, 209610, 209612, 209612, 209614, 209615, 209615, 209616, 209616, 209618, 209619, 209622, 209623, 209627, 209605, 209606, 209615, 209606, 209607, 209609, 209609, 209608, 209611, 209607, 209608, 209608, 209610, 209610, 209611, 209614, 209615, 209616, 209627, 209629, 209608, 209609, 209610, 209610, 209612, 209612, 209613, 209613, 209617, 209617, 209621, 209626, 209629, 209629, 209609, 209610, 209611, 209611, 209612, 209612, 209613, 209613, 209614, 209615, 209616, 209617, 209618, 209619, 209621, 209622, 209626, 209628, 209630, 209610, 209611, 209611, 209612, 209612, 209613, 209613, 209614, 209614, 209615, 209615, 209616, 209617, 209618, 209618, 209619, 209619, 209621, 209628, 209630, 209630, 209613, 209615, 209618, 209631, 209612, 209613, 209613, 209614, 209615, 209615, 209617, 209619, 209619, 209631, 209613, 209614, 209614, 209615, 209615, 209616, 209616, 209617, 209617, 209618, 209618, 209619, 209619, 209620, 209620, 209621, 209621, 209622, 209623, 209624, 209624, 209626, 209627, 209628, 209628, 209630, 209630, 209632, 209615, 209615, 209616, 209616, 209617, 209618, 209620, 209620, 209622, 209623, 209624, 209630, 209615, 209616, 209617, 209618, 209620, 209620, 209621, 209623, 209628, 209632, 209633, 209616, 209617, 209617, 209618, 209618, 209619, 209619, 209620, 209620, 209621, 209621, 209622, 209623, 209623, 209624, 209625, 209628, 209631, 209632, 209633, 209633, 209617, 209618, 209619, 209619, 209621, 209622, 209625, 209626, 209626, 209634, 209618, 209619, 209620, 209622, 209622, 209623, 209623, 209625, 209634, 209620, 209622, 209623, 209623, 209626, 209629, 209631, 209634, 209635, 209623, 209624, 209624, 209635, 209623, 209628, 209634, 209624, 209624, 209625, 209636, 209624, 209625, 209626, 209637, 209625, 209629, 209625, 209627, 209629, 209630, 209626, 209627, 209627, 209628, 209628, 209629, 209630, 209631, 209631, 209632, 209633, 209633, 209636, 209637, 209638, 209638, 209627, 209628, 209628, 209629, 209630, 209631, 209633, 209637, 209638, 209639, 720308, 209628, 209629, 209629, 209630, 209631, 209636, 209639, 209631, 209632, 209633, 209634, 209638, 209639, 209639, 209640, 209630, 209631, 209632, 209633, 209637, 209638, 209638, 209640, 209640, 209632, 209633, 209635, 209636, 209637, 209639, 209640, 209640, 209641, 209633, 209634, 209634, 209635, 209635, 209636, 209637, 209637, 209638, 209638, 209640, 209640, 209641, 209641, 209642, 209634, 209635, 209636, 209637, 209637, 209638, 209638, 209639, 209640, 209640, 209641, 209641, 209642, 209642, 209643, 209640, 209641, 209641, 209643, 209640, 209644, 209641, 209643, 209644, 209644, 209643, 209643, 209645, 209641, 209645, 209645, 209643, 209644, 209646, 209643, 209646, 209646, 209647, 209645, 209645, 209647, 209647, 209646, 209647, 209648, 209646, 209648, 209649, 209647, 209648, 209648, 209649, 209648, 209649, 209649, 209650, 209650, 209651, 209655, 209658, 209661, 209668, 209677, 209680, 209688, 209689, 209689, 209690, 240394, 240395, 240395, 240396, 240399, 346201, 568349, 568390, 568394, 568400, 741980, 890693, 209652, 209653, 209653, 209654, 209654, 209655, 209655, 209656, 209656, 209657, 209657, 209658, 209659, 209659, 209660, 209660, 209661, 209661, 209662, 209663, 209663, 209664, 209666, 209666, 209667, 209667, 209668, 209669, 209671, 209673, 209674, 209674, 209675, 209679, 209681, 209681, 209683, 209684, 209686, 209686, 209687, 209687, 209688, 209688, 209689, 209689, 209690, 209690, 240394, 240397, 240397, 240398, 209653, 209654, 209655, 209656, 209657, 209657, 209658, 209659, 209662, 209663, 209664, 209668, 209671, 209679, 209687, 209689, 209689, 209690, 209690, 209691, 209657, 209676, 209691, 209691, 209660, 209657, 209659, 209660, 209662, 209663, 209664, 209669, 209678, 209687, 209691, 209692, 209692, 209658, 209692, 209693, 209691, 209692, 209692, 209693, 209661, 209662, 209666, 209676, 209693, 209694, 209694, 209691, 209695, 209664, 209665, 209666, 209667, 209692, 209693, 209695, 209695, 209667, 209667, 209692, 209695, 209665, 209696, 209696, 209667, 209669, 209697, 209668, 209681, 209694, 209695, 209697, 209669, 209695, 209696, 209697, 209670, 209681, 209696, 209698, 209698, 209671, 209696, 209698, 209671, 209695, 209699, 209671, 209690, 209698, 209672, 209673, 209677, 209677, 209685, 209692, 209695, 209697, 209698, 209699, 209699, 209700, 209700, 209696, 209697, 209680, 209686, 209691, 209699, 209700, 209701, 209701, 209699, 209691, 209698, 209700, 209704, 209703, 209704, 209705, 209692, 209705, 209706, 209695, 209707, 209707, 209708, 209705, 209708, 209709, 209709, 209709, 209711, 209712, 209708, 209709, 209698, 209703, 209709, 209710, 209711, 209712, 209712, 209707, 209712, 209713, 209708, 209712, 209713, 209714, 209715, 209716, 209715, 209716, 209717, 209716, 209718, 209718, 209717, 209719, 209719, 209719, 209722, 209720, 209721, 209722, 209724, 209722, 209724, 209724, 209722, 209722, 209723, 209723, 209724, 209724, 209725, 209723, 209724, 209724, 209725, 209723, 209724, 209724, 209725, 209725, 209726, 209724, 209725, 209725, 209726, 209726, 209725, 209726, 209726, 209727, 209726, 209727, 209727, 741997, 209727, 209728, 568387, 209728, 209729, 240431, 240432, 240432, 240433, 240433, 240434, 240434, 240435, 240435, 240436, 240436, 240437, 240437, 240438, 240438, 240439, 269852, 330278, 346237, 346238, 346239, 346240, 346241, 346242, 351093, 391561, 479113, 479178, 520693, 568387, 568387, 568388, 568429, 568436, 568444, 568445, 741998, 813949, 890732, 1078630, 240432, 240433, 240433, 240434, 240435, 240436, 240437, 568387, 568388, 271137, 271135, 271136, 271136, 271137, 271137, 271138, 271139, 271150, 271150, 271151, 271151, 271136, 271137, 271137, 271138, 271139, 271151, 271151, 271152, 271152, 271137, 271138, 271138, 271139, 271140, 271140, 271151, 271151, 271152, 271152, 271153, 271138, 271139, 271140, 271152, 271153, 271153, 271139, 271140, 271140, 271141, 271153, 271153, 271154, 271154, 271156, 271140, 271141, 271141, 271143, 271143, 271153, 271153, 271154, 271154, 271155, 271156, 271156, 271158, 271159, 271141, 271154, 271154, 271155, 271155, 271156, 271142, 271143, 271144, 271144, 271154, 271154, 271155, 271155, 271156, 271156, 271157, 271157, 271158, 271158, 271159, 271160, 271161, 271145, 271154, 271155, 271155, 271156, 271156, 271158, 271158, 271159, 271160, 271160, 271156, 271158, 271159, 271159, 271160, 271160, 271161, 271157, 271158, 271159, 271160, 271163, 271156, 271159, 271162, 271162, 271163, 271161, 271163, 271162, 271166, 271167, 376959, 599105, 271166, 271167, 271167, 271171, 376960, 599105, 271167, 271168, 271168, 271169, 271170, 599107, 271168, 271169, 271170, 271170, 271171, 271173, 376961, 599106, 599107, 772718, 271169, 271170, 271170, 271171, 271171, 271172, 271172, 271173, 271173, 300572, 376957, 376961, 376961, 422279, 599107, 599108, 599149, 751077, 921452, 271171, 271171, 271172, 271173, 271173, 271174, 376958, 376962, 422282, 599107, 599108, 599108, 271172, 271172, 271174, 599109, 599153, 271172, 271174, 271175, 376962, 376962, 422283, 493843, 599108, 599109, 271173, 271174, 271174, 271175, 271175, 300574, 357439, 376959, 376962, 376963, 376966, 422283, 509952, 599109, 599110, 599151, 599164, 271175, 271176, 300574, 376963, 376964, 509905, 599109, 599110, 376964, 599110, 599110, 599152, 271177, 376965, 422285, 599111, 271177, 299727, 376965, 376965, 422285, 509905, 599111, 599112, 376966, 599111, 599112, 599112, 376962, 599112, 599155, 599155, 328350, 627735, 330050, 406440, 539378, 628585, 628586, 443717, 685387, 450843, 688951, 482750, 482763, 482763, 482764, 482764, 482765, 482750, 482765, 482753, 482767, 482767, 482769, 482766, 482768, 482768, 482768, 482769, 482769, 482770, 482771, 704912, 704913, 704913, 704914, 482783, 704913, 704914, 704956, 482783, 704914, 704915, 487621, 528089, 704914, 704915, 704915, 704916, 704916, 492521, 492521, 709814, 709815, 573406, 573405, 573406, 573409, 573409, 750231, 750232, 750231, 923843, 750234, 750234, 750235, 750236, 716524, 821790, 748563, 748629, 748639, 748704, 748705, 748636, 748661, 748660, 748714, 748682, 837864, 837866, 748756, 748780, 837913, 837914, 831702, 831768, 831836, 879465, 927045, 927046, 927046, 927047, 927048, 927048, 927049, 927050, 927050, 927051, 927052, 927053, 927054, 927058, 927063, 927067, 927074, 927075, 927076, 927081, 927083, 927086, 927087, 927087, 927088, 927088, 927113, 927050, 927050, 927084, 927088, 927088, 927050, 927088, 927089, 927089, 927090, 927053, 927066, 927089, 927090, 927090, 927091, 927090, 927091, 927070, 927091, 927056, 927092, 927066, 927092, 927094, 927095, 927099, 927102, 927104, 927105, 927107, 927108, 927115, 927116, 927105, 927117, 927117, 927121, 927122, 927124, 927124, 927127, 927127, 927128, 927129, 927129, 927163, 927130, 927131, 927131, 927132, 927132, 927133, 927133, 927134, 927134, 927135, 927135, 927136, 927136, 927137, 927138, 927139, 927140, 927140, 927141, 927142, 927143, 927144, 927145, 927145, 927146, 927148, 927149, 927149, 927150, 927151, 927153, 927156, 927157, 927163, 927163, 927164, 927131, 927132, 927132, 927133, 927133, 927134, 927135, 927136, 927137, 927138, 927138, 927140, 927140, 927141, 927143, 927143, 927148, 927152, 927153, 927159, 927163, 927164, 927164, 927134, 927136, 927138, 927139, 927141, 927143, 927144, 927147, 927136, 927139, 927141, 927142, 927144, 927144, 927140, 927142, 927158, 927136, 927137, 927139, 927142, 927136, 927138, 927143, 927143, 927146, 927167, 927138, 927141, 927143, 927146, 927146, 927159, 927139, 927144, 927146, 927142, 927144, 927167, 927140, 927141, 927142, 927142, 927143, 927144, 927145, 927145, 927146, 927147, 927148, 927148, 927150, 927151, 927155, 927158, 927159, 927161, 927169, 927141, 927145, 927148, 927144, 927146, 927146, 927170, 927146, 927146, 927147, 927163, 927164, 927145, 927147, 927147, 927150, 927171, 927148, 927148, 927150, 927151, 927164, 927149, 927150, 927155, 927162, 927165, 927173, 927150, 927151, 927151, 927152, 927152, 927153, 927154, 927154, 927155, 927155, 927156, 927157, 927157, 927159, 927160, 927160, 927161, 927161, 927162, 927162, 927163, 927166, 927166, 927167, 927169, 927170, 927170, 927172, 927172, 927173, 927173, 927174, 927151, 927152, 927152, 927153, 927153, 927155, 927155, 927156, 927156, 927158, 927159, 927160, 927161, 927161, 927162, 927163, 927163, 927164, 927165, 927166, 927167, 927168, 927170, 927173, 927173, 927174, 927153, 927156, 927154, 927154, 927157, 927174, 927154, 927170, 927155, 927156, 927156, 927157, 927157, 927158, 927158, 927160, 927160, 927161, 927162, 927163, 927163, 927164, 927164, 927165, 927165, 927166, 927166, 927167, 927167, 927168, 927169, 927169, 927170, 927170, 927171, 927172, 927173, 927175, 927176, 927157, 927157, 927158, 927158, 927159, 927159, 927161, 927162, 927163, 927163, 927164, 927164, 927165, 927165, 927166, 927166, 927167, 927167, 927169, 927169, 927170, 927171, 927172, 927172, 927173, 927174, 927174, 927175, 927175, 927176, 927176, 927177, 927158, 927166, 927166, 927168, 927178, 927160, 927160, 927162, 927163, 927164, 927165, 927165, 927166, 927167, 927168, 927168, 927169, 927171, 927172, 927173, 927173, 927176, 927177, 927177, 927178, 927161, 927164, 927168, 927168, 927169, 927178, 927179, 927161, 927162, 927164, 927165, 927166, 927166, 927167, 927168, 927168, 927171, 927172, 927173, 927173, 927176, 927178, 927178, 927179, 927163, 927164, 927165, 927165, 927166, 927166, 927167, 927168, 927168, 927169, 927170, 927171, 927172, 927172, 927173, 927173, 927174, 927177, 927178, 927178, 927179, 927179, 927180, 927179, 927181, 927180, 927181, 927168, 927168, 927169, 927170, 927174, 927178, 927181, 927172, 927168, 927170, 927175, 927175, 927182, 927183, 927171, 927172, 927175, 927179, 927180, 927183, 1100775, 927170, 927171, 927172, 927172, 927173, 927174, 927176, 927180, 927183, 927184, 927171, 927172, 927173, 927173, 927174, 927175, 927176, 927177, 927177, 927178, 927179, 927180, 927182, 927183, 927184, 927173, 927173, 927174, 927175, 927177, 927177, 927178, 927180, 927181, 927184, 927184, 927185, 927175, 927176, 927180, 927182, 927174, 927175, 927175, 927176, 927178, 927178, 927179, 927179, 927180, 927181, 927183, 927185, 927186, 927175, 927176, 927176, 927177, 927178, 927179, 927179, 927180, 927181, 927182, 927184, 927185, 927186, 927177, 927179, 927179, 927180, 927181, 927182, 927182, 927183, 927183, 927185, 927186, 927187, 927177, 927179, 927180, 927186, 927187, 927187, 927179, 927180, 927180, 927181, 927184, 927185, 927187, 927188, 927182, 927184, 927187, 927188, 927181, 927181, 927182, 927188, 927182, 927183, 927183, 927184, 927184, 927185, 927186, 927187, 927188, 927188, 927189, 927190, 1079084, 927183, 927184, 927184, 927185, 927186, 927187, 927188, 927188, 927189, 927190, 927184, 927185, 927186, 927187, 927187, 927188, 927188, 927189, 927189, 927190, 927190, 927191, 927185, 927186, 927187, 927187, 927190, 927190, 927191, 927191, 1100726, 927187, 927188, 927190, 927191, 927192, 927188, 927191, 927192, 927189, 927192, 927192, 927193, 927189, 927191, 927192, 927193, 927191, 927191, 927192, 927193, 927193, 927194, 927192, 927193, 927194, 927193, 927194, 927194, 927195, 927194, 927195, 927195, 927194, 927195, 927196, 927195, 927196, 927196, 927197, 927197, 927198, 927199, 927199, 927200, 927201, 927201, 927202, 927203, 927204, 927204, 927205, 927206, 927207, 927207, 927208, 927209, 927209, 927210, 927210, 927211, 927211, 927212, 927212, 927213, 927213, 927215, 927216, 927216, 927218, 927220, 927222, 927222, 927223, 927223, 927226, 927228, 927229, 927229, 927231, 927234, 927234, 927235, 927235, 927236, 927236, 927237, 927237, 927238, 927238, 927239, 927239, 1079092, 1079095, 1079095, 1100733, 1100753, 1100754, 1172684, 1172705, 1249467, 927199, 927200, 927200, 927201, 927202, 927202, 927203, 927203, 927204, 927205, 927206, 927206, 927207, 927207, 927208, 927209, 927210, 927210, 927211, 927213, 927215, 927216, 927222, 927223, 927224, 927224, 927226, 927228, 927230, 927231, 927232, 927233, 927234, 927235, 927236, 927237, 927237, 927238, 927239, 927239, 927240, 927201, 927207, 927208, 927209, 927227, 927232, 927236, 927240, 927240, 927214, 927240, 927204, 927205, 927207, 927211, 927212, 927213, 927215, 927219, 927230, 927231, 927233, 927238, 927239, 927240, 927241, 927205, 927204, 927213, 927216, 927210, 927213, 927227, 927240, 927243, 927211, 927212, 927214, 927220, 927235, 927236, 927238, 927241, 927242, 927242, 927243, 927211, 927217, 927239, 927244, 927218, 927242, 927214, 927234, 927239, 927240, 927242, 927244, 927212, 927226, 927240, 927242, 927243, 927212, 927213, 927215, 927235, 927245, 927245, 927232, 927237, 927244, 927215, 927221, 927228, 927231, 927245, 927215, 927218, 927220, 927229, 927231, 927237, 927244, 927245, 927246, 927248, 1079103, 927218, 927219, 927220, 927225, 927230, 927240, 927246, 927247, 927248, 927248, 927217, 927232, 927236, 927241, 927246, 927248, 927249, 927219, 927241, 927249, 927220, 927247, 927225, 927227, 927238, 927242, 927246, 927247, 927248, 927250, 927221, 927222, 927233, 927240, 927245, 927247, 927223, 927228, 927231, 927232, 927243, 927249, 927250, 927251, 927251, 927249, 927252, 927241, 927244, 927247, 927250, 927233, 927235, 927246, 927248, 927253, 927251, 927235, 927244, 927247, 927249, 927252, 927253, 927254, 927242, 927248, 927255, 927246, 927256, 927239, 927253, 927255, 927257, 927249, 927255, 927255, 927257, 927258, 927256, 927259, 927250, 927249, 927246, 927255, 927258, 927258, 927260, 927262, 927260, 927255, 927261, 927261, 927263, 927256, 927261, 927262, 927264, 927259, 927260, 927262, 927262, 927262, 927263, 927265, 927257, 927263, 927259, 927260, 927268, 927267, 927268, 927264, 927269, 927261, 927269, 927262, 927263, 927266, 927269, 927270, 927267, 927268, 927269, 927270, 927270, 927263, 927268, 927269, 927271, 927268, 927264, 927270, 927267, 927267, 927268, 927268, 927269, 927269, 927270, 927270, 927271, 927271, 927272, 927272, 927273, 927268, 927273, 927274, 927274, 927272, 927274, 927271, 927272, 927273, 927274, 927275, 927275, 927272, 927273, 927274, 927275, 927275, 927276, 927274, 927276, 927273, 927274, 927274, 927275, 927276, 927277, 927274, 927275, 927276, 927276, 927277, 927275, 927276, 927276, 927277, 927277, 927278, 1100771, 927276, 927277, 927277, 927278, 927278, 927277, 927278, 927278, 927279, 927278, 927279, 927279, 927279, 927280, 927280, 927281, 997029, 1016341, 1041603, 1076637, 1079130, 1079130, 1079131, 1079131, 1079132, 1079132, 1079133, 1079133, 1079134, 1079134, 1079135, 1079135, 1079136, 1079136, 1079137, 1079137, 1079138, 1100774, 1100774, 1100795, 1100830, 1172725, 1172747, 1249508, 927284, 1016341, 1079131, 1079131, 1079133, 1079134, 1079134, 1079135, 1079135, 1079136, 1079136, 1079137, 1100775, 1079133, 1066796, 1148901, 1105411, 1105413, 1105414, 1105504, 1105506, 1105507, 1105598, 1119859, 1168301, 1189938, 1134126, 1134183, 1134238, 1182619, 1155938, 1193473, 1225998, 1226072, 1226147, 1228569, 1230980, 1230980, 1230981, 1230982, 1230984, 1230997, 1230982, 1230983, 1230984, 1230984, 1230985, 1230986, 1230987, 1230996, 1230997, 1230997, 1230998, 1230998, 1230999, 1230984, 1230986, 1230986, 1230984, 1230985, 1230987, 1230988, 1230985, 1231002, 1231003, 1230985, 1230986, 1230986, 1230987, 1230988, 1230988, 1230989, 1231002, 1231004, 1231005, 1231006, 1230986, 1230987, 1230987, 1230988, 1230988, 1230989, 1230990, 1230999, 1231003, 1231004, 1231004, 1230987, 1230988, 1230988, 1230989, 1230989, 1230990, 1230990, 1230991, 1231000, 1231002, 1231003, 1231004, 1231004, 1231005, 1231005, 1230988, 1230989, 1230989, 1230990, 1230990, 1230991, 1230992, 1231002, 1231004, 1231005, 1231005, 1231006, 1231006, 1231007, 1230989, 1230990, 1230990, 1230991, 1230991, 1230992, 1230993, 1231000, 1231000, 1231001, 1231003, 1231005, 1231005, 1231006, 1231006, 1231007, 1230990, 1230991, 1230991, 1230992, 1230992, 1231004, 1231005, 1231006, 1231006, 1231007, 1230991, 1230992, 1230992, 1231002, 1231006, 1231006, 1231007, 1231007, 1230992, 1230993, 1231001, 1231001, 1231002, 1231002, 1231003, 1231004, 1231005, 1231006, 1231007, 1231007, 1231008, 1231008, 1231009, 1230993, 1230994, 1231002, 1231002, 1231003, 1231006, 1231007, 1231007, 1231008, 1231008, 1231009, 1231010, 1231002, 1231007, 1231008, 1231008, 1231009, 1231009, 1231008, 1231008, 1231009, 1231010, 1231009, 1231010, 1231016, 1231017, 1231013, 1231016, 1231016, 1231017, 1231017, 1231018, 1252640, 1231015, 1231017, 1231018, 1231017, 1231018, 1231019, 1252641, 1231018, 1324592, 1231017, 1231020, 1231020, 1401376, 1324593, 1231020, 1231020, 1231021, 1252643, 1324594, 1231021, 1231021, 1231022, 1231021, 1231022, 1231022, 1231023, 1252644, 1324595, 1324619, 1231022, 1231023, 1231023, 1231027, 1252644, 1252645, 1252701, 1231023, 1231024, 1231024, 1252645, 1252645, 1252666, 1324596, 1324618, 1401379, 1806366, 1231024, 1231025, 1252645, 1252646, 1324597, 1324655, 1401380, 1401432, 1231025, 1252646, 1252647, 1252647, 1252648, 1252650, 1274267, 1274268, 1274269, 1274269, 1274270, 1274270, 1274271, 1274275, 1274277, 1274278, 1274288, 1274288, 1274289, 1274343, 1274288, 1274289, 1274289, 1274271, 1274272, 1274289, 1274290, 1274290, 1274290, 1274291, 1274291, 1274295, 1274288, 1274288, 1274289, 1274290, 1274290, 1274299, 1274332, 1274333, 1274354, 1346230, 1346251, 1423013, 1274300, 1274302, 1346251, 1274308, 1274363, 1274309, 1274310, 1274310, 1274311, 1274313, 1274313, 1274314, 1274314, 1274315, 1274318, 1274320, 1274321, 1274322, 1274325, 1274325, 1274326, 1274328, 1274329, 1274329, 1274330, 1274330, 1274333, 1274334, 1274335, 1274336, 1274337, 1274338, 1274338, 1274339, 1274339, 1274340, 1274340, 1274341, 1274342, 1274342, 1274343, 1274344, 1274345, 1274345, 1274346, 1274347, 1274351, 1274356, 1274358, 1274360, 1274361, 1274363, 1274364, 1274321, 1274325, 1274326, 1274331, 1274337, 1274338, 1274339, 1274343, 1274343, 1274364, 1274364, 1274361, 1274365, 1274338, 1274332, 1274317, 1274326, 1274368, 1274341, 1274368, 1274344, 1274366, 1274370, 1274344, 1274348, 1274354, 1274356, 1274375, 1274342, 1274350, 1274350, 1274351, 1274351, 1274376, 1274351, 1274377, 1274354, 1274350, 1274352, 1274358, 1274347, 1274356, 1274359, 1274380, 1274355, 1274361, 1274357, 1274383, 1274363, 1274384, 1274360, 1274365, 1274360, 1274361, 1274363, 1274356, 1274360, 1274361, 1274361, 1274363, 1274364, 1274364, 1274367, 1274388, 1274389, 1274364, 1274367, 1274368, 1274368, 1274364, 1274366, 1274366, 1274367, 1274368, 1274368, 1274369, 1274391, 1274365, 1274366, 1274392, 1274367, 1274368, 1274369, 1274370, 1274375, 1274389, 1274393, 1274369, 1274375, 1274392, 1274393, 1274370, 1274371, 1274372, 1274372, 1274373, 1274374, 1274391, 1274391, 1274394, 1274370, 1274372, 1274372, 1274373, 1274373, 1274375, 1274378, 1274391, 1274373, 1274374, 1274376, 1274386, 1274391, 1274392, 1274392, 1274394, 1274395, 1274373, 1274381, 1274395, 1274374, 1274396, 1274374, 1274381, 1274384, 1274389, 1274394, 1274396, 1274376, 1274376, 1274383, 1274397, 1274378, 1274379, 1274380, 1274382, 1274393, 1274394, 1274397, 1274397, 1274377, 1274378, 1274383, 1274385, 1274397, 1274398, 1274398, 1274382, 1274394, 1274396, 1274397, 1274399, 1274384, 1274395, 1274396, 1274397, 1274400, 1274382, 1274400, 1274398, 1274401, 1274393, 1274399, 1274402, 1274400, 1274403, 1274403, 1274404, 1274405, 1423063, 1274406, 1274406, 1274407, 1274410, 1274408, 1274411, 1274412, 1274413, 1274410, 1274414, 1274410, 1274415, 1274415, 1274415, 1274415, 1274416, 1346291, 1274414, 1274416, 1274416, 1274417, 1274418, 1274418, 1274439, 1346315, 1274419, 1274420, 1274424, 1274424, 1274429, 1274432, 1274433, 1274437, 1274437, 1274438, 1274438, 1274439, 1274439, 1346294, 1346316, 1346347, 1423077, 1423119, 1525353, 1610975, 1274424, 1274432, 1274438, 1274439, 1274439, 1274440, 1274440, 1274444, 1274445, 1274450, 1274452, 1274453, 1274453, 1274457, 1274458, 1274458, 1274458, 1274459, 1274459, 1346314, 1274460, 1295375, 1295435, 1306878, 1306893, 1346314, 1346315, 1346336, 1423098, 1423139, 1525340, 1832798, 1346315, 1316305, 1316365, 1316429, 1316423, 1367303, 1367309, 1339318, 1339338, 1378755, 1378759, 1418169, 1418170, 1418171, 1418171, 1418172, 1418173, 1418188, 1418189, 1418189, 1418190, 1418190, 1418191, 1418191, 1418192, 1418211, 1418245, 1418245, 1418185, 1418191, 1418192, 1418192, 1418192, 1418194, 1418194, 1418205, 1418209, 1418210, 1418210, 1418211, 1418211, 1418211, 1418212, 1418212, 1418213, 1418214, 1418214, 1418215, 1418215, 1418216, 1418216, 1418217, 1418217, 1418218, 1418218, 1418219, 1418221, 1418221, 1418222, 1418222, 1418224, 1418224, 1418225, 1418226, 1418228, 1418228, 1418229, 1418230, 1418231, 1418232, 1418232, 1418233, 1418234, 1418234, 1418235, 1418235, 1418236, 1418237, 1418238, 1418238, 1418239, 1418240, 1418240, 1418241, 1418241, 1418242, 1418242, 1418243, 1418243, 1418244, 1418244, 1418245, 1418246, 1418247, 1418248, 1418248, 1418250, 1418251, 1418253, 1418254, 1418255, 1418259, 1418262, 1418264, 1418265, 1418266, 1418267, 1418214, 1418216, 1418216, 1418217, 1418217, 1418218, 1418219, 1418222, 1418222, 1418232, 1418232, 1418233, 1418235, 1418236, 1418236, 1418238, 1418238, 1418239, 1418241, 1418242, 1418243, 1418244, 1418246, 1418265, 1418266, 1418267, 1418267, 1418218, 1418229, 1418230, 1418233, 1418233, 1418235, 1418235, 1418239, 1418241, 1418242, 1418267, 1418268, 1418221, 1418248, 1418224, 1418233, 1418235, 1418237, 1418240, 1418243, 1418251, 1418269, 1418227, 1418236, 1418240, 1418241, 1418228, 1418239, 1418242, 1418242, 1418246, 1418223, 1418225, 1418235, 1418236, 1418239, 1418242, 1418271, 1418245, 1418225, 1418237, 1418272, 1418237, 1418254, 1418234, 1418245, 1418238, 1418246, 1418233, 1418243, 1418249, 1418243, 1418247, 1418250, 1418251, 1418252, 1418276, 1418241, 1418244, 1418245, 1418243, 1418246, 1418247, 1418250, 1418260, 1418277, 1418244, 1418255, 1418260, 1418248, 1418259, 1418281, 1418250, 1418265, 1418282, 1418256, 1418251, 1418251, 1418255, 1418258, 1418258, 1418261, 1418265, 1418251, 1418252, 1418256, 1418250, 1418254, 1418256, 1418259, 1418252, 1418253, 1418257, 1418257, 1418259, 1418262, 1418267, 1418260, 1418283, 1418286, 1418253, 1418254, 1418254, 1418257, 1418258, 1418258, 1418260, 1418264, 1418265, 1418267, 1418286, 1418255, 1418255, 1418257, 1418258, 1418287, 1418307, 1418259, 1418261, 1418268, 1418288, 1418256, 1418257, 1418257, 1418258, 1418259, 1418259, 1418260, 1418261, 1418262, 1418262, 1418263, 1418264, 1418265, 1418265, 1418266, 1418266, 1418268, 1418268, 1418270, 1418270, 1418271, 1418288, 1418288, 1494996, 1418258, 1418260, 1418262, 1418265, 1418266, 1418268, 1418269, 1418289, 1418258, 1418260, 1418263, 1418266, 1418266, 1418267, 1418289, 1418289, 1418261, 1418261, 1418261, 1418266, 1418267, 1418268, 1418290, 1418264, 1418265, 1418262, 1418268, 1418272, 1418275, 1418263, 1418264, 1418265, 1418266, 1418266, 1418267, 1418267, 1418268, 1418269, 1418270, 1418272, 1418275, 1418276, 1418278, 1418291, 1418292, 1494999, 1418266, 1418266, 1418267, 1418267, 1418268, 1418269, 1418270, 1418272, 1418274, 1418275, 1418276, 1418290, 1418292, 1418266, 1418267, 1418293, 1418269, 1418274, 1418268, 1418269, 1418270, 1418271, 1418271, 1418272, 1418273, 1418274, 1418274, 1418276, 1418278, 1418280, 1418294, 1418269, 1418270, 1418270, 1418271, 1418272, 1418273, 1418275, 1418275, 1418276, 1418277, 1418277, 1418294, 1418295, 1418271, 1418295, 1495003, 1418271, 1418272, 1418273, 1418274, 1418275, 1418276, 1418277, 1418278, 1418279, 1418279, 1418293, 1418295, 1418295, 1418296, 1418273, 1418273, 1418274, 1418274, 1418275, 1418276, 1418276, 1418277, 1418277, 1418278, 1418279, 1418279, 1418280, 1418281, 1418285, 1418288, 1418289, 1418291, 1418292, 1418296, 1418296, 1418274, 1418275, 1418276, 1418297, 1418275, 1418277, 1418279, 1418281, 1418286, 1418292, 1418297, 1418297, 1418275, 1418276, 1418277, 1418278, 1418278, 1418280, 1418285, 1418286, 1418290, 1418293, 1418295, 1418297, 1418298, 1418278, 1418278, 1418279, 1418298, 1418278, 1418279, 1418279, 1418280, 1418280, 1418281, 1418282, 1418283, 1418296, 1418297, 1418297, 1418298, 1418299, 1418279, 1418280, 1418281, 1418282, 1418289, 1418292, 1418299, 1418300, 1495007, 1495059, 1418280, 1418283, 1418290, 1418294, 1418300, 1418300, 1418282, 1418282, 1418283, 1418284, 1418291, 1418294, 1418296, 1418300, 1418301, 1418282, 1418283, 1418283, 1418284, 1418291, 1418293, 1418299, 1418301, 1418301, 1418283, 1418294, 1418301, 1418302, 1418285, 1418296, 1418298, 1418300, 1418302, 1418302, 1418290, 1418292, 1418295, 1418296, 1418300, 1418302, 1418303, 1418288, 1418303, 1418303, 1418294, 1418300, 1418303, 1418304, 1418295, 1418298, 1418299, 1418304, 1418304, 1418304, 1418305, 1418305, 1418303, 1418306, 1418306, 1418307, 1418308, 1418301, 1418308, 1418309, 1418309, 1418299, 1418304, 1418309, 1418310, 1418301, 1418306, 1418311, 1418312, 1418312, 1418312, 1418313, 1418306, 1418313, 1418313, 1418311, 1418314, 1418314, 1418310, 1418315, 1418315, 1418315, 1418316, 1418316, 1418316, 1418316, 1418317, 1418317, 1418318, 1418317, 1418318, 1418318, 1418319, 1418319, 1418319, 1418319, 1418320, 1418320, 1418321, 1418340, 1418341, 1418342, 1495028, 1418321, 1418322, 1418322, 1418324, 1418325, 1418325, 1418327, 1418333, 1418334, 1418335, 1418336, 1418336, 1418337, 1418339, 1418340, 1418341, 1418341, 1418342, 1418342, 1495028, 1495080, 1495085, 1903379, 1418322, 1418323, 1418323, 1418324, 1418327, 1418336, 1418336, 1418337, 1418338, 1418339, 1418339, 1418340, 1418341, 1418341, 1418342, 1418342, 1418343, 1418342, 1418343, 1418343, 1418344, 1418344, 1418339, 1418346, 1418345, 1418346, 1418347, 1418348, 1418351, 1418353, 1418355, 1418357, 1418357, 1418357, 1418357, 1418358, 1418358, 1418356, 1418358, 1418359, 1418359, 1418359, 1418360, 1418361, 1418360, 1418361, 1418361, 1418362, 1418361, 1418362, 1418362, 1418362, 1418363, 1418363, 1418364, 1486805, 1488057, 1495049, 1495050, 1495103, 1495104, 1597292, 1682948, 1899649, 1899998, 1900037, 1495050, 1555259, 1563504, 1557759, 1564752, 1571735, 1571736, 1571737, 1571738, 1571738, 1571739, 1571740, 1571742, 1571746, 1571747, 1571755, 1571758, 1571759, 1571772, 1571773, 1571776, 1571776, 1571777, 1571777, 1571786, 1571811, 1571738, 1571739, 1571739, 1571747, 1571776, 1571777, 1571777, 1571778, 1571778, 1571749, 1571761, 1571779, 1571779, 1571779, 1571758, 1571780, 1571780, 1571759, 1571782, 1571757, 1571787, 1571788, 1571788, 1571795, 1571797, 1571799, 1673989, 1674023, 1759684, 1976396, 1976734, 1571796, 1571797, 1571800, 1571800, 1571799, 1571813, 1571814, 1571816, 1571817, 1571817, 1571817, 1571818, 1571818, 1571826, 1571828, 1571828, 1571829, 1571829, 1571832, 1571852, 1571818, 1571828, 1571819, 1571820, 1571820, 1571821, 1571821, 1571822, 1571822, 1571823, 1571823, 1571824, 1571824, 1571825, 1571825, 1571826, 1571826, 1571827, 1571827, 1571828, 1571829, 1571829, 1571830, 1571830, 1571831, 1571832, 1571832, 1571833, 1571833, 1571834, 1571834, 1571835, 1571836, 1571836, 1571837, 1571837, 1571838, 1571838, 1571839, 1571840, 1571840, 1571841, 1571843, 1571843, 1571844, 1571844, 1571850, 1571852, 1571853, 1571820, 1571821, 1571821, 1571822, 1571822, 1571823, 1571823, 1571824, 1571824, 1571825, 1571826, 1571827, 1571827, 1571828, 1571829, 1571829, 1571830, 1571832, 1571833, 1571853, 1571853, 1571821, 1571822, 1571822, 1571823, 1571823, 1571825, 1571826, 1571827, 1571828, 1571828, 1571829, 1571830, 1571831, 1571834, 1571837, 1571841, 1571843, 1571854, 1571822, 1571823, 1571828, 1571829, 1571830, 1571830, 1571842, 1571823, 1571824, 1571824, 1571826, 1571827, 1571829, 1571829, 1571830, 1571830, 1571831, 1571832, 1571833, 1571834, 1571835, 1571836, 1571836, 1571838, 1571853, 1571855, 1571824, 1571825, 1571826, 1571829, 1571830, 1571836, 1571838, 1571855, 1571825, 1571826, 1571826, 1571827, 1571828, 1571828, 1571829, 1571829, 1571830, 1571830, 1571831, 1571832, 1571833, 1571835, 1571856, 1571827, 1571828, 1571831, 1571832, 1571833, 1571834, 1571836, 1571856, 1571828, 1571828, 1571830, 1571831, 1571832, 1571833, 1571834, 1571834, 1571829, 1571831, 1571832, 1571836, 1571831, 1571831, 1571832, 1571832, 1571833, 1571834, 1571835, 1571835, 1571838, 1571858, 1571833, 1571834, 1571834, 1571836, 1571858, 1571832, 1571833, 1571859, 1571832, 1571833, 1571834, 1571835, 1571835, 1571836, 1571838, 1571834, 1571836, 1571834, 1571835, 1571836, 1571836, 1571837, 1571838, 1571841, 1571842, 1571843, 1571846, 1571847, 1571855, 1571860, 1571835, 1571836, 1571837, 1571838, 1571837, 1571837, 1571838, 1571838, 1571839, 1571839, 1571840, 1571840, 1571841, 1571841, 1571842, 1571844, 1571845, 1571846, 1571847, 1571848, 1571849, 1571852, 1571853, 1571853, 1571854, 1571855, 1571856, 1571856, 1571859, 1571861, 1571861, 1571860, 1571838, 1571839, 1571839, 1571840, 1571841, 1571842, 1571843, 1571843, 1571844, 1571846, 1571847, 1571848, 1571849, 1571853, 1571853, 1571854, 1571856, 1571857, 1571858, 1571862, 1571839, 1571840, 1571840, 1571841, 1571842, 1571842, 1571843, 1571843, 1571844, 1571844, 1571845, 1571846, 1571846, 1571847, 1571847, 1571848, 1571849, 1571850, 1571850, 1571851, 1571852, 1571853, 1571853, 1571854, 1571854, 1571856, 1571857, 1571858, 1571860, 1571861, 1571861, 1571862, 1571863, 1571840, 1571841, 1571841, 1571842, 1571842, 1571843, 1571844, 1571844, 1571850, 1571852, 1571854, 1571854, 1571855, 1571857, 1571863, 1571841, 1571842, 1571843, 1571843, 1571844, 1571844, 1571845, 1571846, 1571846, 1571847, 1571847, 1571850, 1571851, 1571852, 1571853, 1571854, 1571855, 1571855, 1571857, 1571858, 1571861, 1571864, 1571843, 1571843, 1571844, 1571844, 1571845, 1571845, 1571846, 1571846, 1571847, 1571848, 1571849, 1571850, 1571851, 1571852, 1571852, 1571853, 1571855, 1571855, 1571856, 1571856, 1571858, 1571859, 1571862, 1571864, 1571865, 1571844, 1571845, 1571845, 1571846, 1571846, 1571848, 1571850, 1571851, 1571852, 1571853, 1571853, 1571854, 1571856, 1571856, 1571857, 1571860, 1571862, 1571863, 1571865, 1571845, 1571846, 1571846, 1571847, 1571849, 1571849, 1571850, 1571851, 1571852, 1571853, 1571854, 1571856, 1571857, 1571860, 1571866, 1571846, 1571847, 1571847, 1571848, 1571849, 1571850, 1571851, 1571852, 1571853, 1571854, 1571854, 1571855, 1571857, 1571857, 1571866, 1571847, 1571848, 1571848, 1571849, 1571851, 1571853, 1571853, 1571854, 1571854, 1571855, 1571857, 1571858, 1571859, 1571862, 1571864, 1571865, 1571867, 1571848, 1571849, 1571849, 1571851, 1571852, 1571854, 1571855, 1571855, 1571856, 1571858, 1571859, 1571861, 1571863, 1571864, 1571867, 1571867, 1571849, 1571850, 1571851, 1571852, 1571853, 1571853, 1571854, 1571854, 1571855, 1571855, 1571856, 1571857, 1571858, 1571859, 1571860, 1571861, 1571864, 1571865, 1571867, 1571868, 1571850, 1571852, 1571856, 1571859, 1571860, 1571866, 1571868, 1571868, 1571853, 1571854, 1571856, 1571857, 1571858, 1571858, 1571859, 1571863, 1571868, 1571869, 1571852, 1571857, 1571854, 1571855, 1571856, 1571857, 1571857, 1571860, 1571861, 1571870, 1571855, 1571855, 1571858, 1571859, 1571860, 1571861, 1571864, 1571865, 1571868, 1571870, 1571860, 1571862, 1571871, 1571857, 1571859, 1571859, 1571862, 1571863, 1571863, 1571866, 1571866, 1571871, 1571858, 1571859, 1571859, 1571860, 1571861, 1571862, 1571863, 1571863, 1571870, 1571871, 1571872, 1571863, 1571866, 1571872, 1571860, 1571862, 1571863, 1571863, 1571864, 1571865, 1571867, 1571867, 1571868, 1571870, 1571871, 1571873, 1571860, 1571861, 1571864, 1571861, 1571863, 1571864, 1571865, 1571865, 1571867, 1571868, 1571874, 1759696, 1571862, 1571863, 1571863, 1571864, 1571865, 1571865, 1571866, 1571868, 1571869, 1571872, 1571874, 1571874, 1571864, 1571864, 1571865, 1571866, 1571866, 1571867, 1571868, 1571875, 1571864, 1571870, 1571866, 1571866, 1571867, 1571867, 1571870, 1571874, 1571875, 1571876, 1571868, 1571870, 1571876, 1571867, 1571868, 1571868, 1571875, 1571877, 1571868, 1571869, 1571871, 1571872, 1571873, 1571875, 1571877, 1571877, 1571869, 1571870, 1571871, 1571872, 1571873, 1571873, 1571874, 1571875, 1571877, 1571878, 1571870, 1571872, 1571873, 1571876, 1571876, 1571877, 1571877, 1571878, 1571878, 1571872, 1571873, 1571877, 1571879, 1571879, 1571875, 1571875, 1571876, 1571877, 1571877, 1571878, 1571879, 1571880, 1571880, 1571881, 1571879, 1571879, 1571880, 1571880, 1571881, 1571881, 1571881, 1571882, 1571882, 1571879, 1571882, 1571882, 1571882, 1571883, 1571881, 1571883, 1571881, 1571883, 1571884, 1571882, 1571884, 1571884, 1571884, 1571885, 1571885, 1571885, 1571886, 1571886, 1571887, 1571888, 1571888, 1571889, 1571889, 1571890, 1571892, 1571892, 1571893, 1571893, 1571894, 1571894, 1571895, 1571895, 1571896, 1571896, 1571897, 1571899, 1571900, 1571903, 1571905, 1571907, 1571908, 1571912, 1571916, 1571916, 1571917, 1571918, 1571923, 1571924, 1571926, 1571927, 1571927, 1571928, 1571928, 1674054, 1674076, 1674087, 1674087, 1674106, 1674107, 1759709, 1759748, 1759751, 1759759, 1759768, 1976410, 1976453, 1976464, 1976468, 1976798, 1571888, 1571889, 1571889, 1571890, 1571890, 1571891, 1571892, 1571892, 1571893, 1571894, 1571895, 1571895, 1571896, 1571897, 1571897, 1571899, 1571900, 1571900, 1571901, 1571902, 1571904, 1571906, 1571907, 1571910, 1571912, 1571913, 1571914, 1571918, 1571919, 1571923, 1571926, 1571926, 1571927, 1571928, 1571928, 1571929, 1674054, 1759750, 1976760, 1571889, 1571896, 1571899, 1571901, 1571902, 1571914, 1571925, 1571929, 1571929, 1571892, 1571904, 1571930, 1571892, 1571930, 1571930, 1571930, 1571931, 1571931, 1571898, 1571902, 1571914, 1571927, 1571930, 1571933, 1571900, 1571933, 1571933, 1571934, 1571934, 1571901, 1571903, 1571909, 1571924, 1571934, 1571935, 1571935, 1571902, 1571936, 1571904, 1571904, 1571905, 1571906, 1571906, 1571907, 1571907, 1571911, 1571935, 1571936, 1571936, 1571909, 1571936, 1571937, 1571905, 1571918, 1571937, 1571909, 1571909, 1571935, 1571937, 1571938, 1571938, 1571938, 1571911, 1571939, 1571911, 1571939, 1571940, 1571911, 1571912, 1571939, 1571940, 1571941, 1571923, 1571924, 1571941, 1571941, 1571942, 1571943, 1571943, 1571944, 1571944, 1571944, 1571938, 1571946, 1571947, 1571948, 1571949, 1571950, 1571950, 1571950, 1571951, 1571946, 1571952, 1571950, 1571953, 1571953, 1571951, 1571954, 1571955, 1571946, 1571946, 1571958, 1571947, 1571948, 1571958, 1571958, 1571959, 1571959, 1571959, 1571963, 1571963, 1571964, 1571965, 1571965, 1571963, 1571966, 1571967, 1571965, 1571967, 1571967, 1571967, 1571968, 1571968, 1571968, 1571969, 1571969, 1571970, 1571971, 1571971, 1571972, 1571972, 1571973, 1674095, 1674129, 1674132, 1674145, 1674149, 1759751, 1759790, 1759800, 1759806, 1976452, 1976504, 1976801, 1976840, 1990311, 1997272, 1998453, 1571973, 1674096, 1976452, 1571974, 1653857, 1674096, 1674097, 1674097, 1571975, 1674098, 1674098, 1759795, 1735755, 1735831, 1735906, 1756070, 1776220, 1776221, 1776222, 1776222, 1776223, 1776223, 1776225, 1776228, 1776230, 1776230, 1776231, 1776241, 1776243, 1776244, 1776252, 1776253, 1776254, 1776254, 1776296, 1776223, 1776224, 1776254, 1776255, 1776255, 1776255, 1776226, 1776255, 1776255, 1776255, 1776256, 1776256, 1776256, 1776257, 1776258, 1776261, 1776263, 1776263, 1776265, 1776274, 1776318, 1776276, 1776277, 1776285, 1776286, 1776286, 1776287, 1776287, 1776305, 1776305, 1776288, 1776289, 1776289, 1776290, 1776291, 1776291, 1776292, 1776292, 1776293, 1776293, 1776294, 1776294, 1776295, 1776296, 1776297, 1776299, 1776300, 1776301, 1776301, 1776302, 1776303, 1776304, 1776304, 1776305, 1776306, 1776306, 1776307, 1776307, 1776308, 1776308, 1776309, 1776309, 1776310, 1776310, 1776311, 1776312, 1776313, 1776314, 1776315, 1776321, 1776323, 1776323, 1776326, 1776328, 1776328, 1776329, 1776330, 1776289, 1776290, 1776291, 1776297, 1776303, 1776304, 1776305, 1776306, 1776306, 1776307, 1776308, 1776330, 1776293, 1776297, 1776302, 1776304, 1776305, 1776307, 1776311, 1776331, 1776292, 1776293, 1776294, 1776301, 1776304, 1776304, 1776305, 1776306, 1776307, 1776309, 1776293, 1776305, 1776306, 1776307, 1776309, 1776312, 1776307, 1776309, 1776312, 1776297, 1776307, 1776310, 1776311, 1776297, 1776306, 1776307, 1776309, 1776313, 1776334, 1776308, 1776309, 1776309, 1776310, 1776312, 1776312, 1776314, 1776301, 1776307, 1776312, 1776314, 1776336, 1776307, 1776313, 1776332, 1776337, 1776313, 1776314, 1776324, 1776313, 1776324, 1776314, 1776314, 1776315, 1776316, 1776342, 1776343, 1776318, 1776319, 1776331, 1776343, 1776343, 1776318, 1776319, 1776344, 1776319, 1776319, 1776320, 1776321, 1776321, 1776322, 1776324, 1776329, 1776330, 1776340, 1776341, 1776345, 1776320, 1776321, 1776322, 1776323, 1776325, 1776325, 1776327, 1776330, 1776331, 1776332, 1776333, 1776337, 1776341, 1776344, 1776346, 1776322, 1776322, 1776323, 1776324, 1776325, 1776326, 1776326, 1776327, 1776327, 1776328, 1776328, 1776331, 1776332, 1776332, 1776333, 1776342, 1776346, 1776323, 1776324, 1776325, 1776325, 1776326, 1776326, 1776327, 1776330, 1776332, 1776333, 1776334, 1776343, 1776346, 1776347, 1776325, 1776325, 1776326, 1776327, 1776327, 1776328, 1776329, 1776329, 1776331, 1776332, 1776333, 1776337, 1776339, 1776343, 1776345, 1776348, 1776327, 1776328, 1776331, 1776331, 1776333, 1776343, 1776344, 1776346, 1776348, 1776326, 1776328, 1776328, 1776329, 1776330, 1776330, 1776331, 1776333, 1776334, 1776328, 1776328, 1776329, 1776329, 1776330, 1776331, 1776331, 1776332, 1776334, 1776336, 1776344, 1776345, 1776346, 1776348, 1776349, 1776334, 1776350, 1776329, 1776330, 1776332, 1776348, 1776350, 1776330, 1776331, 1776331, 1776333, 1776334, 1776335, 1776336, 1776345, 1776346, 1776351, 1776331, 1776332, 1776332, 1776333, 1776336, 1776337, 1776338, 1776339, 1776351, 1776351, 1776333, 1776336, 1776337, 1776338, 1776338, 1776351, 1776352, 1776335, 1776337, 1776352, 1776334, 1776337, 1776338, 1776340, 1776353, 1776336, 1776338, 1776352, 1776353, 1776353, 1776338, 1776347, 1776348, 1776354, 1776337, 1776339, 1776340, 1776354, 1776339, 1776342, 1776355, 1776342, 1776342, 1776343, 1776344, 1776344, 1776352, 1776354, 1776355, 1776356, 1776356, 1776343, 1776344, 1776349, 1776352, 1776354, 1776355, 1776355, 1776357, 1776357, 1776355, 1776357, 1776358, 1776358, 1776347, 1776354, 1776358, 1776359, 1776359, 1776360, 1776361, 1776361, 1776363, 1776365, 1776365, 1776389, 1776366, 1776362, 1776366, 1776363, 1776367, 1776367, 1776368, 1776367, 1776369, 1776369, 1776370, 1776369, 1776370, 1776371, 1776371, 1776371, 1776372, 1776373, 1776376, 1776377, 1776379, 1776380, 1776381, 1776382, 1776388, 1776390, 1776393, 1776394, 1776395, 1776396, 1776398, 1776399, 1776402, 1776403, 1776403, 1776404, 1776404, 1776405, 1776405, 1861952, 1861991, 1861992, 1861996, 1861997, 1862001, 1862003, 1862004, 1862007, 2078653, 2078760, 2079041, 2082426, 1776373, 1776374, 1776375, 1776376, 1776376, 1776377, 1776380, 1776382, 1776389, 1776390, 1776390, 1776394, 1776395, 1776395, 1776399, 1776402, 1776403, 1776404, 1776404, 1776405, 1776405, 1776406, 1776404, 1776405, 1776406, 1776406, 1776407, 1776407, 1776408, 1776408, 1776409, 1776394, 1776398, 1776407, 1776409, 1776409, 1776410, 1776410, 1776412, 1776410, 1776403, 1776414, 1776415, 1776421, 1776422, 1776421, 1776421, 1776422, 1776423, 1776426, 1776418, 1776427, 1776428, 1776426, 1776428, 1776429, 1776429, 1776430, 1776425, 1776431, 1776431, 1776430, 1776432, 1776432, 1776433, 1776434, 1776434, 1776435, 1776436, 1776436, 1776436, 1776436, 1776437, 1776437, 1776437, 1776437, 1776438, 1776438, 1861985, 1776439, 1847397, 1861985, 1861985, 1862024, 1862024, 1862026, 1862035, 1862037, 1862039, 1862043, 1862044, 2078686, 2078729, 2079035, 1861985, 1861986, 1918368, 1918370, 1918372, 1932956, 2149657, 1932958, 1932961, 1947531, 1947532, 1947533, 1947534, 1947534, 1947541, 1947542, 1947543, 1947549, 1947553, 1947556, 1947566, 1947569, 1947570, 1947570, 1947571, 1947607, 1947571, 1947571, 1947572, 1947573, 1947573, 1947580, 1947581, 1947582, 1947588, 1947592, 1947594, 1947605, 1947608, 1947608, 1947609, 1947609, 1947610, 1947611, 1947611, 1947612, 1947612, 1947613, 1947613, 1947614, 1947615, 1947615, 1947616, 1947617, 1947617, 1947618, 1947618, 1947619, 1947619, 1947620, 1947621, 1947622, 1947622, 1947623, 1947624, 1947624, 1947625, 1947625, 1947626, 1947626, 1947627, 1947628, 1947629, 1947629, 1947630, 1947631, 1947636, 1947645, 1947646, 1947646, 1947648, 1947611, 1947612, 1947612, 1947621, 1947622, 1947623, 1947636, 1947645, 1947647, 1947612, 1947613, 1947614, 1947615, 1947618, 1947620, 1947621, 1947623, 1947623, 1947624, 1947625, 1947626, 1947626, 1947627, 1947628, 1947629, 1947629, 1947632, 1947646, 1947647, 1947613, 1947614, 1947615, 1947616, 1947617, 1947620, 1947621, 1947622, 1947623, 1947624, 1947625, 1947626, 1947627, 1947628, 1947633, 1947637, 1947644, 1947646, 1947646, 1947647, 1947648, 1947614, 1947615, 1947616, 1947616, 1947617, 1947618, 1947621, 1947622, 1947624, 1947625, 1947625, 1947626, 1947627, 1947628, 1947629, 1947630, 1947647, 1947648, 1947615, 1947618, 1947622, 1947623, 1947625, 1947625, 1947626, 1947631, 1947619, 1947621, 1947622, 1947623, 1947625, 1947627, 1947649, 1947627, 1947630, 1947623, 1947624, 1947626, 1947621, 1947625, 1947627, 1947624, 1947625, 1947627, 1947651, 1947624, 1947626, 1947628, 1947632, 1947634, 1947630, 1947634, 1947633, 1947646, 1947653, 1947627, 1947631, 1947636, 1947653, 1947652, 1947628, 1947630, 1947630, 1947629, 1947629, 1947631, 1947655, 1947630, 1947632, 1947633, 1947634, 1947636, 1947639, 1947644, 1947645, 1947645, 1947649, 1947654, 1947655, 1947656, 1947634, 1947632, 1947633, 1947634, 1947635, 1947635, 1947636, 1947637, 1947637, 1947638, 1947639, 1947639, 1947640, 1947640, 1947641, 1947642, 1947644, 1947646, 1947646, 1947647, 1947647, 1947648, 1947649, 1947655, 1947657, 1947635, 1947634, 1947635, 1947636, 1947636, 1947637, 1947638, 1947639, 1947643, 1947643, 1947645, 1947647, 1947649, 1947657, 1947658, 1947635, 1947636, 1947636, 1947637, 1947637, 1947638, 1947639, 1947640, 1947640, 1947641, 1947641, 1947642, 1947642, 1947643, 1947644, 1947645, 1947646, 1947646, 1947647, 1947648, 1947648, 1947649, 1947649, 1947653, 1947656, 1947657, 1947658, 1947659, 1947659, 1947641, 1947641, 1947654, 1947637, 1947638, 1947638, 1947639, 1947640, 1947641, 1947643, 1947648, 1947649, 1947657, 1947658, 1947638, 1947639, 1947639, 1947640, 1947640, 1947642, 1947642, 1947643, 1947643, 1947644, 1947645, 1947647, 1947648, 1947649, 1947649, 1947650, 1947651, 1947657, 1947660, 1947639, 1947640, 1947641, 1947641, 1947642, 1947642, 1947643, 1947643, 1947644, 1947644, 1947648, 1947649, 1947650, 1947661, 1947640, 1947641, 1947642, 1947643, 1947643, 1947644, 1947644, 1947645, 1947648, 1947650, 1947650, 1947651, 1947652, 1947658, 1947659, 1947661, 1947641, 1947642, 1947643, 1947644, 1947644, 1947645, 1947645, 1947646, 1947647, 1947649, 1947650, 1947651, 1947651, 1947653, 1947655, 1947658, 1947660, 1947662, 1947645, 1947647, 1947643, 1947644, 1947644, 1947645, 1947646, 1947646, 1947647, 1947647, 1947650, 1947651, 1947652, 1947653, 1947658, 1947659, 1947660, 1947663, 1947645, 1947646, 1947648, 1947652, 1947653, 1947660, 1947646, 1947646, 1947647, 1947648, 1947651, 1947653, 1947659, 1947664, 1947646, 1947649, 1947652, 1947657, 1947664, 1947647, 1947648, 1947648, 1947649, 1947649, 1947650, 1947652, 1947653, 1947654, 1947655, 1947661, 1947663, 1947664, 1947665, 1947648, 1947649, 1947649, 1947650, 1947652, 1947655, 1947656, 1947658, 1947660, 1947662, 1947664, 1947665, 1947649, 1947650, 1947650, 1947651, 1947653, 1947653, 1947654, 1947655, 1947655, 1947656, 1947660, 1947663, 1947664, 1947665, 1947666, 2164640, 1947651, 1947653, 1947654, 1947655, 1947656, 1947657, 1947658, 1947660, 1947662, 1947666, 1947651, 1947654, 1947655, 1947656, 1947662, 1947665, 1947666, 1947667, 1947652, 1947653, 1947654, 1947654, 1947655, 1947656, 1947656, 1947657, 1947657, 1947658, 1947667, 1947667, 1947655, 1947656, 1947657, 1947658, 1947658, 1947667, 1947668, 1947668, 1947658, 1947658, 1947657, 1947658, 1947659, 1947659, 1947660, 1947660, 1947662, 1947666, 1947669, 1947670, 1947659, 1947660, 1947661, 1947670, 1947671, 1947660, 1947661, 1947661, 1947670, 1947671, 1947661, 1947662, 1947662, 1947663, 1947667, 1947669, 1947670, 1947671, 1947671, 1947672, 1947662, 1947663, 1947663, 1947664, 1947666, 1947671, 1947672, 1947672, 1947669, 1947671, 1947672, 1947673, 1947667, 1947668, 1947671, 1947672, 1947673, 1947673, 1947672, 1947672, 1947674, 1947675, 1947675, 1947674, 1947676, 1947675, 1947673, 1947677, 1947677, 1947675, 1947676, 1947677, 1947678, 1947678, 1947678, 1947679, 1947680, 1947679, 1947680, 1947679, 1947681, 1947680, 1947681, 1947681, 1947681, 1947682, 1947682, 1947683, 1947684, 1947684, 1947685, 1947686, 1947688, 1947688, 1947689, 1947689, 1947690, 1947691, 1947692, 1947693, 1947693, 1947694, 1947697, 1947700, 1947704, 1947705, 1947708, 1947710, 1947711, 1947712, 1947715, 1947719, 1947719, 1947720, 1947720, 1947721, 1947721, 1947722, 2112320, 2164308, 2164331, 2164351, 2164359, 2164361, 2164362, 2164364, 2164657, 2164696, 2164696, 1947684, 1947685, 1947686, 1947687, 1947688, 1947701, 1947712, 1947720, 1947720, 1947721, 1947721, 1947722, 1947722, 1947723, 2164351, 1947685, 1947689, 1947699, 1947716, 1947723, 1947689, 1947691, 1947692, 1947693, 1947694, 1947695, 1947699, 1947700, 1947702, 1947703, 1947704, 1947709, 1947713, 1947714, 1947715, 1947718, 1947719, 1947720, 1947721, 1947721, 1947722, 1947722, 1947723, 1947723, 1947717, 1947724, 1947725, 1947724, 1947694, 1947695, 1947697, 1947725, 1947726, 2164314, 1947695, 1947697, 1947727, 1947728, 1947725, 1947727, 1947728, 1947699, 1947729, 1947729, 2164665, 1947729, 1947729, 1947717, 1947731, 2164361, 1947731, 2164361, 1947732, 1947733, 1947735, 1947736, 1947737, 1947737, 1947732, 1947733, 1947738, 1947739, 1947740, 1947743, 1947744, 1947737, 1947745, 1947747, 1947749, 1947750, 1947749, 1947750, 1947751, 1947747, 1947752, 1947753, 1947754, 2164340, 1947754, 1947755, 1947756, 1947756, 1947755, 1947757, 1947758, 1947757, 1947758, 1947758, 1947758, 1947759, 1947758, 1947759, 1947759, 1947760, 1947760, 1947761, 1947762, 1947776, 1983042, 1987338, 2112358, 2112360, 2164347, 2164347, 2164389, 2164390, 2164391, 2164395, 2164398, 2164398, 2164400, 2164400, 2164401, 2164401, 2164403, 2164696, 2178056, 2164348, 2164348, 2164363, 2018338, 2018356, 2199643, 2199662, 2026947, 2203957, 2276970, 2276970, 2276972, 2276975, 2329001, 2328960, 2328962, 2380933, 2380934, 2380935, 2380935, 2380936, 2380943, 2380944, 2380944, 2380945, 2380946, 2380956, 2380966, 2380967, 2380972, 2380974, 2380974, 2380975, 2380975, 2380976, 2380976, 2381009, 2380936, 2380936, 2380937, 2380944, 2380945, 2380976, 2380977, 2380946, 2380976, 2380977, 2380977, 2380945, 2380976, 2380977, 2380978, 2380952, 2380978, 2380978, 2380953, 2380954, 2381292, 2380954, 2380955, 2380986, 2380994, 2380955, 2380956, 2380957, 2380957, 2380987, 2381294, 2380988, 2380958, 2380987, 2380989, 2380997, 2380992, 2380998, 2381006, 2381008, 2381008, 2381009, 2381014, 2381016, 2381017, 2381017, 2381017, 2381018, 2381018, 2381022, 2381094, 2381019, 2381020, 2381020, 2381021, 2381021, 2381022, 2381022, 2381023, 2381023, 2381024, 2381024, 2381025, 2381025, 2381026, 2381027, 2381027, 2381028, 2381028, 2381029, 2381029, 2381030, 2381030, 2381031, 2381031, 2381032, 2381033, 2381034, 2381034, 2381035, 2381035, 2381037, 2381037, 2381038, 2381039, 2381040, 2381040, 2381041, 2381044, 2381048, 2381049, 2381050, 2381051, 2381052, 2381056, 2381094, 2381020, 2381021, 2381021, 2381022, 2381024, 2381024, 2381026, 2381027, 2381027, 2381028, 2381029, 2381030, 2381031, 2381031, 2381032, 2381052, 2381052, 2381026, 2381027, 2381028, 2381032, 2381053, 2381027, 2381028, 2381028, 2381029, 2381030, 2381031, 2381041, 2381044, 2381053, 2381028, 2381029, 2381032, 2381028, 2381029, 2381054, 2381029, 2381055, 2381029, 2381055, 2381056, 2381031, 2381034, 2381037, 2381044, 2381056, 2381031, 2381032, 2381032, 2381033, 2381034, 2381035, 2381049, 2381050, 2381057, 2381057, 2381033, 2381033, 2381033, 2381034, 2381035, 2381036, 2381036, 2381037, 2381048, 2381052, 2381054, 2381058, 2381034, 2381035, 2381035, 2381036, 2381036, 2381037, 2381037, 2381038, 2381040, 2381042, 2381042, 2381044, 2381045, 2381049, 2381054, 2381055, 2381056, 2381057, 2381059, 2381059, 2381035, 2381036, 2381036, 2381037, 2381037, 2381038, 2381038, 2381039, 2381040, 2381041, 2381042, 2381042, 2381045, 2381046, 2381047, 2381048, 2381049, 2381049, 2381052, 2381053, 2381054, 2381055, 2381055, 2381057, 2381059, 2381060, 2381036, 2381037, 2381037, 2381038, 2381038, 2381039, 2381039, 2381040, 2381042, 2381042, 2381043, 2381043, 2381044, 2381046, 2381046, 2381048, 2381049, 2381050, 2381050, 2381051, 2381052, 2381053, 2381054, 2381054, 2381055, 2381056, 2381058, 2381060, 2381060, 2381038, 2381039, 2381044, 2381055, 2381058, 2381061, 2381039, 2381039, 2381040, 2381041, 2381044, 2381045, 2381047, 2381049, 2381051, 2381053, 2381058, 2381061, 2381061, 2381039, 2381040, 2381040, 2381042, 2381045, 2381048, 2381049, 2381050, 2381051, 2381052, 2381053, 2381054, 2381055, 2381057, 2381059, 2381062, 2381040, 2381041, 2381043, 2381044, 2381045, 2381045, 2381050, 2381050, 2381051, 2381053, 2381054, 2381055, 2381060, 2381062, 2381041, 2381043, 2381043, 2381044, 2381046, 2381047, 2381048, 2381048, 2381049, 2381050, 2381051, 2381052, 2381053, 2381053, 2381055, 2381056, 2381058, 2381061, 2381061, 2381062, 2381063, 2381042, 2381043, 2381043, 2381044, 2381045, 2381045, 2381046, 2381046, 2381047, 2381049, 2381049, 2381050, 2381051, 2381051, 2381052, 2381052, 2381053, 2381053, 2381055, 2381056, 2381057, 2381057, 2381059, 2381060, 2381061, 2381061, 2381063, 2381063, 2381046, 2381054, 2381055, 2381056, 2381064, 2381045, 2381047, 2381057, 2381064, 2381064, 2381046, 2381047, 2381050, 2381054, 2381054, 2381060, 2381062, 2381065, 2381051, 2381053, 2381053, 2381055, 2381061, 2381062, 2381064, 2381065, 2381047, 2381049, 2381060, 2381066, 2381052, 2381056, 2381063, 2381049, 2381057, 2381060, 2381067, 2381050, 2381053, 2381053, 2381055, 2381055, 2381061, 2381065, 2381067, 2381053, 2381053, 2381055, 2381056, 2381057, 2381057, 2381058, 2381059, 2381061, 2381066, 2381068, 2381055, 2381055, 2381056, 2381062, 2381068, 2381058, 2381069, 2381063, 2381070, 2381058, 2381059, 2381060, 2381061, 2381062, 2381063, 2381069, 2381070, 2381070, 2381066, 2381070, 2381071, 2381344, 2381063, 2381071, 2381072, 2381060, 2381061, 2381061, 2381064, 2381067, 2381070, 2381072, 2381072, 2381346, 2381061, 2381062, 2381064, 2381065, 2381065, 2381066, 2381067, 2381070, 2381073, 2381063, 2381065, 2381066, 2381067, 2381073, 2381073, 2381064, 2381066, 2381068, 2381073, 2381074, 2381347, 2381066, 2381067, 2381069, 2381070, 2381071, 2381072, 2381074, 2381065, 2381067, 2381072, 2381074, 2381075, 2381068, 2381069, 2381073, 2381075, 2381076, 2381069, 2381070, 2381069, 2381070, 2381076, 2381077, 2381071, 2381071, 2381072, 2381073, 2381074, 2381077, 2381077, 2381390, 2381078, 2381072, 2381073, 2381074, 2381076, 2381077, 2381078, 2381079, 2381074, 2381074, 2381076, 2381077, 2381077, 2381079, 2381077, 2381078, 2381079, 2381080, 2381078, 2381080, 2381080, 2381354, 2381081, 2381081, 2381124, 2381081, 2381082, 2381081, 2381082, 2381082, 2381356, 2381082, 2381083, 2381083, 2381357, 2381083, 2381084, 2381084, 2381085, 2381086, 2381086, 2381087, 2381088, 2381088, 2381089, 2381089, 2381091, 2381091, 2381094, 2381094, 2381098, 2381099, 2381100, 2381110, 2381116, 2381118, 2381122, 2381123, 2381124, 2381124, 2381125, 2381126, 2381126, 2381127, 2381127, 2381358, 2381358, 2381397, 2384761, 2381086, 2381087, 2381088, 2381088, 2381089, 2381089, 2381090, 2381090, 2381091, 2381092, 2381093, 2381094, 2381095, 2381096, 2381097, 2381100, 2381110, 2381110, 2381117, 2381122, 2381123, 2381124, 2381125, 2381125, 2381126, 2381126, 2381127, 2381127, 2381128, 2381089, 2381128, 2381096, 2381128, 2381129, 2381129, 2381130, 2381092, 2381097, 2381098, 2381101, 2381128, 2381130, 2381361, 2381361, 2381116, 2381129, 2381131, 2381097, 2381129, 2381131, 2381362, 2381128, 2381129, 2381130, 2381132, 2381363, 2381402, 2381096, 2381132, 2381133, 2381133, 2381364, 2381134, 2381132, 2381135, 2381135, 2381136, 2381367, 2381108, 2381135, 2381137, 2381109, 2381138, 2381139, 2381140, 2381372, 2381125, 2381133, 2381141, 2381142, 2381143, 2381152, 2381152, 2381152, 2381153, 2381155, 2381159, 2381160, 2381160, 2381164, 2381164, 2381164, 2381165, 2381166, 2381164, 2381166, 2381166, 2381167, 2381397, 2381166, 2381166, 2381167, 2381167, 2381168, 2381167, 2381168, 2381168, 2381169, 2381169, 2381170, 2381400, 2381401, 2381440, 2384803, 2384825, 2381401, 2381631, 2381632, 2381633, 2381633, 2381634, 2381634, 2381635, 2381635, 2381636, 2381636, 2381637, 2381641, 2381642, 2381643, 2381643, 2381647, 2381653, 2381654, 2381659, 2381662, 2381666, 2381666, 2381668, 2381669, 2381670, 2381670, 2381671, 2381633, 2381634, 2381635, 2381635, 2381636, 2381636, 2381643, 2381650, 2381670, 2381671, 2381671, 2381634, 2381635, 2381671, 2381671, 2381635, 2381636, 2381671, 2381672, 2381672, 2381643, 2381672, 2381638, 2381638, 2381641, 2381642, 2381661, 2381672, 2381672, 2381673, 2381673, 2381638, 2381672, 2381657, 2381673, 2381674, 2381674, 2381674, 2381675, 2381675, 2381670, 2381678, 2381652, 2381652, 2381680, 2381653, 2381654, 2381681, 2381654, 2381682, 2381655, 2381656, 2381676, 2381682, 2381656, 2381666, 2381683, 2381686, 2381688, 2381692, 2381693, 2381697, 2381698, 2381701, 2381702, 2381703, 2381704, 2381705, 2381706, 2381707, 2381708, 2381708, 2381708, 2381709, 2381709, 2381710, 2381711, 2381711, 2381712, 2381712, 2381713, 2381713, 2381714, 2381714, 2381715, 2381715, 2381716, 2381717, 2381717, 2381718, 2381719, 2381720, 2381720, 2381721, 2381721, 2381722, 2381722, 2381723, 2381723, 2381725, 2381726, 2381726, 2381727, 2381727, 2381728, 2381728, 2381729, 2381730, 2381733, 2381734, 2381734, 2381737, 2381737, 2381742, 2381746, 2381779, 2381711, 2381712, 2381712, 2381713, 2381713, 2381714, 2381714, 2381715, 2381715, 2381716, 2381717, 2381717, 2381718, 2381719, 2381720, 2381721, 2381722, 2381722, 2381723, 2381724, 2381725, 2381727, 2381747, 2381712, 2381713, 2381713, 2381714, 2381715, 2381716, 2381717, 2381720, 2381721, 2381723, 2381723, 2381724, 2381713, 2381714, 2381714, 2381716, 2381716, 2381717, 2381718, 2381719, 2381720, 2381721, 2381722, 2381725, 2381727, 2381714, 2381715, 2381716, 2381716, 2381717, 2381717, 2381718, 2381719, 2381720, 2381721, 2381722, 2381722, 2381723, 2381724, 2381725, 2381725, 2381727, 2381735, 2381717, 2381717, 2381718, 2381720, 2381722, 2381723, 2381725, 2381726, 2381737, 2381716, 2381718, 2381718, 2381722, 2381723, 2381723, 2381724, 2381748, 2381718, 2381719, 2381720, 2381722, 2381723, 2381723, 2381724, 2381727, 2381719, 2381719, 2381720, 2381723, 2381724, 2381724, 2381726, 2381727, 2381719, 2381720, 2381721, 2381722, 2381724, 2381725, 2381726, 2381739, 2381720, 2381721, 2381721, 2381722, 2381722, 2381723, 2381724, 2381725, 2381725, 2381726, 2381727, 2381728, 2381728, 2381730, 2381722, 2381722, 2381723, 2381723, 2381724, 2381725, 2381726, 2381727, 2381727, 2381728, 2381729, 2381725, 2381724, 2381725, 2381726, 2381727, 2381728, 2381729, 2381730, 2381725, 2381726, 2381727, 2381727, 2381728, 2381729, 2381729, 2381730, 2381725, 2381727, 2381728, 2381729, 2381734, 2381727, 2381728, 2381728, 2381729, 2381731, 2381733, 2381727, 2381728, 2381729, 2381729, 2381730, 2381731, 2381731, 2381732, 2381734, 2381745, 2381746, 2381755, 2381755, 2381729, 2381730, 2381730, 2381731, 2381732, 2381732, 2381733, 2381733, 2381735, 2381752, 2381731, 2381732, 2381732, 2381733, 2381733, 2381734, 2381734, 2381735, 2381735, 2381736, 2381737, 2381737, 2381738, 2381739, 2381739, 2381740, 2381740, 2381741, 2381743, 2381745, 2381747, 2381747, 2381751, 2381756, 2381757, 2381734, 2381736, 2381733, 2381734, 2381734, 2381735, 2381736, 2381737, 2381737, 2381738, 2381738, 2381739, 2381740, 2381740, 2381744, 2381745, 2381748, 2381751, 2381734, 2381735, 2381735, 2381736, 2381737, 2381737, 2381738, 2381740, 2381740, 2381742, 2381742, 2381746, 2381747, 2381748, 2381749, 2381749, 2381751, 2381752, 2381758, 2381735, 2381736, 2381736, 2381737, 2381737, 2381738, 2381738, 2381739, 2381740, 2381740, 2381741, 2381742, 2381742, 2381743, 2381745, 2381746, 2381747, 2381747, 2381749, 2381749, 2381754, 2381736, 2381737, 2381738, 2381739, 2381741, 2381742, 2381743, 2381745, 2381746, 2381737, 2381738, 2381738, 2381739, 2381739, 2381740, 2381740, 2381741, 2381741, 2381742, 2381742, 2381743, 2381743, 2381744, 2381745, 2381746, 2381747, 2381748, 2381748, 2381750, 2381750, 2381751, 2381754, 2381754, 2381755, 2381759, 2381759, 2381760, 2381739, 2381740, 2381740, 2381742, 2381747, 2381750, 2381739, 2381740, 2381741, 2381747, 2381748, 2381749, 2381751, 2381740, 2381741, 2381741, 2381742, 2381742, 2381743, 2381744, 2381744, 2381745, 2381745, 2381746, 2381746, 2381747, 2381748, 2381748, 2381749, 2381750, 2381751, 2381752, 2381752, 2381755, 2381756, 2381756, 2381757, 2381757, 2381760, 2381761, 2381761, 2381741, 2381742, 2381743, 2381744, 2381747, 2381747, 2381749, 2381752, 2381742, 2381743, 2381744, 2381745, 2381745, 2381747, 2381749, 2381750, 2381751, 2381752, 2381753, 2381758, 2381743, 2381744, 2381744, 2381745, 2381745, 2381746, 2381746, 2381747, 2381748, 2381748, 2381749, 2381749, 2381750, 2381751, 2381753, 2381753, 2381754, 2381755, 2381756, 2381757, 2381757, 2381758, 2381762, 2381763, 2381744, 2381745, 2381746, 2381746, 2381747, 2381752, 2381753, 2381759, 2381763, 2381745, 2381746, 2381746, 2381747, 2381747, 2381748, 2381749, 2381750, 2381751, 2381752, 2381753, 2381754, 2381754, 2381759, 2381764, 2381746, 2381747, 2381747, 2381748, 2381749, 2381749, 2381751, 2381752, 2381753, 2381754, 2381755, 2381756, 2381758, 2381747, 2381748, 2381751, 2381753, 2381755, 2381755, 2381759, 2381748, 2381749, 2381749, 2381750, 2381752, 2381752, 2381753, 2381753, 2381754, 2381755, 2381756, 2381756, 2381758, 2381759, 2381760, 2381765, 2381765, 2381750, 2381751, 2381752, 2381753, 2381753, 2381754, 2381754, 2381756, 2381760, 2381764, 2381765, 2381750, 2381751, 2381751, 2381752, 2381753, 2381754, 2381755, 2381756, 2381758, 2381760, 2381761, 2381761, 2381762, 2381762, 2381766, 2381766, 2381751, 2381752, 2381753, 2381753, 2381754, 2381755, 2381757, 2381752, 2381754, 2381755, 2381756, 2381763, 2381754, 2381754, 2381755, 2381756, 2381758, 2381758, 2381759, 2381759, 2381762, 2381763, 2381767, 2381768, 2381755, 2381758, 2381755, 2381756, 2381757, 2381760, 2381756, 2381757, 2381757, 2381758, 2381759, 2381760, 2381760, 2381763, 2381763, 2381764, 2381765, 2381768, 2381769, 2381769, 2381757, 2381758, 2381760, 2381760, 2381769, 2381758, 2381759, 2381760, 2381761, 2381761, 2381762, 2381764, 2381765, 2381766, 2381770, 2381770, 2381759, 2381761, 2381766, 2381771, 2381760, 2381761, 2381761, 2381762, 2381762, 2381763, 2381764, 2381765, 2381765, 2381766, 2381766, 2381769, 2381769, 2381771, 2381771, 2381762, 2381762, 2381762, 2381766, 2381770, 2381763, 2381764, 2381766, 2381766, 2381767, 2381767, 2381768, 2381769, 2381770, 2381772, 2381773, 2381764, 2381765, 2381765, 2381767, 2381767, 2381768, 2381768, 2381769, 2381769, 2381770, 2381771, 2381771, 2381772, 2381772, 2381773, 2381773, 2403760, 2381765, 2381766, 2381766, 2381767, 2381767, 2381768, 2381768, 2381769, 2381770, 2381771, 2381771, 2381772, 2381772, 2381773, 2381773, 2381774, 2381767, 2381768, 2381768, 2381769, 2381770, 2381774, 2381774, 2381767, 2381768, 2381768, 2381769, 2381769, 2381770, 2381775, 2381769, 2381775, 2381775, 2381769, 2381770, 2381770, 2381771, 2381771, 2381774, 2381775, 2381776, 2381770, 2381771, 2381771, 2381772, 2381773, 2381773, 2381774, 2381774, 2381775, 2381775, 2381776, 2381776, 2381771, 2381772, 2381772, 2381773, 2381774, 2381774, 2381776, 2381776, 2381777, 2381772, 2381773, 2381773, 2381774, 2381775, 2381775, 2381776, 2381776, 2381777, 2381777, 2381773, 2381774, 2381775, 2381776, 2381777, 2381777, 2381778, 2381774, 2381775, 2381776, 2381776, 2381777, 2381777, 2381778, 2381778, 2381775, 2381777, 2381778, 2381778, 2381779, 2381777, 2381778, 2381779, 2381779, 2381778, 2381779, 2381780, 2381778, 2381779, 2381779, 2381780, 2381780, 2381779, 2381780, 2381780, 2381781, 2381780, 2381781, 2381781, 2381781, 2381782, 2381782, 2381783, 2381784, 2381784, 2381785, 2381786, 2381788, 2381788, 2381789, 2381789, 2381790, 2381790, 2381791, 2381791, 2381792, 2381792, 2381793, 2381793, 2381794, 2381795, 2381797, 2381798, 2381799, 2381801, 2381807, 2381807, 2381808, 2381809, 2381811, 2381812, 2381812, 2381815, 2381817, 2381817, 2381818, 2381818, 2381819, 2381819, 2381820, 2381820, 2381821, 2381821, 2381822, 2385110, 2385131, 2385131, 2385132, 2385133, 2386543, 2381784, 2381785, 2381785, 2381786, 2381786, 2381787, 2381787, 2381788, 2381788, 2381789, 2381789, 2381790, 2381790, 2381791, 2381791, 2381792, 2381792, 2381793, 2381793, 2381794, 2381795, 2381796, 2381797, 2381797, 2381798, 2381801, 2381805, 2381806, 2381807, 2381808, 2381810, 2381810, 2381811, 2381812, 2381812, 2381813, 2381813, 2381815, 2381816, 2381817, 2381817, 2381818, 2381818, 2381819, 2381819, 2381820, 2381820, 2381821, 2381821, 2381822, 2381822, 2385132, 2385196, 2381785, 2381786, 2381787, 2381788, 2381790, 2381790, 2381791, 2381792, 2381793, 2381793, 2381798, 2381806, 2381812, 2381816, 2381819, 2381820, 2381821, 2381822, 2381823, 2381788, 2381790, 2381791, 2381792, 2381793, 2381793, 2381794, 2381806, 2381807, 2381810, 2381816, 2381817, 2381819, 2381820, 2381821, 2381823, 2381791, 2381791, 2381792, 2381823, 2381792, 2381792, 2381793, 2381794, 2381824, 2381793, 2381793, 2381792, 2381793, 2381793, 2381794, 2381795, 2381813, 2381792, 2381796, 2381804, 2381823, 2381794, 2381794, 2381797, 2381800, 2381824, 2385115, 2381795, 2381797, 2381804, 2381817, 2381825, 2381795, 2381797, 2381797, 2381798, 2381799, 2381801, 2381808, 2381812, 2381814, 2381821, 2381825, 2381827, 2381828, 2381796, 2381797, 2381797, 2381798, 2381798, 2381799, 2381799, 2381800, 2381801, 2381820, 2381821, 2381824, 2381825, 2381825, 2381826, 2381827, 2381827, 2381828, 2385138, 2390840, 2381798, 2381802, 2381822, 2381827, 2381828, 2385117, 2381799, 2381800, 2381817, 2381825, 2381827, 2381828, 2381799, 2381800, 2381800, 2381801, 2381827, 2381829, 2381830, 2381800, 2381801, 2381801, 2381802, 2381806, 2381808, 2381813, 2381818, 2381818, 2381820, 2381820, 2381823, 2381825, 2381827, 2381828, 2381828, 2381829, 2381829, 2381830, 2381801, 2381802, 2381802, 2381803, 2381804, 2381808, 2381808, 2381815, 2381824, 2381826, 2381827, 2381828, 2381829, 2381829, 2381830, 2385140, 2381802, 2381803, 2381804, 2381804, 2381807, 2381812, 2381815, 2381816, 2381828, 2381828, 2381829, 2381830, 2381830, 2381831, 2381804, 2381805, 2381806, 2381807, 2381822, 2381827, 2381829, 2381829, 2381831, 2381831, 2381832, 2381804, 2381805, 2381805, 2381807, 2381808, 2381809, 2381815, 2381822, 2381825, 2381825, 2381826, 2381827, 2381828, 2381828, 2381829, 2381829, 2381831, 2381831, 2381808, 2381816, 2381826, 2381830, 2381832, 2381833, 2381806, 2381830, 2381807, 2381808, 2381819, 2381821, 2381823, 2381824, 2381829, 2381831, 2381833, 2381834, 2381809, 2381823, 2381826, 2381831, 2381819, 2381827, 2381834, 2381816, 2381827, 2381829, 2381812, 2381821, 2381829, 2381833, 2381814, 2381828, 2381835, 2381835, 2381821, 2381829, 2381834, 2381836, 2381825, 2381831, 2381835, 2381826, 2381832, 2381834, 2381836, 2381835, 2381834, 2381838, 2381835, 2381837, 2381832, 2381839, 2381839, 2381840, 2381841, 2381829, 2381838, 2381841, 2381842, 2381844, 2381838, 2381840, 2381836, 2381838, 2381841, 2381842, 2381842, 2381843, 2381845, 2381846, 2381844, 2381835, 2381838, 2381840, 2381842, 2381845, 2381847, 2381848, 2381846, 2381846, 2381846, 2381847, 2381847, 2381840, 2381841, 2381844, 2381847, 2381849, 2381848, 2381848, 2381849, 2381850, 2381851, 2381848, 2381848, 2381849, 2381850, 2381851, 2381846, 2381848, 2381849, 2381847, 2381849, 2381852, 2381846, 2381850, 2381852, 2381851, 2381852, 2381853, 2381848, 2381849, 2381850, 2381851, 2381851, 2381853, 2381853, 2381851, 2381852, 2381853, 2381854, 2390866, 2381852, 2381852, 2381852, 2381852, 2381853, 2381854, 2381852, 2381853, 2381853, 2381854, 2381855, 2381856, 2385166, 2381853, 2381854, 2381854, 2381855, 2381856, 2381854, 2381855, 2381855, 2381856, 2381856, 2381857, 2381857, 2381855, 2381856, 2381856, 2381857, 2381857, 2381858, 2385167, 2381856, 2381857, 2381857, 2381858, 2381857, 2381858, 2381859, 2381858, 2381859, 2381859, 2381859, 2381860, 2381860, 2395058, 2381861, 2381862, 2381865, 2381868, 2381905, 2381921, 2381945, 2382129, 2385148, 2385149, 2385170, 2385170, 2386498, 2395257, 2385149, 2385149, 2385150, 2385153, 2385156, 2385193, 2385209, 2382043, 2385246, 2382467, 2385487, 2388436, 2388437, 2388438, 2388438, 2388439, 2388440, 2388440, 2388441, 2388442, 2388443, 2388444, 2388444, 2388448, 2388449, 2388450, 2388454, 2388455, 2388456, 2388457, 2388457, 2388458, 2388458, 2388438, 2388439, 2388443, 2388457, 2388458, 2388458, 2388439, 2388458, 2388459, 2388459, 2388441, 2388442, 2388442, 2388443, 2388445, 2388458, 2388458, 2388459, 2388459, 2388460, 2388459, 2388460, 2388460, 2388460, 2388460, 2388461, 2388461, 2388461, 2388462, 2388461, 2388463, 2388463, 2388464, 2388464, 2388464, 2388465, 2388462, 2388470, 2388470, 2388470, 2388472, 2388475, 2388477, 2388477, 2388477, 2388477, 2388478, 2388478, 2388479, 2388479, 2388480, 2388481, 2388481, 2388482, 2388482, 2388483, 2388484, 2388484, 2388485, 2388485, 2388486, 2388486, 2388487, 2388487, 2388488, 2388488, 2388489, 2388489, 2388490, 2388490, 2388491, 2388491, 2388492, 2388493, 2388493, 2388494, 2388494, 2388495, 2388496, 2388496, 2388497, 2388497, 2388498, 2388498, 2388499, 2388500, 2388500, 2388501, 2388501, 2388502, 2388502, 2388503, 2388503, 2388504, 2388504, 2388505, 2388505, 2388506, 2388506, 2388507, 2388508, 2388509, 2388509, 2388510, 2388510, 2388511, 2388512, 2388514, 2388516, 2388516, 2388517, 2388517, 2388522, 2388525, 2388526, 2388530, 2388534, 2388555, 2388481, 2388482, 2388483, 2388485, 2388485, 2388486, 2388486, 2388487, 2388487, 2388488, 2388488, 2388489, 2388489, 2388490, 2388490, 2388491, 2388492, 2388493, 2388494, 2388495, 2388496, 2388497, 2388497, 2388498, 2388499, 2388500, 2388501, 2388502, 2388503, 2388504, 2388506, 2388506, 2388508, 2388508, 2388510, 2388516, 2388534, 2388482, 2388483, 2388483, 2388486, 2388486, 2388489, 2388490, 2388491, 2388491, 2388493, 2388496, 2388497, 2388499, 2388501, 2388502, 2388503, 2388505, 2388506, 2388508, 2388509, 2388485, 2388485, 2388487, 2388487, 2388488, 2388488, 2388491, 2388492, 2388492, 2388493, 2388494, 2388495, 2388496, 2388497, 2388497, 2388500, 2388501, 2388502, 2388503, 2388504, 2388504, 2388505, 2388505, 2388507, 2388509, 2388509, 2388511, 2388512, 2388484, 2388486, 2388487, 2388491, 2388491, 2388492, 2388498, 2388503, 2388507, 2388487, 2388488, 2388488, 2388492, 2388493, 2388498, 2388502, 2388503, 2388506, 2388509, 2388487, 2388504, 2388505, 2388488, 2388490, 2388500, 2388509, 2388512, 2388491, 2388494, 2388496, 2388499, 2388505, 2388509, 2388490, 2388494, 2388500, 2388504, 2388505, 2388506, 2388507, 2388508, 2388508, 2388510, 2388491, 2388495, 2388501, 2388505, 2388507, 2388508, 2388512, 2388513, 2388513, 2388515, 2388492, 2388494, 2388495, 2388496, 2388498, 2388501, 2388502, 2388504, 2388504, 2388509, 2388510, 2388510, 2388512, 2388520, 2388498, 2388503, 2388507, 2388508, 2388509, 2388512, 2388515, 2388495, 2388503, 2388506, 2388508, 2388508, 2388511, 2388515, 2388515, 2388497, 2388501, 2388509, 2388510, 2388515, 2388517, 2388501, 2388505, 2388508, 2388510, 2388510, 2388516, 2388498, 2388499, 2388511, 2388513, 2388500, 2388504, 2388507, 2388507, 2388508, 2388509, 2388510, 2388511, 2388512, 2388513, 2388517, 2388519, 2388522, 2388503, 2388507, 2388509, 2388509, 2388510, 2388511, 2388512, 2388517, 2388519, 2388502, 2388503, 2388507, 2388509, 2388511, 2388513, 2388514, 2388516, 2388517, 2388518, 2388522, 2388514, 2388525, 2388519, 2388506, 2388508, 2388512, 2388513, 2388515, 2388515, 2388517, 2388520, 2388509, 2388508, 2388508, 2388509, 2388510, 2388514, 2388515, 2388527, 2388508, 2388510, 2388516, 2388518, 2388519, 2388520, 2388523, 2388514, 2388516, 2388518, 2388520, 2388524, 2388511, 2388511, 2388512, 2388515, 2388516, 2388517, 2388517, 2388522, 2388513, 2388519, 2388524, 2388513, 2388515, 2388517, 2388518, 2388519, 2388521, 2388523, 2388550, 2388513, 2388514, 2388515, 2388516, 2388517, 2388518, 2388518, 2388519, 2388519, 2388520, 2388520, 2388522, 2388524, 2388524, 2388526, 2388526, 2388540, 2388550, 2388518, 2388519, 2388520, 2388520, 2388521, 2388518, 2388519, 2388520, 2388521, 2388522, 2388523, 2388526, 2388529, 2388516, 2388519, 2388520, 2388521, 2388526, 2388518, 2388519, 2388520, 2388520, 2388521, 2388521, 2388522, 2388522, 2388524, 2388526, 2388519, 2388520, 2388520, 2388521, 2388522, 2388522, 2388523, 2388525, 2388526, 2388527, 2388527, 2388520, 2388524, 2388526, 2388527, 2388522, 2388523, 2388523, 2388524, 2388524, 2388525, 2388525, 2388526, 2388526, 2388527, 2388528, 2388529, 2388530, 2388533, 2388537, 2388554, 2388522, 2388526, 2388528, 2388529, 2388523, 2388524, 2388524, 2388525, 2388525, 2388526, 2388526, 2388527, 2388527, 2388528, 2388529, 2388529, 2388531, 2388532, 2388535, 2388535, 2388536, 2388537, 2388539, 2388555, 2388555, 2388565, 2388524, 2388525, 2388526, 2388528, 2388533, 2388525, 2388526, 2388526, 2388527, 2388528, 2388528, 2388529, 2388529, 2388530, 2388530, 2388531, 2388536, 2388539, 2388539, 2388556, 2388526, 2388527, 2388527, 2388528, 2388529, 2388529, 2388530, 2388531, 2388532, 2388533, 2388534, 2388534, 2388538, 2388527, 2388528, 2388528, 2388529, 2388529, 2388530, 2388531, 2388531, 2388533, 2388533, 2388535, 2388537, 2388538, 2388541, 2388541, 2388542, 2388550, 2388528, 2388529, 2388529, 2388530, 2388530, 2388531, 2388532, 2388533, 2388534, 2388535, 2388558, 2388529, 2388530, 2388530, 2388531, 2388532, 2388532, 2388534, 2388534, 2388558, 2388530, 2388531, 2388532, 2388533, 2388531, 2388532, 2388533, 2388533, 2388534, 2388534, 2388535, 2388535, 2388536, 2388536, 2388537, 2388538, 2388539, 2388539, 2388540, 2388541, 2388541, 2388542, 2388544, 2388551, 2388559, 2388559, 2388532, 2388533, 2388534, 2388535, 2388536, 2388536, 2388537, 2388537, 2388538, 2388534, 2388534, 2388535, 2388536, 2388536, 2388537, 2388537, 2388539, 2388541, 2388543, 2388560, 2388534, 2388535, 2388541, 2388535, 2388536, 2388536, 2388537, 2388537, 2388538, 2388538, 2388539, 2388539, 2388540, 2388540, 2388541, 2388541, 2388544, 2388557, 2388561, 2394301, 2388536, 2388537, 2388537, 2388538, 2388538, 2388539, 2388539, 2388540, 2388540, 2388541, 2388541, 2388542, 2388542, 2388543, 2388543, 2388544, 2388544, 2388546, 2388547, 2388549, 2388551, 2388552, 2388553, 2388555, 2388561, 2388562, 2388537, 2388538, 2388538, 2388539, 2388538, 2388539, 2388539, 2388540, 2388540, 2388541, 2388542, 2388543, 2388543, 2388544, 2388546, 2388546, 2388547, 2388548, 2388563, 2388539, 2388540, 2388540, 2388541, 2388542, 2388543, 2388544, 2388544, 2388545, 2388545, 2388546, 2388546, 2388547, 2388548, 2388548, 2388551, 2388554, 2388556, 2388562, 2388563, 2388563, 2388540, 2388541, 2388541, 2388542, 2388542, 2388543, 2388543, 2388544, 2388544, 2388545, 2388545, 2388546, 2388546, 2388547, 2388547, 2388548, 2388549, 2388549, 2388552, 2388553, 2388555, 2388555, 2388556, 2388556, 2388559, 2388562, 2388563, 2388563, 2388564, 2388541, 2388542, 2388543, 2388543, 2388544, 2388544, 2388545, 2388546, 2388546, 2388547, 2388549, 2388553, 2388554, 2388554, 2388555, 2388556, 2388558, 2388564, 2388542, 2388543, 2388543, 2388544, 2388544, 2388545, 2388545, 2388546, 2388546, 2388547, 2388547, 2388548, 2388548, 2388550, 2388552, 2388553, 2388554, 2388558, 2388564, 2388565, 2388543, 2388544, 2388544, 2388545, 2388545, 2388546, 2388546, 2388547, 2388547, 2388548, 2388548, 2388549, 2388549, 2388550, 2388550, 2388553, 2388553, 2388555, 2388556, 2388557, 2388558, 2388559, 2388561, 2388562, 2388564, 2388565, 2388565, 2388544, 2388545, 2388546, 2388546, 2388548, 2388549, 2388565, 2388566, 2388545, 2388546, 2388547, 2388548, 2388549, 2388549, 2388551, 2388566, 2388546, 2388547, 2388547, 2388548, 2388548, 2388549, 2388549, 2388550, 2388550, 2388551, 2388551, 2388552, 2388554, 2388555, 2388556, 2388557, 2388562, 2388563, 2388566, 2388567, 2388547, 2388548, 2388548, 2388549, 2388550, 2388550, 2388551, 2388552, 2388552, 2388555, 2388557, 2388558, 2388559, 2388566, 2388567, 2388567, 2388548, 2388549, 2388549, 2388550, 2388550, 2388551, 2388551, 2388552, 2388552, 2388553, 2388554, 2388555, 2388556, 2388557, 2388557, 2388558, 2388562, 2388565, 2388567, 2388567, 2388568, 2388549, 2388550, 2388550, 2388551, 2388551, 2388552, 2388552, 2388553, 2388553, 2388554, 2388556, 2388557, 2388558, 2388558, 2388560, 2388561, 2388564, 2388565, 2388568, 2388568, 2388550, 2388551, 2388551, 2388552, 2388552, 2388553, 2388556, 2388558, 2388559, 2388567, 2388568, 2388569, 2388551, 2388552, 2388552, 2388553, 2388553, 2388554, 2388556, 2388558, 2388560, 2388562, 2388566, 2388569, 2388569, 2388552, 2388553, 2388553, 2388555, 2388556, 2388557, 2388557, 2388558, 2388558, 2388559, 2388559, 2388560, 2388560, 2388570, 2388553, 2388554, 2388554, 2388555, 2388555, 2388558, 2388558, 2388559, 2388560, 2388560, 2388562, 2388563, 2388564, 2388566, 2388566, 2388569, 2388570, 2388570, 2389844, 2388554, 2388555, 2388555, 2388556, 2388557, 2388558, 2388558, 2388559, 2388559, 2388560, 2388561, 2388562, 2388563, 2388566, 2388567, 2388569, 2388570, 2388571, 2388555, 2388556, 2388556, 2388557, 2388558, 2388558, 2388559, 2388560, 2388561, 2388561, 2388562, 2388562, 2388563, 2388563, 2388564, 2388567, 2388570, 2388570, 2388571, 2388571, 2388556, 2388557, 2388558, 2388558, 2388560, 2388561, 2388562, 2388563, 2388564, 2388566, 2388567, 2388568, 2388569, 2388571, 2388571, 2388572, 2388558, 2388560, 2388561, 2388562, 2388563, 2388571, 2388572, 2388572, 2388558, 2388559, 2388559, 2388560, 2388560, 2388561, 2388561, 2388562, 2388563, 2388563, 2388564, 2388565, 2388566, 2388567, 2388568, 2388569, 2388569, 2388570, 2388570, 2388571, 2388572, 2388573, 2388560, 2388563, 2388572, 2388573, 2388561, 2388563, 2388565, 2388573, 2388574, 2388562, 2388563, 2388564, 2388565, 2388570, 2388573, 2388574, 2388563, 2388565, 2388566, 2388568, 2388574, 2388575, 2388564, 2388564, 2388565, 2388565, 2388566, 2388566, 2388568, 2388570, 2388570, 2388571, 2388575, 2388575, 2388565, 2388575, 2388576, 2388565, 2388566, 2388566, 2388567, 2388567, 2388568, 2388575, 2388576, 2388576, 2388566, 2388567, 2388569, 2388577, 2388567, 2388568, 2388568, 2388569, 2388569, 2388570, 2388570, 2388572, 2388573, 2388574, 2388576, 2388577, 2388577, 2388568, 2388569, 2388569, 2388570, 2388570, 2388571, 2388577, 2388577, 2388578, 2388569, 2388570, 2388570, 2388571, 2388571, 2388572, 2388573, 2388574, 2388578, 2388578, 2388570, 2388571, 2388571, 2388572, 2388578, 2388578, 2388579, 2388571, 2388572, 2388572, 2388573, 2388574, 2388574, 2388575, 2388576, 2388576, 2388578, 2388579, 2388579, 2388572, 2388573, 2388576, 2388577, 2388577, 2388579, 2388579, 2388580, 2388573, 2388574, 2388575, 2388577, 2388577, 2388580, 2388580, 2388574, 2388575, 2388576, 2388577, 2388578, 2388579, 2388580, 2388581, 2388579, 2388580, 2388581, 2388577, 2388579, 2388581, 2388582, 2388578, 2388581, 2388582, 2388582, 2388582, 2388583, 2388579, 2388580, 2388582, 2388583, 2388583, 2388581, 2388583, 2388584, 2388584, 2388584, 2388584, 2388585, 2388584, 2388585, 2388585, 2388586, 2388586, 2388586, 2388586, 2388587, 2389861, 2388587, 2388588, 2388589, 2388591, 2388592, 2388593, 2388593, 2388594, 2388595, 2388595, 2388596, 2388597, 2388598, 2388598, 2388599, 2388600, 2388602, 2388604, 2388605, 2388606, 2388607, 2388607, 2388608, 2388608, 2388609, 2388609, 2389862, 2389880, 2389880, 2389915, 2394235, 2394328, 2396227, 2388589, 2388590, 2388590, 2388591, 2388592, 2388593, 2388594, 2388594, 2388595, 2388595, 2388596, 2388596, 2388597, 2388597, 2388598, 2388598, 2388599, 2388599, 2388600, 2388600, 2388601, 2388601, 2388602, 2388602, 2388603, 2388605, 2388605, 2388606, 2388606, 2388607, 2388608, 2388608, 2388609, 2388609, 2388610, 2388591, 2388593, 2388594, 2388596, 2388599, 2388601, 2388609, 2388610, 2388610, 2388600, 2388608, 2388610, 2388602, 2388603, 2388610, 2388611, 2388596, 2388601, 2388598, 2388604, 2388610, 2388614, 2388599, 2388605, 2388613, 2388614, 2388614, 2388604, 2388605, 2388608, 2388611, 2388614, 2388606, 2388615, 2388605, 2388606, 2388612, 2388614, 2388614, 2388615, 2388616, 2388613, 2388616, 2388615, 2388616, 2388617, 2396235, 2388608, 2388605, 2388617, 2388618, 2388618, 2388607, 2388609, 2388608, 2388609, 2388609, 2388610, 2388615, 2388619, 2388610, 2388616, 2388620, 2388611, 2388615, 2388620, 2388611, 2388621, 2388614, 2388614, 2388615, 2388615, 2388616, 2388616, 2388617, 2388618, 2388618, 2388619, 2388619, 2388620, 2388620, 2388621, 2388621, 2389874, 2396239, 2388617, 2388621, 2388622, 2388622, 2388615, 2388622, 2388621, 2388623, 2388623, 2388620, 2388622, 2388623, 2388624, 2388623, 2388624, 2388624, 2388623, 2388621, 2388625, 2388625, 2388624, 2388626, 2388624, 2388625, 2388624, 2388625, 2388626, 2388627, 2388625, 2388626, 2388627, 2388627, 2388626, 2388628, 2388627, 2388627, 2388628, 2388628, 2388627, 2388628, 2388628, 2388629, 2388628, 2388629, 2388629, 2388629, 2388630, 2388630, 2388631, 2388632, 2389874, 2389882, 2389883, 2389883, 2389902, 2389904, 2389912, 2394257, 2394285, 2394349, 2396212, 2396263, 2398443, 2398497, 2409444, 25876478, 2388632, 2389883, 2389884, 2389902, 2394258, 2396249, 2389884, 2389884, 2391126, 2391134, 2391135, 2391136, 2391137, 2391137, 2391138, 2391138, 2391139, 2391139, 2391140, 2391140, 2391141, 2391141, 2391142, 2391144, 2391145, 2391146, 2391147, 2391153, 2391153, 2391154, 2391154, 2391137, 2391139, 2391139, 2391140, 2391142, 2391147, 2391152, 2391153, 2391153, 2391154, 2391154, 2391155, 2391139, 2391140, 2391141, 2391143, 2391149, 2391154, 2391155, 2391155, 2391155, 2391156, 2391156, 2391155, 2391156, 2391157, 2391148, 2391157, 2391157, 2391157, 2391157, 2391157, 2391158, 2391158, 2391159, 2391159, 2391159, 2391159, 2391160, 2391160, 2391161, 2391163, 2391164, 2391164, 2391165, 2391167, 2391170, 2391170, 2391170, 2391171, 2391171, 2391172, 2391172, 2391229, 2391173, 2391174, 2391174, 2391175, 2391175, 2391176, 2391176, 2391177, 2391177, 2391178, 2391178, 2391179, 2391179, 2391180, 2391180, 2391181, 2391182, 2391182, 2391183, 2391183, 2391184, 2391185, 2391188, 2391188, 2391189, 2391189, 2391190, 2391190, 2391191, 2391192, 2391192, 2391193, 2391193, 2391194, 2391195, 2391195, 2391197, 2391198, 2391198, 2391199, 2391200, 2391201, 2391201, 2391202, 2391202, 2391203, 2391203, 2391204, 2391205, 2391205, 2391206, 2391206, 2391207, 2391207, 2391208, 2391208, 2391209, 2391210, 2391211, 2391211, 2391212, 2391212, 2391213, 2391217, 2391222, 2391222, 2391223, 2391226, 2391229, 2391230, 2391174, 2391175, 2391176, 2391177, 2391177, 2391178, 2391179, 2391181, 2391181, 2391182, 2391182, 2391185, 2391190, 2391191, 2391192, 2391193, 2391193, 2391195, 2391198, 2391198, 2391199, 2391201, 2391201, 2391203, 2391204, 2391204, 2391206, 2391208, 2391209, 2391212, 2391216, 2391218, 2391230, 2391230, 2391177, 2391179, 2391183, 2391188, 2391193, 2391198, 2391199, 2391209, 2391216, 2391230, 2391231, 2391179, 2391199, 2391201, 2391194, 2391197, 2391199, 2391206, 2391231, 2391180, 2391180, 2391195, 2391200, 2391184, 2391198, 2391200, 2391180, 2391195, 2391201, 2391202, 2391207, 2391207, 2391224, 2391233, 2391233, 2391181, 2391186, 2391195, 2391196, 2391197, 2391207, 2391184, 2391185, 2391187, 2391196, 2391202, 2391202, 2391203, 2391204, 2391205, 2391208, 2391208, 2391234, 2391184, 2391188, 2391197, 2391203, 2391208, 2391235, 2391234, 2391203, 2391204, 2391207, 2391205, 2391206, 2391210, 2391197, 2391202, 2391204, 2391205, 2391205, 2391206, 2391207, 2391215, 2391215, 2391191, 2391200, 2391206, 2391209, 2391197, 2391206, 2391206, 2391216, 2391238, 2391200, 2391201, 2391204, 2391206, 2391202, 2391207, 2391209, 2391202, 2391203, 2391205, 2391206, 2391195, 2391202, 2391208, 2391214, 2391240, 2391215, 2391203, 2391216, 2391218, 2391218, 2391223, 2391218, 2391224, 2391219, 2391213, 2391221, 2391223, 2391209, 2391211, 2391212, 2391222, 2391246, 2391246, 2391207, 2391210, 2391215, 2391216, 2391217, 2391223, 2391211, 2391216, 2391217, 2391218, 2391222, 2391222, 2391224, 2391248, 2391211, 2391214, 2391217, 2391217, 2391222, 2391223, 2391228, 2391231, 2391232, 2391248, 2391249, 2391214, 2391217, 2391217, 2391219, 2391223, 2391223, 2391226, 2391227, 2391233, 2391249, 2391217, 2391218, 2391220, 2391221, 2391224, 2391250, 2391250, 2391220, 2391225, 2391227, 2391238, 2391251, 2391219, 2391220, 2391225, 2391226, 2391228, 2391230, 2391231, 2391245, 2391220, 2391224, 2391226, 2391229, 2391226, 2391222, 2391223, 2391224, 2391225, 2391228, 2391228, 2391230, 2391230, 2391231, 2391231, 2391232, 2391232, 2391233, 2391233, 2391237, 2391237, 2391244, 2391254, 2391254, 2391223, 2391225, 2391225, 2391226, 2391228, 2391229, 2391230, 2391231, 2391232, 2391233, 2391234, 2391237, 2391254, 2391255, 2391225, 2391226, 2391227, 2391227, 2391228, 2391229, 2391229, 2391231, 2391231, 2391232, 2391233, 2391233, 2391234, 2391234, 2391236, 2391237, 2391255, 2391255, 2391226, 2391230, 2391226, 2391227, 2391228, 2391228, 2391230, 2391230, 2391231, 2391235, 2391236, 2391250, 2391256, 2391257, 2395647, 2391228, 2391231, 2391229, 2391230, 2391231, 2391231, 2391232, 2391233, 2391235, 2391237, 2391248, 2391231, 2391232, 2391232, 2391234, 2391240, 2391233, 2391259, 2391233, 2391259, 2391233, 2391234, 2391236, 2391237, 2391238, 2391239, 2391241, 2391234, 2391236, 2391236, 2391238, 2391238, 2391239, 2391239, 2391242, 2391243, 2391256, 2391260, 2391260, 2391236, 2391237, 2391237, 2391238, 2391238, 2391239, 2391239, 2391240, 2391240, 2391241, 2391242, 2391243, 2391243, 2391244, 2391244, 2391245, 2391246, 2391247, 2391248, 2391250, 2391251, 2391254, 2391256, 2391257, 2391259, 2391259, 2391260, 2391261, 2391262, 2391238, 2391239, 2391240, 2391240, 2391241, 2391243, 2391243, 2391245, 2391247, 2391251, 2391257, 2391260, 2391262, 2391262, 2391240, 2391240, 2391241, 2391241, 2391242, 2391243, 2391245, 2391246, 2391246, 2391253, 2391261, 2391262, 2391263, 2391242, 2391244, 2391246, 2391253, 2391263, 2391263, 2391242, 2391242, 2391243, 2391245, 2391247, 2391263, 2391264, 2391242, 2391243, 2391244, 2391244, 2391246, 2391247, 2391249, 2391251, 2391262, 2391263, 2391264, 2391264, 2391243, 2391244, 2391244, 2391245, 2391245, 2391246, 2391247, 2391247, 2391248, 2391254, 2391258, 2391260, 2391260, 2391264, 2391265, 2391244, 2391245, 2391245, 2391246, 2391247, 2391248, 2391248, 2391252, 2391259, 2391260, 2391261, 2391265, 2391265, 2391247, 2391247, 2391248, 2391248, 2391249, 2391251, 2391253, 2391254, 2391255, 2391261, 2391264, 2391265, 2391265, 2391266, 2391246, 2391249, 2391266, 2391266, 2391247, 2391248, 2391249, 2391249, 2391250, 2391266, 2391267, 2391250, 2391251, 2391252, 2391253, 2391256, 2391267, 2391249, 2391250, 2391250, 2391252, 2391267, 2391268, 2391251, 2391255, 2391262, 2391267, 2391268, 2391268, 2391252, 2391265, 2391268, 2391269, 2391252, 2391254, 2391262, 2391264, 2391266, 2391268, 2391269, 2391269, 2391254, 2391255, 2391259, 2391260, 2391262, 2391267, 2391268, 2391269, 2391270, 2391264, 2391270, 2391256, 2391271, 2391258, 2391271, 2391259, 2391261, 2391262, 2391268, 2391271, 2391272, 2391271, 2391267, 2391272, 2391273, 2391262, 2391270, 2391271, 2391272, 2391273, 2391274, 2391274, 2391264, 2391275, 2391275, 2391266, 2391267, 2391275, 2391275, 2391276, 2391276, 2391276, 2391267, 2391276, 2391277, 2391277, 2391277, 2391278, 2391279, 2391279, 2391274, 2391279, 2391280, 2391280, 2391280, 2391277, 2391280, 2391281, 2391281, 2391281, 2391282, 2391282, 2391282, 2391283, 2391282, 2391283, 2391283, 2391284, 2391284, 2391284, 2391285, 2391285, 2391285, 2391285, 2391286, 2391286, 2391287, 2391288, 2391288, 2391289, 2391295, 2391299, 2391300, 2391300, 2391301, 2391301, 2391302, 2391303, 2391303, 2391304, 2391304, 2391305, 2391305, 2395585, 2395585, 2395613, 2395615, 2395641, 2395677, 2399771, 2391288, 2391289, 2391291, 2391292, 2391293, 2391293, 2391294, 2391295, 2391295, 2391296, 2391298, 2391298, 2391299, 2391300, 2391300, 2391301, 2391301, 2391302, 2391302, 2391303, 2391304, 2391304, 2391305, 2391305, 2391306, 2391289, 2391290, 2391303, 2391304, 2391304, 2391305, 2391305, 2391306, 2391306, 2391295, 2391306, 2391307, 2391306, 2391306, 2391306, 2391307, 2391308, 2391309, 2391307, 2391310, 2391311, 2391311, 2391312, 2391308, 2391304, 2391313, 2391313, 2391313, 2391314, 2391315, 2391315, 2391316, 2391317, 2391314, 2391314, 2391316, 2391317, 2391318, 2391317, 2391318, 2391318, 2391317, 2391319, 2391319, 2391317, 2391319, 2391319, 2391318, 2391318, 2391319, 2391319, 2391320, 2391320, 2391319, 2391319, 2391320, 2391321, 2391320, 2391321, 2391321, 2391322, 2391321, 2391322, 2391322, 2391322, 2391323, 2391323, 2395603, 2399841, 2391324, 2395231, 2395603, 2395604, 2395607, 2395631, 2395631, 2395654, 2395658, 2395696, 2397558, 2397558, 2397595, 2397600, 2397609, 2397612, 2399790, 2399988, 2406949, 2408088, 2410436, 2395604, 2395604, 2395632, 2397596, 2397612, 2399204, 2399577, 2399883, 2399884, 2399885, 2399885, 2399886, 2399886, 2399887, 2399888, 2399889, 2399892, 2399893, 2399894, 2399895, 2399910, 2399910, 2399911, 2399911, 2399917, 2399959, 2399886, 2399890, 2399911, 2399912, 2399911, 2399912, 2399913, 2399889, 2399891, 2399913, 2399913, 2399892, 2399914, 2399895, 2399911, 2399913, 2399914, 2399914, 2399914, 2399915, 2399917, 2399919, 2399920, 2399902, 2399903, 2399903, 2399903, 2399904, 2399905, 2399921, 2399926, 2399986, 2401848, 2401885, 2401950, 2404079, 2399922, 2399986, 2399987, 2399988, 2401900, 2399936, 2399937, 2399937, 2399938, 2399938, 2399960, 2399939, 2399940, 2399940, 2399941, 2399941, 2399942, 2399943, 2399943, 2399944, 2399944, 2399946, 2399946, 2399947, 2399948, 2399950, 2399950, 2399952, 2399953, 2399953, 2399954, 2399954, 2399955, 2399955, 2399956, 2399957, 2399957, 2399958, 2399959, 2399960, 2399960, 2399961, 2399961, 2399962, 2399962, 2399963, 2399963, 2399964, 2399964, 2399965, 2399965, 2399966, 2399966, 2399967, 2399967, 2399968, 2399968, 2399969, 2399970, 2399976, 2399976, 2399981, 2399983, 2399984, 2399984, 2399985, 2399985, 2399986, 2399987, 2399987, 2399941, 2399952, 2399954, 2399962, 2399964, 2399968, 2399985, 2399986, 2399987, 2399987, 2399961, 2399962, 2399942, 2399963, 2399985, 2399987, 2399988, 2399948, 2399962, 2399963, 2399963, 2399965, 2399964, 2399990, 2399965, 2399968, 2399969, 2399991, 2399965, 2399992, 2399966, 2399969, 2399970, 2399971, 2399965, 2399995, 2399994, 2399983, 2399972, 2399980, 2399970, 2400000, 2400001, 2399976, 2399974, 2400002, 2399976, 2399977, 2400003, 2399978, 2400003, 2400000, 2400004, 2399988, 2399983, 2399985, 2399991, 2399981, 2399989, 2399982, 2399992, 2400007, 2399986, 2399987, 2399997, 2400006, 2399982, 2399983, 2399985, 2399986, 2399987, 2399992, 2399993, 2400008, 2399983, 2399986, 2399987, 2399988, 2399992, 2400009, 2399984, 2399985, 2399985, 2399986, 2399986, 2399987, 2399987, 2399988, 2399989, 2399989, 2399991, 2399992, 2399993, 2399999, 2400000, 2400003, 2400005, 2400006, 2400006, 2400007, 2400007, 2400009, 2400009, 2399986, 2399987, 2399989, 2400010, 2399987, 2399989, 2399991, 2399997, 2400010, 2400010, 2399988, 2399988, 2399989, 2399989, 2399991, 2400010, 2400011, 2399988, 2399990, 2399991, 2399994, 2400009, 2400011, 2399989, 2399990, 2399990, 2399992, 2399994, 2400007, 2400009, 2400010, 2400012, 2399990, 2399992, 2399993, 2399995, 2399998, 2400006, 2400008, 2400009, 2400011, 2400012, 2400012, 2399993, 2399994, 2399996, 2400008, 2400010, 2400013, 2400000, 2400011, 2400012, 2400013, 2400003, 2400010, 2400014, 2399994, 2399996, 2399998, 2400004, 2400014, 2399996, 2400011, 2400014, 2400015, 2400015, 2399999, 2400013, 2400014, 2400014, 2400016, 2400016, 2400014, 2400017, 2400010, 2400014, 2400017, 2400013, 2400015, 2400018, 2400003, 2400018, 2400014, 2400018, 2400019, 2400020, 2400020, 2400018, 2400019, 2400017, 2400021, 2400024, 2400024, 2400024, 2400026, 2400021, 2400027, 2400026, 2400027, 2400029, 2400027, 2400029, 2400030, 2400028, 2400029, 2400031, 2400031, 2400030, 2400031, 2400032, 2400059, 2400030, 2400031, 2400032, 2400032, 2400049, 2400031, 2400032, 2400033, 2400032, 2400033, 2400033, 2400034, 2400034, 2400035, 2400036, 2400036, 2400037, 2400048, 2400051, 2400057, 2400060, 2400060, 2400061, 2400061, 2400062, 2400062, 2401914, 2401951, 2402015, 2404145, 2404198, 2400036, 2400037, 2400038, 2400042, 2400053, 2400061, 2400061, 2400062, 2400062, 2400063, 2400037, 2400059, 2400063, 2400059, 2400061, 2400063, 2400064, 2400064, 2400065, 2400068, 2400074, 2400076, 2400068, 2400077, 2400078, 2400079, 2400079, 2400079, 2400080, 2400082, 2400085, 2400085, 2400087, 2400087, 2400088, 2400088, 2401939, 2400089, 2400089, 2400090, 2401708, 2401941, 2401941, 2401978, 2401999, 2404172, 2404173, 2404221, 2404221, 2404224, 2404371, 2408499, 2411332, 2401942, 2403401, 2403635, 2403792, 2403793, 2403794, 2403794, 2403795, 2403795, 2403796, 2403796, 2403797, 2403804, 2403815, 2403821, 2403822, 2403828, 2403828, 2403829, 2403829, 2403830, 2403832, 2403865, 2403868, 2403795, 2403829, 2403830, 2403830, 2403798, 2403830, 2403831, 2403798, 2403831, 2403831, 2403832, 2403832, 2403833, 2403833, 2403833, 2403833, 2403834, 2403816, 2403842, 2406085, 2406235, 2403851, 2403858, 2403859, 2403865, 2403865, 2403866, 2403866, 2403905, 2403867, 2403868, 2403868, 2403869, 2403869, 2403870, 2403870, 2403871, 2403871, 2403872, 2403873, 2403874, 2403875, 2403876, 2403877, 2403878, 2403879, 2403879, 2403880, 2403880, 2403881, 2403881, 2403882, 2403882, 2403883, 2403885, 2403885, 2403886, 2403887, 2403887, 2403888, 2403890, 2403891, 2403891, 2403892, 2403892, 2403893, 2403893, 2403898, 2403903, 2403904, 2403905, 2403905, 2403906, 2403868, 2403873, 2403877, 2403879, 2403880, 2403880, 2403881, 2403881, 2403884, 2403887, 2403888, 2403893, 2403905, 2403906, 2403871, 2403880, 2403881, 2403881, 2403882, 2403884, 2403888, 2403906, 2403874, 2403879, 2403880, 2403882, 2403883, 2403873, 2403874, 2403878, 2403881, 2403882, 2403882, 2403883, 2403883, 2403884, 2403885, 2403890, 2403904, 2403908, 2403875, 2403883, 2403884, 2403890, 2403882, 2403883, 2403884, 2403876, 2403878, 2403883, 2403885, 2403883, 2403884, 2403885, 2403887, 2403883, 2403884, 2403885, 2403892, 2403893, 2403910, 2403887, 2403911, 2403911, 2403881, 2403886, 2403886, 2403888, 2403889, 2403889, 2403890, 2403889, 2403891, 2403891, 2403891, 2403892, 2403892, 2403894, 2403895, 2403908, 2403912, 2403913, 2403917, 2403893, 2403894, 2403895, 2403898, 2403899, 2403904, 2403908, 2403917, 2403892, 2403893, 2403893, 2403896, 2403900, 2403904, 2403906, 2403907, 2403908, 2403909, 2403893, 2403894, 2403895, 2403898, 2403899, 2403900, 2403900, 2403901, 2403902, 2403905, 2403906, 2403906, 2403908, 2403909, 2403915, 2403916, 2403918, 2403918, 2403894, 2403895, 2403895, 2403896, 2403897, 2403901, 2403902, 2403906, 2403906, 2403910, 2403916, 2403918, 2403919, 2403896, 2403896, 2403897, 2403897, 2403898, 2403899, 2403899, 2403900, 2403900, 2403901, 2403901, 2403902, 2403903, 2403904, 2403905, 2403905, 2403906, 2403906, 2403907, 2403907, 2403908, 2403912, 2403914, 2403916, 2403916, 2403917, 2403917, 2403919, 2403919, 2403897, 2403911, 2403916, 2403898, 2403898, 2403907, 2403910, 2403917, 2403920, 2403899, 2403901, 2403902, 2403908, 2403908, 2403909, 2403921, 2403899, 2403908, 2403908, 2403909, 2403918, 2403901, 2403902, 2403902, 2403903, 2403904, 2403904, 2403905, 2403908, 2403909, 2403909, 2403910, 2403914, 2403917, 2403921, 2403922, 2403922, 2403904, 2403904, 2403905, 2403906, 2403921, 2403922, 2403923, 2403905, 2403906, 2403912, 2403924, 2406080, 2403906, 2403906, 2403907, 2403911, 2403914, 2403924, 2403906, 2403907, 2403907, 2403911, 2403912, 2403913, 2403925, 2403907, 2403908, 2403912, 2403912, 2403913, 2403921, 2403923, 2403923, 2403925, 2403925, 2403908, 2403912, 2403912, 2403913, 2403913, 2403918, 2403922, 2403923, 2403924, 2403926, 2403912, 2403913, 2403913, 2403914, 2403914, 2403917, 2403919, 2403921, 2403921, 2403923, 2403924, 2403924, 2403925, 2403926, 2403926, 2403914, 2403914, 2403927, 2403915, 2403928, 2403916, 2403916, 2403916, 2403929, 2403929, 2403916, 2403917, 2403917, 2403919, 2403925, 2403930, 2403917, 2403918, 2403920, 2403921, 2403927, 2403928, 2403928, 2403930, 2403918, 2403919, 2403920, 2403921, 2403922, 2403924, 2403926, 2403927, 2403928, 2403928, 2403930, 2403931, 2403919, 2403920, 2403921, 2403922, 2403928, 2403929, 2403929, 2403930, 2403931, 2403921, 2403930, 2403932, 2403923, 2403930, 2403930, 2403933, 2403928, 2403929, 2403930, 2403931, 2403933, 2403934, 2403934, 2403929, 2403931, 2403934, 2403935, 2403936, 2403937, 2403937, 2403938, 2403938, 2403938, 2403935, 2403939, 2403939, 2403937, 2403940, 2403938, 2403938, 2403939, 2403940, 2403976, 2403977, 2406096, 2403939, 2403940, 2403941, 2403941, 2403941, 2403967, 2403978, 2406097, 2403941, 2403942, 2406098, 2403942, 2403943, 2403943, 2403944, 2403945, 2403945, 2403946, 2403947, 2403948, 2403948, 2403949, 2403949, 2403950, 2403951, 2403951, 2403952, 2403952, 2403954, 2403956, 2403957, 2403965, 2403969, 2403970, 2403972, 2403972, 2403974, 2403976, 2403978, 2403978, 2403979, 2403979, 2403980, 2403980, 2403981, 2406100, 2406148, 2406148, 2406150, 2406162, 2406298, 2406318, 2406319, 2410426, 2410426, 2413308, 2403947, 2403948, 2403949, 2403949, 2403950, 2403953, 2403953, 2403970, 2403973, 2403975, 2403976, 2403978, 2403979, 2403979, 2403980, 2403980, 2403981, 2403981, 2403980, 2403981, 2403982, 2406101, 2403951, 2403983, 2403983, 2403984, 2403955, 2403983, 2403985, 2406104, 2403954, 2403982, 2403984, 2403985, 2406104, 2403955, 2403986, 2403955, 2403982, 2403985, 2403985, 2403986, 2403987, 2403986, 2403987, 2403988, 2403986, 2403986, 2403988, 2403987, 2403989, 2403988, 2403989, 2403990, 2403990, 2403993, 2403993, 2403998, 2404001, 2404006, 2403997, 2403997, 2404007, 2403998, 2404007, 2404008, 2404008, 2404007, 2404009, 2404010, 2404011, 2404011, 2404012, 2404011, 2404012, 2404013, 2404013, 2404012, 2404013, 2404014, 2404013, 2404014, 2404014, 2404015, 2404014, 2404015, 2404016, 2406135, 2404015, 2404016, 2404016, 2404017, 2406136, 2404017, 2406136, 2404018, 2406136, 2406136, 2406137, 2406170, 2406185, 2406185, 2406187, 2406188, 2406191, 2406335, 2410505, 2406137, 2406137, 2408254, 2408255, 2408256, 2408257, 2408257, 2408259, 2408261, 2408262, 2408263, 2408264, 2408265, 2408267, 2408271, 2408271, 2408275, 2408276, 2408276, 2408284, 2408285, 2408287, 2408288, 2408289, 2408291, 2408293, 2408294, 2408294, 2408296, 2408296, 2408297, 2408298, 2408301, 2408301, 2408302, 2408303, 2408303, 2408304, 2408304, 2408308, 2408331, 2408332, 2408257, 2408258, 2408259, 2408264, 2408273, 2408290, 2408296, 2408302, 2408303, 2408304, 2408304, 2408304, 2408304, 2408305, 2408265, 2408305, 2408305, 2408266, 2408266, 2408269, 2408269, 2408273, 2408276, 2408277, 2408285, 2408292, 2408299, 2408301, 2408304, 2408309, 2408309, 2408310, 2408311, 2408311, 2408312, 2408311, 2408313, 2408313, 2408316, 2408516, 2408314, 2408315, 2408315, 2408317, 2408317, 2408317, 2408319, 2408319, 2408303, 2408323, 2408324, 2408324, 2408324, 2408326, 2408332, 2408332, 2408333, 2408333, 2408334, 2408335, 2408336, 2408336, 2408337, 2408337, 2408339, 2408339, 2408331, 2408339, 2408341, 2408342, 2408341, 2408343, 2408344, 2408344, 2408344, 2408343, 2408348, 2408349, 2408348, 2408349, 2408349, 2408349, 2408350, 2408349, 2408350, 2408350, 2408351, 2408351, 2408352, 2408357, 2408379, 2408352, 2408353, 2408353, 2408354, 2408354, 2408355, 2408355, 2408356, 2408356, 2408357, 2408358, 2408359, 2408360, 2408361, 2408361, 2408362, 2408365, 2408366, 2408368, 2408369, 2408379, 2408379, 2408380, 2408384, 2408385, 2408353, 2408354, 2408354, 2408355, 2408355, 2408356, 2408357, 2408358, 2408358, 2408359, 2408360, 2408362, 2408362, 2408366, 2408367, 2408370, 2408376, 2408377, 2408379, 2408380, 2408380, 2408381, 2408385, 2408386, 2408354, 2408355, 2408355, 2408356, 2408356, 2408357, 2408360, 2408361, 2408362, 2408366, 2408375, 2408380, 2408355, 2408356, 2408356, 2408357, 2408358, 2408359, 2408359, 2408360, 2408361, 2408364, 2408367, 2408368, 2408369, 2408378, 2408381, 2408381, 2408356, 2408357, 2408357, 2408358, 2408358, 2408359, 2408359, 2408360, 2408361, 2408361, 2408362, 2408362, 2408363, 2408368, 2408368, 2408369, 2408371, 2408379, 2408381, 2408381, 2408382, 2408357, 2408358, 2408358, 2408359, 2408359, 2408360, 2408360, 2408362, 2408362, 2408363, 2408363, 2408364, 2408364, 2408368, 2408372, 2408380, 2408381, 2408382, 2408382, 2408358, 2408359, 2408359, 2408360, 2408360, 2408361, 2408362, 2408362, 2408363, 2408364, 2408364, 2408366, 2408368, 2408369, 2408370, 2408373, 2408376, 2408378, 2408380, 2408382, 2408382, 2408383, 2408359, 2408360, 2408360, 2408361, 2408361, 2408362, 2408363, 2408363, 2408364, 2408364, 2408365, 2408365, 2408369, 2408370, 2408372, 2408372, 2408377, 2408380, 2408381, 2408381, 2408382, 2408383, 2408383, 2408360, 2408361, 2408362, 2408365, 2408370, 2408362, 2408362, 2408363, 2408364, 2408364, 2408365, 2408366, 2408366, 2408370, 2408370, 2408371, 2408377, 2408378, 2408380, 2408381, 2408382, 2408383, 2408384, 2408384, 2408363, 2408365, 2408367, 2408384, 2408363, 2408365, 2408365, 2408366, 2408367, 2408367, 2408369, 2408369, 2408371, 2408374, 2408376, 2408378, 2408379, 2408380, 2408381, 2408383, 2408383, 2408384, 2408385, 2408385, 2408386, 2408364, 2408365, 2408365, 2408366, 2408367, 2408367, 2408368, 2408370, 2408371, 2408372, 2408373, 2408375, 2408376, 2408379, 2408380, 2408381, 2408383, 2408384, 2408385, 2408385, 2408386, 2408386, 2408366, 2408368, 2408367, 2408368, 2408373, 2408376, 2408376, 2408378, 2408380, 2408380, 2408382, 2408384, 2408386, 2408386, 2408367, 2408368, 2408368, 2408369, 2408369, 2408373, 2408376, 2408377, 2408380, 2408385, 2408386, 2408387, 2408368, 2408369, 2408369, 2408370, 2408371, 2408373, 2408374, 2408376, 2408377, 2408377, 2408385, 2408387, 2408387, 2408388, 2408371, 2408374, 2408381, 2408387, 2408387, 2408370, 2408371, 2408374, 2408375, 2408377, 2408378, 2408382, 2408383, 2408384, 2408386, 2408388, 2408388, 2408389, 2408371, 2408375, 2408383, 2408385, 2408385, 2408387, 2408388, 2408389, 2408373, 2408375, 2408376, 2408377, 2408378, 2408379, 2408379, 2408383, 2408384, 2408385, 2408385, 2408386, 2408387, 2408389, 2408389, 2408380, 2408388, 2408390, 2408390, 2408386, 2408388, 2408391, 2408378, 2408379, 2408392, 2408382, 2408389, 2408391, 2408392, 2408393, 2408395, 2408380, 2408381, 2408382, 2408382, 2408383, 2408383, 2408384, 2408384, 2408387, 2408389, 2408390, 2408391, 2408391, 2408392, 2408393, 2408393, 2408394, 2408399, 2408399, 2408381, 2408384, 2408384, 2408392, 2408394, 2408394, 2408399, 2408383, 2408384, 2408387, 2408394, 2408383, 2408384, 2408395, 2408385, 2408393, 2408395, 2408396, 2408385, 2408395, 2408396, 2408386, 2408387, 2408388, 2408389, 2408390, 2408392, 2408393, 2408394, 2408396, 2408396, 2408397, 2408388, 2408389, 2408390, 2408391, 2408395, 2408396, 2408397, 2408394, 2408397, 2408397, 2408396, 2408397, 2408392, 2408394, 2408398, 2408399, 2408399, 2408395, 2408398, 2408400, 2408400, 2408397, 2408399, 2408400, 2408401, 2408401, 2408397, 2408399, 2408400, 2408401, 2408402, 2408402, 2408400, 2408400, 2408401, 2408402, 2408403, 2408403, 2408403, 2408401, 2408403, 2408404, 2408404, 2408404, 2408403, 2408404, 2408404, 2408405, 2408405, 2408405, 2408405, 2408405, 2408406, 2408406, 2408407, 2408409, 2408529, 2408407, 2408408, 2408409, 2408411, 2408411, 2408412, 2408413, 2408417, 2408421, 2408450, 2408455, 2408530, 2408550, 2411252, 2408408, 2408409, 2408410, 2408410, 2408411, 2408412, 2408412, 2408413, 2408413, 2408414, 2408415, 2408415, 2408416, 2408417, 2408417, 2408418, 2408418, 2408421, 2408422, 2408423, 2408424, 2408425, 2408425, 2408426, 2408426, 2408427, 2408427, 2408445, 2408447, 2408451, 2408452, 2408453, 2408453, 2408454, 2408454, 2408455, 2408455, 2408456, 2408530, 2408553, 2408582, 2416672, 2408409, 2408410, 2408410, 2408411, 2408411, 2408412, 2408412, 2408413, 2408413, 2408414, 2408415, 2408416, 2408417, 2408417, 2408418, 2408418, 2408419, 2408420, 2408421, 2408422, 2408423, 2408423, 2408425, 2408427, 2408427, 2408428, 2408429, 2408432, 2408439, 2408439, 2408440, 2408446, 2408448, 2408449, 2408449, 2408451, 2408452, 2408453, 2408454, 2408454, 2408455, 2408455, 2408456, 2408456, 2408531, 2411288, 2408410, 2408411, 2408411, 2408412, 2408413, 2408413, 2408414, 2408414, 2408416, 2408416, 2408417, 2408418, 2408430, 2408440, 2408440, 2408454, 2408454, 2408455, 2408455, 2408456, 2408456, 2408457, 2408411, 2408413, 2408414, 2408415, 2408415, 2408419, 2408420, 2408424, 2408429, 2408441, 2408455, 2408456, 2408457, 2408458, 2408532, 2408414, 2408415, 2408416, 2408418, 2408420, 2408426, 2408457, 2408458, 2408416, 2408459, 2408416, 2408417, 2408421, 2408421, 2408424, 2408428, 2408458, 2408459, 2408416, 2408417, 2408417, 2408419, 2408420, 2408421, 2408422, 2408443, 2408457, 2408458, 2408459, 2408460, 2408534, 2408417, 2408418, 2408459, 2408460, 2408460, 2408418, 2408420, 2408461, 2408419, 2408420, 2408420, 2408421, 2408422, 2408423, 2408423, 2408427, 2408427, 2408432, 2408433, 2408442, 2408444, 2408454, 2408455, 2408456, 2408459, 2408459, 2408460, 2408461, 2408461, 2408536, 2408559, 2412705, 2408423, 2408426, 2408428, 2408460, 2408460, 2408461, 2408462, 2408422, 2408460, 2408462, 2408422, 2408424, 2408430, 2408446, 2408463, 2408423, 2408425, 2408425, 2408435, 2408438, 2408461, 2408462, 2408463, 2408425, 2408432, 2408464, 2408464, 2408427, 2408445, 2408460, 2408464, 2408465, 2408427, 2408429, 2408430, 2408432, 2408433, 2408435, 2408437, 2408437, 2408439, 2408448, 2408463, 2408463, 2408464, 2408465, 2408465, 2415550, 2408431, 2408432, 2408432, 2408435, 2408437, 2408437, 2408438, 2408460, 2408463, 2408464, 2408465, 2408465, 2408466, 2408435, 2408438, 2408465, 2408466, 2408442, 2408433, 2408467, 2408436, 2408466, 2408469, 2408458, 2408467, 2408469, 2408544, 2408468, 2408469, 2408441, 2408442, 2408468, 2408469, 2408470, 2408440, 2408442, 2408471, 2408441, 2408469, 2408445, 2408463, 2408471, 2408472, 2408471, 2408472, 2408443, 2408446, 2408468, 2408471, 2408473, 2408474, 2408548, 2408474, 2408474, 2408455, 2408458, 2408467, 2408473, 2408475, 2408468, 2408471, 2408473, 2408474, 2408474, 2408475, 2408474, 2408475, 2408476, 2408459, 2408473, 2408471, 2408476, 2408477, 2408476, 2408478, 2408477, 2408479, 2408484, 2408485, 2408486, 2408485, 2408485, 2408486, 2408487, 2408484, 2408486, 2408487, 2408487, 2408492, 2408493, 2408494, 2408488, 2408494, 2408496, 2408493, 2408494, 2408496, 2408495, 2408495, 2408496, 2408496, 2408496, 2408494, 2408497, 2408498, 2408495, 2408496, 2408498, 2408499, 2408497, 2408499, 2408498, 2408498, 2408499, 2408500, 2408498, 2408499, 2408499, 2408501, 2408499, 2408500, 2408501, 2408501, 2408500, 2408501, 2408501, 2408502, 2408501, 2408502, 2408502, 2408502, 2408503, 2408503, 2408504, 2408578, 2408578, 2408601, 2408602, 2408602, 2408603, 2408604, 2408628, 2408631, 2411251, 2412706, 2412706, 2412748, 2416678, 2408578, 2408579, 2408603, 2408652, 2408653, 2408654, 2408654, 2408655, 2408656, 2408656, 2408657, 2408658, 2408661, 2408662, 2408664, 2408665, 2408669, 2408671, 2408671, 2408672, 2408672, 2408673, 2408673, 2408674, 2408674, 2408675, 2408675, 2408676, 2408676, 2408677, 2408677, 2408678, 2408694, 2408658, 2408664, 2408671, 2408671, 2408672, 2408673, 2408673, 2408674, 2408676, 2408677, 2408671, 2408673, 2408664, 2408674, 2408660, 2408678, 2408675, 2408661, 2408676, 2408676, 2408676, 2408676, 2408677, 2408677, 2408678, 2408678, 2408680, 2408680, 2408681, 2408681, 2408672, 2408673, 2408683, 2408688, 2408692, 2408673, 2408674, 2408675, 2408683, 2408684, 2408684, 2408687, 2408687, 2408688, 2408717, 2411356, 2411359, 2411361, 2408684, 2412847, 2408683, 2408689, 2408690, 2408689, 2408689, 2408690, 2408690, 2408691, 2408690, 2408691, 2408691, 2408692, 2408692, 2408693, 2408695, 2408695, 2408693, 2408694, 2408695, 2408695, 2408696, 2408696, 2408697, 2408697, 2408699, 2408717, 2408720, 2408726, 2408694, 2408695, 2408695, 2408696, 2408696, 2408697, 2408697, 2408698, 2408714, 2408717, 2408718, 2408720, 2408723, 2408749, 2408695, 2408696, 2408696, 2408697, 2408697, 2408698, 2408698, 2408699, 2408699, 2408702, 2408703, 2408706, 2408708, 2408709, 2408712, 2408714, 2408719, 2408720, 2408722, 2408723, 2408725, 2408727, 2408749, 2408696, 2408697, 2408697, 2408698, 2408698, 2408699, 2408701, 2408704, 2408704, 2408707, 2408708, 2408712, 2408712, 2408714, 2408715, 2408717, 2408718, 2408724, 2408727, 2408730, 2408733, 2408739, 2408750, 2408697, 2408698, 2408698, 2408699, 2408704, 2408705, 2408706, 2408707, 2408712, 2408713, 2408717, 2408722, 2408724, 2408724, 2408729, 2408729, 2408731, 2408735, 2408750, 2408750, 2408698, 2408699, 2408699, 2408703, 2408720, 2408721, 2408727, 2408751, 2408699, 2408700, 2408700, 2408708, 2408719, 2408719, 2408720, 2408723, 2408751, 2408772, 2408700, 2408701, 2408702, 2408702, 2408703, 2408704, 2408706, 2408706, 2408710, 2408712, 2408714, 2408714, 2408715, 2408716, 2408716, 2408717, 2408717, 2408719, 2408720, 2408720, 2408721, 2408721, 2408722, 2408723, 2408724, 2408725, 2408725, 2408726, 2408728, 2408731, 2408735, 2408752, 2408773, 2408701, 2408702, 2408702, 2408703, 2408704, 2408705, 2408706, 2408707, 2408708, 2408708, 2408709, 2408710, 2408711, 2408712, 2408713, 2408714, 2408715, 2408715, 2408717, 2408717, 2408718, 2408718, 2408720, 2408720, 2408721, 2408721, 2408722, 2408722, 2408723, 2408723, 2408724, 2408724, 2408725, 2408725, 2408726, 2408728, 2408729, 2408730, 2408736, 2408748, 2408749, 2408750, 2408751, 2408752, 2408752, 2408702, 2408703, 2408703, 2408704, 2408705, 2408705, 2408706, 2408707, 2408707, 2408708, 2408709, 2408709, 2408710, 2408711, 2408712, 2408713, 2408715, 2408716, 2408717, 2408718, 2408718, 2408719, 2408719, 2408720, 2408720, 2408721, 2408721, 2408722, 2408723, 2408724, 2408724, 2408725, 2408725, 2408726, 2408726, 2408727, 2408727, 2408729, 2408729, 2408730, 2408730, 2408732, 2408735, 2408736, 2408746, 2408749, 2408750, 2408750, 2408752, 2408753, 2408774, 2408703, 2408704, 2408705, 2408705, 2408706, 2408707, 2408707, 2408708, 2408709, 2408710, 2408713, 2408713, 2408716, 2408718, 2408719, 2408720, 2408721, 2408722, 2408723, 2408724, 2408724, 2408725, 2408725, 2408727, 2408729, 2408730, 2408730, 2408731, 2408733, 2408734, 2408735, 2408735, 2408751, 2408753, 2408753, 2408704, 2408705, 2408706, 2408707, 2408708, 2408708, 2408710, 2408712, 2408715, 2408715, 2408717, 2408718, 2408719, 2408722, 2408723, 2408725, 2408726, 2408730, 2408734, 2408751, 2408751, 2408754, 2408705, 2408706, 2408707, 2408707, 2408709, 2408709, 2408710, 2408712, 2408717, 2408719, 2408720, 2408720, 2408721, 2408722, 2408723, 2408725, 2408727, 2408728, 2408730, 2408732, 2408733, 2408738, 2408754, 2408775, 2408706, 2408707, 2408709, 2408709, 2408719, 2408722, 2408724, 2408724, 2408726, 2408709, 2408755, 2408709, 2408710, 2408715, 2408722, 2408723, 2408730, 2408732, 2408716, 2408719, 2408721, 2408729, 2408730, 2408746, 2408756, 2408714, 2408716, 2408719, 2408723, 2408726, 2408733, 2408711, 2408713, 2408724, 2408713, 2408714, 2408714, 2408718, 2408720, 2408721, 2408723, 2408726, 2408726, 2408727, 2408732, 2408735, 2408718, 2408719, 2408722, 2408723, 2408724, 2408727, 2408729, 2408730, 2408731, 2408734, 2408758, 2408758, 2408721, 2408735, 2408719, 2408722, 2408725, 2408732, 2408733, 2408733, 2408735, 2408716, 2408718, 2408722, 2408724, 2408725, 2408726, 2408730, 2408723, 2408726, 2408729, 2408734, 2408736, 2408738, 2408739, 2408760, 2408723, 2408724, 2408720, 2408724, 2408733, 2408762, 2408722, 2408723, 2408725, 2408726, 2408728, 2408735, 2408736, 2408739, 2408762, 2408762, 2408726, 2408727, 2408727, 2408728, 2408729, 2408732, 2408740, 2408751, 2408763, 2408734, 2408738, 2408745, 2408764, 2408726, 2408733, 2408736, 2408764, 2408734, 2408743, 2408765, 2408728, 2408732, 2408734, 2408738, 2408743, 2408761, 2408766, 2408730, 2408732, 2408732, 2408733, 2408733, 2408734, 2408735, 2408736, 2408736, 2408737, 2408738, 2408740, 2408744, 2408752, 2408766, 2408732, 2408733, 2408735, 2408740, 2408732, 2408733, 2408733, 2408767, 2408733, 2408737, 2408738, 2408741, 2408744, 2408768, 2408734, 2408737, 2408738, 2408739, 2408741, 2408742, 2408744, 2408735, 2408735, 2408736, 2408738, 2408739, 2408740, 2408741, 2408742, 2408743, 2408745, 2408746, 2408748, 2408749, 2408750, 2408769, 2408735, 2408736, 2408737, 2408738, 2408738, 2408739, 2408740, 2408742, 2408742, 2408743, 2408743, 2408745, 2408746, 2408746, 2408747, 2408747, 2408751, 2408765, 2408769, 2408737, 2408738, 2408739, 2408740, 2408742, 2408743, 2408744, 2408746, 2408747, 2408750, 2408751, 2408753, 2408770, 2408737, 2408739, 2408739, 2408740, 2408741, 2408742, 2408744, 2408745, 2408770, 2408738, 2408740, 2408747, 2408748, 2408754, 2408771, 2408739, 2408740, 2408740, 2408741, 2408742, 2408742, 2408743, 2408744, 2408745, 2408748, 2408749, 2408754, 2408767, 2408771, 2408741, 2408742, 2408746, 2408748, 2408749, 2408751, 2408755, 2408772, 2408741, 2408742, 2408743, 2408744, 2408744, 2408745, 2408746, 2408746, 2408749, 2408749, 2408750, 2408751, 2408755, 2408772, 2408772, 2408743, 2408744, 2408744, 2408745, 2408746, 2408746, 2408747, 2408747, 2408749, 2408749, 2408750, 2408750, 2408751, 2408752, 2408754, 2408755, 2408773, 2408743, 2408744, 2408745, 2408746, 2408747, 2408747, 2408749, 2408751, 2408751, 2408773, 2408744, 2408746, 2408748, 2408751, 2408751, 2408755, 2408769, 2408774, 2408745, 2408747, 2408750, 2408751, 2408751, 2408752, 2408754, 2408754, 2408756, 2408757, 2408772, 2408774, 2408746, 2408747, 2408748, 2408748, 2408749, 2408751, 2408751, 2408752, 2408775, 2411392, 2408747, 2408748, 2408748, 2408749, 2408749, 2408751, 2408753, 2408754, 2408773, 2408775, 2411456, 2408749, 2408750, 2408752, 2408752, 2408753, 2408753, 2408776, 2408750, 2408750, 2408752, 2408753, 2408754, 2408757, 2408759, 2408750, 2408751, 2408753, 2408753, 2408754, 2408754, 2408755, 2408756, 2408771, 2408776, 2408777, 2408751, 2408753, 2408754, 2408754, 2408755, 2408756, 2408757, 2408759, 2408760, 2408771, 2408777, 2408753, 2408754, 2408754, 2408755, 2408755, 2408756, 2408757, 2408758, 2408760, 2408761, 2408763, 2408763, 2408765, 2408768, 2408769, 2408771, 2408771, 2408772, 2408773, 2408773, 2408775, 2408775, 2408776, 2408776, 2408778, 2408755, 2408756, 2408761, 2408778, 2408755, 2408764, 2408756, 2408757, 2408757, 2408759, 2408761, 2408762, 2408763, 2408763, 2408764, 2408766, 2408770, 2408771, 2408773, 2408775, 2408775, 2408777, 2408777, 2408778, 2408778, 2408779, 2408780, 2408758, 2408759, 2408760, 2408762, 2408763, 2408764, 2408766, 2408767, 2408773, 2408773, 2408777, 2408778, 2408780, 2408780, 2408758, 2408760, 2408761, 2408761, 2408763, 2408764, 2408764, 2408765, 2408767, 2408776, 2408778, 2408778, 2408780, 2408781, 2408759, 2408760, 2408760, 2408761, 2408762, 2408763, 2408763, 2408764, 2408764, 2408765, 2408765, 2408766, 2408767, 2408768, 2408768, 2408769, 2408770, 2408771, 2408772, 2408773, 2408773, 2408774, 2408774, 2408775, 2408777, 2408778, 2408779, 2408779, 2408780, 2408781, 2408781, 2408761, 2408775, 2408778, 2408779, 2408782, 2408762, 2408763, 2408764, 2408782, 2408762, 2408764, 2408764, 2408765, 2408765, 2408766, 2408766, 2408768, 2408769, 2408770, 2408772, 2408773, 2408774, 2408774, 2408775, 2408775, 2408778, 2408780, 2408782, 2408783, 2408764, 2408770, 2408782, 2408782, 2408783, 2408765, 2408765, 2408766, 2408767, 2408768, 2408770, 2408777, 2408778, 2408782, 2408784, 2408766, 2408784, 2408767, 2408771, 2408780, 2408780, 2408782, 2408785, 2408768, 2408768, 2408769, 2408772, 2408774, 2408777, 2408783, 2408785, 2408770, 2408774, 2408776, 2408783, 2408785, 2408786, 2408769, 2408772, 2408775, 2408777, 2408780, 2408781, 2408784, 2408786, 2408772, 2408773, 2408774, 2408775, 2408778, 2408778, 2408782, 2408784, 2408785, 2408785, 2408786, 2408787, 2408772, 2408774, 2408776, 2408778, 2408782, 2408787, 2408779, 2408784, 2408788, 2408776, 2408778, 2408785, 2408788, 2408786, 2408787, 2408789, 2408780, 2408789, 2408777, 2408779, 2408785, 2408785, 2408788, 2408789, 2408790, 2408781, 2408782, 2408785, 2408788, 2408790, 2408780, 2408782, 2408791, 2408784, 2408784, 2408788, 2408789, 2408791, 2408782, 2408789, 2408785, 2408791, 2408792, 2408784, 2408788, 2408789, 2408785, 2408786, 2408788, 2408793, 2408785, 2408793, 2408789, 2408791, 2408792, 2408794, 2408794, 2408786, 2408792, 2408794, 2408795, 2408791, 2408793, 2408794, 2408795, 2408795, 2411477, 2408788, 2408791, 2408793, 2408795, 2408791, 2408792, 2408796, 2408794, 2408795, 2408797, 2408797, 2408795, 2408798, 2408795, 2408796, 2408798, 2408796, 2408798, 2408799, 2408795, 2408796, 2408799, 2408799, 2411416, 2408796, 2408798, 2408800, 2408800, 2408800, 2408798, 2408799, 2408799, 2408801, 2408799, 2408801, 2408801, 2408800, 2408801, 2408802, 2408802, 2412855, 2416869, 2408803, 2408803, 2408804, 2408805, 2408805, 2408806, 2408806, 2408807, 2408808, 2408808, 2408809, 2408810, 2408810, 2408811, 2408811, 2408817, 2408817, 2408819, 2408819, 2408820, 2408821, 2408821, 2408822, 2408822, 2408823, 2408823, 2408824, 2408824, 2408825, 2411401, 2411417, 2411418, 2411421, 2411457, 2411486, 2412856, 2412898, 2415738, 2416828, 2408805, 2408806, 2408806, 2408807, 2408807, 2408809, 2408810, 2408811, 2408811, 2408812, 2408813, 2408817, 2408818, 2408819, 2408821, 2408822, 2408823, 2408823, 2408824, 2408824, 2408825, 2408825, 2408806, 2408810, 2408812, 2408823, 2408807, 2408808, 2408808, 2408809, 2408810, 2408810, 2408811, 2408812, 2408818, 2408819, 2408820, 2408821, 2408824, 2408824, 2408825, 2408825, 2408826, 2408826, 2408808, 2408811, 2408813, 2408821, 2408824, 2408825, 2408826, 2408826, 2408827, 2408810, 2408811, 2408819, 2408824, 2408825, 2408826, 2408826, 2408827, 2408827, 2408820, 2408822, 2408826, 2408826, 2408827, 2408827, 2408828, 2408821, 2408826, 2408827, 2408826, 2408813, 2408827, 2408828, 2408828, 2408829, 2408829, 2408815, 2408822, 2408826, 2408826, 2408827, 2408828, 2408829, 2408829, 2408830, 2408826, 2408830, 2408831, 2408829, 2408830, 2408831, 2408818, 2408824, 2408826, 2408829, 2408830, 2408830, 2408831, 2408831, 2408832, 2408832, 2408832, 2408832, 2408835, 2408837, 2408835, 2408837, 2408837, 2408832, 2408834, 2408836, 2408837, 2408838, 2408836, 2408837, 2408837, 2408839, 2408840, 2408836, 2408839, 2408841, 2408839, 2408840, 2408840, 2408841, 2408841, 2408842, 2408840, 2408841, 2408842, 2408843, 2408841, 2408842, 2408842, 2408843, 2408843, 2408842, 2408843, 2408843, 2408844, 2408843, 2408844, 2408844, 2408844, 2408845, 2411421, 2408845, 2412918, 2408846, 2408847, 2411421, 2411422, 2411439, 2411442, 2411475, 2412877, 2412877, 2412919, 2415710, 2416849, 2416891, 2411422, 2411423, 2413997, 2413998, 2413999, 2413999, 2414000, 2414000, 2414001, 2414003, 2414011, 2414013, 2414014, 2414015, 2414016, 2414017, 2414018, 2414018, 2414073, 2414076, 2413999, 2414000, 2414001, 2414014, 2414015, 2414015, 2414018, 2414018, 2414015, 2414016, 2414016, 2414012, 2414016, 2414017, 2414019, 2414020, 2414017, 2414017, 2414016, 2414023, 2414030, 2414028, 2414030, 2414030, 2414031, 2414057, 2414032, 2414033, 2414034, 2414034, 2414035, 2414037, 2414038, 2414039, 2414040, 2414043, 2414045, 2414047, 2414048, 2414050, 2414055, 2414056, 2414057, 2414058, 2414060, 2414062, 2414064, 2414065, 2414066, 2414068, 2414068, 2414070, 2414071, 2414072, 2414073, 2414076, 2414091, 2414093, 2414093, 2414033, 2414035, 2414042, 2414068, 2414094, 2414036, 2414094, 2414036, 2414036, 2414037, 2414037, 2414056, 2414038, 2414039, 2414040, 2414041, 2414041, 2414042, 2414043, 2414046, 2414047, 2414048, 2414050, 2414051, 2414052, 2414053, 2414053, 2414054, 2414054, 2414055, 2414055, 2414056, 2414056, 2414057, 2414057, 2414058, 2414058, 2414059, 2414060, 2414061, 2414061, 2414062, 2414063, 2414063, 2414064, 2414065, 2414066, 2414067, 2414067, 2414068, 2414069, 2414069, 2414070, 2414070, 2414071, 2414072, 2414073, 2414074, 2414074, 2414075, 2414075, 2414076, 2414076, 2414079, 2414085, 2414086, 2414087, 2414093, 2414093, 2414061, 2414093, 2414094, 2414067, 2414045, 2414061, 2414045, 2414059, 2414065, 2414068, 2414076, 2414095, 2414096, 2414099, 2414099, 2414062, 2414064, 2414064, 2414069, 2414097, 2414062, 2414065, 2414066, 2414068, 2414072, 2414076, 2414101, 2414066, 2414070, 2414071, 2414073, 2414074, 2414076, 2414079, 2414098, 2414067, 2414072, 2414085, 2414075, 2414060, 2414075, 2414081, 2414064, 2414071, 2414109, 2414084, 2414071, 2414107, 2414108, 2414075, 2414082, 2414109, 2414109, 2414085, 2414086, 2414110, 2414110, 2414079, 2414092, 2414076, 2414077, 2414078, 2414082, 2414083, 2414111, 2414077, 2414093, 2414112, 2414115, 2414084, 2414081, 2414094, 2414113, 2414080, 2414084, 2414085, 2414088, 2414092, 2414093, 2414113, 2414081, 2414082, 2414095, 2414095, 2414114, 2414117, 2414096, 2414097, 2414114, 2414084, 2414086, 2414088, 2414089, 2414093, 2414094, 2414096, 2414097, 2414116, 2414119, 2415496, 2414085, 2414086, 2414087, 2414088, 2414089, 2414090, 2414097, 2414097, 2414106, 2414116, 2414119, 2414094, 2414094, 2414098, 2414117, 2414088, 2414094, 2414094, 2414096, 2414098, 2414100, 2414117, 2415497, 2414099, 2414091, 2414092, 2414093, 2414095, 2414100, 2414102, 2414119, 2414122, 2415499, 2414091, 2414093, 2414094, 2414095, 2414096, 2414097, 2414102, 2414104, 2414112, 2414119, 2414093, 2414094, 2414094, 2414095, 2414095, 2414096, 2414097, 2414097, 2414098, 2414099, 2414102, 2414121, 2414124, 2414101, 2414121, 2414099, 2414102, 2414103, 2414107, 2414108, 2414122, 2414098, 2414101, 2414099, 2414104, 2414113, 2414123, 2414126, 2414098, 2414100, 2414100, 2414101, 2414104, 2414123, 2414101, 2414102, 2414124, 2414127, 2414102, 2414103, 2414104, 2414105, 2414106, 2414112, 2414115, 2414116, 2414117, 2414125, 2414103, 2414103, 2414104, 2414106, 2414125, 2414104, 2414107, 2414109, 2414115, 2414126, 2414104, 2414105, 2414105, 2414106, 2414107, 2414109, 2414110, 2414112, 2414118, 2414119, 2414124, 2414126, 2414129, 2414106, 2414108, 2414127, 2414106, 2414108, 2414123, 2414127, 2414127, 2414108, 2414109, 2414110, 2414128, 2414131, 2414109, 2414110, 2414114, 2414128, 2414131, 2414129, 2414110, 2414120, 2414122, 2414126, 2414129, 2414112, 2414113, 2414115, 2414116, 2414116, 2414117, 2414121, 2414122, 2414129, 2414130, 2414132, 2414132, 2414133, 2414113, 2414130, 2414133, 2414131, 2414131, 2414131, 2414132, 2414134, 2414135, 2414132, 2414133, 2414133, 2414134, 2414135, 2414137, 2414137, 2414133, 2414135, 2414135, 2414130, 2414136, 2414138, 2414139, 2414133, 2414140, 2414150, 2414141, 2414141, 2414144, 2414142, 2414142, 2414143, 2414145, 2414145, 2414147, 2414151, 2414148, 2414149, 2414150, 2414151, 2414152, 2414157, 2414158, 2414162, 2414163, 2414164, 2414165, 2414167, 2414168, 2414169, 2415528, 2415529, 2415570, 2418362, 2418414, 2414152, 2414152, 2414168, 2414169, 2414169, 2414153, 2414154, 2414154, 2414155, 2414156, 2414161, 2414166, 2414167, 2414167, 2414168, 2414170, 2414170, 2414171, 2414171, 2414172, 2415531, 2415532, 2415572, 2419504, 2419546, 2414163, 2414165, 2414169, 2414171, 2414172, 2414172, 2414173, 2414166, 2414167, 2414177, 2414178, 2414168, 2414169, 2414178, 2414179, 2414179, 2414182, 2414183, 2414183, 2414184, 2414184, 2414184, 2414185, 2414186, 2414186, 2414187, 2414187, 2414188, 2414188, 2414189, 2415548, 2415549, 2415572, 2415587, 2415589, 2415590, 2415590, 2415604, 2415606, 2415608, 2418382, 2418433, 2419521, 2415549, 2415549, 2415591, 2416908, 2416919, 2416909, 2416910, 2416911, 2416911, 2416912, 2416918, 2416919, 2416932, 2416946, 2416947, 2416947, 2416948, 2416949, 2416949, 2416950, 2416950, 2416984, 2416911, 2416912, 2416920, 2416927, 2416929, 2416948, 2416949, 2416950, 2416950, 2416951, 2416912, 2416949, 2416952, 2416952, 2416950, 2416952, 2416953, 2416953, 2416954, 2416929, 2416929, 2416930, 2416961, 2416962, 2416966, 2416973, 2419801, 2419805, 2420933, 2420933, 2416931, 2416961, 2416969, 2419802, 2419806, 2416962, 2416968, 2416970, 2416973, 2416973, 2416988, 2416988, 2416988, 2416988, 2416989, 2416999, 2416989, 2416990, 2416990, 2416991, 2417016, 2416991, 2417026, 2416992, 2416993, 2416993, 2416994, 2416994, 2416995, 2416996, 2416996, 2416997, 2416997, 2416998, 2416999, 2416999, 2417000, 2417001, 2417001, 2417002, 2417002, 2417003, 2417003, 2417004, 2417005, 2417007, 2417008, 2417009, 2417009, 2417010, 2417011, 2417012, 2417012, 2417013, 2417015, 2417017, 2417018, 2417018, 2417019, 2417019, 2417020, 2417023, 2417025, 2417026, 2416993, 2416994, 2416994, 2417000, 2417000, 2417002, 2417002, 2417004, 2417004, 2417018, 2417026, 2417000, 2417001, 2417002, 2417002, 2417003, 2417011, 2416996, 2417001, 2417001, 2417003, 2417009, 2417014, 2417002, 2417004, 2417004, 2417002, 2417002, 2417007, 2417003, 2417007, 2417002, 2417002, 2417007, 2417013, 2417005, 2417008, 2417006, 2417008, 2417008, 2417006, 2417007, 2417008, 2417009, 2417010, 2417011, 2417024, 2417033, 2417007, 2417008, 2417009, 2417009, 2417010, 2417011, 2417012, 2417013, 2417015, 2417017, 2417018, 2417019, 2417021, 2417025, 2417033, 2417009, 2417009, 2417010, 2417010, 2417011, 2417011, 2417012, 2417013, 2417015, 2417015, 2417016, 2417017, 2417020, 2417021, 2417022, 2417022, 2417023, 2417024, 2417025, 2417026, 2417027, 2417027, 2417028, 2417028, 2417031, 2417033, 2417034, 2417010, 2417011, 2417012, 2417014, 2417017, 2417019, 2417021, 2417021, 2417022, 2417026, 2417027, 2417028, 2417029, 2417032, 2417011, 2417012, 2417013, 2417013, 2417014, 2417015, 2417017, 2417018, 2417019, 2417021, 2417022, 2417023, 2417024, 2417027, 2417028, 2417028, 2417029, 2417029, 2417033, 2417035, 2417012, 2417013, 2417013, 2417014, 2417015, 2417016, 2417017, 2417017, 2417018, 2417019, 2417019, 2417021, 2417022, 2417022, 2417023, 2417024, 2417024, 2417025, 2417027, 2417027, 2417028, 2417028, 2417029, 2417029, 2417030, 2417031, 2417032, 2417034, 2417036, 2417013, 2417014, 2417014, 2417015, 2417018, 2417020, 2417023, 2417024, 2417028, 2417030, 2417034, 2417036, 2417036, 2417016, 2417021, 2417023, 2417026, 2417029, 2417030, 2417030, 2417034, 2417036, 2417037, 2417037, 2417015, 2417016, 2417016, 2417017, 2417019, 2417020, 2417021, 2417023, 2417025, 2417025, 2417028, 2417030, 2417033, 2417035, 2417037, 2417017, 2417018, 2417019, 2417020, 2417020, 2417021, 2417021, 2417023, 2417024, 2417024, 2417025, 2417025, 2417026, 2417029, 2417030, 2417031, 2417031, 2417032, 2417034, 2417036, 2417037, 2417038, 2417030, 2417020, 2417021, 2417021, 2417022, 2417022, 2417023, 2417024, 2417025, 2417025, 2417026, 2417027, 2417027, 2417028, 2417030, 2417031, 2417031, 2417032, 2417032, 2417033, 2417038, 2417039, 2417033, 2417021, 2417022, 2417023, 2417026, 2417040, 2417022, 2417034, 2417037, 2417041, 2417024, 2417025, 2417026, 2417028, 2417030, 2417033, 2417034, 2417038, 2417041, 2417041, 2417026, 2417028, 2417030, 2417030, 2417033, 2417034, 2417035, 2417037, 2417042, 2417028, 2417029, 2417034, 2417029, 2417029, 2417031, 2417031, 2417034, 2417036, 2417043, 2417029, 2417030, 2417030, 2417032, 2417035, 2417035, 2417037, 2417038, 2417043, 2417043, 2417033, 2417036, 2417038, 2417044, 2417030, 2417037, 2417038, 2417044, 2420983, 2417032, 2417033, 2417033, 2417038, 2417042, 2417045, 2419852, 2417033, 2417033, 2417034, 2417034, 2417035, 2417039, 2417039, 2417043, 2417046, 2417034, 2417034, 2417037, 2417038, 2417039, 2417039, 2417040, 2417044, 2417046, 2417034, 2417035, 2417036, 2417035, 2417036, 2417036, 2417039, 2417039, 2417040, 2417041, 2417045, 2417047, 2417047, 2419805, 2417037, 2417039, 2417040, 2417040, 2417041, 2417041, 2417042, 2417046, 2417048, 2417040, 2417041, 2417042, 2417043, 2417045, 2417048, 2417038, 2417040, 2417042, 2417043, 2417043, 2417044, 2417049, 2417041, 2417043, 2417049, 2417045, 2417049, 2417042, 2417044, 2417043, 2417044, 2417044, 2417045, 2417045, 2417046, 2417046, 2417047, 2417048, 2417049, 2417049, 2417051, 2417051, 2419809, 2417044, 2417045, 2417045, 2417046, 2417047, 2417049, 2417051, 2417052, 2417045, 2417046, 2417046, 2417051, 2417052, 2417052, 2417046, 2417047, 2417047, 2417048, 2417052, 2417052, 2417053, 2417047, 2417048, 2417048, 2417049, 2417049, 2417050, 2417051, 2417051, 2417052, 2417053, 2417053, 2417048, 2417049, 2417051, 2417052, 2417053, 2417054, 2417049, 2417050, 2417053, 2417054, 2417050, 2417055, 2417055, 2417053, 2417055, 2417054, 2417055, 2417056, 2417056, 2419863, 2417057, 2417057, 2417057, 2417056, 2417057, 2417058, 2417058, 2417058, 2417058, 2417059, 2417059, 2417060, 2417061, 2417063, 2417063, 2417064, 2417064, 2417065, 2417066, 2417066, 2417067, 2417067, 2417068, 2417068, 2417069, 2417069, 2417070, 2417071, 2417072, 2417072, 2417073, 2417073, 2417076, 2417077, 2417083, 2417085, 2417088, 2417090, 2417091, 2417091, 2417094, 2417095, 2417097, 2417099, 2417099, 2417100, 2417100, 2417101, 2417101, 2419817, 2419863, 2419866, 2419867, 2419868, 2419869, 2419875, 2420956, 2420998, 2417061, 2417062, 2417064, 2417064, 2417065, 2417066, 2417066, 2417067, 2417068, 2417068, 2417069, 2417069, 2417070, 2417071, 2417072, 2417072, 2417073, 2417074, 2417079, 2417080, 2417084, 2417090, 2417091, 2417092, 2417097, 2417099, 2417100, 2417101, 2417101, 2417102, 2417070, 2417075, 2417101, 2417102, 2417103, 2417069, 2417105, 2417069, 2417072, 2417093, 2417104, 2417105, 2417077, 2419822, 2421017, 2417074, 2417077, 2417078, 2417092, 2417106, 2417107, 2419872, 2417073, 2417074, 2417079, 2417106, 2417107, 2419872, 2417076, 2417078, 2417106, 2417108, 2417075, 2417080, 2417108, 2419873, 2417076, 2417080, 2417109, 2419825, 2417077, 2417077, 2417079, 2417099, 2417103, 2417105, 2417108, 2417109, 2417109, 2419825, 2417078, 2417081, 2417092, 2417095, 2417099, 2417110, 2420965, 2421007, 2417080, 2417081, 2417082, 2417100, 2417109, 2417110, 2419875, 2417080, 2417082, 2417083, 2417092, 2417099, 2417100, 2417110, 2417111, 2417081, 2417110, 2417111, 2417112, 2417083, 2417111, 2417113, 2417103, 2417112, 2417113, 2419878, 2417085, 2417107, 2417097, 2417104, 2417111, 2417113, 2417113, 2417114, 2417114, 2419830, 2417090, 2417114, 2417115, 2417115, 2417117, 2417116, 2417118, 2417120, 2417110, 2417124, 2417124, 2417125, 2417121, 2417124, 2417116, 2417127, 2417117, 2417128, 2417119, 2417131, 2417121, 2417127, 2417130, 2417131, 2417129, 2417130, 2417131, 2417132, 2417132, 2419848, 2417128, 2417133, 2417136, 2417136, 2417137, 2417137, 2417138, 2417138, 2417139, 2417139, 2417140, 2417140, 2417140, 2417141, 2417140, 2417141, 2417141, 2417142, 2417142, 2417143, 2417144, 2419858, 2419859, 2419908, 2420998, 2419859, 2419860, 2422574, 2422575, 2422576, 2422576, 2422577, 2422579, 2422581, 2422590, 2422599, 2422599, 2422604, 2422604, 2422607, 2422608, 2422620, 2422621, 2422622, 2422622, 2422623, 2422623, 2422624, 2422650, 2422579, 2422623, 2422624, 2422624, 2422625, 2422625, 2422580, 2422581, 2422621, 2422626, 2422626, 2422626, 2422627, 2422627, 2422628, 2422630, 2422639, 2422647, 2422648, 2422653, 2422653, 2422655, 2422657, 2422667, 2422668, 2422669, 2422669, 2422670, 2422671, 2422671, 2422671, 2422671, 2422672, 2422672, 2422673, 2422674, 2422674, 2422675, 2422675, 2422676, 2422676, 2422677, 2422677, 2422678, 2422678, 2422679, 2422680, 2422680, 2422681, 2422681, 2422682, 2422682, 2422683, 2422684, 2422685, 2422688, 2422690, 2422691, 2422692, 2422693, 2422694, 2422697, 2422699, 2422699, 2422674, 2422675, 2422675, 2422676, 2422677, 2422677, 2422678, 2422679, 2422682, 2422684, 2422691, 2422694, 2422696, 2422697, 2422699, 2422700, 2422676, 2422679, 2422681, 2422676, 2422677, 2422678, 2422678, 2422680, 2422683, 2422696, 2422697, 2422697, 2422700, 2422701, 2422677, 2422678, 2422678, 2422679, 2422680, 2422680, 2422681, 2422682, 2422683, 2422683, 2422684, 2422696, 2422698, 2422701, 2422678, 2422679, 2422679, 2422681, 2422682, 2422683, 2422683, 2422684, 2422685, 2422685, 2422689, 2422692, 2422693, 2422693, 2422694, 2422696, 2422696, 2422698, 2422698, 2422699, 2422699, 2422701, 2422702, 2422680, 2422686, 2422698, 2422680, 2422682, 2422682, 2422683, 2422683, 2422684, 2422699, 2422699, 2422703, 2422681, 2422682, 2422683, 2422684, 2422685, 2422685, 2422686, 2422686, 2422687, 2422688, 2422688, 2422689, 2422692, 2422693, 2422694, 2422696, 2422697, 2422698, 2422699, 2422700, 2422700, 2422701, 2422703, 2422703, 2422685, 2422686, 2422686, 2422691, 2422704, 2422704, 2422685, 2422686, 2422687, 2422687, 2422688, 2422688, 2422694, 2422695, 2422696, 2422696, 2422697, 2422697, 2422698, 2422699, 2422699, 2422701, 2422701, 2422702, 2422702, 2422704, 2422705, 2422705, 2422687, 2422688, 2422690, 2422698, 2422698, 2422699, 2422700, 2422700, 2422702, 2422703, 2422705, 2422706, 2422689, 2422699, 2422703, 2422706, 2422690, 2422692, 2422696, 2422699, 2422700, 2422701, 2422701, 2422703, 2422704, 2422706, 2422707, 2422689, 2422691, 2422699, 2422700, 2422704, 2422705, 2422707, 2422707, 2422690, 2422691, 2422700, 2422700, 2422702, 2422704, 2422704, 2422707, 2422708, 2422691, 2422693, 2422701, 2422701, 2422702, 2422705, 2422706, 2422706, 2422708, 2422708, 2422699, 2422700, 2422700, 2422703, 2422709, 2422703, 2422704, 2422709, 2422709, 2422710, 2422704, 2422705, 2422707, 2422710, 2422705, 2422710, 2422711, 2422711, 2422703, 2422713, 2422714, 2422715, 2422707, 2422708, 2422715, 2422716, 2422707, 2422716, 2422708, 2422717, 2422712, 2422714, 2422717, 2422717, 2423781, 2422712, 2422718, 2422711, 2422718, 2422716, 2422718, 2422719, 2423782, 2422714, 2422716, 2422717, 2422717, 2422719, 2422720, 2422715, 2422716, 2422717, 2422720, 2422720, 2422721, 2422721, 2422718, 2422722, 2422719, 2422720, 2422722, 2422722, 2422720, 2422723, 2422723, 2422723, 2422724, 2422725, 2422726, 2422727, 2422727, 2422728, 2422728, 2422729, 2422730, 2422731, 2422732, 2422732, 2422735, 2422735, 2422736, 2422737, 2422741, 2422743, 2422743, 2422744, 2422744, 2422745, 2422745, 2422746, 2422747, 2422753, 2422753, 2422759, 2422760, 2422765, 2422768, 2422768, 2422772, 2422773, 2422773, 2422774, 2422774, 2422775, 2423789, 2423831, 2424236, 2422728, 2422728, 2422729, 2422729, 2422730, 2422731, 2422732, 2422732, 2422734, 2422735, 2422735, 2422736, 2422736, 2422737, 2422737, 2422740, 2422741, 2422745, 2422745, 2422746, 2422752, 2422754, 2422767, 2422773, 2422773, 2422774, 2422774, 2422775, 2422776, 2422729, 2422730, 2422733, 2422733, 2422751, 2422769, 2422773, 2422774, 2422774, 2422775, 2422776, 2422776, 2423833, 2422738, 2422770, 2422775, 2422777, 2423833, 2422733, 2422739, 2422745, 2422750, 2422775, 2422777, 2422776, 2422778, 2423834, 2422778, 2422779, 2422750, 2422777, 2422779, 2422778, 2422780, 2422780, 2422738, 2422742, 2422744, 2422752, 2422752, 2422777, 2422780, 2422781, 2423795, 2422748, 2422781, 2422783, 2422783, 2422772, 2422778, 2422784, 2422783, 2422752, 2422753, 2422755, 2422778, 2422784, 2422785, 2422755, 2422786, 2422770, 2422789, 2422788, 2422760, 2422790, 2422768, 2422763, 2422792, 2422792, 2422793, 2422785, 2422789, 2422791, 2422793, 2422764, 2422794, 2422792, 2422794, 2422792, 2422794, 2422795, 2422793, 2422795, 2422790, 2422794, 2422796, 2422796, 2422793, 2422801, 2422802, 2422802, 2422807, 2422808, 2422809, 2422812, 2422814, 2422811, 2422815, 2422816, 2422817, 2422816, 2422817, 2422818, 2422818, 2422820, 2422818, 2422820, 2422819, 2422820, 2422821, 2422821, 2422820, 2422821, 2422821, 2422822, 2422821, 2422822, 2422822, 2422823, 2422823, 2422824, 2423838, 2423838, 2423880, 2423881, 2423889, 2424239, 2424294, 2426186, 2423839, 2424852, 2424853, 2424854, 2424854, 2424855, 2424855, 2424856, 2424856, 2424857, 2424859, 2424863, 2424863, 2424874, 2424875, 2424877, 2424883, 2424885, 2424887, 2424889, 2424892, 2424893, 2424893, 2424894, 2424894, 2424895, 2424854, 2424855, 2424855, 2424856, 2424856, 2424858, 2424874, 2424883, 2424883, 2424886, 2424889, 2424891, 2424892, 2424892, 2424894, 2424894, 2424895, 2424895, 2424855, 2424856, 2424857, 2424858, 2424884, 2424895, 2424895, 2424856, 2424857, 2424857, 2424865, 2424877, 2424892, 2424893, 2424895, 2424895, 2424896, 2424896, 2424857, 2424895, 2424896, 2424858, 2424859, 2424866, 2424870, 2424876, 2424876, 2424877, 2424877, 2424878, 2424880, 2424881, 2424882, 2424885, 2424885, 2424886, 2424888, 2424889, 2424893, 2424894, 2424895, 2424896, 2424896, 2424897, 2424897, 2424860, 2424860, 2424877, 2424882, 2424896, 2424897, 2424897, 2424898, 2424871, 2424887, 2424897, 2424897, 2424898, 2424896, 2424897, 2424898, 2424898, 2424899, 2424900, 2424904, 2424898, 2424905, 2424909, 2424914, 2424915, 2424915, 2424915, 2424915, 2424916, 2424899, 2424916, 2424917, 2424900, 2424916, 2424918, 2424919, 2424908, 2424919, 2424920, 2424920, 2424921, 2424924, 2424923, 2424924, 2424925, 2424927, 2424926, 2424927, 2424928, 2424929, 2424930, 2424931, 2424931, 2424932, 2424933, 2424933, 2424934, 2424933, 2424934, 2424934, 2424934, 2424935, 2424935, 2424936, 2424937, 2424938, 2424938, 2424939, 2424939, 2424940, 2424941, 2424941, 2424943, 2424943, 2424944, 2424944, 2424945, 2424945, 2424946, 2424947, 2424948, 2424948, 2424949, 2424950, 2424951, 2424951, 2424952, 2424955, 2424958, 2424959, 2424959, 2424961, 2424969, 2424970, 2424970, 2424938, 2424939, 2424939, 2424940, 2424940, 2424941, 2424942, 2424942, 2424943, 2424943, 2424944, 2424944, 2424945, 2424945, 2424946, 2424947, 2424947, 2424948, 2424951, 2424953, 2424966, 2424970, 2424971, 2424939, 2424940, 2424940, 2424941, 2424942, 2424942, 2424943, 2424944, 2424944, 2424945, 2424946, 2424946, 2424947, 2424969, 2424940, 2424941, 2424941, 2424942, 2424944, 2424945, 2424945, 2424946, 2424947, 2424941, 2424942, 2424942, 2424943, 2424943, 2424944, 2424944, 2424945, 2424945, 2424946, 2424947, 2424947, 2424948, 2424949, 2424950, 2424951, 2424951, 2424952, 2424953, 2424958, 2424942, 2424943, 2424943, 2424944, 2424944, 2424945, 2424945, 2424946, 2424946, 2424947, 2424947, 2424948, 2424949, 2424949, 2424951, 2424962, 2424943, 2424944, 2424944, 2424945, 2424945, 2424946, 2424946, 2424947, 2424948, 2424948, 2424949, 2424951, 2424952, 2424955, 2424944, 2424946, 2424947, 2424948, 2424946, 2424946, 2424947, 2424947, 2424948, 2424948, 2424949, 2424949, 2424951, 2424974, 2424946, 2424947, 2424948, 2424948, 2424953, 2424947, 2424948, 2424948, 2424949, 2424949, 2424950, 2424950, 2424954, 2424948, 2424949, 2424949, 2424950, 2424951, 2424952, 2424949, 2424950, 2424950, 2424951, 2424951, 2424952, 2424953, 2424954, 2424955, 2424950, 2424951, 2424951, 2424952, 2424953, 2424956, 2424956, 2424957, 2424951, 2424952, 2424952, 2424953, 2424954, 2424954, 2424955, 2424956, 2424957, 2424959, 2424960, 2424961, 2424969, 2424952, 2424953, 2424954, 2424956, 2424953, 2424954, 2424954, 2424955, 2424956, 2424957, 2424958, 2424959, 2424960, 2424978, 2424954, 2424955, 2424955, 2424956, 2424956, 2424957, 2424957, 2424958, 2424958, 2424959, 2424959, 2424960, 2424960, 2424961, 2424963, 2424964, 2424965, 2424968, 2424970, 2424971, 2424972, 2424973, 2424979, 2424955, 2424956, 2424957, 2424958, 2424959, 2424956, 2424957, 2424957, 2424958, 2424958, 2424959, 2424959, 2424960, 2424961, 2424962, 2424962, 2424963, 2424965, 2424966, 2424968, 2424972, 2424977, 2424957, 2424958, 2424958, 2424959, 2424959, 2424960, 2424960, 2424961, 2424961, 2424962, 2424963, 2424964, 2424965, 2424965, 2424968, 2424970, 2424972, 2424972, 2424974, 2424980, 2424958, 2424959, 2424959, 2424960, 2424961, 2424961, 2424963, 2424972, 2424959, 2424960, 2424960, 2424961, 2424962, 2424962, 2424964, 2424968, 2424968, 2424960, 2424961, 2424961, 2424962, 2424962, 2424963, 2424963, 2424964, 2424964, 2424966, 2424966, 2424967, 2424968, 2424969, 2424971, 2424971, 2424973, 2424975, 2424982, 2424961, 2424962, 2424962, 2424963, 2424963, 2424964, 2424964, 2424965, 2424966, 2424966, 2424967, 2424968, 2424968, 2424969, 2424969, 2424970, 2424971, 2424972, 2424973, 2424976, 2424962, 2424963, 2424963, 2424964, 2424964, 2424965, 2424966, 2424966, 2424967, 2424967, 2424968, 2424968, 2424969, 2424971, 2424972, 2424972, 2424974, 2424975, 2424963, 2424964, 2424964, 2424965, 2424965, 2424966, 2424967, 2424968, 2424968, 2424969, 2424969, 2424970, 2424970, 2424971, 2424972, 2424973, 2424973, 2424975, 2424983, 2424964, 2424965, 2424965, 2424966, 2424967, 2424968, 2424968, 2424970, 2424971, 2424972, 2424975, 2424983, 2424965, 2424966, 2424966, 2424967, 2424967, 2424968, 2424968, 2424969, 2424970, 2424971, 2424972, 2424973, 2424975, 2424975, 2424976, 2424978, 2424984, 2424966, 2424967, 2424967, 2424968, 2424968, 2424969, 2424969, 2424970, 2424970, 2424971, 2424972, 2424972, 2424973, 2424974, 2424975, 2424985, 2424967, 2424968, 2424968, 2424969, 2424969, 2424970, 2424970, 2424971, 2424971, 2424972, 2424972, 2424973, 2424974, 2424975, 2424976, 2424977, 2424977, 2424979, 2424981, 2424983, 2424984, 2424985, 2424968, 2424969, 2424969, 2424970, 2424971, 2424972, 2424973, 2424975, 2424975, 2424986, 2424969, 2424970, 2424970, 2424971, 2424971, 2424972, 2424972, 2424973, 2424973, 2424974, 2424974, 2424975, 2424975, 2424976, 2424976, 2424977, 2424978, 2424978, 2424979, 2424979, 2424980, 2424984, 2424984, 2424985, 2424986, 2424986, 2424970, 2424971, 2424972, 2424973, 2424973, 2424975, 2424976, 2424978, 2424979, 2424971, 2424972, 2424972, 2424973, 2424973, 2424974, 2424974, 2424975, 2424976, 2424977, 2424977, 2424979, 2424980, 2424981, 2424987, 2424972, 2424973, 2424973, 2424974, 2424974, 2424975, 2424976, 2424976, 2424977, 2424977, 2424978, 2424979, 2424979, 2424980, 2424980, 2424983, 2424984, 2424985, 2424985, 2424988, 2424973, 2424974, 2424974, 2424975, 2424975, 2424976, 2424977, 2424978, 2424978, 2424979, 2424980, 2424980, 2424982, 2424985, 2424988, 2424974, 2424975, 2424975, 2424976, 2424976, 2424977, 2424978, 2424978, 2424981, 2424982, 2424986, 2424988, 2424989, 2424975, 2424976, 2424976, 2424977, 2424978, 2424978, 2424979, 2424981, 2424982, 2424983, 2424984, 2424986, 2424987, 2424988, 2424988, 2424989, 2424989, 2424976, 2424977, 2424977, 2424978, 2424979, 2424979, 2424977, 2424978, 2424978, 2424979, 2424979, 2424980, 2424980, 2424981, 2424982, 2424983, 2424983, 2424984, 2424988, 2424988, 2424989, 2424989, 2424990, 2424990, 2424978, 2424979, 2424979, 2424980, 2424980, 2424981, 2424981, 2424982, 2424982, 2424983, 2424984, 2424987, 2424988, 2424989, 2424990, 2424991, 2424979, 2424980, 2424981, 2424982, 2424985, 2424980, 2424981, 2424981, 2424982, 2424983, 2424983, 2424984, 2424984, 2424985, 2424988, 2424990, 2424991, 2424992, 2424981, 2424982, 2424982, 2424983, 2424984, 2424988, 2424992, 2424982, 2424983, 2424983, 2424984, 2424984, 2424985, 2424985, 2424986, 2424986, 2424987, 2424988, 2424989, 2424990, 2424990, 2424991, 2424991, 2424992, 2424993, 2425318, 2424983, 2424984, 2424984, 2424985, 2424985, 2424986, 2424986, 2424987, 2424987, 2424988, 2424989, 2424991, 2424992, 2424993, 2424993, 2424984, 2424985, 2424985, 2424986, 2424986, 2424987, 2424987, 2424992, 2424993, 2424994, 2424985, 2424986, 2424986, 2424988, 2424988, 2424989, 2424994, 2424994, 2424986, 2424987, 2424987, 2424988, 2424988, 2424989, 2424990, 2424990, 2424991, 2424992, 2424994, 2424994, 2424995, 2427349, 2424987, 2424988, 2424988, 2424989, 2424989, 2424990, 2424991, 2424993, 2424994, 2424994, 2424995, 2424988, 2424989, 2424989, 2424990, 2424991, 2424992, 2424992, 2424993, 2424994, 2424995, 2424995, 2424996, 2424989, 2424990, 2424990, 2424992, 2424992, 2424994, 2424995, 2424996, 2424996, 2424990, 2424991, 2424992, 2424992, 2424993, 2424993, 2424994, 2424994, 2424995, 2424995, 2424996, 2424997, 2424991, 2424992, 2424992, 2424993, 2424993, 2424994, 2424994, 2424995, 2424995, 2424996, 2424996, 2424997, 2424997, 2424992, 2424993, 2424993, 2424994, 2424994, 2424995, 2424995, 2424996, 2424996, 2424997, 2424997, 2424998, 2424993, 2424998, 2424994, 2424995, 2424996, 2424996, 2424997, 2424997, 2424998, 2424998, 2424999, 2424995, 2424996, 2424997, 2424997, 2424998, 2424998, 2424999, 2424999, 2424996, 2424997, 2424997, 2424998, 2424998, 2424999, 2424999, 2425000, 2424997, 2424998, 2424998, 2424999, 2425000, 2425000, 2424998, 2424999, 2425000, 2425000, 2425001, 2424999, 2425000, 2425000, 2425001, 2425001, 2425326, 2425000, 2425001, 2425001, 2425002, 2425001, 2425002, 2425002, 2425002, 2425003, 2425003, 2425004, 2425005, 2425005, 2425006, 2425006, 2425007, 2425008, 2425008, 2425009, 2425010, 2425010, 2425011, 2425011, 2425012, 2425012, 2425013, 2425013, 2425014, 2425014, 2425015, 2425015, 2425016, 2425017, 2425017, 2425020, 2425021, 2425021, 2425022, 2425028, 2425029, 2425033, 2425035, 2425037, 2425038, 2425038, 2425041, 2425042, 2425043, 2425043, 2425044, 2425044, 2425045, 2425045, 2425046, 2425329, 2425375, 2425439, 2430230, 2425005, 2425006, 2425006, 2425007, 2425007, 2425008, 2425009, 2425009, 2425010, 2425010, 2425011, 2425011, 2425012, 2425012, 2425013, 2425014, 2425014, 2425015, 2425015, 2425016, 2425016, 2425017, 2425017, 2425018, 2425020, 2425020, 2425021, 2425022, 2425025, 2425028, 2425030, 2425030, 2425032, 2425034, 2425034, 2425035, 2425036, 2425038, 2425039, 2425040, 2425041, 2425042, 2425042, 2425043, 2425044, 2425044, 2425045, 2425045, 2425046, 2425046, 2425006, 2425007, 2425007, 2425008, 2425009, 2425009, 2425010, 2425011, 2425013, 2425014, 2425015, 2425016, 2425017, 2425017, 2425018, 2425028, 2425031, 2425043, 2425044, 2425044, 2425045, 2425046, 2425047, 2425007, 2425008, 2425008, 2425009, 2425010, 2425011, 2425011, 2425012, 2425013, 2425013, 2425014, 2425014, 2425015, 2425016, 2425016, 2425017, 2425019, 2425024, 2425027, 2425031, 2425034, 2425035, 2425038, 2425038, 2425043, 2425045, 2425045, 2425046, 2425046, 2425047, 2425047, 2425008, 2425009, 2425010, 2425013, 2425015, 2425016, 2425020, 2425021, 2425042, 2425046, 2425048, 2425009, 2425010, 2425011, 2425011, 2425012, 2425012, 2425013, 2425014, 2425014, 2425015, 2425015, 2425016, 2425016, 2425017, 2425018, 2425018, 2425019, 2425019, 2425030, 2425030, 2425031, 2425032, 2425044, 2425045, 2425046, 2425046, 2425047, 2425047, 2425048, 2425048, 2425011, 2425011, 2425012, 2425014, 2425017, 2425018, 2425020, 2425038, 2425046, 2425049, 2425012, 2425013, 2425013, 2425014, 2425015, 2425016, 2425016, 2425017, 2425018, 2425019, 2425020, 2425021, 2425026, 2425029, 2425032, 2425039, 2425048, 2425050, 2425333, 2425014, 2425014, 2425015, 2425016, 2425017, 2425018, 2425018, 2425020, 2425048, 2425050, 2425050, 2425014, 2425033, 2425051, 2425015, 2425016, 2425016, 2425017, 2425017, 2425018, 2425018, 2425019, 2425020, 2425021, 2425022, 2425023, 2425028, 2425037, 2425039, 2425048, 2425051, 2425051, 2425016, 2425017, 2425017, 2425018, 2425018, 2425019, 2425019, 2425020, 2425021, 2425022, 2425022, 2425023, 2425036, 2425040, 2425047, 2425052, 2425018, 2425019, 2425019, 2425023, 2425044, 2425018, 2425019, 2425019, 2425020, 2425024, 2425041, 2425050, 2425053, 2425019, 2425020, 2425020, 2425021, 2425023, 2425025, 2425051, 2425053, 2425020, 2425021, 2425021, 2425022, 2425022, 2425023, 2425023, 2425024, 2425025, 2425025, 2425026, 2425027, 2425035, 2425039, 2425051, 2425051, 2425052, 2425053, 2425054, 2425021, 2425022, 2425023, 2425023, 2425024, 2425024, 2425025, 2425025, 2425026, 2425031, 2425036, 2425036, 2425050, 2425051, 2425052, 2425053, 2425054, 2425022, 2425023, 2425023, 2425024, 2425024, 2425026, 2425028, 2425053, 2425055, 2425023, 2425024, 2425024, 2425025, 2425025, 2425026, 2425026, 2425029, 2425031, 2425031, 2425032, 2425033, 2425037, 2425046, 2425051, 2425052, 2425055, 2427285, 2425024, 2425025, 2425025, 2425026, 2425046, 2425050, 2425051, 2425053, 2425339, 2425025, 2425026, 2425026, 2425027, 2425028, 2425028, 2425029, 2425033, 2425041, 2425043, 2425050, 2425053, 2425055, 2425056, 2425056, 2425026, 2425027, 2425027, 2425028, 2425028, 2425034, 2425037, 2425040, 2425041, 2425050, 2425055, 2425056, 2425027, 2425028, 2425028, 2425029, 2425039, 2425039, 2425040, 2425054, 2425055, 2425057, 2425057, 2425028, 2425029, 2425029, 2425030, 2425032, 2425033, 2425039, 2425040, 2425042, 2425045, 2425048, 2425053, 2425055, 2425055, 2425057, 2425058, 2425029, 2425035, 2425057, 2425058, 2425058, 2425030, 2425031, 2425031, 2425032, 2425032, 2425033, 2425034, 2425034, 2425036, 2425036, 2425037, 2425037, 2425039, 2425040, 2425040, 2425041, 2425042, 2425043, 2425046, 2425047, 2425047, 2425049, 2425050, 2425051, 2425052, 2425053, 2425053, 2425054, 2425056, 2425056, 2425057, 2425057, 2425058, 2425058, 2425059, 2425031, 2425032, 2425033, 2425035, 2425036, 2425037, 2425039, 2425041, 2425042, 2425043, 2425043, 2425047, 2425047, 2425048, 2425050, 2425051, 2425051, 2425052, 2425053, 2425054, 2425055, 2425055, 2425056, 2425057, 2425057, 2425058, 2425059, 2425059, 2425388, 2425037, 2425041, 2425045, 2425050, 2425054, 2425059, 2425060, 2425042, 2425051, 2425057, 2425059, 2425043, 2425058, 2425038, 2425054, 2425055, 2425061, 2425038, 2425039, 2425058, 2425060, 2425061, 2425062, 2425059, 2425063, 2425045, 2425061, 2425062, 2425063, 2425063, 2425045, 2425052, 2425058, 2425046, 2425054, 2425056, 2425063, 2425064, 2425043, 2425046, 2425047, 2425061, 2425062, 2425063, 2425064, 2425064, 2425060, 2425062, 2425065, 2425046, 2425047, 2425061, 2425062, 2425063, 2425060, 2425065, 2425066, 2425055, 2425064, 2425066, 2425051, 2425051, 2425060, 2425051, 2425055, 2425064, 2425066, 2425066, 2425068, 2425069, 2425069, 2425054, 2425055, 2425056, 2425060, 2425061, 2425063, 2425065, 2425067, 2425067, 2425068, 2425069, 2425070, 2425066, 2425067, 2425070, 2425055, 2425055, 2425056, 2425062, 2425064, 2425065, 2425067, 2425068, 2425070, 2425070, 2425071, 2425071, 2425063, 2425068, 2425069, 2425070, 2425071, 2425072, 2425063, 2425070, 2425071, 2425072, 2425073, 2425062, 2425065, 2425068, 2425072, 2425073, 2425073, 2425074, 2425072, 2425073, 2425074, 2425075, 2425069, 2425071, 2425072, 2425073, 2425074, 2425075, 2425067, 2425074, 2425075, 2425076, 2425076, 2425067, 2425072, 2425072, 2425077, 2425070, 2425078, 2425075, 2425076, 2425077, 2425077, 2425078, 2425071, 2425073, 2425076, 2425077, 2425078, 2425079, 2425071, 2425072, 2425079, 2425079, 2425074, 2425077, 2425078, 2425080, 2425073, 2425076, 2425078, 2425080, 2425080, 2425074, 2425077, 2425077, 2425078, 2425079, 2425080, 2425081, 2425078, 2425081, 2425077, 2425078, 2425078, 2425079, 2425080, 2425080, 2425081, 2425081, 2425082, 2425079, 2425080, 2425081, 2425082, 2425079, 2425081, 2425082, 2425082, 2425083, 2425079, 2425080, 2425081, 2425081, 2425082, 2425083, 2425081, 2425081, 2425082, 2425083, 2425083, 2425084, 2425081, 2425082, 2425083, 2425084, 2425084, 2425082, 2425083, 2425083, 2425084, 2425084, 2425085, 2425083, 2425084, 2425084, 2425085, 2425085, 2425084, 2425085, 2425085, 2425086, 2425085, 2425086, 2425086, 2425086, 2425087, 2425087, 2425088, 2425089, 2425132, 2425370, 2425371, 2425417, 2425424, 2427318, 2427332, 2427372, 2425089, 2425095, 2425133, 2425371, 2425371, 2425372, 2425378, 2425415, 2425653, 2425654, 2425655, 2425655, 2425656, 2425656, 2425657, 2425658, 2425659, 2425661, 2425664, 2425664, 2425665, 2425666, 2425667, 2425669, 2425675, 2425676, 2425676, 2425678, 2425685, 2425686, 2425687, 2425689, 2425694, 2425695, 2425696, 2425697, 2425698, 2425698, 2425699, 2425699, 2425700, 2425655, 2425656, 2425656, 2425657, 2425657, 2425658, 2425660, 2425662, 2425664, 2425675, 2425688, 2425690, 2425693, 2425697, 2425698, 2425699, 2425699, 2425700, 2425700, 2425666, 2425690, 2425700, 2425700, 2425659, 2425701, 2425663, 2425701, 2425702, 2425664, 2425701, 2425702, 2425702, 2425702, 2425663, 2425702, 2425703, 2425663, 2425665, 2425703, 2425704, 2425704, 2425704, 2425705, 2425705, 2425705, 2425679, 2425706, 2425707, 2425707, 2425674, 2425675, 2425687, 2425709, 2425675, 2425676, 2425676, 2425710, 2425711, 2425711, 2425712, 2425712, 2425712, 2425713, 2425690, 2425716, 2425720, 2425721, 2425721, 2425722, 2425722, 2425723, 2425724, 2425729, 2425732, 2425732, 2425733, 2425734, 2425735, 2425738, 2425739, 2425740, 2425741, 2425741, 2425742, 2425743, 2425742, 2425743, 2425743, 2425743, 2425744, 2425744, 2425744, 2425745, 2425745, 2425746, 2425747, 2425747, 2425748, 2425748, 2425749, 2425749, 2425750, 2425750, 2425751, 2425751, 2425752, 2425752, 2425753, 2425753, 2425754, 2425755, 2425758, 2425759, 2425760, 2425762, 2425775, 2425775, 2425776, 2425747, 2425748, 2425748, 2425749, 2425749, 2425750, 2425751, 2425753, 2425748, 2425749, 2425749, 2425750, 2425750, 2425752, 2425753, 2425756, 2425749, 2425750, 2425750, 2425751, 2425752, 2425756, 2425750, 2425751, 2425751, 2425754, 2425751, 2425752, 2425752, 2425753, 2425757, 2425752, 2425753, 2425753, 2425754, 2425754, 2425755, 2425776, 2425778, 2425753, 2425754, 2425754, 2425755, 2425755, 2425756, 2425756, 2425757, 2425758, 2425759, 2425759, 2425761, 2425767, 2425768, 2425770, 2425773, 2425775, 2425776, 2425777, 2425779, 2425754, 2425755, 2425755, 2425759, 2425755, 2425756, 2425756, 2425757, 2425757, 2425758, 2425758, 2425759, 2425759, 2425760, 2425760, 2425761, 2425762, 2425762, 2425763, 2425763, 2425764, 2425771, 2425771, 2425772, 2425774, 2425775, 2425776, 2425776, 2425777, 2425778, 2425778, 2425756, 2425757, 2425757, 2425758, 2425758, 2425759, 2425760, 2425773, 2425778, 2425757, 2425758, 2425758, 2425759, 2425759, 2425760, 2425760, 2425761, 2425761, 2425762, 2425763, 2425764, 2425770, 2425772, 2425772, 2425773, 2425775, 2425776, 2425777, 2425777, 2425778, 2425779, 2425779, 2425780, 2425780, 2425781, 2425758, 2425759, 2425759, 2425760, 2425761, 2425762, 2425762, 2425763, 2425764, 2425764, 2425771, 2425773, 2425775, 2425777, 2425759, 2425760, 2425760, 2425761, 2425761, 2425762, 2425762, 2425763, 2425764, 2425764, 2425765, 2425765, 2425766, 2425769, 2425770, 2425771, 2425773, 2425773, 2425774, 2425775, 2425777, 2425781, 2425760, 2425761, 2425761, 2425762, 2425762, 2425763, 2425763, 2425764, 2425764, 2425765, 2425766, 2425767, 2425768, 2425769, 2425771, 2425772, 2425773, 2425774, 2425775, 2425776, 2425776, 2425777, 2425778, 2425779, 2425779, 2425782, 2425782, 2425761, 2425762, 2425762, 2425763, 2425763, 2425764, 2425764, 2425765, 2425765, 2425766, 2425766, 2425767, 2425767, 2425768, 2425768, 2425769, 2425769, 2425770, 2425771, 2425771, 2425772, 2425774, 2425774, 2425775, 2425775, 2425776, 2425777, 2425778, 2425778, 2425779, 2425779, 2425781, 2425782, 2425783, 2425762, 2425763, 2425763, 2425764, 2425764, 2425766, 2425774, 2425775, 2425778, 2425763, 2425764, 2425764, 2425765, 2425765, 2425766, 2425766, 2425767, 2425767, 2425768, 2425769, 2425769, 2425773, 2425775, 2425775, 2425776, 2425776, 2425777, 2425778, 2425780, 2425781, 2425784, 2425764, 2425765, 2425765, 2425766, 2425766, 2425767, 2425767, 2425768, 2425768, 2425769, 2425771, 2425771, 2425772, 2425774, 2425775, 2425776, 2425777, 2425778, 2425779, 2425780, 2425765, 2425766, 2425766, 2425767, 2425767, 2425768, 2425768, 2425769, 2425770, 2425771, 2425772, 2425774, 2425774, 2425776, 2425776, 2425777, 2425778, 2425781, 2425782, 2425784, 2425785, 2425766, 2425767, 2425767, 2425768, 2425768, 2425769, 2425770, 2425770, 2425771, 2425772, 2425774, 2425776, 2425778, 2425780, 2425781, 2425785, 2425768, 2425768, 2425769, 2425769, 2425770, 2425771, 2425771, 2425772, 2425774, 2425775, 2425775, 2425777, 2425777, 2425779, 2425780, 2425782, 2425768, 2425769, 2425772, 2425776, 2425779, 2425782, 2425786, 2425769, 2425770, 2425770, 2425771, 2425771, 2425772, 2425773, 2425773, 2425774, 2425775, 2425776, 2425776, 2425778, 2425778, 2425779, 2425779, 2425782, 2425783, 2425783, 2425784, 2425785, 2425786, 2425770, 2425771, 2425771, 2425772, 2425772, 2425773, 2425773, 2425774, 2425775, 2425776, 2425777, 2425777, 2425778, 2425778, 2425779, 2425779, 2425780, 2425780, 2425781, 2425782, 2425782, 2425783, 2425784, 2425784, 2425785, 2425785, 2425787, 2425771, 2425772, 2425773, 2425773, 2425774, 2425774, 2425775, 2425776, 2425776, 2425777, 2425777, 2425778, 2425779, 2425779, 2425780, 2425781, 2425782, 2425783, 2425785, 2425787, 2425788, 2425772, 2425773, 2425774, 2425774, 2425775, 2425775, 2425776, 2425777, 2425777, 2425778, 2425779, 2425780, 2425781, 2425782, 2425783, 2425785, 2425786, 2425787, 2425788, 2425773, 2425774, 2425778, 2425778, 2425780, 2425783, 2425786, 2425788, 2425774, 2425775, 2425775, 2425777, 2425777, 2425779, 2425780, 2425781, 2425781, 2425782, 2425783, 2425784, 2425786, 2425787, 2425775, 2425776, 2425778, 2425779, 2425781, 2425786, 2425789, 2425776, 2425778, 2425778, 2425779, 2425779, 2425780, 2425781, 2425781, 2425782, 2425782, 2425786, 2425778, 2425779, 2425779, 2425780, 2425782, 2425782, 2425783, 2425785, 2425786, 2425787, 2425789, 2425779, 2425780, 2425781, 2425782, 2425783, 2425783, 2425784, 2425791, 2425781, 2425783, 2425783, 2425784, 2425789, 2425780, 2425782, 2425783, 2425785, 2425788, 2425788, 2425781, 2425782, 2425782, 2425784, 2425784, 2425785, 2425786, 2425787, 2425789, 2425782, 2425783, 2425784, 2425785, 2425785, 2425786, 2425792, 2425792, 2425793, 2425793, 2425783, 2425784, 2425785, 2425785, 2425786, 2425787, 2425788, 2425789, 2425784, 2425785, 2425785, 2425786, 2425786, 2425787, 2425787, 2425788, 2425789, 2425789, 2425790, 2425791, 2425791, 2425792, 2425792, 2425794, 2425794, 2425785, 2425786, 2425788, 2425789, 2425786, 2425787, 2425787, 2425788, 2425788, 2425791, 2425787, 2425788, 2425788, 2425789, 2425790, 2425790, 2425791, 2425791, 2425792, 2425792, 2425793, 2425794, 2425794, 2425795, 2425795, 2425796, 2425788, 2425789, 2425789, 2425790, 2425791, 2425792, 2425792, 2425793, 2425793, 2425794, 2425796, 2425796, 2425789, 2425790, 2425791, 2425791, 2425792, 2425793, 2425793, 2425794, 2425794, 2425795, 2425796, 2425796, 2425790, 2425791, 2425791, 2425792, 2425792, 2425793, 2425793, 2425794, 2425794, 2425795, 2425796, 2425792, 2425792, 2425793, 2425793, 2425794, 2425794, 2425795, 2425796, 2425796, 2425797, 2425798, 2425792, 2425793, 2425795, 2425793, 2425794, 2425794, 2425795, 2425795, 2425796, 2425797, 2425797, 2425798, 2425798, 2425799, 2425794, 2425795, 2425796, 2425799, 2425795, 2425796, 2425796, 2425797, 2425797, 2425798, 2425799, 2425799, 2425800, 2425796, 2425797, 2425798, 2425799, 2425800, 2425797, 2425798, 2425798, 2425799, 2425799, 2425800, 2425800, 2425801, 2425798, 2425799, 2425799, 2425800, 2425800, 2425801, 2425801, 2425799, 2425800, 2425800, 2425801, 2425801, 2425802, 2425800, 2425801, 2425801, 2425802, 2425802, 2425801, 2425802, 2425802, 2425803, 2425802, 2425803, 2425803, 2425803, 2425804, 2425804, 2425850, 2425805, 2425806, 2425807, 2425807, 2425808, 2425809, 2425813, 2425814, 2425814, 2425815, 2425816, 2425817, 2425819, 2425819, 2425820, 2425821, 2425821, 2425826, 2425829, 2425831, 2425834, 2425836, 2425837, 2425839, 2425839, 2425842, 2425848, 2425848, 2425849, 2425850, 2425850, 2425851, 2427676, 2427691, 2427758, 25895065, 2425806, 2425807, 2425807, 2425808, 2425808, 2425809, 2425809, 2425810, 2425810, 2425811, 2425812, 2425812, 2425813, 2425813, 2425814, 2425814, 2425815, 2425815, 2425817, 2425818, 2425818, 2425819, 2425820, 2425820, 2425821, 2425822, 2425823, 2425823, 2425824, 2425825, 2425826, 2425826, 2425827, 2425827, 2425829, 2425829, 2425833, 2425834, 2425835, 2425837, 2425839, 2425839, 2425840, 2425840, 2425841, 2425841, 2425842, 2425843, 2425844, 2425845, 2425846, 2425847, 2425847, 2425848, 2425848, 2425849, 2425850, 2425850, 2425851, 2425851, 2427759, 2425807, 2425808, 2425809, 2425810, 2425811, 2425814, 2425815, 2425816, 2425820, 2425823, 2425826, 2425835, 2425843, 2425848, 2425852, 2425809, 2425809, 2425815, 2425818, 2425829, 2425836, 2425838, 2425851, 2425852, 2425812, 2425815, 2425840, 2425852, 2425853, 2425811, 2425811, 2425812, 2425813, 2425816, 2425817, 2425820, 2425827, 2425853, 2425811, 2425812, 2425825, 2425812, 2425813, 2425814, 2425815, 2425817, 2425817, 2425820, 2425825, 2425826, 2425854, 2425814, 2425814, 2425816, 2425817, 2425818, 2425819, 2425821, 2425826, 2425827, 2425843, 2425846, 2425848, 2425851, 2425852, 2425854, 2425854, 2425855, 2425852, 2425816, 2425817, 2425817, 2425818, 2425819, 2425822, 2425822, 2425823, 2425825, 2425827, 2425819, 2425843, 2425845, 2425856, 2425818, 2425819, 2425821, 2425820, 2425819, 2425820, 2425849, 2425821, 2425821, 2425829, 2425858, 2425855, 2425822, 2425823, 2425823, 2425824, 2425824, 2425825, 2425825, 2425826, 2425827, 2425828, 2425829, 2425829, 2425831, 2425843, 2425856, 2425858, 2425859, 2425823, 2425824, 2425824, 2425827, 2425828, 2425829, 2425829, 2425830, 2425831, 2425843, 2425850, 2425855, 2425857, 2425858, 2425860, 2425824, 2425825, 2425825, 2425826, 2425826, 2425827, 2425827, 2425828, 2425829, 2425830, 2425832, 2425840, 2425856, 2425856, 2425858, 2425859, 2425860, 2425860, 2425826, 2425827, 2425827, 2425830, 2425832, 2425857, 2425861, 2425826, 2425828, 2425829, 2425830, 2425861, 2427687, 2425828, 2425836, 2425861, 2425862, 2425828, 2425831, 2425829, 2425831, 2425833, 2425834, 2425838, 2425851, 2425862, 2425831, 2425832, 2425833, 2425833, 2425835, 2425846, 2425847, 2425861, 2425861, 2425863, 2425832, 2425833, 2425835, 2425851, 2425834, 2425834, 2425835, 2425836, 2425840, 2425844, 2425864, 2425865, 2425835, 2425837, 2425851, 2425865, 2425865, 2427745, 2425835, 2425836, 2425836, 2425837, 2425865, 2425865, 2425866, 2425836, 2425838, 2425838, 2425839, 2425865, 2425866, 2425866, 2425838, 2425838, 2425839, 2425840, 2425847, 2425851, 2425855, 2425864, 2425866, 2425867, 2425849, 2425851, 2427693, 2425839, 2425857, 2425868, 2425840, 2425841, 2425842, 2425842, 2425843, 2425844, 2425846, 2425850, 2425851, 2425852, 2425852, 2425853, 2425857, 2425860, 2425864, 2425864, 2425865, 2425865, 2425866, 2425866, 2425867, 2425867, 2425868, 2425868, 2425843, 2425853, 2425866, 2425866, 2425869, 2425843, 2425845, 2425852, 2425868, 2425869, 2425869, 2425844, 2425846, 2425855, 2425870, 2425847, 2425855, 2425866, 2425871, 2425847, 2425870, 2425871, 2425848, 2425870, 2425872, 2425854, 2425872, 2425872, 2425850, 2425851, 2425857, 2425858, 2425871, 2425872, 2425873, 2425854, 2425854, 2425871, 2425854, 2425855, 2425875, 2425856, 2425857, 2425874, 2425876, 2425857, 2425876, 2425859, 2425860, 2425862, 2425871, 2425877, 2425861, 2425869, 2425874, 2425875, 2425878, 2425863, 2425865, 2425875, 2425877, 2425879, 2425879, 2425880, 2425868, 2425876, 2425877, 2425880, 2425880, 2425869, 2425878, 2425879, 2425880, 2425881, 2425866, 2425868, 2425869, 2425882, 2425869, 2425878, 2425879, 2425880, 2425882, 2425870, 2425883, 2425871, 2425883, 2425875, 2425882, 2425883, 2425872, 2425875, 2425884, 2425873, 2425874, 2425874, 2425876, 2425884, 2425885, 2425874, 2425875, 2425875, 2425885, 2425885, 2425876, 2425882, 2425885, 2425885, 2425886, 2425878, 2425886, 2425885, 2425886, 2425887, 2425883, 2425887, 2425880, 2425884, 2425881, 2425884, 2425887, 2425888, 2425888, 2425882, 2425889, 2425882, 2425889, 2425883, 2425886, 2425886, 2425886, 2425887, 2425890, 2425888, 2425889, 2425888, 2425890, 2425891, 2425891, 2425892, 2425892, 2425889, 2425890, 2425891, 2425892, 2425892, 2425893, 2425890, 2425891, 2425891, 2425892, 2425893, 2425893, 2425891, 2425892, 2425893, 2425893, 2425894, 2425892, 2425893, 2425893, 2425894, 2425894, 2425894, 2425894, 2425895, 2425894, 2425895, 2425895, 2425895, 2425896, 2425896, 2425897, 2427722, 2427722, 2427736, 2427737, 2427762, 2427772, 2427774, 2427775, 2427777, 2427804, 2428077, 2427723, 2429547, 2429548, 2429549, 2429549, 2429550, 2429550, 2429551, 2429551, 2429552, 2429552, 2429553, 2429553, 2429554, 2429558, 2429559, 2429560, 2429561, 2429561, 2429562, 2429562, 2429597, 2429598, 2429599, 2429602, 2429603, 2429603, 2429605, 2429623, 2429549, 2429550, 2429550, 2429551, 2429552, 2429553, 2429556, 2429561, 2429561, 2429562, 2429562, 2429563, 2429561, 2429562, 2429562, 2429563, 2429563, 2429562, 2429563, 2429563, 2429564, 2429554, 2429555, 2429556, 2429562, 2429563, 2429563, 2429564, 2429554, 2429563, 2429564, 2429564, 2429565, 2429565, 2429566, 2429565, 2429566, 2429566, 2429565, 2429566, 2429567, 2429567, 2429566, 2429568, 2429570, 2429572, 2429573, 2429574, 2429574, 2429574, 2429575, 2429575, 2429576, 2429576, 2429621, 2429577, 2429578, 2429578, 2429579, 2429579, 2429581, 2429581, 2429582, 2429583, 2429583, 2429584, 2429584, 2429585, 2429585, 2429586, 2429586, 2429587, 2429588, 2429589, 2429589, 2429590, 2429590, 2429591, 2429591, 2429592, 2429592, 2429593, 2429594, 2429594, 2429595, 2429595, 2429597, 2429597, 2429598, 2429599, 2429599, 2429600, 2429601, 2429601, 2429602, 2429602, 2429603, 2429603, 2429604, 2429605, 2429606, 2429606, 2429607, 2429607, 2429608, 2429608, 2429609, 2429609, 2429611, 2429611, 2429612, 2429612, 2429613, 2429613, 2429614, 2429615, 2429615, 2429616, 2429617, 2429621, 2429635, 2429636, 2429637, 2429638, 2429578, 2429579, 2429579, 2429580, 2429580, 2429582, 2429582, 2429583, 2429583, 2429584, 2429584, 2429586, 2429589, 2429589, 2429590, 2429592, 2429593, 2429594, 2429595, 2429595, 2429596, 2429597, 2429598, 2429599, 2429599, 2429601, 2429601, 2429602, 2429603, 2429605, 2429606, 2429607, 2429611, 2429611, 2429612, 2429612, 2429613, 2429617, 2429579, 2429580, 2429590, 2429595, 2429600, 2429601, 2429602, 2429603, 2429605, 2429607, 2429609, 2429612, 2429613, 2429581, 2429590, 2429593, 2429602, 2429602, 2429612, 2429614, 2429581, 2429596, 2429599, 2429600, 2429602, 2429604, 2429607, 2429610, 2429582, 2429583, 2429583, 2429584, 2429585, 2429586, 2429586, 2429589, 2429591, 2429592, 2429592, 2429596, 2429597, 2429598, 2429600, 2429601, 2429601, 2429602, 2429602, 2429603, 2429603, 2429604, 2429605, 2429605, 2429606, 2429607, 2429607, 2429608, 2429613, 2429614, 2429614, 2429615, 2429618, 2429619, 2429591, 2429600, 2429603, 2429605, 2429592, 2429600, 2429602, 2429594, 2429600, 2429607, 2429612, 2429605, 2429589, 2429616, 2429603, 2429606, 2429612, 2429600, 2429604, 2429605, 2429611, 2429593, 2429597, 2429598, 2429603, 2429605, 2429606, 2429607, 2429613, 2429618, 2429624, 2429605, 2429612, 2429606, 2429610, 2429607, 2429609, 2429617, 2429620, 2429598, 2429621, 2429604, 2429610, 2429610, 2429621, 2429621, 2429625, 2429604, 2429611, 2429611, 2429612, 2429616, 2429621, 2429603, 2429609, 2429612, 2429613, 2429618, 2429623, 2429624, 2429605, 2429614, 2429615, 2429624, 2429605, 2429606, 2429611, 2429613, 2429615, 2429623, 2429620, 2429615, 2429628, 2429608, 2429613, 2429620, 2429625, 2429613, 2429616, 2429616, 2429633, 2429614, 2429616, 2429617, 2429618, 2429619, 2429622, 2429628, 2429613, 2429614, 2429615, 2429617, 2429634, 2429612, 2429613, 2429615, 2429624, 2429629, 2429630, 2429618, 2429619, 2429620, 2429629, 2429630, 2429619, 2429620, 2429621, 2429630, 2429617, 2429619, 2429620, 2429623, 2429630, 2429631, 2429620, 2429631, 2429630, 2429618, 2429619, 2429621, 2429621, 2429622, 2429623, 2429626, 2429627, 2429630, 2429631, 2429632, 2429632, 2429634, 2429619, 2429622, 2429620, 2429621, 2429622, 2429622, 2429623, 2429624, 2429626, 2429627, 2429629, 2429632, 2429633, 2429633, 2429635, 2429637, 2429638, 2429638, 2429639, 2429639, 2429622, 2429623, 2429623, 2429624, 2429625, 2429625, 2429626, 2429626, 2429628, 2429631, 2429634, 2429627, 2429634, 2429644, 2429624, 2429627, 2429634, 2429624, 2429625, 2429625, 2429626, 2429626, 2429628, 2429629, 2429631, 2429632, 2429635, 2429635, 2429636, 2429637, 2429638, 2429639, 2429640, 2429661, 2429625, 2429626, 2429626, 2429627, 2429628, 2429630, 2429630, 2429631, 2429632, 2429633, 2429635, 2429635, 2429636, 2429637, 2429637, 2429638, 2429640, 2429626, 2429627, 2429627, 2429629, 2429632, 2429634, 2429635, 2429636, 2429636, 2429637, 2429638, 2429627, 2429629, 2429631, 2429633, 2429637, 2429628, 2429629, 2429630, 2429630, 2429631, 2429632, 2429634, 2429634, 2429635, 2429636, 2429637, 2429637, 2429638, 2429639, 2429639, 2429641, 2429641, 2429630, 2429634, 2429635, 2429637, 2429638, 2429650, 2429638, 2429638, 2429636, 2429638, 2429639, 2429632, 2429633, 2429635, 2429635, 2429637, 2429637, 2429638, 2429639, 2429639, 2429640, 2429641, 2429634, 2429636, 2429638, 2429639, 2429640, 2429642, 2429640, 2429635, 2429636, 2429637, 2429637, 2429639, 2429639, 2429640, 2429640, 2429641, 2429642, 2429642, 2429643, 2429636, 2429638, 2429638, 2429640, 2429641, 2429641, 2429646, 2429641, 2429644, 2429639, 2429642, 2429642, 2429643, 2429639, 2429640, 2429641, 2429642, 2429643, 2429644, 2429641, 2429642, 2429643, 2429643, 2429652, 2429661, 2429641, 2429643, 2429643, 2429644, 2429644, 2429644, 2429644, 2429644, 2429645, 2429645, 2429645, 2429646, 2429649, 2429646, 2429647, 2429647, 2429648, 2429648, 2429649, 2429650, 2429650, 2429651, 2429651, 2429652, 2429647, 2429648, 2429648, 2429649, 2429649, 2429650, 2429650, 2429651, 2429651, 2429652, 2429652, 2429653, 2429654, 2429656, 2429656, 2429661, 2429672, 2429673, 2429648, 2429649, 2429649, 2429652, 2429649, 2429650, 2429651, 2429651, 2429652, 2429652, 2429653, 2429653, 2429654, 2429654, 2429665, 2429667, 2429673, 2429674, 2429650, 2429651, 2429651, 2429652, 2429652, 2429653, 2429653, 2429654, 2429654, 2429655, 2429656, 2429657, 2429658, 2429669, 2429672, 2429673, 2429674, 2429674, 2429651, 2429652, 2429652, 2429653, 2429653, 2429654, 2429654, 2429655, 2429655, 2429659, 2429659, 2429660, 2429669, 2429671, 2429674, 2429675, 2429652, 2429653, 2429653, 2429654, 2429654, 2429655, 2429653, 2429654, 2429654, 2429655, 2429655, 2429656, 2429657, 2429675, 2429654, 2429655, 2429655, 2429656, 2429656, 2429657, 2429658, 2429659, 2429668, 2429672, 2429676, 2429655, 2429656, 2429656, 2429657, 2429657, 2429659, 2429660, 2429677, 2429656, 2429657, 2429657, 2429658, 2429658, 2429659, 2429660, 2429661, 2429663, 2429663, 2429664, 2429666, 2429670, 2429670, 2429671, 2429672, 2429675, 2429676, 2429677, 2429657, 2429658, 2429658, 2429659, 2429659, 2429660, 2429660, 2429661, 2429661, 2429662, 2429663, 2429663, 2429664, 2429667, 2429668, 2429669, 2429671, 2429673, 2429675, 2429675, 2429676, 2429676, 2429677, 2429677, 2429678, 2429658, 2429659, 2429659, 2429660, 2429661, 2429661, 2429662, 2429662, 2429663, 2429663, 2429664, 2429664, 2429666, 2429667, 2429668, 2429668, 2429670, 2429671, 2429672, 2429672, 2429673, 2429673, 2429675, 2429676, 2429677, 2429677, 2429678, 2429678, 2429659, 2429660, 2429660, 2429661, 2429661, 2429662, 2429662, 2429663, 2429663, 2429664, 2429664, 2429665, 2429667, 2429668, 2429669, 2429669, 2429670, 2429671, 2429671, 2429672, 2429673, 2429674, 2429674, 2429675, 2429676, 2429677, 2429677, 2429678, 2429678, 2429679, 2429660, 2429661, 2429661, 2429662, 2429662, 2429663, 2429663, 2429664, 2429665, 2429665, 2429668, 2429669, 2429671, 2429672, 2429674, 2429675, 2429675, 2429676, 2429676, 2429677, 2429678, 2429678, 2429679, 2429679, 2429661, 2429662, 2429662, 2429663, 2429663, 2429664, 2429664, 2429665, 2429669, 2429670, 2429675, 2429676, 2429677, 2429679, 2429679, 2429680, 2429663, 2429663, 2429664, 2429664, 2429665, 2429666, 2429666, 2429667, 2429668, 2429669, 2429670, 2429670, 2429672, 2429672, 2429673, 2429673, 2429677, 2429678, 2429678, 2429679, 2429679, 2429680, 2429680, 2429665, 2429671, 2429676, 2429681, 2429664, 2429666, 2429667, 2429667, 2429673, 2429674, 2429675, 2429676, 2429676, 2429677, 2429679, 2429681, 2429681, 2429665, 2429666, 2429666, 2429667, 2429667, 2429668, 2429668, 2429669, 2429670, 2429671, 2429671, 2429672, 2429674, 2429674, 2429675, 2429676, 2429677, 2429677, 2429678, 2429679, 2429679, 2429680, 2429680, 2429681, 2429681, 2429682, 2429666, 2429668, 2429668, 2429670, 2429670, 2429672, 2429672, 2429673, 2429674, 2429674, 2429675, 2429675, 2429677, 2429679, 2429680, 2429681, 2429681, 2429682, 2429682, 2429667, 2429668, 2429671, 2429672, 2429673, 2429673, 2429674, 2429675, 2429675, 2429676, 2429678, 2429678, 2429679, 2429680, 2429680, 2429681, 2429681, 2429682, 2429682, 2429683, 2429669, 2429669, 2429673, 2429675, 2429676, 2429678, 2429679, 2429681, 2429669, 2429670, 2429672, 2429675, 2429677, 2429678, 2429681, 2429681, 2429683, 2429684, 2429670, 2429671, 2429672, 2429673, 2429674, 2429675, 2429676, 2429679, 2429679, 2429682, 2429683, 2429683, 2429684, 2429684, 2429671, 2429672, 2429672, 2429673, 2429674, 2429675, 2429676, 2429678, 2429680, 2429680, 2429681, 2429681, 2429683, 2429684, 2429684, 2429685, 2429676, 2429677, 2429681, 2429683, 2429684, 2429684, 2429685, 2429685, 2429677, 2429678, 2429677, 2429682, 2429685, 2429686, 2429677, 2429678, 2429683, 2429684, 2429686, 2429687, 2429678, 2429679, 2429680, 2429680, 2429685, 2429685, 2429686, 2429687, 2429687, 2429682, 2429679, 2429680, 2429682, 2429683, 2429683, 2429684, 2429685, 2429687, 2429688, 2429688, 2429681, 2429682, 2429684, 2429685, 2429686, 2429687, 2429688, 2429688, 2429689, 2429681, 2429683, 2429686, 2429687, 2429688, 2429689, 2429689, 2429683, 2429682, 2429683, 2429684, 2429685, 2429688, 2429689, 2429689, 2429690, 2429690, 2429683, 2429684, 2429684, 2429685, 2429686, 2429686, 2429687, 2429688, 2429689, 2429690, 2429690, 2429691, 2429684, 2429685, 2429685, 2429686, 2429687, 2429688, 2429689, 2429689, 2429690, 2429691, 2429691, 2429689, 2429691, 2429691, 2429692, 2429686, 2429687, 2429689, 2429690, 2429692, 2429692, 2429687, 2429689, 2429690, 2429692, 2429692, 2429693, 2429688, 2429692, 2429693, 2429689, 2429690, 2429691, 2429691, 2429692, 2429692, 2429693, 2429693, 2429694, 2429691, 2429692, 2429692, 2429693, 2429693, 2429694, 2429694, 2429692, 2429693, 2429694, 2429695, 2429692, 2429693, 2429694, 2429695, 2429695, 2429693, 2429694, 2429695, 2429696, 2429694, 2429695, 2429695, 2429696, 2429696, 2429695, 2429696, 2429696, 2429697, 2429711, 2429696, 2429697, 2429697, 2429697, 2429698, 2429698, 2429699, 2429700, 2429700, 2429701, 2429701, 2429702, 2429702, 2429703, 2429705, 2429713, 2429749, 2429700, 2429701, 2429701, 2429702, 2429702, 2429703, 2429704, 2429705, 2429706, 2429702, 2429706, 2429750, 2429702, 2429707, 2429704, 2429707, 2429707, 2429705, 2429708, 2429708, 2429709, 2429710, 2429711, 2429712, 2429713, 2429713, 2429714, 2429714, 2429715, 2429716, 2429716, 2429717, 2429717, 2429718, 2429718, 2429719, 2429719, 2429720, 2429720, 2429721, 2429722, 2429722, 2429723, 2429723, 2429755, 2429756, 2429762, 2429766, 2429713, 2429714, 2429714, 2429715, 2429716, 2429716, 2429717, 2429717, 2429718, 2429718, 2429719, 2429719, 2429720, 2429720, 2429723, 2429714, 2429717, 2429717, 2429718, 2429719, 2429720, 2429720, 2429715, 2429717, 2429718, 2429719, 2429719, 2429720, 2429720, 2429721, 2429721, 2429724, 2429718, 2429720, 2429721, 2429721, 2429722, 2429723, 2429725, 2429718, 2429720, 2429722, 2429719, 2429721, 2429722, 2429723, 2429720, 2429721, 2429721, 2429722, 2429722, 2429723, 2429723, 2429724, 2429721, 2429722, 2429724, 2429724, 2429722, 2429723, 2429724, 2429724, 2429725, 2429723, 2429724, 2429724, 2429725, 2429725, 2429724, 2429725, 2429725, 2429726, 2429725, 2429726, 2429726, 2429726, 2429727, 2429727, 2429730, 2429763, 2429728, 2429729, 2429729, 2429730, 2429730, 2429731, 2429731, 2429732, 2429735, 2429740, 2429743, 2429743, 2429746, 2429746, 2429747, 2429747, 2429750, 2429752, 2429753, 2429755, 2429755, 2429758, 2429759, 2429760, 2429760, 2429761, 2429761, 2429762, 2429762, 2429763, 2429763, 2429764, 2429993, 25897026, 2429730, 2429731, 2429733, 2429761, 2429763, 2429763, 2429764, 2429733, 2429757, 2429764, 2429731, 2429732, 2429732, 2429765, 2429732, 2429733, 2429765, 2429733, 2429734, 2429750, 2429734, 2429755, 2429766, 2429766, 2429767, 2429735, 2429767, 2429737, 2429744, 2429747, 2429761, 2429764, 2429765, 2429766, 2429767, 2429767, 2429768, 2430038, 2429768, 2429769, 2429769, 2429775, 2429776, 2429776, 2429778, 2429778, 2429779, 2429781, 2429782, 2429782, 2429782, 2429783, 2429786, 2429777, 2429780, 2429787, 2429788, 2429789, 2429790, 2429790, 2429791, 2429791, 2429793, 2429794, 2429794, 2429795, 2429795, 2429795, 2429796, 2429796, 2429797, 2429797, 2429797, 2429798, 2429798, 2429799, 2429799, 2429831, 2429800, 2429801, 2429801, 2429802, 2429802, 2429803, 2429803, 2429804, 2429804, 2429805, 2429805, 2429806, 2429806, 2429807, 2429810, 2429810, 2429811, 2429811, 2429812, 2429812, 2429814, 2429817, 2429819, 2429826, 2429829, 2429831, 2429831, 2429833, 2429875, 2429801, 2429802, 2429802, 2429803, 2429803, 2429804, 2429804, 2429805, 2429805, 2429806, 2429806, 2429807, 2429808, 2429811, 2429831, 2429802, 2429803, 2429803, 2429804, 2429805, 2429805, 2429806, 2429806, 2429807, 2429807, 2429819, 2429803, 2429804, 2429804, 2429805, 2429805, 2429806, 2429806, 2429807, 2429807, 2429808, 2429809, 2429812, 2429819, 2429804, 2429805, 2429805, 2429806, 2429806, 2429807, 2429807, 2429808, 2429808, 2429805, 2429806, 2429806, 2429807, 2429807, 2429808, 2429813, 2429806, 2429807, 2429807, 2429808, 2429808, 2429809, 2429807, 2429808, 2429808, 2429809, 2429809, 2429811, 2429808, 2429809, 2429809, 2429810, 2429810, 2429811, 2429814, 2429820, 2429809, 2429810, 2429810, 2429811, 2429811, 2429812, 2429814, 2429814, 2429818, 2429819, 2429836, 2429810, 2429811, 2429811, 2429812, 2429814, 2429815, 2429815, 2429816, 2429817, 2429819, 2429820, 2429811, 2429812, 2429813, 2429813, 2429814, 2429815, 2429815, 2429816, 2429818, 2429819, 2429819, 2429820, 2429823, 2429823, 2429824, 2429832, 2429834, 2429837, 2429812, 2429813, 2429813, 2429814, 2429815, 2429816, 2429816, 2429817, 2429818, 2429819, 2429819, 2429820, 2429820, 2429821, 2429822, 2429823, 2429825, 2429837, 2429813, 2429814, 2429814, 2429815, 2429815, 2429816, 2429816, 2429817, 2429817, 2429818, 2429818, 2429819, 2429819, 2429820, 2429820, 2429821, 2429821, 2429822, 2429823, 2429823, 2429824, 2429824, 2429825, 2429826, 2429826, 2429828, 2429832, 2429833, 2429835, 2429838, 2429814, 2429816, 2429817, 2429815, 2429816, 2429816, 2429817, 2429817, 2429818, 2429818, 2429819, 2429819, 2429820, 2429820, 2429821, 2429821, 2429822, 2429822, 2429823, 2429823, 2429824, 2429824, 2429825, 2429825, 2429826, 2429826, 2429827, 2429828, 2429834, 2429836, 2429839, 2429816, 2429817, 2429818, 2429818, 2429821, 2429822, 2429822, 2429823, 2429827, 2429817, 2429818, 2429818, 2429819, 2429819, 2429822, 2429830, 2429835, 2429818, 2429819, 2429820, 2429820, 2429821, 2429823, 2429823, 2429824, 2429835, 2429838, 2429819, 2429820, 2429820, 2429821, 2429821, 2429822, 2429822, 2429823, 2429823, 2429824, 2429826, 2429826, 2429827, 2429828, 2429828, 2429833, 2429836, 2429838, 2429838, 2429820, 2429821, 2429821, 2429822, 2429822, 2429823, 2429823, 2429824, 2429824, 2429825, 2429825, 2429826, 2429826, 2429827, 2429827, 2429828, 2429828, 2429829, 2429834, 2429836, 2429840, 2429841, 2429821, 2429822, 2429822, 2429823, 2429823, 2429824, 2429824, 2429825, 2429825, 2429826, 2429827, 2429827, 2429828, 2429828, 2429829, 2429830, 2429833, 2429834, 2429835, 2429837, 2429841, 2429842, 2429822, 2429823, 2429823, 2429824, 2429824, 2429825, 2429825, 2429826, 2429826, 2429827, 2429828, 2429828, 2429829, 2429830, 2429832, 2429833, 2429835, 2429837, 2429839, 2429840, 2429841, 2429842, 2429842, 2429823, 2429824, 2429824, 2429825, 2429825, 2429826, 2429826, 2429827, 2429827, 2429828, 2429829, 2429830, 2429835, 2429838, 2429839, 2429840, 2429840, 2429843, 2429824, 2429825, 2429825, 2429826, 2429826, 2429827, 2429827, 2429828, 2429828, 2429829, 2429829, 2429831, 2429833, 2429838, 2429841, 2429843, 2429825, 2429826, 2429826, 2429827, 2429827, 2429828, 2429829, 2429829, 2429830, 2429830, 2429831, 2429831, 2429832, 2429832, 2429833, 2429836, 2429839, 2429826, 2429827, 2429827, 2429828, 2429828, 2429830, 2429832, 2429842, 2429827, 2429828, 2429828, 2429829, 2429830, 2429830, 2429831, 2429831, 2429832, 2429834, 2429834, 2429835, 2429837, 2429840, 2429842, 2429828, 2429829, 2429829, 2429830, 2429830, 2429831, 2429831, 2429832, 2429832, 2429833, 2429835, 2429838, 2429840, 2429840, 2429843, 2429845, 2429829, 2429830, 2429830, 2429831, 2429831, 2429832, 2429832, 2429833, 2429833, 2429834, 2429834, 2429838, 2429841, 2429841, 2429842, 2429843, 2429843, 2429846, 2429830, 2429831, 2429831, 2429832, 2429832, 2429833, 2429833, 2429834, 2429834, 2429835, 2429836, 2429838, 2429839, 2429839, 2429841, 2429844, 2429846, 2429831, 2429832, 2429832, 2429833, 2429833, 2429834, 2429834, 2429835, 2429835, 2429836, 2429839, 2429842, 2429844, 2429845, 2429847, 2429832, 2429833, 2429833, 2429834, 2429834, 2429835, 2429835, 2429840, 2429842, 2429844, 2429845, 2429833, 2429834, 2429834, 2429835, 2429835, 2429836, 2429837, 2429837, 2429838, 2429840, 2429843, 2429844, 2429845, 2429847, 2429848, 2429834, 2429835, 2429835, 2429836, 2429838, 2429838, 2429840, 2429843, 2429845, 2429846, 2429848, 2429835, 2429836, 2429836, 2429837, 2429837, 2429838, 2429839, 2429840, 2429840, 2429841, 2429843, 2429844, 2429844, 2429845, 2429846, 2429846, 2429847, 2429848, 2429849, 2429836, 2429837, 2429837, 2429838, 2429839, 2429839, 2429840, 2429842, 2429844, 2429846, 2429847, 2429848, 2429849, 2429849, 2429837, 2429838, 2429838, 2429839, 2429839, 2429840, 2429841, 2429842, 2429842, 2429843, 2429844, 2429845, 2429845, 2429846, 2429847, 2429849, 2429850, 2429838, 2429839, 2429840, 2429840, 2429841, 2429842, 2429843, 2429843, 2429844, 2429845, 2429845, 2429848, 2429850, 2429839, 2429840, 2429841, 2429841, 2429843, 2429844, 2429845, 2429845, 2429846, 2429848, 2429850, 2429851, 2429841, 2429843, 2429844, 2429846, 2429847, 2429848, 2429849, 2429851, 2429845, 2429847, 2429849, 2429842, 2429844, 2429846, 2429847, 2429849, 2429850, 2429845, 2429845, 2429846, 2429847, 2429848, 2429850, 2429850, 2429852, 2429848, 2429849, 2429850, 2429851, 2429849, 2429847, 2429848, 2429850, 2429851, 2429852, 2429853, 2429854, 2429855, 2429848, 2429849, 2429850, 2429852, 2429852, 2429855, 2429850, 2429851, 2429853, 2429851, 2429852, 2429851, 2429852, 2429857, 2429852, 2429854, 2429854, 2429855, 2429857, 2429853, 2429854, 2429854, 2429855, 2429855, 2429856, 2429857, 2429857, 2429858, 2429855, 2429856, 2429855, 2429856, 2429856, 2429856, 2429857, 2429857, 2429858, 2429859, 2429859, 2429857, 2429858, 2429859, 2429859, 2429860, 2429858, 2429859, 2429859, 2429860, 2429860, 2429859, 2429860, 2429860, 2429861, 2429860, 2429861, 2429861, 2429861, 2429862, 2429862, 2429863, 2429864, 2429864, 2429865, 2429867, 2429867, 2429868, 2429869, 2429869, 2429871, 2429871, 2429872, 2429872, 2429873, 2429873, 2429874, 2429875, 2429876, 2429876, 2429877, 2429878, 2429879, 2429886, 2429891, 2429896, 2429896, 2429898, 2429901, 2429902, 2429903, 2429904, 2429905, 2429905, 2429906, 2429907, 2430060, 2430100, 2430120, 2429864, 2429865, 2429865, 2429866, 2429866, 2429867, 2429867, 2429868, 2429868, 2429869, 2429869, 2429870, 2429870, 2429871, 2429871, 2429872, 2429872, 2429873, 2429874, 2429874, 2429875, 2429875, 2429876, 2429876, 2429877, 2429877, 2429878, 2429878, 2429879, 2429882, 2429883, 2429885, 2429890, 2429891, 2429893, 2429893, 2429900, 2429901, 2429902, 2429903, 2429905, 2429905, 2429906, 2429907, 2429907, 2430101, 2429865, 2429866, 2429866, 2429867, 2429867, 2429868, 2429868, 2429869, 2429869, 2429870, 2429870, 2429871, 2429872, 2429872, 2429873, 2429874, 2429874, 2429875, 2429876, 2429876, 2429877, 2429877, 2429878, 2429878, 2429879, 2429879, 2429884, 2429885, 2429892, 2429893, 2429894, 2429896, 2429897, 2429902, 2429903, 2429904, 2429905, 2429905, 2429906, 2429906, 2429907, 2429907, 2429908, 2430061, 2430101, 2429866, 2429867, 2429868, 2429868, 2429869, 2429870, 2429870, 2429871, 2429872, 2429873, 2429873, 2429874, 2429875, 2429875, 2429877, 2429878, 2429878, 2429879, 2429879, 2429881, 2429891, 2429897, 2429904, 2429906, 2429906, 2429907, 2429908, 2430102, 2429867, 2429869, 2429869, 2429870, 2429871, 2429871, 2429873, 2429874, 2429875, 2429878, 2429878, 2429879, 2429881, 2429883, 2429893, 2429906, 2429907, 2429909, 2429868, 2429870, 2429871, 2429871, 2429873, 2429876, 2429887, 2429909, 2429870, 2429872, 2429873, 2429880, 2429906, 2429870, 2429871, 2429871, 2429873, 2429875, 2429879, 2429879, 2429871, 2429872, 2429873, 2429876, 2429877, 2429881, 2429881, 2429883, 2429900, 2429906, 2429911, 2429872, 2429873, 2429873, 2429874, 2429874, 2429875, 2429875, 2429876, 2429876, 2429877, 2429877, 2429878, 2429878, 2429879, 2429879, 2429880, 2429881, 2429882, 2429895, 2429896, 2429908, 2429909, 2429909, 2429910, 2429911, 2429911, 2430065, 2429873, 2429874, 2429875, 2429878, 2429910, 2429912, 2429874, 2429876, 2429877, 2429878, 2429879, 2429880, 2429882, 2429883, 2429883, 2429892, 2429911, 2429912, 2429876, 2429877, 2429877, 2429878, 2429878, 2429879, 2429879, 2429880, 2429881, 2429881, 2429882, 2429882, 2429883, 2429883, 2429884, 2429887, 2429891, 2429901, 2429902, 2429905, 2429908, 2429909, 2429909, 2429910, 2429911, 2429911, 2429912, 2429913, 2429877, 2429878, 2429880, 2429880, 2429882, 2429883, 2429912, 2429878, 2429880, 2429883, 2429879, 2429880, 2429881, 2429883, 2429901, 2429914, 2429879, 2429880, 2429881, 2429882, 2429882, 2429883, 2429883, 2429884, 2429884, 2429885, 2429885, 2429886, 2429894, 2429895, 2429899, 2429905, 2429910, 2429911, 2429913, 2429915, 2430068, 2429880, 2429881, 2429882, 2429882, 2429883, 2429884, 2429884, 2429885, 2429885, 2429886, 2429915, 2429881, 2429882, 2429882, 2429883, 2429885, 2429885, 2429886, 2429888, 2429899, 2429912, 2429914, 2429915, 2429883, 2429884, 2429885, 2429885, 2429886, 2429887, 2429891, 2429912, 2429916, 2429883, 2429884, 2429886, 2429886, 2429887, 2429888, 2429915, 2429884, 2429885, 2429885, 2429886, 2429886, 2429887, 2429887, 2429888, 2429889, 2429890, 2429892, 2429894, 2429896, 2429906, 2429915, 2429915, 2429916, 2429917, 2430111, 2430120, 2429885, 2429886, 2429887, 2429887, 2429888, 2429888, 2429914, 2429916, 2429918, 2429886, 2429887, 2429887, 2429888, 2429888, 2429889, 2429903, 2429916, 2429917, 2429887, 2429888, 2429888, 2429889, 2429889, 2429896, 2429911, 2429917, 2429919, 2429888, 2429889, 2429889, 2429890, 2429891, 2429892, 2429913, 2429889, 2429890, 2429890, 2429891, 2429891, 2429894, 2429896, 2429898, 2429908, 2429910, 2429913, 2429914, 2429915, 2429916, 2429917, 2429917, 2429918, 2429919, 2429920, 2430113, 2429890, 2429891, 2429891, 2429892, 2429892, 2429893, 2429894, 2429895, 2429896, 2429898, 2429904, 2429906, 2429908, 2429909, 2429913, 2429915, 2429916, 2429917, 2429918, 2429918, 2429919, 2429920, 2429891, 2429892, 2429892, 2429893, 2429893, 2429894, 2429895, 2429898, 2429910, 2429914, 2429917, 2429917, 2429918, 2429918, 2429919, 2429919, 2429920, 2429921, 2430114, 2429892, 2429893, 2429893, 2429894, 2429895, 2429896, 2429897, 2429899, 2429900, 2429901, 2429901, 2429903, 2429905, 2429909, 2429910, 2429910, 2429913, 2429913, 2429914, 2429915, 2429915, 2429916, 2429917, 2429917, 2429918, 2429918, 2429919, 2429919, 2429920, 2429921, 2429921, 2430075, 2430115, 2429893, 2429894, 2429898, 2429899, 2429900, 2429901, 2429906, 2429909, 2429910, 2429911, 2429915, 2429917, 2429917, 2429918, 2429918, 2429919, 2429920, 2429920, 2429922, 2430115, 2429894, 2429895, 2429895, 2429896, 2429897, 2429897, 2429901, 2429902, 2429906, 2429907, 2429911, 2429912, 2429913, 2429913, 2429914, 2429915, 2429915, 2429918, 2429919, 2429919, 2429920, 2429920, 2429921, 2429896, 2429905, 2429907, 2429912, 2429915, 2429918, 2429919, 2429920, 2429920, 2429921, 2429921, 2430116, 2429896, 2429903, 2429910, 2429918, 2429919, 2429920, 2429921, 2429922, 2429897, 2429898, 2429902, 2429904, 2429905, 2429910, 2429912, 2429920, 2429921, 2429922, 2429923, 2429899, 2429923, 2429902, 2429908, 2429921, 2429922, 2429923, 2429923, 2429925, 2429905, 2429907, 2429908, 2429909, 2429917, 2429921, 2429921, 2429922, 2429923, 2429923, 2429925, 2429904, 2429912, 2429920, 2429916, 2429924, 2429924, 2429925, 2429917, 2429922, 2429927, 2429913, 2429925, 2429916, 2429921, 2429922, 2429927, 2429913, 2429915, 2429916, 2429920, 2429927, 2429927, 2429912, 2429918, 2429927, 2429917, 2429928, 2429920, 2429921, 2429927, 2429928, 2429930, 2429928, 2429928, 2429929, 2429931, 2429926, 2429925, 2429923, 2429931, 2429917, 2429929, 2429931, 2429932, 2429933, 2429923, 2429930, 2429919, 2429923, 2429925, 2429931, 2429932, 2429932, 2429933, 2429935, 2429922, 2429925, 2429929, 2429933, 2429935, 2429933, 2429934, 2429931, 2429933, 2429934, 2429932, 2429933, 2429934, 2429936, 2429926, 2429936, 2429936, 2429927, 2429934, 2429935, 2429937, 2429932, 2429933, 2429937, 2429939, 2429928, 2429929, 2429932, 2429933, 2429933, 2429935, 2429936, 2429938, 2429929, 2429930, 2429932, 2429933, 2429936, 2429936, 2429937, 2429938, 2429938, 2429940, 2429930, 2429933, 2429937, 2429937, 2429938, 2429938, 2429939, 2429937, 2429938, 2429939, 2429939, 2429941, 2429936, 2429939, 2429940, 2429938, 2429942, 2429939, 2429940, 2429941, 2429939, 2429941, 2429943, 2429939, 2429940, 2429941, 2429942, 2429939, 2429940, 2429941, 2429942, 2429942, 2430137, 2429940, 2429942, 2429943, 2429941, 2429942, 2429943, 2429943, 2429945, 2429943, 2429944, 2429941, 2429942, 2429942, 2429943, 2429944, 2429944, 2429942, 2429943, 2429943, 2429944, 2429944, 2429945, 2429946, 2429943, 2429944, 2429944, 2429945, 2429945, 2429947, 2429944, 2429945, 2429945, 2429946, 2429947, 2429947, 2429945, 2429946, 2429946, 2429947, 2429946, 2429947, 2429947, 2429948, 2429948, 2429947, 2429948, 2429949, 2429948, 2429949, 2429949, 2430103, 2429949, 2429950, 2429950, 2430104, 2429951, 2430045, 2430085, 2430104, 2430104, 2430126, 2430144, 2430157, 2430319, 2430320, 2430443, 18265339, 2430086, 2430104, 2430105, 2430198, 2430238, 2430239, 2430257, 2430258, 2430259, 2430259, 2430260, 2430260, 2430261, 2430261, 2430262, 2430262, 2430264, 2430265, 2430266, 2430266, 2430267, 2430268, 2430270, 2430271, 2430274, 2430274, 2430276, 2430277, 2430278, 2430281, 2430283, 2430287, 2430288, 2430289, 2430290, 2430293, 2430294, 2430296, 2430296, 2430297, 2430297, 2430298, 2430316, 2430333, 2430260, 2430261, 2430263, 2430265, 2430277, 2430289, 2430296, 2430297, 2430297, 2430298, 2430261, 2430262, 2430263, 2430267, 2430277, 2430297, 2430298, 2430298, 2430299, 2430264, 2430278, 2430299, 2430278, 2430298, 2430299, 2430299, 2430300, 2430300, 2430279, 2430300, 2430300, 2430280, 2430285, 2430301, 2430280, 2430281, 2430300, 2430301, 2430301, 2430302, 2430302, 2430283, 2430303, 2430304, 2430283, 2430304, 2430306, 2430285, 2430306, 2430286, 2430288, 2430309, 2430310, 2430313, 2430314, 2430297, 2430298, 2430299, 2430309, 2430310, 2430311, 2430313, 2430315, 2430315, 2430316, 2430316, 2430317, 2430317, 2430318, 2430317, 2430320, 2430320, 2430320, 2430321, 2430315, 2430326, 2430328, 2430327, 2430330, 2430330, 2430330, 2430331, 2430331, 2430331, 2430332, 2430334, 2430334, 2430335, 2430334, 2430334, 2430335, 2430335, 2430335, 2430336, 2430336, 2430336, 2430337, 2430337, 2430338, 2430339, 2430339, 2430340, 2430340, 2430341, 2430341, 2430342, 2430342, 2430343, 2430343, 2430344, 2430344, 2430345, 2430345, 2430346, 2430346, 2430347, 2430347, 2430348, 2430348, 2430349, 2430350, 2430350, 2430351, 2430352, 2430352, 2430353, 2430353, 2430354, 2430355, 2430356, 2430357, 2430357, 2430358, 2430358, 2430361, 2430373, 2430373, 2430388, 2430339, 2430340, 2430340, 2430341, 2430341, 2430342, 2430342, 2430343, 2430343, 2430344, 2430345, 2430345, 2430346, 2430347, 2430347, 2430348, 2430349, 2430349, 2430350, 2430351, 2430352, 2430353, 2430340, 2430341, 2430342, 2430342, 2430343, 2430344, 2430345, 2430347, 2430348, 2430349, 2430350, 2430351, 2430351, 2430341, 2430342, 2430342, 2430344, 2430345, 2430346, 2430348, 2430351, 2430351, 2430352, 2430355, 2430343, 2430344, 2430345, 2430345, 2430346, 2430347, 2430348, 2430349, 2430350, 2430352, 2430352, 2430344, 2430344, 2430345, 2430346, 2430346, 2430347, 2430348, 2430349, 2430349, 2430350, 2430351, 2430352, 2430352, 2430353, 2430354, 2430373, 2430346, 2430346, 2430347, 2430349, 2430350, 2430351, 2430352, 2430353, 2430353, 2430355, 2430346, 2430350, 2430350, 2430353, 2430354, 2430361, 2430377, 2430346, 2430347, 2430348, 2430351, 2430352, 2430353, 2430354, 2430354, 2430350, 2430351, 2430355, 2430348, 2430350, 2430350, 2430351, 2430352, 2430353, 2430353, 2430355, 2430355, 2430362, 2430363, 2430350, 2430351, 2430352, 2430352, 2430353, 2430355, 2430356, 2430351, 2430356, 2430351, 2430352, 2430352, 2430353, 2430356, 2430356, 2430357, 2430352, 2430353, 2430354, 2430357, 2430357, 2430354, 2430354, 2430356, 2430357, 2430357, 2430358, 2430355, 2430358, 2430358, 2430355, 2430356, 2430357, 2430358, 2430359, 2430356, 2430357, 2430357, 2430358, 2430359, 2430359, 2430360, 2430361, 2430361, 2430362, 2430362, 2430365, 2430382, 2430359, 2430359, 2430360, 2430358, 2430359, 2430359, 2430360, 2430360, 2430359, 2430360, 2430360, 2430361, 2430362, 2430363, 2430361, 2430361, 2430361, 2430362, 2430363, 2430363, 2430364, 2430368, 2430362, 2430363, 2430364, 2430364, 2430365, 2430365, 2430366, 2430367, 2430368, 2430369, 2430371, 2430373, 2430374, 2430363, 2430364, 2430364, 2430365, 2430365, 2430366, 2430366, 2430367, 2430367, 2430368, 2430369, 2430369, 2430370, 2430371, 2430372, 2430373, 2430374, 2430376, 2430377, 2430383, 2430384, 2430385, 2430386, 2430364, 2430365, 2430366, 2430366, 2430376, 2430365, 2430366, 2430366, 2430367, 2430367, 2430368, 2430369, 2430369, 2430370, 2430375, 2430387, 2430366, 2430367, 2430367, 2430368, 2430368, 2430369, 2430369, 2430370, 2430370, 2430371, 2430371, 2430375, 2430376, 2430377, 2430378, 2430381, 2430386, 2430387, 2430367, 2430368, 2430368, 2430369, 2430369, 2430370, 2430370, 2430371, 2430371, 2430372, 2430372, 2430373, 2430375, 2430376, 2430377, 2430378, 2430379, 2430379, 2430381, 2430382, 2430385, 2430387, 2430388, 2430368, 2430369, 2430369, 2430370, 2430370, 2430371, 2430371, 2430372, 2430372, 2430373, 2430373, 2430376, 2430376, 2430378, 2430381, 2430388, 2430369, 2430370, 2430370, 2430371, 2430371, 2430372, 2430372, 2430373, 2430373, 2430374, 2430374, 2430376, 2430377, 2430377, 2430378, 2430378, 2430379, 2430380, 2430381, 2430382, 2430382, 2430383, 2430384, 2430385, 2430385, 2430386, 2430388, 2430389, 2430370, 2430371, 2430371, 2430372, 2430372, 2430373, 2430374, 2430374, 2430375, 2430375, 2430377, 2430377, 2430378, 2430378, 2430383, 2430388, 2430389, 2430371, 2430372, 2430372, 2430373, 2430373, 2430374, 2430375, 2430377, 2430378, 2430378, 2430381, 2430383, 2430387, 2430389, 2430390, 2430372, 2430373, 2430373, 2430374, 2430375, 2430375, 2430376, 2430378, 2430378, 2430379, 2430380, 2430382, 2430382, 2430373, 2430374, 2430374, 2430375, 2430375, 2430376, 2430378, 2430379, 2430379, 2430380, 2430381, 2430382, 2430382, 2430386, 2430388, 2430390, 2430390, 2430391, 2430374, 2430375, 2430375, 2430376, 2430376, 2430377, 2430379, 2430379, 2430380, 2430380, 2430381, 2430381, 2430382, 2430383, 2430383, 2430384, 2430385, 2430386, 2430390, 2430390, 2430391, 2430391, 2430375, 2430376, 2430376, 2430377, 2430377, 2430378, 2430379, 2430379, 2430380, 2430380, 2430381, 2430382, 2430383, 2430383, 2430386, 2430387, 2430389, 2430389, 2430391, 2430392, 2430376, 2430377, 2430377, 2430378, 2430378, 2430379, 2430379, 2430380, 2430380, 2430381, 2430381, 2430382, 2430382, 2430383, 2430384, 2430384, 2430385, 2430385, 2430386, 2430387, 2430387, 2430389, 2430390, 2430391, 2430392, 2430392, 2430377, 2430378, 2430378, 2430379, 2430379, 2430380, 2430381, 2430381, 2430383, 2430384, 2430387, 2430387, 2430389, 2430390, 2430392, 2430392, 2430393, 2430378, 2430379, 2430381, 2430381, 2430382, 2430383, 2430383, 2430384, 2430384, 2430385, 2430390, 2430392, 2430393, 2430379, 2430380, 2430380, 2430381, 2430382, 2430382, 2430384, 2430385, 2430385, 2430386, 2430393, 2430394, 2430380, 2430382, 2430382, 2430383, 2430384, 2430386, 2430387, 2430390, 2430394, 2430382, 2430383, 2430383, 2430387, 2430389, 2430390, 2430390, 2430391, 2430392, 2430394, 2430395, 2430383, 2430383, 2430385, 2430392, 2430384, 2430384, 2430385, 2430385, 2430386, 2430386, 2430387, 2430388, 2430392, 2430395, 2430395, 2430396, 2430396, 2430385, 2430386, 2430386, 2430387, 2430388, 2430388, 2430390, 2430391, 2430394, 2430396, 2430396, 2430397, 2430386, 2430387, 2430388, 2430388, 2430389, 2430390, 2430391, 2430392, 2430392, 2430394, 2430396, 2430397, 2430397, 2430387, 2430388, 2430389, 2430389, 2430391, 2430391, 2430393, 2430394, 2430397, 2430398, 2430388, 2430389, 2430390, 2430394, 2430395, 2430398, 2430389, 2430390, 2430390, 2430392, 2430392, 2430393, 2430395, 2430396, 2430397, 2430398, 2430398, 2430399, 2430390, 2430391, 2430395, 2430396, 2430391, 2430392, 2430393, 2430393, 2430394, 2430395, 2430395, 2430396, 2430397, 2430398, 2430398, 2430399, 2430399, 2430400, 2430392, 2430393, 2430394, 2430394, 2430395, 2430395, 2430396, 2430396, 2430397, 2430398, 2430399, 2430399, 2430400, 2430400, 2430394, 2430395, 2430395, 2430396, 2430396, 2430397, 2430398, 2430400, 2430401, 2430397, 2430398, 2430395, 2430396, 2430397, 2430397, 2430398, 2430398, 2430399, 2430399, 2430400, 2430401, 2430401, 2430402, 2430397, 2430398, 2430399, 2430399, 2430401, 2430402, 2430402, 2430398, 2430403, 2430398, 2430399, 2430399, 2430400, 2430400, 2430401, 2430401, 2430402, 2430402, 2430403, 2430403, 2430399, 2430400, 2430400, 2430401, 2430401, 2430402, 2430403, 2430404, 2430400, 2430401, 2430401, 2430402, 2430403, 2430404, 2430404, 2430401, 2430402, 2430402, 2430403, 2430403, 2430404, 2430404, 2430405, 2430402, 2430404, 2430405, 2430405, 2430403, 2430404, 2430404, 2430405, 2430405, 2430406, 2430404, 2430405, 2430405, 2430406, 2430406, 2430406, 2430406, 2430407, 2430406, 2430407, 2430407, 2430407, 2430408, 2430408, 2430409, 2430410, 2430410, 2430411, 2430411, 2430414, 2430414, 2430415, 2430416, 2430417, 2430417, 2430418, 2430419, 2430420, 2430423, 2430424, 2430427, 2430429, 2430430, 2430431, 2430435, 2430438, 2430439, 2430441, 2430442, 2430443, 2430443, 2430444, 2430444, 2430445, 2430446, 2430446, 2430447, 2430448, 2430448, 2430449, 2430548, 2430549, 2430581, 2430604, 2430710, 2430410, 2430411, 2430411, 2430412, 2430412, 2430413, 2430414, 2430414, 2430415, 2430415, 2430416, 2430416, 2430417, 2430417, 2430418, 2430418, 2430419, 2430419, 2430420, 2430420, 2430421, 2430421, 2430423, 2430424, 2430425, 2430426, 2430426, 2430430, 2430431, 2430432, 2430433, 2430434, 2430435, 2430435, 2430437, 2430437, 2430438, 2430441, 2430442, 2430443, 2430443, 2430444, 2430444, 2430445, 2430445, 2430446, 2430446, 2430447, 2430447, 2430448, 2430448, 2430449, 2430449, 2430549, 2430411, 2430412, 2430412, 2430413, 2430413, 2430414, 2430414, 2430417, 2430418, 2430418, 2430419, 2430420, 2430420, 2430421, 2430422, 2430425, 2430428, 2430430, 2430432, 2430434, 2430440, 2430442, 2430443, 2430444, 2430447, 2430447, 2430449, 2430450, 2430412, 2430414, 2430416, 2430417, 2430418, 2430418, 2430419, 2430420, 2430421, 2430421, 2430434, 2430445, 2430450, 2430413, 2430414, 2430414, 2430415, 2430416, 2430418, 2430421, 2430422, 2430441, 2430443, 2430447, 2430448, 2430449, 2430449, 2430451, 2430417, 2430421, 2430422, 2430428, 2430447, 2430449, 2430451, 2430551, 2430418, 2430423, 2430428, 2430428, 2430435, 2430449, 2430449, 2430420, 2430422, 2430423, 2430450, 2430452, 2430421, 2430424, 2430443, 2430419, 2430420, 2430421, 2430453, 2430422, 2430425, 2430426, 2430420, 2430422, 2430422, 2430424, 2430425, 2430427, 2430437, 2430451, 2430452, 2430454, 2430423, 2430423, 2430426, 2430455, 2430424, 2430440, 2430449, 2430454, 2430423, 2430424, 2430425, 2430426, 2430427, 2430429, 2430436, 2430450, 2430454, 2430455, 2430456, 2430456, 2430556, 2430426, 2430426, 2430427, 2430427, 2430428, 2430442, 2430443, 2430452, 2430454, 2430456, 2430427, 2430427, 2430428, 2430435, 2430451, 2430452, 2430453, 2430456, 2430457, 2430429, 2430430, 2430431, 2430454, 2430456, 2430429, 2430429, 2430431, 2430436, 2430455, 2430458, 2430430, 2430450, 2430454, 2430454, 2430456, 2430430, 2430432, 2430435, 2430445, 2430448, 2430456, 2430459, 2430431, 2430432, 2430432, 2430433, 2430433, 2430434, 2430435, 2430435, 2430437, 2430437, 2430438, 2430439, 2430441, 2430442, 2430443, 2430445, 2430446, 2430447, 2430448, 2430450, 2430451, 2430451, 2430452, 2430452, 2430453, 2430453, 2430454, 2430454, 2430455, 2430455, 2430456, 2430456, 2430457, 2430457, 2430458, 2430458, 2430459, 2430460, 2430433, 2430433, 2430439, 2430451, 2430458, 2430458, 2430460, 2430433, 2430441, 2430455, 2430457, 2430458, 2430459, 2430434, 2430440, 2430441, 2430442, 2430445, 2430447, 2430449, 2430452, 2430456, 2430457, 2430458, 2430460, 2430460, 2430446, 2430452, 2430454, 2430457, 2430446, 2430460, 2430460, 2430444, 2430438, 2430446, 2430458, 2430463, 2430450, 2430456, 2430459, 2430461, 18820849, 2430445, 2430457, 2430462, 2430442, 2430445, 2430453, 2430457, 2430447, 2430450, 2430458, 2430462, 2430458, 2430463, 2430464, 2430463, 2430464, 2430465, 2430466, 2430449, 2430451, 2430455, 2430457, 2430452, 2430452, 2430462, 2430465, 2430466, 2430466, 2430469, 2430452, 2430459, 2430461, 2430464, 2430464, 2430466, 2430467, 2430468, 2430469, 2430469, 2430469, 2430470, 2430454, 2430456, 2430463, 2430466, 2430467, 2430468, 2430471, 2430460, 2430469, 2430471, 2430462, 2430463, 2430465, 2430466, 2430469, 2430470, 2430470, 2430471, 2430472, 2430470, 2430471, 2430468, 2430470, 2430472, 2430472, 2430468, 2430468, 2430469, 2430466, 2430468, 2430471, 2430472, 2430474, 2430465, 2430475, 2430475, 2430466, 2430473, 2430474, 2430475, 2430466, 2430474, 2430475, 2430468, 2430473, 2430474, 2430477, 2430477, 2430478, 2430471, 2430472, 2430475, 2430476, 2430478, 2430478, 2430479, 2430472, 2430476, 2430476, 2430479, 2430479, 2430472, 2430473, 2430477, 2430474, 2430474, 2430475, 2430478, 2430479, 2430473, 2430474, 2430477, 2430477, 2430478, 2430478, 2430479, 2430480, 2430481, 2430475, 2430475, 2430476, 2430477, 2430478, 2430480, 2430477, 2430478, 2430479, 2430479, 2430480, 2430476, 2430477, 2430478, 2430479, 2430480, 2430480, 2430482, 2430482, 2430478, 2430479, 2430480, 2430480, 2430481, 2430481, 2430483, 2430480, 2430480, 2430481, 2430481, 2430482, 2430482, 2430483, 2430479, 2430480, 2430480, 2430481, 2430481, 2430482, 2430483, 2430484, 2430584, 2430480, 2430481, 2430481, 2430482, 2430482, 2430483, 2430484, 2430481, 2430482, 2430482, 2430483, 2430483, 2430484, 2430484, 2430485, 2430482, 2430483, 2430483, 2430484, 2430484, 2430485, 2430483, 2430484, 2430484, 2430485, 2430485, 2430486, 2430484, 2430485, 2430485, 2430486, 2430486, 2430485, 2430486, 2430486, 2430487, 2430586, 2430486, 2430487, 2430487, 2430487, 2430488, 2430488, 2430489, 2430527, 2430529, 2430529, 2430555, 2430587, 2430588, 2430589, 2430589, 2430621, 2430642, 2430712, 2431423, 11359288, 18274293, 25897407, 2430530, 2430589, 2430589, 2430627, 2430629, 2430590, 2430629, 2430629, 2430649, 2430649, 2430655, 2430687, 2430688, 2430689, 2430690, 2430690, 2430692, 2430695, 2430698, 2430699, 2430700, 2430701, 2430701, 2430702, 2430703, 2430704, 2430704, 2430705, 2430706, 2430712, 2430715, 2430717, 2430718, 2430719, 2430720, 2430721, 2430721, 2430764, 2430690, 2430691, 2430694, 2430695, 2430698, 2430699, 2430700, 2430702, 2430704, 2430716, 2430720, 2430721, 2430721, 2430722, 2430699, 2430701, 2430722, 2430700, 2430701, 2430723, 2430724, 2430725, 2430706, 2430726, 2430730, 2430708, 2430709, 2430709, 2430731, 2430709, 2430710, 2430731, 2430732, 2430711, 2430712, 2430712, 2430713, 2430713, 2430714, 2430715, 2430716, 2430722, 2430723, 2430725, 2430726, 2430731, 2430732, 2430732, 2430775, 2430823, 2430712, 2430713, 2430713, 2430733, 2430714, 2430715, 2430732, 2430733, 2430733, 2430734, 2430754, 2430762, 2430825, 2430862, 2430734, 2430734, 2430735, 2430717, 2430735, 2430864, 2430719, 2430735, 2430736, 2430737, 2430736, 2430736, 2430737, 2430737, 2430737, 2430738, 2430743, 2430744, 2430746, 2430747, 2430748, 2430750, 2430750, 2430751, 2430752, 2430752, 2430753, 2430753, 2430754, 2430755, 2430755, 2430756, 2430756, 2430757, 2430758, 2430758, 2430759, 2430759, 2430760, 2430760, 2430761, 2430761, 2430762, 2430762, 2430763, 2430765, 2430765, 2430766, 2430766, 2430767, 2430768, 2430769, 2430770, 2430770, 2430771, 2430771, 2430772, 2430773, 2430773, 2430774, 2430775, 2430775, 2430776, 2430776, 2430777, 2430777, 2430778, 2430778, 2430779, 2430779, 2430780, 2430780, 2430781, 2430781, 2430782, 2430782, 2430784, 2430787, 2430789, 2430790, 2430791, 2430792, 2430795, 2430795, 2430796, 2430797, 2430755, 2430756, 2430756, 2430757, 2430758, 2430758, 2430759, 2430759, 2430763, 2430766, 2430766, 2430767, 2430770, 2430770, 2430771, 2430771, 2430772, 2430772, 2430774, 2430775, 2430777, 2430780, 2430781, 2430797, 2430797, 2430757, 2430757, 2430758, 2430771, 2430771, 2430773, 2430757, 2430758, 2430760, 2430772, 2430773, 2430776, 2430780, 2430798, 2430758, 2430760, 2430764, 2430765, 2430767, 2430770, 2430771, 2430772, 2430773, 2430774, 2430777, 2430782, 2430759, 2430768, 2430772, 2430772, 2430773, 2430773, 2430774, 2430774, 2430775, 2430763, 2430774, 2430774, 2430775, 2430775, 2430775, 2430776, 2430779, 2430781, 2430783, 2430764, 2430771, 2430774, 2430775, 2430775, 2430776, 2430776, 2430777, 2430779, 2430780, 2430802, 2430767, 2430770, 2430775, 2430776, 2430776, 2430777, 2430777, 2430775, 2430772, 2430778, 2430778, 2430779, 2430782, 2430778, 2430787, 2430788, 2430797, 2430778, 2430779, 2430779, 2430805, 2430778, 2430779, 2430781, 2430782, 2430781, 2430782, 2430783, 2430788, 2430782, 2430783, 2430785, 2430792, 2430783, 2430784, 2430788, 2430781, 2430783, 2430784, 2430807, 2430785, 2430785, 2430786, 2430789, 2430806, 2430785, 2430786, 2430786, 2430787, 2430787, 2430790, 2430792, 2430792, 2430795, 2430808, 2430812, 2430897, 2430786, 2430787, 2430787, 2430788, 2430790, 2430794, 2430798, 2430806, 2430787, 2430788, 2430788, 2430790, 2430790, 2430791, 2430792, 2430796, 2430803, 2430808, 2430813, 2430788, 2430789, 2430790, 2430791, 2430791, 2430792, 2430793, 2430793, 2430796, 2430797, 2430798, 2430798, 2430807, 2430809, 2430812, 2430813, 2430814, 2430789, 2430790, 2430791, 2430791, 2430792, 2430792, 2430793, 2430794, 2430794, 2430795, 2430796, 2430797, 2430798, 2430814, 2430790, 2430791, 2430791, 2430792, 2430792, 2430793, 2430793, 2430794, 2430794, 2430795, 2430795, 2430796, 2430796, 2430797, 2430797, 2430798, 2430798, 2430799, 2430799, 2430800, 2430802, 2430803, 2430805, 2430807, 2430809, 2430810, 2430811, 2430812, 2430812, 2430813, 2430813, 2430814, 2430815, 2430791, 2430792, 2430799, 2430792, 2430793, 2430794, 2430797, 2430798, 2430800, 2430811, 2430816, 2430794, 2430794, 2430795, 2430796, 2430797, 2430797, 2430798, 2430799, 2430799, 2430800, 2430812, 2430814, 2430816, 2430902, 2430794, 2430795, 2430795, 2430796, 2430796, 2430797, 2430797, 2430799, 2430799, 2430800, 2430800, 2430801, 2430801, 2430810, 2430810, 2430811, 2430811, 2430815, 2430816, 2430816, 2430817, 2430795, 2430796, 2430796, 2430797, 2430797, 2430798, 2430798, 2430799, 2430799, 2430800, 2430801, 2430810, 2430815, 2430817, 2430817, 2430796, 2430797, 2430797, 2430798, 2430798, 2430799, 2430799, 2430800, 2430800, 2430801, 2430801, 2430802, 2430803, 2430810, 2430811, 2430812, 2430816, 2430817, 2430818, 2430798, 2430798, 2430799, 2430800, 2430802, 2430818, 2430798, 2430799, 2430799, 2430801, 2430801, 2430802, 2430802, 2430803, 2430812, 2430812, 2430813, 2430813, 2430819, 2430799, 2430800, 2430800, 2430801, 2430801, 2430802, 2430803, 2430804, 2430804, 2430805, 2430810, 2430813, 2430814, 2430815, 2430815, 2430819, 2430819, 2430800, 2430801, 2430801, 2430802, 2430802, 2430803, 2430803, 2430804, 2430804, 2430805, 2430809, 2430813, 2430814, 2430815, 2430817, 2430818, 2430819, 2430819, 2430820, 2430801, 2430802, 2430802, 2430803, 2430803, 2430804, 2430804, 2430814, 2430815, 2430816, 2430818, 2430820, 2430820, 2430802, 2430803, 2430803, 2430804, 2430804, 2430805, 2430807, 2430807, 2430808, 2430809, 2430812, 2430814, 2430815, 2430816, 2430818, 2430819, 2430820, 2430821, 2430803, 2430804, 2430804, 2430805, 2430817, 2430821, 2430821, 2430804, 2430805, 2430805, 2430806, 2430807, 2430808, 2430813, 2430813, 2430818, 2430819, 2430821, 2430822, 2430870, 2430805, 2430806, 2430806, 2430807, 2430807, 2430808, 2430808, 2430809, 2430809, 2430810, 2430811, 2430811, 2430813, 2430814, 2430815, 2430815, 2430816, 2430816, 2430817, 2430817, 2430818, 2430820, 2430821, 2430822, 2430822, 2430806, 2430807, 2430807, 2430808, 2430809, 2430812, 2430814, 2430815, 2430816, 2430817, 2430821, 2430823, 2430807, 2430808, 2430808, 2430809, 2430811, 2430811, 2430812, 2430812, 2430814, 2430814, 2430815, 2430817, 2430818, 2430819, 2430820, 2430821, 2430821, 2430822, 2430822, 2430823, 2430808, 2430809, 2430809, 2430810, 2430811, 2430812, 2430812, 2430816, 2430816, 2430818, 2430820, 2430823, 2430824, 2430809, 2430813, 2430817, 2430817, 2430819, 2430821, 2430822, 2430822, 2430823, 2430824, 2430824, 2430811, 2430812, 2430813, 2430818, 2430819, 2430819, 2430820, 2430822, 2430823, 2430823, 2430825, 2430825, 2430817, 2430820, 2430824, 2430825, 2430821, 2430826, 2430813, 2430814, 2430826, 2430826, 2430821, 2430822, 2430825, 2430827, 2430815, 2430821, 2430820, 2430821, 2430825, 2430827, 2430828, 2430820, 2430820, 2430821, 2430826, 2430828, 2430828, 2430821, 2430828, 2430829, 2430823, 2430829, 2430823, 2430830, 2430830, 2430823, 2430824, 2430824, 2430826, 2430827, 2430828, 2430830, 2430831, 2430826, 2430827, 2430831, 2430831, 2430826, 2430830, 2430832, 2430825, 2430826, 2430827, 2430830, 2430830, 2430832, 2430826, 2430827, 2430828, 2430829, 2430831, 2430832, 2430833, 2430827, 2430829, 2430829, 2430832, 2430833, 2430834, 2430828, 2430829, 2430829, 2430830, 2430831, 2430831, 2430832, 2430833, 2430833, 2430834, 2430832, 2430832, 2430834, 2430834, 2430834, 2430835, 2430831, 2430833, 2430835, 2430835, 2430833, 2430834, 2430835, 2430836, 2430834, 2430836, 2430836, 2430834, 2430837, 2430835, 2430836, 2430837, 2430837, 2430836, 2430837, 2430838, 2430838, 2430838, 2430838, 2430839, 2430839, 2430840, 2430841, 2430841, 2430842, 2430842, 2430843, 2430843, 2430844, 2430844, 2430845, 2430845, 2430847, 2430848, 2430849, 2430850, 2430852, 2430854, 2430854, 2430855, 2430855, 2430856, 2430857, 2430857, 2430858, 2430859, 2430859, 2430860, 2430861, 2430861, 2430862, 2430863, 2430865, 2430865, 2430866, 2430867, 2430868, 2430868, 2430869, 2430869, 2430870, 2430870, 2430871, 2430871, 2430872, 2430872, 2430888, 2430925, 2430940, 2430841, 2430842, 2430842, 2430843, 2430843, 2430844, 2430844, 2430845, 2430845, 2430846, 2430848, 2430848, 2430849, 2430849, 2430853, 2430854, 2430855, 2430855, 2430856, 2430857, 2430859, 2430860, 2430860, 2430861, 2430862, 2430863, 2430864, 2430865, 2430866, 2430867, 2430868, 2430868, 2430869, 2430869, 2430870, 2430870, 2430871, 2430871, 2430872, 2430872, 2430873, 2430888, 2430926, 2430842, 2430843, 2430844, 2430844, 2430845, 2430849, 2430850, 2430851, 2430856, 2430858, 2430860, 2430862, 2430862, 2430868, 2430872, 2430873, 2430889, 2430843, 2430844, 2430853, 2430872, 2430874, 2430844, 2430846, 2430857, 2430873, 2430845, 2430846, 2430846, 2430850, 2430852, 2430853, 2430854, 2430857, 2430859, 2430859, 2430867, 2430870, 2430872, 2430873, 2430874, 2430874, 2430875, 2430846, 2430849, 2430852, 2430868, 2430871, 2430872, 2430875, 2430875, 2430847, 2430849, 2430850, 2430852, 2430857, 2430859, 2430870, 2430872, 2430875, 2430876, 2430852, 2430853, 2430853, 2430858, 2430861, 2430863, 2430864, 2430869, 2430871, 2430872, 2430873, 2430875, 2430876, 2430876, 2430876, 2430877, 2430859, 2430877, 2430860, 2430865, 2430867, 2430878, 2430879, 2430861, 2430879, 2430880, 2430860, 2430862, 2430862, 2430863, 2430864, 2430867, 2430870, 2430876, 2430879, 2430880, 14033387, 2430861, 2430859, 2430866, 2430870, 2430874, 2430876, 2430876, 2430878, 2430881, 2430866, 2430864, 2430880, 2430879, 2430883, 2430865, 2430871, 2430873, 2430879, 2430880, 2430882, 2430884, 2430884, 2430885, 2430869, 2430870, 2430871, 2430875, 2430878, 2430879, 2430881, 2430881, 2430882, 2430883, 2430884, 2430885, 2430886, 2430869, 2430872, 2430878, 2430886, 2430886, 2430887, 2430871, 2430871, 2430873, 2430874, 2430874, 2430876, 2430876, 2430877, 2430880, 2430883, 2430886, 2430887, 2430887, 2430888, 2430875, 2430877, 2430878, 2430883, 2430885, 2430887, 2430888, 2430878, 2430881, 2430883, 2430886, 2430886, 2430887, 2430888, 2430889, 2430877, 2430878, 2430889, 2430889, 2430882, 2430886, 2430890, 2430886, 2430879, 2430891, 2430882, 2430883, 2430884, 2430884, 2430886, 2430886, 2430890, 2430892, 2430881, 2430887, 2430889, 2430892, 2430892, 2430888, 2430889, 2430889, 2430890, 2430892, 2430893, 2430893, 2430946, 2430883, 2430885, 2430891, 2430893, 2430894, 2430889, 2430893, 2430894, 2430894, 2430895, 2430894, 2430895, 2430895, 2430896, 2430896, 2430892, 2430895, 2430890, 2430892, 2430893, 2430894, 2430895, 2430895, 2430896, 2430897, 2430897, 2430895, 2430897, 2430898, 2430895, 2430898, 2430899, 2430894, 2430896, 2430898, 2430899, 2430895, 2430896, 2430896, 2430897, 2430897, 2430898, 2430899, 2430899, 2430900, 2430898, 2430900, 2430900, 2430897, 2430900, 2430900, 2430901, 2430899, 2430900, 2430901, 2430901, 2430899, 2430900, 2430901, 2430902, 2430900, 2430901, 2430902, 2430901, 2430902, 2430902, 2430903, 2430902, 2430903, 2430903, 2430903, 2430904, 2430904, 2430905, 2430906, 2430918, 2430920, 2430920, 2430958, 2430972, 2431023, 2431631, 18274501, 2430920, 2430921, 2430921, 2430934, 2430935, 2430936, 2430937, 2430937, 2430938, 2430938, 2430939, 2430939, 2430942, 2430942, 2430943, 2430944, 2430951, 2430952, 2430953, 2430954, 2430956, 2430957, 2430958, 2430961, 2430962, 2430964, 2430967, 2430968, 2430969, 2430970, 2430971, 2430971, 2430972, 2430972, 2430973, 2430973, 2431011, 2430937, 2430939, 2430943, 2430954, 2430959, 2430962, 2430972, 2430973, 2430973, 2430974, 2430942, 2430974, 2430974, 2430974, 2430967, 2430942, 2430976, 2430976, 2430977, 2430978, 2430977, 2430979, 2430980, 2430980, 2430968, 2430989, 2430979, 2430990, 2430990, 2430991, 2430991, 2430993, 2430994, 2430994, 2430995, 2430998, 2430999, 2430998, 2430999, 2431001, 2431001, 2431004, 2431005, 2431006, 2431007, 2431008, 2431007, 2431008, 2431008, 2431008, 2431009, 2431008, 2431009, 2431009, 2431009, 2431010, 2431010, 2431011, 2431012, 2431012, 2431013, 2431013, 2431014, 2431014, 2431015, 2431015, 2431016, 2431016, 2431017, 2431017, 2431018, 2431018, 2431019, 2431020, 2431020, 2431021, 2431021, 2431022, 2431022, 2431023, 2431024, 2431024, 2431025, 2431025, 2431026, 2431026, 2431027, 2431027, 2431028, 2431028, 2431029, 2431030, 2431031, 2431031, 2431032, 2431032, 2431033, 2431035, 2431035, 2431036, 2431037, 2431038, 2431038, 2431042, 2431049, 2431012, 2431013, 2431013, 2431014, 2431014, 2431015, 2431015, 2431016, 2431016, 2431017, 2431017, 2431018, 2431018, 2431019, 2431019, 2431021, 2431022, 2431022, 2431023, 2431023, 2431024, 2431025, 2431025, 2431026, 2431027, 2431029, 2431031, 2431035, 2431036, 2431047, 2431049, 2431049, 2431013, 2431014, 2431014, 2431015, 2431016, 2431017, 2431018, 2431019, 2431019, 2431022, 2431022, 2431023, 2431024, 2431026, 2431031, 2431050, 2431014, 2431015, 2431016, 2431017, 2431017, 2431019, 2431020, 2431021, 2431023, 2431024, 2431025, 2431026, 2431036, 2431017, 2431017, 2431018, 2431020, 2431021, 2431024, 2431025, 2431027, 2431018, 2431020, 2431020, 2431021, 2431024, 2431025, 2431026, 2431028, 2431018, 2431019, 2431021, 2431022, 2431025, 2431026, 2431028, 2431021, 2431026, 2431028, 2431030, 2431020, 2431022, 2431024, 2431026, 2431026, 2431027, 2431029, 2431029, 2431020, 2431021, 2431022, 2431023, 2431025, 2431025, 2431026, 2431027, 2431028, 2431029, 2431030, 2431033, 2431053, 2431021, 2431022, 2431022, 2431023, 2431023, 2431024, 2431025, 2431026, 2431026, 2431027, 2431027, 2431028, 2431029, 2431030, 2431030, 2431023, 2431027, 2431029, 2431030, 2431042, 2431024, 2431025, 2431026, 2431028, 2431029, 2431032, 2431025, 2431025, 2431027, 2431028, 2431029, 2431030, 2431031, 2431032, 2431033, 2431033, 2431025, 2431026, 2431026, 2431027, 2431029, 2431029, 2431030, 2431031, 2431032, 2431033, 2431036, 2431038, 2431028, 2431029, 2431029, 2431030, 2431031, 2431032, 2431032, 2431033, 2431034, 2431036, 2431038, 2431043, 2431056, 2431028, 2431029, 2431030, 2431031, 2431032, 2431033, 2431033, 2431034, 2431032, 2431032, 2431033, 2431038, 2431040, 2431032, 2431033, 2431040, 2431032, 2431032, 2431033, 2431033, 2431034, 2431032, 2431033, 2431034, 2431035, 2431035, 2431038, 2431033, 2431034, 2431035, 2431036, 2431036, 2431037, 2431034, 2431035, 2431036, 2431036, 2431037, 2431037, 2431038, 2431038, 2431039, 2431040, 2431040, 2431043, 2431046, 2431047, 2431048, 2431060, 2431035, 2431037, 2431036, 2431037, 2431037, 2431038, 2431038, 2431039, 2431039, 2431041, 2431041, 2431042, 2431043, 2431043, 2431044, 2431046, 2431047, 2431048, 2431049, 2431050, 2431051, 2431052, 2431053, 2431061, 2431061, 2431037, 2431038, 2431038, 2431041, 2431038, 2431039, 2431039, 2431040, 2431040, 2431042, 2431042, 2431044, 2431048, 2431048, 2431049, 2431052, 2431039, 2431040, 2431040, 2431041, 2431042, 2431043, 2431044, 2431044, 2431045, 2431045, 2431046, 2431047, 2431048, 2431049, 2431049, 2431050, 2431051, 2431051, 2431053, 2431055, 2431056, 2431058, 2431059, 2431061, 2431062, 2431063, 2431040, 2431041, 2431041, 2431042, 2431042, 2431043, 2431043, 2431045, 2431046, 2431046, 2431047, 2431048, 2431049, 2431049, 2431050, 2431051, 2431051, 2431063, 2431041, 2431042, 2431043, 2431045, 2431046, 2431048, 2431049, 2431050, 2431050, 2431051, 2431052, 2431055, 2431042, 2431043, 2431044, 2431044, 2431045, 2431045, 2431046, 2431046, 2431047, 2431047, 2431049, 2431049, 2431050, 2431050, 2431051, 2431052, 2431052, 2431053, 2431057, 2431060, 2431043, 2431044, 2431044, 2431045, 2431046, 2431046, 2431047, 2431047, 2431048, 2431048, 2431049, 2431050, 2431050, 2431051, 2431051, 2431052, 2431053, 2431054, 2431054, 2431055, 2431057, 2431058, 2431061, 2431063, 2431063, 2431065, 2431045, 2431047, 2431051, 2431065, 2431045, 2431046, 2431048, 2431049, 2431054, 2431056, 2431046, 2431047, 2431048, 2431048, 2431049, 2431049, 2431050, 2431051, 2431051, 2431052, 2431052, 2431053, 2431054, 2431054, 2431059, 2431064, 2431066, 2431047, 2431048, 2431048, 2431049, 2431049, 2431050, 2431050, 2431051, 2431051, 2431052, 2431053, 2431053, 2431054, 2431055, 2431056, 2431060, 2431061, 2431065, 2431066, 2431067, 2431049, 2431049, 2431054, 2431049, 2431050, 2431051, 2431054, 2431054, 2431055, 2431061, 2431068, 2431050, 2431051, 2431051, 2431052, 2431054, 2431055, 2431056, 2431057, 2431057, 2431061, 2431068, 2431051, 2431052, 2431052, 2431053, 2431053, 2431054, 2431054, 2431055, 2431055, 2431056, 2431056, 2431057, 2431059, 2431061, 2431062, 2431063, 2431067, 2431069, 2431052, 2431053, 2431053, 2431055, 2431056, 2431057, 2431058, 2431059, 2431060, 2431062, 2431064, 2431067, 2431069, 2431053, 2431054, 2431055, 2431056, 2431056, 2431058, 2431058, 2431060, 2431063, 2431067, 2431069, 2431070, 2431054, 2431056, 2431056, 2431057, 2431058, 2431058, 2431059, 2431070, 2431056, 2431057, 2431057, 2431057, 2431057, 2431058, 2431060, 2431066, 2431072, 2431058, 2431059, 2431065, 2431059, 2431060, 2431060, 2431061, 2431061, 2431062, 2431062, 2431063, 2431063, 2431064, 2431065, 2431066, 2431067, 2431068, 2431069, 2431071, 2431072, 2431073, 2431099, 2431060, 2431061, 2431061, 2431062, 2431062, 2431063, 2431063, 2431064, 2431064, 2431065, 2431066, 2431066, 2431068, 2431068, 2431069, 2431069, 2431070, 2431072, 2431073, 2431073, 2431061, 2431063, 2431067, 2431062, 2431063, 2431063, 2431064, 2431064, 2431065, 2431067, 2431067, 2431069, 2431070, 2431071, 2431072, 2431072, 2431073, 2431074, 2431074, 2431063, 2431064, 2431064, 2431065, 2431065, 2431066, 2431066, 2431067, 2431067, 2431068, 2431069, 2431070, 2431072, 2431072, 2431073, 2431073, 2431074, 2431075, 2431064, 2431065, 2431065, 2431066, 2431066, 2431068, 2431069, 2431070, 2431071, 2431073, 2431073, 2431074, 2431075, 2431075, 2431065, 2431066, 2431066, 2431067, 2431067, 2431068, 2431069, 2431070, 2431071, 2431071, 2431072, 2431072, 2431073, 2431074, 2431074, 2431075, 2431076, 2431066, 2431067, 2431067, 2431069, 2431070, 2431071, 2431072, 2431073, 2431073, 2431074, 2431074, 2431075, 2431075, 2431076, 2431076, 2431067, 2431068, 2431068, 2431069, 2431071, 2431072, 2431073, 2431073, 2431074, 2431074, 2431075, 2431075, 2431076, 2431076, 2431077, 2431068, 2431069, 2431069, 2431070, 2431070, 2431071, 2431072, 2431073, 2431074, 2431075, 2431075, 2431076, 2431077, 2431077, 2431069, 2431070, 2431071, 2431071, 2431072, 2431073, 2431074, 2431074, 2431075, 2431076, 2431077, 2431077, 2431078, 2431071, 2431071, 2431075, 2431076, 2431076, 2431077, 2431078, 2431078, 2431072, 2431073, 2431074, 2431077, 2431078, 2431079, 2431072, 2431073, 2431074, 2431076, 2431077, 2431077, 2431079, 2431074, 2431074, 2431075, 2431075, 2431076, 2431077, 2431078, 2431078, 2431079, 2431080, 2431076, 2431076, 2431076, 2431077, 2431079, 2431079, 2431080, 2431080, 2431081, 2431078, 2431078, 2431079, 2431080, 2431080, 2431081, 2431081, 2431078, 2431078, 2431079, 2431081, 2431082, 2431078, 2431080, 2431082, 2431082, 2431079, 2431080, 2431081, 2431082, 2431083, 2431080, 2431081, 2431081, 2431082, 2431083, 2431083, 2431081, 2431082, 2431083, 2431084, 2431082, 2431083, 2431084, 2431084, 2431083, 2431084, 2431084, 2431085, 2431085, 2431085, 2431085, 2431086, 2431086, 2431087, 2431088, 2431088, 2431089, 2431089, 2431091, 2431091, 2431092, 2431092, 2431093, 2431093, 2431094, 2431095, 2431096, 2431096, 2431097, 2431099, 2431101, 2431102, 2431104, 2431108, 2431110, 2431112, 2431113, 2431114, 2431115, 2431115, 2431116, 2431117, 2431118, 2431119, 2431120, 2431121, 2431122, 2431123, 2431123, 2431124, 2431124, 2431722, 2433271, 3758471, 2431088, 2431089, 2431089, 2431090, 2431090, 2431091, 2431091, 2431092, 2431092, 2431093, 2431093, 2431094, 2431094, 2431095, 2431095, 2431096, 2431096, 2431097, 2431097, 2431098, 2431099, 2431100, 2431101, 2431103, 2431105, 2431105, 2431108, 2431108, 2431109, 2431110, 2431110, 2431113, 2431114, 2431114, 2431115, 2431115, 2431116, 2431117, 2431119, 2431120, 2431120, 2431121, 2431121, 2431122, 2431123, 2431123, 2431124, 2431124, 2431125, 2431089, 2431090, 2431090, 2431092, 2431093, 2431094, 2431095, 2431095, 2431096, 2431097, 2431097, 2431099, 2431101, 2431102, 2431108, 2431110, 2431112, 2431115, 2431116, 2431120, 2431121, 2431124, 2431125, 2431125, 2431090, 2431091, 2431092, 2431094, 2431097, 2431097, 2431115, 2431124, 2431126, 2431091, 2431093, 2431093, 2431094, 2431098, 2431099, 2431100, 2431101, 2431106, 2431106, 2431110, 2431126, 2431126, 2431092, 2431093, 2431098, 2431107, 2431117, 2431118, 2431126, 2431126, 2431127, 2431094, 2431096, 2431097, 2431098, 2431099, 2431121, 2431124, 2431094, 2431127, 2431127, 2431128, 2431095, 2431096, 2431097, 2431098, 2431098, 2431099, 2431100, 2431101, 2431104, 2431112, 2431122, 2431122, 2431126, 2431127, 2431128, 2431128, 2431097, 2431098, 2431100, 2431100, 2431106, 2431109, 2431119, 2431128, 2431129, 2431108, 2431129, 2431098, 2431099, 2431100, 2431101, 2431102, 2431107, 2431108, 2431119, 2431120, 2431122, 2431125, 2431126, 2431127, 2431129, 2431129, 2431130, 2431101, 2431101, 2431102, 2431110, 2431117, 2431130, 2431130, 2431102, 2431130, 2431131, 2431103, 2431115, 2431122, 2431123, 2431126, 2431129, 2431130, 2431131, 2431131, 2431103, 2431106, 2431109, 2431112, 2431124, 2431131, 2431103, 2431104, 2431119, 2431104, 2431105, 2431106, 2431107, 2431109, 2431128, 2431132, 2431133, 2431105, 2431106, 2431106, 2431107, 2431108, 2431109, 2431110, 2431114, 2431117, 2431118, 2431118, 2431122, 2431123, 2431124, 2431125, 2431126, 2431127, 2431128, 2431130, 2431131, 2431132, 2431132, 2431133, 2431133, 2431107, 2431120, 2431122, 2431124, 2431126, 2431132, 2431133, 2431133, 2431134, 2431116, 2431118, 2431125, 2431132, 2431134, 2431113, 2431118, 2431119, 2431127, 2431127, 2431132, 2431134, 2431120, 2431132, 2431135, 2431132, 2431112, 2431114, 2431125, 2431125, 2431127, 2431128, 2431129, 2431131, 2431133, 2431135, 2431114, 2431125, 2431126, 2431127, 2431128, 2431131, 2431132, 2431137, 2431127, 2431130, 2431132, 2431133, 2431133, 2431137, 2431138, 2431138, 2431119, 2431129, 2431136, 2431136, 2431119, 2431139, 2431132, 2431136, 2431140, 2431129, 2431132, 2431140, 2431134, 2431135, 2431137, 2431138, 2431141, 2431133, 2431140, 2431141, 2431132, 2431143, 2431144, 2431145, 2431143, 2431145, 2431138, 2431145, 2431145, 2431146, 2431138, 2431132, 2431141, 2431147, 2431135, 2431147, 2431147, 2431139, 2431139, 2431140, 2431149, 2431144, 2431147, 2431140, 2431148, 2431149, 2431149, 2431143, 2431149, 2431141, 2431143, 2431145, 2431151, 2431142, 2431143, 2431150, 2431151, 2431142, 2431144, 2431147, 2431152, 2431143, 2431144, 2431144, 2431145, 2431147, 2431149, 2431150, 2431151, 2431151, 2431152, 2431152, 2431153, 2431152, 2431153, 2431153, 2431147, 2431148, 2431149, 2431150, 2431151, 2431152, 2431152, 2431153, 2431153, 2431154, 2431752, 2431152, 2431153, 2431153, 2431154, 2431154, 2431150, 2431155, 2431150, 2431153, 2431154, 2431155, 2431155, 2431153, 2431156, 2431151, 2431156, 2431156, 2431153, 2431154, 2431154, 2431155, 2431155, 2431156, 2431157, 2431153, 2431155, 2431156, 2431157, 2431155, 2431157, 2431158, 2431156, 2431157, 2431158, 2431158, 2431157, 2431158, 2431158, 2431159, 2431157, 2431158, 2431159, 2431159, 2431158, 2431159, 2431159, 2431160, 2431159, 2431160, 2431160, 2431160, 2431161, 2431161, 2431162, 2431163, 2431169, 2431224, 2431759, 2431760, 2431760, 2431780, 2431783, 2431810, 2431811, 2433308, 2433309, 2433358, 2433360, 3758505, 3758513, 4717461, 4717462, 6272435, 6763064, 8230377, 11359602, 11359625, 13930140, 25897743, 2431163, 2431760, 2431780, 2431781, 2433309, 2433330, 2433358, 3115667, 2431761, 2431781, 2431784, 2433309, 2433310, 2433359, 2433360, 3758512, 4717463, 4968789, 7930601, 2431252, 2431301, 2431359, 2431837, 2431843, 2431894, 2432357, 2432358, 2432359, 2432359, 2432360, 2432361, 2432364, 2432367, 2432368, 2432373, 2432377, 2432377, 2432378, 2432378, 2432359, 2432360, 2432361, 2432378, 2432378, 2432379, 2432365, 2432379, 2432380, 2432362, 2432364, 2432381, 2432380, 2432381, 2432382, 2432384, 2432385, 2432377, 2432378, 2432388, 2432379, 2432387, 2433918, 2432394, 2432397, 2432397, 2432398, 2432453, 2432398, 2432454, 2432399, 2432400, 2432400, 2432401, 2432401, 2432403, 2432403, 2432406, 2432408, 2432408, 2432409, 2432411, 2432412, 2432414, 2432414, 2432415, 2432415, 2432416, 2432417, 2432417, 2432418, 2432419, 2432420, 2432420, 2432421, 2432421, 2432422, 2432423, 2432423, 2432424, 2432424, 2432425, 2432425, 2432426, 2432427, 2432427, 2432428, 2432428, 2432429, 2432430, 2432430, 2432431, 2432432, 2432435, 2432436, 2432436, 2432437, 2432438, 2432439, 2432441, 2432442, 2432443, 2432444, 2432445, 2432445, 2432446, 2432446, 2432447, 2432447, 2432448, 2432449, 2432450, 2432451, 2432452, 2432452, 2432453, 2432453, 2432454, 2432454, 2432401, 2432402, 2432414, 2432415, 2432419, 2432422, 2432425, 2432429, 2432439, 2432441, 2432445, 2432454, 2432454, 2432430, 2432403, 2432419, 2432421, 2432447, 2432405, 2432405, 2432413, 2432423, 2432427, 2432429, 2432430, 2432456, 2432442, 2432410, 2432424, 2432443, 2432457, 2432456, 2432430, 2432435, 2432452, 2432438, 2432448, 2432448, 2432426, 2432449, 2432461, 2432433, 2432435, 2432454, 2432465, 2432469, 2432454, 2432436, 2432447, 2432438, 2432471, 2432471, 2432467, 2432437, 2432440, 2432441, 2432442, 2432443, 2432445, 2432448, 2432457, 2432472, 2432473, 2432444, 2432452, 2432465, 2432474, 2432452, 2432453, 2432453, 2432444, 2432449, 2432450, 2432455, 2432475, 2433949, 2432476, 2432445, 2432446, 2432450, 2432451, 2432453, 2432454, 2432455, 2432476, 2433950, 2433999, 2432447, 2432451, 2432452, 2432453, 2432455, 2432474, 2432477, 2432448, 2432448, 2432451, 2432452, 2432454, 2432456, 2432475, 2432478, 2433951, 2432452, 2432453, 2432455, 2432458, 2432476, 2432478, 2433952, 2432451, 2432453, 2432479, 2433952, 2432450, 2432453, 2432454, 2432455, 2432457, 2432464, 2432474, 2432477, 2432479, 2433952, 2433953, 2432453, 2432461, 2433953, 2432455, 2432455, 2432456, 2433955, 2432461, 2432466, 2432474, 2432475, 2432477, 2432456, 2432457, 2432459, 2432459, 2432461, 2432464, 2432465, 2432466, 2432467, 2432470, 2432471, 2432472, 2432477, 2432482, 2432457, 2432483, 2432459, 2432459, 2432460, 2432461, 2432462, 2432464, 2432465, 2432466, 2432468, 2432469, 2432474, 2432475, 2432476, 2432478, 2432478, 2432480, 2432481, 2432483, 2432483, 2432462, 2432465, 2432472, 2432474, 2432484, 2432461, 2432462, 2432466, 2432474, 2432475, 2432477, 2432482, 2432485, 2432464, 2432465, 2432468, 2432470, 2432474, 2432485, 2432486, 2433959, 2432479, 2432486, 2432475, 2432476, 2432484, 2432486, 2432487, 2432480, 2432487, 2432472, 2432488, 2432489, 2432471, 2432490, 2433963, 2432482, 2432490, 2432473, 2432491, 2432477, 2432478, 2432491, 2433965, 2432492, 2432477, 2432490, 2432493, 2432493, 2432479, 2432480, 2432483, 2432484, 2432484, 2432487, 2432487, 2432489, 2432494, 2432486, 2432487, 2432490, 2432494, 2432492, 2432489, 2432495, 2432496, 2432491, 2432497, 2432493, 2432495, 2432497, 2432498, 2432490, 2432497, 2432499, 2432494, 2432496, 2432497, 2432499, 2432499, 2432499, 2432500, 2432497, 2432499, 2432500, 2432494, 2432496, 2432501, 2432501, 2433975, 2432497, 2432498, 2432502, 2432502, 2432503, 2433977, 2432499, 2432501, 2432501, 2432504, 2432503, 2432504, 2432504, 2432504, 2432505, 2433979, 2432503, 2432506, 2432505, 2432506, 2432506, 2432507, 2432507, 2432508, 2432508, 2432509, 2432510, 2432511, 2432513, 2432514, 2432517, 2432520, 2432522, 2432525, 2432525, 2432526, 2432526, 2432527, 2432527, 2432528, 2432529, 2432529, 2433982, 2433982, 2434031, 2434036, 2432510, 2432511, 2432514, 2432514, 2432515, 2432524, 2432526, 2432528, 2432528, 2432529, 2432530, 2432527, 2432528, 2432530, 2432523, 2432531, 2432533, 2432531, 2432533, 2432534, 2432532, 2432538, 2432541, 2432541, 2432542, 2432544, 2432545, 2432546, 2432546, 2432546, 2432547, 2432547, 2432548, 2432548, 2432549, 2432549, 2432550, 2434002, 2434003, 2434003, 2434023, 2434052, 2434056, 2434056, 3524040, 3759199, 3759202, 3759202, 4969481, 4969489, 8543676, 10473581, 14034234, 25898437, 2434003, 2434003, 2435455, 2435456, 2435457, 2435457, 2435458, 2435458, 2435459, 2435461, 2435462, 2435467, 2435467, 2435487, 2435490, 2435491, 2435492, 2435494, 2435497, 2435498, 2435502, 2435502, 2435503, 2435503, 2435504, 2435504, 2435505, 2435508, 2435458, 2435459, 2435489, 2435502, 2435504, 2435504, 2435505, 2435505, 2435459, 2435468, 2435505, 2435506, 2435460, 2435461, 2435462, 2435504, 2435506, 2435507, 2435461, 2435462, 2435465, 2435469, 2435481, 2435484, 2435496, 2435496, 2435505, 2435506, 2435506, 2435507, 2435507, 2435507, 2435508, 2435508, 2435509, 2435509, 2435510, 2435511, 2435515, 2435516, 3760662, 2435516, 2435525, 2435527, 2435531, 2435536, 2435535, 2435539, 2435532, 2435540, 2435540, 2435541, 2435542, 2435542, 2435543, 2435545, 2435546, 2435544, 2435550, 2435551, 2435551, 2435551, 2435551, 2435551, 2435552, 2435552, 2435552, 2435553, 2435553, 2435554, 2435555, 2435555, 2435556, 2435556, 2435557, 2435557, 2435558, 2435558, 2435559, 2435559, 2435560, 2435560, 2435561, 2435563, 2435564, 2435567, 2435567, 2435570, 2435571, 2435572, 2435572, 2435573, 2435573, 2435574, 2435575, 2435575, 2435577, 2435577, 2435578, 2435578, 2435579, 2435580, 2435580, 2435581, 2435555, 2435556, 2435556, 2435557, 2435558, 2435559, 2435560, 2435560, 2435561, 2435562, 2435567, 2435575, 2435576, 2435577, 2435578, 2435580, 2435581, 2435556, 2435558, 2435559, 2435559, 2435581, 2435557, 2435558, 2435559, 2435559, 2435560, 2435561, 2435561, 2435562, 2435567, 2435571, 2435573, 2435576, 2435576, 2435578, 2435578, 2435579, 2435580, 2435581, 2435581, 2435582, 2435558, 2435559, 2435560, 2435562, 2435563, 2435569, 2435573, 2435582, 2435582, 2435560, 2435560, 2435561, 2435561, 2435562, 2435562, 2435563, 2435564, 2435566, 2435567, 2435568, 2435577, 2435580, 2435580, 2435582, 2435582, 2435583, 2435566, 2435561, 2435562, 2435563, 2435564, 2435565, 2435566, 2435567, 2435568, 2435572, 2435576, 2435578, 2435578, 2435580, 2435581, 2435583, 2435583, 2435584, 2435562, 2435563, 2435564, 2435564, 2435565, 2435566, 2435568, 2435571, 2435578, 2435579, 2435579, 2435580, 2435583, 2435583, 2435584, 2435584, 2435585, 2435563, 2435564, 2435564, 2435565, 2435565, 2435567, 2435569, 2435570, 2435571, 2435572, 2435574, 2435575, 2435576, 2435576, 2435577, 2435579, 2435579, 2435580, 2435581, 2435582, 2435582, 2435584, 2435584, 2435585, 2435564, 2435565, 2435565, 2435583, 2435585, 2435566, 2435566, 2435569, 2435572, 2435573, 2435577, 2435579, 2435580, 2435580, 2435582, 2435583, 2435585, 2435585, 2435586, 2435566, 2435567, 2435568, 2435569, 2435571, 2435572, 2435578, 2435580, 2435582, 2435583, 2435585, 2435586, 2435586, 2435567, 2435568, 2435571, 2435576, 2435578, 2435579, 2435580, 2435581, 2435581, 2435582, 2435583, 2435584, 2435584, 2435585, 2435586, 2435586, 2435587, 2435573, 2435575, 2435576, 2435578, 2435579, 2435580, 2435581, 2435582, 2435584, 2435584, 2435586, 2435587, 2435575, 2435588, 2435582, 2435585, 2435588, 2435588, 2435573, 2435588, 2435583, 2435589, 2435589, 2435577, 2435581, 2435583, 2435584, 2435585, 2435585, 2435589, 2435590, 2435578, 2435585, 2435588, 2435591, 2435582, 2435583, 2435591, 2435579, 2435587, 2435588, 2435591, 2435592, 2435587, 2435587, 2435592, 2435593, 2435584, 2435591, 2435593, 2435588, 2435589, 2435591, 2435593, 2435594, 2435591, 2435593, 2435594, 2435595, 2435585, 2435590, 2435590, 2435591, 2435593, 2435596, 2435597, 2435596, 2435597, 2435592, 2435592, 2435595, 2435595, 2435597, 2435598, 2435591, 2435593, 2435597, 2435598, 2435598, 3760724, 2435598, 2435599, 2435593, 2435597, 2435598, 2435594, 2435598, 2435599, 2435600, 2435595, 2435596, 2435597, 2435597, 2435598, 2435598, 2435599, 2435600, 2435600, 2435601, 2435598, 2435599, 2435600, 2435600, 2435601, 2435601, 2435598, 2435602, 11361842, 2435598, 2435602, 2435602, 2435600, 2435601, 2435602, 2435603, 2435600, 2435601, 2435602, 2435603, 2435603, 2435603, 2435604, 2435603, 2435604, 2435604, 2435604, 2435604, 2435605, 2435604, 2435605, 2435605, 2435605, 2435606, 2435607, 2435626, 2435606, 3760727, 2435607, 2435608, 2435608, 2435609, 2435609, 2435610, 2435610, 2435611, 2435612, 2435613, 2435613, 2435614, 2435614, 2435616, 2435616, 2435618, 2435618, 2435620, 2435620, 2435621, 2435622, 2435622, 2435623, 2435623, 2435624, 2435624, 2435626, 2435626, 2435627, 2435627, 2435630, 2435634, 2435635, 2435636, 2435640, 2435647, 2435649, 2435651, 2435652, 2435652, 2435653, 2435654, 2435654, 2435655, 2435655, 2435656, 2596753, 2667969, 2722933, 3760734, 4719684, 4719685, 6976632, 7932822, 8545203, 9354225, 10475106, 2435608, 2435609, 2435609, 2435610, 2435611, 2435611, 2435612, 2435613, 2435613, 2435614, 2435616, 2435617, 2435618, 2435620, 2435621, 2435623, 2435624, 2435624, 2435625, 2435626, 2435628, 2435628, 2435633, 2435636, 2435637, 2435639, 2435650, 2435653, 2435654, 2435654, 2435655, 2435656, 2435656, 2464827, 4719682, 2435610, 2435610, 2435612, 2435617, 2435623, 2435624, 2435628, 2435635, 2435654, 2435655, 2435656, 2435657, 5109467, 2435612, 2435657, 2435611, 2435613, 2435615, 2435618, 2435622, 2435623, 2435626, 2435627, 2435629, 2435638, 2435653, 2435655, 2435656, 2435657, 2435658, 3760738, 6626946, 6765289, 2435620, 2435621, 2435626, 2435639, 2435641, 2435654, 2435657, 2435658, 2997373, 2435617, 2435659, 2435620, 2435627, 2435659, 2435636, 2435660, 2435619, 2435656, 2435660, 2435660, 2435661, 2435626, 2435661, 2435622, 2435626, 2435631, 2435662, 2435623, 2435662, 2435633, 2435663, 2435631, 2435663, 2435625, 2435629, 2435632, 2435635, 2435636, 2435637, 2435663, 2435665, 2435627, 2435633, 2435634, 2435634, 2435636, 2435637, 2435639, 2435642, 2435650, 2435651, 2435664, 2435665, 2435665, 2435662, 2435666, 2435667, 2435667, 2435667, 2435640, 2435666, 2435637, 2435639, 2435641, 2435668, 2435669, 2435636, 2435661, 2435670, 2435671, 3117904, 2435671, 2435643, 2435645, 2435672, 2435672, 2435644, 2435644, 2435673, 2435645, 2435657, 2435670, 2435673, 2435646, 2435673, 2435674, 2435646, 2435670, 2435673, 2435675, 2435647, 2435676, 3760748, 2435649, 2435661, 2435670, 2435672, 2435673, 2435674, 2435676, 2435677, 2435675, 2435677, 2435678, 2435678, 2435679, 2435679, 2435682, 3760754, 2435664, 2435681, 2435684, 2435684, 2435682, 2435685, 2435680, 2435683, 4075574, 2435689, 2435689, 2435690, 2435686, 2435695, 2435689, 2435694, 2435695, 2435698, 2435697, 2435698, 2435699, 2435698, 2435699, 2435699, 2435700, 3851669, 2435701, 2435699, 2435700, 2435701, 2435701, 2435702, 2435701, 2435701, 2435702, 2435701, 2435702, 2435702, 2435703, 2435702, 2435703, 2435703, 2435704, 2435704, 2435705, 2435765, 2464876, 2567248, 2567249, 2567253, 2596804, 2668018, 2706760, 2780397, 2831599, 2831668, 2925406, 2954550, 2954942, 2975915, 2997366, 2997419, 2997420, 2997421, 2997421, 3099185, 3099188, 3117938, 3117938, 3117939, 3169646, 3193214, 3193216, 3193280, 3252463, 3291724, 3324861, 3525617, 3525618, 3525618, 3525619, 3533050, 3533051, 3533051, 3533052, 3533052, 3534532, 3534532, 3544630, 3595828, 3595838, 3597467, 3597469, 3705835, 3705835, 3705836, 3747454, 3760775, 3760776, 3760776, 3760777, 3760777, 3760778, 3760779, 3760780, 3760780, 3760781, 3760781, 3760782, 3760782, 3760783, 3760783, 3760784, 3760784, 3760785, 3760785, 3760786, 3851674, 3851712, 3851715, 3851736, 3951757, 3995795, 4002891, 4002892, 4075591, 4115354, 4224364, 4224390, 4363169, 4363170, 4363172, 4363173, 4363174, 4622747, 4719729, 4719729, 4719730, 4719730, 4719731, 4719731, 4719732, 4719732, 4719733, 4719733, 4719734, 4719734, 4719735, 4784935, 4971056, 4971057, 4971061, 4971063, 4971064, 4971066, 5078677, 5109514, 5109515, 5109516, 5806757, 6255576, 6765334, 6765334, 6765335, 6765335, 6976681, 7141419, 7184362, 7337692, 7404889, 7932874, 8545252, 8545253, 8545254, 8545254, 8632145, 8692646, 9354274, 9760382, 10475155, 11307289, 11361873, 13932411, 14035812, 25900015, 2685705, 3117938, 3533051, 3597470, 3760778, 3760785, 3851674, 4719730, 4719734, 2435853, 3525706, 2494062, 2494062, 2494064, 3789963, 3789964, 3789971, 2698808, 2698809, 2698812, 3128980, 3892343, 3892344, 3983284, 2757913, 2757915, 2990451, 3695644, 2900344, 3186876, 3765378, 3993103, 2935722, 4101691, 2977832, 10031454, 3010271, 3284715, 3125165, 3462706, 3222986, 5113378, 3227513, 4156693, 3227644, 4247650, 3415176, 3607708, 3473410, 3473411, 4279637, 3636799, 3474195, 3516672, 4052303, 5238986, 3516172, 3516317, 3516474, 4301196, 3559050, 4322461, 5281415, 5346619, 3559149, 3559152, 3559152, 3559151, 3559153, 3559157, 3679668, 4094780, 4322514, 4413403, 4892030, 3679029, 4322506, 4322509, 4717225, 3762681, 3762683, 3781433, 4424276, 3798901, 4207222, 3800171, 3800184, 3800185, 3800185, 3800186, 3800186, 3800187, 3800187, 3800190, 3800185, 3800186, 3800187, 3800187, 3800188, 3800188, 3800188, 4215298, 4443024, 5401978, 7447581, 3800200, 4207866, 4443023, 4533921, 3800205, 4207865, 4215298, 4215298, 4443025, 4443025, 4443030, 5401979, 5401982, 7447582, 7447583, 8615117, 4207867, 4215299, 4215299, 4216782, 4443025, 4532673, 4533922, 4533969, 5401981, 7447584, 4207866, 4443025, 4443026, 4443026, 4533923, 5045422, 4279719, 4443026, 4517219, 4533923, 5401982, 4226884, 4443033, 3903602, 3927170, 3950734, 3950734, 3950799, 3950801, 3950744, 4290571, 5477250, 3950865, 3951003, 3951148, 3951151, 7899151, 3951929, 3952726, 4519306, 4519306, 4069236, 4349824, 4147755, 4616811, 4214030, 5608901, 4615543, 4615544, 4615544, 4615545, 4622976, 4622977, 4622978, 4850702, 4850703, 4850703, 4850706, 4850708, 4850709, 4850709, 4850711, 4941600, 4941662, 5453099, 5809659, 7855261, 4630409, 4630409, 4630409, 4630410, 4630410, 4630411, 4630411, 4858135, 4803195, 4858135, 4858136, 4858136, 4858138, 4858139, 4858141, 4858142, 4858143, 4949033, 4949075, 5460531, 5817088, 5817088, 5817089, 5817090, 6068416, 6206875, 6206876, 7862694, 12459255, 4633374, 4633375, 4633376, 4633377, 4859619, 4859625, 4696312, 4950564, 4653571, 4653573, 4960614, 6218456, 4755966, 4755982, 4920915, 4876032, 4759244, 4759246, 4759247, 4759249, 4759250, 4759252, 4922554, 4922555, 5013451, 5013496, 5881511, 4922556, 4922557, 4922561, 5013453, 5881510, 4922558, 4922560, 4975978, 4975968, 4975979, 4975979, 4975990, 5030921, 5989872, 8035479, 4996084, 5040973, 5059219, 6031497, 5085860, 5085854, 5085863, 5085848, 5085864, 5085848, 5085849, 5085851, 5085853, 5085855, 5085859, 5085863, 5085864, 5085865, 5085867, 5085849, 5085850, 5085852, 5085852, 5085854, 5085854, 5085855, 5085855, 5085856, 5085856, 5085857, 5085862, 5085863, 5085864, 5085864, 5085865, 5085865, 5085866, 5085866, 5085867, 5085868, 5085850, 5085851, 5085852, 5085852, 5085853, 5085853, 5085854, 5085854, 5085855, 5085855, 5085856, 5085857, 5085858, 5085864, 5085865, 5085865, 5085866, 5085866, 5085867, 5085867, 5085868, 5085868, 5085869, 5085871, 5085872, 5085855, 5085855, 5085856, 5085856, 5085865, 5085866, 5085867, 5085868, 5085871, 5085856, 5085856, 5085854, 5085856, 5085860, 5085875, 5085856, 5085856, 5085857, 5085857, 5085859, 5085861, 5085868, 5085875, 5085876, 5085856, 5085858, 5085860, 5085876, 5085876, 5085857, 5085858, 5085858, 5085859, 5085859, 5085876, 5085876, 5085877, 5085858, 5085859, 5085859, 5085860, 5085869, 5085873, 5085877, 5085859, 5085860, 5085860, 5085861, 5085863, 5085869, 5085872, 5085877, 5085878, 5085860, 5085861, 5085861, 5085862, 5085863, 5085864, 5085870, 5085870, 5085873, 5085874, 5085877, 5085878, 5085861, 5085862, 5085862, 5085863, 5085863, 5085864, 5085870, 5085875, 5085878, 5085878, 5085879, 5085862, 5085863, 5085863, 5085864, 5085864, 5085871, 5085872, 5085872, 5085873, 5085878, 5085879, 5085879, 5085863, 5085864, 5085864, 5085865, 5085871, 5085871, 5085872, 5085873, 5085873, 5085874, 5085877, 5085879, 5085879, 5085880, 5085864, 5085865, 5085865, 5085871, 5085873, 5085874, 5085875, 5085879, 5085880, 5085880, 5085865, 5085866, 5085873, 5085874, 5085875, 5085875, 5085880, 5085881, 5085866, 5085867, 5085874, 5085875, 5085879, 5085880, 5085881, 5085881, 5085873, 5085874, 5085874, 5085875, 5085876, 5085881, 5085881, 5085882, 5085876, 5085882, 5176756, 5327976, 5176759, 5085879, 6044819, 5085883, 5085887, 5085887, 5176761, 6296143, 5085880, 5085881, 5085882, 5085882, 5085883, 5085885, 5085887, 5085887, 5085888, 5085888, 5176761, 6044818, 6044820, 8090422, 5085882, 5085882, 5085885, 5085886, 5085888, 5085888, 5176762, 5320877, 5688259, 6044820, 6044820, 6044821, 6044822, 6296143, 6296145, 6296145, 6327862, 7426330, 8090422, 8090423, 8090423, 5085882, 5085883, 5085889, 5176762, 5266420, 5400679, 6044817, 6044821, 6044822, 6110023, 9870342, 5085883, 5085885, 5085889, 5085890, 5176763, 5400680, 5688262, 5688262, 5688264, 6044821, 6044823, 6122584, 6434604, 5085885, 5085885, 5085886, 5085889, 5085890, 5085890, 5176763, 5176763, 5320879, 5425167, 6044820, 6044822, 6044822, 6044823, 5085886, 5085888, 5085891, 5085891, 5176764, 6044819, 6044820, 6044823, 8090425, 5085886, 5085888, 5085890, 5085891, 5085891, 5176764, 6044822, 5085891, 5085892, 5176765, 6044824, 5085891, 5085892, 5085892, 5688264, 6044824, 6434605, 5085893, 5085893, 5085893, 6044825, 5085893, 5085893, 5085894, 8090427, 5085894, 6044826, 6044826, 5176768, 5085895, 5085896, 5176769, 5176830, 5264633, 5276853, 6044824, 6044824, 6044825, 6044826, 6044828, 6044829, 8090429, 8090430, 11085477, 5085896, 5085897, 5176769, 5505621, 6044824, 6044828, 6044828, 6296154, 5085897, 5085898, 5144301, 5176770, 5176817, 5276853, 5327988, 5549486, 5688268, 5954738, 6044824, 6044825, 6044825, 6044826, 6044826, 6044828, 6044828, 6044829, 6044829, 6044830, 6044832, 6044833, 6044834, 6296152, 6296156, 6296158, 6296159, 6296160, 6296161, 6296161, 6296162, 8090431, 8090431, 9870348, 11085478, 12686992, 5085898, 5176770, 5327990, 5327990, 5400687, 5549487, 5674746, 6044825, 6044826, 6044827, 6044828, 6044829, 6296153, 6296158, 6296158, 6434614, 5176833, 6044826, 6044830, 6296155, 5202731, 5202742, 6103255, 5337718, 5234259, 5250963, 5265154, 6597008, 5267642, 5267644, 5267644, 5267645, 5267645, 5267646, 5267681, 5267686, 5267704, 5267704, 5267705, 5267706, 5267706, 5267707, 5267707, 5267708, 5267743, 5267754, 5267757, 5267747, 5267748, 5267750, 5267751, 5267752, 5267767, 5267777, 5267777, 5267790, 5267776, 5267777, 5267777, 5267778, 5267778, 5267790, 5267791, 5267791, 5267787, 5267852, 5267788, 5267789, 5267792, 5267801, 5267802, 5267802, 5267804, 5267851, 5267853, 5267853, 6135775, 6200977, 5267791, 5267854, 5633025, 5267855, 5267856, 5267866, 6135785, 6135787, 5267866, 5608593, 6135784, 6135785, 5267867, 6135788, 5267868, 5779228, 6135789, 8043050, 6387170, 6135838, 5355645, 5357438, 5411895, 5411896, 5411902, 5418998, 5491697, 5519454, 5519544, 5633089, 5754273, 5779275, 5779275, 5779276, 5779276, 5779277, 5779280, 5779280, 5779281, 5779281, 5815091, 6049622, 6135834, 6135835, 6135835, 6135836, 6135836, 6135837, 6135837, 6135838, 6135838, 6135839, 6135839, 6135840, 6135840, 6135841, 6135842, 6135843, 6213601, 6387162, 6387166, 6387171, 6393559, 6525621, 6525622, 6525622, 6918171, 8181441, 8181442, 8181442, 8392788, 8557528, 10770381, 11176489, 12777980, 12778003, 5443386, 5443385, 6223580, 5831799, 5446981, 5446982, 5868822, 5508541, 8270985, 5467820, 5467824, 5467824, 6235794, 8281400, 6235797, 5472688, 5475322, 5477957, 6240870, 5555898, 5555899, 5555899, 5555906, 5555905, 5923279, 5923283, 6279840, 6279842, 6279839, 6279842, 8325445, 5570092, 5570093, 5570093, 5570094, 5570095, 5570095, 5895151, 5916851, 6286931, 6286934, 6286935, 6538262, 6676716, 8332536, 5715487, 5715499, 6359630, 6003081, 6359636, 6359638, 6359638, 6359640, 6359640, 6359641, 6424843, 5764465, 6384120, 5770999, 5771099, 5771186, 5771198, 6387480, 6387484, 5795014, 6399392, 5875300, 6439539, 5925362, 6464569, 5949397, 5981224, 5998276, 6501025, 6501026, 6013034, 6013060, 6013077, 6013080, 6013118, 6013121, 6013120, 6013122, 6013164, 6151905, 6508460, 6508462, 6508465, 6573666, 6759794, 6766184, 13096020, 6220205, 6220208, 6611989, 6611990, 6224907, 6614336, 6240644, 6873540, 6263603, 6593410, 6885010, 6290652, 6290652, 6290652, 6290653, 6290638, 6290638, 6290652, 6290654, 6290655, 6290655, 6290655, 6290656, 6290656, 6290656, 6290656, 6290657, 6290657, 6290657, 6290656, 6290658, 6290658, 6290659, 6290671, 6647215, 6647214, 6647216, 8692818, 6647212, 6647213, 6647214, 6647215, 6647216, 6647216, 6647213, 6647213, 6647214, 6647215, 6647216, 6647216, 6647217, 6647218, 7036999, 7103092, 7429549, 7908826, 8692819, 6362274, 6683022, 6809799, 6809899, 6809998, 6906885, 6823591, 6823650, 6913727, 6831368, 6917586, 6923220, 6963497, 7003756, 7003772, 7003754, 7003755, 7003757, 7003757, 7003754, 7003755, 7003756, 7003756, 7003757, 7003757, 7003758, 7003760, 7003762, 7003771, 7003772, 7003772, 7003773, 7003774, 7003754, 7003755, 7003756, 7003756, 7003757, 7003758, 7003769, 7003771, 7003772, 7003774, 7003755, 7003756, 7003757, 7003757, 7003758, 7003759, 7003770, 7003771, 7003772, 7003774, 7003775, 7003776, 7003756, 7003757, 7003758, 7003759, 7003759, 7003771, 7003772, 7003773, 7003774, 7003774, 7003775, 7003776, 7003776, 7003758, 7003758, 7003759, 7003759, 7003760, 7003764, 7003764, 7003772, 7003772, 7003774, 7003775, 7003776, 7003759, 7003760, 7003774, 7003776, 7003759, 7003760, 7003760, 7003761, 7003763, 7003764, 7003774, 7003774, 7003775, 7003775, 7003776, 7003776, 7003777, 7003777, 7003778, 7003778, 7003760, 7003761, 7003761, 7003774, 7003775, 7003775, 7003776, 7003776, 7003777, 7003777, 7003778, 7003778, 7003779, 7003761, 7003762, 7003762, 7003763, 7003764, 7003765, 7003766, 7003766, 7003767, 7003774, 7003775, 7003775, 7003776, 7003776, 7003777, 7003777, 7003778, 7003778, 7003779, 7003779, 7003762, 7003763, 7003764, 7003765, 7003765, 7003766, 7003775, 7003776, 7003777, 7003777, 7003778, 7003778, 7003779, 7003780, 7003763, 7003765, 7003767, 7003776, 7003776, 7003777, 7003777, 7003778, 7003778, 7003779, 7003779, 7003780, 7003780, 7003778, 7003778, 7003779, 7003780, 7003782, 7003783, 7003767, 7003768, 7003778, 7003782, 7003784, 7003769, 7003770, 7003779, 7003781, 7003781, 7003784, 7003769, 7003780, 7003781, 7003781, 7003782, 7003783, 7003783, 7003786, 7003779, 7003780, 7003781, 7003786, 7003771, 7003781, 7003786, 7003787, 7003772, 7003781, 7003782, 7003783, 7003785, 7003787, 7003780, 7003781, 7003782, 7003785, 9049374, 7068975, 7003795, 7393556, 7393558, 7003790, 7255098, 7393555, 10829293, 7003790, 7003790, 7003791, 7003791, 7003792, 7003793, 7255104, 8635174, 7003790, 7003791, 7003791, 7003792, 7003793, 7003796, 7081537, 7255098, 7255105, 7255108, 7393558, 7940768, 8911035, 9425463, 12044425, 7003791, 7003792, 7003792, 7003793, 7003793, 7003794, 7003794, 7003797, 7010984, 7068978, 7255103, 7255109, 8002966, 9049377, 9049378, 9049378, 9425463, 10505297, 10916188, 12044425, 12759198, 7003792, 7003793, 7003793, 7003794, 7003794, 7003795, 7003796, 7003796, 7003797, 7068978, 7081538, 7081538, 7255106, 7255107, 7255109, 7393559, 8319706, 9049378, 9049378, 9049379, 9049379, 7003793, 7003794, 7003794, 7003795, 7003795, 7003796, 7003797, 7068979, 7081539, 7255100, 7255100, 7255101, 7255101, 7255105, 7255107, 7393557, 7393559, 7393560, 7459652, 7786109, 7786110, 7831988, 7853913, 7893165, 7940769, 7940770, 8197805, 8265336, 8265388, 8314280, 8487983, 9049378, 9049379, 9049379, 9049381, 11638320, 20538408, 7003794, 7003795, 7003795, 7003796, 7003797, 7003798, 7068979, 7081539, 7081542, 7255100, 7255100, 7255101, 7255101, 7255106, 7255108, 7261497, 7393559, 7393560, 7393560, 7459653, 7578769, 7940770, 8090801, 8539622, 9049379, 9049379, 9049380, 9049380, 9425464, 9621736, 10296785, 10829296, 11638319, 12044426, 12044427, 12759199, 7003795, 7003796, 7003796, 7003797, 7003798, 7003799, 7068980, 7081540, 7255101, 7255107, 7255108, 7255109, 7255111, 7393558, 7393561, 8911039, 9049380, 9049380, 9425464, 10216917, 7003796, 7003797, 7003799, 7003799, 7068980, 7081540, 7255101, 7255102, 7255105, 7255107, 7255108, 7255108, 7255109, 7261498, 7393561, 8539620, 9049380, 9049381, 10829298, 7003797, 7003799, 7003800, 7068981, 7255103, 7255104, 7255105, 7255108, 7255110, 7255111, 7255111, 7261499, 7393563, 7681010, 7786111, 7926520, 7940772, 8197809, 8229005, 8911039, 9049380, 9049381, 9049381, 10829298, 7003799, 7003800, 7003800, 7068941, 7068981, 7081541, 7255101, 7255103, 7255104, 7255105, 7255106, 7255106, 7255107, 7255107, 7255108, 7255109, 7255110, 7255111, 7255112, 7255113, 7255113, 7393560, 7393561, 7786111, 7786112, 7786112, 8635178, 9049380, 9049381, 9049381, 9049382, 9425465, 10829298, 11629149, 7255107, 7003802, 7255110, 7255110, 7255111, 9049382, 9049383, 7068983, 7003802, 7068923, 7255104, 7255105, 7255106, 7255109, 7255110, 7255110, 7255111, 7255112, 7459657, 7786113, 9049383, 9049384, 10829301, 11638323, 7003804, 7068984, 7255107, 7255108, 7255108, 7255109, 7255110, 7255111, 7255115, 7393566, 7683103, 8265394, 8487997, 8911043, 9049383, 9049384, 9049384, 9049384, 7255110, 7018214, 7088768, 7134051, 7134057, 7134127, 7134146, 7134167, 7134185, 7134186, 7134186, 7134188, 7134202, 7134206, 9114584, 7134207, 7134208, 7146746, 7191102, 7320308, 7320308, 7320309, 7320311, 7320311, 7320312, 7320314, 7320316, 7326704, 7458768, 8959694, 9114586, 9114586, 9114587, 9114587, 10894504, 12109633, 7320317, 7159295, 7159296, 7159296, 7159297, 7159297, 7159298, 7159299, 7159301, 7159301, 7332857, 7332858, 7332858, 7339254, 7471314, 7471316, 8423265, 8738897, 9127134, 9127135, 9127136, 9127136, 8988794, 11716076, 7471315, 9100185, 8605731, 7332859, 7332869, 7471321, 7248065, 7248168, 7248276, 7515838, 7506422, 7506421, 7506420, 7506421, 7506423, 7506426, 7506410, 7506422, 7506423, 7506425, 7506409, 7506411, 7506414, 7506415, 7506416, 7506416, 7506417, 7506421, 7506423, 7506423, 7506424, 7506424, 7506425, 7506426, 7506431, 7506413, 7506415, 7506424, 7506425, 7506425, 7506426, 7506413, 7506416, 7506417, 7506425, 7506426, 7506431, 7506432, 7506432, 7506433, 7506416, 7506435, 7506415, 7506416, 7506418, 7506436, 7506415, 7506416, 7506418, 7506436, 7506421, 7506437, 7506440, 7506417, 7506419, 7506422, 7506437, 7506439, 7506417, 7506418, 7506418, 7506419, 7506419, 7506427, 7506438, 7506418, 7506419, 7506420, 7506423, 7506438, 7506419, 7506420, 7506421, 7506422, 7506422, 7506424, 7506439, 7506420, 7506421, 7506421, 7506422, 7506422, 7506423, 7506439, 7506440, 7506421, 7506422, 7506422, 7506423, 7506423, 7506424, 7506425, 7506430, 7506440, 7506440, 7506422, 7506423, 7506424, 7506425, 7506431, 7506432, 7506440, 7506441, 7506441, 7506423, 7506424, 7506425, 7506425, 7506441, 7506424, 7506425, 7506426, 7506432, 7506441, 7506443, 7506425, 7506426, 7506427, 7506429, 7506432, 7506442, 7506442, 7506426, 7506427, 7506428, 7506432, 7506434, 7506442, 7506444, 7506427, 7506432, 7506435, 7506442, 7506443, 7506443, 7506444, 7506428, 7506429, 7506434, 7506443, 7506431, 7506432, 7506444, 7506444, 7506430, 7506444, 7506437, 7506446, 7506446, 9300700, 9300699, 7506447, 7639576, 7644883, 9300700, 9300701, 11080619, 7506439, 7506448, 10468237, 7506449, 7506450, 9300702, 7506449, 7710975, 9300702, 9300703, 9873055, 11080620, 7506450, 9162361, 9300703, 9300703, 7506450, 8037434, 7506451, 7644884, 9162362, 9300704, 10468241, 9300704, 11889645, 7639585, 8037440, 9300709, 9300709, 9300711, 7506458, 7506459, 7506460, 7506460, 7506461, 7512830, 7644889, 7644892, 7644892, 7644893, 7644894, 7644894, 7644895, 7644895, 7664316, 7739142, 8037442, 8037442, 8037443, 8037443, 8144789, 8192103, 8342134, 8516670, 8516720, 8516721, 8596841, 8809568, 8904701, 9161674, 9300711, 9300711, 9300712, 9300712, 9300713, 9678907, 10540491, 11080630, 7506460, 7506461, 7512830, 7644892, 8083164, 8886509, 9300712, 9300712, 9300713, 13010533, 7506461, 7644895, 8083165, 8330789, 9300713, 9300713, 13014881, 7506462, 7644893, 7644893, 7644894, 7644895, 7644896, 8037443, 8037445, 8516673, 9300713, 13010534, 7644894, 9300714, 11080634, 7519201, 7519213, 7519213, 7519216, 7519213, 9307094, 9307095, 7651275, 7651277, 8348520, 8523107, 9307097, 9307098, 9307098, 11896037, 7569854, 9332416, 7721661, 12403366, 7772732, 7772737, 8325247, 8170591, 7783337, 7783338, 7783323, 7783338, 7783340, 7783341, 7783338, 7783339, 7783339, 7783339, 7783340, 7783327, 7783340, 7783341, 7783342, 7783327, 7783328, 7783338, 7783339, 7783341, 7783328, 7783342, 7783340, 7783341, 7783342, 7783343, 7783343, 7783344, 7783331, 7783342, 7783343, 7783344, 7783345, 7783345, 7783346, 7783344, 7783346, 7783347, 9439158, 7783353, 9439159, 8175891, 9439160, 7783356, 7783358, 7849433, 8330551, 8580558, 9300818, 9439159, 9439160, 9439160, 14035721, 7783358, 7783359, 7849435, 8175891, 8330552, 8668435, 9284268, 9300819, 9351631, 9439160, 9439160, 9439161, 9439161, 9439162, 10606698, 11219077, 12028100, 7928420, 9439161, 9439162, 10606697, 12434209, 8175892, 8366280, 7783361, 8175892, 8330553, 8655169, 8735294, 9300821, 9439162, 9439163, 9439163, 7783361, 8330554, 9439162, 9439163, 9439163, 9815248, 8839574, 9439163, 7822178, 7822200, 7822384, 7822603, 7822660, 9458813, 7915512, 7915524, 7915513, 7915524, 7915524, 7915525, 7915525, 7915526, 8241980, 7915537, 8653677, 9505251, 9091048, 9505251, 7928864, 8465507, 7971839, 9533408, 8073497, 9584239, 8153756, 8361096, 8358258, 9726630, 8362415, 9728696, 8568436, 8568426, 8568437, 8568437, 8568438, 8568438, 8636241, 8723097, 8723098, 9047715, 9322121, 9693365, 9831706, 9831706, 9831707, 9831707, 10861798, 12420646, 8659869, 8659879, 8659880, 8679517, 9877428, 8660259, 12872697, 8699154, 9897064, 8704046, 8704048, 9899511, 9899514, 8782555, 9938769, 8783145, 11106605, 8849256, 8849326, 8849401, 9972193, 8877746, 8877758, 8877758, 8877747, 8877758, 8877759, 8877759, 8877770, 9134794, 9986368, 9703328, 9848026, 9986368, 9986368, 10362453, 10558724, 8949212, 9460707, 9002154, 9002156, 10048567, 10048569, 9155193, 9155306, 9155415, 10125226, 9177826, 9177826, 9177827, 10136404, 10512489, 10136405, 9377772, 10236374, 9391832, 9391833, 9391834, 9459365, 10243406, 10243407, 9454228, 10274604, 9526896, 9526897, 9526898, 9607070, 9801182, 10310938, 13305986, 9526993, 9526995, 9526997, 9526998, 9526999, 9526998, 9526999, 9526999, 9527000, 12090905, 10310987, 10310989, 9749602, 10310990, 10310989, 10310990, 10310990, 10310990, 9553516, 9553571, 9553647, 10185975, 9624789, 9624864, 9624935, 10359959, 9635630, 9635717, 9635805, 11703420, 9687239, 9687241, 9687241, 9743081, 10391109, 10391110, 9766837, 9766905, 9766981, 10431005, 9798921, 10446949, 9895805, 10495394, 9972192, 9972202, 9972202, 10533588, 10533589, 10533589, 10533590, 10052157, 10052233, 10052308, 10949726, 10075446, 10075461, 10075463, 10075463, 10075467, 10075476, 10585221, 10585220, 11825001, 10585224, 10075803, 10075866, 10075928, 10585451, 10112689, 10603834, 10113721, 10604350, 10266573, 10680776, 10680776, 10303004, 10303079, 10303153, 10560747, 10318500, 10706739, 10528897, 10811938, 10785207, 10940099, 10816901, 13544876, 10818290, 10818292, 10818293, 10818293, 10818294, 10818292, 10818293, 10818294, 10818292, 10818386, 10818387, 10818387, 10956635, 10956635, 10956635, 10818385, 10956635, 10956636, 10956635, 10956636, 12736553, 10818477, 10818482, 10818482, 10818483, 10818483, 10956727, 10956728, 10956729, 10956729, 11332816, 10956730, 10919945, 11007474, 11041070, 11444107, 11094963, 11094963, 11094964, 11094964, 11094965, 11094981, 11094964, 11094965, 11094965, 11094979, 11094980, 11094981, 11094965, 11094966, 11094978, 11094980, 11094980, 11094981, 11094981, 11094982, 11094982, 11094983, 11094983, 11094984, 11094985, 11094966, 11094977, 11094978, 11094978, 11094979, 11094979, 11094980, 11094980, 11094981, 11094981, 11094982, 11094982, 11094983, 11094983, 11094984, 11094984, 11094985, 11094986, 11094987, 11094989, 11094968, 11094978, 11094978, 11094979, 11094980, 11094981, 11094981, 11094982, 11094982, 11094983, 11094983, 11094984, 11094985, 11094985, 11094986, 11094987, 11094988, 11094982, 11094992, 11094992, 11094993, 11094994, 11094992, 11094993, 11094996, 11094993, 11094993, 11094994, 11094995, 12874895, 11094994, 11094995, 11094996, 11094994, 11094996, 11094994, 11094995, 11094996, 11094996, 12874896, 11094995, 11094996, 11094996, 11094997, 11094997, 11094998, 12262515, 14090027, 11094996, 11094997, 11094997, 11094998, 11094998, 11094999, 11095000, 11095001, 11095003, 11095004, 11306326, 11427473, 11471067, 11471068, 11667337, 11667337, 11667339, 12262517, 12262518, 12874896, 12874898, 12874898, 12874899, 12874899, 13683920, 14090028, 14142908, 11094997, 11094998, 11094998, 11094999, 11095000, 11095000, 11095001, 11095001, 11095004, 11471065, 11471067, 11473176, 11667334, 11667335, 11667336, 12262517, 12262518, 12262519, 12762672, 12874898, 12874898, 12874899, 12874900, 12874900, 13022291, 13683920, 14090028, 14804817, 11094998, 11094999, 11094999, 11095000, 11095000, 11095001, 11095002, 11095003, 11095004, 11095006, 11306328, 11427472, 11471067, 11471068, 11471069, 11667335, 11667337, 11667338, 11667338, 12262517, 12262517, 12262518, 12262519, 12733783, 12874898, 12874899, 12874899, 12874900, 12874900, 13683921, 13683921, 14090028, 14090029, 11094999, 11095000, 11095000, 11095001, 11095001, 11095002, 11095002, 11095003, 11095004, 11095004, 11095006, 11182932, 11202749, 11202749, 11306328, 11306329, 11415525, 11471066, 11471067, 11471067, 11471068, 11471069, 11471069, 11471070, 11524479, 11524480, 11667337, 11667337, 11667338, 11667339, 11667339, 11671067, 12262517, 12262519, 12262520, 12262522, 12376121, 12874899, 12874899, 12874900, 12874900, 12874901, 12874901, 13683921, 13811587, 13811588, 14090028, 14090029, 14090029, 11095000, 11095001, 11095001, 11095002, 11095002, 11095003, 11095004, 11095004, 11095005, 11137329, 11279977, 11306327, 11306329, 11471067, 11471067, 11471068, 11471068, 11473177, 11473179, 11667336, 11667338, 11667340, 12262518, 12262518, 12262519, 12262519, 12262520, 12874899, 12874899, 12874900, 12874900, 12874901, 13683922, 13683922, 13683923, 13683924, 14090029, 14090030, 14804802, 15691521, 11095001, 11095002, 11095002, 11095003, 11095003, 11095004, 11095005, 11095006, 11306328, 11427472, 11471067, 11473178, 11524481, 11667338, 11667340, 12262519, 12262519, 12262520, 12262521, 12610783, 12874899, 12874900, 12874902, 13683922, 13683923, 13811589, 14090029, 11095002, 11095003, 11095003, 11095005, 11095005, 11306328, 11306330, 11306330, 11427473, 11435511, 11471069, 11667340, 12262519, 12262520, 12874902, 12961793, 13683923, 13683924, 14090031, 14090033, 15691522, 11095003, 11095004, 11095005, 11095005, 11095006, 11095007, 11471068, 11471070, 11471071, 11473179, 11473180, 11484839, 11516989, 11667339, 11667341, 11667342, 12262521, 12262523, 12874900, 12874901, 12874901, 12874902, 12874902, 12874903, 13683923, 13683925, 14090031, 11095004, 11095005, 11471068, 11471069, 11471071, 11471071, 11516989, 11524482, 11667340, 12262521, 12874901, 12874901, 12874902, 13683924, 14090032, 14470639, 11095005, 11095006, 11095006, 11095007, 11095008, 11306329, 11471069, 11471071, 11471072, 11667339, 11667341, 11836172, 12262519, 12262520, 12262521, 12262522, 12262523, 12262523, 12262524, 12874902, 12874902, 12874903, 12961795, 13683924, 13683925, 11095007, 11471072, 11667341, 11667344, 11671069, 12262519, 12262521, 12262522, 12262525, 12262526, 12874903, 12874903, 13683925, 11095007, 11427474, 11667342, 11667343, 13683925, 13683925, 11095009, 11427481, 11471073, 12262522, 12262527, 12874904, 12961797, 13683926, 11095009, 11297517, 11484842, 12262523, 12711927, 12874905, 13022298, 13683927, 12262524, 13683927, 11095011, 11471072, 11667344, 12262524, 12262525, 12874905, 13683927, 13811594, 12262525, 12262525, 12576476, 11306335, 15691527, 14142918, 14090037, 11179673, 11709683, 11270917, 11559052, 11310510, 11310511, 11414090, 11632241, 11464969, 12447511, 11500041, 11673597, 11517669, 11517668, 11517670, 11517669, 11517672, 11517670, 11517671, 11517671, 11517673, 11517660, 11517672, 11517673, 11517674, 11517674, 12473860, 11878680, 11682409, 11684518, 12385995, 12473860, 12473861, 12473861, 12974019, 13895264, 11638814, 11682409, 11682409, 13895264, 11735824, 12473861, 13086243, 14301374, 11682413, 15016161, 11736067, 11736139, 14004522, 11759957, 11759956, 11759957, 11759960, 11759961, 11759962, 11759965, 11803551, 11803552, 11760051, 13207387, 11803557, 11803557, 13207389, 11760140, 11803643, 11776087, 11811645, 11847148, 11847150, 11847135, 11847136, 11847149, 11847149, 11847150, 11847150, 11847151, 11847150, 11847151, 11847151, 11847136, 11847137, 11847151, 11847152, 11847137, 11847151, 11847152, 11847152, 11847138, 11847139, 11847151, 11847152, 11847152, 11847153, 11847153, 11847152, 11847152, 11847153, 11847153, 11847152, 11847152, 11847153, 11847153, 11847154, 11847153, 11847154, 13250980, 11847165, 12043420, 12043423, 12638601, 14060004, 11847166, 11849260, 12043418, 12043421, 12638601, 12638601, 13250984, 14060004, 14466112, 11847167, 12043420, 12638600, 12638601, 12638602, 13250982, 13250983, 14060005, 14060006, 11847167, 12043421, 12609381, 13250982, 13250983, 13250984, 13250985, 13398377, 14060005, 14060006, 14187674, 12043420, 12043422, 12043423, 12043424, 12047150, 12210171, 12388080, 12638600, 12638602, 12638603, 12638603, 12638606, 13250983, 13250983, 13250984, 13250985, 14278542, 14466113, 14466114, 15180886, 15187878, 13250986, 11851369, 11851370, 11851368, 11851370, 11851371, 11851371, 11851371, 13253090, 12640711, 12045530, 12045531, 12045532, 13253092, 14468222, 14613143, 15183010, 11874690, 11874690, 12652372, 12207877, 11933033, 13380816, 11938986, 12972899, 15226815, 11953972, 11953972, 11953972, 11953973, 12096829, 12692010, 13304394, 12692009, 13304392, 14113414, 12239675, 12239675, 12239675, 12239687, 12239689, 12239674, 12239687, 12239689, 12239676, 12239688, 12239692, 12239687, 12239689, 12239690, 12239690, 12239691, 12239691, 12239692, 12239692, 12239677, 12239678, 12239679, 12239690, 12239692, 12239693, 12239693, 12239694, 12239692, 12239693, 12239693, 12239694, 12239694, 12239695, 12239693, 12239694, 12239695, 12239694, 12239695, 12239693, 12239694, 12239695, 12239701, 12614106, 13447251, 13447251, 13447252, 12239706, 12239705, 14256274, 14662382, 12834872, 14256274, 14595611, 12239707, 12239708, 12834870, 13447252, 13447253, 13447253, 14256275, 14256276, 12239707, 12239708, 12834872, 12834873, 13447252, 13447253, 13447253, 13447254, 13447256, 14116442, 14256275, 14662383, 12239708, 12239709, 12834871, 12834873, 12834873, 13447253, 13447253, 14662384, 12834868, 12834873, 12834874, 12834876, 13447253, 13447254, 13447254, 13447255, 13447256, 13594648, 13618114, 14256276, 16263875, 12686695, 12834871, 13447255, 13447255, 13447256, 13447257, 14256277, 14662385, 14715266, 16263929, 12361054, 12834876, 12247145, 12247145, 12247146, 12838598, 12838599, 13450980, 12374084, 14323469, 12482413, 13456388, 12541064, 13597939, 12573189, 13001621, 12577352, 13616084, 12929009, 14600934, 12988523, 13682643, 13133726, 14065214, 13155161, 13904985, 13254318, 13508762, 13371606, 13400828, 13430049, 13430034, 13430035, 13430036, 13430050, 13430051, 13430038, 13430051, 13430035, 13430037, 13430039, 13430050, 13430051, 13430036, 13430037, 13430048, 13430050, 13430051, 13430051, 13430052, 13430037, 13430038, 13430038, 13430050, 13430052, 13430052, 13430053, 13430055, 13430038, 13430039, 13430051, 13430053, 13430053, 13430054, 13430039, 13430040, 13430041, 13430053, 13430053, 13430054, 13430053, 13430054, 13430055, 13430057, 13430042, 13430055, 13430056, 13430057, 13430057, 13430058, 13430043, 13430057, 13430054, 13430058, 13430056, 13430058, 13430059, 13430059, 13430060, 13430060, 13430060, 13430061, 14851452, 13430066, 13430066, 13430069, 14851456, 15976684, 16859105, 14042432, 13430068, 14042432, 14042433, 14042434, 14042440, 14851455, 15972349, 13430068, 14042433, 14042433, 14042434, 14042434, 14042435, 14042435, 14042436, 14851456, 15257564, 13430069, 13430071, 13430071, 13430072, 13596651, 13870520, 13939404, 14042433, 14042434, 14042434, 14042435, 14042435, 14042436, 14042436, 14851456, 14851456, 14851457, 14851458, 14979120, 15257564, 15257564, 15310446, 15972348, 13430070, 14851457, 13430071, 14042435, 13430072, 14002886, 14851458, 15972347, 13430073, 13430074, 14042436, 14042437, 13841744, 14042436, 14042437, 14042437, 14851458, 15972343, 15972354, 13430075, 14042437, 14367085, 14851459, 15257567, 16859058, 14042438, 14851460, 14851460, 15257571, 15972340, 15972354, 13574536, 14114675, 16044581, 13589789, 15337430, 13657258, 14965058, 13763204, 13763228, 13763248, 13763253, 14209030, 14209031, 13771037, 14212923, 14006802, 14006812, 14330811, 15139833, 14029612, 15557345, 14057953, 14356382, 14126580, 14390698, 14253423, 14253524, 14253625, 14454217, 14310981, 15698025, 14328863, 16419988, 14372587, 15322724, 14376762, 14515785, 14430362, 14430361, 14430365, 14542586, 14907396, 14542588, 14448751, 15360802, 14575711, 14615261, 14654799, 14654800, 14654813, 14654798, 14654799, 14654799, 14654800, 14654800, 14654801, 14654813, 14654814, 14654815, 14654799, 14654800, 14654800, 14654801, 14654801, 14654811, 14654811, 14654812, 14654812, 14654814, 14654814, 14654815, 14654815, 14654816, 14654800, 14654801, 14654801, 14654802, 14654814, 14654814, 14654815, 14654815, 14654816, 14654816, 14654817, 14654801, 14654802, 14654802, 14654803, 14654813, 14654814, 14654815, 14654815, 14654816, 14654816, 14654817, 14654817, 14654818, 14654802, 14654803, 14654804, 14654814, 14654815, 14654816, 14654816, 14654817, 14654817, 14654803, 14654804, 14654805, 14654814, 14654815, 14654816, 14654816, 14654817, 14654818, 14654818, 14654814, 14654815, 14654816, 14654816, 14654817, 14654817, 14654818, 14654818, 14654819, 14654820, 14654813, 14654819, 14654819, 14654818, 14654820, 14654828, 14654822, 14654826, 14654827, 14654827, 14654828, 14654827, 14654827, 15463836, 14654829, 15869943, 14654827, 14654829, 14654830, 14654828, 14654830, 15463836, 14654829, 14654830, 14654831, 14802208, 15463836, 15463836, 16584717, 16584718, 16584723, 14654831, 14654831, 14654832, 14741708, 15019622, 15463837, 15591503, 15591503, 15869945, 16584721, 16584732, 14654831, 14654832, 15463837, 15463838, 16584726, 16584732, 14654832, 14654833, 15454666, 15463835, 15463837, 15463838, 15463838, 15591504, 16584719, 16584720, 16584723, 14654833, 14654835, 14741709, 14741709, 14802207, 14802207, 14802210, 14816302, 14883900, 15324006, 15324007, 15454666, 15463837, 15463837, 15463838, 15463838, 15463839, 15463840, 15491699, 15591504, 15591505, 15591506, 15774080, 15869945, 15869946, 15869946, 16584719, 16584719, 16584731, 16584731, 16584734, 16584735, 16589068, 16589069, 16591710, 16882303, 17416853, 17471437, 17471459, 17471460, 17526616, 17526617, 20042031, 14681448, 14727953, 15019624, 15463837, 15463839, 15463839, 15463840, 15591503, 15591505, 15591507, 15869946, 15869947, 16584720, 16584734, 15463840, 15591506, 15463840, 15869948, 15463843, 14708096, 15490486, 14801089, 15536976, 14828600, 14828601, 14828601, 15151347, 15550730, 15680584, 15956838, 16671611, 16671612, 15678398, 14949598, 14949582, 14949598, 14949597, 14949600, 14949598, 14949601, 14949603, 15611226, 14949613, 15611229, 15738895, 16017336, 16017337, 16070218, 15611231, 15611232, 14977784, 15625320, 14996578, 14996736, 14996680, 15634775, 14996878, 15634883, 15112980, 15692918, 15304110, 15788484, 15384428, 15384430, 15384431, 16956514, 15828644, 16234753, 15474131, 15474206, 15474282, 16994481, 15993191, 15993192, 15993192, 16133024, 16539132, 16254512, 16254514, 16254516, 16263684, 16669793, 18271340, 16272841, 16272842, 16272856, 16272859, 16272842, 16272843, 16272844, 16272858, 16272843, 16272844, 16272858, 16272859, 16272844, 16272845, 16272845, 16272846, 16272858, 16272858, 16272859, 16272859, 16272860, 16272860, 16272861, 16272861, 16272846, 16272857, 16272859, 16272859, 16272860, 16272861, 16272861, 16272862, 16272861, 16272862, 16272863, 16272848, 16272860, 16272861, 16272862, 16272862, 16272863, 16272863, 16272864, 16272864, 16272873, 17107366, 16272875, 16272875, 16272875, 16400524, 16272875, 16272875, 16272876, 16272876, 16678966, 16678966, 16678967, 17393740, 17393754, 17398089, 18280458, 16272875, 16272876, 16400525, 16678967, 17393749, 16272876, 16272877, 16272877, 16272878, 16400524, 16400525, 16400526, 16595027, 16678967, 16678968, 16678969, 16678970, 16731847, 16731848, 16731849, 16731849, 16731850, 17393741, 17393753, 16272877, 16400526, 16678967, 16678968, 16678968, 16731849, 16731850, 17393740, 17393746, 17393753, 16272878, 16272879, 16272879, 16272880, 16380411, 16400527, 16400527, 16400528, 16400528, 16508017, 16531996, 16560076, 16678968, 16678968, 16678969, 16678973, 16731847, 16731848, 16731849, 16731849, 16731850, 16731850, 16731851, 16731856, 16923352, 17059575, 17225344, 17391987, 17393740, 17393741, 17393743, 17393744, 17393745, 17393749, 17393750, 17393752, 17393753, 17393753, 17393754, 17393755, 17393756, 17393757, 17398090, 17400732, 17400733, 18280460, 18280518, 16272879, 16272880, 16400527, 16400528, 16400529, 16400530, 16678968, 16678969, 16731849, 16731849, 17393742, 17393746, 17393748, 17393758, 18280460, 18280483, 16400529, 16678969, 16678969, 16678970, 16731851, 17393743, 17393753, 16678970, 17393746, 16731851, 17393758, 16328578, 16759706, 16487959, 16786517, 16528174, 16528187, 16528188, 16528175, 16528175, 16528176, 16528188, 16528188, 16528190, 16528191, 16528191, 16528194, 16528188, 16528189, 16528190, 16528191, 16528191, 16528192, 16528191, 16528195, 16528193, 16528193, 16528193, 16528193, 16528194, 16528198, 16528202, 17519648, 17521416, 16528204, 17521418, 16806631, 16806631, 16806632, 16859513, 16806632, 16528206, 16705908, 16806633, 16859513, 17521406, 17528397, 16528210, 16615342, 16806632, 16806633, 16806633, 16859513, 17521406, 17521421, 16806636, 17521409, 17521424, 16806637, 16532568, 16808821, 16702536, 16893827, 16709990, 16710065, 16710119, 17612388, 16743172, 17628907, 16791131, 17652876, 16847284, 16966177, 16883625, 16984350, 16893342, 16989208, 16917191, 17001132, 16951528, 16951606, 16951684, 17737499, 17085058, 17085059, 17085074, 17085059, 17085063, 17085074, 17085060, 17085061, 17085062, 17085063, 17085072, 17085072, 17085073, 17085073, 17085074, 17085074, 17085075, 17085075, 17085075, 17085064, 17085076, 17085077, 17085078, 17085080, 17085067, 17085067, 17085078, 17085078, 17085078, 17085079, 17085076, 17085084, 17085085, 17085085, 17085087, 17085085, 17085086, 17085087, 17085086, 17085087, 17085087, 17085088, 17085087, 17085088, 17137953, 17085088, 17085089, 17085089, 17085090, 17137955, 17085090, 17137953, 17137954, 17137954, 17137955, 17137955, 17137956, 17137956, 17137957, 17137957, 17329459, 17394275, 17408786, 17414268, 17675439, 17712016, 17771872, 17788161, 17798093, 17799847, 17799847, 17799848, 17799849, 17799850, 17799850, 17799851, 17799852, 17799852, 17799853, 17799854, 17799854, 17799855, 17799855, 17799856, 17799856, 17799857, 17799857, 17799858, 17799859, 17799860, 17799860, 17799861, 17799861, 17799862, 17799862, 17799863, 17799863, 17803439, 17804195, 17804196, 17804197, 17806838, 17806839, 17806840, 17831606, 18025736, 18330235, 18330238, 18476014, 18519055, 18606576, 18631981, 18658033, 18658034, 18686565, 18686566, 18686584, 18686588, 18686589, 18686589, 20295007, 17085092, 17137953, 17137955, 17137956, 17137956, 17137957, 17137957, 17585391, 17799848, 17799848, 17799851, 17799855, 17799856, 17799860, 17799861, 17799863, 17799863, 17799864, 17804196, 17804197, 17806839, 17806840, 18658034, 18686566, 17137958, 17799864, 17190818, 17190820, 17190834, 17190835, 17190820, 17190820, 17190821, 17190821, 17190833, 17190834, 17190835, 17190835, 17190836, 17190821, 17190821, 17190834, 17190835, 17190836, 17190836, 17190821, 17190822, 17190835, 17190836, 17190836, 17190837, 17190822, 17190823, 17190835, 17190836, 17190837, 17190837, 17190824, 17190835, 17190836, 17190837, 17190838, 17190836, 17190838, 17190838, 17190838, 17190839, 17190849, 17190849, 17190850, 17190850, 17824922, 17852726, 18739445, 17190850, 17852727, 17852728, 17852743, 18739445, 17190851, 17382338, 17774779, 17852728, 17852732, 17852739, 17852741, 17852743, 17857076, 17859719, 18150311, 17190852, 17852728, 17852731, 17852734, 17852734, 17852740, 17190852, 17794034, 17852728, 17852729, 17852729, 17852731, 17852732, 17852735, 17852741, 17852742, 17852744, 17859719, 18078614, 18794627, 17190855, 17202390, 17320113, 17382340, 17382340, 17382341, 17774768, 17774778, 17850974, 17852728, 17852729, 17852729, 17852730, 17852731, 17852732, 17852733, 17852733, 17852734, 17852734, 17852736, 17852736, 17852737, 17852740, 17852740, 17852742, 17852742, 17852743, 17852744, 17852744, 17852745, 17859721, 18528893, 18739447, 18739470, 19453696, 17850976, 17852740, 17213945, 17864283, 17374912, 17944772, 17449384, 17982000, 17573838, 17573839, 17573842, 17573844, 17573845, 17573844, 17573847, 18044228, 18044228, 18720396, 18044240, 18044233, 18044233, 18044239, 17703478, 18109050, 17732492, 19010295, 17743457, 18129049, 17846287, 17846287, 18180462, 18180460, 17941876, 18228249, 18085709, 18300181, 18177886, 18178014, 18178141, 18346424, 18265800, 18390212, 18338952, 18338967, 18338987, 18426803, 18358707, 18358723, 18358725, 18436668, 18436678, 18436674, 18397227, 18454167, 18458731, 18458868, 18459003, 18459037, 18486842, 18486846, 18491242, 18491356, 18491470, 18503042, 18511107, 18511107, 18511111, 18512863, 18512866, 18512876, 18512877, 18517211, 18512877, 18512865, 18514605, 18514604, 18514605, 18514605, 18514619, 18514622, 18514605, 18514606, 18514606, 18514608, 18514608, 18514609, 18514609, 18514610, 18514611, 18514611, 18514612, 18514612, 18514614, 18514615, 18514615, 18514616, 18514617, 18514617, 18514618, 18514618, 18514619, 18514619, 18514620, 18514620, 18514621, 18514621, 18514622, 18514623, 18514623, 18514624, 18514624, 18514625, 18514625, 18514626, 18514627, 18514636, 18514606, 18514607, 18514608, 18514608, 18514609, 18514610, 18514610, 18514611, 18514611, 18514612, 18514612, 18514613, 18514614, 18514615, 18514617, 18514617, 18514618, 18514618, 18514619, 18514619, 18514620, 18514621, 18514621, 18514622, 18514622, 18514623, 18514623, 18514624, 18514624, 18514625, 18514626, 18514636, 18514610, 18514614, 18514617, 18514618, 18514619, 18514621, 18514624, 18514625, 18514633, 18514610, 18514612, 18514617, 18514617, 18514618, 18514618, 18514619, 18514620, 18514621, 18514622, 18514623, 18514636, 18514616, 18514619, 18514637, 18514623, 18514623, 18514638, 18514611, 18514613, 18514613, 18514614, 18514615, 18514615, 18514621, 18514621, 18514623, 18514624, 18514626, 18514627, 18514628, 18514638, 18514612, 18514613, 18514613, 18514615, 18514615, 18514616, 18514617, 18514618, 18514618, 18514620, 18514620, 18514621, 18514621, 18514622, 18514622, 18514623, 18514623, 18514624, 18514627, 18514628, 18514639, 18514615, 18514619, 18514621, 18514624, 18514625, 18514639, 18514616, 18514617, 18514619, 18514621, 18514623, 18514624, 18514625, 18514640, 18514617, 18514620, 18514621, 18514623, 18514624, 18514626, 18514640, 18514616, 18514618, 18514621, 18514625, 18514623, 18514626, 18514626, 18514628, 18514628, 18514642, 18514619, 18514619, 18514622, 18514622, 18514624, 18514626, 18514627, 18514627, 18514629, 18514642, 18514642, 18514624, 18514626, 18514627, 18514627, 18514628, 18514642, 18514621, 18514622, 18514623, 18514625, 18514627, 18514628, 18514628, 18514630, 18514643, 18514622, 18514623, 18514625, 18514626, 18514627, 18514628, 18514628, 18514629, 18514643, 18514623, 18514624, 18514625, 18514626, 18514628, 18514628, 18514629, 18514644, 18514626, 18514627, 18514627, 18514644, 18514624, 18514625, 18514626, 18514627, 18514628, 18514628, 18514629, 18514630, 18514627, 18514629, 18514630, 18514630, 18514631, 18514645, 18514626, 18514627, 18514628, 18514628, 18514629, 18514629, 18514630, 18514632, 18514633, 18514633, 18514646, 18514646, 18514629, 18514629, 18514630, 18514631, 18514645, 18514646, 18514647, 18514742, 18514629, 18514630, 18514630, 18514631, 18514631, 18514632, 18514632, 18514637, 18514647, 18514647, 18514630, 18514630, 18514631, 18514631, 18514632, 18514632, 18514635, 18514647, 18514648, 18514630, 18514631, 18514632, 18514632, 18514633, 18514633, 18514639, 18514641, 18514647, 18514648, 18514648, 18514631, 18514632, 18514632, 18514633, 18514633, 18514634, 18514635, 18514636, 18514648, 18514649, 18514744, 18514632, 18514633, 18514633, 18514634, 18514634, 18514636, 18514637, 18514649, 18514649, 18514650, 18514745, 18514633, 18514634, 18514634, 18514635, 18514635, 18514636, 18514637, 18514639, 18514649, 18514650, 18514634, 18514635, 18514635, 18514636, 18514638, 18514640, 18514648, 18514650, 18514650, 18514635, 18514636, 18514636, 18514637, 18514637, 18514638, 18514638, 18514639, 18514650, 18514650, 18514651, 18514652, 18514654, 18514636, 18514637, 18514637, 18514638, 18514638, 18514639, 18514639, 18514640, 18514640, 18514641, 18514641, 18514650, 18514651, 18514651, 18514652, 18514653, 18740507, 19401339, 18514637, 18514638, 18514638, 18514639, 18514639, 18514640, 18514640, 18514641, 18514647, 18514651, 18514651, 18514652, 18514652, 18514653, 18514654, 18518969, 18812204, 19401362, 18514638, 18514639, 18514639, 18514640, 18514652, 18514652, 18514653, 19401340, 19401363, 18514639, 18514640, 18514641, 18514642, 18514652, 18514640, 18514641, 18514641, 18514642, 18514646, 18514653, 18514653, 18514654, 18518970, 18518972, 19321352, 19401341, 19401363, 19401364, 18514641, 18514642, 18514642, 18514643, 18514644, 18514645, 18514649, 18514653, 18514653, 18514654, 18518972, 18518972, 18521613, 18812207, 19386446, 19401341, 19401364, 18514642, 18514643, 18514644, 18514654, 18514654, 18521614, 18700399, 18775121, 19190788, 19401342, 19401365, 18514643, 18514644, 18514644, 18514651, 18514654, 18514655, 18518973, 18521615, 18812207, 19401342, 19401365, 18514644, 18514645, 18514648, 18514654, 18514655, 18514655, 18514751, 18518973, 18521615, 19401366, 18514647, 18514648, 18514654, 18514655, 18514655, 18514656, 18514659, 19372810, 19401343, 18514651, 18514656, 18514656, 19401367, 18514655, 18514656, 18514657, 19346760, 19401367, 18514657, 18514658, 18514652, 19401346, 18514653, 18514659, 18514660, 18514660, 18514661, 18514662, 18514662, 19401350, 19401374, 18514664, 18514665, 18514665, 18521626, 18514665, 18514666, 18518984, 18521627, 19401353, 18514666, 18514667, 18514667, 18514670, 18514762, 18518984, 18518984, 18518985, 18518985, 18518986, 18521626, 18521627, 18521627, 18521628, 18812216, 18812219, 19321365, 19346769, 19372821, 19372822, 19401354, 19401377, 19401410, 18514667, 18514668, 18514668, 18514669, 18514669, 18514670, 18514762, 18514762, 18518228, 18518984, 18518984, 18518985, 18518985, 18521626, 18521626, 18521627, 18521627, 18521628, 18521628, 18521629, 18756270, 18786063, 18812218, 18812219, 18812219, 18812220, 18812220, 18812221, 18841211, 18867345, 18986516, 19190800, 19190801, 19190802, 19190802, 19290594, 19321365, 19346770, 19346770, 19372821, 19372822, 19401354, 19401377, 19401377, 19401406, 19671137, 21925014, 18514668, 18518985, 18518985, 18518986, 18521627, 18521628, 18521628, 18681283, 18796669, 18812220, 18997934, 19045024, 19190802, 19190803, 19346770, 19372822, 19372823, 19401354, 19401355, 19401405, 20164331, 18514763, 18518985, 18518986, 18521627, 18521628, 18521628, 18812219, 18812221, 19190802, 19321366, 19321366, 19346771, 19401355, 19401355, 19401378, 18518987, 19401356, 18518987, 18521629, 19401356, 19401379, 19401380, 18518988, 19401380, 18521631, 18514867, 18514867, 18519090, 18519090, 18519091, 18521732, 18521734, 18812322, 19190905, 19346875, 19401459, 19401482, 18521803, 18521804, 19324941, 19404930, 18523301, 18523302, 18523316, 18523317, 18523302, 18523303, 18523316, 18523317, 18523318, 18523303, 18523316, 18523317, 18523318, 18523318, 18523305, 18523316, 18523316, 18523317, 18523318, 18523319, 18523317, 18523319, 18523320, 18523331, 18523331, 18523332, 18525958, 18525959, 18525959, 18685614, 18760600, 18816552, 19345917, 18523331, 18523332, 18525936, 19405709, 18523333, 18525959, 18525960, 18525960, 18760603, 18790395, 19325698, 19351102, 19377155, 19405687, 19405710, 19405738, 18525961, 18525960, 18525960, 18525961, 18525961, 18525962, 18525963, 18538340, 18574367, 18685616, 18760602, 18816552, 18816552, 18816553, 18816554, 18816554, 18816555, 18930154, 19049337, 19171203, 19325699, 19351103, 19377155, 19377156, 19405687, 19405688, 19405709, 19405710, 19405711, 19405736, 19405737, 19405738, 18528551, 18528575, 18528600, 18528587, 18528601, 18528601, 18528587, 18528588, 18528598, 18528600, 18528601, 18528602, 18528603, 18528588, 18528600, 18528601, 18528601, 18528602, 18528602, 18528603, 18528603, 18528602, 18528603, 18528604, 18528603, 18528604, 18528604, 18528605, 18528607, 19328337, 19353743, 19408327, 18819193, 18819195, 19353743, 18528616, 18528617, 18819194, 19328339, 19353744, 19379796, 19379797, 19408328, 19408351, 19408351, 18747494, 19408329, 19408352, 19408417, 18528618, 18688257, 18747495, 18819195, 19197776, 19353745, 19408329, 19408352, 19408352, 18819195, 19328341, 19408330, 18763246, 18819195, 18819196, 18819197, 18931019, 19051980, 19051990, 19051999, 19129400, 19197777, 19197778, 19353746, 19353757, 19371605, 19379798, 19379798, 19379799, 19408330, 19408330, 19408353, 19408359, 18819197, 18553356, 19340715, 18578135, 19378510, 18625418, 18625480, 18625551, 19456810, 18847910, 18847911, 18847911, 19567982, 18907151, 18978849, 19487998, 18886203, 21195586, 18966390, 18966391, 18966393, 18966393, 18966394, 18966396, 19627225, 19270895, 19547236, 19627225, 18997872, 18997882, 18997886, 18997885, 18997888, 18997888, 19027677, 18997897, 19642969, 19432417, 19562982, 19053837, 19642972, 19035614, 19661886, 19057476, 19057483, 19057486, 19102641, 19644243, 19413466, 19078681, 19078753, 19078819, 19683456, 19109784, 19109784, 19109787, 19109771, 19109785, 19109786, 19109786, 19109787, 19109774, 19109787, 19109787, 19109788, 19109787, 19109789, 19109788, 19109788, 19109790, 19109788, 19109789, 19109789, 19109802, 19342571, 19342590, 19342591, 19342592, 19488367, 19488368, 19531411, 19644337, 19670389, 19698921, 19698921, 19698944, 19223388, 19342592, 19488368, 19488371, 19644337, 19698922, 19109804, 19644338, 19284085, 19639154, 19644338, 19164911, 19644339, 19698924, 19147809, 19717936, 19167766, 19517356, 19220030, 19220035, 19543490, 19674055, 19333446, 19782224, 19336990, 19336994, 19732535, 19757943, 19458381, 19873219, 19873245, 19481212, 19884632, 19575396, 19575404, 19575414, 19575416, 19575424, 19575425, 19575407, 19575427, 19931736, 19931746, 19877163, 19851766, 19877170, 19931755, 19730193, 19730326, 19730457, 20009254, 19769432, 19861232, 19819091, 20053576, 19866948, 19866947, 19866949, 19866950, 19866950, 19866951, 19866937, 19866949, 19866949, 19866949, 19866951, 19866952, 19866952, 19866953, 19866953, 19866953, 19866952, 19866952, 19866953, 19866954, 20077524, 20077502, 19997512, 19997513, 20022918, 20077503, 20077503, 19866967, 20022919, 20077504, 20077526, 20022920, 20048972, 20077527, 20022920, 20077505, 20022921, 20077505, 19953033, 19953036, 20120543, 20120546, 20066536, 20122712, 20128076, 20128078, 20128077, 20128079, 20128083, 20153482, 20208066, 20153483, 20179534, 20179536, 20179536, 20208068, 20208091, 20168516, 20173700, 20178873, 20178874, 20178874, 20178892, 20178896, 20178897, 20178898, 20178899, 20178899, 20178915, 20178917, 20178899, 20178917, 20178899, 20178900, 20178918, 20178917, 20178918, 20233476, 20233480, 20233482, 20178924, 20178942, 20204951, 20204951, 20204952, 20218587, 20233482, 20233483, 20233505, 20233506, 20233510, 21841922, 21841922, 20178943, 20204951, 20204951, 20218588, 20233472, 20233483, 20233506, 20233484, 20233492, 20233499, 20233501, 20233501, 20233524, 20214603, 20222796, 20230989, 20230991, 20230992, 20230992, 20230979, 20230992, 20230993, 20230993, 20230991, 20230992, 20230993, 20230993, 20230993, 20230995, 20230992, 20231006, 20259523, 20259523, 20259524, 20259547, 20259524, 20259570, 20259524, 20259525, 20259547, 20259548, 20259548, 20259526, 20258263, 20258264, 20273159, 20288030, 20288041, 20288042, 20288043, 20288043, 20288044, 20288044, 20288045, 20288045, 20288051, 20288053, 20288058, 20288062, 20288063, 20288064, 20288064, 20288065, 20288067, 20288118, 20288043, 20288044, 20288044, 20288045, 20288052, 20288058, 20288064, 20288064, 20288065, 20288044, 20288045, 20288045, 20288046, 20288059, 20288065, 20288065, 20288045, 20288046, 20288059, 20288063, 20288065, 20288066, 20288046, 20288066, 20288047, 20288048, 20288049, 20288050, 20288055, 20288057, 20288062, 20288063, 20288063, 20288064, 20288065, 20288066, 20288066, 20288067, 20288067, 20288048, 20288063, 20288067, 20288067, 20288065, 20288067, 20288068, 20288069, 20288056, 20288063, 20288070, 20288073, 20288061, 20288062, 20288065, 20288062, 20288063, 20288074, 20288065, 20288075, 20288076, 20288141, 20288077, 20288077, 20288078, 20288080, 20288080, 20288081, 20288078, 20288082, 20288083, 20288083, 20288083, 20288083, 20288084, 20288084, 20288085, 20288085, 20288086, 20288086, 20288086, 20288087, 20288087, 20288117, 20288088, 20288089, 20288089, 20288090, 20288090, 20288091, 20288091, 20288092, 20288092, 20288093, 20288093, 20288094, 20288096, 20288097, 20288097, 20288099, 20288100, 20288101, 20288103, 20288103, 20288104, 20288104, 20288105, 20288105, 20288106, 20288106, 20288107, 20288107, 20288108, 20288108, 20288109, 20288110, 20288110, 20288111, 20288111, 20288112, 20288112, 20288113, 20288114, 20288114, 20288115, 20288115, 20288116, 20288117, 20288118, 20288139, 20288140, 20288089, 20288090, 20288090, 20288091, 20288091, 20288092, 20288092, 20288093, 20288093, 20288094, 20288094, 20288096, 20288097, 20288098, 20288100, 20288102, 20288103, 20288106, 20288107, 20288107, 20288108, 20288109, 20288109, 20288110, 20288111, 20288114, 20288115, 20288115, 20288141, 20288090, 20288091, 20288091, 20288092, 20288093, 20288093, 20288103, 20288104, 20288108, 20288109, 20288112, 20288116, 20288091, 20288092, 20288092, 20288093, 20288094, 20288095, 20288099, 20288102, 20288104, 20288106, 20288108, 20288108, 20288110, 20288110, 20288112, 20288116, 20288092, 20288093, 20288094, 20288094, 20288095, 20288096, 20288099, 20288102, 20288105, 20288106, 20288107, 20288109, 20288110, 20288110, 20288111, 20288112, 20288115, 20288116, 20288117, 20288093, 20288094, 20288094, 20288095, 20288096, 20288097, 20288098, 20288101, 20288102, 20288103, 20288105, 20288106, 20288106, 20288107, 20288107, 20288108, 20288108, 20288109, 20288109, 20288110, 20288110, 20288111, 20288111, 20288112, 20288112, 20288113, 20288113, 20288114, 20288116, 20288116, 20288117, 20288117, 20288118, 20288118, 20288119, 20288119, 20288121, 20288126, 20288143, 20288095, 20288096, 20288105, 20288108, 20288109, 20288109, 20288110, 20288113, 20288095, 20288096, 20288096, 20288097, 20288097, 20288098, 20288100, 20288101, 20288103, 20288104, 20288106, 20288107, 20288108, 20288110, 20288110, 20288111, 20288112, 20288114, 20288114, 20288117, 20288096, 20288097, 20288100, 20288101, 20288101, 20288104, 20288107, 20288108, 20288109, 20288110, 20288111, 20288112, 20288113, 20288114, 20288118, 20288097, 20288098, 20288102, 20288106, 20288107, 20288108, 20288111, 20288112, 20288115, 20288098, 20288099, 20288108, 20288111, 20288115, 20288120, 20288099, 20288100, 20288100, 20288101, 20288101, 20288103, 20288104, 20288105, 20288106, 20288107, 20288107, 20288108, 20288110, 20288110, 20288111, 20288111, 20288112, 20288112, 20288113, 20288113, 20288114, 20288116, 20288116, 20288118, 20288119, 20288120, 20288137, 20288106, 20288111, 20288114, 20288114, 20288116, 20288117, 20288122, 20288105, 20288113, 20288114, 20288116, 20288106, 20288114, 20288116, 20288116, 20288118, 20288111, 20288118, 20288116, 20288124, 20288106, 20288107, 20288115, 20288119, 20288124, 20288111, 20288114, 20288114, 20288115, 20288116, 20288116, 20288117, 20288118, 20288119, 20288119, 20288117, 20288116, 20288117, 20288117, 20288116, 20288117, 20288131, 20288115, 20288117, 20288117, 20288118, 20288120, 20288120, 20288121, 20288126, 20288127, 20288114, 20288116, 20288119, 20288121, 20288121, 20288116, 20288119, 20288121, 20288122, 20288124, 20288124, 20288117, 20288120, 20288120, 20288122, 20288118, 20288119, 20288120, 20288120, 20288121, 20288122, 20288123, 20288123, 20288125, 20288125, 20288126, 20288128, 20288129, 20288130, 20288119, 20288121, 20288121, 20288122, 20288123, 20288124, 20288125, 20288126, 20288130, 20288132, 20288121, 20288123, 20288124, 20288125, 20288139, 20288121, 20288122, 20288123, 20288123, 20288125, 20288127, 20288127, 20288128, 20288130, 20288131, 20288132, 20288122, 20288123, 20288124, 20288125, 20288125, 20288126, 20288127, 20288128, 20288130, 20288131, 20288132, 20288135, 20288140, 20288123, 20288124, 20288124, 20288125, 20288126, 20288127, 20288130, 20288132, 20288124, 20288126, 20288126, 20288127, 20288128, 20288129, 20288129, 20288131, 20288132, 20288132, 20288133, 20288134, 20288125, 20288126, 20288127, 20288129, 20288129, 20288130, 20288133, 21051056, 20288127, 20288127, 20288128, 20288129, 20288130, 20288130, 20288132, 20288133, 20288134, 20288134, 20288135, 20288135, 20288136, 20288127, 20288128, 20288128, 20288129, 20288130, 20288128, 20288129, 20288130, 20288131, 20288133, 20288134, 20288134, 20288135, 20288135, 20288136, 20288137, 20288138, 20288143, 20288129, 20288130, 20288130, 20288131, 20288131, 20288132, 20288134, 20288134, 20288135, 20288135, 20288136, 20288137, 20288137, 20288138, 20288139, 20288172, 20288131, 20288131, 20288132, 20288132, 20288134, 20288135, 20288136, 20288136, 20288137, 20288144, 20288161, 20288131, 20288132, 20288135, 20288137, 20288132, 20288133, 20288133, 20288135, 20288136, 20288136, 20288138, 20288133, 20288134, 20288134, 20288135, 20288136, 20288136, 20288137, 20288137, 20288138, 20288138, 20288139, 20288139, 20288140, 20288141, 20288141, 20288142, 20288143, 20288143, 20288145, 20288145, 20288146, 20288148, 20288157, 20288134, 20288135, 20288135, 20288136, 20288136, 20288137, 20288137, 20288138, 20288138, 20288139, 20288139, 20288140, 20288140, 20288141, 20288141, 20288142, 20288148, 20288135, 20288136, 20288137, 20288137, 20288138, 20288138, 20288139, 20288139, 20288140, 20288140, 20288141, 20288142, 20288137, 20288137, 20288139, 20288139, 20288142, 20288138, 20288139, 20288139, 20288140, 20288138, 20288139, 20288140, 20288140, 20288139, 20288140, 20288140, 20288141, 20288141, 20288142, 20288142, 20288143, 20288143, 20288144, 20288146, 20288148, 20288149, 20288151, 20288140, 20288141, 20288141, 20288142, 20288142, 20288143, 20288143, 20288144, 20288150, 20288151, 20343270, 20288141, 20288142, 20288142, 20288143, 20288143, 20288144, 20288144, 20288145, 20288146, 20288147, 20288149, 20288150, 20288167, 20288142, 20288143, 20288143, 20288144, 20288144, 20288145, 20288145, 20288146, 20288147, 20288148, 20288148, 20288150, 20288150, 20288163, 20288167, 20288143, 20288144, 20288144, 20288145, 20288145, 20288146, 20288146, 20288147, 20288148, 20288149, 20288149, 20288150, 20288150, 20288151, 20288151, 20288153, 20288161, 20288167, 20288168, 20288144, 20288145, 20288145, 20288146, 20288146, 20288148, 20288149, 20288149, 20288151, 20288151, 20288152, 20288167, 20288168, 20288145, 20288146, 20288146, 20288147, 20288147, 20288148, 20288148, 20288149, 20288149, 20288150, 20288150, 20288151, 20288152, 20288152, 20288153, 20288154, 20288159, 20288166, 20288167, 20288167, 20288169, 20288146, 20288147, 20288147, 20288148, 20288148, 20288149, 20288149, 20288150, 20288150, 20288151, 20288151, 20288152, 20288152, 20288153, 20288154, 20288154, 20288155, 20288159, 20288162, 20288164, 20288167, 20288169, 20288147, 20288148, 20288148, 20288149, 20288149, 20288150, 20288150, 20288152, 20288152, 20288153, 20288154, 20288155, 20288157, 20288170, 20288148, 20288149, 20288149, 20288150, 20288150, 20288151, 20288151, 20288152, 20288152, 20288153, 20288153, 20288154, 20288154, 20288155, 20288160, 20288163, 20288165, 20288168, 20288170, 20288149, 20288150, 20288150, 20288151, 20288151, 20288152, 20288152, 20288153, 20288153, 20288154, 20288154, 20288155, 20288156, 20288157, 20288158, 20288159, 20288160, 20288162, 20288164, 20288166, 20288169, 20288170, 20288171, 20288150, 20288151, 20288151, 20288152, 20288152, 20288153, 20288153, 20288154, 20288154, 20288155, 20288155, 20288156, 20288156, 20288160, 20288161, 20288162, 20288165, 20288171, 20288171, 20288151, 20288152, 20288152, 20288153, 20288154, 20288154, 20288155, 20288155, 20288157, 20288172, 20288152, 20288153, 20288153, 20288154, 20288154, 20288155, 20288155, 20288156, 20288157, 20288166, 20288172, 20288153, 20288154, 20288155, 20288155, 20288156, 20288156, 20288157, 20288158, 20288161, 20288164, 20288166, 20288166, 20288168, 20288171, 20288171, 20288173, 20288154, 20288155, 20288155, 20288156, 20288156, 20288157, 20288157, 20288158, 20288158, 20288160, 20288161, 20288162, 20288163, 20288165, 20288168, 20288171, 20288173, 20288173, 20288155, 20288156, 20288156, 20288157, 20288157, 20288158, 20288160, 20288162, 20288168, 20288174, 20288156, 20288157, 20288157, 20288158, 20288162, 20288164, 20288157, 20288158, 20288158, 20288159, 20288159, 20288160, 20288163, 20288165, 20288166, 20288169, 20288174, 20288175, 20288158, 20288159, 20288159, 20288160, 20288160, 20288161, 20288161, 20288162, 20288163, 20288164, 20288165, 20288165, 20288166, 20288167, 20288167, 20288168, 20288170, 20288171, 20288172, 20288173, 20288173, 20288174, 20288174, 20288175, 20288175, 20288159, 20288160, 20288160, 20288161, 20288161, 20288162, 20288163, 20288163, 20288164, 20288164, 20288165, 20288165, 20288166, 20288167, 20288167, 20288168, 20288168, 20288169, 20288170, 20288170, 20288171, 20288172, 20288173, 20288173, 20288174, 20288174, 20288175, 20288175, 20288176, 20288160, 20288161, 20288161, 20288162, 20288163, 20288163, 20288165, 20288165, 20288166, 20288166, 20288168, 20288168, 20288170, 20288170, 20288171, 20288171, 20288172, 20288174, 20288175, 20288176, 20288176, 20288161, 20288162, 20288163, 20288164, 20288167, 20288173, 20288175, 20288176, 20288177, 20288162, 20288164, 20288164, 20288165, 20288167, 20288169, 20288169, 20288170, 20288173, 20288177, 20288177, 20288164, 20288164, 20288165, 20288165, 20288166, 20288166, 20288167, 20288168, 20288169, 20288169, 20288170, 20288170, 20288171, 20288171, 20288172, 20288172, 20288173, 20288174, 20288176, 20288176, 20288177, 20288177, 20288178, 20288165, 20288178, 20288178, 20288165, 20288166, 20288169, 20288172, 20288178, 20288179, 20288166, 20288167, 20288168, 20288169, 20288169, 20288174, 20288177, 20288178, 20288179, 20288167, 20288168, 20288169, 20288170, 20288179, 20288180, 20288168, 20288169, 20288169, 20288170, 20288170, 20288171, 20288177, 20288178, 20288180, 20288180, 20288169, 20288170, 20288171, 20288172, 20288174, 20288175, 20288177, 20288180, 20288181, 20288170, 20288171, 20288171, 20288172, 20288173, 20288174, 20288176, 20288178, 20288181, 20288181, 20288171, 20288173, 20288173, 20288176, 20288176, 20288180, 20288181, 20288181, 20288172, 20288176, 20288177, 20288180, 20288182, 20288182, 20288173, 20288174, 20288175, 20288175, 20288176, 20288176, 20288177, 20288177, 20288178, 20288180, 20288180, 20288181, 20288182, 20288182, 20288183, 20288176, 20288176, 20288177, 20288181, 20288182, 20288183, 20288175, 20288182, 20288183, 20288184, 20288197, 20288176, 20288178, 20288178, 20288179, 20288180, 20288180, 20288181, 20288183, 20288184, 20288184, 20288177, 20288179, 20288179, 20288183, 20288184, 20288184, 20288185, 20288183, 20288184, 20288184, 20288185, 20288180, 20288181, 20288186, 20288180, 20288181, 20288183, 20288186, 20288186, 20288181, 20288182, 20288184, 20288185, 20288186, 20288186, 20288187, 20288182, 20288183, 20288183, 20288185, 20288186, 20288186, 20288187, 20288187, 20288210, 20288186, 20288187, 20288187, 20288188, 20288186, 20288187, 20288188, 20288188, 20288187, 20288187, 20288188, 20288189, 20288189, 20288189, 20288189, 20288189, 20288190, 20288190, 20288189, 20288190, 20288190, 20288191, 20288190, 20288191, 20288191, 22858654, 20288191, 20288192, 20288192, 20288193, 20288194, 20288194, 20288195, 20288196, 20288197, 20288199, 20288200, 20288203, 20288204, 20288205, 20288205, 20288206, 20288206, 20288210, 20288211, 20288211, 20288212, 20288213, 20288214, 20288214, 20288215, 20288216, 20326165, 20343296, 20343297, 20343297, 20343298, 20343299, 20343299, 20397529, 20416447, 20575659, 20575662, 20733821, 20733822, 20733822, 20733824, 21001461, 21001461, 21002365, 21002366, 21002366, 21002367, 21002367, 21051090, 21051090, 21051091, 21051092, 21051092, 21051094, 21051094, 21051095, 21550463, 21550464, 21550464, 21550465, 21896558, 21896581, 22056963, 22182615, 22278321, 22497423, 22733761, 22811777, 22811777, 22858655, 22962078, 34826259, 20288194, 20288195, 20288195, 20288196, 20288197, 20288197, 20288198, 20288199, 20288200, 20288201, 20288202, 20288202, 20288203, 20288203, 20288204, 20288204, 20288205, 20288206, 20288206, 20288207, 20288208, 20288209, 20288210, 20288210, 20288211, 20288211, 20288212, 20288212, 20288213, 20288213, 20288214, 20288214, 20288215, 20288216, 20288216, 20343298, 21002368, 21550466, 20288195, 20288196, 20288197, 20288199, 20288199, 20288201, 20288205, 20288206, 20288207, 20288210, 20288211, 20288212, 20288212, 20288213, 20288213, 20288214, 20288214, 20288215, 20288215, 20288196, 20288207, 20288214, 20288217, 20288200, 20288200, 20288202, 20288203, 20288207, 20733824, 20288201, 20288204, 20288210, 20288210, 20288215, 20288216, 20288218, 20288201, 20288215, 20288218, 20288206, 20288210, 20288210, 20288215, 20288218, 20288219, 20288205, 20288218, 20288212, 20288219, 20288222, 20288207, 20288209, 20288213, 20288217, 20288217, 20288218, 20288218, 20288219, 20288220, 20288221, 20288223, 21002373, 20288222, 20288213, 20288214, 20288218, 20288220, 20288222, 20288223, 20288214, 20288219, 20288220, 20288222, 20288215, 20288224, 20288222, 20288216, 20288217, 21550475, 20288217, 20288217, 20288219, 22278333, 20288217, 20288224, 20288225, 20288228, 20288218, 20288219, 20288221, 20288223, 20288224, 20288225, 20288225, 20288226, 20288227, 21896571, 20288222, 20288222, 20288225, 20288226, 20288227, 20288227, 20288229, 20343309, 21002379, 20288224, 20288225, 20288227, 20288229, 20288227, 20288227, 20288224, 20288229, 20288226, 20288226, 20288227, 20288227, 20288229, 20288230, 20288227, 20288228, 20288229, 20288231, 20288227, 20288228, 20288229, 20288231, 20288228, 20288229, 20288230, 20288230, 20288232, 20343314, 20288229, 20288230, 20288230, 20288231, 20288232, 20288230, 20288231, 20288231, 20288232, 20288232, 20288233, 20288231, 20288232, 20288233, 20288233, 20288234, 20288235, 20343315, 20288232, 20288233, 20288234, 20288233, 20288234, 20288234, 20288235, 20288235, 20288236, 20288234, 20288235, 20288235, 20288236, 20288237, 20288236, 20288237, 20288237, 20343318, 20288237, 20288238, 20288238, 20288239, 20288240, 20288240, 20288241, 20288277, 20288295, 20324624, 20324683, 20343316, 20343318, 20343319, 20343320, 20343320, 20343321, 20343321, 20343322, 20343322, 20343323, 20449262, 20548371, 20575683, 20575684, 20603574, 20733842, 20733844, 20733845, 20733845, 20943320, 20943321, 21001482, 21001482, 21001484, 21001485, 21002388, 21002389, 21002389, 21002390, 21002390, 21051112, 21051113, 21051113, 21051114, 21051115, 21051116, 21051118, 21125702, 21550487, 21550488, 21550488, 21896580, 21896581, 21896581, 21896582, 22087348, 22278351, 22623338, 22811801, 22858678, 22962079, 20288240, 20288278, 20299528, 20324625, 20343320, 20343320, 20343321, 20343321, 20343322, 20343323, 20343324, 20349933, 20454048, 20575685, 20733845, 20733846, 20733848, 20943321, 21002389, 21002389, 21002390, 21002390, 21002391, 21051113, 21051115, 21051118, 21550488, 21896581, 21896582, 22858679, 20343320, 20343321, 20343322, 20343322, 20343323, 20397557, 20733845, 20733846, 20943322, 21002389, 21002389, 21002391, 21051114, 21051117, 21896582, 20343323, 20361710, 20288391, 20343376, 20343430, 20343433, 21051229, 20310829, 20354622, 20361064, 20361068, 20361140, 20361142, 20361198, 20361213, 20361215, 20379835, 20379835, 20379836, 21038903, 21087629, 20364147, 20381279, 20398408, 20398409, 20398399, 20398400, 20398401, 20398401, 20398402, 20398402, 20398403, 20398403, 20398415, 20398415, 20398416, 20398416, 20398417, 20398417, 20398401, 20398402, 20398402, 20398403, 20398405, 20398415, 20398416, 20398416, 20398402, 20398403, 20398404, 20398404, 20398415, 20398416, 20398416, 20398417, 20398417, 20398418, 20398403, 20398404, 20398416, 20398417, 20398417, 20398418, 20398418, 20398417, 20398417, 20398418, 20398418, 20398419, 20398419, 20398405, 20398406, 20398417, 20398418, 20398418, 20398419, 20398420, 20398406, 20398418, 20398418, 20398419, 20398419, 20398421, 20398418, 20398419, 20398422, 20398419, 20398420, 20398420, 21057481, 20788941, 20398431, 20398430, 20398431, 20398431, 20398432, 20529066, 20582981, 20658670, 20788940, 20788940, 20788941, 20954538, 21056579, 21057482, 21057484, 21057485, 21057485, 21057486, 21106209, 21106211, 21106213, 21605582, 21605584, 21951677, 22913819, 20398431, 20398432, 20398433, 20398435, 20452652, 20471565, 20658515, 20783441, 20788940, 20788941, 20788942, 20954935, 20985832, 20998417, 20998417, 20998418, 21057484, 21057485, 21057485, 21057486, 21106210, 21106211, 21106214, 21605583, 21605584, 21951677, 22913774, 22913820, 20398432, 20398433, 20398433, 20405782, 20416804, 20452652, 20532080, 20630779, 20788941, 20788941, 20788942, 20954936, 20991724, 20998417, 20998418, 20998419, 21056580, 21056581, 21057484, 21057485, 21057485, 21057486, 21057486, 21057487, 21106209, 21106210, 21106211, 21106211, 21106213, 21605583, 21605584, 21605585, 21951675, 21951676, 21951677, 21951678, 22472078, 22725522, 22866897, 22913775, 20398433, 20398434, 20398434, 20405783, 20471567, 20613020, 20630781, 20677865, 20788941, 20788942, 20788942, 20788943, 20998418, 20998418, 21056580, 21057485, 21057486, 21057486, 21057487, 21057487, 21106209, 21106210, 21106211, 21106211, 21106212, 21106212, 21605585, 21951676, 21951677, 21951678, 21951696, 22913775, 22913821, 20452653, 20788943, 20788945, 20998418, 20998418, 21050732, 21056582, 21057484, 21057487, 21106213, 21106213, 21951679, 21951679, 20788943, 21050733, 21057486, 21057487, 21057488, 21951679, 21605586, 21057488, 21106215, 21951680, 20411641, 21005030, 20413142, 20413146, 20413259, 21005781, 20413376, 21959170, 20435186, 20435307, 20435308, 20435431, 20435431, 21075990, 21075991, 20506879, 20506885, 20506885, 20506885, 20843172, 21009168, 20843175, 21160445, 21160447, 20544712, 20544713, 20544717, 21130632, 21130631, 22406593, 20610303, 20894883, 20619875, 21216940, 20659713, 21188132, 20665748, 20811534, 20767547, 21182983, 20808517, 21262535, 20827620, 21272086, 22166278, 20863141, 20863140, 20863141, 20863143, 20863143, 21289847, 21289847, 21021304, 21338573, 21338575, 23146137, 20918611, 21317581, 20918925, 20918925, 21865838, 21865839, 20957311, 20957312, 21068389, 21336931, 21168521, 21174021, 21179462, 21179463, 21179453, 21179464, 21179465, 21179466, 21179468, 21179469, 21179469, 21179451, 21179453, 21179466, 21179466, 21179467, 21179467, 21179468, 21179469, 21179466, 21179467, 21179467, 21179468, 21179468, 21179469, 21179469, 21179454, 21179467, 21179468, 21179470, 21179468, 21179469, 21179469, 21179471, 21179470, 21179472, 21179500, 22342200, 21448010, 21179482, 21179483, 21179484, 21193623, 21382249, 21388942, 21388943, 21447105, 21447105, 21448009, 21448009, 21448010, 21448010, 21496734, 21496734, 21496735, 21496736, 21496738, 21496739, 21996110, 22342202, 22342202, 22342225, 21388942, 21448008, 21448010, 21448011, 21448012, 21496734, 21179484, 21179485, 21388943, 21388944, 21448011, 21448011, 21448012, 21496736, 21496737, 21996110, 22342203, 21448011, 21448012, 21448013, 22978145, 21179486, 21448013, 21448013, 21179486, 21388944, 21448011, 21448012, 21496741, 22342205, 21179489, 21345463, 21388945, 21448013, 21448013, 21448014, 21462989, 22342205, 21388946, 21448013, 21448014, 21448014, 21448016, 21179533, 21448042, 21207780, 21510893, 21510722, 21613667, 21511441, 21511478, 21511479, 21554856, 21554959, 21614026, 21662752, 21573245, 21693622, 21585031, 21585032, 21650790, 21699519, 21598207, 21598316, 21598402, 21598417, 21598417, 21598403, 21598418, 21598418, 21598418, 21598419, 21598419, 21598419, 21598419, 21598422, 21598424, 21657486, 21598433, 21656581, 21657485, 21657486, 21706212, 22205585, 22551677, 22551678, 21656582, 21657484, 21657485, 21657486, 21657486, 21657487, 21657487, 21657488, 21706211, 21706212, 21706212, 22551679, 21657488, 22551679, 21657488, 21703042, 21703046, 21758522, 21709801, 21714737, 21714735, 21714737, 21714738, 21714739, 21714740, 21714741, 21714742, 21714742, 21714742, 21714805, 21714806, 21714806, 21714805, 21714807, 21714807, 21714808, 21714808, 21714809, 21714809, 22609839, 21714873, 21714873, 21714874, 21714874, 21715709, 21715711, 21715711, 21715712, 21715713, 21764436, 21764437, 21764438, 22609904, 21716536, 21716537, 21716549, 21716537, 21716537, 21716552, 21716538, 21716553, 21716538, 21716551, 21716552, 21716552, 21716554, 21716554, 21716538, 21716539, 21716539, 21716540, 21716553, 21716553, 21716554, 21716555, 21716539, 21716540, 21716540, 21716553, 21716554, 21716554, 21716555, 21716555, 21716540, 21716541, 21716552, 21716552, 21716553, 21716553, 21716554, 21716555, 21716555, 21716556, 21716541, 21716552, 21716553, 21716553, 21716554, 21716554, 21716555, 21716555, 21716556, 21716556, 21716553, 21716553, 21716554, 21716554, 21716555, 21716555, 21716556, 21716556, 21716557, 21716564, 21716566, 21716567, 21716567, 21716566, 21716567, 21716567, 21716568, 22264650, 22610743, 21716567, 21716569, 21765276, 21765277, 21765279, 22610743, 23572842, 21716567, 21716568, 21716568, 21716569, 21716569, 21765278, 22264651, 22264652, 22610745, 21716568, 21716569, 21716569, 21716570, 21765278, 21765279, 22264651, 22264651, 22610745, 22610746, 21716569, 21716570, 21716570, 21765277, 21765278, 21765279, 21765279, 21765280, 21765281, 21765283, 22264651, 22264653, 22264653, 22382119, 22610746, 23525966, 23572843, 23572901, 23676244, 21716570, 21716571, 21765278, 21765279, 21765279, 21765280, 21765280, 21765281, 21765281, 21765282, 21765283, 22264650, 22264652, 22264653, 22264653, 22476070, 22610746, 22610747, 23281187, 23572844, 23572889, 21716571, 21765279, 21765280, 21765281, 21765282, 21765284, 22254589, 22264651, 22264652, 22264654, 22264654, 22429211, 22610747, 22610747, 22610769, 23572844, 21758124, 21765278, 21765279, 21765279, 21765280, 21765280, 21765281, 21765281, 21765282, 21765282, 21765283, 21765283, 21765284, 21765284, 21765285, 21855606, 22264651, 22264653, 22264653, 22264654, 22264654, 22264655, 22264655, 22444790, 22536729, 22536730, 22536731, 22610746, 22610747, 22610747, 22610748, 22610769, 22992510, 22992513, 23525967, 23525967, 23525968, 23572845, 21746502, 21780250, 21799689, 21806844, 22306219, 21813986, 21814002, 21813987, 21813988, 21813989, 21814002, 21814003, 21813987, 21813989, 21813989, 21814003, 21814004, 21814006, 21814007, 21813989, 21813989, 21813990, 21813990, 21813991, 21813991, 21813992, 21813992, 21813993, 21814003, 21814004, 21814005, 21814005, 21814006, 21814006, 21814007, 21814007, 21813990, 21813990, 21814007, 21814008, 21813990, 21813991, 21813992, 21813992, 21813993, 21813993, 21814004, 21814005, 21814008, 21814008, 21814009, 21813991, 21813992, 21813993, 21813994, 21814005, 21814006, 21814006, 21814007, 21814008, 21814009, 21814009, 21814010, 21813992, 21813993, 21813993, 21813994, 21814005, 21814006, 21814008, 21814009, 21814010, 21814010, 21813994, 21813994, 21814008, 21814010, 21814010, 21814011, 21814011, 21813995, 21814007, 21814010, 21814011, 21814011, 21813995, 21813996, 21814008, 21814010, 21814011, 21814011, 21814012, 21814013, 21813996, 21813997, 21814007, 21814011, 21814012, 21814008, 21814009, 21814012, 21814012, 21814013, 21814010, 21814013, 21814014, 21814013, 21814019, 21814020, 21814023, 22313377, 22313377, 22313378, 22659470, 22659471, 22659471, 23574691, 23621568, 23621614, 23724991, 21814021, 21814024, 21814025, 22313378, 22659472, 22659494, 21814024, 23041237, 21814022, 21814023, 21814024, 21814026, 21859727, 22313379, 22659472, 22659472, 22659473, 21814025, 21814026, 22659473, 23574692, 21814025, 21814026, 21814026, 22659473, 21814025, 22659474, 21814027, 21814027, 22313381, 22313381, 22659473, 22659474, 21814027, 21814028, 21814029, 21950383, 22074043, 22270407, 22313378, 22313379, 22313380, 22313380, 22313381, 22313381, 22313382, 22313382, 22313383, 22493518, 22585458, 22659473, 22659474, 22659475, 22659475, 22712597, 22714175, 22802708, 22819880, 23041246, 23574694, 23574695, 23621572, 23621618, 21814028, 21814029, 22313381, 22313382, 22313383, 22313386, 22659474, 22659474, 22659475, 22659475, 22659476, 21814029, 22313382, 22313382, 22313384, 22659475, 22659475, 22659476, 23329916, 23574695, 22313382, 22313384, 22659475, 22659476, 22313384, 22493520, 22659476, 22659496, 21905444, 22359097, 21963181, 22734061, 21994665, 22403713, 22086768, 22086843, 22086919, 22449838, 22449841, 22334074, 22919506, 23881603, 22726802, 23115870, 22792620, 23201895, 22812744, 22812744, 22812733, 22812749, 22812747, 22812734, 22812748, 22812750, 22812735, 22812736, 22812749, 22812751, 22812735, 22812736, 22812748, 22812750, 22812750, 22812751, 22812736, 22812737, 22812737, 22812750, 22812750, 22812751, 22812751, 22812752, 22812737, 22812751, 22812751, 22812752, 22812752, 22812750, 22812752, 22812752, 22812753, 22812752, 22812753, 22812753, 22812754, 22812759, 23158841, 24224339, 23158842, 22812763, 22812765, 23158843, 22812766, 23084826, 23158843, 23158844, 22812765, 22812766, 22812766, 23158843, 23158844, 23158867, 22812766, 22812767, 23158843, 23158844, 23158844, 23158845, 23213546, 22812767, 23084827, 23084828, 23158844, 23158844, 23158845, 23158845, 23158846, 23158864, 24074064, 26168955, 22812769, 22946053, 23080741, 23084828, 23158844, 23158844, 23158845, 23158845, 23158846, 23158846, 23158868, 23227942, 23476583, 23719636, 24074065, 24120943, 23158845, 24120944, 23158849, 23047681, 23276308, 23079358, 23292151, 23141863, 23323398, 23173020, 23173021, 23264960, 23338978, 23338978, 23235638, 23370315, 23348730, 23426834, 23356901, 23356901, 23356901, 23356902, 23356902, 23430918, 23430919, 23430919, 23430920, 23430942, 24346137, 23504920, 23504921, 23504921, 23504922, 23504944, 23504921, 23504922, 23504922, 23504939, 23504939, 23504943, 23504922, 23504923, 23504923, 23504924, 23504939, 23504942, 23504944, 23504948, 23504924, 23504925, 23504925, 23504927, 23504931, 23504932, 23504934, 23504937, 23504938, 23504938, 23504939, 23504939, 23504940, 23504940, 23504941, 23504941, 23504942, 23504942, 23504943, 23504943, 23504944, 23504944, 23504945, 23504945, 23504946, 23504946, 23504947, 23504947, 23504948, 23504948, 23504949, 23504949, 23504950, 23504950, 23504951, 23504951, 23504952, 23504952, 23504953, 23504953, 23504954, 23504954, 23504955, 23504956, 23504956, 23504925, 23504926, 23504937, 23504938, 23504938, 23504939, 23504939, 23504940, 23504940, 23504941, 23504941, 23504942, 23504942, 23504943, 23504943, 23504944, 23504944, 23504945, 23504945, 23504946, 23504946, 23504947, 23504947, 23504949, 23504950, 23504953, 23504958, 23504933, 23504943, 23504944, 23504955, 23504943, 23504954, 23504946, 23504950, 23504947, 23504953, 23504952, 23504950, 23504954, 23504956, 23504958, 23504952, 23504954, 23504965, 23504953, 23504954, 23504956, 23504957, 23504958, 23504963, 23504955, 23504955, 23504956, 23504957, 23504958, 23504959, 23504960, 23504961, 23504963, 23504966, 23504967, 23504968, 23886709, 24116849, 23504956, 23504956, 23504957, 23504957, 23504958, 23504958, 23504959, 23504960, 23504962, 23504963, 23504964, 23504966, 23504968, 23504977, 24420158, 24467036, 23504957, 23504957, 23504958, 23504959, 23504959, 23504960, 23504961, 23504962, 23504964, 23504968, 23504969, 24467037, 23504958, 23504959, 23504959, 23504960, 23504961, 23504965, 24420159, 23504958, 23504959, 23504960, 23504960, 23504963, 23504968, 24467038, 23504959, 23504960, 23504960, 23504961, 23504961, 23504962, 23504963, 23504963, 23504964, 23504965, 23504966, 23504968, 23504971, 23504979, 23817855, 24467038, 23504960, 23504961, 23504961, 23504962, 23504962, 23504963, 23504964, 23504965, 23504965, 23504967, 23504968, 23504970, 23504973, 24105807, 24175382, 23504961, 23504962, 23504962, 23504963, 23504963, 23504964, 23504964, 23504965, 23504966, 23504969, 23504970, 23504971, 23504972, 23504974, 23504980, 23886704, 24420161, 24420162, 24467039, 23504962, 23504963, 23504963, 23504964, 23504964, 23504965, 23504966, 23504966, 23504967, 23504968, 23504969, 23504970, 23504970, 23504971, 23504972, 23504972, 23504973, 23504974, 23504975, 23504981, 24420160, 24420162, 24420162, 24467040, 24467085, 23504963, 23504964, 23504964, 23504965, 23504965, 23504966, 23504966, 23504967, 23504968, 23504968, 23504969, 23504970, 23504970, 23504971, 23504971, 23504972, 23504972, 23504973, 23504973, 23504974, 23504975, 23504981, 23565984, 24420162, 24420163, 24467040, 23504964, 23504965, 23504965, 23504966, 23504966, 23504967, 23504968, 23504968, 23504969, 23504970, 23504971, 23504972, 23504973, 23504975, 23504976, 23886708, 24087088, 24278788, 24420163, 24467041, 24570441, 23504965, 23504966, 23504966, 23504967, 23504967, 23504968, 23504968, 23504969, 23504970, 23504971, 23504971, 23504973, 23504973, 23504974, 23504975, 23504982, 23504982, 23806362, 23817861, 23886712, 23886716, 24420162, 24420164, 24467041, 23504966, 23504967, 23504967, 23504968, 23504968, 23504969, 23504969, 23504970, 23504971, 23504971, 23504972, 23504972, 23504973, 23504973, 23504974, 23504976, 23504977, 23504983, 23504984, 23886706, 24175385, 24420162, 24420164, 24420164, 23504967, 23504968, 23504968, 23504969, 23504971, 23504971, 23504972, 23504972, 23504973, 23504974, 23504975, 23504977, 23504983, 23695732, 24420163, 24420165, 24467042, 23504968, 23504969, 23504969, 23504970, 23504970, 23504972, 23504972, 23504973, 23504974, 23504975, 23504976, 23504984, 24175386, 24420162, 24420165, 24420165, 23504969, 23504970, 23504970, 23504971, 23504971, 23504972, 23504972, 23504973, 23504973, 23504974, 23504975, 23504975, 23504976, 23504978, 23504978, 23504984, 23504985, 23504985, 23504986, 23817845, 23886717, 24420165, 23504970, 23504971, 23504971, 23504972, 23504972, 23504973, 23504973, 23504974, 23504975, 23504975, 23504976, 23504977, 23504978, 23504985, 24467044, 24510063, 23504971, 23504972, 23504972, 23504973, 23504974, 23504974, 23504975, 23504975, 23504976, 23504977, 23504978, 23504979, 23817851, 23886707, 23504972, 23504973, 23504973, 23504974, 23504974, 23504975, 23504976, 23504976, 23504977, 23504979, 23504980, 23695734, 23817851, 24467045, 23504973, 23504974, 23504974, 23504975, 23504975, 23504976, 23504977, 23504977, 23504979, 23504980, 23504982, 23504986, 23695717, 23886707, 23886708, 24420168, 24467045, 24570446, 23504974, 23504975, 23504976, 23504976, 23504978, 23504981, 23504987, 23665354, 23731825, 23886612, 23886714, 23886721, 23504975, 23504976, 23504976, 23504977, 23504977, 23504978, 23504978, 23504979, 23504979, 23504981, 23504987, 23886714, 23886714, 24467046, 23504976, 23504977, 23504977, 23504978, 23504978, 23504979, 23504979, 23504980, 23504981, 23886719, 24219982, 24420169, 24467047, 23504977, 23504978, 23504978, 23504979, 23504979, 23504980, 23504980, 23504989, 23886714, 24420170, 24467047, 23504978, 23504979, 23504979, 23504980, 23504980, 23504981, 23504981, 23504982, 23504985, 23817858, 23817863, 23886694, 23886712, 23886717, 23886720, 24231707, 24467048, 23504979, 23504980, 23504980, 23504981, 23504981, 23504982, 23504982, 23504983, 23504983, 23504989, 24420169, 24420170, 24420171, 24420171, 24467048, 24570449, 23504980, 23504981, 23504981, 23504982, 23504982, 23504983, 23504990, 23559654, 23665357, 23782198, 23817848, 23886716, 24467049, 24570449, 24648290, 23504981, 23504982, 23504982, 23504983, 23504983, 23504984, 23504984, 23504985, 23504985, 23504989, 23504990, 23504991, 23559657, 23665357, 23695736, 23886711, 23886722, 23886725, 24065700, 24105818, 24108602, 24175392, 24420171, 24420171, 24420172, 24465839, 24467049, 24467108, 24570450, 23504982, 23504983, 23504983, 23504984, 23504984, 23504985, 23504991, 23504991, 23504992, 23695742, 23886710, 23886713, 23886713, 23886714, 23886722, 24420170, 24420171, 24420172, 24467050, 23504983, 23504984, 23504984, 23504985, 23504985, 23504991, 23504992, 23886664, 23886714, 24000656, 24025353, 24087069, 24420172, 24420172, 24420173, 24467106, 23504984, 23504985, 23504985, 23504986, 23504986, 23504991, 23504992, 23886713, 23886715, 23886720, 23886723, 24000657, 24116864, 24140900, 24175394, 24420173, 24467096, 24570451, 23504985, 23504986, 23504986, 23504987, 23504988, 23504992, 23886719, 23886729, 24278797, 24420174, 23504986, 23504987, 23504993, 24420174, 24420174, 24467052, 23504987, 23504988, 23504989, 23504992, 23504993, 23504994, 23504994, 23559656, 23638165, 23817848, 23817860, 23817862, 23886517, 23886608, 23886666, 23886715, 23886715, 23886716, 23886717, 23886717, 23886723, 23886725, 23886727, 24000658, 24087065, 24087099, 24105820, 24140898, 24140901, 24140902, 24140902, 24175394, 24175395, 24420172, 24420173, 24420174, 24420175, 24420175, 24467052, 24467098, 24570475, 23504988, 23504989, 23504989, 23504990, 23504994, 23504994, 23558073, 23558074, 23692828, 23886619, 23886717, 23886719, 23886726, 23886728, 24000703, 24025355, 24140901, 24140902, 24420174, 24420174, 24420175, 24420175, 24420176, 24467053, 23504994, 23559658, 23695746, 23886722, 24105821, 24305551, 24420175, 24420176, 23504991, 23504995, 23504996, 23695743, 23886719, 24467054, 23504995, 23665364, 23886718, 24105823, 24467054, 23504996, 23796893, 24420177, 24420177, 23558078, 23559662, 23505000, 23886724, 23505000, 23505001, 23505001, 23558079, 23558081, 23559662, 23559664, 23695751, 23782206, 23813472, 23817859, 23817871, 23817874, 23817876, 23817879, 23886675, 23886677, 23886718, 23886722, 23886723, 23886726, 23886726, 23886727, 23886729, 23886731, 23886734, 23980024, 24000665, 24025361, 24086979, 24087051, 24105826, 24116872, 24140908, 24175400, 24175401, 24175402, 24278804, 24278806, 24420179, 24420180, 24420180, 24420181, 24420181, 24420182, 24467058, 24467059, 24467104, 24467111, 23559663, 23695752, 23817855, 23817875, 23886726, 23886727, 23886733, 24025361, 24105827, 24175401, 24420181, 24420181, 24420182, 24467059, 23559665, 23648195, 23886724, 24105828, 24420179, 24420183, 24467060, 24467060, 23886733, 23611174, 23611174, 23611174, 23611174, 23611180, 24473272, 24158921, 24520153, 23612759, 23939823, 24473278, 23614339, 23614339, 23614341, 23614340, 23614341, 23614341, 23614342, 23614343, 23614345, 23614345, 23868150, 24474858, 24474859, 23836886, 24055343, 24171551, 24474860, 24474860, 24521738, 24474863, 23627020, 24528076, 23643127, 24174896, 23771358, 24019811, 23791410, 23791412, 24563396, 24610276, 23825744, 23825746, 23825747, 23825749, 24730889, 23978255, 24047103, 24335781, 24730861, 24047080, 23880681, 23994789, 23886513, 23886521, 23886538, 23886533, 23886541, 23886543, 23886534, 23886543, 23886544, 24610965, 24657843, 24657844, 24610972, 24299292, 24008655, 24366194, 24610973, 24657851, 23958688, 24647032, 24059424, 24059426, 24059428, 24095086, 24163950, 24383046, 24077054, 24706216, 24088817, 24178625, 24107777, 24721579, 24108900, 24188582, 24121959, 24121962, 24728668, 24775547, 24130717, 24130731, 24130756, 24130743, 24130747, 24130733, 24130746, 24130754, 24130755, 24130758, 24130765, 24130755, 24130761, 24130747, 24130763, 24130764, 24130769, 24130766, 24130765, 24130768, 24130765, 24130771, 24544595, 24130776, 24130776, 24418710, 24779942, 24779945, 24733067, 24199620, 24199612, 24779948, 24779949, 24199627, 24733073, 24488293, 24199616, 24199581, 24733076, 24199627, 24733078, 24453806, 24733079, 24140420, 24737901, 24268062, 24801720, 24268255, 24268325, 24268361, 24268421, 24268410, 24268427, 24268440, 24268449, 24487527, 24522608, 24801881, 24268457, 24268458, 24268440, 24268469, 24268455, 24268471, 24268471, 24268456, 24268472, 24268445, 24268450, 24268472, 24268472, 24268473, 24268449, 24268473, 24268474, 24268473, 24268448, 24268449, 24268473, 24268474, 24268474, 24268482, 24268453, 24268474, 24268475, 24268450, 24268453, 24268475, 24268475, 24268454, 24268475, 24268476, 24268458, 24268476, 24268478, 24268476, 24268477, 24268478, 24268478, 24268477, 24268478, 24268478, 24268478, 24268479, 24268478, 24268478, 24268478, 24268480, 24268480, 24268479, 24268460, 24268479, 24268480, 24268481, 24268481, 24268463, 24268481, 24268481, 24268482, 24268482, 24268483, 24268482, 24268482, 24268483, 24268483, 24268482, 24268484, 24268483, 24268484, 24268484, 24268485, 24268485, 24268486, 24268489, 24268484, 24268485, 24268485, 24268486, 24268492, 24801929, 24801930, 24848807, 24268500, 24268501, 24268501, 24463185, 24522657, 24522658, 24557151, 24557152, 24660554, 24801929, 24801930, 24801931, 24801931, 24848809, 24952209, 24952296, 24268501, 24361774, 24407111, 24487577, 24487577, 24488718, 24557151, 24801929, 24801930, 24801931, 24801932, 24848809, 24268503, 24557152, 24557153, 24613470, 24680873, 24801932, 24801932, 24848810, 24361775, 24487579, 24557153, 24801932, 24801933, 24801933, 24848810, 24487578, 24557152, 24557153, 24801933, 24801933, 24848811, 24801933, 24468773, 24848814, 24500305, 24455060, 24455062, 24455063, 24455172, 24895220, 24895220, 24455282, 24895327, 24496400, 24496444, 24496520, 24496521, 24496642, 24496588, 24496642, 24915984, 24612730, 24916038, 24916038, 24962916, 24545723, 24545734, 24545735, 24545736, 24545740, 24940553, 24695778, 24940552, 24940555, 24987433, 24987436, 24626421, 24626423, 24626424, 24626431, 24626471, 24626505, 24626528, 24626529, 24626553, 24626570, 24666603, 24980973, 24657881, 25146928, 24668961, 24669023, 24669057, 25002220, 24669094, 24669104, 24669169, 24669114, 24669177, 24669188, 24669195, 24669223, 24687943, 24757517, 25002298, 25002298, 25049176, 24706653, 24706665, 24706665, 24706666, 24706664, 24706666, 24706667, 24706669, 24706667, 24706668, 24706668, 24706763, 25021020, 25067897, 24706678, 25021019, 25021020, 25067898, 25067943, 24706679, 24741747, 25021020, 25067898, 25018522, 25021021, 25021021, 25021022, 25021023, 24706863, 24741845, 24708948, 25022161, 24712011, 24712129, 24712239, 24712247, 25023809, 24779033, 24728759, 24728759, 24728760, 25032068, 25032068, 24732107, 24788961, 24776826, 24776827, 24776827, 24776830, 24776830, 24776831, 24776831, 24776834, 24776832, 24776835, 25056102, 25056102, 24811325, 25056104, 25056104, 25102982, 24867642, 25056104, 25056104, 25056105, 25056107, 24845815, 24845813, 24845814, 24845816, 24845817, 24845803, 24845813, 24845815, 24845816, 24845817, 24845817, 24845818, 24845818, 24845818, 24845815, 24845818, 24845819, 24845820, 24845825, 24845826, 25090594, 25090594, 25090595, 25090595, 25090596, 25137474, 24845833, 24949206, 24949222, 25090597, 25137475, 25090596, 25090597, 25090598, 25137475, 25090595, 25090596, 25090596, 25090597, 25090598, 25090598, 25137476, 25090597, 25090598, 25137476, 25137479, 25090602, 24935064, 24935170, 24935276, 25135354, 24958451, 24958452, 24958449, 24958451, 25193789, 25146912, 25146913, 25146914, 25052621, 25052631, 25052637, 25194008, 25240886, 25194010, 25194011, 25194012, 25240889, 25093258, 25214316, 25106124, 25220747, 25179339, 25304279, 25330376, 25332875, 25335358, 25335359, 25335358, 25335359, 25335360, 25335375, 25335360, 25335360, 25335361, 25335375, 25335376, 25335359, 25335360, 25335361, 25335373, 25335376, 25335360, 25335361, 25335361, 25335362, 25335373, 25335375, 25335376, 25335376, 25335361, 25335362, 25335362, 25335375, 25335376, 25335377, 25335377, 25335362, 25335363, 25335374, 25335376, 25335376, 25335377, 25335377, 25335378, 25335363, 25335376, 25335376, 25335377, 25335377, 25335378, 25335378, 25335364, 25335375, 25335376, 25335376, 25335377, 25335377, 25335378, 25335378, 25335379, 25335379, 25335388, 25335388, 25335388, 25335390, 25382252, 25335391, 25335390, 25335390, 25335391, 25335391, 25382253, 25335391, 25335391, 25335392, 25382254, 25335391, 25335392, 25335392, 25382254, 25335392, 25335393, 25382254, 25382255, 25485678, 25335393, 25382255, 25382301, 25485656, 25485678, 25335395, 25367979, 25375570, 25377244, 25381046, 25382256, 25382301, 25382303, 25485656, 25382257, 25400579, 25414856, 25415766, 25422452, 25419105, 25424117, 25426713, 25426714, 25427923, 25429117, 25429118, 25429119, 25429119, 25429120, 25429120, 25429121, 25429128, 25429129, 25429129, 25429148, 25429149, 25429150, 25429161, 25429161, 25429162, 25429162, 25429163, 25429163, 25429176, 25429120, 25429163, 25429164, 25429164, 25429164, 25429164, 25429165, 25429152, 25429165, 25429166, 25429167, 25532528, 25429174, 25429180, 25532529, 25429141, 25429175, 25429193, 25429193, 25429194, 25429195, 25429195, 25429206, 25429206, 25429207, 25429207, 25429208, 25429208, 25429209, 25429210, 25429211, 25429212, 25429212, 25429213, 25429213, 25429214, 25429215, 25429215, 25429216, 25429216, 25429217, 25429218, 25429218, 25429219, 25429219, 25429220, 25429220, 25429221, 25429221, 25429222, 25429224, 25429227, 25429227, 25429228, 25429229, 25429229, 25429231, 25429231, 25429233, 25429233, 25429234, 25429234, 25429236, 25429237, 25429237, 25429238, 25429239, 25429212, 25429213, 25429214, 25429214, 25429217, 25429219, 25429222, 25429228, 25429238, 25429239, 25429214, 25429215, 25429215, 25429216, 25429218, 25429223, 25429239, 25429240, 25429215, 25429216, 25429242, 25429216, 25429223, 25429217, 25429218, 25429219, 25429220, 25429220, 25429221, 25429223, 25429224, 25429224, 25429225, 25429226, 25429231, 25429232, 25429234, 25429235, 25429238, 25429238, 25429240, 25429240, 25429241, 25429241, 25429242, 25429243, 25429218, 25429219, 25429220, 25429220, 25429221, 25429222, 25429223, 25429224, 25429226, 25429232, 25429234, 25429235, 25429236, 25429237, 25429239, 25429239, 25429240, 25429241, 25429241, 25429242, 25429243, 25429220, 25429221, 25429221, 25429222, 25429223, 25429224, 25429224, 25429225, 25429225, 25429227, 25429229, 25429230, 25429234, 25429234, 25429235, 25429236, 25429238, 25429239, 25429239, 25429240, 25429241, 25429241, 25429242, 25429243, 25429244, 25429222, 25429222, 25429223, 25429224, 25429226, 25429227, 25429235, 25429239, 25429240, 25429240, 25429241, 25429244, 25429245, 25429223, 25429243, 25429245, 25429223, 25429224, 25429225, 25429225, 25429226, 25429226, 25429228, 25429228, 25429237, 25429240, 25429240, 25429241, 25429243, 25429246, 25429225, 25429225, 25429226, 25429228, 25429228, 25429229, 25429236, 25429237, 25429238, 25429239, 25429240, 25429241, 25429241, 25429244, 25429244, 25429245, 25429245, 25429246, 25429246, 25429226, 25429227, 25429228, 25429231, 25429231, 25429233, 25429235, 25429235, 25429236, 25429238, 25429239, 25429240, 25429241, 25429242, 25429242, 25429243, 25429244, 25429245, 25429247, 25429247, 25429228, 25429231, 25429238, 25429238, 25429239, 25429240, 25429240, 25429242, 25429245, 25429247, 25429248, 25429229, 25429239, 25429241, 25429232, 25429233, 25429234, 25429239, 25429241, 25429242, 25429244, 25429249, 25429231, 25429232, 25429235, 25429239, 25429240, 25429241, 25429242, 25429243, 25429245, 25429240, 25429242, 25429247, 25429250, 25429233, 25429241, 25429245, 25429249, 25429250, 25429235, 25429241, 25429243, 25429243, 25429251, 25429244, 25429246, 25429250, 25429251, 25429235, 25429240, 25429241, 25429242, 25429242, 25429243, 25429244, 25429246, 25429247, 25429247, 25429248, 25429249, 25429249, 25429252, 25429238, 25429245, 25429244, 25429253, 25429254, 25429247, 25429249, 25429251, 25429245, 25429255, 25429246, 25429251, 25429257, 25429248, 25429257, 25429253, 25429258, 25429251, 25429253, 25429256, 25429258, 25429259, 25532584, 25429251, 25429252, 25429253, 25429254, 25429254, 25429255, 25429258, 25429259, 25429259, 25429258, 25429260, 25429252, 25429253, 25429254, 25429255, 25429255, 25429256, 25429256, 25429257, 25429258, 25429258, 25429260, 25429258, 25429259, 25429261, 25429255, 25429255, 25429256, 25429256, 25429257, 25429257, 25429258, 25429259, 25429261, 25429262, 25429257, 25429258, 25429258, 25429260, 25429260, 25429261, 25429261, 25429263, 25429258, 25429259, 25429259, 25429260, 25429262, 25429262, 25429263, 25429263, 25429261, 25429261, 25429262, 25429263, 25429264, 25429261, 25429262, 25429263, 25429263, 25429264, 25429262, 25429263, 25429264, 25429265, 25429265, 25429263, 25429264, 25429265, 25429266, 25429264, 25429265, 25429266, 25429266, 25429266, 25429266, 25429267, 25532614, 25429267, 25429268, 29751144, 25429268, 25429269, 25429270, 25429270, 25429271, 25429272, 25429274, 25429275, 25429276, 25429276, 25429277, 25429278, 25429278, 25429280, 25429281, 25429282, 25429283, 25429284, 25429285, 25429286, 25429286, 25429287, 25429287, 25429288, 25429290, 25429296, 25429296, 25429298, 25429298, 25429303, 25429304, 25429304, 25429307, 25429308, 25429309, 25429311, 25429312, 25429312, 25429313, 25429313, 25429314, 25429314, 25532594, 25532615, 25532616, 25532618, 25532619, 25532646, 25429271, 25429273, 25429273, 25429275, 25429276, 25429277, 25429278, 25429280, 25429280, 25429281, 25429284, 25429284, 25429285, 25429286, 25429286, 25429299, 25429307, 25429310, 25429311, 25429312, 25429312, 25429313, 25429314, 25429314, 25429315, 25429276, 25429288, 25429315, 25429315, 25429277, 25429283, 25429277, 25429317, 25429318, 25429317, 25429283, 25429307, 25429310, 25429319, 25429287, 25429320, 25429314, 25429319, 25429321, 25429321, 25429287, 25429289, 25429289, 25429292, 25429295, 25429295, 25429322, 25429323, 25429323, 25429288, 25429317, 25429319, 25532604, 25429325, 25429325, 25429325, 25429326, 25429305, 25429325, 25429326, 25429324, 25429326, 25429327, 25429298, 25429327, 25429327, 25429328, 25429310, 25429328, 25429329, 25429313, 25429329, 25429329, 25429330, 25429324, 25429330, 25429331, 25532633, 25429329, 25429330, 25429331, 25429332, 25429332, 25429332, 25429333, 25429333, 25429335, 25429338, 25429331, 25429341, 25429325, 25429341, 25429342, 25429333, 25429339, 25429343, 25429344, 25532650, 25429349, 25429349, 25429348, 25429349, 25429350, 25429350, 25429351, 25429353, 25429353, 25429353, 25429354, 25429355, 25429356, 25429357, 25429355, 25429356, 25429357, 25429357, 25429358, 25429357, 25429358, 25429358, 25429359, 25429359, 25429360, 25429521, 25451207, 25462798, 25462798, 25508799, 25519248, 25532453, 25532530, 25532638, 25532639, 25532639, 25532662, 26730470, 29751191, 25462798, 25532640, 25429753, 25532871, 25473065, 25554497, 25496249, 25496250, 25496250, 25496251, 25496251, 25496249, 25496251, 25496252, 25566090, 25566090, 25496264, 25566091, 25566092, 25566092, 25566093, 25515168, 26773380, 25588260, 25588313, 25612101, 25612154, 25609149, 25622540, 25635621, 25635808, 25635776, 25635885, 25635917, 25635918, 25635918, 25635919, 25635923, 25635923, 25635924, 25635926, 25635932, 25635939, 25635939, 25635940, 25635940, 25635941, 25635941, 25635944, 25635923, 25635941, 25635942, 25635930, 25635944, 25635945, 25635945, 25635928, 25635945, 25635946, 25635946, 25635946, 25635948, 25635948, 25635954, 25635961, 25635961, 25635962, 25635962, 25635962, 25635962, 25635963, 25635963, 25635964, 25635965, 25635965, 25635966, 25635966, 25635967, 25635967, 25635968, 25635968, 25635969, 25635969, 25635970, 25635970, 25635971, 25635971, 25635972, 25635973, 25635973, 25635974, 25635974, 25635975, 25635976, 25635976, 25635977, 25635978, 25635978, 25635979, 25635980, 25635981, 25635982, 25635982, 25635983, 25635983, 25635984, 25635984, 25635985, 25635986, 25635986, 25635987, 25635987, 25635988, 25635988, 25635989, 25635989, 25635990, 25635990, 25635991, 25635991, 25635992, 25635992, 25635993, 25635993, 25635994, 25635994, 25635995, 25635997, 25635999, 25636004, 25636012, 25636014, 25636014, 25636015, 25636016, 25636017, 25635965, 25635966, 25635967, 25635968, 25635969, 25635969, 25635970, 25635971, 25635971, 25635973, 25635979, 25635982, 25635982, 25635983, 25635983, 25635984, 25635984, 25635986, 25635987, 25635988, 25635990, 25635992, 25635992, 25635995, 25635967, 25635967, 25635969, 25635969, 25635971, 25635971, 25635972, 25635972, 25635973, 25635979, 25635982, 25635983, 25635983, 25635984, 25635986, 25635987, 25635987, 25635988, 25635990, 25635991, 25635992, 25635995, 25635998, 25636000, 25636018, 25635967, 25635968, 25635970, 25635976, 25635980, 25635987, 25635988, 25635991, 25635968, 25635970, 25635970, 25635972, 25635972, 25635978, 25635983, 25635985, 25635986, 25635988, 25635988, 25635989, 25635991, 25635992, 25635970, 25635970, 25635971, 25635971, 25635973, 25635973, 25635974, 25635975, 25635976, 25635977, 25635980, 25635981, 25635982, 25635984, 25635984, 25635986, 25635987, 25635987, 25635988, 25635989, 25635990, 25635990, 25635991, 25635992, 25635992, 25635993, 25635994, 25635994, 25635999, 25636001, 25636001, 25636019, 25635979, 25635976, 25635985, 25636020, 25635972, 25635974, 25635976, 25635986, 25635989, 25635990, 25635991, 25635991, 25635992, 25635993, 25635994, 25635999, 25635974, 25635975, 25635975, 25635976, 25635978, 25635979, 25635980, 25635984, 25635986, 25635986, 25635987, 25635988, 25635989, 25635989, 25635990, 25635990, 25635991, 25635991, 25635992, 25635994, 25635995, 25635996, 25635996, 25635997, 25635998, 25636021, 25635980, 25635983, 25635986, 25635991, 25635992, 25635995, 25635984, 25635976, 25635977, 25635981, 25635985, 25635987, 25635988, 25635989, 25635990, 25635992, 25635993, 25635994, 25635995, 25635996, 25635997, 25636001, 25635977, 25635979, 25635979, 25635980, 25635982, 25635983, 25635986, 25635988, 25635989, 25635990, 25635992, 25635993, 25635994, 25635996, 25635997, 25635998, 25635998, 25636002, 25636023, 25635978, 25635979, 25635980, 25635981, 25635982, 25635983, 25635983, 25635990, 25635990, 25635997, 25635998, 25636012, 25636018, 25636024, 25635981, 25635983, 25635993, 25635994, 25636001, 25636024, 25635990, 25635992, 25635995, 25636000, 25635989, 25635991, 25635992, 25635996, 25635998, 25635984, 25635990, 25635993, 25636026, 25635984, 25635985, 25635987, 25635991, 25635993, 25636026, 25635988, 25635992, 25635998, 25636009, 25635990, 25635987, 25635989, 25635992, 25635997, 25635998, 25635999, 25636000, 25636001, 25636002, 25636003, 25636006, 25636028, 25635990, 25635993, 25635996, 25635996, 25635999, 25636001, 25636001, 25636007, 25636029, 25635990, 25635993, 25635997, 25635998, 25636000, 25636004, 25635993, 25635995, 25636001, 25635995, 25635996, 25635997, 25636000, 25636000, 25636001, 25636004, 25636006, 25636012, 25635999, 25636006, 25636007, 25636010, 25635996, 25636000, 25636004, 25635998, 25636001, 25636003, 25636005, 25636017, 25636000, 25636000, 25636002, 25636003, 25636004, 25636007, 25635999, 25636000, 25636000, 25636001, 25636001, 25636002, 25636002, 25636003, 25636004, 25636004, 25636006, 25636007, 25636007, 25636008, 25636009, 25636009, 25636011, 25636016, 25636028, 25636034, 25636000, 25636001, 25636004, 25636004, 25636005, 25636006, 25636012, 25636013, 25636015, 25636017, 25636033, 25636002, 25636003, 25636004, 25636006, 25636007, 25636008, 25636010, 25636011, 25636013, 25636035, 25636002, 25636005, 25636005, 25636006, 25636008, 25636017, 25636003, 25636004, 25636005, 25636006, 25636007, 25636008, 25636009, 25636010, 25636011, 25636015, 25636034, 25636036, 25636004, 25636006, 25636008, 25636009, 25636009, 25636010, 25636010, 25636011, 25636011, 25636012, 25636013, 25636005, 25636006, 25636007, 25636007, 25636008, 25636009, 25636010, 25636010, 25636012, 25636013, 25636014, 25636018, 25636019, 25636037, 25636007, 25636008, 25636010, 25636011, 25636012, 25636013, 25636014, 25636015, 25636022, 25636010, 25636011, 25636008, 25636009, 25636009, 25636010, 25636010, 25636011, 25636011, 25636012, 25636012, 25636013, 25636014, 25636016, 25636016, 25636017, 25636036, 25636039, 25636009, 25636010, 25636011, 25636012, 25636012, 25636013, 25636013, 25636014, 25636014, 25636015, 25636016, 25636016, 25636017, 25636018, 25636039, 25636010, 25636011, 25636011, 25636012, 25636012, 25636013, 25636013, 25636014, 25636014, 25636015, 25636016, 25636017, 25636017, 25636018, 25636022, 25636040, 25636011, 25636012, 25636012, 25636013, 25636013, 25636014, 25636015, 25636015, 25636017, 25636017, 25636018, 25636018, 25636019, 25636021, 25636038, 25636040, 25636012, 25636013, 25636013, 25636014, 25636014, 25636015, 25636016, 25636018, 25636041, 26347659, 25636013, 25636014, 25636014, 25636015, 25636015, 25636016, 25636016, 25636018, 25636019, 25636020, 25636041, 25636014, 25636015, 25636015, 25636016, 25636017, 25636017, 25636018, 25636019, 25636019, 25636020, 25636022, 25636024, 25636015, 25636016, 25636016, 25636017, 25636017, 25636018, 25636020, 25636021, 25636042, 25636016, 25636017, 25636017, 25636018, 25636019, 25636019, 25636020, 25636021, 25636021, 25636023, 25636024, 25636027, 25636030, 25636037, 25636040, 25636043, 25636017, 25636018, 25636018, 25636019, 25636020, 25636020, 25636021, 25636022, 25636025, 25636032, 25636036, 25636018, 25636019, 25636021, 25636022, 25636025, 25636026, 25636037, 25636044, 25636019, 25636020, 25636020, 25636021, 25636021, 25636022, 25636023, 25636023, 25636027, 25636027, 25636029, 25636030, 25636033, 25636034, 25636035, 25636038, 25636038, 25636041, 25636042, 25636044, 28648997, 25636020, 25636021, 25636021, 25636022, 25636022, 25636023, 25636024, 25636025, 25636026, 25636026, 25636027, 25636027, 25636029, 25636030, 25636030, 25636031, 25636034, 25636035, 25636036, 25636037, 25636038, 25636039, 25636040, 25636042, 25636042, 25636043, 25636044, 25636045, 25636022, 25636023, 25636024, 25636025, 25636027, 25636042, 25636045, 25636022, 25636023, 25636023, 25636024, 25636025, 25636026, 25636027, 25636028, 25636030, 25636036, 25636037, 25636039, 25636039, 25636040, 25636045, 25636046, 25636023, 25636024, 25636025, 25636025, 25636026, 25636028, 25636039, 25636040, 25636045, 25636046, 25636024, 25636025, 25636026, 25636026, 25636027, 25636027, 25636028, 25636028, 25636029, 25636030, 25636031, 25636037, 25636038, 25636039, 25636041, 25636044, 25636044, 25636045, 25636045, 25636047, 25636025, 25636026, 25636027, 25636027, 25636028, 25636028, 25636029, 25636029, 25636030, 25636031, 25636033, 25636035, 25636039, 25636039, 25636040, 25636040, 25636042, 25636044, 25636045, 25636045, 25636047, 25636047, 25636026, 25636029, 25636038, 25636041, 25636027, 25636028, 25636028, 25636029, 25636030, 25636030, 25636031, 25636031, 25636033, 25636034, 25636034, 25636036, 25636037, 25636038, 25636038, 25636039, 25636040, 25636040, 25636041, 25636041, 25636042, 25636042, 25636043, 25636043, 25636045, 25636045, 25636046, 25636046, 25636047, 25636048, 25636048, 25636030, 25636049, 25636029, 25636031, 25636031, 25636032, 25636041, 25636047, 25636049, 25636049, 25636031, 25636032, 25636033, 25636039, 25636041, 25636042, 25636043, 25636045, 25636046, 25636047, 25636049, 25636050, 25636032, 25636050, 25636032, 25636033, 25636037, 25636042, 25636033, 25636034, 25636036, 25636037, 25636037, 25636038, 25636039, 25636041, 25636043, 25636044, 25636047, 25636049, 25636049, 25636051, 25636035, 25636035, 25636036, 25636037, 25636037, 25636038, 25636039, 25636039, 25636040, 25636041, 25636041, 25636042, 25636043, 25636045, 25636046, 25636046, 25636047, 25636049, 25636049, 25636050, 25636050, 25636051, 25636052, 25636041, 25636050, 25636052, 25636037, 25636038, 25636042, 25636043, 25636044, 25636046, 25636047, 25636053, 25636037, 25636051, 25636053, 25636041, 25636047, 25636053, 25636054, 25636041, 25636042, 25636045, 25636047, 25636054, 25636054, 25636054, 25636055, 25636044, 25636045, 25636051, 25636055, 25636046, 25636046, 25636050, 25636056, 25636046, 25636056, 25636045, 25636056, 25636057, 25636046, 25636047, 25636050, 25636054, 25636055, 25636057, 25636057, 25636058, 25636051, 25636052, 25636055, 25636058, 25636049, 25636050, 25636052, 25636052, 25636053, 25636058, 25636059, 25636057, 25636059, 25636050, 25636051, 25636052, 25636052, 25636053, 25636055, 25636057, 25636058, 25636059, 25636060, 25636052, 25636056, 25636058, 25636053, 25636055, 25636061, 25636054, 25636054, 25636055, 25636058, 25636059, 25636059, 25636061, 25636055, 25636056, 25636057, 25636060, 25636062, 25636055, 25636056, 25636057, 25636060, 25636062, 25636057, 25636058, 25636058, 25636059, 25636060, 25636061, 25636061, 25636062, 25636062, 25636063, 25636060, 25636061, 25636063, 25636060, 25636061, 25636061, 25636062, 25636063, 25636064, 25636063, 25636064, 25636061, 25636065, 25636062, 25636063, 25636065, 25636063, 25636064, 25636064, 25636065, 25636066, 25636066, 25636064, 25636067, 25636065, 25636066, 25636067, 25636067, 25636066, 25636067, 25636068, 25636067, 25636068, 25636068, 25636068, 25636069, 25636069, 25636070, 25636071, 25636072, 25636073, 25636074, 25636075, 25636075, 25636076, 25636076, 25636077, 25636079, 25636080, 25636080, 25636081, 25636082, 25636082, 25636083, 25636083, 25636084, 25636085, 25636085, 25636087, 25636088, 25636088, 25636089, 25636089, 25636090, 25636090, 25636091, 25636091, 25636092, 25636092, 26347688, 26609077, 27615713, 27787425, 28649024, 29854545, 25636071, 25636072, 25636072, 25636073, 25636075, 25636076, 25636076, 25636077, 25636077, 25636078, 25636078, 25636079, 25636079, 25636080, 25636081, 25636082, 25636082, 25636083, 25636083, 25636084, 25636085, 25636087, 25636087, 25636088, 25636089, 25636089, 25636090, 25636090, 25636091, 25636091, 25636092, 25636092, 25636093, 25636084, 25636089, 25636093, 25636090, 25636094, 25636094, 25636095, 25636080, 25636085, 25636090, 25636094, 25636095, 25636083, 25636084, 25636087, 25636089, 25636093, 25636095, 25636096, 25636096, 25636097, 25636097, 25636087, 25636088, 25636093, 25636094, 25636098, 25636098, 25636085, 25636088, 25636095, 25636096, 25636097, 25636099, 25636098, 25636099, 25636100, 25636100, 25636099, 25636100, 25636092, 25636097, 25636101, 25636102, 25636102, 25636093, 25636103, 25636093, 25636096, 25636102, 25636104, 25636094, 25636097, 25636104, 25636095, 25636097, 25636101, 25636102, 25636105, 25636096, 25636105, 25636097, 25636102, 25636106, 25636104, 25636106, 25636101, 25636102, 25636104, 25636105, 25636107, 25636108, 25636109, 25636105, 25636106, 25636107, 25636108, 25636109, 25636108, 25636110, 25636108, 25636109, 25636110, 25636111, 25636108, 25636111, 25636109, 25636110, 25636112, 25636110, 25636111, 25636112, 25636112, 25636113, 25636113, 25636113, 25636114, 25636114, 25636115, 25700934, 25718138, 25780804, 25781953, 25781956, 25781957, 25806129, 25841220, 25841221, 25841222, 25841222, 25868043, 25949396, 25954340, 26013966, 26099784, 26099784, 26347708, 26347709, 26347710, 26347710, 26347711, 26347711, 26361568, 26363342, 26364629, 26364629, 26364630, 26364630, 26408860, 26408862, 26479028, 26479028, 26479029, 26479029, 26489493, 26497112, 26549344, 26570177, 26600204, 26600207, 26609097, 26609098, 26609099, 26609100, 26611218, 26650954, 26757052, 26782124, 26833845, 26833847, 26833850, 26833851, 26886703, 26992435, 27097235, 27188458, 27206245, 27233152, 27298067, 27337701, 27337705, 27353411, 27353414, 27468810, 27533657, 27571623, 27580629, 27585699, 27585702, 27615734, 27615734, 27615735, 27615735, 27615736, 27615736, 27615738, 27615738, 27615847, 27731070, 27787446, 27787446, 27787447, 27787447, 27787448, 27970029, 28649045, 28649046, 28649046, 28920472, 28920475, 28987719, 29095562, 29108957, 29324384, 29355420, 29461103, 29854568, 29854569, 29868389, 29877106, 33388855, 26347712, 26833848, 27615735, 25765754, 25765766, 25765767, 25765769, 25765767, 27680566, 27852279, 25846789, 27680567, 26898682, 25791612, 26911602, 25800172, 25800174, 26446665, 26915884, 25925565, 27932209, 25927807, 25927810, 25927810, 25927811, 26979701, 26033235, 26493564, 26979701, 25976153, 25976271, 25976388, 26436051, 26046340, 26046341, 26046342, 26046342, 27038967, 27091822, 27820855, 27820856, 26100039, 26100170, 26100282, 27065955, 26138672, 26645058, 26262690, 27912566, 26272582, 27933977, 26391853, 26643796, 27211734, 26563465, 26563466, 26563468, 26563469, 28251128, 28079418, 27297532, 28251132, 26895719, 27463657, 28245544, 27059317, 27059304, 27059318, 27059319, 27059318, 27059318, 27059319, 27059319, 27059320, 27059319, 27059320, 27059321, 27059330, 27201101, 27307864, 27545455, 28327343, 27059332, 28499056, 28499056, 30579998, 27073177, 27076238, 27221059, 27320709, 27320709, 27493733, 27545456, 28327343, 28327343, 28499056, 28499057, 28645750, 28681638, 29360655, 30172712, 27362563, 27087036, 27087037, 27559316, 27559317, 27090583, 27561088, 27093155, 27093156, 27093156, 27093157, 27137386, 27207556, 27484405, 27562374, 28344261, 27151466, 27591546, 27181617, 27181618, 27181618, 27181675, 27181630, 27606604, 27267275, 27396728, 27181732, 28388548, 27321956, 27321957, 27321955, 27321956, 27321957, 27321957, 27673104, 27676774, 28076079, 27676775, 28458662, 27676775, 28630375, 27676776, 27342883, 27687238, 28469125, 27352931, 27467514, 27358121, 27358122, 27853294, 27521740, 27382794, 27382805, 28489080, 27462582, 27462651, 27462719, 28529041, 27504250, 27504263, 27767920, 28549820, 29583130, 27556410, 27794001, 27564308, 27564315, 27564316, 28170350, 27624840, 27797956, 27582095, 27582096, 27582097, 27582097, 27582098, 27755117, 27806843, 27806845, 28519420, 28588732, 28588733, 28760445, 27806845, 27586337, 28762566, 27611834, 27821712, 27665807, 27665808, 27848701, 27848701, 27685361, 27685364, 27858478, 27858479, 27875654, 27953623, 27878013, 27954808, 27928139, 27928145, 27928146, 27928148, 27979867, 27979869, 28761757, 27979871, 28024262, 28809819, 28031578, 28031578, 28031581, 28031582, 28031591, 28031592, 28031592, 28031593, 28031593, 28031594, 28031594, 28031595, 28031595, 28031596, 28031596, 28031597, 28031597, 28031598, 28031598, 28031601, 28031594, 28031596, 28031594, 28031599, 28031597, 28031604, 28031604, 28985192, 28031605, 28031607, 28031607, 28031608, 28031608, 28031610, 28031612, 28031726, 28513361, 28535452, 28551156, 28694930, 28813479, 28813480, 28813480, 28813481, 28813481, 28928815, 28985191, 28985192, 29846790, 28031606, 28031607, 28031607, 28031608, 28031608, 28031609, 28031609, 28031610, 28219921, 28551157, 28804939, 28813480, 28813480, 28813481, 28813481, 28813482, 28813482, 28813484, 28985193, 29846804, 30637536, 28031607, 28031608, 28031727, 28813482, 28031611, 28084449, 28634427, 28813480, 28813481, 28813481, 28985192, 28985194, 28031609, 28535448, 28813481, 28031610, 28031611, 28031612, 28031612, 28031616, 28190179, 28294981, 28493869, 28535454, 28551159, 28731407, 28783449, 28804941, 28813482, 28813482, 28813483, 28813484, 28813484, 28813485, 28985193, 28985194, 28985194, 28985195, 28985195, 29846793, 29846793, 30839856, 28031611, 28031615, 28403992, 28493869, 28551159, 28813482, 28813482, 28813483, 28813483, 28985195, 28985196, 28031612, 28031613, 28413872, 28535449, 28735310, 28777986, 28813483, 28813483, 28985196, 28985196, 28813483, 28813484, 28813485, 29846794, 28813484, 28495817, 28813484, 28813485, 28985197, 28985198, 28783453, 28813485, 28813486, 28985198, 28813485, 28985200, 29846798, 28813488, 28813488, 28031858, 28031861, 28813611, 28813614, 28137303, 28137304, 28682122, 28866336, 28866337, 28348464, 28348614, 28348763, 28348765, 28348767, 28972066, 29143778, 30005378, 28408251, 29001812, 28558364, 28558366, 29076864, 29076866, 28740829, 28740904, 28740980, 29168180, 28776389, 28776391, 29357592, 29185880, 29357593, 28796151, 29195762, 28830204, 28830205, 29065866, 31451620, 29212787, 28956138, 29092036, 29275751, 28960035, 29277702, 29277702, 28995130, 29295248, 29039298, 29039302, 29039311, 29039311, 29039312, 29039312, 29039314, 29039316, 29317332, 29489042, 29317335, 29489053, 29489053, 29317341, 29317342, 29317341, 29317345, 29070720, 29070720, 29070725, 29333043, 29333043, 29255463, 29333043, 29504755, 29333045, 29226937, 29381118, 29227936, 29583364, 29237264, 29416318, 29301520, 29301527, 29448444, 29448447, 29358293, 30848827, 29431215, 29431222, 29513292, 29513297, 29439011, 29439081, 29517251, 29440206, 29517787, 29456749, 29526061, 29507141, 29507217, 29507293, 29521296, 29524378, 29559875, 29525156, 29560262, 31799094, 29535298, 29535301, 29535301, 29535301, 29565333, 29565334, 29565335, 29562440, 30958130, 29578284, 29578285, 29586825, 29586825, 29586826, 29595353, 29595354, 29595354, 29595354, 29595355, 29595355, 29595356, 29595356, 29595357, 29595357, 29595358, 29595363, 29595364, 29595365, 29595366, 29595366, 29595367, 29595367, 29595368, 29595369, 29595369, 29595370, 29595370, 29595371, 29595355, 29595356, 29595356, 29595357, 29595357, 29595358, 29595358, 29595359, 29595359, 29595366, 29595366, 29595367, 29595369, 29595369, 29595370, 29595370, 29595371, 29595371, 29595372, 29595356, 29595357, 29595357, 29595366, 29595368, 29595368, 29595369, 29595370, 29595370, 29595371, 29595371, 29595372, 29595372, 29595373, 29595374, 29595357, 29595358, 29595358, 29595359, 29595367, 29595367, 29595368, 29595368, 29595369, 29595370, 29595370, 29595371, 29595371, 29595372, 29595372, 29595374, 29595374, 29595358, 29595359, 29595360, 29595367, 29595368, 29595369, 29595370, 29595371, 29595371, 29595372, 29595373, 29595373, 29595374, 29595374, 29595375, 29595359, 29595360, 29595368, 29595368, 29595371, 29595372, 29595372, 29595360, 29595361, 29595368, 29595369, 29595372, 29595373, 29595375, 29595369, 29595370, 29595371, 29595372, 29595372, 29595373, 29595373, 29595376, 29595377, 29595371, 29595374, 29595375, 29595370, 29595372, 29595374, 29595373, 29595379, 29595380, 29595378, 29595378, 29595379, 29595380, 29595381, 29595381, 29595382, 29595382, 29595383, 29595384, 29595480, 29595379, 29595381, 29595381, 29595382, 29595480, 29595380, 29595381, 29595382, 29595382, 29595383, 29595385, 29595481, 29595380, 29595382, 29595384, 29595382, 29595382, 29595383, 29595383, 29595384, 29595480, 29595482, 29595384, 29595383, 29595384, 29595384, 29595387, 29595483, 29767081, 29595384, 29595385, 29595385, 29595386, 29595386, 29595387, 29595387, 29595483, 29767080, 29767081, 29767081, 29767082, 29767082, 30628680, 30628680, 30628681, 30967353, 29595385, 29595386, 29595386, 29595387, 29595387, 29595388, 29595390, 29595484, 29714978, 29767081, 29767081, 29767082, 29767082, 29767083, 30628680, 30628680, 30628681, 31440738, 31834204, 31848024, 29595386, 29595387, 29595387, 29595388, 29595388, 29595389, 29595390, 29595482, 29595483, 29595484, 29595504, 29767081, 29767081, 29767082, 29767082, 29767083, 29767083, 30628680, 30628681, 31419425, 31834203, 29595387, 29595388, 29595389, 29595391, 29595484, 29595485, 29767082, 29767082, 29767083, 29767083, 30628682, 31834205, 29595389, 29595389, 29595485, 29595489, 29767080, 29767081, 29767082, 29767083, 29767083, 29767084, 29767084, 31088594, 31834205, 29595389, 29595484, 29595486, 29657866, 29767082, 29767083, 29767084, 29767084, 29767085, 29595390, 29595391, 29595485, 29595486, 29767082, 29767083, 29767084, 29767084, 29767085, 29767085, 29595391, 29595392, 29595485, 29595487, 29767084, 29767084, 29767085, 29767085, 29904907, 29595485, 29595487, 29767084, 29767085, 29767086, 29767086, 30628684, 30628685, 29767086, 29767087, 29595489, 29767085, 29595581, 29595590, 29595582, 29595591, 29595592, 29595592, 29595599, 29660202, 29746188, 29767189, 29767190, 29767190, 29767191, 29767191, 29905011, 30628788, 30628789, 30628789, 30900218, 30900221, 31834362, 29767194, 29595631, 29767209, 29720368, 29720438, 29720485, 29829633, 29724816, 29831806, 29826038, 29826038, 29882414, 30744032, 29834583, 29886687, 29896796, 29917799, 29938788, 29938777, 29938776, 29938777, 29938778, 29938777, 29938778, 29938778, 29938779, 29938792, 29938792, 29938794, 29938778, 29938779, 29938779, 29938780, 29938793, 29938794, 29938796, 29938796, 29938779, 29938780, 29938794, 29938780, 29938781, 29938786, 29938791, 29938792, 29938793, 29938794, 29938794, 29938795, 29938795, 29938796, 29938796, 29938797, 29938797, 29938798, 29938798, 29938799, 29938803, 29938781, 29938782, 29938793, 29938793, 29938794, 29938794, 29938795, 29938795, 29938796, 29938796, 29938797, 29938797, 29938798, 29938798, 29938799, 29938799, 29938800, 29938803, 29938794, 29938795, 29938795, 29938796, 29938796, 29938797, 29938797, 29938798, 29938797, 29938797, 29938800, 29938801, 29938807, 29938808, 30522000, 32005969, 29938807, 29938808, 29938807, 29938808, 29938808, 29938809, 29938809, 29938807, 29938808, 29938808, 29938809, 29938809, 30121375, 32019771, 29938808, 29938809, 29938809, 29938810, 29938810, 30800408, 29938809, 29938810, 29938810, 29938811, 29938811, 29938812, 30800393, 31139066, 29938810, 29938811, 29938811, 29938812, 29938812, 29938814, 29938814, 30076616, 30800391, 30800393, 30800393, 30800401, 30800408, 31071822, 32005916, 32028453, 29938811, 29938812, 29938812, 29938813, 29938813, 29938814, 29938814, 29938815, 29938817, 30076616, 30076617, 30800393, 30800393, 30800394, 30800394, 31071823, 31612451, 32005917, 32019737, 29938812, 29938813, 29938813, 29938814, 29938814, 29938815, 29938816, 29938817, 30076617, 30076618, 30085487, 30121377, 30121378, 30723136, 30800392, 30800393, 30800393, 30800394, 30800394, 30800411, 30890211, 31139068, 31242530, 31908948, 32005917, 29938813, 29938814, 29938814, 29938815, 29938815, 29938816, 29938817, 29938819, 30076618, 30076618, 30121378, 30560725, 30626067, 30698921, 30800392, 30800393, 30800394, 30800394, 30800395, 30800395, 31071824, 31139067, 32005917, 32005918, 32005964, 32005967, 32019738, 29938814, 29938815, 29938815, 29938816, 29938816, 29938817, 29938819, 29938822, 29938822, 30076617, 30076620, 30323752, 30698921, 30800393, 30800394, 30800394, 30800395, 30800395, 31071815, 31071824, 31071827, 32005917, 32005918, 29938815, 29938816, 29938816, 29938817, 29938817, 29938818, 29938819, 29938820, 29938820, 30018154, 30076619, 30076619, 30076620, 30109845, 30121379, 30767866, 30800271, 30800395, 30800395, 30800396, 30800396, 30800411, 30800414, 31071825, 31107524, 31139067, 31139068, 31139069, 31139069, 32005918, 32005919, 32005964, 32005965, 32014468, 29938816, 29938817, 29938817, 29938818, 29938818, 29938819, 29938820, 29938820, 30076619, 30076620, 30800392, 30800395, 30800396, 30800396, 31612454, 32014468, 29938817, 29938818, 29938818, 29938819, 29938819, 29938820, 29938820, 29938821, 29938821, 30076620, 30121380, 30800395, 30800396, 30800396, 30800397, 30800397, 30800411, 31139069, 31139070, 32005920, 32005970, 32005974, 29938818, 29938819, 29938819, 29938820, 29938821, 29938826, 30085491, 30323755, 30800396, 30800397, 30800397, 30800412, 31071826, 31675709, 29938819, 29938820, 29938820, 29938823, 30076621, 30076621, 30083145, 30085492, 30111879, 30121379, 30121381, 30800396, 30800396, 30800397, 30800397, 30800398, 30800399, 32005921, 32005966, 32005972, 29938820, 29938821, 29938821, 29938822, 29938823, 29938827, 30109847, 30698909, 30800396, 30800398, 30800398, 29938822, 29938823, 29938825, 29938828, 30800397, 30800398, 30800399, 31139072, 29938822, 30121382, 30800398, 30800399, 30800399, 30800403, 29988140, 30800399, 30800400, 30800419, 29938826, 30800400, 30800409, 30560731, 30800399, 30800399, 30800400, 30800400, 30800401, 30085493, 30800401, 30800401, 30800401, 30800401, 30800402, 30800401, 29938832, 30800403, 30800404, 30085499, 30800405, 30800406, 30800406, 30037491, 30849750, 30097548, 30097623, 30097679, 30879844, 30214435, 30214436, 30214436, 30214437, 30214436, 30214437, 30214437, 30214438, 30214438, 30938212, 30259196, 30836740, 30938212, 30938213, 30938213, 31781275, 30938213, 30938213, 30227481, 30944733, 30232180, 30232180, 30232179, 30232181, 30232168, 30232179, 30232189, 31285757, 30268069, 30947086, 30947086, 30947087, 30947088, 30280889, 30280891, 30971440, 31310114, 30284951, 30284968, 30284988, 30973489, 30303941, 30303954, 30303955, 30303957, 30303957, 30303958, 30303957, 30303958, 30982971, 30982971, 30982971, 30982972, 30982972, 31321645, 30982973, 30982974, 31321646, 32188496, 30982975, 32188498, 30708702, 30708703, 31185345, 31185348, 31105243, 31843545, 31182656, 31422325, 32627896, 31313337, 31487663, 31459027, 31459052, 31459053, 31560515, 31560525, 31560525, 31507534, 31507634, 31507735, 32044803, 31596936, 31968139, 31661736, 31661861, 31661971, 31661974, 31661990, 31661974, 31661975, 31661988, 31661988, 31661974, 31661975, 31661975, 31661987, 31661989, 31661975, 31661976, 31661989, 31661990, 31661990, 31661991, 31661992, 31661976, 31661977, 31661984, 31661988, 31661991, 31661991, 31661992, 31661992, 31661993, 31661993, 31661994, 31661994, 31661996, 31661977, 31661978, 31661978, 31661979, 31661979, 31661980, 31661980, 31661981, 31661982, 31661983, 31661984, 31661985, 31661985, 31661986, 31661987, 31661987, 31661988, 31661988, 31661989, 31661989, 31661990, 31661990, 31661991, 31661991, 31661992, 31661992, 31661993, 31661993, 31661994, 31661994, 31661995, 31661995, 31661996, 31661997, 31661978, 31661980, 31661982, 31661983, 31661986, 31661988, 31661990, 31661990, 31661991, 31661992, 31661992, 31661993, 31661993, 31661994, 31661996, 31661980, 31661981, 31661982, 31661983, 31661985, 31661987, 31661989, 31661990, 31661992, 31661993, 31661993, 31661994, 31661983, 31661992, 31661994, 31661995, 31661982, 31661983, 31661988, 31661989, 31661992, 31661995, 31661995, 31661998, 31661985, 31661989, 31661991, 31661993, 31661995, 31661997, 31661989, 31661991, 31661985, 31661987, 31661995, 31661996, 31662015, 31661996, 31661997, 31661991, 31661992, 31661994, 31661998, 31661995, 31661994, 31661998, 31661997, 31661999, 31662000, 31662001, 31661996, 31661997, 31662000, 31661995, 31662001, 31662019, 31662000, 31662000, 31662001, 31662001, 31662004, 31662002, 31662002, 31662003, 31662000, 31662002, 31662002, 31662003, 31662003, 31662003, 31662003, 31662003, 31662003, 31662004, 32867511, 31662003, 31662004, 31662008, 31662002, 31662003, 31662004, 31662005, 31662005, 31662006, 31662007, 31662023, 31662003, 31662004, 31662004, 31662005, 31662005, 31662006, 31662006, 32867513, 31662005, 31662005, 31662006, 31662007, 31933419, 31662005, 31662006, 31662006, 31662007, 31662007, 31662025, 31779224, 32000664, 32573111, 32867567, 31662006, 31662007, 31662007, 31662008, 31662008, 31662009, 31662010, 31662025, 31933420, 32121903, 32452737, 32867514, 32890100, 31662007, 31662008, 31662008, 31662009, 31662009, 31662010, 31662010, 31662011, 31662012, 31662020, 31662022, 31662023, 31662024, 31662026, 31751806, 31933421, 32000664, 32000665, 32121904, 32414934, 32474049, 32867514, 32867515, 32867566, 32881335, 32890052, 31662008, 31662009, 31662009, 31662010, 31662010, 31662011, 31662011, 31662012, 31662013, 31662026, 31779226, 31933412, 31933421, 32000664, 32000666, 32121904, 32121905, 32121906, 32335631, 32414934, 32671143, 32867515, 32867561, 32867565, 32867570, 32876066, 32881336, 31662009, 31662010, 31662010, 31662011, 31662011, 31662012, 31662012, 31662013, 31662013, 31662014, 31662023, 31662027, 31751809, 31933419, 31933422, 32000666, 32000666, 32000667, 32000668, 32121905, 32121905, 32121906, 32122636, 32291202, 32414935, 32452738, 32474050, 32474050, 32867297, 32867515, 32867516, 32867562, 32867564, 32867566, 32881336, 31662010, 31662011, 31662011, 31662012, 31662012, 31662013, 31662013, 31662014, 31662017, 31662022, 31662023, 31662024, 31662025, 31662027, 31662029, 31933422, 32000666, 32000666, 32000667, 32121905, 32452737, 32452739, 32867516, 32867562, 32867565, 32881337, 31662011, 31662012, 31662012, 31662013, 31662013, 31662014, 31662015, 31662015, 31662016, 31662025, 31662025, 31662028, 31662028, 31933420, 31933423, 32000667, 32000667, 32121906, 32121906, 32452741, 32474051, 32867517, 32867568, 32881337, 31662012, 31662013, 31662013, 31662014, 31662014, 31662015, 31662016, 31662016, 31662018, 31662019, 31662028, 31662029, 31933423, 32000667, 32414936, 32452739, 32474051, 32867517, 32867565, 31662013, 31662014, 31662014, 31662015, 31662015, 31662016, 31662016, 31662017, 31662017, 31662020, 31662020, 31662029, 31662030, 31933424, 31933426, 32000667, 32000668, 32000668, 32121907, 32452739, 32474052, 32585474, 32867517, 32867518, 32867564, 32881338, 31662014, 31662015, 31662015, 31662016, 31662017, 31662018, 31662026, 31662029, 31662030, 31662030, 31933415, 31933424, 32000667, 32000668, 32121907, 32867517, 32867518, 31662015, 31662016, 31662016, 31662017, 31662020, 31662021, 31662023, 31662030, 31662030, 32867519, 32867562, 31662016, 31662017, 31662018, 31662019, 31662030, 31662031, 32867519, 32867565, 31662017, 31662018, 31662018, 31662019, 31662020, 31662028, 31662030, 31662031, 31662032, 31933426, 32452741, 31662018, 31662019, 31662030, 31662030, 31662031, 31662032, 31933426, 31662019, 31662026, 31662032, 31892543, 32867521, 32881341, 31662029, 31662032, 31933427, 32000671, 32000672, 31662021, 31662031, 31662033, 32000675, 31662024, 31662034, 32000672, 31662034, 31751819, 31662027, 31933431, 31662031, 31662033, 31662033, 31662036, 32414943, 31933432, 31662035, 31662039, 31933435, 31662042, 31662041, 31662041, 31933436, 31662042, 31662043, 32121920, 32867531, 31662042, 31933437, 31662043, 31933438, 32000681, 32121921, 31662043, 31662044, 32867533, 31662045, 31662046, 31662046, 31662047, 31751826, 31751829, 31751829, 31751831, 31933437, 31933440, 31933441, 31969139, 31997777, 32000682, 32000684, 32000684, 32007464, 32104143, 32121922, 32121923, 32121924, 32121925, 32368363, 32368385, 32414953, 32452752, 32452755, 32452756, 32452757, 32474068, 32537323, 32573131, 32723227, 32867533, 32867533, 32867534, 32867580, 32867581, 32867589, 32881354, 32890071, 31662046, 31933440, 32000684, 32000685, 32452756, 32474068, 32867534, 32867555, 32867581, 32867584, 32881355, 32881404, 32890120, 31662047, 31933441, 32000685, 32000685, 32337347, 32867534, 32867535, 32867589, 32890072, 31751830, 31933432, 31933441, 32000685, 32121926, 32452757, 32867535, 32867581, 32867585, 32881356, 32867535, 31841620, 31841621, 31841622, 31841623, 31841615, 31841628, 31841626, 31841626, 31841630, 31841626, 31841636, 32957327, 32054553, 32169976, 32971150, 32369393, 32023237, 32090481, 32211722, 32957333, 31896459, 31896460, 32050655, 32123082, 33098106, 32204825, 32204851, 32204832, 32204858, 32204836, 32204854, 32204860, 32204860, 32204861, 32204871, 32204879, 32204862, 32204880, 32204880, 32204881, 32204882, 32204879, 32204880, 33138948, 32204885, 32393342, 32204886, 32204904, 32236178, 32272104, 32272104, 32272105, 32272105, 32313675, 32375563, 32393343, 32393343, 32393344, 32545620, 32686373, 32724175, 32724177, 32724178, 32745488, 32745490, 32776493, 32808745, 33138953, 33138954, 33138954, 33139000, 33139000, 33139004, 32204905, 32246133, 32272105, 32272105, 32272106, 32272107, 32607071, 32607072, 32724177, 32724184, 32745489, 32745489, 32783275, 32808744, 32844552, 33138955, 33139000, 33152775, 32272115, 33138965, 33152786, 32272123, 32272123, 32379966, 32393362, 32724200, 33138973, 33139019, 33152793, 32267481, 32267573, 32267574, 32267665, 32267668, 32303499, 33170400, 32276244, 32892598, 33174639, 32287390, 32434601, 32333557, 33203366, 32339321, 32339336, 32339339, 32339322, 32339334, 32339337, 32339337, 32339338, 32339338, 32339339, 32339339, 32339340, 32339323, 32339324, 32339335, 32339337, 32339338, 32339338, 32339339, 32339339, 32339340, 32339340, 32339324, 32339336, 32339336, 32339338, 32339339, 32339339, 32339340, 32339340, 32339341, 32339339, 32339340, 32339341, 32339341, 32339342, 32339344, 32339346, 33206185, 32339351, 32812719, 33220059, 32339353, 33206187, 32339355, 32674305, 32812722, 33206187, 33206188, 33206234, 32339354, 32339355, 32791410, 32791411, 33206188, 33220009, 32339355, 32339356, 32339356, 32460579, 32551909, 32791410, 32791412, 32791415, 33206188, 33206189, 33206235, 33220009, 32339357, 32460578, 32478000, 32753608, 32791410, 32812723, 33206188, 33206189, 33206189, 33206240, 32382241, 32418838, 32460578, 32460579, 32791411, 32791412, 32875980, 33206190, 33206236, 33206236, 33206245, 33220010, 32460579, 32460580, 32674308, 32791412, 32812724, 33206189, 33206190, 33220011, 33206191, 32460580, 33206191, 33206192, 32352893, 33213018, 32353822, 32819963, 32422540, 32422841, 32423141, 33248119, 32425143, 32855626, 32498331, 32498332, 32540073, 33285684, 32546256, 32546256, 32546260, 33309646, 33309647, 32555024, 32920565, 33327851, 32581814, 32581814, 32581814, 32581815, 32581815, 32581801, 32581802, 32581815, 32581816, 32581816, 32581817, 32581803, 32581816, 32581817, 32581817, 32581817, 32581818, 32581817, 32581818, 32581818, 33327426, 32581830, 32581831, 32828278, 32912649, 32933960, 33327426, 32581831, 32581832, 32795544, 32933961, 32997216, 33327426, 33327426, 33327427, 33327472, 33327473, 33327476, 33349964, 32582548, 32713759, 32912649, 32912650, 32933961, 33327427, 33327427, 33327473, 33327476, 33341248, 32828279, 33327428, 32583282, 32583283, 32934695, 33328162, 32616687, 33344877, 32764475, 32956718, 32845703, 33459372, 32886372, 33479706, 32897159, 33091631, 32920407, 33496720, 33009270, 33009269, 33009270, 33009271, 33541152, 33554974, 33541154, 33012666, 33012664, 33542848, 33542854, 33074689, 33074710, 33074729, 33074743, 33573877, 33074812, 33074875, 33159176, 33159177, 33573954, 33148961, 33196220, 33167875, 33167875, 33167876, 33167873, 33620452, 33205678, 33290246, 33620457, 33620502, 33620503, 33629008, 33243477, 33243476, 33243481, 33243480, 33243483, 33243467, 33243481, 33243482, 33243482, 33243483, 33243483, 33243484, 33243485, 33243482, 33243484, 33243485, 33243479, 33243480, 33243483, 33243483, 33243484, 33243485, 33243485, 33243484, 33243489, 33243491, 33243492, 33243495, 33243494, 33243496, 33658255, 33658257, 33658258, 33363856, 33658259, 33246265, 33658260, 33658306, 33658260, 33264795, 33363858, 33658260, 33658261, 33672081, 33658307, 33243502, 33398609, 33658261, 33658262, 33666812, 33658262, 33658263, 33658309, 33264797, 33264800, 33658267, 33658267, 33658313, 33658268, 33658269, 33249045, 33674860, 33286091, 33286103, 33286104, 33286104, 33286105, 33286106, 33286106, 33286107, 33286108, 33286104, 33286104, 33286105, 33286107, 33286109, 33679568, 33679569, 33286119, 33679568, 33679569, 33679570, 33679616, 33679619, 33693390, 33349359, 33679570, 33679616, 33679571, 33286121, 33679571, 33679572, 33693392, 33679572, 33679573, 33679574, 33348111, 33348111, 33348245, 33348242, 33348371, 33348378, 33710702, 33710705, 33361674, 33717354, 33412612, 33412613, 33412613, 33412614, 33412615, 33742822, 33765409, 33742824, 33742870, 33742823, 33742824, 33484229, 33484229, 33484241, 33778632, 33778631, 33778632, 33778678, 33778682, 33508950, 33508953, 33791040, 33553732, 33813436, 33648177, 33648389, 33648601, 33860850, 33680289, 33680375, 33680460, 33876746, 33784424, 33928731, 33879107, 33976076, 34072649, 34072867, 34073020, 34073021, 34073022, 34073022, 34073023, 34073024, 34073024, 34073025, 34073025, 34073026, 34073027, 34073028, 34073031, 34073032, 34073033, 34073034, 34073034, 34073043, 34073050, 34073065, 34073066, 34073067, 34073067, 34073068, 34073068, 34073069, 34073069, 34073070, 34073070, 34073071, 34073071, 34073024, 34073025, 34073025, 34073026, 34073028, 34073028, 34073032, 34073033, 34073038, 34073067, 34073068, 34073068, 34073069, 34073069, 34073025, 34073026, 34073026, 34073032, 34073033, 34073069, 34073028, 34073033, 34073034, 34073069, 34073070, 34073027, 34073028, 34073029, 34073034, 34073035, 34073047, 34073069, 34073070, 34073070, 34073030, 34073035, 34073070, 34073070, 34073071, 34073071, 34073070, 34073071, 34073072, 34073073, 34073072, 34073073, 34073040, 34073041, 34073041, 34073042, 34073043, 34073043, 34073077, 34073077, 34073078, 34073085, 34073043, 34073044, 34073079, 34073079, 34073092, 34073144, 34073145, 34073045, 34073046, 34073079, 34073080, 34073046, 34073080, 34073080, 34073081, 34073082, 34073084, 34073086, 34073089, 34073145, 34073146, 34073080, 34073081, 34073081, 34073088, 34073146, 34073082, 34073087, 34073096, 34073091, 34073095, 34073110, 34073111, 34073111, 34073112, 34073112, 34073111, 34073112, 34073112, 34073112, 34073113, 34073114, 34073113, 34073114, 34073119, 34073114, 34073115, 34073116, 34073116, 34073117, 34073118, 34073119, 34073123, 34073144, 34073115, 34073116, 34073116, 34073117, 34073117, 34073118, 34073118, 34073119, 34073119, 34073120, 34073120, 34073121, 34073121, 34073122, 34073122, 34073123, 34073124, 34073125, 34073127, 34073127, 34073130, 34073132, 34073135, 34073137, 34073144, 34073144, 34073116, 34073117, 34073117, 34073118, 34073118, 34073119, 34073119, 34073120, 34073120, 34073121, 34073121, 34073122, 34073122, 34073123, 34073123, 34073124, 34073124, 34073125, 34073127, 34073135, 34073137, 34073143, 34073144, 34073145, 34073117, 34073118, 34073118, 34073119, 34073120, 34073120, 34073121, 34073122, 34073123, 34073124, 34073125, 34073131, 34073136, 34073145, 34073118, 34073119, 34073119, 34073120, 34073120, 34073121, 34073121, 34073122, 34073122, 34073123, 34073124, 34073124, 34073125, 34073125, 34073126, 34073126, 34073127, 34073127, 34073137, 34073145, 34073145, 34073146, 34073119, 34073120, 34073120, 34073121, 34073121, 34073122, 34073122, 34073123, 34073123, 34073124, 34073124, 34073125, 34073126, 34073127, 34073134, 34073134, 34073137, 34073137, 34073146, 34073146, 34073147, 34073120, 34073121, 34073121, 34073122, 34073122, 34073123, 34073123, 34073124, 34073125, 34073126, 34073126, 34073129, 34073140, 34073145, 34073147, 34073147, 34073121, 34073122, 34073122, 34073123, 34073123, 34073124, 34073126, 34073126, 34073127, 34073127, 34073144, 34073147, 34073148, 34073148, 34073122, 34073123, 34073123, 34073124, 34073124, 34073125, 34073125, 34073127, 34073127, 34073129, 34073140, 34073143, 34073144, 34073145, 34073146, 34073148, 34073123, 34073124, 34073124, 34073125, 34073125, 34073126, 34073126, 34073127, 34073127, 34073128, 34073128, 34073129, 34073130, 34073131, 34073132, 34073134, 34073136, 34073138, 34073139, 34073139, 34073141, 34073141, 34073142, 34073142, 34073143, 34073144, 34073144, 34073145, 34073146, 34073146, 34073147, 34073147, 34073148, 34073148, 34073149, 34073124, 34073125, 34073125, 34073126, 34073126, 34073127, 34073128, 34073128, 34073129, 34073130, 34073131, 34073132, 34073133, 34073138, 34073139, 34073140, 34073140, 34073141, 34073142, 34073142, 34073143, 34073144, 34073146, 34073147, 34073148, 34073149, 34073125, 34073126, 34073126, 34073127, 34073127, 34073128, 34073129, 34073132, 34073139, 34073142, 34073143, 34073144, 34073145, 34073145, 34073146, 34073149, 34073149, 34073126, 34073127, 34073128, 34073128, 34073129, 34073130, 34073131, 34073132, 34073133, 34073135, 34073139, 34073141, 34073143, 34073145, 34073147, 34073147, 34073148, 34073149, 34073149, 34073150, 34073127, 34073128, 34073128, 34073129, 34073129, 34073130, 34073130, 34073131, 34073131, 34073132, 34073133, 34073133, 34073134, 34073134, 34073138, 34073138, 34073139, 34073142, 34073143, 34073143, 34073144, 34073144, 34073145, 34073146, 34073146, 34073147, 34073147, 34073148, 34073148, 34073149, 34073150, 34073150, 34073151, 34073128, 34073129, 34073129, 34073130, 34073130, 34073131, 34073131, 34073132, 34073133, 34073133, 34073134, 34073135, 34073136, 34073142, 34073144, 34073145, 34073146, 34073149, 34073150, 34073150, 34073151, 34073129, 34073130, 34073130, 34073131, 34073131, 34073132, 34073132, 34073133, 34073134, 34073139, 34073142, 34073143, 34073145, 34073145, 34073146, 34073147, 34073148, 34073149, 34073150, 34073151, 34073152, 34073130, 34073131, 34073131, 34073132, 34073134, 34073140, 34073142, 34073143, 34073144, 34073144, 34073145, 34073147, 34073150, 34073151, 34073152, 34073131, 34073132, 34073135, 34073143, 34073144, 34073145, 34073152, 34073152, 34073132, 34073133, 34073133, 34073134, 34073135, 34073135, 34073136, 34073137, 34073137, 34073138, 34073139, 34073140, 34073141, 34073142, 34073143, 34073145, 34073145, 34073146, 34073146, 34073147, 34073147, 34073148, 34073149, 34073149, 34073150, 34073150, 34073151, 34073152, 34073152, 34073153, 34073133, 34073134, 34073134, 34073135, 34073136, 34073136, 34073137, 34073137, 34073138, 34073139, 34073139, 34073141, 34073142, 34073143, 34073144, 34073144, 34073145, 34073146, 34073146, 34073147, 34073147, 34073150, 34073151, 34073153, 34073153, 34073134, 34073137, 34073138, 34073139, 34073142, 34073143, 34073145, 34073146, 34073146, 34073147, 34073147, 34073150, 34073152, 34073153, 34073154, 34073154, 34073136, 34073144, 34073145, 34073146, 34073146, 34073147, 34073148, 34073149, 34073150, 34073153, 34073154, 34073154, 34073137, 34073137, 34073143, 34073144, 34073147, 34073149, 34073149, 34073154, 34073155, 34073155, 34073155, 34073138, 34073144, 34073147, 34073148, 34073149, 34073151, 34073156, 34073140, 34073145, 34073145, 34073147, 34073147, 34073148, 34073149, 34073149, 34073150, 34073151, 34073152, 34073153, 34073154, 34073156, 34073156, 34073142, 34073143, 34073145, 34073146, 34073147, 34073148, 34073148, 34073151, 34073152, 34073154, 34073154, 34073155, 34073155, 34073157, 34073144, 34073146, 34073148, 34073148, 34073152, 34073158, 34073143, 34073144, 34073148, 34073151, 34073157, 34073158, 34073149, 34073154, 34073158, 34073147, 34073149, 34073154, 34073158, 34073150, 34073152, 34073155, 34073156, 34073159, 34073159, 34073149, 34073152, 34073160, 34073152, 34073156, 34073159, 34073160, 34073161, 34073149, 34073155, 34073161, 34073150, 34073153, 34073154, 34073154, 34073155, 34073155, 34073156, 34073158, 34073162, 34073156, 34073157, 34073157, 34073160, 34073162, 34073155, 34073155, 34073159, 34073161, 34073162, 34073163, 34073156, 34073156, 34073160, 34073163, 34073154, 34073155, 34073156, 34073156, 34073157, 34073157, 34073158, 34073160, 34073160, 34073161, 34073161, 34073163, 34073164, 34073164, 34086909, 34073156, 34073157, 34073157, 34073158, 34073161, 34073163, 34073164, 34073165, 34073157, 34073158, 34073158, 34073160, 34073161, 34073162, 34073162, 34073164, 34073165, 34073165, 34073158, 34073159, 34073159, 34073160, 34073161, 34073162, 34073164, 34073165, 34073166, 34073159, 34073160, 34073160, 34073161, 34073161, 34073162, 34073163, 34073164, 34073165, 34073166, 34073166, 34073160, 34073161, 34073161, 34073162, 34073163, 34073163, 34073164, 34073164, 34073165, 34073165, 34073166, 34073167, 34073167, 34086912, 34073161, 34073162, 34073163, 34073163, 34073164, 34073165, 34073165, 34073167, 34073167, 34073168, 34073162, 34073163, 34073164, 34073165, 34073165, 34073167, 34073168, 34086913, 34073164, 34073164, 34073165, 34073166, 34073166, 34073167, 34073167, 34073168, 34073168, 34073166, 34073167, 34073168, 34073168, 34073169, 34086914, 34073165, 34073166, 34073166, 34073167, 34073168, 34073168, 34073169, 34073169, 34073170, 34081643, 34086914, 34073166, 34073167, 34073167, 34073168, 34073169, 34073169, 34073170, 34073167, 34073168, 34073168, 34073169, 34073170, 34073170, 34073168, 34073169, 34073169, 34073170, 34073170, 34073171, 34081645, 34086916, 34073169, 34073170, 34073170, 34073171, 34073171, 34073172, 34073170, 34073171, 34073171, 34073172, 34073172, 34073175, 34086917, 34073171, 34073172, 34073172, 34073173, 34073172, 34073173, 34073219, 34073173, 34073174, 34073209, 34073219, 34073174, 34073175, 34073175, 34073176, 34073176, 34073178, 34073178, 34073186, 34073186, 34073187, 34073187, 34073189, 34073190, 34073205, 34073209, 34073210, 34073219, 34073220, 34081648, 34086739, 34086919, 34095635, 34073175, 34073176, 34073176, 34073177, 34073178, 34073179, 34073179, 34073180, 34073181, 34073182, 34073182, 34073183, 34073183, 34073185, 34073185, 34073186, 34073187, 34073187, 34073188, 34073189, 34073189, 34073191, 34073192, 34073192, 34073193, 34073195, 34073196, 34073197, 34073198, 34073202, 34073206, 34073206, 34073208, 34073208, 34073210, 34073210, 34073211, 34073213, 34073214, 34073215, 34073216, 34073216, 34073217, 34073218, 34073218, 34073219, 34073219, 34073220, 34073220, 34086919, 34073176, 34073177, 34073179, 34073179, 34073180, 34073185, 34073187, 34073188, 34073189, 34073190, 34073193, 34073193, 34073196, 34073197, 34073206, 34073207, 34073209, 34073218, 34073218, 34073219, 34073219, 34073220, 34073220, 34073221, 34073177, 34073183, 34073189, 34073215, 34073217, 34073218, 34073220, 34073221, 34073221, 34073178, 34073180, 34073192, 34073198, 34073204, 34073207, 34073221, 34073221, 34073222, 34073179, 34073184, 34073218, 34073222, 34073223, 34073182, 34073190, 34073193, 34073224, 34073183, 34073184, 34073191, 34073194, 34073224, 34073184, 34073190, 34073224, 34073225, 34073185, 34073194, 34073225, 34073226, 34073222, 34073194, 34073217, 34073227, 34073225, 34073194, 34073229, 34073196, 34073202, 34073203, 34073227, 34073231, 34073229, 34073231, 34073198, 34073220, 34073229, 34086931, 34073200, 34073203, 34073207, 34073228, 34073230, 34073231, 34073231, 34073232, 34073232, 34086931, 34073203, 34073223, 34081661, 34086932, 34073202, 34073204, 34073204, 34073206, 34073215, 34073227, 34073233, 34086932, 34073205, 34073204, 34073205, 34073219, 34073234, 34073234, 34073235, 34081659, 34081661, 34073221, 34073235, 34073236, 34073220, 34073221, 34073236, 34086935, 34073237, 34073237, 34073238, 34073222, 34073235, 34073238, 34073225, 34073241, 34073241, 34073242, 34073242, 34073242, 34073245, 34073248, 34073249, 34073247, 34073248, 34073249, 34073250, 34073251, 34073251, 34073251, 34073252, 34073252, 34073253, 34073254, 34073245, 34073246, 34073255, 34073256, 34073257, 34081684, 34073256, 34073257, 34073259, 34073255, 34073257, 34073260, 34073260, 34073260, 34073259, 34073260, 34073261, 34073262, 34073261, 34073262, 34073263, 34073261, 34073262, 34073262, 34073263, 34073263, 34073263, 34073263, 34073264, 34073263, 34073264, 34073264, 34073265, 34073265, 34073266, 34073267, 34073268, 34073300, 34081691, 34081692, 34081693, 34081693, 34081694, 34081694, 34081695, 34081695, 34081696, 34081696, 34081698, 34081703, 34081704, 34086785, 34086964, 34086965, 34086996, 34095681, 34073268, 34081694, 34081695, 34081696, 34081697, 34086965, 34086965, 34081692, 34081694, 34081695, 34081696, 34081697, 34086966, 34086997, 34086997, 34086998, 34087002, 34087007, 34087007, 34087018, 34087018, 34087023, 34087062, 34095682, 34095730, 34095731, 34095795, 34642263, 40782803, 34086966, 34086967, 34081737, 34086999, 34090135, 34090130, 34090137, 34090129, 34090136, 34090137, 34090135, 34090121, 34090121, 34090129, 34090132, 34090135, 34090135, 34090136, 34090137, 34090139, 34090136, 34090136, 34090140, 34090141, 34090144, 34090122, 34090123, 34090137, 34090137, 34090138, 34090138, 34090123, 34090125, 34090134, 34090134, 34090135, 34090135, 34090136, 34090137, 34090137, 34090138, 34090138, 34090139, 34090139, 34090140, 34090135, 34090137, 34090139, 34090139, 34090140, 34090140, 34090141, 34090136, 34090138, 34090140, 34090140, 34090141, 34090141, 34090141, 34090142, 34090146, 34090142, 34090145, 34090145, 34090143, 34090145, 34090226, 34090226, 34090153, 34090153, 34090153, 34095404, 34095436, 34090149, 34090151, 34090154, 34095405, 34095405, 34095406, 34090152, 34095407, 34095407, 34090152, 34090157, 34095407, 34095408, 34090156, 34095408, 34095409, 34095409, 34095410, 34095441, 34095410, 34090158, 34095411, 34095411, 34095412, 34095412, 34095413, 34095234, 34095414, 34095415, 34095415, 34090322, 34090323, 34095498, 34095498, 34100376, 34100378, 34100379, 34100556, 34100558, 34100559, 34100663, 34100664, 34100665, 34100665, 34100666, 34100666, 34100667, 34100671, 34100677, 34100685, 34100690, 34100691, 34100692, 34100693, 34100693, 34100694, 34100694, 34100695, 34100695, 34100696, 34100696, 34100697, 34100698, 34100739, 34100668, 34100694, 34100695, 34100695, 34100696, 34100696, 34100696, 34100696, 34100696, 34100696, 34100697, 34100696, 34100697, 34100699, 34100698, 34100702, 34100709, 34100714, 34100716, 34100721, 34100723, 34100721, 34100722, 34100723, 34100722, 34100724, 34100724, 34100725, 34100768, 34100770, 34100723, 34100724, 34100724, 34100725, 34100725, 34100726, 34100728, 34100770, 34100724, 34100725, 34100725, 34100726, 34100733, 34100769, 34100771, 34100725, 34100726, 34100726, 34100727, 34100744, 34100760, 34100770, 34100770, 34100771, 34100726, 34100727, 34100727, 34100728, 34100734, 34100744, 34100746, 34100749, 34100770, 34100770, 34100771, 34100727, 34100728, 34100728, 34100729, 34100729, 34100730, 34100730, 34100731, 34100731, 34100734, 34100734, 34100736, 34100741, 34100742, 34100743, 34100744, 34100745, 34100745, 34100746, 34100747, 34100747, 34100748, 34100749, 34100750, 34100750, 34100751, 34100752, 34100752, 34100770, 34100771, 34100771, 34100728, 34100729, 34100729, 34100730, 34100730, 34100731, 34100731, 34100732, 34100733, 34100734, 34100735, 34100736, 34100736, 34100737, 34100738, 34100738, 34100739, 34100740, 34100741, 34100742, 34100743, 34100744, 34100744, 34100745, 34100745, 34100746, 34100747, 34100747, 34100748, 34100748, 34100749, 34100750, 34100751, 34100751, 34100752, 34100752, 34100753, 34100753, 34100754, 34100756, 34100756, 34100757, 34100768, 34100769, 34100771, 34100771, 34100772, 34100729, 34100730, 34100730, 34100731, 34100731, 34100732, 34100732, 34100735, 34100735, 34100736, 34100737, 34100738, 34100739, 34100739, 34100745, 34100746, 34100746, 34100747, 34100748, 34100748, 34100749, 34100750, 34100751, 34100752, 34100753, 34100753, 34100756, 34100771, 34100772, 34100772, 34100731, 34100733, 34100734, 34100735, 34100736, 34100736, 34100738, 34100740, 34100746, 34100747, 34100747, 34100748, 34100749, 34100749, 34100750, 34100751, 34100751, 34100754, 34100754, 34100757, 34100772, 34100772, 34100773, 34100732, 34100736, 34100736, 34100746, 34100747, 34100749, 34100749, 34100753, 34100769, 34100773, 34100732, 34100733, 34100733, 34100736, 34100737, 34100737, 34100740, 34100742, 34100743, 34100747, 34100748, 34100749, 34100750, 34100751, 34100757, 34100766, 34100772, 34100773, 34100774, 34100733, 34100734, 34100735, 34100735, 34100737, 34100748, 34100749, 34100750, 34100765, 34100772, 34100774, 34100734, 34100735, 34100737, 34100738, 34100747, 34100748, 34100749, 34100749, 34100749, 34100750, 34100751, 34100752, 34100754, 34100768, 34100774, 34100749, 34100750, 34100753, 34100775, 34100776, 34100750, 34100752, 34100755, 34100774, 34100740, 34100745, 34100747, 34100756, 34100747, 34100750, 34100752, 34100752, 34100754, 34100755, 34100760, 34100776, 34100777, 34100742, 34100745, 34100750, 34100752, 34100753, 34100754, 34100756, 34100757, 34100762, 34100774, 34100778, 34100779, 34100750, 34100757, 34100779, 34100752, 34100754, 34100756, 34100779, 34100754, 34100764, 34100756, 34100776, 34100748, 34100755, 34100757, 34100758, 34100760, 34100761, 34100755, 34100756, 34100758, 34100758, 34100770, 34100755, 34100756, 34100758, 34100760, 34100774, 34100782, 34100782, 34100756, 34100757, 34100758, 34100759, 34100760, 34100777, 34100782, 34100759, 34100760, 34100783, 34100757, 34100758, 34100760, 34100761, 34100767, 34100785, 34100760, 34100762, 34100763, 34100785, 34100763, 34100768, 34100761, 34100766, 34100770, 34100762, 34100762, 34100765, 34100766, 34100772, 34100788, 34100762, 34100764, 34100763, 34100764, 34100765, 34100765, 34100766, 34100766, 34100767, 34100767, 34100768, 34100768, 34100769, 34100769, 34100770, 34100770, 34100771, 34100772, 34100772, 34100773, 34100774, 34100775, 34100778, 34100780, 34100782, 34100786, 34100787, 34100788, 34100788, 34100789, 34100789, 34100765, 34100765, 34100766, 34100766, 34100768, 34100768, 34100769, 34100771, 34100771, 34100772, 34100773, 34100781, 34100781, 34100783, 34100789, 34100789, 34100765, 34100766, 34100767, 34100770, 34100772, 34100772, 34100773, 34100774, 34100781, 34100790, 34100767, 34100768, 34100769, 34100769, 34100770, 34100770, 34100771, 34100771, 34100772, 34100774, 34100774, 34100775, 34100776, 34100778, 34100782, 34100783, 34100784, 34100790, 34100791, 34100768, 34100769, 34100769, 34100770, 34100770, 34100771, 34100771, 34100772, 34100773, 34100773, 34100775, 34100775, 34100786, 34100791, 34100791, 34100792, 34100770, 34100770, 34100771, 34100771, 34100772, 34100772, 34100773, 34100773, 34100774, 34100775, 34100775, 34100776, 34100777, 34100780, 34100781, 34100784, 34100789, 34100789, 34100790, 34100790, 34100791, 34100791, 34100792, 34100792, 34100774, 34100775, 34100776, 34100771, 34100772, 34100772, 34100773, 34100773, 34100774, 34100776, 34100778, 34100779, 34100782, 34100785, 34100790, 34100792, 34100793, 34100793, 34109434, 34100772, 34100773, 34100774, 34100777, 34100780, 34100780, 34100793, 34100773, 34100774, 34100777, 34100777, 34100778, 34100781, 34100784, 34100785, 34100790, 34100791, 34100793, 34100794, 34100774, 34100776, 34100777, 34100778, 34100778, 34100783, 34100789, 34100792, 34100793, 34100794, 34100795, 34109435, 34100775, 34100776, 34100778, 34100778, 34100780, 34100786, 34100787, 34100790, 34100792, 34100792, 34100794, 34100795, 34100795, 34100778, 34100779, 34100791, 34100793, 34100795, 34100796, 34100777, 34100778, 34100779, 34100784, 34100796, 34100778, 34100779, 34100780, 34100782, 34100782, 34100785, 34100787, 34100794, 34100796, 34100797, 34100782, 34100784, 34100784, 34100795, 34100796, 34100796, 34100797, 34100781, 34100783, 34100787, 34100788, 34100794, 34100795, 34100796, 34100797, 34100798, 34100783, 34100790, 34100793, 34100794, 34100795, 34100796, 34100797, 34100798, 34100798, 34100799, 34100799, 34100799, 34100799, 34100799, 34100785, 34100788, 34100797, 34100799, 34100800, 34100800, 34100800, 34100800, 34100793, 34100801, 34100794, 34100801, 34100801, 34100797, 34100802, 34100802, 34100793, 34100796, 34100803, 34100803, 34100804, 34100802, 34100803, 34100803, 34100804, 34100795, 34100805, 34100805, 34100805, 34100806, 34100798, 34100799, 34100803, 34100806, 34100804, 34100806, 34100806, 34100805, 34100807, 34100807, 34100804, 34100807, 34100808, 34100807, 34100808, 34100809, 34100809, 34100810, 34100810, 34100808, 34100810, 34100810, 34100812, 34100811, 34100811, 34100809, 34100811, 34100812, 34100812, 34100810, 34100812, 34100812, 34100813, 34109502, 34100811, 34100812, 34100812, 34100813, 34100813, 34100812, 34100813, 34100813, 34100813, 34100814, 34100814, 34100814, 34100815, 34109455, 34100815, 34100816, 34100816, 34100821, 34100836, 34100844, 34100845, 34100845, 34100846, 34100846, 34109456, 34109504, 34109504, 34109567, 34100816, 34100817, 34100818, 34100821, 34100823, 34100823, 34100826, 34100828, 34100828, 34100829, 34100829, 34100831, 34100833, 34100834, 34100835, 34100836, 34100842, 34100842, 34100844, 34100845, 34100845, 34100846, 34100846, 34100847, 34109456, 34109504, 34109505, 34100817, 34100818, 34100819, 34100819, 34100821, 34100823, 34100827, 34100829, 34100833, 34100834, 34100834, 34100837, 34100838, 34100842, 34100844, 34100844, 34100845, 34100845, 34100846, 34100846, 34100847, 34100847, 34100818, 34100822, 34100824, 34100826, 34100846, 34100847, 34100847, 34100848, 34100848, 34100848, 34100820, 34100846, 34100847, 34100847, 34100848, 34100848, 34100849, 34100836, 34100839, 34100847, 34100849, 34100845, 34100848, 34100849, 34100833, 34100838, 34100851, 34100851, 34100852, 34100840, 34100851, 34100830, 34100854, 34100852, 34100854, 34100856, 34100851, 34100856, 34100857, 34100858, 34100858, 34100858, 34100859, 34100860, 34100859, 34100862, 34100861, 34100863, 34100863, 34100863, 34100864, 34100864, 34100862, 34100863, 34100863, 34100864, 34100865, 34100865, 34100856, 34100857, 34100867, 34100867, 34100867, 34100867, 34100868, 34100868, 34100872, 34100871, 34100872, 34100873, 34100874, 34100873, 34100873, 34100874, 34100875, 34100875, 34100874, 34100875, 34100876, 34100875, 34100876, 34100876, 34100876, 34100877, 34109486, 34100877, 34109487, 34100878, 34100879, 34109456, 34109487, 34109487, 34109535, 41732601, 34109488, 34109536, 34109488, 34118065, 34118096, 34118097, 34118098, 34118099, 34118099, 34118100, 34118100, 34118101, 34118102, 34118104, 34118104, 34118106, 34118107, 34118107, 34118108, 34118111, 34118119, 34118119, 34118121, 34118124, 34118126, 34118127, 34118136, 34118137, 34118139, 34118140, 34118141, 34118142, 34118142, 34118143, 34118144, 34118144, 34118145, 34118145, 34118146, 34118146, 34118147, 34118098, 34118099, 34118099, 34118100, 34118100, 34118101, 34118104, 34118111, 34118119, 34118137, 34118137, 34118138, 34118142, 34118144, 34118145, 34118145, 34118146, 34118146, 34118100, 34118100, 34118119, 34118145, 34118145, 34118146, 34118100, 34118146, 34118101, 34118102, 34118102, 34118110, 34118113, 34118127, 34118130, 34118132, 34118138, 34118139, 34118139, 34118144, 34118146, 34118146, 34118147, 34118147, 34118148, 34118102, 34118103, 34118113, 34118131, 34118140, 34118144, 34118144, 34118145, 34118146, 34118146, 34118147, 34118147, 34118103, 34118144, 34118147, 34118147, 34118148, 34118148, 34118149, 34118150, 34118151, 34118152, 34118152, 34118154, 34118118, 34118156, 34118156, 34118157, 34118220, 34118155, 34118158, 34118158, 34118158, 34118159, 34118159, 34118166, 34118166, 34118166, 34118167, 34118167, 34118168, 34118169, 34118172, 34118173, 34118174, 34118174, 34118175, 34118174, 34118178, 34118183, 34118183, 34118184, 34118184, 34118183, 34118184, 34118184, 34118185, 34118187, 34118188, 34118186, 34118189, 34118189, 34118189, 34118190, 34118189, 34118189, 34118190, 34118190, 34118190, 34118191, 34118191, 34118192, 34118192, 34118192, 34118193, 34118198, 34118193, 34118194, 34118194, 34118195, 34118195, 34118196, 34118196, 34118197, 34118199, 34118200, 34118205, 34118208, 34118210, 34118194, 34118195, 34118195, 34118196, 34118196, 34118197, 34118197, 34118198, 34118198, 34118199, 34118199, 34118200, 34118201, 34118201, 34118203, 34118204, 34118206, 34118207, 34118214, 34118215, 34118216, 34118216, 34118217, 34118220, 34118221, 34118195, 34118196, 34118196, 34118197, 34118197, 34118198, 34118198, 34118199, 34118199, 34118200, 34118200, 34118201, 34118201, 34118202, 34118202, 34118203, 34118203, 34118204, 34118204, 34118210, 34118219, 34118221, 34118221, 34118196, 34118197, 34118197, 34118198, 34118198, 34118199, 34118199, 34118200, 34118201, 34118204, 34118217, 34118218, 34118220, 34118222, 34118197, 34118198, 34118198, 34118199, 34118199, 34118200, 34118200, 34118201, 34118201, 34118202, 34118203, 34118204, 34118204, 34118206, 34118207, 34118210, 34118212, 34118213, 34118216, 34118219, 34118222, 34118198, 34118199, 34118199, 34118200, 34118200, 34118201, 34118201, 34118202, 34118202, 34118203, 34118203, 34118204, 34118204, 34118205, 34118205, 34118212, 34118214, 34118215, 34118216, 34118218, 34118218, 34118219, 34118223, 34118199, 34118200, 34118200, 34118201, 34118201, 34118202, 34118202, 34118203, 34118203, 34118205, 34118206, 34118206, 34118208, 34118208, 34118210, 34118212, 34118217, 34118219, 34118223, 34118200, 34118201, 34118201, 34118202, 34118202, 34118203, 34118203, 34118204, 34118205, 34118206, 34118206, 34118207, 34118209, 34118212, 34118213, 34118215, 34118218, 34118219, 34118219, 34118221, 34118223, 34118223, 34118224, 34118201, 34118202, 34118202, 34118203, 34118203, 34118204, 34118204, 34118205, 34118205, 34118206, 34118206, 34118207, 34118207, 34118209, 34118218, 34118218, 34118219, 34118220, 34118222, 34118223, 34118224, 34118224, 34118202, 34118203, 34118203, 34118204, 34118204, 34118205, 34118205, 34118206, 34118206, 34118207, 34118207, 34118208, 34118210, 34118214, 34118216, 34118217, 34118218, 34118219, 34118219, 34118220, 34118220, 34118221, 34118221, 34118222, 34118222, 34118223, 34118224, 34118225, 34118203, 34118204, 34118204, 34118205, 34118205, 34118206, 34118206, 34118207, 34118207, 34118208, 34118208, 34118210, 34118213, 34118214, 34118215, 34118215, 34118216, 34118216, 34118217, 34118219, 34118219, 34118220, 34118221, 34118222, 34118223, 34118225, 34118225, 34118204, 34118205, 34118205, 34118206, 34118206, 34118207, 34118207, 34118208, 34118208, 34118209, 34118210, 34118211, 34118215, 34118218, 34118219, 34118220, 34118220, 34118221, 34118221, 34118222, 34118223, 34118224, 34118225, 34118226, 34118205, 34118206, 34118206, 34118207, 34118207, 34118208, 34118208, 34118209, 34118209, 34118211, 34118214, 34118217, 34118218, 34118220, 34118220, 34118221, 34118222, 34118223, 34118224, 34118226, 34118206, 34118207, 34118207, 34118208, 34118208, 34118209, 34118209, 34118210, 34118212, 34118213, 34118216, 34118218, 34118219, 34118220, 34118220, 34118221, 34118222, 34118222, 34118223, 34118224, 34118226, 34118227, 34118207, 34118208, 34118208, 34118209, 34118209, 34118210, 34118210, 34118212, 34118213, 34118215, 34118216, 34118217, 34118220, 34118221, 34118221, 34118222, 34118223, 34118225, 34118225, 34118226, 34118227, 34118227, 34118208, 34118209, 34118209, 34118210, 34118210, 34118211, 34118212, 34118213, 34118215, 34118217, 34118218, 34118219, 34118219, 34118221, 34118222, 34118223, 34118223, 34118224, 34118225, 34118209, 34118210, 34118210, 34118211, 34118211, 34118213, 34118213, 34118216, 34118220, 34118221, 34118221, 34118222, 34118222, 34118223, 34118224, 34118225, 34118226, 34118228, 34118210, 34118211, 34118211, 34118213, 34118218, 34118219, 34118220, 34118222, 34118223, 34118223, 34118224, 34118224, 34118225, 34118229, 34118211, 34118212, 34118212, 34118214, 34118214, 34118215, 34118216, 34118217, 34118218, 34118220, 34118221, 34118221, 34118223, 34118223, 34118224, 34118224, 34118225, 34118225, 34118226, 34118227, 34118229, 34118212, 34118213, 34118213, 34118214, 34118214, 34118215, 34118216, 34118216, 34118218, 34118221, 34118221, 34118222, 34118223, 34118224, 34118225, 34118225, 34118226, 34118227, 34118230, 34118213, 34118215, 34118215, 34118219, 34118219, 34118220, 34118220, 34118221, 34118222, 34118224, 34118225, 34118225, 34118226, 34118227, 34118230, 34118215, 34118215, 34118216, 34118216, 34118218, 34118219, 34118220, 34118220, 34118221, 34118222, 34118224, 34118225, 34118225, 34118226, 34118226, 34118227, 34118228, 34118229, 34118230, 34118231, 34118223, 34118225, 34118217, 34118225, 34118217, 34118218, 34118219, 34118221, 34118224, 34118226, 34118226, 34118227, 34118229, 34118230, 34118231, 34118219, 34118220, 34118221, 34118221, 34118224, 34118224, 34118225, 34118226, 34118228, 34118228, 34118229, 34118229, 34118230, 34118233, 34118227, 34118227, 34118221, 34118226, 34118227, 34118228, 34118228, 34118229, 34118229, 34118234, 34118229, 34118230, 34118223, 34118225, 34118230, 34118230, 34118233, 34118223, 34118224, 34118226, 34118228, 34118229, 34118230, 34118231, 34118235, 34118225, 34118227, 34118230, 34118231, 34118231, 34118232, 34118233, 34118235, 34118225, 34118230, 34118231, 34118232, 34118226, 34118227, 34118228, 34118230, 34118232, 34118232, 34118233, 34118234, 34118234, 34118235, 34118235, 34118229, 34118231, 34118231, 34118233, 34118235, 34118230, 34118231, 34118232, 34118233, 34118235, 34118238, 34485867, 34118232, 34118234, 34118238, 34118231, 34118232, 34118233, 34118234, 34118234, 34118235, 34118239, 34118233, 34118233, 34118234, 34118235, 34118235, 34118236, 34118236, 34118237, 34118238, 34118239, 34118239, 34118233, 34118234, 34118235, 34118236, 34118240, 34118234, 34118234, 34118235, 34118237, 34118238, 34118234, 34118236, 34118235, 34118236, 34118237, 34118238, 34118238, 34118239, 34118239, 34118241, 34118241, 34664747, 34118236, 34118237, 34118237, 34118238, 34118239, 34118240, 34118240, 34118241, 34118242, 37635291, 34118237, 34118238, 34118240, 34118240, 34118242, 34118242, 34118238, 34118239, 34118240, 34118241, 34118241, 34118242, 34118242, 34118243, 34118239, 34118240, 34118240, 34118241, 34118241, 34118242, 34118242, 34118243, 34118243, 34118240, 34118241, 34118243, 34118244, 34118242, 34118242, 34118243, 34118244, 34118244, 34118242, 34118243, 34118243, 34118244, 34118245, 34118243, 34118244, 34118244, 34118245, 34118245, 34118244, 34118245, 34118245, 34118246, 34118245, 34118246, 34118246, 34118246, 34118247, 34118247, 34118248, 34118249, 34118249, 34118250, 34118250, 34118251, 34118252, 34118252, 34118253, 34118253, 34118254, 34118254, 34118255, 34118255, 34118257, 34118257, 34118258, 34118259, 34118259, 34118261, 34118262, 34118262, 34118263, 34118264, 34118264, 34118265, 34118266, 34118266, 34118267, 34118268, 34118269, 34118281, 34118281, 34118282, 34118283, 34118284, 34118285, 34118286, 34118287, 34118287, 34118292, 34118294, 34118294, 34118295, 34118295, 34118296, 34118296, 34664753, 34664753, 35105875, 41741286, 34118249, 34118250, 34118250, 34118251, 34118251, 34118252, 34118253, 34118254, 34118254, 34118255, 34118255, 34118256, 34118257, 34118257, 34118258, 34118262, 34118263, 34118264, 34118264, 34118265, 34118265, 34118266, 34118266, 34118268, 34118268, 34118269, 34118269, 34118277, 34118279, 34118281, 34118284, 34118288, 34118292, 34118294, 34118295, 34118295, 34118296, 34118296, 34118297, 34118250, 34118251, 34118251, 34118252, 34118253, 34118254, 34118256, 34118295, 34118251, 34118252, 34118253, 34118256, 34118264, 34118269, 34118271, 34118282, 34118297, 34118298, 34118252, 34118253, 34118253, 34118254, 34118254, 34118255, 34118255, 34118256, 34118256, 34118257, 34118257, 34118259, 34118260, 34118265, 34118266, 34118268, 34118270, 34118270, 34118271, 34118280, 34118282, 34118283, 34118285, 34118290, 34118291, 34118292, 34118294, 34118295, 34118296, 34118296, 34118297, 34118297, 34118298, 34118298, 34664755, 34664756, 34118253, 34118255, 34118256, 34118257, 34118258, 34118261, 34118265, 34118265, 34118268, 34118270, 34118271, 34118271, 34118274, 34118284, 34118296, 34118296, 34118297, 34118298, 34118299, 34118255, 34118256, 34118256, 34118257, 34118257, 34118258, 34118260, 34118261, 34118262, 34118263, 34118264, 34118265, 34118267, 34118268, 34118269, 34118269, 34118270, 34118270, 34118271, 34118272, 34118274, 34118275, 34118281, 34118286, 34118287, 34118288, 34118296, 34118297, 34118298, 34118298, 34118299, 34176273, 34118271, 34118257, 34118258, 34118258, 34118263, 34118269, 34118272, 34118274, 34118284, 34118290, 34118298, 34118300, 34118269, 34118271, 34118272, 34118298, 34118301, 34118258, 34118259, 34118259, 34118260, 34118260, 34118261, 34118262, 34118262, 34118265, 34118267, 34118268, 34118271, 34118272, 34118274, 34118274, 34118281, 34118285, 34118294, 34118299, 34118299, 34118300, 34118300, 34118301, 34664759, 41691752, 34118259, 34118260, 34118261, 34118262, 34118264, 34118265, 34118267, 34118269, 34118270, 34118271, 34118273, 34118274, 34118285, 34118287, 34118298, 34118298, 34118300, 34118301, 34118302, 34664655, 34118261, 34118261, 34118262, 34118263, 34118264, 34118265, 34118266, 34118267, 34118269, 34118270, 34118271, 34118271, 34118272, 34118273, 34118273, 34118274, 34118275, 34118281, 34118286, 34118293, 34118300, 34118301, 34118302, 34664759, 34664759, 34118263, 34118264, 34118267, 34118271, 34118274, 34118290, 34118298, 34118303, 34118265, 34118266, 34118268, 34118271, 34118273, 34118273, 34118274, 34118275, 34118301, 34118302, 34118303, 34118303, 34118263, 34118264, 34118272, 34118275, 34118276, 34118301, 34118303, 34118304, 34118266, 34118273, 34118275, 34118302, 34118266, 34118274, 34118302, 34118303, 34118305, 34118271, 34118275, 34118276, 34118277, 34118278, 34118281, 34118292, 34118302, 34118303, 34118303, 34118304, 34118304, 34118304, 34118305, 34118306, 34118268, 34118272, 34118275, 34118271, 34118275, 34118276, 34118276, 34118306, 34118307, 34118278, 34118279, 34118303, 34118306, 34118307, 34118273, 34118278, 34189220, 34118276, 34118285, 34118301, 34118277, 34118277, 34118277, 34118280, 34118284, 34118309, 34118278, 34118279, 34118279, 34118310, 34118276, 34118294, 34118309, 34118278, 34118282, 34118283, 34118299, 34118309, 34118311, 34118280, 34118290, 34118308, 34118311, 34118280, 34118280, 34118281, 34118283, 34664769, 34118287, 34118309, 34118312, 34118281, 34118282, 34118282, 34118285, 34118285, 34118297, 34118309, 34118311, 34118312, 34118313, 34118282, 34118283, 34118284, 34118295, 34118298, 34118302, 34118311, 34118312, 34664770, 34118283, 34118285, 34118286, 34118286, 34118292, 34118298, 34118312, 34118285, 34118285, 34118286, 34118286, 34118287, 34118302, 34118305, 34118309, 34118313, 34118313, 34118314, 34664770, 34118286, 34118287, 34118287, 34118288, 34118290, 34118313, 34118315, 34118286, 34118288, 34118311, 34118313, 34118315, 34118287, 34118288, 34118288, 34118291, 34118292, 34118298, 34118300, 34118301, 34118308, 34118309, 34118310, 34118313, 34118313, 34118314, 34118314, 34118315, 34118316, 34118289, 34118294, 34118296, 34118315, 34118315, 34118316, 34118289, 34118290, 34118291, 34118296, 34118301, 34118302, 34118302, 34118303, 34118307, 34118313, 34118314, 34118314, 34118315, 34118315, 34118316, 34118316, 34118317, 34118291, 34118293, 34118298, 34118304, 34118305, 34118311, 34118312, 34118313, 34118314, 34118315, 34118315, 34118316, 34118316, 34118317, 34118317, 34118305, 34118316, 34118317, 34118318, 34118292, 34118302, 34118317, 34118315, 34118318, 34118319, 34118316, 34118317, 34118320, 34118319, 34118320, 34118319, 34118321, 34118322, 34118321, 34118304, 34118320, 34118323, 34118322, 34118324, 34118324, 34118313, 34118325, 34118321, 34118320, 34118325, 34118325, 34118327, 34118323, 34118326, 34118316, 34118319, 34118322, 34118326, 34118326, 34118327, 34118328, 34118329, 34118326, 34118329, 34118328, 34118328, 34118329, 34118330, 34118321, 34118327, 34118327, 34118321, 34118330, 34118331, 34118332, 34118330, 34118331, 34118325, 34118330, 34118332, 34118333, 34118322, 34118331, 34118333, 34118323, 34118324, 34118334, 34118324, 34118334, 34118333, 34118335, 34118333, 34118334, 34118334, 34118335, 34118335, 34118336, 34118336, 34118334, 34118335, 34118335, 34118336, 34118336, 34118338, 34118334, 34118335, 34118337, 34118338, 34118336, 34118339, 34118338, 34118339, 34118340, 34118338, 34118339, 34118340, 34118338, 34118339, 34118340, 34118341, 34118339, 34118339, 34118340, 34118341, 34118339, 34118340, 34118340, 34118341, 34118342, 34118340, 34118341, 34118341, 34118342, 34118341, 34118342, 34118343, 34118342, 34118343, 34118343, 34118343, 34118344, 34118344, 34118345, 34118346, 34119686, 34138067, 34165832, 34165834, 34172405, 34176318, 34189256, 34189257, 34189257, 34189258, 34189260, 34189260, 34189261, 34189261, 34189262, 34189265, 34189266, 34189268, 34189269, 34269984, 34284390, 34293710, 34302562, 34302562, 34424044, 34424044, 34424045, 34424046, 34449998, 34485917, 34485917, 34485919, 34523168, 34631052, 34631187, 34664699, 34664700, 34664700, 34664707, 34664712, 34664713, 34664714, 34664798, 34664799, 34664799, 34664800, 34664800, 34664801, 34664801, 34664802, 34664802, 34664803, 34664808, 34687987, 34851745, 35008984, 35105922, 35105922, 35105923, 35126829, 35566328, 35566329, 35566329, 35566331, 35566331, 35984894, 36008077, 37338135, 37338136, 37629970, 37632230, 37632231, 37632231, 37632232, 37635345, 37635347, 37786900, 38195784, 38639617, 39122452, 39321443, 39399254, 40263730, 41741335, 34189257, 34189258, 34664714, 34664799, 34664801, 34664801, 34664802, 34664802, 34664803, 34664803, 35105924, 38195782, 41741335, 34189258, 34631188, 34664800, 34664801, 34664802, 34664802, 34664803, 34664803, 34664804, 41691796, 34121084, 34666196, 34157802, 41761070, 34213341, 34213343, 34236766, 35153432, 34226476, 34718874, 34234304, 34234307, 34722787, 34722789, 34260183, 34260183, 34260184, 34260186, 34260169, 34260184, 34260186, 34260186, 34260187, 34260187, 34260189, 34260192, 34260193, 34260195, 34260182, 34260183, 34260184, 34260184, 34260185, 34260185, 34260186, 34260187, 34260188, 34260190, 34260186, 34260191, 34260199, 34260200, 34260200, 34260199, 34260201, 34260203, 34260205, 34260207, 34260209, 34735726, 34735728, 34735727, 34735728, 34260199, 34494971, 34735728, 34735641, 34735726, 34735728, 34735729, 34735730, 34735727, 34735729, 34735730, 34494973, 34735730, 34494974, 34594099, 34735729, 34735731, 34735731, 34735729, 34735732, 34735732, 34735733, 34702121, 34735633, 34735735, 34735737, 34735738, 34700324, 34735739, 34702126, 34735740, 34735741, 34735741, 34735741, 34735741, 34421635, 34816452, 34450447, 34830859, 34469085, 34599420, 34486794, 34486795, 34849033, 34849034, 34729758, 34729758, 34729757, 34729758, 34729758, 34729759, 34729758, 34729759, 34729759, 34729761, 34729759, 34729762, 34970514, 34970515, 34970427, 34970512, 34970513, 34970514, 34970516, 38945331, 34970428, 34970515, 34970428, 34970513, 34970514, 34970515, 34970515, 34970516, 34970517, 34970517, 34970518, 34781724, 34996527, 34853506, 34853507, 34853514, 34853518, 35032389, 35032304, 35032306, 35032308, 34928003, 34928004, 34928007, 35069637, 35069637, 35069549, 35069638, 35140440, 35175854, 35143770, 35143905, 35144040, 35144042, 35144042, 35144043, 35144044, 35177654, 35177656, 35177656, 35177657, 35618778, 38145087, 35211065, 35211062, 35211064, 35211066, 35211066, 35211081, 35211165, 35211163, 35211168, 35211167, 35211169, 35211081, 35211092, 35211091, 35211092, 35211093, 35211093, 35211095, 35211176, 35211101, 35211102, 35211177, 35211178, 35211178, 35211179, 35211180, 35211180, 35211180, 35211181, 35211181, 35211184, 35211183, 35211254, 35211254, 35211255, 35211272, 35211254, 35211254, 35211255, 35211255, 35211256, 35211270, 35211271, 35211274, 35211255, 35211256, 35211257, 35211255, 35211256, 35211256, 35211257, 35211258, 35211257, 35211257, 35211258, 35211258, 35211271, 35211272, 35211272, 35211273, 35211274, 35211277, 35211257, 35211258, 35211258, 35211259, 35211274, 35211274, 35211258, 35211259, 35211259, 35211264, 35211272, 35211273, 35211273, 35211274, 35211274, 35211275, 35211275, 35211276, 35211259, 35211260, 35211261, 35211261, 35211262, 35211270, 35211272, 35211272, 35211273, 35211273, 35211274, 35211274, 35211275, 35211275, 35211276, 35211276, 35211277, 35211278, 35211278, 35211279, 35211281, 35211260, 35211261, 35211261, 35211262, 35211263, 35211264, 35211264, 35211269, 35211271, 35211271, 35211272, 35211272, 35211273, 35211273, 35211274, 35211274, 35211275, 35211275, 35211276, 35211276, 35211277, 35211277, 35211278, 35211278, 35211279, 35211281, 35211261, 35211262, 35211262, 35211263, 35211264, 35211265, 35211266, 35211266, 35211267, 35211268, 35211268, 35211269, 35211271, 35211271, 35211272, 35211272, 35211273, 35211273, 35211274, 35211274, 35211275, 35211275, 35211276, 35211276, 35211277, 35211278, 35211279, 35211263, 35211269, 35211273, 35211274, 35211274, 35211275, 35211275, 35211276, 35211277, 35211278, 35211269, 35211273, 35211274, 35211274, 35211275, 35211276, 35211276, 35211277, 35211273, 35211276, 35211278, 35211279, 35211275, 35211276, 35211277, 35211277, 35211281, 35211279, 35211277, 35211280, 35211270, 35211277, 35211279, 35211279, 35211280, 35211289, 35211281, 35211281, 35211282, 35211277, 35211284, 35211276, 35211283, 35211281, 35211282, 35211282, 35211282, 35211284, 35211283, 35211286, 35211287, 35211283, 35211285, 35211286, 35211283, 35211284, 35211285, 35211285, 35211286, 35211285, 35211286, 35211287, 35211287, 35211288, 35211288, 35211285, 35211286, 35211287, 35211287, 35211288, 35211288, 35211289, 35211286, 35211287, 35211287, 35211288, 35211288, 35211289, 35211289, 35211290, 35211290, 35211291, 35211291, 41411108, 35211287, 35211288, 35211288, 35211289, 35211289, 35211290, 35211293, 35652394, 36112800, 35211288, 35211289, 35211289, 35211290, 35211290, 35211291, 35211291, 35211292, 35398217, 35652394, 36112804, 36515381, 38178703, 38181818, 35211289, 35211290, 35211290, 35211291, 35211291, 35211292, 35211293, 35211295, 35211296, 35211299, 35652395, 36112801, 36112802, 38176442, 38178701, 38178702, 38178703, 38178703, 38181818, 42287807, 35211290, 35211291, 35211291, 35211292, 35211292, 35211293, 35211295, 35211295, 35211296, 35652395, 35652396, 36027279, 36112801, 37772662, 38176443, 38178704, 38181819, 38181820, 38742254, 35211291, 35211292, 35211292, 35211293, 35211293, 35211294, 35211294, 35211295, 35211295, 35211296, 35211297, 35211298, 35211299, 35211302, 35302294, 35555457, 35652395, 35652396, 35652396, 35749421, 36062406, 36112802, 36112803, 36112804, 36112804, 37061950, 37884607, 37884611, 38176444, 38176444, 38178702, 38178703, 38178704, 38178707, 38181818, 38181819, 38181820, 38181820, 38742254, 39668926, 42287808, 35211292, 35211293, 35211293, 35211294, 35211294, 35211295, 35211296, 35211298, 35211299, 35211300, 35211302, 35349877, 35517238, 35652397, 35673304, 36112804, 36112806, 36112808, 36199222, 36911522, 37089775, 37841476, 38176444, 38178702, 38178703, 38178703, 38178704, 38178704, 38178705, 38181820, 38181821, 38994577, 39186091, 39668926, 40810203, 41411109, 35211293, 35211294, 35211294, 35211295, 35211295, 35211296, 35211296, 35211297, 35211297, 35211298, 35211298, 35211299, 35211299, 35492869, 35652395, 35652396, 35652397, 35652397, 35658989, 35673307, 35744879, 35844579, 36112803, 36112804, 36112804, 36112805, 36112806, 36112807, 36199224, 36334910, 37089776, 37101804, 37604644, 37772664, 37884607, 37884608, 37884609, 37884610, 37884612, 38176442, 38176443, 38176444, 38176444, 38176445, 38178704, 38178704, 38178705, 38178705, 38178706, 38178708, 38178708, 38181820, 38181821, 38333935, 38742255, 38742256, 39085737, 39095432, 39186091, 39438944, 39668927, 39867917, 40812441, 41411109, 42287809, 35211294, 35211295, 35211295, 35211296, 35211296, 35211297, 35211297, 35211298, 35211300, 35398219, 35555459, 35652397, 35652398, 35652398, 35652404, 35673304, 36002964, 36027277, 36112803, 36112805, 36112806, 36501739, 37884610, 37884612, 38176445, 38176445, 38176446, 38178703, 38178705, 40810204, 41928622, 35211295, 35211296, 35211296, 35211297, 35211297, 35211298, 35211300, 35211301, 35652396, 35652397, 35652398, 35652398, 36112799, 36112804, 36112805, 36112809, 36199223, 36531369, 36911524, 37608220, 37884616, 38176444, 38176445, 38176446, 38178705, 38178706, 38181822, 38742257, 40810205, 41411112, 41411112, 35211296, 35211297, 35211297, 35211298, 35211298, 35211299, 35211299, 35211300, 35211302, 35211303, 35211304, 35652398, 35652398, 35652399, 35733170, 35749424, 36112804, 36112805, 37604645, 37772665, 37828989, 37884611, 38176445, 38176446, 38176447, 38178704, 38178704, 38178706, 38178707, 38178707, 38178708, 38178708, 35211297, 35211298, 35211298, 35211299, 35211299, 35211300, 35211300, 35211301, 35211301, 35211302, 35507107, 35652320, 35652398, 35652399, 35749424, 36062409, 36112804, 36112807, 36112810, 36515385, 37089778, 37772666, 38176444, 38176445, 38176447, 38178706, 38178707, 38178707, 38178708, 38178708, 38181823, 39065909, 41411114, 35211298, 35211299, 35211299, 35211300, 35211300, 35211302, 35211303, 35349879, 35398225, 35555461, 35652399, 35652399, 35652400, 35673306, 36112804, 36112807, 36112809, 37280406, 37772666, 37884613, 37884613, 38176446, 38176448, 38178707, 38181824, 35211299, 35211300, 35211300, 35211301, 35211301, 35211302, 35211302, 35211303, 35652399, 35652400, 35652400, 36112806, 36112807, 36112807, 36199225, 37884611, 38176449, 38178706, 38178707, 39668930, 35211300, 35211301, 35211301, 35211302, 35211303, 35211304, 35268555, 35652407, 35673310, 36112807, 36112808, 37089779, 37772667, 37884613, 38176448, 38176449, 38178708, 38178709, 35211302, 35211303, 35652322, 35652401, 35652401, 35749426, 36112808, 36112809, 36112809, 36199226, 36515387, 36531372, 36769669, 38176448, 38176449, 38178710, 38181825, 38333358, 39353334, 35398224, 35652402, 36112808, 36112809, 36199229, 37884614, 38178709, 38181826, 39095437, 35211303, 35211304, 35211305, 35652401, 35652402, 35652402, 35652403, 36112809, 37884615, 38176449, 38176449, 38178709, 38454140, 39095437, 35211305, 35652401, 36112808, 37844057, 37884614, 38066263, 38176449, 38178710, 35211305, 35652402, 35652403, 36112808, 36112809, 36112810, 36112810, 36112811, 36112812, 36824199, 36911629, 35211307, 35349883, 35398225, 35652403, 35652403, 35652404, 35669164, 36112810, 36112811, 36112813, 36334916, 36554551, 37884615, 38176452, 38178710, 38178711, 35302301, 35555467, 35652404, 35652405, 35673310, 35673312, 36112812, 36419230, 37884616, 38178712, 38178712, 38178713, 38178714, 38178715, 40810211, 35652405, 36112813, 36112814, 37884620, 38178714, 35257663, 36136008, 35325822, 36170074, 35393306, 35393309, 35743409, 38269720, 35488474, 35488477, 35488475, 35790993, 36557821, 38317305, 35585157, 35585158, 35585158, 35585159, 35585162, 35585165, 35989818, 36949170, 38365642, 36743449, 35860074, 36299750, 35774462, 38166203, 35802988, 35803097, 35803212, 36408801, 35823194, 36418759, 35899636, 35899636, 35899637, 35899639, 39086433, 35996575, 36466339, 39086433, 36456977, 35996576, 36093353, 36093354, 36093434, 36093429, 36093499, 36093515, 36093518, 36093500, 36093514, 36093500, 36093501, 36093515, 36093515, 36093516, 36093516, 36093517, 36093517, 36093518, 36093518, 36093519, 36093502, 36093516, 36093516, 36093517, 36093518, 36093520, 36093520, 36093504, 36093512, 36093516, 36093516, 36093517, 36093517, 36093518, 36093518, 36093519, 36093519, 36093520, 36093520, 36093521, 36093521, 36093522, 36093522, 36093525, 36093519, 36093521, 36093516, 36093518, 36093520, 36093539, 36093540, 36093527, 36553921, 38325727, 36093531, 36093532, 38617564, 38619824, 40386847, 36093532, 36093532, 36553923, 36553925, 36995660, 38325728, 38619823, 36093532, 36093533, 36093534, 36093536, 36093537, 36093548, 36553922, 36553923, 36553923, 37071465, 37369544, 37883545, 38325727, 38325728, 38619824, 38619825, 38619828, 38622941, 39536552, 39627211, 41251323, 41852230, 36093533, 36114424, 36553923, 36553925, 36553926, 37640315, 37895549, 38213784, 38325727, 38325730, 38617564, 38617564, 38619824, 38622941, 38622941, 39627211, 39880066, 42679389, 36093549, 36190543, 36242576, 36396111, 36553923, 36553924, 36553928, 36661417, 38325735, 38617565, 38617565, 38617566, 38619825, 38619826, 36093539, 36553925, 38213785, 38617564, 36093536, 36190544, 36775970, 36776031, 38325731, 38617566, 38619825, 38619826, 38617563, 38619827, 38619827, 42728931, 36114428, 36553925, 38619826, 36108340, 36553928, 38617567, 38619827, 36114428, 36553930, 38325734, 38617565, 38617568, 38619827, 36553931, 38619827, 36093553, 40309042, 38325734, 38325735, 38619832, 36154354, 36553940, 36553941, 38619840, 36106707, 36560522, 36123152, 36568738, 36127034, 36570680, 36134986, 36796764, 36135329, 36135329, 36135329, 36135330, 36135330, 36135331, 36135332, 36135332, 36135333, 36370524, 36574832, 38638470, 36306719, 36574829, 36574830, 36574831, 38346634, 38346635, 38638470, 38640730, 36215161, 36614747, 36255058, 38406499, 36278495, 36646422, 36287564, 36287566, 36382832, 38714585, 38714586, 38714586, 38716846, 36408727, 36391629, 36702979, 36394477, 38768040, 36477875, 36477991, 36478102, 36478105, 36478107, 36746219, 38518019, 38809855, 36529897, 36529972, 36530040, 38543991, 36605716, 36605800, 36605885, 38873747, 36698722, 36856537, 36794648, 36904487, 36843273, 36843279, 37727522, 38994704, 36913534, 36963932, 39027571, 37014309, 37014319, 37014329, 37014313, 37014313, 37014316, 37014329, 37014314, 37014316, 37014316, 37014318, 37014328, 37014329, 37014329, 37014330, 37014330, 37014331, 37014332, 37014334, 37014315, 37014317, 37014317, 37014323, 37014329, 37014329, 37014330, 37014331, 37014316, 37014317, 37014318, 37014319, 37014321, 37014330, 37014330, 37014331, 37014316, 37014317, 37014318, 37014319, 37014320, 37014331, 37014331, 37014331, 37014332, 37014332, 37014319, 37014332, 37014333, 37014333, 37014332, 37014334, 37014321, 37014332, 37014333, 37014333, 37014334, 37014334, 37014336, 37014332, 37014334, 37014334, 37014336, 37014336, 37014335, 37014337, 37014335, 37014335, 37014338, 37014340, 37014337, 37014340, 39017064, 37014344, 37014348, 39077970, 39080230, 37014346, 39080229, 39643783, 41713967, 42312636, 37014347, 37014348, 37014349, 37100751, 37403263, 37432894, 37671192, 37991302, 39077969, 39077970, 39080233, 40087614, 42312638, 37014347, 37014349, 37100748, 37144145, 37236437, 37269628, 37432893, 37432895, 37456068, 37456070, 37724712, 37829952, 38472883, 38674191, 38786134, 38786135, 38786135, 38786136, 38786136, 38786137, 38786138, 39077969, 39077970, 39077971, 39077972, 39077972, 39080229, 39080230, 39080230, 39080231, 39080231, 39080232, 39080232, 39080233, 39080234, 39083348, 39235462, 39996959, 40087618, 40570454, 41711731, 41713968, 37014350, 37639416, 37671195, 38674191, 38786134, 38786136, 39077971, 39077972, 39080232, 40087618, 41711731, 37014350, 37559664, 39077972, 39080229, 39080233, 39643783, 39080232, 39080233, 37026825, 37262743, 37991305, 38372623, 38578915, 38674193, 38786138, 39077973, 39077974, 39080232, 39080232, 39080234, 39080234, 39080235, 40087620, 42312639, 39080235, 40769449, 37033045, 39089589, 37039352, 39095876, 37187165, 37187167, 37187168, 37187169, 38872557, 39164389, 39166648, 38872554, 39103488, 39164389, 39166649, 40855862, 37229310, 37510752, 37273964, 37585886, 37458419, 37947764, 37458544, 39008240, 39008243, 39008250, 39302338, 39302339, 39302341, 37511147, 39328637, 37524929, 38218943, 37627168, 37627168, 39386650, 39386651, 37792194, 37792195, 39175064, 39469161, 37819485, 37819486, 39309236, 39482806, 39482805, 37851454, 37851455, 37851456, 39498793, 39498793, 39204699, 39496533, 40415520, 42130292, 43607897, 37897804, 37897810, 37897811, 37897819, 37897824, 37897821, 39521968, 37897843, 39458811, 38052812, 39521977, 41211192, 38254812, 37901738, 43633037, 38049410, 38343365, 38104996, 39331469, 38207838, 39497025, 38264496, 39299271, 38313207, 38313291, 38313374, 39729763, 38328052, 38328053, 38328055, 39737091, 38737020, 40300645, 38435090, 39790609, 38437105, 38437108, 39791616, 40355170, 38611770, 38611773, 38611774, 39472911, 39876692, 39878952, 42512688, 38611978, 39584965, 38637333, 38672000, 38645569, 39601751, 39893589, 38706656, 39632297, 38912624, 40029377, 38912952, 40027282, 38968270, 38968271, 38968271, 39763103, 40054937, 40057199, 39763105, 40057198, 40057199, 40057200, 38992328, 42700728, 39145985, 39324338, 39187109, 40166617, 39349557, 40245598, 39502692, 40030321, 39673572, 40409850, 39697578, 40127759, 39730904, 41928736, 39931432, 40538780, 39998010, 39998011, 40277981, 40569811, 40005160, 40575645, 40143495, 40238773, 40334050, 40334051, 40445995, 40445996, 40446001, 40676930, 40737830, 40737831, 40740086, 40740087, 40740088, 40740090, 40740091, 40740092, 40743207, 41747478, 43373828, 40446695, 40794151, 40471675, 40806642, 40476823, 40699029, 40557938, 40557924, 40557938, 40557937, 40557938, 40557939, 40557939, 40557938, 40557939, 40557939, 40557940, 40557926, 40557940, 40557940, 40557941, 40557943, 40557928, 40557941, 40557941, 40557928, 40557929, 40557932, 40557940, 40557941, 40557942, 40557941, 40557941, 40557945, 40557941, 40557942, 40557943, 40557943, 40557944, 40557947, 40557948, 40557947, 40557949, 40557950, 40557950, 40852035, 40849775, 40557955, 40849774, 40849775, 40852035, 40852036, 43485772, 40849774, 40849775, 40852034, 40852035, 41415586, 42026661, 40849774, 40849776, 40849777, 40852034, 40852034, 40852036, 40852036, 40852037, 41007376, 41415589, 43483535, 44084442, 44961140, 40557959, 40557959, 40627691, 40849773, 40849774, 40849774, 40849775, 40849775, 40849776, 40849776, 40849777, 40849777, 40852034, 40852035, 40852036, 40852037, 40852037, 42541249, 44961141, 40849778, 40855155, 40849778, 40849779, 40849779, 40852037, 40852039, 41859425, 42112280, 40697436, 41485333, 40786175, 40786246, 40786310, 40786322, 40786402, 40966295, 40798997, 40972567, 40921235, 40921237, 41033681, 45142788, 41019810, 41019813, 41080712, 41082971, 41080714, 41082973, 41141593, 41141608, 41141593, 41141594, 41141594, 41141594, 41141595, 41141609, 41141594, 41141594, 41141595, 41141595, 41141608, 41141609, 41141609, 41141610, 41141594, 41141595, 41141595, 41141596, 41141596, 41141610, 41141595, 41141596, 41141596, 41141597, 41141608, 41141609, 41141610, 41141611, 41141596, 41141597, 41141597, 41141609, 41141610, 41141611, 41141611, 41141612, 41141597, 41141598, 41141607, 41141608, 41141609, 41141610, 41141611, 41141612, 41141612, 41141613, 41141598, 41141610, 41141611, 41141611, 41141612, 41141612, 41141613, 41141613, 41141599, 41141611, 41141613, 41141613, 41141614, 41141613, 41141622, 41141623, 41143868, 41141624, 41141625, 41141625, 41141626, 41143868, 41143870, 41141625, 41141626, 41141626, 41141626, 41143870, 41143874, 41147634, 41141626, 41141627, 41143869, 41143870, 41143871, 41141627, 41141628, 41141629, 41143869, 41143870, 41143870, 41143871, 41143871, 41143872, 41143872, 41143873, 41143874, 41143875, 41146986, 41146987, 41146988, 41707423, 41976043, 43409160, 43775371, 44376275, 45252976, 41141628, 41143869, 41143869, 41143870, 41143871, 41143871, 41143872, 41143872, 41143873, 41143873, 41143874, 41143875, 41146988, 41143870, 41143871, 41143872, 41143872, 41143873, 41143873, 41143874, 41143874, 41146989, 43777608, 41143875, 41146112, 41146112, 41146113, 41146130, 41146129, 41146112, 41146114, 41146114, 41146116, 41146125, 41146130, 41146131, 41146113, 41146114, 41146114, 41146115, 41146116, 41146116, 41146117, 41146129, 41146133, 41146114, 41146115, 41146115, 41146116, 41146116, 41146117, 41146127, 41146130, 41146131, 41146132, 41146115, 41146116, 41146117, 41146129, 41146130, 41146132, 41146133, 41146116, 41146117, 41146117, 41146118, 41146118, 41146119, 41146119, 41146120, 41146128, 41146129, 41146131, 41146131, 41146132, 41146132, 41146133, 41146133, 41146134, 41146117, 41146118, 41146118, 41146119, 41146120, 41146131, 41146132, 41146132, 41146133, 41146134, 41146135, 41146135, 41146118, 41146119, 41146119, 41146120, 41146120, 41146131, 41146131, 41146132, 41146132, 41146133, 41146133, 41146134, 41146134, 41146135, 41146135, 41146136, 41146119, 41146120, 41146121, 41146121, 41146129, 41146132, 41146132, 41146133, 41146133, 41146134, 41146134, 41146135, 41146135, 41146136, 41146136, 41146120, 41146121, 41146122, 41146122, 41146123, 41146130, 41146132, 41146133, 41146133, 41146134, 41146134, 41146135, 41146135, 41146136, 41146136, 41146137, 41146137, 41146122, 41146122, 41146123, 41146132, 41146133, 41146134, 41146134, 41146135, 41146135, 41146136, 41146137, 41146137, 41146138, 41146135, 41146135, 41146138, 41146123, 41146135, 41146135, 41146136, 41146136, 41146137, 41146138, 41146139, 41146124, 41146135, 41146135, 41146136, 41146136, 41146137, 41146139, 41146137, 41146138, 41146137, 45255232, 41146144, 41146144, 41146145, 41709681, 41146145, 42062857, 41146146, 41146147, 41146146, 41146146, 41146148, 41149246, 41146146, 41146147, 41146147, 41146148, 41146148, 41146149, 41146150, 41149248, 41709682, 43753182, 44378536, 44378538, 45255235, 41146147, 41146148, 41146148, 41146149, 41146149, 41146150, 41146150, 41146151, 41146151, 41149246, 41149247, 41149247, 41149248, 41149249, 41301362, 41709682, 41709683, 41709684, 42062859, 42153518, 42636354, 43524644, 43777631, 44378535, 41146148, 41146149, 41146149, 41146150, 41146150, 41146151, 41146151, 41149247, 41149248, 41149249, 41300781, 41300781, 41709683, 42636354, 42835345, 43777631, 43779868, 44378536, 44378537, 44378539, 45255236, 41146149, 41146150, 41146150, 41146151, 41146151, 41146152, 41149247, 41149247, 41149248, 41149249, 41300801, 41709684, 41951140, 42320756, 42636355, 43411421, 43777632, 44378537, 41146150, 41146151, 41146151, 41146152, 41146152, 41149249, 41149249, 41149250, 41149250, 41301363, 41709684, 42062861, 42835346, 43777632, 43779868, 43779869, 44378537, 44896049, 41146151, 41146152, 41146152, 41146153, 41149248, 41149248, 41149249, 41149249, 41149250, 41149251, 41300782, 41300783, 41300802, 41301471, 41709682, 41709684, 41709685, 42062861, 42153520, 42320758, 42320760, 42321794, 42406375, 42636356, 42636356, 42835346, 43777633, 43779869, 43779870, 43779871, 44378538, 44378539, 45205698, 45255238, 41146152, 41146153, 41146153, 41149251, 41300802, 41709685, 41709685, 43524646, 43777633, 43779870, 44378540, 41146153, 41146154, 41146154, 41149249, 41149249, 41149250, 41149250, 41149251, 41149251, 41149252, 41300797, 41300800, 41300804, 41301473, 41709685, 41709686, 41709688, 42062864, 42320760, 42835347, 43235518, 43524647, 43777633, 43777634, 43777636, 44378539, 44378541, 45255239, 41146154, 41149248, 41149249, 41149249, 41149250, 41149250, 41149251, 41149251, 41149252, 41149252, 41300801, 41709686, 41709686, 42153520, 42636357, 42636357, 42835348, 43411422, 43777634, 44378539, 44378540, 44378542, 45255239, 41146155, 41146156, 41149248, 41149250, 41149251, 41149251, 41149252, 41149252, 41163591, 41260506, 41300804, 41709686, 41709687, 41709688, 42153522, 42835348, 43777635, 43779871, 43779873, 43779874, 44378540, 44378545, 45255240, 41149252, 41709687, 41149253, 41152345, 41152346, 41152344, 41152347, 41152346, 41152347, 41152347, 41152357, 41152360, 41152361, 41152347, 41152347, 41152348, 41152348, 41152359, 41152361, 41152362, 41152362, 41152363, 41152363, 41152347, 41152348, 41152362, 41152362, 41152363, 41152348, 41152349, 41152349, 41152350, 41152360, 41152363, 41152363, 41152364, 41152364, 41152349, 41152350, 41152360, 41152363, 41152364, 41152350, 41152351, 41152360, 41152361, 41152362, 41152363, 41152363, 41152364, 41152365, 41152365, 41152364, 41152365, 41152366, 41152366, 41152364, 41152364, 41152366, 41152366, 43780742, 41152376, 41152376, 42409486, 41152376, 41304586, 41152377, 41712796, 41152378, 41712797, 42056279, 42838460, 41152378, 41152379, 41303914, 43780746, 41152379, 41152379, 41712798, 41712798, 41712799, 41712799, 42065975, 42156633, 42156634, 42323873, 42838460, 43780746, 43780746, 43782983, 43782984, 44381651, 45125747, 41152379, 43780745, 44381653, 41152380, 41152381, 41277148, 41303896, 41303897, 41303917, 41303917, 41303918, 41303918, 41303920, 41303920, 41304478, 41304585, 41304588, 41341543, 41649848, 41712799, 41712799, 41712800, 41712801, 41780785, 41965119, 41965119, 41965122, 42065975, 42065976, 42156634, 42156635, 42156636, 42323873, 42409489, 42409490, 42639469, 42639470, 42639471, 42703422, 42838461, 42916271, 43527758, 43527760, 43527761, 43527762, 43527763, 43741977, 43780747, 43780749, 43782984, 43782985, 44381651, 44381652, 44381652, 44381653, 44381654, 44381655, 44381655, 45208813, 45258352, 41152381, 41153012, 41237367, 41303916, 41303917, 41424561, 41649848, 41712799, 41712800, 41712800, 41712801, 41965122, 41965123, 42056282, 42065976, 42156635, 42237033, 42344901, 42478358, 42639471, 42639471, 42838461, 43780748, 43782985, 43782985, 44381652, 44381653, 45258353, 41303918, 41304588, 41712800, 41712801, 41712802, 41965123, 41967961, 42156636, 43780748, 44381653, 44381653, 41153667, 41153686, 41153742, 41153761, 41153818, 41153832, 41304648, 42057026, 41181030, 41181036, 41181058, 41181128, 41181181, 43795149, 41322366, 41797798, 41374871, 43892000, 41401933, 41837584, 41455442, 41455430, 41455435, 41455444, 41455434, 41455435, 41455442, 41455465, 42308168, 41455467, 41455468, 41455470, 41455470, 41455469, 41455470, 41455471, 41864336, 41455471, 41455471, 41455472, 41455471, 41455472, 41455471, 41455473, 41493081, 41455473, 41864337, 43934523, 41455475, 41455476, 43934530, 41864345, 41864343, 41864352, 42990014, 41456139, 41456142, 41864353, 41864355, 42217530, 42990015, 43934538, 44533209, 41864353, 42116676, 44533208, 41456033, 42308190, 42990016, 43932302, 43566092, 42990017, 41456586, 41456587, 41456587, 41456588, 41456591, 41456700, 41456701, 41456698, 41456699, 41456695, 41456702, 41456703, 41456704, 41456803, 41456808, 41456809, 41456810, 41456811, 41456811, 41456812, 41456812, 41456814, 41456815, 41456817, 41456816, 41456816, 43932965, 43932969, 43935207, 41865020, 41865023, 42208503, 42218199, 42308857, 43566759, 43932970, 43932970, 45410575, 43679983, 41530719, 41530720, 41530722, 41901975, 42154299, 41901979, 41696752, 41696873, 41696991, 41696994, 41985111, 41985111, 42147318, 42147367, 42147369, 42147442, 42147515, 42537200, 42907078, 42273216, 42273230, 42273216, 42273218, 42273219, 42273219, 42273220, 42273221, 42273232, 42273233, 42273233, 42273234, 42273234, 42273235, 42273236, 42273219, 42273220, 42273220, 42273233, 42273234, 42273234, 42273235, 42273235, 42273222, 42273234, 42273235, 42273235, 42273237, 42273235, 42273236, 42273236, 42273235, 42273236, 42273237, 42273235, 42273236, 42273236, 42273238, 42273237, 42273237, 42273248, 42273251, 43199904, 42273249, 42525556, 42717069, 44341181, 44341181, 42273249, 42273250, 42273250, 42273251, 42525557, 42616714, 42626410, 42717069, 42717069, 43199905, 43398895, 43451359, 43974971, 44088193, 44341181, 44341182, 44343418, 44343419, 44942086, 44942086, 44942088, 44942088, 44942089, 42273250, 42273251, 42273252, 42525557, 42626411, 42717070, 42884306, 42884309, 43398896, 43398897, 44341182, 44343419, 44343419, 44343420, 44942087, 44942088, 44942088, 44942089, 45459599, 45818787, 42273251, 42525558, 42626411, 42717070, 42717071, 42969925, 43199905, 43199906, 43719578, 44199665, 44341181, 44341183, 44343420, 44942091, 45769248, 45818788, 42525558, 42626410, 42717070, 42717071, 42969926, 43308613, 43398897, 43996762, 44341183, 44343420, 44881522, 44942091, 45818788, 44343421, 44942089, 42626413, 43451362, 43877223, 44341185, 43398899, 42409202, 44409164, 42756146, 44582638, 42777874, 42777876, 42777875, 42777878, 42777876, 42777877, 42777877, 42777879, 42777879, 43651215, 44340496, 44593502, 44593503, 44593502, 45143337, 46071107, 43136627, 45194407, 43136630, 44340517, 45194409, 42841426, 42969391, 44593504, 44595742, 42783555, 43974738, 42810471, 42985686, 42904976, 43933946, 42920537, 46092899, 42926853, 42953220, 42960195, 42960196, 42960199, 42960199, 42960197, 45285567, 42969890, 43060548, 43543386, 43543388, 45285571, 42979570, 42979582, 42979585, 42979583, 42979584, 42979585, 42979585, 42979586, 42979586, 42979587, 42979587, 42979597, 43070243, 43553078, 43553079, 43700917, 43752068, 44670325, 44694355, 44696592, 45236840, 45295259, 45295261, 45295263, 43187682, 43752070, 44694356, 42979599, 43237483, 44694357, 43070244, 43553080, 43553081, 43752071, 44441371, 44694357, 43070245, 43070245, 43070246, 43160898, 43160898, 43160900, 43160902, 43160903, 43160904, 43160904, 43160905, 43160906, 43160906, 43160891, 43160903, 43160903, 43160904, 43160904, 43160905, 43160906, 43160906, 43160906, 43160906, 43160905, 43160905, 43643736, 44785013, 43842728, 43842729, 43920540, 44242899, 44532029, 43842729, 43160920, 43328143, 43413758, 43643739, 44643499, 44785016, 45385921, 45385924, 43328142, 44785016, 44785017, 44785018, 44787254, 46262622, 43413759, 43842731, 43910676, 44418806, 44532030, 44785017, 44787254, 45385922, 46262622, 44787255, 43413760, 44785018, 44787255, 45385924, 46213084, 43413761, 45385924, 45385926, 45385924, 43321697, 45466317, 43395781, 43761177, 43495378, 43495379, 43495380, 43495380, 43495380, 43495380, 43495380, 43495381, 43495381, 43495384, 44810735, 44952253, 44009967, 46429859, 43810977, 43810978, 44952254, 44954491, 43580997, 44009968, 44952255, 44699270, 43497457, 44953296, 43537431, 44030992, 43666609, 43666610, 43666600, 43666612, 43666612, 43666613, 43749290, 44635663, 44896352, 45037870, 45040106, 45040107, 45638775, 46515475, 43804359, 45106749, 43831972, 46598156, 44126574, 44126575, 44126561, 44126571, 44126575, 44126573, 44126573, 44126576, 44126575, 44126575, 44126576, 44126576, 44126577, 44126576, 45868753, 44126588, 45267850, 44325565, 45014864, 45267852, 46745457, 45267850, 45270090, 44325566, 44646248, 44865646, 44901642, 45014865, 45267852, 45267852, 45267853, 45267854, 45868757, 45868758, 45868759, 45868760, 45868761, 45868763, 46311168, 46745458, 45267853, 44254477, 45932707, 44343986, 44881723, 44422258, 44473409, 44524542, 44524554, 44524554, 44524555, 44524555, 44524556, 44524556, 44524557, 44524557, 44524558, 44524557, 44524558, 44524558, 46067745, 46894906, 45466841, 46067745, 46944446, 44524569, 45466840, 45466841, 46067747, 46067749, 46944446, 44524570, 45466842, 46944447, 44524572, 45325330, 45466842, 45466843, 45469079, 45469080, 46007181, 46009328, 46067747, 46067751, 46944448, 44577021, 44845239, 44951444, 45213854, 45213855, 45466843, 45466845, 45469080, 45469081, 46067749, 46944448, 45213857, 45325331, 45466844, 45469081, 46067751, 45466844, 45469081, 44629484, 44629485, 45521544, 46120212, 46120213, 44660455, 44660483, 45190364, 44680175, 44680176, 44680176, 45291665, 45544651, 45546888, 44962907, 45686016, 45165919, 45165921, 45787523, 45787524, 45787525, 45789762, 45324897, 45324898, 45867013, 45869250, 45378331, 45893730, 45419462, 46515199, 45481203, 45945165, 45604776, 45604933, 45605090, 46007140, 45676705, 45676706, 45676708, 46042917, 46643822, 45901401, 46042919, 46583258, 46643822, 46643826, 47520524, 45720256, 45720298, 45720298, 45720397, 45720372, 45720445, 46064792, 46064792, 45903114, 45903137, 45903152, 45903153, 45903154, 45903154, 45903155, 45903153, 45903155, 45903156, 45903156, 45903155, 45903157, 45903157, 45903157, 45903159, 47633746, 46757045, 47633746, 46757047, 47633747, 46757047, 47633747, 46156143, 46156144, 46158379, 46158380, 46158380, 46158381, 46757047, 46757048, 46757051, 46126094, 46126096, 46126097, 46126096, 46126098, 46126104, 46267612, 46267613, 46269850, 47745220, 46269852, 46672818, 46868525, 46331602, 46971276, 46360289, 46985644, 46361065, 46385095, 46409128, 46409127, 46409128, 46409113, 46409114, 46409128, 46409129, 46409114, 46409129, 46409130, 46409115, 46409116, 46409118, 46409118, 46409129, 46409129, 46409130, 46409130, 46409131, 46409131, 46409132, 46409132, 46409130, 46409131, 46409132, 46409132, 46409131, 46409132, 46409133, 46409133, 46409134, 46409134, 46409135, 46409134, 46409134, 46409134, 46411365, 46409144, 46409144, 46409145, 46411366, 46409145, 46409146, 46411367, 46411367, 47010034, 47010034, 47010035, 47010037, 47010038, 47010038, 47886735, 46409146, 46409147, 46409147, 46409148, 46409149, 46409149, 46411366, 46411367, 46411367, 46411368, 46411369, 46910518, 46938198, 47010033, 47010034, 47010035, 47010035, 47010036, 47010037, 47010037, 47010038, 47010038, 47010039, 47837196, 47886735, 46409148, 46409149, 46411367, 46411368, 46411368, 47010035, 47010036, 47010037, 47010038, 47010039, 47837196, 47886736, 46411368, 46411369, 47010036, 47010037, 47010038, 47010039, 47886736, 46409150, 46411368, 46411369, 46814334, 47010036, 47010037, 47010038, 47010038, 47010039, 47010040, 47010037, 47010038, 47010039, 47010039, 47010040, 47886737, 47010038, 47010039, 46411370, 47010038, 47010041, 47010042, 46413603, 46413603, 46413588, 46413589, 46413603, 46413603, 46413604, 46413589, 46413604, 46413604, 46413604, 46413605, 46413605, 46413606, 46413607, 46413606, 46413608, 47012271, 46413619, 46443943, 46952973, 46952976, 47012271, 47012272, 47012273, 47012273, 47888972, 46413620, 46685400, 46952975, 46953372, 46953853, 46961197, 47012270, 47012271, 47012272, 47012272, 47012273, 47012273, 47012274, 47012274, 47012275, 47012275, 47012276, 47012276, 47012277, 47529784, 47839433, 47888972, 46953853, 47012273, 47012274, 47012274, 47012277, 46474282, 47042613, 46957191, 47284063, 47219535, 47219541, 47415239, 47415245, 47411930, 47511448, 47467279, 47539117, 47489803, 47489805, 47489808, 47550370, 47799925, 47550376, 47492343, 47492346, 47492348, 47492351, 47551642, 47551644, 47551644, 47551648, 47493133, 47493228, 47493323, 47552129, 47494098, 47494099, 47494100, 47494100, 47552517, 47552519, 47552520, 47552522, 47552521, 47508791, 47508796, 47559867, 47610922, 47610923, 47610924, 47610926, 47610923, 47610924, 47610925, 47610924, 47610925, 47610925, 47610926, 47610926, 47610927, 47610927, 47610938, 47610939, 47610940, 47610941, 47610942, 47610925, 47610926, 47610926, 47610927, 47610927, 47610928, 47610928, 47610929, 47610929, 47610930, 47610939, 47610940, 47610940, 47610941, 47610941, 47610942, 47610943, 47610926, 47610927, 47610927, 47610928, 47610928, 47610929, 47610929, 47610941, 47610941, 47610927, 47610928, 47610928, 47610929, 47610929, 47610930, 47610931, 47610939, 47610940, 47610941, 47610942, 47610943, 47610943, 47610944, 47610944, 47610945, 47610928, 47610929, 47610929, 47610930, 47610939, 47610941, 47610942, 47610943, 47610943, 47610944, 47610944, 47610929, 47610930, 47610930, 47610931, 47610931, 47610932, 47610932, 47610938, 47610940, 47610941, 47610942, 47610942, 47610943, 47610944, 47610944, 47610945, 47610930, 47610931, 47610931, 47610932, 47610932, 47610940, 47610942, 47610942, 47610943, 47610943, 47610944, 47610944, 47610945, 47610945, 47610946, 47610931, 47610932, 47610932, 47610933, 47610939, 47610941, 47610942, 47610943, 47610943, 47610944, 47610944, 47610945, 47610945, 47610946, 47610946, 47610932, 47610941, 47610942, 47610943, 47610943, 47610944, 47610944, 47610945, 47610946, 47610946, 47610947, 47610947, 47610941, 47610943, 47610944, 47610944, 47610945, 47610946, 47610946, 47610947, 47610947, 47610943, 47610944, 47610945, 47610946, 47610946, 47610947, 47610948, 47610944, 47610947, 47610947, 47610948, 47610951, 47610945, 47610945, 47610947, 47610953, 47610954, 47610953, 47610955, 47610951, 47610953, 47610955, 47610955, 47610956, 47611069, 47610953, 47610956, 47610957, 47610953, 47610954, 47610955, 47610955, 47610956, 47610957, 47610957, 47610958, 48487639, 47610955, 47610956, 47610956, 47610957, 47610957, 47610958, 47610961, 48487640, 47610956, 47610957, 47610957, 47610958, 47610958, 47610959, 47610959, 48128452, 48487640, 47610957, 47610958, 47610958, 47610959, 47610959, 47611068, 47685299, 47860493, 48487641, 47610958, 47610959, 47610959, 47906042, 48487641, 47610959, 47610960, 47610960, 47611074, 48438102, 48470589, 48487642, 47610960, 47610961, 47610961, 47610963, 47611064, 47612521, 48438103, 48487642, 47610961, 47610962, 47610962, 47610963, 47610964, 47610966, 47611067, 47611071, 47611071, 47611072, 47667885, 47860493, 47860494, 48059382, 48128455, 48128455, 48318981, 48337595, 48355038, 48355040, 48436642, 48438091, 48438103, 48487643, 47610962, 47611071, 47611072, 47860496, 47995398, 48128455, 48355039, 48438104, 48470590, 48487643, 47610963, 48103462, 48128456, 48487644, 47611074, 48487644, 48487645, 48487646, 48128458, 48487648, 47611181, 47611184, 47611188, 47611192, 47611182, 47611191, 47611192, 47611193, 47611196, 47611197, 47611201, 48487759, 48487761, 48128575, 48487764, 48487766, 47612646, 47614093, 47614094, 48489215, 48489216, 47724823, 48544580, 47759655, 48561997, 48110042, 48110043, 48110044, 48110044, 48110045, 48378004, 48737191, 48737192, 48201137, 48782736, 48379858, 48872103, 48495818, 48495905, 48495995, 48930198, 48507815, 48936076, 48595974, 48930237, 48645961, 48645961, 48645963, 48645963, 48645964, 48645964, 48645965, 48645968, 48645962, 48645965, 48645966, 49005149, 48955610, 49005149, 49005151, 49005151, 49005152, 49005152, 49005153, 49005154, 49005156, 49027066, 49027146, 49027189, 49027233, 49027257, 49146256, 49064235, 49064311, 49064386, 49214358, 49099130, 49099131, 49099131, 49099132, 49231735, 49262342, 49313342, 49264564, 49264878, 49265191, 49265244, 49265246, 49265256, 49265257, 49314796, 49330227, 49330234, 49330283, 49347286, 49330340, 49347337], "xaxis": "x", "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 0, 1, 0, 34, 18971, 183, 136, 620, 88, 376, 20, 2, 141, 105, 114, 50, 22, 41, 126, 223, 461, 9844, 3757, 25, 1186, 395, 222, 1588, 80, 201, 218, 225, 113, 228, 697, 12521, 1548, 50, 135, 26, 138, 226, 1583, 8, 256, 141, 227, 27, 287, 307, 1673, 485, 81, 2, 6, 0, 0, 200, 249, 114, 106, 115, 49, 23, 228, 42, 241, 229, 175, 51, 1178, 352, 29630, 16066, 6904, 5851, 9054, 636, 2387, 1174, 139, 173, 835, 979, 294, 551, 704, 3031, 766, 82, 7142, 3462, 4095, 1036, 395, 24, 55, 546, 293, 217, 315, 781, 319, 41, 226, 13, 232, 17, 52, 95, 25, 481, 1762, 2, 1974, 774, 3486, 193, 1090, 223, 263, 249, 2722, 1605, 2930, 210, 8, 283, 98, 43, 27, 1245, 2477, 230, 397, 250, 641, 266, 3, 1432, 414, 703, 272, 401, 124, 67, 2490, 637, 164, 709, 1780, 453, 1363, 60, 173, 76, 108, 1189, 207, 993, 770, 404, 257, 1294, 1407, 1348, 1071, 2537, 1061, 2765, 434, 355, 163, 196, 248, 372, 2, 119, 69, 134, 97, 81, 194, 456, 747, 270, 65, 346, 322, 1685, 853, 484, 547, 274, 251, 6, 1157, 265, 448, 270, 128, 68, 216, 317, 19, 481, 229, 286, 175, 199, 1544, 145, 142, 405, 703, 219, 323, 51, 199, 138, 16, 295, 674, 1034, 224, 296, 7, 1487, 135, 161, 56, 136, 420, 1029, 4727, 785, 378, 170, 83, 231, 246, 874, 481, 1088, 749, 201, 451, 9, 247, 83, 9514, 8339, 1048, 461, 231, 509, 929, 476, 22, 1568, 3, 360, 57, 125, 284, 300, 42, 183, 89, 202, 15175, 315, 2166, 195, 288, 176, 916, 1365, 257, 1111, 521, 173, 705, 42, 293, 156, 483, 204, 194, 199, 12, 399, 36, 16025, 62, 1037, 879, 2595, 2622, 3206, 1701, 2271, 948, 1379, 1211, 298, 620, 541, 928, 344, 721, 110, 116, 91, 453, 282, 415, 509, 717, 316, 1119, 453, 428, 717, 2656, 2288, 5215, 131, 3475, 219, 283, 1361, 13, 198, 71, 80, 1769, 617, 461, 216, 435, 39, 253, 29, 183, 410, 517, 1001, 259, 454, 99, 713, 229, 178, 714, 289, 290, 730, 377, 341, 124, 3, 98, 520, 212, 213, 1713, 1511, 455, 556, 563, 4, 26, 357, 957, 170, 260, 290, 145, 153, 1407, 454, 3603, 138, 275, 673, 15, 2, 2, 164, 59, 963, 347, 40, 18, 103, 233, 877, 1466, 725, 422, 4745, 525, 197, 1192, 809, 221, 227, 2, 257, 157, 12, 3631, 9, 673, 419, 201, 679, 475, 119, 126, 4, 905, 90, 701, 187, 509, 550, 452, 222, 883, 293, 124, 46, 874, 1107, 4182, 50, 218, 1607, 351, 181, 586, 331, 1006, 1010, 4202, 273, 169, 267, 675, 117, 52, 429, 5, 131, 229, 388, 221, 603, 315, 1337, 321, 282, 277, 653, 188, 494, 256, 410, 96, 363, 342, 627, 407, 349, 123, 346, 648, 1102, 16, 104, 302, 172, 508, 651, 1169, 953, 115, 1019, 65, 399, 60, 554, 2130, 683, 507, 57, 498, 333, 523, 138, 821, 144, 1269, 1120, 798, 282, 17, 57, 3, 46, 281, 361, 3, 328, 6, 8, 370, 1686, 441, 270, 217, 364, 638, 836, 2525, 120, 74, 126, 426, 512, 202, 227, 302, 122, 350, 13, 1006, 72, 462, 3638, 14, 48, 854, 1017, 197, 224, 349, 1064, 97, 2402, 11, 146, 40, 7631, 4930, 2449, 1079, 1542, 5890, 1420, 138, 257, 262, 6, 6, 601, 444, 665, 4508, 963, 1540, 379, 1018, 2201, 975, 56, 317, 114, 3388, 0, 406, 619, 656, 2506, 2127, 878, 953, 1844, 653, 147, 369, 296, 624, 98, 3078, 615, 995, 469, 449, 382, 203, 222, 283, 369, 1112, 359, 470, 423, 575, 198, 522, 611, 833, 514, 6084, 567, 97, 259, 110, 161, 754, 264, 418, 626, 827, 578, 173, 5472, 514, 287, 431, 1159, 449, 412, 121, 144, 791, 370, 839, 1013, 898, 2108, 6370, 286, 214, 4, 1097, 256, 96, 179, 8, 148, 899, 368, 998, 289, 226, 448, 979, 705, 411, 421, 278, 474, 449, 1107, 228, 842, 464, 2766, 920, 178, 861, 596, 502, 1, 1251, 776, 1769, 7299, 314, 1586, 3163, 4292, 11874, 40987, 14, 5, 5, 4, 2, 13, 1, 11, 16, 147, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7073, 303, 134, 1326, 91, 12, 307, 368, 314, 1635, 338, 307, 416, 291, 618, 200, 230, 124, 1277, 420, 129, 96, 148, 81, 492, 141, 73, 75, 211, 103, 138, 717, 162, 93, 35, 183, 50, 20, 50, 143, 572, 347, 1117, 940, 1097, 2510, 5888, 3635, 0, 0, 0, 0, 240, 1312, 223, 683, 107, 228, 219, 245, 230, 407, 372, 22, 98, 129, 160, 49, 192, 622, 1001, 468, 239, 95, 179, 26, 135, 112, 319, 201, 238, 116, 668, 70, 105, 111, 210, 90, 375, 222, 92, 11, 141, 24, 111, 139, 149, 238, 521, 149, 238, 103, 117, 177, 242, 434, 163, 227, 153, 370, 113, 343, 200, 112, 224, 318, 220, 227, 237, 78, 244, 200, 4, 227, 76, 133, 102, 6, 587, 68, 226, 66, 316, 172, 131, 168, 68, 130, 162, 68, 451, 63, 409, 123, 111, 115, 122, 220, 137, 111, 201, 252, 46, 122, 488, 261, 789, 1146, 315, 315, 121, 128, 129, 174, 199, 355, 373, 8, 128, 94, 95, 276, 147, 80, 491, 136, 110, 139, 90, 72, 3, 76, 127, 119, 21, 68, 97, 150, 102, 171, 74, 64, 124, 161, 75, 103, 137, 50, 143, 20, 142, 96, 125, 128, 200, 104, 109, 1, 127, 76, 182, 110, 160, 173, 12, 36, 181, 251, 49, 124, 19, 19, 155, 118, 314, 184, 139, 390, 120, 57, 94, 247, 29, 351, 185, 406, 58, 161, 123, 276, 132, 188, 206, 196, 431, 958, 841, 50, 235, 1454, 1824, 105, 1700, 1052, 619, 0, 9442, 1410, 0, 25001, 42, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 7, 1, 2, 1, 1, 1, 2, 2, 1, 1, 11, 2, 5, 4, 2, 5, 3, 1, 2, 5, 22, 15, 5, 12, 1, 3, 5, 3, 5, 9, 9, 3, 2, 2, 2, 4, 39, 7, 7, 5, 8, 20, 24, 10, 1, 5, 16, 8, 3, 2, 4, 23, 17, 35, 19, 14, 8, 1, 2, 3, 6, 2, 4, 3, 1, 6, 2, 1, 1, 3, 5, 14, 15, 6, 5, 8, 15, 2, 3, 3, 2, 1, 1, 3, 15, 12, 4, 8, 18, 4, 2, 2, 3, 2, 4, 5, 1, 1, 1, 1, 3, 2, 1, 2, 1, 3, 2, 2, 1, 1, 2, 1, 1, 2, 2, 0, 0, 2, 4, 4, 2, 0, 0, 21, 14, 1, 2, 3, 0, 44, 4, 4, 3, 1, 1, 0, 0, 0, 0, 26, 1, 12, 9, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 14, 1, 2, 2, 3, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 3, 1, 2, 0, 0, 0, 0, 0, 0, 4, 1, 2, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 8, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 6, 3, 2, 1, 1, 1, 1, 1, 1, 1, 1, 4, 6, 5, 11, 4, 1, 1, 0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 5, 2, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 4, 4, 8, 1, 1, 1, 2, 2, 1, 0, 0, 2, 4, 0, 0, 1, 2, 1, 0, 22, 313, 46, 1360, 335, 129, 3606, 195, 204, 99, 148, 140, 62, 110, 267, 256, 41, 70, 78, 311, 50, 64, 174, 3031, 13168, 7106, 1, 205, 175, 207, 239, 544, 111, 142, 86, 113, 18, 1484, 144, 120, 288, 940, 971, 176, 196, 78, 128, 1485, 100, 149, 1486, 141, 63, 109, 150, 260, 161, 103, 234, 42, 71, 51, 27, 64, 156, 153, 206, 51, 65, 1785, 5548, 622, 22461, 2, 30592, 1239, 571, 231, 216, 715, 1148, 74, 484, 5853, 455, 524, 178, 162, 1078, 673, 8727, 2252, 287, 1541, 923, 34, 13, 301, 730, 127, 36, 1, 50, 35, 11, 22, 1, 787, 52, 1409, 1694, 876, 362, 982, 594, 1630, 9074, 1027, 37, 407, 1380, 500, 7041, 2243, 1243, 721, 14, 36, 31, 50, 409, 300, 152, 276, 1361, 287, 292, 376, 54, 46, 262, 298, 875, 139, 136, 4, 3, 222, 230, 142, 64, 427, 492, 217, 406, 66, 680, 1, 144, 22, 1847, 97, 1287, 181, 150, 29, 75, 65, 1, 137, 313, 42, 852, 229, 309, 3604, 1407, 130, 8012, 2060, 408, 592, 493, 177, 391, 18, 59, 73, 111, 75, 131, 422, 715, 176, 409, 1482, 227, 92, 179, 1, 799, 493, 2, 2968, 362, 162, 406, 112, 7736, 566, 340, 210, 40, 729, 439, 214, 56, 2, 238, 15034, 286, 397, 145, 9266, 3575, 139, 546, 3019, 1051, 404, 2, 20, 9, 81, 1054, 124, 42, 289, 916, 236, 114, 353, 188, 10, 217, 141, 135, 312, 531, 69, 598, 321, 252, 997, 7222, 3211, 2077, 500, 809, 1701, 545, 102, 3, 1172, 11, 261, 181, 615, 585, 81, 223, 25, 228, 149, 139, 1016, 694, 323, 287, 288, 576, 407, 76, 1000, 146, 8228, 466, 37, 2366, 225, 84, 1876, 18, 204, 231, 24, 887, 896, 125, 451, 1255, 99, 460, 649, 12, 253, 952, 400, 225, 311, 57, 53, 306, 34, 1035, 415, 329, 2139, 316, 1207, 1470, 97, 657, 78, 426, 2555, 535, 179, 515, 768, 1367, 315, 314, 304, 770, 326, 975, 146, 422, 116, 397, 22, 55, 3, 349, 439, 341, 664, 178, 467, 38, 185, 284, 1157, 911, 883, 2, 478, 12, 170, 230, 403, 164, 38, 319, 390, 81, 369, 115, 201, 107, 700, 471, 2971, 305, 501, 50, 318, 405, 102, 1221, 20, 40, 51, 929, 240, 103, 408, 172, 174, 44, 121, 616, 432, 288, 62, 1, 204, 100, 262, 228, 108, 699, 247, 1216, 1241, 1542, 3203, 149, 386, 180, 172, 83, 506, 101, 244, 19, 602, 263, 495, 98, 22, 224, 16, 257, 138, 205, 882, 181, 15, 759, 99, 4, 41, 103, 258, 51, 218, 8, 3, 32, 304, 77, 196, 0, 279, 23, 145, 107, 2, 477, 80, 255, 17, 32, 76, 1113, 1085, 172, 489, 139, 1226, 605, 278, 64, 574, 716, 23, 601, 683, 285, 279, 169, 396, 447, 33, 150, 58, 268, 282, 22, 188, 102, 41, 178, 126, 1356, 1183, 86, 220, 291, 1030, 216, 33, 235, 5, 35, 616, 94, 1213, 412, 884, 100, 893, 5, 16, 618, 70, 3, 227, 2177, 1924, 557, 2186, 435, 173, 95, 225, 260, 347, 153, 206, 1264, 1134, 163, 824, 8, 445, 98, 346, 1157, 1549, 917, 192, 110, 465, 3464, 800, 99, 460, 305, 55, 1058, 256, 239, 80, 1872, 2588, 1221, 5, 847, 223, 671, 78, 383, 436, 1936, 1863, 0, 1605, 475, 980, 88, 431, 177, 109, 235, 1691, 1313, 850, 409, 31, 90, 634, 256, 211, 827, 492, 1665, 341, 1057, 334, 148, 83, 726, 82, 1266, 172, 605, 0, 1432, 227, 216, 1498, 562, 428, 761, 864, 1026, 961, 51, 1048, 218, 4, 341, 157, 847, 443, 1227, 2880, 740, 1252, 78, 795, 777, 125, 196, 726, 276, 519, 210, 1190, 1112, 1950, 129, 2532, 1212, 5213, 29923, 8555, 15087, 423, 19, 1099, 114, 362, 690, 345, 269, 202, 19, 149, 476, 485, 113, 371, 113, 342, 21, 128, 31, 68, 15, 55, 29, 79, 424, 53, 245, 279, 161, 125, 107, 41, 90, 194, 31, 182, 824, 195, 39, 50, 406, 9, 118, 1169, 288, 116, 514, 1181, 3129, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2361, 250, 560, 181, 153, 340, 160, 181, 99, 365, 61, 571, 662, 461, 198, 292, 285, 391, 112, 130, 57, 107, 265, 208, 51, 115, 81, 28, 63, 151, 1818, 52, 91, 244, 180, 236, 1192, 465, 80, 572, 1006, 1483, 10, 141, 145, 153, 436, 51, 128, 230, 249, 18, 244, 44, 31, 320, 137, 110, 203, 15, 71, 1, 195, 89, 87, 75, 39, 1484, 65, 180, 47, 154, 165, 66, 100, 98, 62, 109, 113, 172, 121, 94, 38, 60, 150, 103, 18, 245, 1485, 134, 28, 119, 64, 45, 102, 118, 117, 7, 106, 63, 3, 71, 78, 57, 56, 83, 136, 133, 89, 66, 18, 30, 60, 57, 367, 11, 203, 64, 196, 194, 120, 56, 153, 110, 69, 244, 37, 100, 0, 63, 195, 467, 94, 58, 142, 75, 68, 154, 88, 144, 68, 10, 115, 67, 155, 111, 112, 143, 108, 135, 144, 117, 46, 126, 279, 43, 33, 373, 133, 163, 81, 120, 111, 62, 112, 72, 179, 112, 194, 366, 366, 102, 141, 98, 290, 20, 127, 109, 80, 71, 360, 109, 32, 90, 99, 14, 204, 1486, 250, 214, 187, 120, 203, 30, 116, 56, 78, 108, 100, 307, 95, 18, 171, 45, 36, 178, 15, 16, 244, 113, 359, 205, 10, 195, 164, 65, 108, 155, 119, 108, 119, 304, 67, 60, 154, 69, 257, 30, 209, 27, 52, 67, 250, 116, 19, 80, 152, 91, 29, 9, 358, 125, 70, 27, 110, 101, 53, 242, 24, 29, 109, 132, 77, 14, 1547, 226, 29, 65, 150, 170, 435, 1482, 158, 206, 335, 538, 130, 180, 1102, 79, 403, 683, 480, 820, 249, 193, 51, 40, 1481, 90, 213, 255, 248, 70, 408, 155, 99, 437, 55, 160, 68, 80, 690, 49, 213, 136, 832, 186, 674, 262, 185, 326, 68, 120, 8, 1853, 243, 186, 218, 323, 186, 0, 1223, 2367, 1859, 2640, 2687, 269, 1416, 931, 360, 2195, 1058, 858, 5700, 2533, 16078, 84, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 3, 0, 0, 0, 2, 0, 2, 0, 1, 0, 1, 2, 1, 0, 1, 3, 1, 2, 1, 1, 1, 2, 5, 2, 5, 5, 1, 1, 2, 1, 1, 3, 1, 1, 1, 1, 1, 3, 2, 1, 1, 1, 1, 5, 3, 3, 4, 1, 5, 1, 2, 1, 1, 1, 7, 4, 6, 2, 1, 3, 1, 2, 6, 3, 6, 8, 11, 2, 1, 4, 3, 1, 2, 2, 3, 3, 7, 7, 2, 3, 23, 5, 9, 6, 5, 4, 1, 2, 4, 11, 2, 2, 1, 1, 22, 13, 6, 6, 8, 3, 1, 3, 4, 2, 4, 19, 31, 24, 7, 1, 10, 16, 7, 5, 2, 3, 12, 16, 7, 2, 22, 9, 6, 5, 3, 14, 9, 4, 20, 14, 2, 3, 10, 2, 6, 2, 3, 16, 16, 22, 12, 1, 1, 7, 4, 4, 3, 2, 2, 14, 21, 47, 9, 2, 1, 4, 16, 23, 25, 11, 3, 4, 5, 8, 3, 2, 2, 3, 1, 2, 4, 4, 6, 2, 1, 0, 1, 4, 3, 3, 1, 1, 0, 1, 0, 1, 1, 1, 0, 0, 4, 3, 1, 0, 0, 2, 1, 1, 31, 27, 4, 1, 0, 0, 0, 53, 26, 4, 1, 0, 0, 0, 48, 10, 1, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 6, 127, 10, 438, 313, 109, 21, 25, 100, 2, 2414, 4328, 2, 3, 85, 51, 13, 46, 63, 71, 280, 227, 143, 175, 22, 26, 6, 48, 5, 1, 2, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2959, 2, 798, 144, 60, 138, 49, 123, 151, 11, 263, 1, 28, 434, 294, 250, 202, 91, 54, 61, 49, 116, 110, 52, 130, 52, 310, 56, 330, 297, 425, 33, 703, 100, 260, 276, 373, 222, 455, 52, 44, 134, 29, 77, 58, 80, 38, 253, 252, 6966, 83, 32, 126, 1, 94, 41, 119, 32, 33, 106, 159, 67, 81, 61, 1, 59, 81, 50, 43, 88, 152, 12, 60, 66, 177, 23, 0, 30, 61, 22, 30, 202, 67, 142, 48, 248, 82, 213, 39, 33, 36, 58, 60, 180, 29, 64, 2, 54, 32, 27, 0, 47, 96, 18, 0, 37, 35, 40, 0, 16, 10, 60, 0, 51, 212, 64, 36, 64, 51, 42, 52, 254, 38, 0, 88, 50, 8, 43, 67, 148, 30, 28, 99, 66, 97, 50, 117, 93, 32, 43, 251, 212, 1, 65, 66, 45, 45, 129, 55, 655, 3, 68, 25, 59, 97, 41, 94, 37, 237, 128, 117, 83, 26, 153, 90, 1, 345, 97, 1, 5, 65, 90, 2, 69, 58, 43, 9, 259, 82, 34, 26, 607, 207, 60, 11, 48, 31, 127, 56, 447, 17, 29, 8, 34, 215, 413, 54, 63, 38, 27, 29, 499, 206, 42, 101, 53, 17, 61, 45, 62, 267, 2, 1, 105, 95, 227, 68, 54, 27, 0, 76, 33, 57, 1, 82, 57, 42, 79, 39, 41, 32, 97, 37, 223, 92, 760, 0, 81, 28, 212, 80, 133, 734, 1, 0, 2285, 104, 17, 10, 6, 13, 88, 34, 23, 155, 57, 340, 4636, 0, 0, 0, 0, 0, 0, 0, 27, 100, 55, 64, 164, 1771, 100, 46, 11, 5, 99, 12, 86, 33, 22, 62, 139, 116, 629, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 10, 1287, 19, 235, 25, 47, 82, 72, 75, 137, 671, 9870, 6834, 111, 2, 5, 1, 120, 800, 385, 22, 236, 26, 48, 121, 81, 71, 75, 104, 35, 493, 188, 12081, 6314, 1385, 241, 104, 1207, 641, 169, 594, 436, 104, 355, 1, 116, 356, 962, 99, 22, 138, 348, 876, 267, 213, 52, 452, 94, 210, 219, 790, 202, 2970, 507, 976, 340, 119, 2975, 1174, 117, 121, 965, 923, 44, 488, 550, 336, 186, 575, 203, 192, 113, 168, 138, 98, 162, 248, 96, 68, 252, 111, 97, 202, 13, 679, 4865, 47, 8, 838, 201, 143, 197, 240, 396, 309, 139, 100, 156, 624, 54, 135, 90, 1455, 186, 158, 56, 14, 5, 170, 337, 51, 236, 496, 41, 354, 3, 8, 99, 31, 220, 115, 29, 355, 161, 42, 242, 105, 151, 291, 190, 47, 9, 145, 257, 136, 475, 355, 485, 168, 372, 208, 156, 234, 144, 139, 2, 95, 42, 336, 11, 59, 105, 356, 90, 51, 2, 241, 243, 357, 3, 117, 331, 397, 28, 384, 405, 104, 152, 142, 244, 100, 23, 476, 333, 139, 169, 214, 203, 137, 695, 79, 105, 242, 177, 90, 71, 140, 355, 51, 2, 85, 378, 190, 94, 41, 44, 696, 1, 2, 331, 138, 91, 95, 329, 28, 98, 78, 129, 99, 20, 87, 98, 130, 847, 127, 693, 76, 276, 69, 695, 56, 6, 2, 10, 163, 331, 10, 86, 14, 2, 126, 109, 0, 123, 305, 384, 112, 63, 88, 1258, 910, 97, 466, 370, 318, 674, 56, 130, 383, 78, 45, 46, 138, 137, 10, 17, 633, 0, 332, 157, 166, 24, 83, 145, 49, 176, 661, 292, 355, 207, 53, 173, 91, 84, 111, 798, 119, 333, 62, 221, 9, 11, 106, 559, 87, 89, 92, 3238, 122, 986, 312, 1, 1256, 307, 86, 233, 50, 170, 112, 56, 43, 112, 1691, 0, 2732, 1327, 140, 891, 872, 260, 55, 46, 114, 28, 133, 115, 472, 121, 33, 84, 122, 98, 2510, 1731, 1161, 156, 329, 151, 130, 121, 261, 95, 0, 232, 434, 582, 1242, 1702, 435, 181, 850, 159, 186, 167, 96, 50, 29, 627, 600, 263, 0, 1104, 354, 613, 611, 566, 169, 429, 398, 484, 85, 44, 46, 389, 1016, 217, 777, 80, 1537, 154, 238, 170, 271, 139, 20, 215, 27, 119, 75, 4, 76, 49, 145, 695, 644, 1956, 148, 98, 136, 49, 216, 57, 143, 187, 595, 25, 295, 497, 65, 202, 118, 60, 312, 440, 4, 149, 122, 357, 332, 19, 1352, 202, 176, 38, 486, 222, 319, 980, 669, 1, 583, 496, 121, 136, 164, 7, 2, 777, 135, 153, 110, 104, 221, 129, 5, 281, 0, 0, 146, 122, 46, 218, 442, 544, 170, 123, 190, 1, 235, 158, 3, 269, 643, 332, 97, 185, 6, 203, 318, 101, 504, 673, 662, 169, 137, 469, 76, 351, 98, 206, 823, 955, 248, 184, 189, 147, 95, 128, 1547, 141, 214, 249, 113, 11, 4, 705, 188, 2, 476, 364, 91, 3, 363, 57, 74, 142, 44, 328, 3, 247, 67, 399, 3, 354, 220, 183, 239, 353, 146, 445, 541, 151, 165, 75, 121, 48, 840, 157, 266, 568, 475, 219, 144, 474, 382, 97, 241, 10, 694, 135, 99, 203, 43, 1303, 275, 208, 136, 168, 46, 6522, 24, 7, 54, 121, 0, 9245, 168, 35, 102, 44, 418, 16, 175, 47, 92, 197, 35, 55, 174, 186, 624, 482, 2562, 4325, 0, 0, 0, 0, 106, 101, 29, 15, 365, 45, 117, 51, 20, 81, 55, 320, 959, 1189, 414, 2196, 2993, 54, 105, 110, 134, 28, 16, 103, 43, 418, 367, 17, 174, 46, 41, 93, 116, 211, 34, 50, 54, 19, 80, 72, 173, 165, 132, 235, 40, 172, 403, 773, 244, 1035, 816, 377, 1072, 7587, 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 23, 8115, 328, 461, 56, 319, 56, 37, 38, 438, 286, 18, 12, 168, 80, 766, 1496, 10650, 8210, 1, 3, 115, 145, 73, 253, 74, 1203, 4311, 2040, 329, 58, 71, 452, 146, 57, 231, 91, 74, 57, 38, 34, 6, 293, 6, 0, 0, 0, 0, 0, 0, 0, 0, 519, 56, 19, 70, 13, 169, 81, 137, 692, 36, 2211, 964, 3, 6, 8, 188, 10, 2, 53, 217, 20200, 8, 17187, 2290, 785, 5308, 3767, 3687, 365, 442, 451, 1235, 149, 179, 360, 149, 1867, 76, 7489, 2017, 4344, 687, 343, 1311, 205, 518, 252, 53, 915, 181, 104, 349, 74, 192, 82, 5, 46, 12, 22, 1, 59, 71, 131, 235, 9, 310, 278, 50, 2961, 2035, 123, 4515, 1294, 1487, 581, 811, 392, 1529, 94, 134, 613, 112, 692, 438, 1041, 728, 24, 66, 44, 553, 334, 786, 239, 902, 7, 147, 105, 2, 588, 320, 256, 155, 182, 3, 64, 143, 72, 52, 124, 297, 45, 248, 140, 307, 88, 1682, 1519, 205, 347, 534, 842, 2941, 146, 137, 1031, 190, 159, 51, 5, 140, 161, 227, 133, 340, 2383, 585, 1195, 127, 2079, 315, 119, 199, 271, 704, 159, 1281, 420, 213, 299, 649, 778, 1465, 464, 2900, 321, 188, 225, 586, 272, 611, 179, 8, 10, 203, 157, 10, 57, 18, 1512, 238, 53, 2, 81, 313, 218, 253, 225, 171, 1387, 657, 2224, 148, 1001, 145, 30, 7, 587, 273, 314, 150, 95, 58, 421, 45, 136, 233, 306, 218, 2, 461, 1, 135, 706, 150, 1101, 2436, 28, 923, 191, 402, 128, 201, 20, 19, 74, 60, 99, 2011, 1249, 827, 77, 8170, 6619, 2355, 1709, 1048, 35, 196, 278, 376, 578, 348, 253, 163, 20, 215, 36, 63, 214, 332, 161, 215, 534, 221, 136, 163, 824, 445, 147, 9682, 141, 599, 613, 188, 171, 214, 3, 91, 159, 861, 121, 64, 29, 2, 82, 166, 2, 99, 388, 4000, 4230, 3624, 1444, 1313, 747, 919, 2134, 1540, 486, 208, 921, 852, 64, 74, 57, 15, 186, 130, 473, 325, 342, 168, 521, 338, 278, 1111, 2, 94, 659, 314, 13, 2305, 3037, 1193, 73, 499, 525, 332, 1067, 298, 297, 72, 4, 216, 117, 122, 441, 3022, 604, 1823, 12, 328, 1405, 93, 248, 321, 908, 521, 67, 278, 23, 289, 221, 122, 91, 84, 198, 2, 177, 1515, 53, 926, 163, 1010, 502, 158, 599, 104, 154, 77, 177, 228, 873, 629, 132, 669, 633, 316, 196, 578, 456, 353, 1303, 110, 76, 311, 385, 35, 126, 58, 323, 110, 17, 982, 48, 385, 847, 747, 136, 48, 426, 125, 43, 947, 1074, 568, 782, 189, 4, 247, 232, 184, 4, 153, 77, 3, 83, 251, 440, 647, 639, 301, 347, 28, 228, 10, 53, 156, 124, 199, 370, 519, 306, 1262, 205, 344, 7, 6, 187, 149, 340, 188, 447, 63, 55, 8, 253, 135, 77, 317, 2080, 1776, 600, 97, 66, 450, 1089, 1076, 194, 428, 333, 127, 309, 102, 745, 235, 791, 300, 427, 51, 98, 316, 322, 641, 299, 1090, 20, 98, 79, 554, 129, 186, 141, 223, 254, 261, 1101, 258, 1333, 137, 158, 783, 691, 244, 779, 150, 128, 8, 960, 40, 429, 251, 163, 723, 320, 301, 41, 1035, 180, 18, 52, 257, 1372, 800, 337, 153, 27, 223, 401, 610, 162, 238, 228, 341, 83, 65, 52, 40, 65, 394, 105, 76, 73, 535, 248, 88, 792, 154, 328, 177, 910, 168, 234, 45, 5, 71, 322, 10, 2, 315, 217, 221, 120, 194, 6, 791, 14, 18, 117, 126, 68, 551, 306, 148, 335, 655, 35, 298, 194, 258, 274, 185, 746, 0, 814, 523, 1249, 150, 1148, 2002, 190, 707, 14, 212, 492, 669, 605, 154, 1519, 1442, 257, 22, 156, 304, 131, 522, 144, 227, 2593, 904, 183, 350, 386, 1218, 39, 106, 46, 306, 121, 341, 143, 798, 3072, 1177, 284, 141, 264, 152, 143, 1731, 8668, 660, 535, 1807, 436, 406, 20, 583, 310, 2596, 2230, 3948, 2372, 96, 21, 62, 466, 932, 4038, 1584, 1534, 7, 1132, 216, 2088, 94, 735, 414, 227, 1027, 206, 1617, 3361, 13, 716, 507, 4, 520, 2776, 6725, 135, 1902, 1, 405, 263, 308, 734, 259, 332, 490, 425, 277, 1391, 107, 759, 1592, 1772, 2384, 659, 984, 205, 14578, 17936, 638, 161, 418, 39, 121, 17, 64, 60, 252, 5, 64, 397, 318, 160, 231, 223, 211, 278, 58, 35, 51, 29, 2, 2, 3, 0, 3, 3, 64, 269, 88, 358, 1546, 6928, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2877, 294, 75, 320, 91, 916, 79, 154, 174, 832, 230, 457, 352, 99, 265, 153, 189, 401, 93, 262, 197, 113, 34, 102, 109, 34, 181, 39, 16, 76, 38, 364, 662, 315, 1198, 5895, 0, 0, 0, 81, 329, 54, 529, 73, 53, 393, 614, 1371, 124, 155, 257, 272, 74, 146, 88, 268, 89, 270, 394, 116, 447, 198, 78, 81, 87, 111, 124, 61, 173, 166, 126, 56, 323, 232, 4, 201, 262, 258, 20, 65, 119, 80, 328, 119, 207, 76, 101, 349, 48, 121, 494, 257, 146, 12, 19, 98, 255, 165, 229, 456, 92, 118, 53, 270, 185, 167, 327, 210, 269, 517, 132, 256, 23, 436, 910, 211, 260, 154, 125, 206, 56, 198, 34, 112, 33, 50, 30, 147, 72, 30, 257, 118, 24, 110, 1, 35, 52, 179, 3, 1, 5, 4, 2, 4, 38, 10, 60, 19, 197, 256, 75, 2, 446, 392, 61, 37, 254, 222, 851, 253, 1117, 347, 375, 580, 8245, 34, 14, 1, 1, 2, 45, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 2, 0, 0, 0, 0, 1, 0, 0, 0, 2, 4, 2, 0, 1, 810, 82, 48, 443, 429, 36, 54, 31, 19, 15, 50, 2, 32, 52, 649, 7689, 1624, 2, 307, 13, 486, 31, 48, 36, 23, 28, 13, 225, 322, 202, 334, 120, 61, 55, 32, 20, 16, 49, 1, 3, 33, 53, 14, 926, 29, 10873, 4, 1, 2268, 766, 795, 472, 122, 283, 153, 329, 698, 236, 155, 123, 293, 64, 100, 188, 446, 223, 117, 1, 1176, 1595, 2427, 359, 1829, 386, 160, 615, 29, 237, 418, 646, 92, 121, 74, 64, 7, 315, 130, 65, 254, 22, 23, 15, 33, 265, 5081, 127, 90, 360, 96, 106, 197, 195, 148, 267, 203, 91, 417, 55, 63, 26, 119, 287, 218, 122, 18, 91, 279, 208, 60, 61, 94, 90, 2, 6, 5, 151, 40, 63, 187, 75, 55, 123, 362, 152, 284, 83, 280, 72, 56, 144, 8, 96, 51, 36, 112, 266, 274, 73, 53, 96, 99, 237, 285, 64, 93, 124, 120, 95, 60, 22, 64, 238, 65, 101, 97, 189, 61, 137, 121, 312, 225, 284, 27, 0, 20, 98, 145, 2, 62, 189, 953, 117, 188, 136, 29, 49, 218, 41, 112, 84, 41, 535, 122, 95, 209, 81, 336, 110, 74, 64, 78, 58, 60, 118, 1, 489, 866, 967, 178, 557, 184, 480, 148, 54, 103, 29, 122, 337, 571, 116, 89, 291, 728, 152, 119, 159, 47, 93, 54, 3, 185, 267, 308, 53, 65, 111, 164, 188, 826, 162, 432, 590, 52, 115, 176, 96, 546, 216, 66, 105, 93, 49, 796, 65, 281, 55, 111, 107, 9, 18, 49, 184, 225, 268, 193, 195, 23, 76, 46, 169, 82, 41, 197, 105, 529, 6, 58, 92, 210, 407, 28, 198, 91, 148, 162, 355, 193, 48, 96, 58, 120, 52, 199, 101, 174, 316, 23, 63, 244, 367, 129, 7, 504, 157, 131, 77, 71, 823, 400, 94, 43, 81, 833, 121, 426, 3, 49, 255, 97, 780, 63, 36, 523, 22, 76, 216, 109, 78, 28, 120, 119, 57, 270, 91, 121, 63, 70, 53, 104, 48, 212, 217, 95, 202, 1384, 256, 28, 14, 1, 3, 162, 7, 75, 2766, 44, 127, 42, 286, 191, 267, 88, 514, 2377, 70, 193, 270, 253, 88, 93, 94, 395, 13, 136, 65, 104, 171, 375, 20, 0, 64, 77, 544, 76, 271, 650, 199, 69, 385, 479, 259, 32, 341, 149, 6, 1648, 6839, 110, 31, 10, 11, 11, 21, 59, 22, 44, 126, 8, 2, 30, 99, 33, 72, 92, 132, 73, 445, 2521, 1443, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 383, 30, 31, 98, 159, 56, 102, 62, 82, 51, 20, 53, 30, 22, 59, 106, 406, 176, 38, 336, 3262, 1019, 141, 59, 167, 116, 29, 13, 16, 65, 31, 4, 62, 72, 22, 25, 55, 9, 9, 103, 12, 81, 58, 23, 81, 50, 43, 21, 3, 177, 61, 29, 7, 21, 11, 16, 60, 29, 24, 65, 5, 58, 32, 23, 98, 46, 30, 116, 612, 143, 63, 305, 78, 159, 43, 980, 76, 8082, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 7, 1571, 81, 25, 30, 46, 4, 6, 98, 14, 51, 61, 24, 165, 4464, 11166, 1, 917, 686, 82, 26, 31, 45, 2, 0, 97, 15, 52, 60, 25, 106, 62, 5642, 2894, 7676, 4317, 2698, 1170, 204, 167, 442, 492, 412, 89, 172, 111, 153, 51, 160, 709, 2586, 2, 991, 2616, 33, 431, 525, 296, 634, 1, 357, 14, 122, 65, 63, 63, 13, 250, 166, 116, 4202, 2, 858, 678, 121, 79, 39, 559, 294, 107, 183, 2210, 1437, 268, 78, 63, 657, 1299, 286, 846, 248, 2, 204, 160, 263, 1, 41, 1, 99, 76, 370, 1661, 180, 88, 186, 232, 186, 212, 1443, 316, 1222, 186, 193, 78, 65, 6, 320, 70, 122, 294, 54, 155, 618, 164, 682, 61, 287, 170, 314, 1359, 528, 196, 2, 148, 81, 355, 105, 115, 305, 470, 392, 183, 87, 493, 463, 184, 119, 67, 264, 295, 95, 78, 28, 8, 269, 63, 106, 89, 391, 372, 205, 218, 85, 31, 167, 218, 268, 113, 264, 344, 112, 288, 90, 168, 1, 100, 166, 183, 5, 206, 52, 112, 38, 294, 117, 52, 283, 159, 114, 511, 460, 119, 107, 159, 131, 2, 62, 24, 64, 48, 299, 134, 1, 573, 4172, 829, 380, 260, 109, 638, 250, 76, 85, 231, 409, 75, 259, 78, 2, 14, 78, 148, 297, 16, 56, 105, 409, 3, 247, 42, 98, 453, 193, 124, 224, 9, 7, 314, 35, 22, 146, 611, 18, 1358, 1752, 938, 619, 670, 396, 72, 188, 806, 603, 491, 131, 649, 332, 170, 283, 53, 25, 86, 488, 317, 98, 136, 63, 431, 31, 1392, 1, 197, 19, 185, 101, 553, 65, 34, 43, 157, 212, 108, 28, 83, 380, 234, 538, 137, 53, 53, 105, 227, 934, 250, 2, 231, 217, 101, 168, 100, 99, 13, 171, 61, 105, 335, 250, 93, 441, 402, 188, 108, 326, 2, 207, 452, 18, 536, 262, 17, 98, 2, 309, 5, 59, 55, 206, 154, 2, 199, 34, 155, 124, 634, 104, 141, 102, 378, 290, 169, 149, 8, 62, 28, 349, 6, 109, 54, 110, 60, 92, 517, 157, 0, 44, 66, 107, 775, 400, 160, 241, 50, 4, 20, 129, 67, 75, 121, 34, 825, 0, 202, 225, 92, 50, 45, 104, 564, 13, 100, 47, 123, 103, 3, 43, 404, 77, 187, 410, 224, 595, 33, 505, 233, 2, 372, 244, 119, 103, 3, 528, 105, 651, 522, 66, 93, 384, 248, 117, 227, 13, 109, 85, 4, 1179, 85, 317, 365, 172, 3, 135, 68, 610, 348, 207, 147, 80, 88, 8, 1384, 0, 111, 68, 62, 34, 259, 76, 83, 71, 213, 65, 217, 129, 92, 67, 135, 276, 52, 184, 405, 21, 220, 330, 105, 484, 272, 469, 162, 10, 260, 532, 251, 24, 404, 81, 98, 79, 223, 20, 169, 219, 57, 36, 495, 85, 92, 209, 247, 313, 67, 661, 238, 104, 371, 288, 25, 357, 284, 280, 227, 1365, 382, 68, 232, 50, 114, 168, 235, 103, 257, 1588, 238, 255, 507, 56, 254, 672, 84, 1781, 144, 64, 97, 1297, 226, 9, 206, 102, 34, 1649, 54, 53, 514, 438, 12, 208, 251, 70, 135, 477, 338, 102, 108, 134, 74, 327, 120, 933, 683, 205, 79, 373, 302, 167, 1181, 3750, 102, 366, 2799, 6394, 468, 4392, 27, 86, 84, 1, 247, 151, 32, 1, 67, 1, 53, 3, 204, 124, 2, 18, 3, 2, 0, 27, 1, 26, 195, 161, 251, 2706, 69, 2130, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 318, 3264, 65, 121, 60, 38, 146, 181, 47, 160, 1366, 85, 408, 1, 0, 538, 55, 60, 3, 115, 138, 63, 106, 90, 72, 73, 53, 30, 184, 184, 14, 50, 57, 93, 46, 155, 66, 91, 206, 403, 56, 3289, 62, 2445, 26, 64, 85, 120, 83, 59, 69, 54, 66, 0, 44, 83, 41, 74, 111, 62, 163, 58, 31, 187, 0, 89, 134, 71, 57, 0, 51, 0, 74, 2, 206, 52, 61, 31, 49, 77, 224, 185, 13, 1, 17, 70, 49, 2, 10, 2, 56, 171, 69, 92, 45, 73, 2, 0, 76, 154, 91, 65, 110, 25, 90, 547, 25, 371, 52, 334, 351, 431, 559, 9593, 814, 10, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 0, 1, 1, 1, 1, 0, 0, 0, 4, 1365, 357, 824, 243, 14, 30, 26, 54, 193, 11, 6, 162, 38, 50, 89, 16, 942, 7319, 5160, 4, 72, 140, 169, 133, 2, 690, 179, 8, 45, 254, 60, 12, 75, 715, 112, 141, 247, 170, 121, 8, 0, 129, 18, 0, 0, 131, 1, 7, 8, 47, 0, 0, 5, 194, 1, 0, 142, 12, 1, 0, 0, 163, 39, 52, 90, 93, 1223, 147, 11111, 1, 2, 5466, 491, 470, 448, 332, 113, 251, 95, 143, 463, 46, 10, 2123, 2667, 4791, 3970, 229, 738, 1034, 556, 401, 1073, 185, 36, 324, 132, 284, 84, 18, 1, 47, 5, 1, 117, 62, 20, 32, 76, 2, 49, 1, 304, 4462, 1, 1, 625, 2, 140, 212, 195, 312, 476, 684, 972, 227, 238, 163, 80, 395, 118, 487, 192, 315, 434, 244, 104, 26, 90, 132, 73, 11, 31, 13, 1, 67, 65, 105, 485, 4, 284, 9, 257, 83, 30, 2, 253, 96, 72, 106, 26, 48, 91, 90, 132, 70, 209, 105, 36, 2, 69, 75, 47, 11, 598, 952, 932, 79, 6, 37, 256, 193, 78, 39, 154, 1156, 1631, 84, 5, 202, 133, 353, 229, 67, 245, 158, 264, 42, 2, 26, 12, 2, 182, 73, 52, 3076, 452, 38, 463, 86, 689, 1296, 74, 112, 9, 166, 76, 40, 5, 240, 5, 2, 4, 115, 133, 41, 220, 431, 96, 194, 606, 3, 790, 1523, 1107, 1122, 880, 69, 190, 79, 105, 398, 94, 75, 347, 120, 298, 12, 170, 168, 78, 20, 95, 128, 166, 150, 390, 286, 150, 1289, 66, 71, 24, 85, 154, 376, 319, 275, 179, 77, 320, 51, 44, 180, 80, 20, 24, 161, 388, 687, 692, 444, 81, 203, 88, 32, 193, 13, 147, 35, 15, 70, 183, 158, 248, 507, 1112, 24, 67, 593, 191, 133, 119, 16, 33, 7, 62, 107, 239, 1223, 16, 111, 5, 128, 75, 27, 139, 56, 201, 265, 452, 311, 300, 274, 23, 37, 38, 71, 165, 492, 106, 450, 313, 381, 91, 212, 227, 128, 213, 347, 2, 13, 260, 7, 155, 225, 312, 114, 303, 624, 173, 82, 92, 534, 281, 196, 328, 694, 99, 107, 88, 70, 396, 368, 84, 75, 119, 142, 78, 92, 4, 153, 120, 113, 72, 85, 144, 251, 8, 62, 1, 321, 82, 131, 369, 4, 10, 106, 501, 80, 92, 68, 106, 213, 454, 299, 190, 70, 502, 73, 330, 246, 188, 321, 134, 289, 83, 223, 157, 129, 4, 13, 76, 211, 52, 2, 214, 25, 76, 74, 263, 322, 76, 369, 96, 242, 128, 43, 138, 210, 91, 598, 69, 41, 137, 0, 87, 51, 13, 1011, 209, 297, 103, 132, 40, 213, 872, 0, 543, 5, 72, 118, 369, 82, 70, 3, 578, 46, 107, 210, 371, 172, 304, 222, 160, 152, 208, 289, 0, 108, 321, 132, 119, 3, 102, 994, 94, 432, 56, 221, 273, 128, 93, 232, 545, 153, 71, 5, 101, 5, 125, 1102, 132, 396, 127, 58, 73, 443, 1642, 0, 69, 434, 159, 438, 212, 4, 817, 3, 9, 320, 84, 151, 4, 958, 217, 131, 128, 795, 1077, 67, 812, 0, 91, 19, 1, 259, 749, 305, 934, 2204, 0, 130, 558, 366, 0, 212, 350, 5100, 10180, 131, 21, 16, 258, 39, 279, 3, 48, 46, 115, 13, 2, 49, 3, 18, 0, 66, 47, 53, 75, 15, 66, 171, 302, 335, 3291, 0, 0, 0, 0, 523, 158, 96, 643, 19, 358, 350, 137, 145, 47, 76, 69, 138, 52, 47, 70, 93, 47, 24, 40, 141, 14, 107, 150, 49, 359, 723, 276, 4911, 41, 604, 20, 91, 65, 27, 81, 43, 41, 56, 47, 86, 652, 0, 0, 11, 25, 22, 113, 44, 468, 0, 66, 1, 93, 225, 0, 0, 40, 95, 57, 171, 0, 91, 112, 75, 83, 96, 0, 19, 40, 148, 55, 53, 46, 46, 0, 54, 50, 18, 69, 2, 94, 48, 19, 55, 10, 27, 67, 49, 39, 45, 22, 168, 13, 33, 104, 111, 118, 0, 78, 70, 59, 47, 165, 112, 742, 143, 1300, 1008, 3, 0, 0, 0, 0, 0, 0, 16, 21226, 601, 1669, 95, 2945, 4, 1495, 289, 102, 373, 105, 2, 202, 1150, 64, 348, 32, 175, 638, 179, 28, 442, 321, 1089, 15997, 6914, 1963, 1680, 3479, 577, 907, 291, 281, 291, 397, 9507, 2031, 894, 678, 335, 673, 897, 914, 346, 1776, 335, 898, 96, 771, 364, 209, 173, 360, 642, 730, 4239, 565, 424, 161, 149, 438, 2261, 767, 949, 103, 375, 210, 174, 102, 896, 0, 202, 173, 0, 1282, 0, 142, 554, 427, 629, 140, 0, 10, 63, 292, 499, 34, 359, 174, 636, 211, 426, 180, 29, 247, 195, 994, 137, 3417, 187, 44631, 41641, 6478, 6419, 9500, 1190, 2038, 1165, 2708, 1585, 4079, 2270, 1931, 796, 1110, 437, 3324, 6704, 11045, 197, 2542, 1167, 699, 2, 1150, 701, 29, 565, 34, 3, 23, 28, 112, 40, 146, 9, 7, 279, 25, 70, 640, 1, 570, 3843, 7214, 1664, 2458, 950, 2114, 1418, 649, 2158, 608, 2292, 836, 2699, 4162, 5675, 772, 544, 684, 22, 361, 140, 20, 379, 1278, 1542, 162, 288, 281, 774, 117, 1524, 261, 422, 62, 1520, 407, 1068, 1599, 455, 918, 285, 790, 752, 329, 2192, 346, 9, 740, 1001, 543, 520, 2841, 1292, 13, 1838, 1863, 1546, 1357, 5334, 273, 5, 7, 23, 115, 274, 620, 947, 1318, 183, 942, 1101, 364, 38, 46, 279, 1069, 138, 1468, 591, 1605, 414, 14, 827, 213, 331, 260, 274, 517, 984, 163, 713, 73, 355, 350, 1455, 2054, 103, 568, 859, 822, 155, 557, 1025, 1826, 443, 71, 1517, 617, 705, 699, 770, 1310, 985, 2210, 2578, 525, 514, 282, 17, 26, 590, 143, 448, 377, 1167, 3237, 4365, 346, 11, 57, 7, 618, 1138, 1078, 630, 1373, 647, 7, 121, 399, 1307, 1225, 2640, 143, 97, 286, 463, 362, 1186, 934, 35, 3, 998, 3939, 3070, 48, 29, 8, 261, 183, 7745, 6671, 297, 220, 835, 504, 118, 84, 42, 24, 2, 184, 275, 31947, 2138, 308, 650, 419, 1268, 602, 250, 225, 43382, 17432, 12377, 2382, 4695, 12, 78, 2409, 439, 161, 603, 30, 386, 1030, 402, 66, 3, 160, 258, 338, 35, 758, 35, 105, 226, 198, 19526, 14336, 2861, 9504, 1435, 149, 560, 1561, 418, 136, 246, 348, 45, 384, 328, 354, 18542, 3225, 9542, 8, 4563, 675, 298, 346, 83, 97, 623, 475, 512, 105, 46, 61, 454, 110, 102, 4564, 29396, 74, 1920, 4927, 129, 662, 2617, 1255, 89, 879, 290, 163, 213, 121, 133, 180, 478, 505, 858, 528, 9777, 253, 2501, 720, 187, 9, 456, 177, 279, 3767, 3050, 32565, 1672, 5083, 5414, 1363, 775, 1289, 540, 1106, 2373, 723, 108, 8, 1243, 2010, 74, 1093, 1633, 379, 341, 272, 292, 265, 34, 14, 210, 1461, 932, 395, 630, 625, 75, 2828, 860, 656, 79, 203, 433, 9, 2051, 5962, 17118, 1233, 3426, 1390, 3666, 278, 646, 39, 407, 461, 25, 6189, 210, 3103, 1583, 1043, 1242, 558, 1850, 216, 13, 799, 607, 596, 27, 217, 658, 2115, 981, 131, 119, 349, 326, 132, 7005, 1155, 430, 1183, 9, 1107, 1110, 1833, 1080, 49, 538, 461, 586, 4438, 3395, 1195, 3894, 2067, 2638, 1037, 795, 483, 731, 5526, 1760, 2447, 1653, 1367, 397, 467, 439, 845, 1020, 8, 494, 541, 1050, 472, 890, 345, 748, 219, 134, 351, 32, 1489, 174, 1333, 1383, 840, 209, 310, 1746, 2404, 599, 423, 458, 400, 334, 7, 272, 244, 1941, 1029, 1136, 2005, 113, 931, 723, 631, 811, 740, 289, 374, 30, 1080, 143, 387, 29, 886, 131, 1873, 451, 553, 3475, 347, 58, 258, 3382, 171, 1723, 215, 535, 839, 470, 475, 245, 59, 1005, 1865, 782, 2129, 4, 2259, 38, 475, 215, 423, 300, 403, 756, 403, 2061, 2287, 983, 113, 473, 97, 363, 473, 8, 67, 215, 349, 629, 214, 32, 148, 804, 31, 45, 6, 317, 2258, 895, 250, 721, 3243, 785, 1387, 213, 32, 118, 283, 51, 170, 206, 98, 853, 176, 1765, 86, 80, 31, 755, 10918, 8, 10631, 3741, 2035, 90, 91, 1571, 1069, 483, 69, 351, 132, 306, 1332, 110, 338, 273, 2296, 23445, 3261, 1331, 303, 661, 217, 67, 800, 201, 459, 2681, 563, 5, 6, 1137, 1851, 31520, 12481, 2224, 780, 37, 342, 1794, 1230, 954, 7, 683, 489, 533, 754, 382, 920, 422, 928, 37513, 3188, 948, 1483, 2145, 630, 523, 565, 84, 631, 1059, 24087, 214, 1812, 7589, 8872, 1224, 536, 1315, 352, 924, 1046, 788, 393, 257, 6354, 5778, 0, 1793, 1337, 70, 816, 8335, 5749, 956, 557, 636, 364, 210, 296, 804, 259, 2452, 6462, 186, 1570, 261, 741, 779, 168, 495, 288, 427, 2323, 465, 623, 472, 149, 185, 287, 68, 299, 507, 996, 426, 296, 36, 420, 226, 6866, 1317, 673, 2304, 89, 288, 308, 737, 615, 1291, 3982, 5172, 6787, 1380, 4392, 1475, 980, 2662, 760, 4862, 10420, 2097, 2757, 3812, 70, 1986, 622, 275, 435, 1583, 4332, 2933, 1075, 220, 1083, 574, 819, 2257, 3113, 764, 2150, 1089, 534, 882, 5026, 5540, 514, 469, 798, 3335, 4771, 979, 442, 43, 1171, 505, 1054, 2040, 1124, 446, 436, 2357, 4067, 28, 1278, 3149, 4392, 214, 2305, 2285, 2825, 4453, 44688, 48010, 834, 337, 55, 239, 171, 4, 109, 915, 35, 39, 73, 62, 312, 20, 62, 141, 41, 74, 473, 171, 93, 86, 134, 33, 96, 36, 19, 1, 29, 521, 45, 83, 262, 18, 1519, 134, 65, 102, 561, 176, 885, 0, 0, 0, 0, 0, 0, 7069, 4125, 230, 249, 387, 211, 2065, 976, 1814, 630, 2044, 7042, 140, 959, 554, 1231, 1043, 371, 137, 121, 156, 162, 107, 298, 295, 51, 455, 222, 124, 171, 286, 172, 99, 349, 150, 565, 359, 190, 53, 185, 1024, 156, 444, 875, 3947, 868, 389, 824, 1616, 152, 1024, 0, 0, 650, 184, 515, 191, 292, 1816, 109, 1126, 307, 406, 56, 174, 75, 193, 135, 1070, 253, 81, 229, 158, 522, 1186, 269, 289, 315, 470, 177, 54, 254, 161, 376, 321, 365, 161, 6, 54, 229, 183, 248, 245, 740, 1, 103, 45, 210, 159, 232, 234, 614, 503, 209, 270, 96, 734, 142, 190, 1215, 470, 106, 201, 307, 0, 147, 205, 127, 3, 153, 2385, 2, 383, 215, 83, 233, 19, 424, 82, 290, 219, 206, 148, 148, 957, 146, 6022, 2175, 648, 419, 1667, 138, 209, 52, 571, 323, 1677, 16, 190, 412, 45, 0, 0, 660, 147, 108, 34, 139, 0, 1048, 207, 440, 143, 71, 38, 268, 183, 180, 321, 1, 70, 11, 2211, 1828, 1115, 1903, 91, 115, 510, 438, 278, 289, 0, 166, 526, 1631, 267, 288, 232, 351, 32, 628, 480, 1108, 450, 459, 171, 371, 303, 268, 281, 746, 659, 10, 252, 428, 0, 277, 1358, 179, 125, 302, 260, 151, 203, 500, 949, 192, 212, 214, 18, 276, 646, 467, 67, 1, 323, 418, 154, 13, 47, 68, 439, 259, 815, 92, 140, 247, 274, 0, 384, 120, 198, 308, 313, 227, 964, 1405, 101, 373, 439, 142, 474, 40, 87, 16, 258, 178, 444, 458, 514, 257, 124, 137, 232, 200, 114, 43, 645, 272, 170, 73, 468, 82, 82, 457, 106, 91, 646, 231, 206, 352, 66, 35, 486, 249, 645, 170, 441, 90, 92, 126, 416, 372, 143, 67, 116, 52, 87, 18, 261, 458, 175, 511, 234, 97, 578, 141, 55, 223, 1046, 304, 644, 202, 145, 367, 230, 140, 123, 135, 170, 31, 176, 253, 437, 91, 256, 1561, 69, 19, 448, 176, 98, 271, 123, 2, 74, 724, 347, 17, 136, 149, 5, 144, 45, 360, 203, 30, 358, 73, 208, 90, 105, 366, 169, 34, 217, 893, 354, 687, 51, 272, 260, 125, 289, 493, 724, 167, 360, 142, 920, 435, 659, 0, 184, 365, 581, 1568, 995, 44, 522, 127, 2113, 27, 81, 51, 0, 456, 1685, 89, 174, 520, 5046, 261, 797, 252, 903, 2, 129, 6562, 4692, 5770, 15942, 380, 690, 0, 953, 3679, 4397, 53, 3752, 4915, 125, 15960, 33, 261, 10678, 38231, 11393, 0, 87, 3, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 15, 6549, 869, 14339, 642, 584, 383, 702, 397, 62, 225, 790, 332, 507, 300, 202, 179, 704, 2648, 24610, 18929, 4899, 341, 1273, 493, 543, 2035, 1911, 295, 194, 544, 188, 292, 144, 51, 439, 704, 536, 237, 6959, 6250, 376, 362, 282, 122, 172, 585, 145, 384, 704, 52, 440, 398, 494, 63, 239, 693, 792, 333, 418, 87, 299, 334, 205, 182, 1581, 207, 2579, 1000, 41349, 1908, 73165, 43452, 13092, 16040, 2523, 2612, 1069, 845, 693, 3245, 2013, 2272, 723, 1976, 776, 1547, 1013, 1150, 1747, 427, 2207, 402, 375, 1190, 1291, 1434, 685, 743, 845, 367, 4596, 1255, 723, 240, 2755, 1442, 405, 6460, 495, 5911, 387, 3354, 2364, 2014, 973, 1116, 295, 3566, 1777, 2287, 2573, 2883, 58, 1019, 83, 406, 550, 259, 21, 16, 1, 4, 333, 8, 7, 94, 160, 831, 2, 7407, 4027, 3796, 808, 1050, 334, 1304, 1357, 10, 1800, 884, 221, 977, 1520, 11, 1360, 611, 1147, 1055, 2315, 684, 332, 1598, 1456, 78, 363, 564, 3160, 780, 609, 714, 333, 122, 28, 423, 287, 100, 2323, 1613, 408, 414, 784, 1194, 1165, 980, 1015, 920, 473, 1070, 1320, 1629, 1274, 1470, 163, 1609, 3, 712, 8, 906, 2894, 2118, 490, 456, 1146, 536, 681, 789, 1056, 668, 8, 267, 734, 325, 169, 2512, 1151, 2, 292, 942, 320, 466, 1020, 512, 1218, 752, 247, 333, 784, 736, 487, 177, 7, 67, 1308, 562, 409, 1366, 725, 590, 450, 248, 797, 1124, 806, 593, 9, 478, 907, 594, 427, 21, 400, 334, 126, 447, 908, 809, 123, 415, 4, 675, 18, 859, 1014, 9, 189, 790, 1311, 1093, 416, 785, 347, 2293, 437, 192, 964, 335, 785, 487, 1027, 1092, 811, 595, 1094, 533, 360, 491, 220, 11, 562, 598, 881, 488, 1336, 335, 491, 21, 704, 23, 457, 650, 915, 423, 440, 570, 777, 793, 458, 1265, 319, 567, 88, 197, 674, 422, 222, 1115, 482, 547, 737, 384, 979, 768, 840, 459, 393, 1147, 741, 5, 141, 2480, 304, 44, 555, 1167, 228, 812, 178, 417, 726, 48, 384, 10, 385, 981, 449, 600, 591, 1165, 56, 1312, 578, 1130, 210, 314, 158, 403, 680, 988, 594, 1369, 489, 790, 450, 18, 126, 1049, 1148, 337, 675, 559, 1266, 1100, 615, 342, 813, 720, 501, 216, 2, 1053, 669, 686, 595, 392, 3, 351, 438, 345, 2078, 2243, 860, 676, 1288, 4, 2, 674, 265, 739, 449, 355, 1469, 437, 3, 649, 6, 6, 291, 487, 2058, 1040, 592, 560, 567, 423, 534, 426, 922, 298, 2818, 885, 339, 824, 397, 1342, 2083, 5, 12, 157, 1452, 1302, 821, 921, 414, 1, 1168, 13, 1146, 1611, 133, 107, 361, 2164, 492, 1350, 324, 1164, 77, 393, 368, 361, 486, 416, 465, 2480, 2296, 795, 448, 494, 1018, 137, 65, 311, 346, 247, 107, 298, 9889, 3081, 2536, 1039, 1189, 1264, 599, 1092, 210, 17, 948, 11, 304, 13, 22, 2, 1143, 494, 1337, 791, 2154, 7806, 8794, 4466, 5171, 517, 737, 4860, 1979, 953, 648, 3346, 460, 0, 46, 60, 7, 464, 192, 78, 116, 0, 1705, 2012, 293, 1074, 483, 5171, 4786, 4888, 265, 5912, 1212, 693, 726, 2618, 2531, 473, 0, 132, 20, 39, 4611, 4417, 902, 4785, 1970, 2211, 1327, 1168, 2, 0, 0, 129, 447, 6192, 4, 565, 8813, 1456, 815, 3214, 2295, 1398, 419, 9, 82, 73, 28, 34, 740, 791, 1471, 794, 11893, 3715, 3184, 2715, 319, 837, 468, 95, 131, 190, 4621, 366, 413, 1384, 155, 2, 294, 22, 920, 1477, 175, 598, 18658, 9488, 13392, 5683, 25, 1905, 1164, 963, 21, 826, 2423, 213, 125, 125, 12, 173, 14, 46, 146, 16, 217, 92, 14192, 13778, 3093, 351, 398, 610, 407, 1169, 67, 21867, 7263, 1004, 800, 2539, 1285, 50, 236, 351, 263, 492, 727, 1054, 805, 45135, 278, 4603, 3181, 11421, 2125, 164, 2117, 640, 188, 1007, 114, 356, 22, 277, 285, 0, 803, 30813, 13216, 19830, 3592, 3904, 3345, 396, 108, 727, 268, 1463, 1450, 1351, 565, 171, 465, 10, 405, 80, 1056, 161, 3, 180, 43, 1512, 409, 394, 26, 277, 15392, 16884, 1973, 1548, 2265, 473, 1590, 984, 191, 89, 160, 75, 213, 744, 289, 22937, 3524, 4607, 2186, 852, 1473, 1386, 163, 108, 188, 884, 674, 64, 216, 375, 697, 144, 17, 3, 338, 282, 14782, 10565, 19123, 1981, 1048, 7766, 2946, 5843, 2792, 1199, 613, 472, 2209, 1128, 360, 224, 169, 27, 475, 1097, 14, 244, 123, 300, 387, 115, 123, 623, 2058, 7510, 7646, 1973, 981, 766, 2914, 1193, 921, 208, 4, 1280, 1052, 339, 473, 94, 389, 422, 218, 7369, 2172, 738, 4618, 2797, 2037, 438, 3452, 823, 1619, 935, 1040, 1157, 2, 556, 351, 14, 270, 672, 285, 2245, 1382, 11983, 2086, 9281, 4721, 1560, 644, 512, 2426, 687, 3067, 808, 175, 309, 594, 1153, 34, 60, 704, 65, 392, 179, 283, 9, 1916, 1285, 411, 613, 1649, 2564, 1220, 242, 641, 93, 1714, 1224, 2008, 768, 68, 258, 418, 189, 4618, 5431, 3519, 4, 500, 1289, 2501, 3743, 2610, 2, 557, 1863, 427, 1123, 402, 111, 746, 320, 791, 2068, 4789, 2157, 1876, 738, 989, 175, 272, 411, 397, 527, 620, 786, 770, 208, 124, 245, 11053, 1586, 1794, 3024, 4406, 1667, 3740, 1485, 178, 1149, 301, 2, 460, 6, 684, 113, 636, 556, 591, 1586, 2728, 2287, 4276, 2088, 3223, 6434, 3036, 1737, 61, 3883, 379, 1838, 175, 1762, 714, 200, 198, 394, 413, 1229, 760, 4453, 794, 1784, 1464, 744, 50, 978, 437, 1508, 279, 914, 530, 1555, 144, 1187, 2691, 1851, 2176, 502, 878, 1166, 174, 799, 1228, 2195, 2326, 1673, 3792, 1907, 784, 270, 17, 52, 631, 210, 49, 290, 1319, 943, 6423, 2648, 1012, 931, 2670, 340, 1127, 891, 563, 661, 388, 728, 289, 623, 586, 251, 731, 1732, 0, 5866, 1908, 2247, 2949, 600, 5, 1379, 954, 2675, 1661, 1084, 166, 811, 25, 1392, 1884, 953, 773, 2808, 487, 6172, 1076, 2824, 438, 1261, 678, 2936, 2939, 242, 2237, 883, 203, 556, 569, 22, 331, 1417, 2308, 501, 37, 360, 753, 690, 2678, 1122, 11, 626, 119, 682, 843, 159, 1003, 1752, 903, 486, 176, 607, 792, 212, 467, 410, 3622, 14, 986, 1491, 1093, 1571, 930, 1511, 1539, 3101, 1533, 1071, 949, 1122, 199, 1143, 789, 60, 596, 311, 1614, 2502, 2978, 8, 378, 8, 26, 485, 1384, 1068, 359, 205, 783, 1795, 1413, 6, 634, 1139, 378, 503, 269, 6, 1094, 437, 1, 743, 784, 43, 1913, 1225, 1362, 1074, 979, 390, 177, 2071, 961, 3211, 476, 1004, 1985, 3334, 2164, 1959, 1922, 795, 662, 661, 364, 783, 2226, 209, 653, 7017, 3173, 4898, 1920, 567, 492, 784, 863, 1047, 6, 1089, 2344, 3763, 3253, 10855, 2132, 242, 255, 788, 4, 2705, 3651, 3950, 2817, 1148, 41, 1115, 591, 1165, 31, 1348, 4708, 13592, 1724, 4079, 1093, 485, 2339, 3269, 2335, 4031, 4798, 1214, 209, 806, 1151, 781, 1551, 618, 3107, 3800, 2228, 769, 627, 333, 208, 710, 1995, 1870, 1693, 974, 560, 481, 299, 8437, 3523, 269, 446, 782, 444, 940, 595, 2498, 7705, 590, 787, 1481, 464, 118, 683, 2202, 1164, 208, 978, 1421, 3114, 389, 1789, 178, 689, 2052, 2567, 947, 4172, 1429, 1690, 2411, 3007, 1174, 546, 1149, 915, 1892, 3768, 1267, 5126, 2354, 0, 74289, 70735, 718, 0, 143, 39, 190, 101, 23, 53, 79, 0, 18, 7, 61, 1786, 40, 176, 15, 280, 97, 270, 67, 50, 480, 3639, 0, 0, 0, 0, 0, 0, 0, 10141, 713, 600, 191, 1384, 1634, 2628, 243, 2119, 521, 907, 569, 240, 98, 91, 435, 997, 132, 627, 22348, 591, 104, 210, 320, 777, 141, 392, 348, 543, 1425, 1458, 1483, 153, 4824, 10296, 342, 533, 279, 601, 858, 5070, 221, 822, 2089, 263, 176, 268, 176, 233, 341, 190, 190, 1, 271, 1333, 306, 142, 565, 290, 297, 241, 560, 661, 1159, 278, 390, 524, 564, 244, 640, 460, 22, 309, 464, 499, 84, 600, 542, 517, 392, 49, 0, 568, 239, 78, 238, 97, 2, 90, 14, 2, 2, 435, 5, 28, 2530, 244, 51, 515, 254, 66, 625, 4, 193, 791, 490, 342, 432, 421, 851, 1356, 328, 1385, 2515, 7058, 597, 9265, 11312, 0, 0, 244, 84, 435, 103, 232, 209, 231, 319, 190, 402, 358, 305, 39, 188, 166, 908, 339, 253, 431, 173, 140, 419, 391, 243, 124, 1248, 21, 880, 385, 532, 1216, 585, 653, 272, 569, 123, 1598, 1128, 1255, 596, 2233, 1221, 724, 7325, 7542, 1115, 1677, 32314, 92, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 5, 24, 5919, 2207, 532, 284, 302, 46, 132, 901, 130, 441, 53, 106, 77, 11, 4, 120, 574, 1077, 14132, 3047, 1285, 232, 83, 46, 84, 41, 161, 165, 74, 164, 3511, 160, 149, 88, 43, 155, 65, 281, 2548, 200, 348, 190, 286, 233, 400, 54, 89, 125, 7, 51, 83, 353, 642, 131, 394, 49, 54, 107, 85, 157, 78, 90, 1, 0, 163, 64, 162, 169, 234, 846, 2090, 88, 27369, 2, 16016, 1924, 100, 718, 1700, 310, 1662, 632, 1519, 1562, 8, 500, 2, 739, 132, 261, 324, 19, 342, 636, 170, 374, 7, 1, 537, 962, 119, 315, 998, 1174, 152, 535, 185, 412, 336, 243, 3552, 1428, 1122, 159, 1373, 1572, 403, 11, 660, 278, 762, 4571, 293, 86, 106, 10, 24, 378, 386, 51, 241, 153, 299, 22, 34, 267, 61, 120, 61, 68, 196, 225, 1797, 3848, 672, 865, 406, 325, 314, 584, 193, 980, 444, 1528, 311, 809, 427, 4, 280, 119, 739, 254, 1333, 306, 1041, 4, 110, 133, 146, 1090, 624, 190, 137, 140, 211, 88, 588, 738, 239, 252, 160, 95, 208, 858, 168, 142, 327, 159, 8, 866, 75, 27, 356, 50, 44, 235, 38, 211, 573, 1, 919, 483, 26, 212, 303, 240, 94, 326, 406, 349, 177, 106, 236, 64, 167, 464, 108, 304, 149, 348, 405, 63, 3, 278, 3, 346, 280, 17, 265, 272, 115, 574, 950, 867, 270, 189, 412, 9, 386, 116, 194, 3, 349, 575, 55, 125, 244, 317, 133, 71, 632, 495, 192, 152, 294, 91, 172, 247, 792, 238, 136, 604, 312, 325, 168, 161, 2, 7, 13, 227, 64, 117, 1, 695, 247, 86, 551, 150, 171, 697, 289, 276, 363, 260, 96, 6, 0, 485, 246, 52, 197, 428, 164, 157, 316, 131, 120, 54, 3, 84, 119, 229, 248, 313, 463, 698, 239, 488, 154, 118, 3, 82, 471, 415, 239, 1389, 295, 2, 355, 148, 338, 118, 121, 1, 53, 226, 353, 0, 7, 0, 20, 101, 955, 375, 114, 269, 14, 186, 253, 0, 117, 145, 263, 434, 543, 47, 78, 80, 49, 64, 25, 126, 165, 82, 38, 0, 2184, 3001, 587, 165, 64, 1196, 166, 55, 124, 107, 165, 1156, 90, 558, 84, 130, 125, 189, 527, 988, 1276, 195, 814, 392, 1140, 20, 38, 498, 150, 149, 0, 32, 251, 1208, 653, 817, 917, 431, 1066, 1608, 130, 223, 64, 61, 106, 254, 300, 83, 462, 121, 318, 345, 160, 14, 350, 1178, 405, 223, 1087, 3173, 69, 98, 118, 213, 38, 0, 5, 531, 339, 427, 655, 1183, 1434, 228, 203, 185, 389, 279, 1181, 713, 164, 64, 1342, 10, 149, 508, 194, 1263, 241, 110, 168, 0, 218, 4480, 297, 70, 7, 764, 275, 601, 60, 225, 97, 146, 767, 3546, 2262, 1532, 238, 1190, 2676, 1972, 3426, 698, 172, 372, 61, 949, 1470, 129, 190, 679, 301, 336, 427, 374, 23, 108, 19, 9, 175, 2200, 2596, 294, 303, 425, 485, 193, 261, 366, 701, 285, 242, 148, 75, 111, 586, 787, 387, 466, 440, 183, 318, 348, 556, 268, 165, 116, 157, 714, 762, 857, 332, 120, 426, 692, 136, 89, 151, 108, 92, 1, 295, 25, 431, 337, 627, 130, 496, 111, 154, 121, 68, 137, 479, 1178, 690, 810, 348, 370, 410, 666, 103, 77, 219, 4, 193, 160, 191, 1204, 1830, 979, 138, 150, 116, 44, 848, 412, 49, 181, 63, 5, 1078, 625, 359, 269, 299, 772, 149, 324, 206, 661, 196, 178, 866, 212, 1972, 2279, 385, 315, 189, 913, 347, 171, 149, 152, 692, 131, 61, 64, 301, 346, 333, 279, 129, 847, 93, 219, 192, 1041, 702, 499, 495, 474, 63, 514, 623, 150, 94, 300, 202, 65, 1, 535, 286, 429, 14, 1063, 2142, 227, 2, 316, 227, 175, 356, 147, 2389, 1193, 164, 131, 300, 189, 191, 226, 155, 241, 281, 345, 476, 552, 328, 210, 300, 332, 205, 337, 154, 190, 146, 783, 89, 147, 574, 289, 424, 240, 291, 133, 198, 427, 439, 280, 297, 612, 1050, 16, 241, 61, 245, 536, 197, 339, 636, 22, 180, 211, 535, 74, 285, 328, 463, 336, 97, 181, 568, 446, 465, 153, 865, 75, 212, 676, 180, 828, 26772, 19527, 694, 304, 263, 1, 11, 32, 19, 219, 163, 224, 238, 181, 263, 2225, 4091, 1839, 0, 0, 0, 0, 0, 0, 0, 2982, 156, 48, 161, 56, 79, 79, 70, 21, 55, 71, 161, 145, 240, 104, 86, 417, 262, 684, 370, 1061, 1037, 3281, 6256, 1226, 98, 147, 57, 127, 544, 152, 752, 1293, 476, 97, 110, 190, 46, 110, 250, 146, 13, 47, 160, 55, 78, 78, 96, 69, 5, 58, 25, 54, 6, 70, 159, 144, 10, 94, 58, 85, 102, 31, 85, 68, 18, 104, 340, 187, 90, 80, 342, 102, 147, 188, 175, 242, 155, 159, 150, 167, 599, 589, 498, 520, 553, 1676, 1329, 84, 8741, 367, 23516, 0, 0, 43, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 18, 371, 30, 16, 488, 57, 509, 11, 267, 26, 74, 52, 2, 98, 67, 721, 3535, 1, 1, 96, 28, 108, 154, 21, 11, 19, 163, 6, 117, 326, 37, 22, 30, 78, 99, 187, 304, 12, 93, 264, 31, 27, 57, 10, 1, 56, 4, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 79, 194, 119, 92, 1408, 1, 1025, 146, 444, 170, 34, 170, 75, 160, 49, 179, 38, 33, 5, 31, 22, 53, 15, 35, 40, 90, 34, 86, 42, 57, 5, 1, 113, 134, 97, 164, 95, 1651, 97, 37, 124, 127, 234, 128, 12, 22, 53, 71, 191, 4, 101, 54, 94, 34, 27, 41, 66, 91, 689, 12, 213, 197, 355, 4138, 4, 109, 2, 59, 163, 222, 51, 98, 18, 28, 299, 63, 86, 132, 137, 122, 58, 110, 59, 133, 76, 40, 35, 98, 75, 35, 42, 54, 108, 1, 50, 2, 180, 39, 58, 34, 6, 32, 23, 25, 30, 1, 16, 36, 41, 91, 60, 35, 12, 74, 37, 5, 43, 16, 4, 2, 2, 35, 74, 38, 79, 90, 55, 31, 21, 26, 14, 134, 0, 12, 22, 97, 44, 16, 138, 56, 77, 26, 137, 16, 66, 38, 48, 237, 138, 146, 238, 100, 27, 26, 31, 117, 23, 28, 9, 9, 28, 90, 35, 62, 494, 99, 108, 348, 45, 39, 24, 22, 5, 4, 2, 31, 34, 39, 189, 18, 48, 46, 12, 59, 36, 57, 38, 181, 26, 41, 132, 214, 60, 19, 4, 66, 84, 21, 283, 279, 28, 1, 4, 36, 55, 6, 57, 245, 21, 75, 171, 25, 47, 1, 38, 1, 180, 32, 20, 98, 139, 2, 4, 79, 17, 37, 134, 3, 65, 87, 179, 26, 156, 15, 39, 52, 48, 64, 3, 262, 38, 97, 24, 29, 109, 37, 40, 84, 14, 16, 135, 43, 15, 104, 22, 34, 54, 32, 33, 51, 45, 8, 8, 23, 22, 5, 65, 27, 192, 97, 188, 31, 178, 3, 124, 223, 136, 1006, 1, 149, 35, 257, 267, 0, 88, 79, 756, 134, 100, 829, 322, 1483, 1710, 48, 108, 22, 34, 1, 9, 125, 6, 56, 114, 231, 3786, 0, 0, 0, 0, 0, 152, 194, 77, 21, 66, 29, 77, 57, 91, 880, 13, 21, 160, 99, 18, 30, 158, 19, 76, 20, 17, 15, 3, 22, 16, 49, 4, 4, 65, 8, 98, 20, 32, 112, 33, 157, 0, 207, 373, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 14, 367, 433, 32, 44, 203, 15, 532, 99, 6, 52, 42, 104, 75, 131, 164, 4211, 5715, 53, 1, 1, 60, 49, 138, 130, 35, 67, 343, 33, 48, 15, 45, 206, 16, 328, 252, 102, 37, 3, 0, 0, 0, 53, 41, 105, 78, 134, 223, 5353, 2, 2695, 401, 47, 601, 551, 171, 351, 74, 517, 121, 123, 355, 82, 82, 73, 330, 514, 488, 2707, 1392, 4749, 153, 216, 64, 774, 164, 198, 119, 15, 317, 173, 40, 25, 71, 400, 329, 86, 51, 177, 72, 208, 597, 3865, 1, 79, 37, 97, 55, 14, 921, 2, 458, 8, 105, 268, 18, 377, 307, 80, 8, 4, 60, 54, 183, 84, 18, 48, 3, 234, 129, 241, 343, 9, 5, 4, 5, 5, 33, 62, 6, 23, 125, 86, 58, 59, 23, 93, 81, 215, 8, 131, 3, 344, 61, 13, 1, 455, 19, 58, 60, 60, 4, 23, 5, 37, 49, 35, 124, 345, 356, 348, 83, 5, 79, 6, 74, 98, 4, 240, 125, 61, 118, 56, 30, 2, 3, 60, 240, 349, 42, 94, 122, 40, 36, 164, 75, 6, 571, 34, 37, 123, 40, 62, 75, 62, 479, 1862, 99, 57, 284, 89, 221, 298, 90, 5, 312, 177, 155, 6, 12, 15, 92, 456, 974, 132, 20, 66, 157, 3, 186, 180, 209, 94, 137, 42, 171, 278, 37, 52, 1255, 50, 206, 239, 125, 126, 388, 438, 141, 53, 25, 119, 149, 619, 1920, 700, 239, 32, 123, 12, 63, 37, 145, 2, 73, 2111, 154, 133, 7, 110, 18, 27, 104, 350, 257, 95, 59, 6, 141, 2, 38, 43, 67, 155, 111, 53, 24, 260, 228, 206, 133, 207, 197, 58, 359, 195, 68, 7, 57, 96, 59, 608, 49, 2, 0, 240, 103, 105, 87, 154, 278, 64, 70, 302, 0, 93, 6, 266, 80, 8, 83, 396, 8, 7, 24, 62, 162, 153, 218, 88, 95, 53, 18, 160, 106, 9, 361, 129, 213, 59, 291, 305, 269, 85, 5, 55, 53, 538, 73, 174, 541, 263, 85, 2, 3, 78, 133, 31, 121, 94, 59, 99, 232, 187, 59, 89, 52, 24, 39, 72, 35, 53, 52, 5, 142, 70, 60, 58, 61, 583, 322, 18, 34, 13, 155, 1, 1086, 521, 286, 42, 380, 423, 159, 118, 101, 22, 394, 190, 2304, 215, 176, 138, 25, 5, 308, 167, 88, 1402, 355, 37, 1274, 61, 73, 101, 483, 83, 184, 7, 68, 186, 393, 1, 356, 152, 132, 192, 263, 178, 157, 82, 355, 87, 1, 344, 240, 245, 64, 4, 3, 33, 465, 13, 16, 0, 136, 21, 161, 244, 1567, 0, 2, 0, 164, 141, 0, 450, 207, 3313, 5043, 166, 97, 25, 26, 67, 80, 48, 454, 19, 20, 50, 104, 76, 26, 53, 24, 52, 1, 5, 23, 9, 187, 43, 99, 102, 135, 417, 1590, 200, 3076, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 51, 191, 50, 33, 74, 46, 53, 0, 42, 22, 77, 39, 28, 469, 378, 1866, 118, 1353, 40, 33, 87, 0, 95, 24, 50, 25, 157, 61, 30, 0, 49, 14, 54, 6, 0, 2, 76, 48, 73, 64, 93, 383, 48, 18, 14, 3, 95, 1, 106, 46, 56, 74, 45, 52, 25, 54, 23, 25, 27, 2, 22, 2, 11, 19, 6, 5, 28, 22, 48, 21, 185, 50, 25, 72, 42, 24, 38, 13, 31, 66, 50, 94, 84, 71, 139, 271, 257, 0, 633, 637, 275, 4637, 0, 574, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 18, 7473, 456, 1396, 143, 521, 130, 10721, 127, 6, 204, 117, 102, 2, 61, 56, 435, 311, 82, 77, 143, 132, 19, 97, 272, 190, 125, 21, 132, 201, 40, 160, 254, 8615, 8608, 666, 2, 33, 1, 160, 315, 333, 2982, 208, 281, 210, 104, 198, 1662, 1079, 139, 407, 76, 883, 679, 161, 334, 144, 522, 131, 330, 120, 487, 179, 50, 321, 275, 523, 228, 297, 615, 6032, 6259, 155, 128, 331, 0, 0, 0, 186, 3, 0, 0, 119, 486, 116, 101, 207, 3, 60, 56, 2, 180, 120, 311, 49, 310, 206, 81, 76, 280, 41, 101, 320, 131, 28, 276, 99, 29, 271, 163, 239, 646, 20, 134, 135, 202, 277, 195, 76, 169, 234, 199, 161, 2020, 31, 23567, 34, 2, 2, 49173, 476, 708, 2125, 994, 418, 986, 20, 47, 138, 179, 98, 183, 29, 3, 279, 1, 94, 107, 3, 28, 131, 1785, 1, 132, 27134, 15169, 9712, 3745, 1515, 3096, 1517, 1546, 194, 87, 62, 168, 1, 201, 144, 124, 226, 96, 1391, 978, 52, 94, 17, 1, 13648, 8235, 531, 648, 2284, 787, 313, 234, 571, 98, 186, 210, 18267, 3125, 1341, 1305, 1282, 477, 1762, 98, 8, 406, 221, 258, 71, 244, 679, 107, 9740, 5880, 9906, 332, 2277, 239, 2460, 1238, 420, 247, 68, 753, 363, 459, 144, 222, 70, 362, 1340, 1653, 407, 5908, 3171, 118, 594, 217, 117, 1804, 340, 11, 585, 916, 214, 502, 108, 22, 57, 2216, 1322, 4, 7242, 165, 1361, 848, 535, 931, 586, 8, 364, 269, 471, 238, 325, 110, 313, 22, 47, 29, 237, 772, 752, 161, 161, 7575, 1051, 2640, 4626, 1780, 12, 848, 391, 7, 602, 1233, 1684, 27, 66, 205, 13, 432, 519, 978, 1313, 1692, 295, 163, 166, 119, 21, 333, 1665, 2139, 249, 706, 1255, 1554, 494, 695, 198, 2657, 175, 126, 378, 147, 263, 1099, 422, 1405, 70, 1639, 218, 380, 124, 2413, 1304, 216, 113, 114, 1146, 459, 481, 241, 307, 150, 83, 163, 159, 120, 1102, 115, 740, 246, 120, 11, 453, 617, 1431, 1392, 1138, 522, 689, 405, 333, 2717, 221, 356, 368, 179, 229, 203, 1467, 345, 2382, 1624, 47, 39, 99, 454, 610, 495, 88, 1122, 235, 250, 294, 123, 9, 45, 293, 509, 704, 624, 1215, 175, 220, 50, 186, 219, 138, 9, 340, 288, 134, 394, 564, 471, 9, 530, 945, 705, 480, 133, 593, 69, 857, 2, 392, 809, 754, 586, 370, 367, 545, 10, 1298, 187, 1492, 552, 353, 592, 1014, 524, 136, 26, 628, 979, 338, 228, 169, 239, 437, 714, 546, 123, 1033, 9, 8, 366, 168, 221, 201, 228, 773, 436, 1180, 1609, 378, 10, 407, 599, 34, 460, 547, 482, 406, 531, 327, 197, 124, 332, 99, 9, 2, 643, 229, 202, 598, 1065, 1, 282, 285, 339, 329, 86, 472, 1960, 349, 5795, 2092, 256, 40, 11, 145, 167, 117, 528, 28, 8, 143, 477, 228, 144, 223, 8, 181, 130, 9, 906, 267, 108, 219, 621, 296, 76, 13, 157, 851, 317, 365, 934, 807, 1645, 1297, 4, 218, 132, 7, 234, 233, 2, 313, 12, 397, 21, 284, 586, 149, 251, 158, 131, 995, 753, 418, 5, 556, 255, 467, 1566, 364, 47, 754, 408, 204, 352, 158, 686, 255, 242, 791, 1136, 1957, 168, 87, 546, 1379, 254, 1145, 1143, 1245, 290, 7996, 5515, 336, 2028, 314, 692, 1077, 42179, 430, 46, 0, 48415, 1, 34, 6, 8, 159, 344, 38, 1, 21, 17, 0, 0, 0, 25460, 55, 562, 282, 313, 606, 67, 128, 950, 57, 183, 406, 121, 52, 495, 499, 366, 14, 180, 162, 133, 89, 106, 47, 48, 56, 114, 0, 109, 72, 103, 25, 255, 330, 432, 217, 234, 1593, 0, 0, 0, 0, 6114, 193, 2145, 50, 274, 497, 1045, 150, 80, 2337, 281, 40, 170, 449, 1063, 516, 143, 60, 94, 10, 205, 16, 110, 102, 154, 599, 111, 84, 57, 138, 79, 99, 42, 70, 210, 75, 153, 52, 797, 619, 628, 219, 652, 3350, 0, 0, 152, 188, 54, 803, 491, 93, 119, 890, 19, 109, 75, 208, 163, 271, 528, 105, 96, 193, 292, 241, 250, 859, 192, 151, 362, 45, 536, 242, 304, 109, 136, 106, 57, 275, 171, 785, 0, 61, 20, 71, 86, 3, 49, 52, 35, 240, 32, 134, 435, 44, 396, 60, 240, 99, 261, 161, 249, 498, 114, 65, 315, 504, 110, 134, 41, 83, 359, 0, 91, 66, 46, 160, 234, 956, 79, 16, 475, 48, 53, 22, 268, 1160, 482, 100, 163, 144, 162, 18, 123, 107, 98, 120, 123, 775, 298, 418, 1435, 0, 0, 0, 14, 5, 40, 75, 68, 48, 201, 56, 43, 3, 147, 223, 18, 86, 56, 167, 78, 93, 146, 113, 163, 64, 222, 184, 166, 74, 171, 262, 158, 181, 107, 54, 1054, 237, 105, 96, 200, 155, 139, 43, 108, 157, 157, 260, 119, 144, 1056, 0, 189, 62, 261, 443, 395, 225, 132, 358, 221, 87, 565, 142, 1003, 199, 123, 169, 20, 236, 6, 61, 104, 188, 152, 5, 99, 22, 0, 162, 61, 77, 204, 101, 108, 394, 161, 103, 34, 48, 199, 167, 132, 198, 348, 47, 88, 105, 160, 75, 154, 365, 149, 0, 47, 101, 52, 102, 394, 90, 419, 224, 145, 113, 144, 245, 672, 159, 42, 132, 166, 110, 159, 162, 107, 114, 237, 85, 159, 53, 8, 56, 591, 122, 43, 93, 35, 80, 197, 707, 7, 2, 97, 131, 108, 41, 393, 69, 106, 209, 130, 223, 97, 158, 357, 119, 167, 514, 71, 144, 332, 355, 157, 392, 51, 102, 109, 69, 198, 551, 162, 1324, 149, 218, 992, 1006, 864, 903, 2842, 1098, 976, 3237, 1019, 3116, 7273, 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 2993, 86, 666, 110, 31, 341, 61, 3235, 28, 42, 298, 66, 120, 315, 127, 2216, 6244, 1524, 802, 194, 142, 48, 566, 1963, 165, 66, 30, 6, 1, 586, 44, 58, 173, 458, 1055, 493, 14, 136, 26, 63, 25, 497, 172, 69, 43, 32, 203, 125, 20, 62, 167, 617, 2553, 225, 112, 33, 234, 221, 30, 445, 58, 3, 1, 0, 443, 441, 5, 76, 67, 3, 0, 11, 0, 0, 0, 0, 0, 1, 0, 65, 86, 30, 123, 89, 352, 43, 172, 297, 116, 3843, 230, 14773, 222, 35, 88, 20572, 109, 7, 516, 255, 4, 3, 2, 11, 3, 1, 5, 28557, 514, 45, 894, 1082, 43, 10, 10, 2, 1, 1, 1, 1, 32, 18928, 2195, 1095, 4311, 982, 210, 3, 131, 91, 117, 46, 298, 352, 194, 122, 53, 236, 167, 37, 157, 70, 134, 354, 4838, 2461, 5217, 2915, 1429, 321, 213, 131, 203, 182, 178, 58, 138, 203, 81, 289, 65, 300, 120, 135, 104, 114, 161, 1111, 1351, 1049, 409, 287, 95, 262, 248, 77, 334, 171, 87, 282, 570, 226, 92, 160, 92, 46, 281, 5195, 413, 149, 728, 201, 1, 162, 165, 20424, 12, 4, 85, 162, 1, 141, 194, 71, 1, 28703, 138, 166, 238, 4, 157, 335, 7, 293, 10, 140, 207, 80, 141, 3, 4, 9, 42, 24, 114, 119, 117, 1, 7, 2, 168, 11, 403, 78, 22, 36, 180, 2, 25989, 594, 1032, 648, 76, 38, 265, 134, 105, 159, 116, 78, 293, 133, 5, 306, 293, 178, 133, 477, 193, 223, 263, 30, 24, 206, 472, 67, 134, 150, 480, 257, 116, 28, 491, 234, 225, 31, 164, 31, 40, 66, 130, 78, 1125, 12661, 1865, 1397, 272, 182, 313, 575, 616, 533, 466, 539, 156, 205, 158, 41, 27, 388, 153, 150, 88, 321, 746, 137, 233, 276, 116, 212, 898, 133, 311, 1, 117, 37, 498, 63, 80, 107, 289, 9, 226, 269, 80, 3, 121, 54, 56, 7, 173, 319, 741, 1, 4380, 698, 329, 406, 225, 266, 206, 138, 202, 323, 438, 80, 1035, 385, 262, 344, 689, 306, 305, 10, 88, 111, 184, 587, 73, 234, 12, 219, 254, 272, 159, 106, 101, 204, 27, 2139, 167, 261, 447, 196, 42, 643, 367, 350, 50, 462, 260, 777, 735, 133, 168, 78, 71, 91, 126, 37, 34, 91, 222, 134, 657, 1010, 476, 141, 214, 371, 166, 200, 169, 13, 14, 75, 302, 22, 218, 5, 250, 127, 108, 187, 1, 13, 57, 111, 215, 28, 9, 168, 5, 156, 330, 14, 516, 324, 223, 273, 84, 77, 183, 262, 64, 135, 39, 315, 158, 55, 448, 528, 297, 49, 362, 226, 60, 458, 267, 435, 468, 146, 232, 325, 331, 403, 121, 47, 112, 106, 197, 264, 625, 43, 187, 204, 387, 55, 1, 32, 204, 71, 225, 477, 94, 191, 459, 340, 45, 270, 185, 124, 263, 337, 363, 160, 203, 133, 178, 249, 721, 299, 334, 324, 147, 12, 117, 86, 449, 183, 206, 338, 294, 368, 63, 179, 159, 213, 241, 232, 184, 141, 54, 182, 439, 263, 130, 370, 224, 529, 126, 200, 77, 81, 157, 220, 4, 626, 11, 62, 351, 51, 78, 476, 139, 3, 15, 57, 246, 42, 141, 1013, 598, 614, 207, 372, 87, 298, 45, 208, 680, 180, 460, 416, 140, 450, 514, 79, 154, 332, 438, 226, 238, 404, 44, 142, 149, 204, 160, 349, 2, 186, 169, 93, 29, 386, 265, 27, 4, 497, 129, 139, 156, 333, 279, 136, 141, 93, 87, 212, 16, 433, 146, 736, 500, 208, 200, 50, 124, 794, 451, 271, 198, 199, 211, 88, 184, 249, 146, 14, 138, 1263, 598, 145, 239, 304, 365, 124, 50, 266, 205, 60, 472, 363, 28, 138, 423, 211, 145, 131, 268, 134, 72, 364, 206, 99, 63, 14, 2, 300, 578, 292, 318, 262, 326, 85, 383, 93, 0, 8, 70, 33, 494, 115, 621, 477, 192, 6, 0, 35, 615, 1, 542, 138, 385, 105, 438, 230, 2, 965, 106, 48, 101, 64, 101, 345, 295, 402, 222, 987, 266, 1443, 119, 438, 4, 0, 324, 1, 234, 169, 391, 25, 281, 318, 493, 293, 43, 770, 422, 206, 192, 291, 174, 114, 132, 0, 172, 104, 176, 66, 173, 720, 81, 249, 0, 8, 67, 114, 51, 9, 310, 76, 722, 467, 427, 160, 774, 282, 70, 8, 637, 0, 243, 190, 645, 54, 1027, 202, 0, 198, 136, 342, 0, 683, 391, 324, 39, 490, 484, 284, 81, 246, 165, 13, 123, 238, 136, 1553, 2646, 699, 52, 380, 302, 66, 92, 163, 145, 214, 1178, 1486, 64, 228, 155, 108, 283, 334, 38, 46, 479, 319, 3993, 665, 589, 3281, 552, 84, 597, 362, 260, 367, 222, 597, 61, 2, 172, 158, 171, 220, 186, 231, 85, 130, 1, 1735, 82, 269, 120, 106, 96, 221, 619, 912, 2226, 1469, 453, 6, 726, 237, 2, 705, 138, 461, 191, 143, 82, 61, 622, 28, 1, 393, 1932, 1080, 3, 450, 95, 250, 101, 207, 205, 124, 65, 32, 120, 112, 445, 1109, 1402, 278, 6, 132, 333, 185, 132, 175, 1, 238, 103, 650, 231, 1070, 119, 2246, 376, 207, 511, 98, 283, 1419, 270, 1, 50, 417, 275, 99, 45, 303, 4, 228, 1, 127, 177, 134, 135, 52, 187, 1079, 27, 55, 252, 2097, 633, 275, 193, 160, 187, 279, 271, 227, 185, 439, 369, 123, 350, 106, 304, 785, 207, 149, 472, 290, 224, 199, 85, 294, 341, 126, 167, 94, 1877, 278, 282, 231, 208, 322, 267, 136, 295, 146, 230, 377, 159, 59, 184, 555, 239, 5, 279, 368, 272, 208, 474, 973, 217, 356, 69, 454, 118, 333, 137, 708, 240, 133, 302, 99, 470, 107, 2, 109, 278, 176, 296, 499, 125, 142, 142, 339, 639, 407, 171, 56, 137, 374, 269, 187, 172, 1364, 62, 109, 271, 628, 261, 580, 70, 165, 107, 232, 133, 63, 241, 51, 143, 461, 206, 441, 369, 193, 206, 795, 329, 286, 388, 455, 94, 206, 915, 367, 368, 392, 176, 227, 253, 46, 499, 388, 134, 233, 463, 212, 304, 277, 119, 291, 134, 367, 113, 195, 157, 303, 227, 627, 454, 137, 418, 198, 170, 205, 640, 71, 275, 84, 197, 601, 0, 133, 332, 421, 93, 838, 176, 353, 389, 192, 1035, 451, 295, 207, 114, 365, 966, 689, 704, 828, 187, 207, 83, 1805, 0, 51, 290, 525, 113, 534, 940, 282, 524, 169, 121, 1914, 7666, 236, 289, 936, 2168, 0, 0, 207, 8234, 14830, 355, 3377, 480, 537, 358, 33, 136, 88, 39, 327, 297, 36, 76, 154, 146, 229, 28, 84, 143, 68, 227, 804, 276, 2173, 624, 4163, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 537, 5314, 463, 1000, 781, 319, 134, 71, 487, 136, 73, 113, 127, 115, 190, 71, 254, 307, 137, 890, 745, 2355, 481, 278, 44, 81, 1035, 372, 594, 283, 180, 938, 212, 385, 69, 81, 214, 169, 78, 1090, 308, 1110, 244, 1906, 649, 106, 141, 129, 289, 108, 145, 280, 138, 185, 92, 452, 213, 464, 60, 459, 194, 455, 136, 247, 262, 254, 429, 182, 235, 124, 161, 186, 32, 173, 321, 91, 67, 46, 35, 107, 279, 79, 93, 34, 425, 263, 25, 286, 211, 40, 133, 159, 117, 223, 43, 152, 180, 140, 132, 104, 64, 66, 459, 135, 76, 72, 307, 255, 278, 68, 75, 36, 261, 151, 70, 45, 80, 123, 81, 569, 159, 61, 412, 168, 27, 81, 317, 259, 83, 138, 374, 94, 47, 66, 716, 291, 270, 231, 717, 1526, 1545, 788, 1349, 1373, 705, 998, 2222, 8359, 0, 6506, 0, 19, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1165, 28, 17, 476, 192, 24, 3, 50, 522, 2063, 4534, 74, 450, 1534, 1, 3, 1, 33, 22, 31, 134, 262, 535, 27, 156, 29, 34, 21, 39, 44, 296, 51, 85, 32, 196, 25, 4, 38, 51, 140, 559, 2658, 1, 1074, 58, 132, 683, 8344, 110, 403, 110, 95, 56, 147, 47, 75, 1, 63, 126, 32, 250, 3, 59, 24, 97, 144, 216, 56, 145, 278, 61, 258, 46, 51, 134, 2174, 76, 336, 374, 125, 180, 59, 77, 25, 54, 133, 1234, 46, 301, 171, 26, 485, 288, 198, 182, 156, 76, 191, 93, 30, 42, 20, 21, 35, 200, 104, 83, 407, 251, 14, 3, 214, 150, 90, 1017, 802, 72, 132, 100, 365, 418, 652, 1, 87, 1, 794, 57, 430, 138, 115, 346, 351, 66, 100, 265, 160, 34, 30, 32, 45, 75, 144, 56, 144, 5358, 61, 96, 152, 172, 27, 111, 130, 24, 1, 55, 398, 143, 66, 40, 40, 35, 73, 71, 45, 69, 2, 103, 131, 68, 21, 27, 94, 28, 1, 21, 9, 60, 71, 96, 26, 375, 157, 57, 77, 151, 42, 148, 150, 92, 48, 76, 31, 151, 43, 21, 0, 20, 34, 12, 130, 57, 105, 57, 28, 95, 3, 75, 57, 3, 168, 23, 237, 10, 45, 13, 1, 30, 2, 13, 117, 33, 17, 1, 94, 26, 61, 84, 0, 63, 147, 110, 2, 125, 88, 93, 4, 252, 410, 108, 226, 24, 259, 335, 86, 0, 92, 136, 70, 42, 114, 27, 109, 132, 219, 147, 48, 130, 22, 0, 48, 37, 91, 54, 61, 34, 83, 88, 0, 98, 112, 50, 96, 17, 45, 20, 70, 149, 0, 68, 192, 124, 40, 0, 19, 8, 56, 53, 283, 12, 193, 0, 38, 393, 115, 410, 67, 58, 44, 56, 194, 20, 22, 13, 23, 375, 115, 172, 2, 88, 1, 88, 20, 38, 2, 320, 23, 220, 178, 85, 98, 76, 790, 219, 11, 116, 56, 113, 61, 67, 410, 75, 18, 118, 1, 53, 355, 2, 47, 0, 246, 179, 220, 194, 84, 47, 58, 12, 8, 102, 147, 303, 23, 77, 16, 103, 20, 33, 318, 201, 60, 331, 70, 2, 28, 9, 30, 307, 165, 66, 1, 97, 272, 244, 65, 104, 21, 93, 399, 393, 374, 25, 276, 211, 116, 183, 1, 21, 3, 166, 133, 159, 359, 1494, 56, 66, 809, 3, 307, 124, 148, 34, 94, 324, 2, 387, 85, 76, 57, 173, 2, 105, 47, 15, 64, 5, 165, 17, 264, 493, 132, 176, 0, 24, 452, 81, 19, 57, 164, 8, 275, 46, 142, 734, 1998, 187, 228, 7512, 1, 0, 10, 28, 17, 136, 47, 192, 1798, 0, 0, 0, 0, 0, 210, 1449, 10, 49, 287, 185, 56, 863, 2521, 24, 25, 31, 64, 85, 171, 66, 245, 24, 215, 4930, 0, 0, 0, 0, 0, 199, 46, 71, 65, 315, 1749, 20, 5, 8, 24, 4, 2, 14, 4, 10, 213, 54, 27, 30, 63, 100, 169, 135, 70, 65, 71, 444, 96, 953, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 1, 3210, 96, 517, 394, 103, 14, 103, 21, 57, 69, 1505, 56, 79, 152, 2539, 5964, 1, 385, 347, 2, 57, 39, 118, 84, 92, 787, 1375, 97, 119, 89, 709, 140, 325, 387, 54, 51, 4, 4, 20, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 56, 38, 22, 1, 58, 57, 14, 993, 975, 1, 57, 170, 18, 230, 1, 4994, 5, 1812, 582, 675, 106, 128, 3, 162, 133, 278, 120, 275, 1348, 3136, 5868, 1871, 1366, 3634, 927, 187, 637, 1113, 1362, 1, 95, 77, 78, 1, 1, 201, 62, 84, 40, 80, 6, 88, 70, 117, 164, 56, 457, 2586, 186, 160, 278, 382, 292, 92, 73, 54, 97, 43, 180, 202, 84, 151, 187, 104, 48, 161, 50, 246, 37, 181, 168, 279, 33, 75, 162, 80, 50, 4, 163, 134, 279, 1, 1, 401, 135, 102, 174, 3, 147, 437, 29, 466, 144, 5, 28, 110, 2013, 180, 87, 576, 98, 45, 1, 57, 113, 26, 90, 148, 487, 42, 161, 457, 1062, 3739, 576, 113, 313, 1151, 114, 257, 54, 104, 5, 2, 107, 91, 51, 220, 41, 159, 12, 242, 239, 16, 2, 134, 209, 476, 451, 549, 18, 429, 53, 344, 321, 2, 44, 89, 61, 231, 37, 60, 842, 93, 467, 50, 227, 30, 10, 107, 42, 188, 80, 96, 24, 246, 61, 440, 26, 84, 37, 338, 1283, 12, 433, 1030, 1156, 121, 84, 283, 60, 94, 218, 398, 527, 209, 695, 4, 43, 32, 49, 1132, 592, 62, 34, 345, 87, 74, 106, 235, 929, 76, 156, 1100, 230, 219, 94, 177, 16, 45, 146, 66, 150, 514, 57, 77, 19, 13, 56, 114, 122, 99, 164, 101, 2, 291, 150, 171, 206, 47, 70, 60, 10, 160, 10, 45, 368, 56, 153, 289, 808, 186, 317, 5, 57, 61, 339, 2, 303, 514, 8, 340, 117, 110, 313, 290, 97, 37, 162, 126, 253, 490, 151, 796, 9, 8, 55, 249, 179, 173, 155, 263, 65, 254, 406, 2, 201, 71, 63, 383, 61, 28, 326, 933, 31, 122, 207, 187, 58, 1, 123, 108, 83, 469, 57, 6, 282, 542, 50, 182, 55, 114, 151, 116, 12, 208, 144, 138, 46, 6, 11, 54, 200, 66, 7, 56, 54, 108, 70, 64, 31, 60, 76, 3, 11, 157, 80, 422, 267, 25, 115, 108, 66, 78, 43, 90, 256, 9, 281, 180, 137, 0, 65, 8, 20, 350, 79, 116, 0, 207, 64, 178, 198, 53, 431, 485, 87, 394, 56, 64, 107, 1016, 41, 9, 213, 94, 656, 7, 206, 158, 143, 6, 88, 455, 176, 216, 175, 49, 131, 181, 0, 65, 208, 205, 141, 231, 537, 149, 3, 322, 62, 24, 5, 171, 237, 424, 32, 77, 36, 48, 4, 12, 424, 157, 31, 70, 40, 106, 44, 48, 464, 625, 557, 228, 81, 81, 37, 97, 1, 56, 5, 507, 1886, 0, 304, 339, 469, 5, 57, 340, 181, 499, 475, 150, 87, 162, 367, 934, 1468, 228, 54, 61, 138, 412, 2190, 1038, 60, 102, 60, 242, 338, 381, 62, 284, 243, 2499, 112, 80, 203, 112, 223, 1597, 80, 111, 56, 212, 249, 508, 566, 241, 105, 161, 113, 173, 245, 0, 653, 840, 786, 125, 234, 411, 229, 54, 40, 650, 5443, 7069, 83, 38, 51, 144, 2, 59, 221, 132, 29, 68, 392, 275, 340, 174, 50, 127, 1, 10, 252, 70, 77, 28, 21, 122, 17, 139, 415, 23, 58, 64, 44, 23, 55, 209, 327, 181, 3560, 0, 0, 0, 0, 0, 0, 0, 0, 0, 154, 25, 85, 514, 115, 358, 249, 93, 6, 378, 190, 103, 76, 182, 153, 185, 71, 95, 85, 169, 69, 132, 583, 12, 33, 144, 282, 120, 192, 2023, 44, 37, 99, 53, 26, 37, 134, 140, 48, 56, 137, 267, 114, 0, 0, 150, 99, 19, 18, 157, 103, 0, 162, 3, 19, 87, 191, 0, 60, 17, 36, 51, 161, 39, 79, 0, 7, 59, 4, 0, 149, 149, 160, 27, 92, 27, 68, 124, 165, 0, 56, 120, 48, 92, 37, 257, 0, 0, 55, 46, 94, 74, 117, 236, 0, 2, 59, 55, 50, 50, 146, 24, 118, 49, 48, 181, 1, 159, 59, 286, 67, 157, 213, 0, 45, 11, 18, 58, 113, 66, 70, 20, 526, 0, 54, 48, 113, 36, 76, 53, 27, 84, 170, 51, 22, 47, 17, 68, 53, 69, 91, 17, 16, 55, 104, 22, 108, 82, 47, 55, 109, 339, 1208, 0, 22, 11, 67, 91, 63, 21, 22, 98, 16, 112, 188, 74, 16, 170, 86, 959, 242, 1095, 1459, 21, 2, 0, 0, 0, 0, 0, 0, 7, 1423, 121, 40, 618, 186, 23, 32, 29, 10, 14, 7, 140, 20, 359, 129, 51, 774, 1293, 3447, 8315, 1, 53, 87, 360, 952, 123, 41, 58, 134, 174, 86, 173, 60, 56, 282, 40, 24, 30, 28, 9, 15, 6, 144, 21, 173, 103, 30, 233, 128, 52, 461, 326, 968, 777, 6201, 8299, 503, 1945, 1411, 5468, 257, 959, 3894, 207, 124, 1194, 729, 389, 264, 419, 192, 252, 164, 53, 276, 179, 70, 24, 1, 1, 73, 43, 71, 858, 5756, 212, 300, 1585, 1937, 578, 1800, 118, 178, 72, 53, 137, 121, 46, 48, 228, 980, 346, 213, 159, 714, 447, 147, 117, 379, 74, 46, 8, 101, 176, 55, 1377, 4, 67, 348, 473, 828, 116, 51, 35, 30, 73, 66, 58, 227, 96, 895, 2259, 640, 191, 168, 328, 126, 41, 338, 173, 123, 76, 8, 388, 495, 94, 87, 46, 116, 93, 427, 2478, 130, 131, 101, 789, 563, 163, 199, 23, 73, 2, 36, 834, 211, 1751, 301, 969, 98, 320, 391, 77, 145, 81, 438, 6, 152, 207, 260, 112, 201, 559, 228, 295, 141, 113, 173, 2238, 119, 204, 45, 119, 45, 598, 141, 398, 422, 114, 414, 220, 95, 2, 327, 55, 197, 303, 82, 90, 198, 143, 758, 283, 220, 146, 1214, 165, 27, 180, 21, 109, 107, 2, 84, 57, 117, 59, 531, 399, 175, 2, 62, 178, 28, 289, 4, 160, 42, 37, 213, 3, 22, 120, 1258, 51, 74, 187, 155, 36, 99, 111, 250, 151, 84, 4, 138, 376, 31, 94, 99, 636, 59, 176, 62, 115, 128, 55, 84, 74, 61, 481, 7, 48, 258, 78, 460, 78, 70, 146, 650, 54, 22, 82, 177, 54, 380, 230, 108, 470, 7, 294, 153, 68, 208, 3, 94, 124, 6, 1, 5, 862, 6, 54, 443, 11, 0, 196, 318, 3, 1148, 229, 111, 166, 0, 375, 127, 67, 465, 379, 538, 374, 29, 57, 472, 1054, 523, 145, 86, 601, 142, 230, 565, 1010, 180, 694, 338, 1411, 145, 5559, 8144, 137, 1114, 166, 225, 1, 59, 154, 142, 86, 12, 2, 163, 22, 12, 29, 78, 52, 59, 61, 9, 59, 178, 83, 11, 29, 87, 24, 36, 19, 561, 364, 252, 368, 226, 4013, 0, 0, 0, 871, 70, 184, 206, 94, 135, 33, 716, 35, 85, 50, 107, 235, 169, 30, 121, 33, 50, 21, 99, 83, 138, 71, 127, 625, 118, 60, 3382, 134, 122, 246, 95, 167, 186, 78, 51, 20, 134, 67, 35, 745, 0, 95, 69, 22, 165, 0, 55, 128, 65, 190, 54, 154, 58, 144, 0, 93, 58, 69, 64, 54, 94, 32, 153, 83, 30, 75, 190, 126, 91, 166, 251, 0, 82, 84, 34, 84, 51, 13, 106, 234, 44, 94, 65, 30, 103, 242, 11, 38, 76, 122, 34, 11, 42, 81, 64, 123, 77, 51, 51, 64, 58, 20, 60, 20, 69, 94, 189, 63, 68, 166, 18, 128, 191, 54, 187, 84, 80, 85, 144, 77, 30, 86, 50, 22, 70, 50, 83, 140, 68, 143, 12, 69, 63, 90, 50, 92, 201, 123, 1127, 315, 102, 133, 1190, 129, 966, 46, 993, 638, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 26, 59398, 8241, 19141, 3096, 31954, 352, 1598, 760, 811, 3, 272, 187, 111, 15, 575, 387, 405, 39, 6, 439, 487, 2817, 25138, 1994, 2121, 15457, 1687, 23697, 440, 304, 297, 541, 394, 234, 160, 724, 591, 557, 3051, 1087, 8149, 180, 3427, 3313, 350, 673, 429, 649, 1572, 2917, 26184, 1103, 266, 864, 621, 442, 655, 287, 4706, 177, 5849, 583, 1283, 7192, 2787, 458, 459, 1653, 322, 2927, 771, 465, 396, 506, 806, 242, 857, 895, 426, 581, 6157, 599, 867, 7947, 13593, 40310, 24, 426, 228, 370, 1398, 232, 1104, 5665, 36, 1526, 397, 1132, 595, 747, 427, 590, 847, 229, 305, 812, 1, 267, 732, 1987, 620, 1333, 323, 1324, 121, 2045, 85, 773, 28, 865, 466, 866, 16, 397, 86, 507, 1399, 807, 785, 856, 393, 2694, 385, 427, 233, 580, 670, 201, 1873, 1032, 4607, 1033, 1165, 428, 440, 486, 381, 2975, 18763, 27346, 161108, 228885, 15901, 17134, 24081, 11885, 3671, 1823, 35, 1944, 2189, 4474, 307, 917, 2627, 350, 336, 38, 78, 440, 10, 6, 64, 7, 211, 9, 121, 1, 1, 29, 13, 529, 57165, 60425, 47249, 38054, 8282, 2416, 650, 221, 54, 5382, 260, 4466, 80, 1423, 1596, 1537, 18, 127, 2, 135, 135, 70, 18, 20106, 28042, 11149, 4369, 2297, 100, 1345, 266, 1601, 1928, 1780, 16, 160, 1, 62157, 23954, 3375, 1083, 2205, 1300, 1361, 1631, 716, 100960, 20388, 559, 5282, 2245, 313, 3354, 10840, 4236, 7252, 3982, 1915, 7, 19, 56, 66, 147, 100, 37, 15, 93601, 1754, 16596, 5719, 4507, 4065, 14896, 9360, 18367, 950, 7581, 6564, 1853, 4, 445, 67, 7752, 22121, 4890, 24976, 8032, 23064, 6233, 23082, 6796, 4771, 331, 5, 1124, 669, 3134, 5102, 1158, 674, 4550, 9268, 13113, 6043, 12224, 1790, 4995, 2792, 40, 4, 3164, 2402, 2529, 5517, 36, 5094, 20165, 4145, 5236, 1186, 1404, 222, 309, 19385, 2823, 3918, 3575, 3272, 473, 30484, 44882, 2155, 26602, 11389, 135, 857, 81, 132, 43467, 2652, 20818, 4410, 6, 904, 6, 188, 18365, 110067, 40347, 1493, 1647, 1349, 689, 1501, 105, 241, 111, 544, 56, 19797, 6291, 311, 1112, 195224, 2825, 6015, 2675, 2668, 790, 1160, 641, 409, 19, 17991, 160410, 50051, 3267, 1694, 18349, 13687, 4754, 1982, 1533, 3862, 1335, 1621, 695, 715, 37, 72, 511, 12, 24, 87, 36, 412, 11961, 7072, 8, 378, 1418, 113658, 8049, 3171, 28382, 16240, 1318, 7050, 1591, 1892, 1324, 1354, 459, 588, 227, 24, 14, 48, 22590, 17770, 62378, 43342, 11624, 6475, 1894, 2317, 7, 4726, 843, 956, 433, 406, 224, 71, 194, 231, 195, 32, 2889, 15247, 9044, 2734, 3047, 128, 2282, 50, 8705, 8957, 2602, 662, 448, 1412, 2414, 350, 39, 101570, 11786, 8848, 3079, 2162, 24, 2528, 677, 3292, 114, 1224, 53, 185, 346, 142, 247, 334, 71, 172, 82393, 41029, 10186, 12553, 14988, 15533, 824, 8315, 1905, 37, 1146, 2242, 119, 2384, 2099, 53, 329, 975, 104, 44, 40231, 19637, 25520, 5576, 11135, 9842, 1750, 275, 626, 138, 534, 120, 1683, 1499, 753, 344, 148, 968, 16554, 25952, 18781, 21721, 2200, 13869, 2102, 801, 147, 1728, 822, 932, 567, 789, 266, 41, 47, 7, 473, 9789, 16085, 13587, 9068, 982, 2556, 673, 684, 570, 1838, 154, 1419, 28850, 20901, 5008, 17326, 1691, 397, 3197, 981, 1055, 1511, 832, 395, 567, 1274, 23, 588, 30, 44625, 2225, 20244, 452, 4969, 388, 231, 2575, 1589, 1620, 4326, 888, 891, 2043, 8, 828, 5500, 77604, 687, 10706, 6632, 5029, 4117, 1402, 179, 9834, 2936, 2672, 1748, 2849, 10, 210, 329, 551, 2415, 1241, 1382, 687, 11738, 241, 2409, 1429, 596, 537, 630, 469, 126, 668, 11541, 16249, 25139, 14466, 20242, 13675, 2572, 30310, 11283, 1093, 7179, 20, 7237, 1949, 1237, 126, 6120, 105, 1100, 555, 1420, 916, 3606, 665, 503, 168, 1690, 6110, 899, 3324, 2831, 1172, 175, 453, 688, 9357, 5447, 1745, 5175, 1350, 2383, 1616, 5377, 1702, 30, 1543, 8, 1701, 234, 1429, 6396, 7645, 8022, 1950, 19459, 2843, 1300, 101, 2745, 796, 1347, 34, 220, 545, 164, 2259, 364, 430, 2201, 1035, 7028, 1035, 2446, 15488, 2635, 391, 2149, 2169, 12, 628, 100, 381, 313, 1136, 49, 7429, 3455, 14726, 4681, 4909, 670, 4117, 3248, 510, 85, 639, 1446, 293, 3259, 20323, 1493, 4124, 337, 2044, 605, 119, 98, 1964, 1388, 1331, 3097, 421, 1499, 2330, 603, 11547, 4918, 1154, 118, 1409, 308, 71469, 3908, 19756, 829, 15966, 9788, 2444, 3943, 39, 805, 477, 649, 1325, 398, 967, 1101, 894, 2093, 5458, 45537, 7810, 23289, 8023, 2388, 1366, 4762, 2767, 3412, 1470, 2072, 1420, 720, 1572, 190, 12861, 1911, 1258, 1133, 230, 6566, 55567, 17266, 7086, 8073, 5712, 223, 116, 118, 650, 2618, 2783, 360, 9740, 4215, 100, 396, 1578, 19, 122, 69635, 13892, 905, 15145, 9979, 4475, 1785, 802, 10, 365, 1556, 1953, 2499, 924, 3050, 1670, 2368, 3107, 0, 38363, 11487, 39375, 13239, 5674, 96, 2720, 4394, 284, 399, 3018, 816, 57, 1942, 1874, 5189, 29757, 16099, 6598, 953, 3975, 3234, 39, 1935, 586, 4222, 5472, 8165, 276, 799, 6, 566, 9, 62352, 28446, 2149, 3142, 5648, 1471, 294, 627, 1462, 1688, 198, 135, 2123, 0, 77111, 20403, 14019, 7525, 14, 101, 6, 3110, 953, 103, 764, 75425, 36117, 13336, 2860, 206, 793, 24, 315, 419, 669, 2769, 3116, 77347, 16852, 1891, 848, 959, 967, 1825, 1420, 2498, 102294, 13102, 2416, 2800, 3700, 773, 1291, 1235, 590, 1568, 4933, 7502, 75236, 265, 12970, 6428, 2206, 8579, 3189, 3736, 5299, 4564, 382, 13005, 20899, 1040, 26255, 1266, 9934, 152, 1519, 5922, 4099, 11248, 4001, 15633, 17591, 1039, 664, 4134, 2454, 2065, 1881, 4168, 9175, 3349, 10202, 9577, 4795, 1160, 1344, 2353, 1382, 1623, 2262, 2727, 4809, 2660, 5194, 1962, 2115, 1554, 8208, 7169, 1135, 2347, 2812, 1806, 5924, 7028, 1430, 3660, 2494, 3858, 3326, 14406, 2403, 2199, 9501, 13241, 0, 8890, 2612, 16217, 18356, 9645, 18946, 26510, 16873, 14556, 147268, 142647, 2527, 1274, 471, 2175, 114, 568, 825, 1103, 833, 46, 83, 24, 32, 18, 89, 85, 213, 281, 70, 31, 25, 150, 10, 438, 67, 99, 0, 593, 106, 183, 2, 160, 3, 86, 28, 128, 440, 108, 49, 224, 65, 1748, 1481, 0, 0, 0, 0, 21974, 33283, 3153, 23464, 4877, 5115, 1399, 590, 8041, 3677, 322, 1252, 1212, 1833, 689, 1838, 727, 1511, 2204, 1467, 336, 844, 316, 530, 187, 228, 126, 325, 254, 636, 150, 291, 130, 495, 288, 469, 1, 602, 68, 1007, 109, 471, 487, 1498, 1654, 1520, 2252, 2394, 2409, 2583, 4722, 864, 5096, 104, 2588, 885, 1841, 589, 140, 710, 62, 351, 1545, 383, 512, 190, 813, 384, 536, 590, 817, 493, 203, 4037, 9078, 479, 1579, 2653, 2672, 994, 894, 60, 2927, 1545, 328, 722, 2387, 910, 648, 264, 581, 537, 500, 644, 613, 390, 572, 430, 665, 293, 333, 183, 1142, 38, 3144, 473, 455, 1052, 681, 863, 513, 826, 41, 434, 31, 1036, 9025, 778, 19, 6492, 1420, 2279, 718, 4184, 3381, 489, 848, 498, 323, 405, 689, 42, 1028, 459, 366, 231, 1925, 426, 313, 85, 1534, 1666, 161, 1107, 925, 1725, 2124, 1303, 687, 267, 330, 100, 12, 417, 101, 2759, 454, 4557, 3840, 20, 1243, 1239, 653, 854, 273, 1087, 1410, 923, 189, 132, 577, 268, 80, 0, 3507, 2605, 702, 1790, 543, 724, 416, 1182, 320, 15, 47, 743, 300, 18, 11300, 1228, 1849, 1940, 4029, 2733, 334, 2182, 482, 304, 610, 725, 578, 290, 782, 467, 169, 184, 2311, 2499, 221, 7967, 1036, 1947, 2879, 1528, 211, 1136, 664, 1279, 828, 440, 131, 132, 1290, 687, 2173, 610, 47, 1233, 2177, 557, 2224, 2712, 1, 424, 5, 1769, 612, 719, 2399, 1232, 451, 475, 101, 6514, 2303, 4769, 1197, 451, 1506, 869, 3353, 3593, 4, 393, 500, 280, 15, 305, 885, 3, 843, 98, 2897, 4856, 623, 1241, 2654, 578, 396, 1318, 736, 991, 270, 689, 126, 194, 86, 573, 1420, 4065, 2253, 707, 718, 1793, 559, 490, 613, 61, 2902, 6825, 2570, 4862, 1322, 1497, 5090, 551, 836, 571, 709, 66, 257, 652, 67, 609, 176, 0, 270, 2482, 1371, 1916, 499, 722, 728, 211, 0, 940, 2158, 2189, 5597, 450, 596, 781, 120, 150, 862, 329, 444, 863, 920, 511, 2518, 3464, 91, 2677, 391, 892, 890, 717, 206, 749, 226, 563, 3175, 397, 7755, 2385, 1165, 1019, 649, 350, 950, 1640, 438, 1848, 9248, 1365, 231, 953, 1231, 1389, 381, 723, 409, 248, 413, 592, 684, 2753, 720, 4879, 382, 763, 92, 43, 18611, 1075, 814, 446, 326, 687, 189, 460, 658, 815, 910, 683, 611, 700, 335, 2618, 1558, 1559, 1317, 842, 1180, 664, 183, 704, 894, 267, 802, 48, 1204, 452, 2069, 1007, 929, 2333, 1360, 696, 247, 1025, 557, 1082, 849, 18, 770, 225, 3550, 1191, 1248, 479, 393, 412, 441, 1101, 1749, 1130, 270, 390, 1307, 301, 1023, 734, 215, 3166, 1028, 0, 678, 512, 395, 263, 695, 595, 230, 392, 780, 813, 246, 445, 825, 489, 325, 499, 186, 550, 1024, 952, 686, 666, 127, 188, 68, 837, 1230, 324, 459, 98, 556, 570, 924, 992, 1, 551, 710, 607, 582, 553, 657, 579, 1083, 679, 339, 383, 67, 1023, 814, 911, 848, 581, 684, 253, 190, 536, 17, 910, 889, 610, 847, 511, 699, 968, 552, 269, 191, 555, 334, 2658, 653, 12, 256, 1187, 836, 690, 1094, 1144, 1020, 1661, 1230, 775, 1362, 512, 658, 872, 232, 1317, 636, 512, 610, 1046, 501, 1177, 718, 151, 1742, 107, 1192, 233, 2147, 292, 814, 737, 637, 1274, 287, 205, 149, 396, 291, 553, 255, 129, 16, 1188, 430, 1047, 408, 216, 532, 909, 2532, 480, 439, 2529, 1181, 470, 392, 964, 2, 4, 576, 13, 33, 837, 6, 781, 636, 262, 498, 2905, 698, 1191, 636, 571, 670, 182, 303, 550, 1426, 290, 302, 46, 1100, 2, 648, 890, 1279, 1165, 84, 647, 67, 1428, 1094, 189, 931, 13, 748, 1691, 531, 328, 1190, 531, 498, 863, 721, 844, 1196, 923, 580, 1376, 66, 552, 108, 268, 530, 308, 600, 425, 1138, 908, 683, 895, 1080, 1127, 1033, 2076, 2802, 1051, 1797, 1426, 1801, 190, 127, 2715, 6998, 4940, 191, 6849, 1456, 4046, 5743, 1211, 8020, 1631, 5008, 5840, 15599, 4915, 4939, 18325, 8921, 19159, 4673, 115448, 677, 3, 2, 0, 0, 0, 0, 0, 0, 0, 13, 2, 1, 0, 0, 0, 0, 0, 106, 35171, 2637, 420, 2282, 1567, 1622, 211, 3024, 1191, 483, 4, 183, 928, 1074, 574, 947, 64, 579, 38, 136, 240, 96, 989, 572, 6, 649, 469, 1263, 3245, 7448, 41583, 8197, 1146, 332, 763, 472, 343, 1451, 2699, 2096, 888, 143, 131, 382, 484, 192, 207, 1656, 5647, 14754, 1549, 178, 730, 243, 2651, 149, 607, 1015, 2006, 33, 984, 399, 586, 75, 344, 651, 94, 885, 718, 212, 735, 150, 872, 1426, 3817, 338, 652, 647, 1180, 3687, 17, 4, 35, 889, 439, 3, 2, 2, 179, 130, 13, 0, 929, 980, 96, 575, 648, 1593, 77, 35, 31, 580, 890, 39, 137, 241, 130, 97, 1292, 813, 485, 280, 292, 7, 650, 470, 193, 391, 479, 738, 2895, 4858, 229, 20206, 863, 107286, 69659, 19208, 16861, 20205, 26376, 30070, 50768, 459, 3063, 149, 349, 173, 206, 609, 156, 43, 1, 18, 41, 31, 25, 277, 275, 2, 13891, 7802, 8539, 13670, 13735, 12118, 1, 66, 2399, 3822, 10146, 9388, 6821, 561, 4, 13, 4251, 3030, 6497, 13118, 199, 12, 8080, 7962, 20836, 3, 38118, 22602, 106, 534, 20, 102582, 873, 562, 621, 57, 1109, 107, 48, 29734, 180947, 3466, 8241, 2456, 1622, 1306, 146, 1714, 66, 58, 52, 93, 98, 174, 10, 44, 105, 11, 95, 28810, 910, 1394, 107, 68120, 100964, 10574, 13169, 6383, 8229, 146, 1278, 801, 105, 858, 51, 1555, 242, 320, 311, 197, 311, 139, 129, 13, 103, 108, 282, 118, 647, 68, 53236, 5619, 6820, 2412, 4026, 725, 213, 256, 60, 63201, 41823, 30721, 17596, 655, 1159, 1608, 1305, 143, 882, 526, 986, 180, 2227, 461, 247, 68, 737, 200, 308, 47, 38, 92, 23, 5, 1, 42541, 21518, 11192, 2763, 745, 691, 758, 812, 715, 5, 178, 494, 176, 700, 67421, 23361, 2112, 1810, 1492, 1718, 2201, 581, 1962, 1307, 533, 36, 6, 851, 55, 393, 88, 145, 89, 114, 113, 21, 93391, 1027, 9780, 6482, 1112, 876, 2306, 1922, 2315, 4277, 525, 76, 397, 9, 5, 59, 1550, 586, 420, 536, 126, 1529, 807, 68, 504, 56, 3, 6805, 44493, 33684, 14619, 7606, 4662, 1535, 7010, 11198, 3384, 1487, 2258, 1003, 538, 795, 1467, 9, 1011, 36, 101, 3334, 3824, 1553, 381, 1980, 65, 439, 493, 307, 725, 7, 210, 1487, 30, 3458, 1377, 2008, 690, 612, 585, 1838, 45, 147, 20545, 4359, 4030, 7017, 695, 11613, 5634, 3425, 101, 281, 375, 1047, 2982, 2226, 204, 386, 495, 810, 277, 796, 50, 11, 12079, 5637, 4971, 3569, 11455, 6709, 6198, 1488, 1100, 4448, 15, 1437, 583, 966, 3851, 899, 447, 99, 613, 443, 2643, 6014, 2774, 6870, 5034, 421, 676, 3023, 750, 1413, 406, 707, 2004, 2269, 1018, 41, 155, 589, 66, 780, 1, 1046, 1893, 4908, 3614, 1447, 556, 1596, 1341, 1784, 795, 2127, 2629, 277, 1227, 74, 144, 5061, 6958, 2573, 1979, 759, 1626, 12, 401, 273, 2530, 602, 3448, 1278, 52, 545, 269, 8978, 451, 25, 406, 1923, 694, 495, 15154, 11035, 1306, 300, 3545, 1563, 2709, 13, 2783, 732, 189, 4399, 8618, 7480, 555, 201, 103, 157, 614, 633, 41, 498, 9029, 5352, 1353, 3884, 2980, 2661, 1189, 262, 1564, 273, 3824, 1704, 935, 7427, 3384, 1697, 6161, 1144, 410, 449, 1971, 496, 450, 132, 902, 788, 2147, 6412, 2514, 1683, 2359, 65, 14, 1824, 1104, 1573, 1442, 4284, 252, 6188, 1695, 2114, 2612, 2017, 232, 6, 19, 59, 97, 1199, 2487, 315, 1278, 526, 1120, 1472, 933, 994, 5340, 1464, 880, 541, 1350, 707, 357, 158, 72, 665, 1368, 301, 1313, 1172, 437, 296, 42, 27, 2131, 3225, 526, 467, 2199, 3991, 5743, 806, 1578, 924, 198, 897, 56, 1504, 2453, 442, 1623, 714, 500, 1342, 2661, 2047, 39, 373, 963, 751, 1511, 4870, 620, 1395, 1487, 1188, 1615, 988, 3347, 4198, 1783, 1047, 715, 402, 827, 557, 15, 1277, 1412, 12, 14, 20, 794, 24, 261, 917, 520, 2350, 407, 1027, 1712, 2552, 2036, 852, 227, 14, 1163, 433, 2524, 1121, 35, 1962, 465, 716, 565, 2459, 1273, 1395, 25, 375, 4, 39, 358, 13, 2877, 564, 5591, 11, 885, 1234, 12, 188, 524, 3771, 15617, 13476, 2111, 2034, 1896, 613, 260, 196, 514, 257, 258, 819, 97, 88, 335, 523, 760, 408, 535, 2871, 1497, 897, 1512, 253, 524, 22009, 16475, 8502, 12441, 12329, 908, 2629, 2821, 9171, 4474, 1363, 627, 2588, 40, 281, 1043, 13735, 15557, 11175, 7381, 2856, 623, 8957, 4044, 4009, 1124, 181, 429, 9668, 7586, 1492, 1907, 8653, 6883, 2545, 1031, 249, 40, 325, 550, 13822, 2091, 3686, 3244, 8638, 532, 8156, 7245, 5119, 156, 1801, 17657, 590, 12621, 3091, 15641, 5642, 2670, 505, 260, 1045, 669, 1203, 1430, 691, 461, 20106, 1637, 18635, 4937, 2320, 1671, 624, 9, 1066, 37, 2293, 4507, 984, 42, 2368, 45985, 12960, 2770, 481, 2407, 533, 435, 751, 6348, 4168, 839, 851, 18, 64284, 38157, 6225, 16354, 4367, 973, 3341, 1034, 67148, 4726, 14779, 6862, 4546, 10033, 7216, 24834, 63905, 10873, 6746, 17029, 3393, 29616, 4448, 900, 1774, 1551, 56602, 24833, 41561, 11393, 17755, 45610, 26286, 47006, 9671, 172858, 6, 112318, 34, 73, 252, 63, 282, 416, 39, 844, 1, 3, 47, 38, 1, 207, 4, 1, 120, 6, 29, 144, 24, 33, 3, 116, 54, 446, 89, 292, 230, 269, 5001, 0, 0, 0, 0, 14786, 1355, 3311, 4157, 551, 4981, 7598, 643, 2697, 1560, 305, 1774, 287, 497, 6107, 3899, 1821, 620, 47, 791, 583, 316, 1443, 1414, 834, 1215, 1820, 1157, 236, 943, 374, 616, 667, 232, 434, 217, 466, 770, 1517, 1415, 404, 140, 133, 300, 455, 995, 275, 1166, 301, 6, 47, 624, 355, 1188, 726, 407, 352, 4109, 4539, 19737, 0, 2529, 784, 498, 2449, 1886, 1922, 915, 97, 248, 378, 439, 691, 249, 133, 1524, 962, 405, 157, 664, 352, 338, 628, 372, 33, 1040, 1050, 818, 399, 74, 1013, 783, 251, 476, 1742, 503, 391, 783, 202, 2, 549, 404, 625, 356, 239, 924, 1916, 922, 913, 335, 1, 310, 2852, 305, 671, 2354, 1470, 624, 150, 511, 394, 1, 455, 403, 247, 110, 245, 590, 902, 644, 1666, 250, 546, 1813, 454, 814, 182, 1039, 1811, 489, 781, 229, 441, 896, 778, 238, 888, 304, 722, 1708, 513, 1497, 547, 670, 287, 498, 4312, 3048, 549, 1981, 664, 655, 774, 997, 605, 470, 1557, 188, 3495, 197, 389, 442, 1617, 4597, 1053, 902, 197, 163, 714, 185, 453, 1403, 740, 38, 246, 283, 343, 302, 1335, 720, 371, 1009, 1016, 1416, 688, 409, 266, 952, 447, 228, 212, 445, 475, 703, 629, 380, 545, 623, 957, 548, 1865, 180, 345, 719, 405, 901, 1077, 592, 0, 720, 665, 372, 4, 1202, 1008, 657, 1318, 1075, 1765, 565, 5, 663, 1030, 237, 249, 1139, 1385, 913, 501, 48, 656, 140, 1380, 540, 404, 584, 1061, 1348, 308, 1470, 544, 1037, 315, 62, 1007, 290, 432, 339, 1108, 0, 1942, 584, 890, 1727, 902, 368, 153, 4851, 1729, 547, 246, 184, 813, 28, 452, 4296, 773, 1046, 1005, 1073, 3, 243, 160, 486, 334, 891, 0, 1120, 914, 301, 1744, 1247, 635, 955, 302, 510, 247, 747, 263, 1646, 1827, 505, 45, 622, 387, 529, 1016, 1172, 449, 814, 457, 2393, 1223, 5186, 546, 667, 481, 593, 1157, 772, 715, 336, 195, 632, 247, 771, 1047, 942, 634, 770, 782, 1499, 438, 301, 373, 666, 545, 119, 617, 564, 410, 259, 544, 1016, 509, 769, 1048, 233, 353, 246, 543, 433, 717, 301, 225, 718, 247, 1038, 229, 544, 1006, 545, 299, 720, 248, 30, 546, 746, 335, 565, 467, 547, 298, 914, 741, 337, 321, 715, 548, 198, 1648, 692, 647, 510, 1177, 668, 455, 4805, 721, 722, 299, 1449, 768, 680, 25, 735, 627, 720, 431, 767, 32, 298, 583, 230, 719, 819, 402, 5, 547, 765, 718, 509, 139, 1238, 313, 235, 86, 979, 1243, 545, 915, 127, 173, 764, 768, 1245, 538, 733, 818, 274, 717, 745, 763, 297, 248, 454, 1728, 716, 621, 761, 300, 714, 760, 713, 247, 402, 5, 913, 46, 1738, 953, 215, 211, 930, 449, 1548, 1547, 759, 246, 1651, 851, 1455, 707, 179, 1185, 803, 5070, 1891, 1181, 480, 242, 1358, 2084, 1245, 2294, 395, 1639, 1949, 1486, 5994, 2668, 1244, 2473, 4407, 17538, 26411, 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 27, 30132, 1705, 1246, 2024, 1115, 977, 363, 1189, 762, 1728, 127, 207, 4, 90, 2178, 1123, 6137, 31074, 5342, 5, 2, 1, 2, 1, 1, 6, 10, 1645, 774, 2171, 1886, 606, 1286, 272, 201, 264, 3749, 16896, 531, 129, 67, 737, 2080, 357, 562, 106, 1172, 190, 229, 949, 325, 172, 47, 511, 1978, 354, 423, 341, 866, 2011, 667, 53, 389, 1384, 28, 230, 763, 3970, 128, 208, 326, 273, 2, 91, 440, 2701, 298, 2199, 13102, 193, 82715, 4, 34487, 5185, 2859, 3005, 20113, 286, 495, 101, 189, 1172, 2029, 1145, 570, 471, 560, 853, 6, 1772, 231, 855, 195, 377, 2, 81, 190, 29, 453, 379, 355, 449, 325, 596, 3033, 4429, 1951, 6, 5452, 1899, 2165, 576, 3110, 218, 119, 1955, 197, 1734, 438, 135, 43, 689, 49, 15, 1218, 344, 3236, 6406, 371, 512, 772, 119, 67, 70, 297, 6, 207, 231, 2, 19, 257, 3342, 773, 712, 9235, 608, 874, 150, 533, 215, 3, 455, 1031, 221, 250, 1149, 187, 361, 317, 394, 843, 579, 747, 640, 2584, 774, 2406, 1143, 545, 519, 663, 1010, 75, 84, 202, 132, 661, 206, 12, 162, 2272, 822, 712, 691, 208, 189, 97, 204, 427, 939, 853, 980, 1257, 603, 471, 31, 445, 937, 60, 1702, 184, 165, 377, 366, 127, 369, 441, 1884, 962, 252, 1180, 554, 637, 798, 669, 3157, 966, 10, 28, 1381, 1301, 2633, 1223, 978, 412, 300, 3434, 2725, 1225, 586, 1180, 447, 506, 1133, 137, 541, 1665, 802, 254, 567, 160, 899, 102, 886, 609, 963, 287, 253, 319, 863, 875, 496, 253, 555, 534, 11, 216, 180, 4, 604, 1000, 210, 799, 1122, 98, 195, 459, 136, 179, 553, 300, 9, 6, 1141, 534, 38, 407, 1032, 25, 42, 483, 79, 800, 572, 670, 149, 135, 7, 786, 222, 604, 782, 900, 208, 772, 964, 823, 1901, 232, 365, 858, 325, 378, 1287, 155, 295, 567, 9, 533, 753, 325, 378, 100, 1, 8, 82, 463, 771, 188, 191, 294, 28, 872, 1, 326, 360, 787, 149, 318, 1, 7, 6, 400, 0, 1259, 925, 713, 395, 354, 185, 141, 338, 1258, 505, 310, 578, 221, 92, 13, 797, 800, 1273, 506, 194, 0, 147, 600, 595, 963, 2594, 268, 544, 8, 267, 323, 712, 487, 1348, 667, 19, 10, 1382, 222, 3149, 303, 2853, 2721, 1219, 2160, 554, 670, 787, 375, 1489, 316, 84, 11, 15, 0, 16, 1, 2087, 408, 1279, 251, 302, 692, 722, 387, 306, 457, 1206, 413, 221, 5, 299, 302, 603, 5592, 1251, 337, 3820, 683, 3124, 1840, 876, 198, 2004, 1918, 992, 464, 14, 75, 112, 27, 2747, 334, 6857, 533, 2841, 925, 106, 886, 289, 1031, 4, 2671, 1135, 118, 293, 519, 54, 530, 3899, 356, 1092, 377, 221, 566, 2044, 2545, 6, 28, 749, 335, 575, 1259, 339, 929, 826, 8127, 874, 3789, 287, 114, 365, 965, 199, 4798, 4346, 523, 4, 198, 12, 0, 1074, 529, 982, 809, 1539, 42, 565, 693, 721, 347, 480, 1692, 4804, 730, 646, 1093, 720, 1235, 7135, 5891, 78, 209, 792, 898, 873, 197, 1132, 0, 832, 846, 1657, 492, 1171, 200, 1564, 580, 6248, 3309, 98, 726, 8, 711, 791, 100, 294, 1142, 931, 76, 1390, 134, 362, 414, 2494, 44, 1870, 234, 1388, 1362, 3484, 376, 1086, 1256, 610, 1493, 115, 26, 233, 722, 1486, 479, 1053, 5455, 201, 1591, 4117, 1286, 5675, 2990, 5, 51554, 230, 1988, 729, 1116, 29, 28, 301, 11, 141, 265, 619, 56535, 26041, 12292, 485, 1477, 2036, 2333, 1098, 2135, 1140, 537, 31, 1, 31, 146, 66, 985, 575, 725, 217, 15, 33419, 16101, 183, 3113, 4587, 2332, 2086, 119, 420, 140, 80, 155, 62, 9, 37870, 906, 3675, 6771, 5371, 4706, 1690, 742, 648, 153, 257, 123, 29, 375, 2, 186, 121, 32, 5603, 12075, 13696, 14533, 12643, 7496, 1103, 419, 432, 56, 352, 492, 26, 16, 10, 31, 1283, 980, 1677, 1267, 1259, 533, 3536, 9179, 3653, 2195, 150, 25, 98, 32, 11960, 9109, 7118, 517, 660, 439, 20, 321, 8, 180, 29, 34626, 10516, 2513, 2102, 607, 333, 54, 315, 43332, 15681, 4484, 2075, 154, 1139, 455, 381, 498, 219, 217, 399, 151, 11, 180, 219, 35, 130, 377, 52143, 12720, 3295, 203, 1298, 613, 305, 1472, 966, 1, 7, 8, 806, 48, 161, 686, 394, 425, 48, 14, 292, 313, 342, 759, 1167, 42797, 8348, 3728, 4413, 532, 2868, 1815, 319, 315, 922, 11, 1692, 251, 1187, 82, 267, 11, 423, 200, 161, 283, 344, 130, 505, 540, 995, 1066, 1099, 18399, 5267, 10700, 11, 2126, 6936, 722, 1141, 297, 583, 780, 2137, 195, 203, 1911, 204, 594, 371, 546, 345, 460, 1281, 254, 179, 2722, 423, 793, 619, 3126, 1792, 6119, 6490, 816, 1884, 3459, 2214, 692, 1527, 2063, 586, 154, 242, 228, 671, 870, 12, 1034, 1181, 354, 1436, 195, 138, 802, 823, 4005, 57, 1825, 2381, 823, 1172, 730, 559, 805, 1355, 565, 155, 618, 85, 264, 96, 3000, 7610, 535, 2289, 313, 1702, 455, 1252, 845, 1296, 249, 383, 688, 139, 33, 243, 720, 1216, 110, 436, 820, 1048, 3159, 614, 815, 58, 15, 3391, 1042, 415, 742, 1144, 560, 332, 306, 1444, 320, 206, 302, 118, 4236, 2633, 1304, 612, 2139, 1490, 2032, 803, 178, 446, 1031, 3, 1001, 397, 1056, 248, 597, 783, 302, 964, 183, 384, 298, 2008, 2465, 1292, 646, 61, 216, 195, 705, 124, 895, 688, 477, 262, 556, 7, 917, 1400, 1160, 208, 1708, 946, 502, 1848, 638, 464, 466, 676, 144, 425, 528, 630, 464, 507, 306, 412, 5, 169, 578, 459, 223, 304, 123, 1770, 926, 1199, 667, 615, 353, 298, 677, 794, 1510, 15, 981, 301, 296, 334, 8, 323, 48, 2683, 51, 499, 10, 728, 903, 2073, 30, 545, 857, 374, 1233, 1040, 249, 968, 1100, 1146, 1256, 1298, 1264, 804, 924, 370, 671, 236, 1034, 133, 752, 469, 215, 489, 496, 548, 261, 663, 1049, 618, 1250, 489, 609, 1145, 498, 802, 194, 386, 212, 319, 960, 145, 564, 14, 84, 927, 75, 528, 1346, 816, 395, 315, 445, 47, 81, 241, 727, 1404, 595, 465, 5, 1360, 337, 1279, 2068, 845, 312, 446, 738, 884, 1211, 4, 652, 902, 46, 1144, 648, 1532, 203, 13, 803, 980, 495, 835, 218, 490, 503, 1085, 630, 1364, 1063, 665, 825, 188, 778, 893, 1228, 1368, 78, 371, 1001, 493, 152, 1362, 152, 228, 1047, 1043, 258, 650, 1156, 875, 1593, 422, 871, 349, 129, 1243, 923, 668, 1981, 1265, 331, 900, 755, 607, 2048, 578, 1170, 305, 791, 2118, 366, 1686, 1099, 2005, 1911, 1001, 2530, 1742, 452, 319, 447, 1442, 1082, 2528, 514, 1699, 191, 892, 865, 451, 3575, 2730, 1600, 695, 760, 495, 2144, 1069, 5607, 3028, 3695, 9925, 3969, 3208, 4380, 3296, 896, 1, 4581, 10252, 3188, 19759, 12971, 78108, 29980, 156, 63, 33, 12, 14, 11, 0, 4583, 10, 0, 1900, 561, 872, 160, 533, 786, 109, 1136, 23164, 232, 1801, 0, 62, 553, 309, 73, 812, 2, 172, 848, 807, 110, 1218, 41660, 3017, 4368, 1778, 140, 638, 10265, 798, 1875, 2007, 5997, 671, 6496, 15047, 6311, 16, 78, 42, 94, 234, 79, 1, 42, 1, 1, 2187, 2417, 1023, 910, 1235, 7365, 1017, 1614, 515, 2337, 3221, 4923, 11565, 1490, 10, 867, 1926, 675, 85, 451, 242, 969, 39, 1698, 503, 1411, 323, 41, 1374, 1817, 466, 9, 399, 683, 499, 704, 448, 84, 25, 568, 141, 344, 637, 136, 872, 224, 806, 288, 1340, 5720, 138, 3816, 9275, 1388, 730, 2264, 788, 8, 1420, 287, 805, 1868, 120, 919, 666, 836, 4335, 140, 3062, 5908, 8904, 202, 3328, 5294, 119, 27857, 1078, 87663, 12, 5, 1855, 705, 178, 42, 325, 913, 553, 7277, 60, 795, 19, 759, 601, 657, 19, 204, 569, 224, 423, 222, 624, 99, 84, 457, 337, 1151, 24, 803, 730, 10623, 33869, 1937, 0, 0, 235, 14, 98, 184, 320, 282, 719, 58, 421, 224, 25, 91, 64, 149, 43, 59, 236, 271, 42, 229, 797, 136, 433, 118, 21, 463, 485, 8, 0, 111, 389, 139, 69, 491, 2227, 3800, 100, 0, 97, 7, 61, 791, 7, 1, 20, 483, 384, 600, 656, 20, 228, 203, 569, 165, 135, 59, 424, 164, 223, 475, 149, 558, 390, 98, 83, 456, 476, 220, 611, 585, 25, 246, 1338, 1053, 17619, 267, 66624, 4, 110601, 14995, 12318, 3958, 3184, 2273, 2814, 2539, 7809, 4769, 6301, 2680, 1962, 713, 36, 125, 44, 35, 56, 40, 56, 33, 24, 151, 200, 166, 174, 2, 2, 23908, 24527, 14959, 3357, 4836, 4138, 5075, 12148, 6110, 8132, 1590, 1634, 191, 347, 17, 9194, 6620, 5218, 432, 1366, 6276, 4039, 3360, 2146, 322, 11, 12030, 7770, 3444, 1346, 5050, 7598, 2886, 4913, 58, 702, 126, 150, 71, 11152, 2806, 1319, 2217, 9821, 6776, 2062, 1004, 480, 5499, 2682, 6504, 9575, 2765, 3667, 46, 784, 3432, 8478, 4522, 1101, 569, 3392, 7512, 550, 1107, 975, 6, 16255, 6120, 4066, 1411, 904, 610, 206, 59, 46145, 28472, 8080, 1646, 199, 528, 270, 53, 282, 16, 11, 62751, 16221, 4336, 1120, 324, 29, 31, 33, 8, 48, 21, 95029, 23169, 5385, 211, 208, 236, 145, 17, 254, 40, 254, 233, 453, 93, 33, 159, 414, 4, 115790, 82, 9064, 689, 1219, 1568, 110, 129, 348, 273, 301, 111, 55, 11, 139, 98, 297, 10, 10045, 103518, 4072, 910, 4134, 4781, 8178, 4471, 1431, 831, 991, 561, 474, 612, 655, 727, 40, 56, 712, 35, 20, 230, 450, 163, 511, 571, 309, 1387, 578, 136, 9878, 261, 200, 10000, 7668, 16967, 26453, 26571, 9749, 3683, 5445, 8130, 1259, 1204, 1635, 1592, 2068, 2618, 1402, 450, 77, 143, 6, 1034, 426, 832, 180, 256, 1284, 490, 22, 1474, 5122, 4125, 904, 361, 338, 870, 94, 1019, 2580, 1032, 4531, 1832, 194, 240, 280, 73, 10217, 7322, 2574, 1841, 212, 524, 637, 203, 6, 390, 25476, 10943, 2233, 325, 2289, 943, 898, 143, 246, 1729, 407, 219, 529, 1822, 20, 553, 241, 650, 348, 37126, 6576, 7122, 2995, 4311, 1264, 1606, 3649, 2651, 2671, 684, 1339, 545, 760, 1024, 336, 833, 394, 37, 2177, 11, 307, 9459, 8255, 9022, 5386, 5684, 5840, 6064, 7322, 406, 1468, 2262, 54, 1350, 123, 39, 1070, 46, 535, 180, 1464, 31, 10, 3187, 1370, 867, 1031, 3229, 4203, 1108, 2090, 1565, 1920, 214, 168, 700, 732, 230, 67, 885, 871, 1147, 253, 410, 137, 149, 6708, 2464, 2416, 2380, 486, 702, 2166, 1134, 2057, 529, 2081, 1040, 549, 353, 928, 521, 578, 36, 4312, 2155, 6972, 5420, 3495, 1533, 1261, 992, 518, 2175, 273, 1053, 1143, 816, 23, 41, 1779, 2643, 4957, 4019, 1843, 1215, 370, 173, 47, 387, 702, 493, 173, 944, 336, 41, 307, 1261, 4854, 3648, 1814, 1754, 899, 1993, 971, 8033, 8898, 3330, 266, 1215, 1148, 1279, 157, 542, 630, 608, 372, 41, 743, 31, 13805, 9207, 2520, 1659, 3088, 721, 1827, 3051, 1337, 1283, 524, 399, 336, 1939, 31, 13, 13722, 8239, 2966, 5906, 1220, 5313, 2302, 2733, 2257, 566, 263, 612, 3798, 173, 383, 575, 641, 512, 5625, 4048, 9656, 1609, 5013, 1960, 2769, 2178, 340, 603, 614, 479, 518, 309, 4109, 1867, 26, 2284, 3245, 3092, 2358, 3899, 1182, 3746, 1235, 815, 1635, 588, 2441, 5, 508, 34, 1464, 1406, 2694, 606, 4005, 166, 567, 1812, 798, 272, 2324, 5215, 6698, 4487, 2593, 3139, 29, 328, 713, 2421, 1287, 1846, 1411, 900, 369, 80, 4332, 681, 3043, 4612, 1287, 1367, 818, 1595, 335, 603, 12, 6500, 6739, 2844, 1545, 504, 584, 709, 1247, 1500, 2473, 1645, 3783, 406, 1273, 2013, 1969, 452, 45, 183, 5935, 1691, 2088, 902, 2050, 3158, 759, 631, 5267, 653, 560, 907, 1213, 70, 4386, 4896, 719, 103, 796, 2772, 793, 1624, 1606, 712, 662, 12283, 889, 447, 2842, 955, 357, 3203, 2345, 1122, 421, 314, 1137, 789, 1705, 897, 844, 15049, 1668, 1369, 948, 707, 1392, 172, 916, 1985, 994, 356, 7674, 339, 1757, 4, 473, 1543, 505, 1101, 949, 1071, 2882, 512, 602, 1223, 91, 741, 1117, 1636, 4359, 708, 2910, 2060, 298, 604, 814, 5739, 569, 3854, 1368, 765, 758, 66, 1248, 2336, 2602, 1118, 6201, 922, 1540, 819, 694, 445, 693, 478, 7175, 536, 1813, 38, 567, 6895, 1117, 1187, 896, 2630, 1227, 308, 3826, 335, 816, 813, 827, 3869, 4853, 13367, 14444, 71969, 1153, 741, 570, 1312, 787, 4542, 2485, 1881, 2325, 4960, 16601, 190, 582, 1821, 499, 21435, 3653, 1618, 5545, 1145, 26268, 10069, 11262, 64734, 32887, 1136, 1217, 17059, 13057, 777, 10388, 1443, 13322, 3255, 122827, 106878, 1075, 324, 222, 4, 292, 3, 276, 13, 51, 9, 148, 25, 77, 99, 81, 4, 3, 5, 43, 6, 3, 8, 9, 3, 24, 2, 32, 32, 208, 354, 18, 337, 91, 435, 0, 0, 0, 63131, 10751, 4248, 547, 499, 439, 2056, 2179, 101, 1271, 2372, 549, 201, 132, 2733, 446, 375, 3, 2643, 216, 356, 253, 318, 616, 81, 1210, 1287, 396, 235, 76, 203, 210, 266, 151, 293, 80, 164, 33, 97, 226, 528, 586, 2016, 81, 346, 0, 16214, 5386, 1392, 2462, 354, 2418, 8468, 569, 2521, 6997, 788, 473, 587, 405, 1110, 287, 1502, 527, 292, 807, 708, 602, 352, 1121, 416, 420, 331, 222, 329, 239, 783, 59, 455, 8, 283, 260, 315, 391, 820, 1447, 169, 81, 543, 0, 0, 2340, 1400, 1847, 1277, 4734, 1764, 4368, 758, 1565, 209, 539, 489, 1624, 1025, 439, 353, 311, 183, 7, 354, 38, 181, 189, 195, 574, 295, 137, 0, 304, 466, 1473, 2203, 1800, 175, 1321, 589, 280, 387, 1231, 72, 595, 191, 304, 368, 304, 99, 6, 822, 568, 1333, 215, 420, 262, 9, 1259, 1007, 416, 5, 274, 114, 911, 210, 320, 274, 353, 450, 3119, 679, 861, 200, 465, 416, 360, 113, 11, 85, 3, 786, 1209, 4630, 562, 677, 91, 1695, 1563, 602, 293, 1653, 1928, 1931, 143, 884, 1053, 1592, 533, 162, 363, 85, 89, 374, 51, 56, 161, 0, 212, 1032, 785, 209, 102, 2, 1990, 2658, 435, 444, 1245, 843, 1243, 202, 232, 56, 129, 243, 551, 1122, 2667, 62, 790, 1189, 6558, 2163, 497, 354, 3381, 637, 1369, 492, 310, 2, 110, 189, 3, 225, 185, 75, 22, 288, 464, 578, 181, 81, 1483, 557, 2235, 191, 351, 208, 174, 678, 417, 202, 550, 472, 784, 330, 92, 14, 734, 1507, 1985, 891, 214, 1380, 495, 1531, 1204, 776, 670, 221, 316, 2, 192, 0, 225, 593, 193, 48, 0, 549, 1099, 388, 1296, 3, 555, 485, 2272, 143, 449, 8, 61, 355, 1954, 538, 551, 434, 598, 46, 273, 84, 263, 81, 647, 572, 694, 789, 1053, 109, 179, 380, 24, 1113, 1188, 495, 1553, 18, 26, 76, 4090, 1296, 1377, 1183, 3866, 3756, 4412, 2220, 701, 272, 317, 464, 306, 279, 783, 366, 701, 29, 0, 0, 1863, 1094, 5011, 3459, 1173, 942, 329, 143, 18, 538, 1186, 1247, 489, 268, 145, 80, 213, 357, 1265, 1324, 3095, 506, 423, 99, 275, 152, 3, 1123, 3793, 229, 544, 261, 554, 693, 10109, 3162, 2943, 3010, 1124, 201, 266, 610, 1, 176, 45, 166, 370, 656, 578, 83, 369, 90, 110, 0, 16807, 10814, 1693, 1223, 672, 460, 583, 312, 59, 283, 845, 492, 6, 339, 1, 59, 433, 214, 342, 560, 943, 125, 15541, 4581, 4237, 1629, 492, 1004, 140, 142, 544, 189, 526, 510, 332, 260, 71, 797, 42, 80, 0, 11385, 5297, 450, 348, 2354, 203, 549, 383, 421, 161, 142, 617, 581, 148, 1425, 1620, 310, 41, 197, 260, 393, 1357, 1278, 1219, 521, 405, 2341, 941, 3026, 250, 311, 0, 0, 12199, 519, 221, 569, 593, 584, 786, 458, 542, 164, 1353, 199, 220, 431, 1071, 1935, 290, 266, 61, 0, 1295, 2907, 5158, 397, 1585, 1020, 466, 205, 779, 354, 740, 538, 948, 671, 691, 377, 409, 1904, 511, 348, 2092, 1597, 701, 672, 792, 596, 576, 4, 402, 764, 107, 560, 132, 428, 0, 549, 331, 447, 736, 753, 553, 491, 603, 346, 1792, 1073, 671, 849, 351, 565, 2166, 529, 379, 79, 345, 396, 494, 200, 1169, 582, 688, 139, 1, 342, 190, 1000, 386, 1176, 344, 313, 270, 313, 378, 75, 1019, 204, 204, 60, 345, 267, 202, 463, 330, 222, 493, 223, 384, 570, 141, 100, 261, 21, 1018, 109, 587, 1083, 527, 546, 465, 420, 305, 317, 57, 585, 162, 7, 141, 534, 341, 1, 670, 848, 616, 189, 791, 526, 507, 758, 39, 199, 272, 792, 778, 287, 443, 648, 1426, 595, 344, 352, 260, 791, 674, 8, 238, 362, 292, 493, 492, 203, 20, 782, 79, 797, 350, 91, 1017, 457, 419, 530, 777, 564, 188, 5, 453, 545, 422, 541, 832, 350, 167, 58, 6, 180, 444, 858, 1016, 1501, 1523, 278, 590, 23, 8, 544, 537, 316, 23, 163, 521, 615, 259, 175, 9, 2, 947, 56, 465, 670, 1, 309, 1175, 108, 690, 40, 3, 717, 569, 539, 645, 1399, 1423, 748, 408, 196, 0, 790, 1645, 220, 501, 563, 1523, 398, 7, 1238, 244, 197, 2350, 282, 291, 329, 58, 813, 553, 576, 219, 2606, 1051, 501, 4668, 2071, 5691, 2145, 2405, 157, 1587, 6866, 5229, 3000, 410, 21, 2998, 3352, 4814, 82, 27819, 9581, 162, 638, 349, 55294, 1388, 614, 31895, 49866, 14640, 0, 30007, 2337, 82833, 0, 56, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 38, 6639, 4194, 3949, 540, 700, 495, 2874, 281, 11543, 777, 361, 99, 521, 209, 269, 955, 127, 159, 154, 17187, 541, 184, 348, 602, 138, 7, 222, 343, 512, 378, 721, 1435, 5916, 15104, 4547, 1, 2, 579, 349, 662, 172, 1645, 446, 357, 166, 1532, 760, 158, 283, 743, 191, 2157, 393, 139, 117, 33, 2455, 1004, 498, 334, 420, 210, 161, 159, 702, 284, 350, 496, 1678, 810, 393, 282, 7005, 556, 941, 1495, 4650, 822, 535, 185, 234, 184, 179, 100, 716, 208, 270, 695, 262, 126, 158, 155, 253, 823, 426, 374, 787, 910, 59, 1887, 11238, 15414, 2003, 542, 185, 254, 824, 1, 427, 811, 347, 603, 137, 6, 670, 693, 250, 373, 786, 910, 203, 307, 377, 825, 58, 358, 558, 451, 273, 1204, 5319, 553, 24136, 2220, 73751, 68274, 6395, 4295, 4101, 8534, 2828, 1915, 1341, 542, 3268, 1938, 1703, 1735, 2360, 2849, 1185, 2455, 16950, 7, 3991, 486, 2500, 8680, 13686, 57, 652, 156, 113, 70, 36, 40, 62, 28, 10, 18, 149, 37, 112, 250, 1, 9400, 5347, 5143, 8388, 727, 2042, 2027, 1093, 418, 2056, 680, 1170, 388, 504, 14958, 1982, 1728, 289, 4486, 4842, 415, 383, 2756, 1122, 4050, 844, 546, 1545, 1102, 143, 1588, 130, 724, 497, 789, 2717, 1834, 159, 598, 687, 995, 4654, 218, 552, 6, 1, 31, 1985, 1183, 431, 560, 298, 610, 4314, 223, 149, 2203, 990, 290, 2378, 361, 6, 879, 1437, 1262, 4393, 1917, 1195, 346, 3320, 881, 142, 120, 3250, 505, 803, 1662, 426, 728, 6, 32, 360, 4, 828, 809, 1996, 1446, 712, 32, 13, 1619, 874, 410, 1042, 291, 232, 1039, 146, 547, 2740, 1117, 1425, 1170, 627, 719, 3065, 1559, 369, 1627, 1800, 589, 815, 117, 807, 536, 1387, 536, 2132, 1903, 1704, 7, 682, 326, 143, 1362, 781, 2126, 880, 499, 426, 2641, 801, 2021, 628, 1906, 3489, 1339, 630, 955, 437, 546, 887, 4309, 691, 26, 3566, 1188, 319, 10547, 2317, 13821, 19263, 19661, 689, 779, 582, 38, 250, 92, 1, 312, 9, 8, 2828, 1173, 4629, 6960, 6987, 253, 1830, 7165, 2465, 728, 27, 1460, 252, 13588, 12816, 508, 1136, 185, 7, 74676, 1405, 1445, 868, 53, 30, 131, 43, 105, 74, 78, 2, 13, 11471, 32624, 76554, 10940, 4402, 8548, 349, 955, 742, 744, 462, 1379, 453, 20, 715, 116, 326, 204, 2, 722, 105, 42, 603, 3567, 7019, 234, 337, 333, 31578, 3527, 1568, 982, 125, 230, 4, 52, 775, 56, 790, 71312, 11410, 26029, 840, 1753, 960, 639, 2229, 1840, 889, 725, 201, 26, 470, 105, 417, 334, 22, 25985, 34107, 4072, 2576, 3395, 3661, 3094, 3231, 1875, 1183, 84, 510, 276, 472, 695, 653, 21, 287, 358, 279, 502, 106, 667, 28674, 3475, 2860, 878, 2261, 1789, 2073, 1200, 398, 8, 98, 38, 38, 39, 26, 249, 21312, 14390, 7611, 16162, 11955, 8893, 6362, 1086, 1525, 414, 1077, 417, 159, 359, 504, 338, 438, 1016, 534, 275, 16, 952, 40, 752, 870, 959, 692, 233, 6103, 2287, 8068, 4005, 2942, 2891, 251, 127, 4, 887, 116, 1516, 126, 252, 298, 58, 448, 4985, 6997, 6430, 4445, 2611, 495, 164, 177, 1069, 578, 3, 37, 541, 296, 132, 3444, 7693, 1458, 1844, 496, 879, 547, 866, 1414, 301, 12, 1105, 827, 12613, 8541, 13957, 874, 59, 7, 1008, 1043, 555, 125, 171, 1626, 389, 673, 101, 165, 211, 23, 16238, 19435, 2525, 1383, 704, 1286, 463, 796, 1149, 90, 431, 391, 647, 370, 1540, 612, 732, 672, 159, 12, 355, 259, 26306, 4028, 2413, 1186, 1601, 633, 209, 3600, 2797, 1674, 555, 1872, 551, 37, 14, 57, 1826, 540, 164, 962, 12111, 4533, 9158, 1954, 2626, 1262, 1186, 14580, 10147, 4418, 1965, 954, 3066, 961, 816, 2, 484, 853, 584, 1008, 482, 3407, 441, 582, 875, 610, 4941, 2207, 1274, 1013, 481, 5370, 2645, 559, 2179, 501, 271, 817, 1211, 283, 16, 709, 54, 4898, 736, 1179, 1311, 270, 939, 1000, 888, 1660, 651, 1279, 614, 312, 239, 5554, 1295, 3236, 1870, 3941, 919, 2045, 884, 1109, 112, 150, 238, 625, 859, 1764, 1158, 12, 250, 1184, 65, 1950, 2325, 548, 585, 1705, 728, 649, 944, 2582, 593, 1010, 1199, 1016, 823, 714, 1393, 15150, 8805, 377, 185, 4840, 3084, 1755, 243, 127, 274, 176, 85, 14538, 971, 511, 12682, 9527, 1708, 98, 952, 976, 245, 730, 1691, 6412, 17901, 868, 6405, 1909, 1559, 694, 1375, 547, 1332, 39, 882, 881, 534, 5027, 2904, 402, 250, 386, 1019, 918, 89, 300, 737, 872, 510, 227, 1445, 779, 1922, 33352, 5327, 2816, 822, 1454, 782, 4232, 7, 1520, 774, 1691, 1688, 590, 889, 511, 27390, 559, 8183, 572, 9457, 1333, 1113, 280, 5882, 139, 913, 1262, 495, 9175, 1644, 4890, 3903, 1104, 7476, 826, 356, 3169, 1718, 1599, 2136, 2919, 5340, 5715, 1099, 1541, 879, 586, 652, 389, 1421, 372, 1, 483, 1108, 749, 5475, 988, 570, 1677, 270, 2708, 726, 46, 2224, 1178, 4599, 1700, 823, 1547, 1064, 1095, 1184, 1816, 2642, 283, 1779, 3325, 492, 824, 3044, 6928, 273, 1438, 5846, 1552, 7948, 692, 755, 1018, 2525, 1099, 440, 1421, 1721, 770, 1306, 4793, 570, 1447, 1081, 1859, 120, 3788, 1034, 2568, 390, 1220, 493, 754, 4286, 4012, 604, 901, 10936, 2796, 1766, 16838, 8250, 12898, 3809, 1246, 9547, 4446, 5068, 1677, 5760, 2576, 3598, 755, 3963, 28963, 27094, 67984, 68883, 1601, 199, 609, 56, 308, 47, 104, 628, 79, 61, 183, 2, 1706, 47, 242, 41, 28, 119, 386, 219, 41, 3, 142, 128, 164, 232, 158, 307, 64, 495, 645, 188, 658, 27, 2060, 0, 0, 0, 0, 0, 21507, 4168, 2709, 1229, 1345, 994, 1159, 743, 1336, 675, 311, 174, 1423, 2662, 1031, 1462, 683, 945, 4, 7504, 2062, 561, 335, 171, 208, 99, 214, 386, 179, 148, 46, 148, 142, 292, 407, 180, 0, 134, 60, 648, 367, 314, 1045, 466, 659, 419, 677, 870, 706, 738, 829, 578, 1945, 0, 209, 3059, 292, 1009, 1024, 356, 490, 503, 496, 1118, 944, 754, 418, 7682, 315, 376, 490, 274, 340, 236, 90, 185, 411, 268, 655, 440, 69, 518, 410, 288, 503, 234, 257, 580, 62, 208, 527, 971, 184, 328, 15, 309, 432, 301, 586, 755, 711, 644, 1079, 268, 935, 143, 228, 234, 50, 95, 308, 451, 504, 275, 80, 210, 54, 0, 343, 769, 265, 433, 70, 107, 799, 600, 340, 1195, 96, 83, 355, 289, 587, 541, 489, 551, 65, 454, 470, 131, 307, 42, 224, 408, 876, 540, 401, 457, 133, 91, 306, 168, 600, 248, 488, 201, 108, 103, 406, 212, 1246, 787, 661, 172, 157, 2, 197, 244, 203, 75, 0, 308, 244, 337, 1019, 2529, 629, 3, 211, 352, 76, 967, 741, 1264, 354, 377, 167, 500, 63, 61, 877, 312, 487, 434, 143, 934, 1775, 434, 341, 100, 184, 2085, 234, 365, 589, 943, 2116, 250, 419, 227, 1, 526, 3, 458, 1529, 2052, 807, 268, 792, 361, 229, 807, 224, 390, 1269, 614, 206, 1399, 121, 174, 368, 225, 423, 527, 388, 901, 268, 264, 717, 177, 1141, 1130, 793, 1612, 406, 3227, 3092, 1421, 1520, 1444, 2995, 897, 287, 338, 169, 344, 203, 274, 792, 1072, 311, 94, 179, 260, 817, 539, 220, 453, 433, 254, 248, 336, 130, 514, 137, 758, 410, 297, 563, 286, 760, 486, 267, 334, 48, 479, 165, 149, 170, 377, 360, 478, 241, 0, 420, 230, 209, 264, 274, 432, 98, 304, 501, 265, 215, 342, 353, 225, 491, 42, 339, 391, 934, 538, 335, 156, 735, 337, 273, 273, 219, 419, 29, 177, 452, 239, 390, 303, 935, 44, 118, 145, 47, 102, 77, 56, 205, 176, 328, 164, 339, 400, 734, 592, 147, 760, 487, 338, 154, 217, 434, 185, 69, 320, 235, 296, 200, 500, 204, 147, 120, 431, 337, 226, 173, 229, 253, 437, 218, 5, 369, 431, 247, 334, 406, 179, 224, 733, 52, 451, 178, 12, 6, 207, 430, 257, 217, 759, 164, 54, 5, 562, 1072, 267, 89, 503, 526, 233, 238, 341, 133, 225, 97, 387, 264, 186, 712, 175, 934, 429, 13, 127, 184, 525, 267, 696, 263, 285, 59, 272, 232, 555, 435, 229, 394, 583, 864, 563, 1194, 409, 107, 1, 295, 75, 389, 651, 533, 393, 85, 1081, 943, 639, 217, 179, 194, 189, 611, 361, 1028, 951, 695, 1496, 210, 298, 0, 845, 908, 1805, 752, 133, 455, 505, 1842, 1450, 807, 150, 808, 2200, 131, 172, 3123, 2090, 460, 2120, 991, 414, 7387, 2918, 3277, 3259, 636, 3562, 7245, 7462, 6802, 1776, 3153, 5076, 6931, 1605, 2511, 0, 13943, 3475, 7529, 9125, 31851, 18395, 28, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 3, 27, 0, 0, 0, 1, 411, 259017, 120, 20, 8, 124, 984, 138, 2301, 15, 474, 180, 87, 67, 76, 63, 102, 45, 49, 27, 56, 8, 228, 3092, 4132, 6, 18481, 83121, 90, 66, 53, 147712, 2721, 341, 78, 107, 97, 40, 4421, 2578, 18061, 460, 86, 82895, 190, 73, 9, 91, 67, 125, 54, 238676, 9698, 112, 76, 238343, 246909, 28, 108, 26, 19, 251, 214, 376, 7, 124, 159, 56, 63, 77, 54, 7, 2656, 1736, 1, 0, 3, 10, 12, 15, 2, 3, 116, 159, 242, 515, 0, 0, 0, 0, 213, 461, 89, 3, 0, 0, 37, 77, 46, 0, 65, 146, 50, 122, 132, 103, 57, 106, 78, 108, 103, 28, 55, 9, 216, 127, 564, 12378, 12801, 819, 1086, 3015, 2225, 335, 79, 312, 1014, 1758, 677, 3, 480, 2, 21, 392, 502, 387, 490, 318, 223, 114, 109, 1659, 1512, 3428, 3776, 4320, 6402, 26, 297, 265, 334, 169, 185, 110, 422, 247, 11, 307, 73, 100, 11, 19, 7, 71, 20, 15, 143, 11, 134, 11, 28, 174, 117, 16, 109, 1273, 150, 713, 1651, 327, 374, 91, 445, 895, 167, 447, 178, 4, 1015, 187, 352, 1441, 1735, 1424, 548, 347, 76, 91, 53, 106, 77, 87, 142, 84, 362, 183, 117, 187, 653, 309, 258, 195, 57, 1, 149, 672, 198, 3, 163, 354, 4, 754, 615, 1242, 758, 11, 194, 9, 90, 169, 1259, 742, 505, 886, 388, 10, 160, 257, 6, 267, 109, 4, 199, 5, 92, 73, 112, 165, 38, 756, 298, 237, 772, 96, 93, 187, 235, 123, 292, 263, 314, 264, 238, 546, 678, 4, 108, 60, 231, 85, 124, 3, 14, 9, 145, 166, 4, 250, 43, 460, 167, 293, 356, 198, 185, 4, 237, 654, 91, 50, 285, 215, 3, 3, 73, 166, 152, 115, 110, 3, 2, 42, 635, 1364, 1509, 201, 580, 9, 50, 0, 138, 3, 8, 0, 771, 1434, 1674, 613, 69, 3, 56, 3, 3384, 2192, 3556, 21, 227, 26, 89, 174, 183, 86, 162, 5616, 5751, 212, 163, 78, 504, 144, 416, 211, 104, 94, 90, 12, 245, 79, 207, 455, 15084, 211, 272, 130, 467, 239, 316, 269, 529, 625, 186, 145, 393, 363, 283, 1157, 1369, 1909, 3862, 4364, 744, 1115, 3844, 2890, 1489, 1676, 268, 875, 3349, 529, 703, 165, 898, 119, 194, 371, 563, 253, 463, 329, 441, 215, 554, 145, 56, 1313, 1140, 24, 261, 212, 10, 637, 18, 174, 25, 252, 66, 23, 802, 730, 263, 284, 162, 4, 9, 267, 162, 167, 29, 179, 15, 0, 101, 236, 130, 135, 87, 142, 32, 180, 217, 64, 18, 47, 129, 23, 75, 201, 311, 106, 74, 137, 70, 1324, 254, 569, 133, 1171, 390, 682, 27, 198, 408, 7, 922, 62, 197, 20, 75, 1112, 1591, 953, 631, 646, 25, 512, 585, 289, 332, 96, 336, 13, 188, 98, 177, 59, 747, 242, 74, 429, 231, 207, 180, 855, 641, 526, 273, 266, 133, 123, 244, 223, 90, 296, 87, 199, 1332, 1851, 252, 284, 506, 1374, 500, 274, 263, 1, 132, 272, 96, 21, 108, 52, 332, 332, 886, 233, 917, 1249, 131, 1213, 140, 88, 148, 57, 622, 609, 158, 464, 142, 91, 214, 711, 801, 291, 794, 1884, 855, 504, 5, 202, 9, 184, 99, 363, 194, 577, 773, 1301, 129, 22, 448, 161, 4, 312, 100, 175, 469, 11, 2, 5, 228, 310, 747, 515, 295, 579, 292, 26, 97, 204, 2822, 314, 752, 246, 271, 238, 184, 108, 211, 24, 182, 742, 0, 1519, 2738, 2103, 684, 797, 307, 149, 210, 319, 30, 233, 201, 316, 51, 255, 230, 324, 631, 258, 97, 509, 217, 6, 969, 1695, 2088, 350, 125, 141, 194, 112, 179, 164, 65, 868, 281, 488, 2825, 479, 349, 17, 73, 1038, 5, 91, 413, 238, 146, 507, 206, 676, 217, 68, 546, 321, 401, 1244, 314, 477, 111, 49, 364, 67, 76, 646, 141, 90, 211, 2490, 1475, 124, 124, 122, 105, 237, 447, 139, 339, 110, 625, 1697, 17, 3, 331, 272, 20, 130, 264, 754, 71, 257, 838, 1, 72, 9, 112, 407, 162, 200, 239, 3, 193, 224, 144, 557, 195, 319, 365, 72, 103, 66, 727, 690, 238, 232, 129, 99, 240, 4, 77, 123, 200, 148, 182, 111, 182, 378, 422, 70, 166, 183, 77, 174, 163, 131, 75, 228, 376, 107, 71, 747, 130, 252, 254, 122, 69, 121, 140, 413, 6, 263, 466, 550, 368, 357, 1245, 470, 507, 91, 5, 339, 2, 365, 72, 1249, 158, 10, 88, 644, 200, 1607, 1095, 177, 122, 229, 2153, 263, 167, 840, 65, 1723, 2948, 245, 90, 183, 1492, 549, 210, 656, 253, 457, 1547, 87, 296, 2499, 904, 1458, 3035, 775, 1734, 599, 168, 16857, 19865, 538, 251, 32, 927, 105, 71, 90, 37, 3, 49, 102, 478, 3, 122, 148, 423, 116, 502, 89, 96, 370, 25, 2, 177, 175, 40, 69, 83, 57, 51, 218, 75, 93, 403, 216, 46, 82, 91, 84, 14, 71, 612, 540, 2462, 0, 0, 0, 3123, 184, 393, 1680, 671, 1123, 1804, 46, 147, 48, 177, 886, 91, 209, 687, 180, 646, 507, 410, 321, 58, 146, 247, 177, 79, 221, 98, 767, 23, 51, 305, 198, 77, 34, 542, 148, 78, 157, 400, 48, 2270, 0, 0, 122, 753, 649, 103, 400, 104, 61, 168, 76, 113, 139, 166, 54, 49, 61, 610, 0, 62, 183, 121, 73, 117, 61, 77, 314, 31, 4, 243, 797, 64, 352, 80, 161, 67, 229, 97, 210, 333, 126, 78, 72, 155, 502, 193, 2, 553, 8, 91, 108, 228, 231, 410, 247, 282, 157, 51, 84, 192, 88, 70, 138, 115, 341, 101, 474, 49, 266, 191, 443, 100, 112, 445, 310, 76, 526, 36, 45, 146, 2, 246, 48, 47, 1, 281, 101, 62, 113, 103, 16, 59, 298, 217, 259, 92, 63, 146, 375, 0, 90, 60, 112, 227, 354, 155, 52, 355, 2, 100, 351, 167, 123, 138, 160, 120, 173, 67, 113, 181, 102, 61, 321, 118, 159, 60, 181, 350, 354, 57, 145, 50, 170, 115, 121, 8, 58, 223, 141, 38, 113, 304, 291, 84, 117, 313, 114, 1, 274, 149, 75, 72, 169, 105, 333, 171, 98, 118, 244, 216, 54, 58, 122, 69, 132, 15, 158, 164, 127, 83, 229, 112, 113, 59, 398, 24, 111, 223, 116, 312, 466, 134, 89, 34, 231, 130, 100, 157, 240, 153, 84, 129, 119, 409, 67, 67, 112, 165, 172, 114, 330, 0, 117, 78, 46, 294, 407, 91, 56, 116, 133, 391, 50, 220, 140, 165, 97, 349, 33, 23, 353, 477, 59, 232, 175, 308, 131, 1022, 42, 22, 53, 52, 162, 71, 99, 506, 89, 377, 239, 98, 51, 149, 115, 53, 395, 409, 830, 66, 197, 452, 76, 294, 122, 975, 75, 354, 674, 188, 128, 231, 802, 1172, 261, 293, 726, 113, 143, 146, 400, 850, 239, 1155, 1108, 3637, 5214, 15, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 104, 10367, 1093, 814, 619, 253, 1334, 71, 169, 359, 463, 68, 57, 165, 2609, 310, 256, 7, 924, 194, 375, 137, 774, 200, 57, 13, 884, 1354, 1637, 8462, 25297, 3702, 1, 124, 311, 258, 508, 597, 207, 207, 3511, 4562, 139, 527, 695, 143, 674, 620, 254, 1650, 327, 528, 171, 259, 361, 464, 69, 56, 164, 145, 1322, 1409, 247, 309, 257, 8, 596, 924, 195, 146, 206, 374, 136, 619, 773, 198, 58, 260, 14, 870, 13, 386, 975, 10, 1051, 1399, 74, 17159, 689, 59591, 79115, 3677, 2591, 3716, 1296, 1337, 827, 786, 3080, 2984, 460, 232, 904, 32, 2990, 724, 95, 1288, 264, 623, 975, 4424, 9140, 241, 782, 2260, 1175, 28, 515, 1164, 34, 180, 68, 474, 134, 33, 91, 70, 299, 10, 330, 518, 7, 38, 140, 64, 23, 637, 9840, 5642, 1546, 2378, 969, 2214, 515, 4101, 7592, 523, 1323, 2975, 3151, 2672, 3305, 1407, 1663, 2353, 7572, 327, 8736, 1803, 4812, 164, 420, 73, 469, 15, 188, 98, 403, 215, 657, 463, 789, 452, 964, 1060, 2958, 770, 1288, 690, 504, 991, 1271, 521, 17, 169, 1002, 318, 1166, 286, 1092, 139, 773, 1509, 1136, 289, 1175, 6, 19, 1502, 154, 2000, 660, 398, 488, 1371, 168, 1395, 146, 1522, 202, 20, 728, 390, 394, 274, 409, 453, 21, 477, 963, 169, 1917, 336, 793, 3, 516, 659, 1106, 777, 4, 908, 8, 275, 2048, 729, 938, 93, 268, 183, 883, 205, 1794, 831, 350, 278, 9, 1958, 1522, 96, 1449, 2108, 201, 520, 1521, 357, 608, 1700, 6075, 198, 42, 787, 731, 1959, 776, 141, 81, 465, 1973, 253, 790, 2441, 125, 366, 665, 885, 24, 8, 147, 1428, 732, 510, 97, 637, 643, 384, 1128, 1114, 1557, 3672, 1090, 819, 9, 454, 18, 363, 239, 1294, 3738, 3788, 220, 722, 203, 165, 13, 82, 345, 650, 1247, 271, 459, 4679, 5, 1065, 15, 202, 1895, 772, 4, 73, 24, 1970, 1827, 1248, 524, 2321, 886, 1367, 498, 582, 1137, 1850, 358, 546, 55, 5096, 4224, 239, 930, 542, 585, 12, 23397, 577, 4712, 1234, 98, 585, 940, 141, 336, 834, 143, 321, 6, 137, 450, 1213, 11, 2513, 19560, 34780, 9993, 1686, 4235, 4333, 1127, 498, 185, 559, 785, 1352, 264, 518, 384, 7, 166, 83, 127, 509, 339, 235, 1979, 593, 3, 184, 14491, 4562, 2310, 3345, 270, 1550, 6, 546, 312, 295, 909, 208, 26660, 5011, 16675, 5717, 2617, 2219, 500, 10, 887, 204, 55, 22, 582, 2805, 1264, 193, 580, 329, 91, 29, 742, 11, 585, 13, 839, 51, 2229, 14123, 12730, 290, 157, 8455, 1495, 470, 590, 1976, 345, 2, 4, 3522, 30, 455, 6, 368, 3470, 3996, 893, 94, 116, 333, 1012, 1006, 449, 6, 29, 172, 19371, 3290, 4934, 4038, 140, 845, 333, 1196, 538, 1100, 685, 396, 1017, 3332, 1569, 726, 29, 55, 795, 125, 2126, 758, 10377, 9185, 392, 2730, 3077, 1305, 824, 1524, 216, 547, 853, 9187, 1890, 1382, 168, 929, 42, 366, 440, 273, 35, 2, 391, 228, 2133, 289, 142, 27, 1939, 1186, 179, 527, 448, 156, 9695, 1012, 942, 6093, 854, 1252, 1419, 415, 472, 1989, 6069, 610, 991, 279, 470, 334, 19, 2512, 2328, 2930, 5404, 1001, 3411, 655, 8, 714, 310, 7837, 766, 1285, 248, 733, 456, 227, 345, 526, 706, 1970, 543, 141, 289, 1261, 1433, 517, 186, 816, 883, 16, 2828, 496, 3624, 828, 1659, 1478, 79, 178, 133, 470, 95, 3133, 1300, 559, 1649, 252, 211, 838, 6817, 3632, 659, 1015, 46, 645, 277, 1345, 487, 360, 102, 539, 1332, 121, 2648, 1277, 205, 160, 458, 414, 797, 24, 92, 605, 973, 11, 63, 12314, 885, 394, 214, 540, 574, 1250, 278, 6, 272, 350, 4426, 1034, 277, 587, 613, 38, 1522, 1467, 251, 1810, 14, 2320, 272, 265, 33, 5959, 1548, 581, 42903, 500, 8895, 3485, 3113, 2755, 3145, 747, 312, 545, 318, 2202, 14, 733, 603, 1488, 1728, 1433, 0, 1794, 19930, 14354, 6423, 2837, 1877, 2364, 588, 208, 789, 9, 929, 1756, 323, 2045, 288, 309, 33, 2891, 2007, 1817, 1449, 498, 11653, 6051, 5062, 3392, 677, 2390, 532, 2141, 184, 517, 78, 794, 25, 354, 1525, 1971, 7506, 9057, 3431, 2314, 278, 539, 25, 5, 6, 1147, 700, 271, 286, 5, 1429, 395, 3200, 1351, 11342, 1436, 1441, 624, 263, 627, 540, 469, 614, 1603, 1788, 385, 2074, 1938, 14244, 7742, 1551, 1153, 230, 269, 585, 464, 155, 38, 976, 897, 533, 138, 45, 3965, 1519, 8196, 3319, 216, 1731, 1274, 352, 653, 288, 709, 2920, 1049, 199, 95, 3250, 3478, 4569, 3256, 1615, 2438, 822, 218, 1420, 1937, 5, 243, 924, 521, 189, 4170, 2866, 2087, 480, 559, 539, 329, 277, 125, 1006, 366, 30, 1536, 392, 5280, 1124, 336, 1013, 544, 645, 430, 564, 11, 239, 2854, 426, 191, 857, 847, 197, 508, 463, 24, 828, 120, 646, 396, 1092, 1104, 927, 558, 4, 721, 8, 531, 839, 439, 196, 538, 445, 1720, 1756, 1317, 782, 520, 855, 3611, 406, 6531, 2200, 644, 440, 446, 1034, 806, 407, 252, 2514, 248, 840, 786, 1615, 456, 1105, 1958, 401, 739, 364, 936, 1406, 1036, 1795, 1596, 1442, 599, 10, 611, 1297, 5099, 1716, 9, 202, 1999, 473, 3471, 1861, 290, 4, 1858, 611, 971, 730, 6464, 4868, 1104, 1307, 12759, 7592, 4488, 2107, 1347, 2288, 81566, 59744, 637, 303, 100, 7, 100, 6, 18, 323, 97, 28, 99, 168, 147, 146, 144, 228, 48, 41, 77, 59, 15, 136, 6, 25, 358, 83, 44, 212, 86, 143, 8, 54, 222, 45, 663, 512, 2847, 0, 0, 0, 11885, 1849, 3932, 1572, 1253, 874, 4034, 503, 507, 3114, 1746, 517, 997, 159, 237, 263, 2018, 248, 384, 428, 1270, 642, 1636, 80, 166, 197, 452, 140, 93, 236, 125, 324, 162, 497, 173, 684, 174, 139, 413, 404, 435, 283, 402, 515, 683, 146, 2177, 2898, 6731, 603, 1579, 936, 1416, 125, 764, 561, 114, 571, 976, 401, 217, 87, 104, 503, 113, 84, 0, 307, 213, 101, 348, 560, 1776, 281, 343, 305, 653, 157, 744, 0, 168, 95, 198, 95, 1085, 1306, 830, 280, 656, 382, 295, 242, 311, 187, 3, 341, 1011, 581, 281, 260, 98, 111, 86, 269, 98, 342, 566, 307, 148, 57, 73, 345, 231, 253, 41, 802, 67, 534, 336, 826, 353, 750, 236, 77, 577, 167, 196, 9, 433, 136, 358, 786, 777, 913, 608, 428, 200, 0, 180, 4, 508, 19, 405, 181, 423, 1373, 66, 195, 5, 44, 216, 81, 124, 1005, 986, 558, 336, 352, 211, 404, 532, 475, 228, 763, 924, 452, 339, 91, 1475, 122, 182, 473, 169, 222, 180, 395, 186, 455, 113, 98, 194, 160, 173, 210, 236, 422, 427, 89, 1068, 258, 570, 496, 329, 98, 1037, 300, 550, 601, 626, 212, 472, 269, 344, 650, 681, 516, 248, 555, 378, 110, 396, 767, 16, 195, 278, 626, 1210, 667, 372, 217, 300, 182, 145, 65, 61, 300, 247, 90, 153, 301, 173, 59, 281, 208, 342, 1150, 373, 143, 155, 600, 427, 216, 655, 92, 259, 328, 153, 112, 759, 532, 394, 125, 137, 170, 88, 171, 197, 61, 163, 56, 213, 204, 571, 169, 96, 185, 195, 103, 1003, 99, 139, 429, 333, 258, 194, 282, 40, 79, 4, 507, 294, 767, 78, 476, 201, 193, 282, 198, 270, 91, 216, 504, 238, 141, 358, 688, 121, 672, 368, 1248, 232, 686, 114, 126, 231, 14, 218, 229, 423, 83, 89, 127, 301, 135, 228, 94, 329, 515, 309, 90, 203, 483, 247, 225, 274, 45, 1970, 198, 300, 173, 339, 368, 699, 339, 63, 300, 654, 217, 300, 1459, 9773, 1, 97, 823, 373, 259, 246, 570, 648, 343, 483, 42, 1356, 1716, 3240, 0, 372, 230, 213, 652, 178, 328, 258, 77, 160, 395, 168, 167, 412, 336, 379, 448, 1006, 184, 402, 514, 195, 187, 1276, 1541, 299, 197, 7, 236, 298, 321, 747, 953, 200, 183, 1668, 985, 398, 428, 426, 732, 1380, 565, 1128, 376, 1892, 1855, 1330, 191, 1387, 1231, 5976, 7773, 26177, 84, 65, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 6, 2648, 458, 44, 9, 36, 11, 12, 2, 8, 30, 222, 2240, 2897, 397, 150, 520, 139, 1199, 293, 446, 414, 45, 155, 157, 10, 521, 38, 159, 453, 12, 10, 7, 0, 1, 6, 0, 11, 38, 802, 135, 6, 5477, 2, 4825, 45, 159, 71, 619, 926, 327, 22, 81, 903, 24, 219, 126, 58, 101, 36, 4, 16, 9, 141, 143, 43, 12, 26, 7, 153, 83, 216, 135, 492, 228, 156, 18, 83, 153, 206, 49, 713, 181, 181, 4, 33, 12, 1, 23, 65, 34, 3, 56, 302, 5, 18, 104, 32, 162, 68, 1, 36, 58, 6, 168, 20, 48, 92, 48, 26, 98, 3936, 12, 1461, 1039, 487, 21, 318, 279, 31, 28, 675, 16, 5, 64, 448, 46, 1463, 160, 5, 68, 673, 792, 1040, 23, 375, 1, 1, 227, 674, 179, 2, 793, 748, 328, 5, 19, 180, 37, 46, 904, 25, 1041, 220, 127, 31, 488, 22, 4, 102, 35, 22, 3, 26, 14, 10, 2, 159, 5, 2, 1, 1, 8, 82, 32, 144, 317, 1, 44, 4, 0, 10, 1, 9, 126, 0, 30, 66, 0, 6, 71, 1, 0, 3, 16, 12, 2, 38, 0, 0, 29, 0, 0, 278, 10, 158, 38, 118, 3, 1, 58, 4, 4, 70, 32, 0, 18, 0, 3, 4, 94, 10, 0, 157, 249, 189, 0, 318, 6, 120, 30, 2, 427, 6, 22, 42, 0, 0, 154, 319, 0, 16, 43, 188, 0, 12, 92, 50, 2, 2, 2, 212, 1, 14, 1, 18, 2, 22, 125, 9, 20, 60, 8, 95, 1, 46, 29, 186, 44, 29, 89, 26, 27, 133, 199, 36, 12, 3, 52, 5, 2, 1, 11, 156, 605, 47, 32, 38, 149, 34, 9, 11, 92, 14, 4, 158, 279, 127, 5, 2, 20, 4, 26, 15, 66, 0, 30, 32, 2, 12, 48, 11, 32, 2, 101, 2, 11, 40, 90, 55, 0, 320, 92, 18, 46, 19, 92, 119, 0, 33, 1042, 21, 3, 299, 673, 375, 901, 101, 1199, 618, 486, 792, 239, 672, 18, 13, 21, 374, 91, 15, 300, 8, 42, 13, 900, 19, 52, 51, 148, 110, 1041, 13, 160, 37, 244, 31, 4, 67, 50, 204, 319, 671, 223, 145, 0, 617, 318, 36, 632, 27, 0, 791, 616, 1039, 385, 670, 792, 34, 317, 106, 0, 1561, 81, 327, 1930, 1806, 97, 1505, 92, 3853, 5390, 25, 79, 8, 49, 80, 13, 22, 118, 33, 8, 64, 34, 28, 46, 38, 2835, 0, 0, 0, 0, 553, 374, 309, 62, 396, 522, 192, 451, 59, 107, 2185, 160, 337, 71, 78, 373, 9, 308, 30, 84, 395, 79, 12, 77, 21, 521, 115, 31, 197, 394, 527, 33, 813, 86, 119, 1043, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 38, 1724, 390, 107, 1049, 5965, 221, 133, 54, 10, 2, 143, 27, 191, 78, 54, 1, 63, 75, 71, 106, 263, 239, 4845, 4793, 2, 68, 746, 137, 24, 93, 72, 393, 219, 203, 4, 187, 108, 463, 123, 69, 44, 349, 82, 286, 481, 36, 43, 100, 86, 114, 96, 51, 148, 197, 3470, 2384, 287, 637, 199, 70, 97, 38, 92, 4, 44, 0, 0, 2, 101, 85, 142, 138, 28, 51, 66, 84, 77, 116, 54, 99, 52, 2, 62, 96, 70, 52, 118, 245, 40, 332, 146, 358, 198, 12142, 5697, 494, 11654, 1006, 2459, 149, 1742, 1553, 3841, 101, 1353, 893, 1259, 279, 163, 87, 1, 115, 33, 239, 10, 171, 30, 125, 107, 45, 160, 194, 43, 106, 94, 326, 2320, 5214, 2, 213, 1744, 314, 226, 142, 515, 197, 470, 194, 414, 176, 48, 31, 216, 128, 200, 513, 137, 214, 55, 239, 65, 556, 2301, 1904, 904, 2675, 115, 141, 632, 312, 166, 118, 78, 155, 95, 2, 25, 122, 525, 1398, 1441, 512, 170, 148, 223, 536, 1, 234, 62, 6, 1116, 1069, 940, 142, 291, 359, 139, 32, 205, 83, 5, 87, 26, 211, 123, 177, 541, 150, 491, 430, 248, 623, 409, 586, 3, 146, 77, 5, 113, 43, 163, 49, 38, 711, 1204, 1285, 3, 126, 110, 178, 228, 149, 61, 70, 399, 225, 130, 287, 174, 329, 502, 1, 611, 1287, 285, 859, 458, 1, 226, 201, 240, 222, 9, 72, 71, 568, 13, 335, 400, 325, 942, 109, 565, 560, 208, 1463, 24, 373, 218, 164, 80, 150, 116, 504, 129, 76, 90, 292, 813, 133, 250, 135, 30, 337, 245, 976, 100, 23, 207, 92, 250, 127, 56, 22, 45, 317, 142, 564, 343, 144, 10, 66, 38, 322, 76, 657, 109, 123, 41, 81, 16, 371, 319, 789, 1937, 128, 269, 120, 18, 537, 6, 102, 193, 98, 133, 59, 363, 408, 33, 213, 22, 145, 203, 74, 156, 2, 585, 208, 83, 124, 151, 124, 4, 12, 339, 197, 9, 147, 224, 85, 147, 84, 75, 6, 118, 101, 200, 184, 6, 127, 241, 429, 0, 2, 130, 7, 77, 10, 409, 178, 223, 206, 149, 76, 8, 119, 9, 167, 67, 32, 73, 19, 241, 123, 119, 70, 146, 233, 37, 563, 83, 126, 89, 11, 0, 536, 495, 576, 4, 29, 5, 291, 150, 199, 47, 130, 3, 540, 111, 174, 118, 438, 475, 1707, 47, 3, 130, 616, 472, 449, 240, 1092, 0, 41, 129, 117, 21, 162, 94, 41, 7, 325, 1430, 80, 1048, 495, 541, 636, 119, 682, 383, 195, 241, 578, 292, 370, 3093, 4568, 1, 1, 14544, 0, 12173, 1112, 59, 731, 195, 33, 120, 25, 70, 14, 56, 80, 4, 140, 321, 36, 108, 118, 3, 39, 4, 4, 83, 97, 18, 54, 80, 45, 49, 100, 41, 50, 82, 47, 26, 43, 82, 137, 79, 15, 180, 70, 519, 149, 415, 3196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1780, 92, 1279, 292, 88, 47, 181, 115, 253, 59, 926, 578, 199, 92, 74, 64, 34, 58, 109, 98, 509, 83, 1, 36, 169, 70, 71, 44, 222, 183, 326, 230, 3550, 0, 0, 913, 253, 144, 158, 30, 84, 102, 59, 101, 70, 154, 770, 0, 58, 91, 113, 74, 36, 288, 105, 63, 139, 58, 204, 181, 88, 87, 83, 88, 1265, 0, 0, 0, 29, 251, 86, 82, 1, 37, 38, 312, 0, 26, 4, 115, 87, 3, 57, 69, 51, 75, 52, 216, 71, 75, 38, 92, 118, 13, 75, 55, 57, 79, 25, 50, 3, 287, 109, 2, 77, 77, 65, 103, 335, 54, 7, 272, 58, 10, 125, 195, 106, 114, 287, 86, 63, 493, 28, 27, 256, 107, 250, 91, 117, 117, 108, 73, 104, 2, 40, 76, 62, 43, 0, 36, 70, 11, 63, 415, 49, 57, 246, 180, 108, 90, 53, 57, 14, 159, 76, 185, 79, 53, 48, 124, 0, 241, 56, 75, 159, 70, 52, 964, 82, 123, 235, 10, 194, 42, 56, 107, 0, 58, 49, 81, 217, 45, 132, 168, 69, 0, 107, 137, 57, 286, 75, 42, 41, 30, 50, 70, 74, 167, 74, 284, 90, 596, 0, 78, 40, 69, 14, 160, 132, 61, 168, 656, 119, 69, 69, 167, 21, 78, 1675, 818, 2083, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 1, 1, 0, 0, 3, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 1, 0, 0, 3, 0, 0, 0, 1, 0, 1, 0, 4, 0, 0, 0, 3, 2, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 4, 3, 1, 13, 7, 2, 5, 1, 1, 2, 6, 3, 1, 1, 3, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 2, 3, 1, 1, 0, 0, 1, 0, 1, 4, 0, 0, 4, 0, 0, 1, 0, 1, 0, 1, 0, 16, 2, 3, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 21, 7, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 3, 1, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 6, 5, 1, 2, 1, 1, 1, 2, 1, 1, 15, 2, 1, 4, 3, 4, 1, 1, 1, 3, 1, 1, 2, 2, 1, 2, 7, 4, 3, 3, 1, 3, 1, 5, 3, 2, 3, 7, 4, 10, 3, 4, 3, 2, 2, 17, 14, 7, 5, 6, 8, 1, 2, 1, 1, 2, 1, 2, 3, 2, 2, 3, 1, 1, 1, 1, 2, 6, 1, 1, 1, 2, 8, 4, 3, 3, 1, 3, 1, 1, 3, 7, 1, 1, 1, 4, 3, 3, 1, 2, 2, 1, 2, 14, 6, 5, 6, 2, 2, 1, 6, 10, 14, 3, 2, 6, 2, 7, 1, 19, 14, 5, 1, 2, 5, 5, 3, 6, 3, 2, 2, 13, 16, 19, 8, 1, 1, 7, 2, 3, 3, 6, 38, 5, 4, 1, 9, 4, 6, 9, 2, 7, 3, 6, 28, 12, 5, 9, 3, 3, 4, 4, 3, 5, 2, 6, 8, 1, 26, 4, 19, 2, 2, 17, 4, 4, 3, 4, 30, 11, 9, 4, 10, 5, 6, 5, 20, 2, 4, 11, 3, 11, 5, 7, 20, 30, 6, 6, 3, 8, 5, 17, 5, 7, 0, 0, 0, 1, 0, 1, 1, 2, 0, 0, 4, 1, 6, 3, 3, 2, 1, 8, 4, 6, 0, 0, 0, 0, 20, 8, 1, 2, 8, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 8, 6, 0, 0, 0, 0, 0, 0, 0, 0, 21, 5, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 4, 5, 12, 8, 13, 0, 0, 0, 0, 0, 0, 0, 0, 8, 1, 10, 1, 0, 0, 0, 0, 0, 17, 3, 5, 5, 7, 0, 0, 16, 3, 0, 0, 10, 2, 1, 0, 0, 0, 4, 1, 1, 0, 2, 1, 1, 0, 2, 0, 0, 0, 40, 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 57, 2, 0, 0, 0, 0, 0, 0, 25, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 5, 0, 1, 0, 1, 1, 1, 3, 2, 2, 3, 2, 1, 5, 206, 2, 2, 4, 3, 3, 5, 1, 1, 1, 1, 1, 2, 1, 1, 2, 10, 1, 3, 2, 8, 449, 4, 1, 1, 1, 2, 1, 6, 19, 4, 2, 5, 2, 6, 1, 3, 200, 0, 0, 4, 14, 0, 3, 3, 1, 0, 0, 2, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 4, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 3, 0, 5, 8, 4, 8, 6, 9, 16, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 8, 0, 0, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 2, 1, 2, 1, 1, 3, 3, 3, 2, 5, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 0, 4, 0, 1, 0, 1, 1, 1, 1, 1, 1, 3, 1, 5, 1, 5, 2, 3, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 6, 1, 1, 1, 1, 1, 1, 2, 3, 4, 3, 1, 1, 1, 2, 1, 1, 1, 2, 6, 3, 2, 3, 1, 1, 1, 1, 1, 3, 2, 1, 5, 2, 5, 1, 5, 1, 1, 1, 1, 2, 1, 2, 1, 2, 1, 2, 9, 23, 4, 7, 3, 2, 3, 9, 7, 2, 3, 3, 2, 2, 3, 1, 19, 3, 21, 2, 8, 3, 5, 2, 3, 1, 2, 1, 1, 27, 43, 1, 6, 5, 1, 1, 1, 2, 2, 8, 8, 46, 21, 19, 21, 3, 3, 3, 5, 27, 1, 1, 9, 3, 2, 1, 14, 12, 9, 6, 4, 5, 1, 5, 3, 7, 10, 12, 26, 47, 73, 28, 17, 2, 4, 3, 2, 3, 3, 2, 1, 2, 4, 3, 5, 2, 1, 2, 2, 5, 4, 2, 2, 7, 2, 3, 3, 2, 5, 2, 1, 3, 5, 8, 1, 2, 5, 1, 1, 10, 3, 2, 3, 5, 2, 3, 9, 3, 3, 0, 0, 2, 0, 0, 1, 0, 0, 0, 13, 7, 1, 2, 1, 1, 0, 0, 5, 4, 5, 2, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 16, 12, 3, 9, 5, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 20, 10, 6, 5, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 38, 11, 4, 10, 4, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 13, 4, 9, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 7, 4, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 4, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 5, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 3, 4, 5, 2, 4, 12, 15, 85, 6, 2, 7, 0, 12, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 16, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 1, 4, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 3, 2, 1, 1, 1, 3, 1, 1, 2, 1, 5, 1, 1, 3, 2, 1, 1, 1, 2, 1, 3, 2, 3, 1, 1, 2, 4, 1, 4, 1, 3, 2, 1, 1, 1, 7, 2, 1, 3, 3, 3, 2, 9, 1, 3, 3, 4, 3, 2, 2, 4, 2, 8, 1, 4, 1, 4, 2, 4, 3, 2, 3, 1, 10, 13, 2, 2, 8, 8, 3, 12, 2, 15, 1, 12, 2, 2, 1, 3, 10, 1, 2, 3, 13, 4, 3, 25, 3, 9, 3, 3, 3, 12, 1, 1, 9, 2, 6, 17, 4, 7, 14, 2, 10, 16, 11, 5, 2, 0, 0, 6, 0, 0, 0, 0, 0, 2, 2, 0, 1, 1, 0, 3, 0, 0, 0, 0, 0, 9, 0, 0, 0, 2, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 11, 7, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 6, 4, 1, 2, 2, 1, 1, 14, 1, 6, 2, 2, 1, 4, 1, 1, 3, 2, 4, 2, 7, 8, 2, 3, 2, 1, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 2, 1, 0, 1, 1, 1, 1, 2, 1, 2, 2, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 16, 3, 5, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 0, 0, 1, 0, 2, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 1, 0, 2, 1, 1, 1, 4, 12, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 2, 0, 0, 0, 1, 0, 1, 2, 1, 0, 0, 0, 1, 0, 1, 2, 1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 2, 1, 1, 0, 0, 0, 1, 2, 1, 0, 1, 0, 2, 0, 1, 1, 2, 0, 0, 0, 0, 1, 2, 1, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 4, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 4, 0, 1, 0, 1, 2, 2, 3, 3, 2, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 3, 5, 5, 1, 1, 26, 20, 1, 1, 4, 2, 242, 11, 3, 13, 6, 4, 1, 13, 6, 1, 1, 1, 2, 275, 15, 9, 14, 14, 8, 15, 89, 201, 155, 51, 59, 14, 7, 2, 8, 1, 1, 1, 1, 8, 2, 3, 5, 25, 60, 128, 77, 43, 22, 13, 2, 7, 1, 2, 1, 2, 9, 1, 9, 3, 1, 2, 5, 2, 2, 2, 1, 6, 0, 8, 5, 2, 5, 1, 15, 8, 7, 3, 0, 72, 39, 8, 4, 11, 1, 0, 0, 171, 55, 43, 16, 5, 2, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 145, 101, 28, 3, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 125, 32, 15, 2, 6, 2, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 92, 23, 12, 19, 3, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 9, 11, 11, 12, 7, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 12, 3, 5, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 6, 3, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 11, 2, 1, 1, 1, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 2, 1, 1, 5, 2, 2, 2, 6, 3, 1, 4, 2, 1, 1, 2, 3, 3, 5, 3, 1, 1, 3, 3, 3, 9, 1, 1, 6, 2, 2, 1, 1, 2, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 24, 0, 0, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 8, 10, 2, 1, 1, 2, 2, 2, 2, 2, 6, 5, 2, 2, 3, 6, 2, 1, 3, 1, 1, 2, 1, 1, 1, 1, 2, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 2, 2, 2, 2, 3, 2, 1, 2, 4, 4, 1, 1, 8, 2, 1, 7, 4, 1, 6, 2, 1, 4, 7, 44, 2, 8, 1, 1, 1, 4, 5, 1, 3, 1, 1, 1, 2, 2, 2, 2, 1, 2, 1, 3, 2, 2, 0, 1, 1, 1, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 2, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 16, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 5, 5, 4, 2, 2, 1, 2, 4, 2, 10, 14, 11, 3, 3, 2, 2, 3, 2, 7, 8, 3, 1, 5, 15, 13, 11, 6, 2, 2, 2, 2, 3, 16, 1, 33, 19, 8, 1, 3, 3, 5, 5, 1, 8, 10, 1, 1, 49, 22, 3, 8, 6, 4, 5, 14, 42, 19, 3, 1, 5, 5, 36, 13, 10, 59, 2, 3, 2, 3, 14, 4, 3, 25, 36, 7, 1, 7, 6, 2, 4, 2, 1, 6, 1, 4, 1, 2, 5, 2, 0, 1, 0, 3, 1, 1, 2, 7, 0, 4, 9, 38, 0, 0, 0, 0, 0, 0, 3, 14, 2, 0, 0, 0, 0, 0, 0, 0, 0, 10, 3, 0, 0, 0, 0, 37, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 6, 1, 4, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 1, 1, 3, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 0, 0, 1, 2, 1, 0, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 2, 1, 1, 1, 1, 1, 2, 5, 2, 1, 1, 23, 5, 15, 1, 3, 5, 47, 17, 105, 46, 74, 8, 5, 2, 2, 14, 5, 7, 39, 2, 7, 1, 1, 1, 6, 10, 4, 24, 3, 2, 1, 2, 1, 0, 2, 1, 2, 0, 13, 3, 18, 1, 0, 0, 0, 0, 0, 0, 0, 4, 4, 0, 0, 0, 10, 38, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 5, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 1, 1, 1, 1, 2, 1, 1, 1, 8, 1, 1, 2, 2, 1, 1, 2, 15, 2, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 5, 21, 2, 37, 1, 2, 7, 6, 3, 10, 61, 50, 27, 8, 127, 125, 740, 5, 10, 2, 8, 4, 1, 1, 3, 11, 1, 2, 5, 1, 12, 27, 22, 1, 12, 41, 8, 10, 14, 15, 7, 35, 16, 7, 0, 19, 108, 122, 3, 0, 33, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 2, 2, 1, 2, 2, 2, 2, 3, 2, 2, 1, 7, 1, 3, 2, 2, 2, 2, 2, 8, 5, 1, 3, 3, 15, 23, 1, 4, 9, 6, 29, 2, 6, 1, 1, 5, 1, 2, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 1, 0, 1, 0, 5, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 4, 1, 1, 2, 1, 55, 4, 6, 5, 4, 2, 2, 2, 1, 2, 1, 1, 1, 3, 4, 5, 5, 1, 3, 3, 1, 4, 19, 6, 3, 4, 1, 3, 6, 2, 2, 1, 1, 2, 1, 1, 1, 1, 6, 18, 19, 1, 4, 3, 3, 2, 1, 2, 1, 4, 9, 2, 6, 3, 9, 4, 16, 8, 13, 1, 2, 6, 1, 4, 2, 1, 2, 1, 3, 1, 2, 2, 2, 2, 1, 2, 1, 1, 1, 1, 3, 1, 2, 1, 4, 1, 2, 3, 1, 1, 1, 1, 7, 1, 1, 3, 2, 8, 5, 1, 1, 6, 2, 2, 1, 2, 4, 1, 4, 6, 1, 1, 5, 1, 2, 1, 3, 3, 1, 1, 1, 2, 6, 1, 5, 10, 2, 2, 2, 6, 5, 1, 3, 2, 2, 2, 2, 4, 1, 2, 4, 1, 2, 3, 1, 6, 1, 8, 1, 4, 3, 4, 1, 11, 1, 1, 6, 2, 3, 2, 1, 5, 2, 6, 1, 2, 3, 5, 1, 8, 4, 1, 2, 2, 1, 3, 1, 5, 2, 3, 3, 2, 4, 1, 3, 2, 4, 2, 1, 3, 1, 1, 4, 1, 3, 1, 1, 1, 1, 1, 1, 4, 1, 2, 2, 1, 3, 1, 2, 1, 1, 1, 2, 3, 3, 8, 2, 7, 2, 7, 3, 2, 1, 2, 11, 2, 2, 2, 2, 4, 2, 4, 4, 2, 12, 2, 4, 2, 1, 3, 1, 0, 4, 9, 3, 4, 6, 3, 0, 3, 1, 1, 6, 1, 5, 2, 13, 4, 2, 5, 1, 3, 9, 5, 5, 7, 9, 2, 3, 3, 5, 3, 20, 6, 3, 9, 2, 3, 2, 3, 11, 3, 0, 16, 3, 27, 27, 28, 5, 4, 5, 5, 1, 0, 4, 37, 17, 5, 4, 4, 5, 3, 7, 5, 17, 8, 6, 8, 3, 3, 5, 11, 6, 92, 51, 1, 2, 31, 15, 4, 4, 3, 33, 55, 1, 1, 59, 15, 3, 28, 20, 15, 12, 10, 2, 9, 6, 7, 47, 51, 1, 1, 0, 0, 16, 4, 33, 29, 3, 13, 4, 3, 4, 2, 63, 53, 2, 1, 2, 0, 0, 0, 11, 11, 10, 4, 13, 9, 1, 0, 0, 2, 12, 3, 4, 3, 41, 3, 12, 3, 3, 21, 11, 1, 0, 0, 0, 0, 0, 0, 28, 11, 11, 6, 3, 2, 3, 1, 27, 11, 0, 0, 0, 0, 0, 0, 0, 3, 5, 7, 20, 13, 0, 0, 0, 0, 0, 0, 20, 4, 8, 1, 8, 7, 0, 0, 0, 0, 0, 4, 3, 3, 10, 11, 5, 0, 0, 0, 0, 4, 5, 2, 2, 3, 10, 1, 0, 0, 7, 6, 5, 0, 5, 6, 4, 0, 0, 1, 1, 3, 0, 2, 8, 1, 2, 6, 3, 2, 0, 0, 4, 4, 1, 0, 6, 14, 0, 0, 0, 153, 9, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 25, 10, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 4, 1, 2, 3, 3, 9, 8, 13, 4, 3, 1, 44, 4, 2, 4, 5, 7, 57, 2, 2, 7, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 3, 2, 3, 1, 1, 2, 3, 8, 7, 8, 2, 1, 11, 2, 4, 3, 26, 3, 8, 41, 1, 1, 4, 2, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 2, 1, 0, 1, 2, 1, 0, 0, 0, 0, 2, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 1, 2, 1, 3, 1, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 2, 1, 0, 1, 1, 1, 1, 1, 3, 5, 1, 2, 23, 3, 2, 3, 1, 1, 1, 1, 2, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 2, 0, 0, 1, 0, 1, 2, 1, 1, 4, 3, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 2, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 1, 0, 1, 4, 2, 18, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 5, 2, 16, 1, 1, 71, 22, 1, 1, 1, 4, 1, 8, 3, 1, 5, 1, 0, 0, 0, 3, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 2, 7, 1, 1, 15, 1, 1, 1, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 1, 29, 36847, 17649, 10044, 3343, 29244, 333, 612, 30, 12, 233, 262, 1642, 4383, 6898, 354, 11, 1, 14244, 1976, 1617, 14376, 52, 616, 363, 1720, 1961, 2285, 5973, 18415, 479, 493, 427, 3886, 302, 8672, 302, 481, 1040, 3538, 9178, 2072, 7543, 4874, 483, 3381, 406, 1560, 203, 709, 1635, 658, 398, 1310, 28215, 28768, 5, 1548, 639, 2265, 3914, 1549, 2891, 2603, 484, 639, 990, 1763, 640, 44, 8, 1, 34, 32, 407, 15, 0, 0, 0, 0, 1559, 0, 989, 921, 728, 204, 640, 917, 1, 1636, 482, 1548, 922, 399, 1339, 1983, 1, 48995, 1, 116000, 1, 134328, 5793, 9297, 13308, 15341, 549, 4323, 1917, 564, 1150, 9338, 1056, 1, 2653, 2372, 2, 1061, 792, 37, 4, 5, 394, 2991, 3, 890, 802, 764, 9, 1572, 3473, 674, 7, 4246, 1276, 1, 451, 602, 135, 2, 693, 6, 715, 254, 23, 8, 1, 257, 21160, 21986, 14204, 14560, 4382, 5105, 8479, 2760, 2271, 10672, 2565, 1211, 1240, 2252, 3520, 3434, 1326, 821, 945, 647, 4174, 1231, 895, 823, 536, 1667, 1460, 271, 26, 4867, 2948, 8933, 1838, 1216, 913, 1954, 1115, 576, 521, 1165, 964, 7900, 9449, 2380, 3023, 1077, 6377, 2299, 5, 552, 275, 1290, 3, 1007, 4, 19, 537, 13526, 3824, 2116, 1884, 7424, 911, 724, 3890, 4, 3, 1090, 9, 9, 491, 11, 14, 1314, 826, 342, 713, 7553, 6427, 278, 14087, 2131, 2022, 1337, 570, 463, 1453, 25, 8, 945, 1873, 1816, 4, 15, 43, 1953, 3306, 2815, 29, 7, 480, 2556, 34, 972, 816, 1079, 1225, 1265, 915, 14, 17, 2832, 2, 2, 4, 2072, 1251, 7, 1727, 1770, 688, 518, 1, 1165, 3, 4149, 9000, 340, 815, 658, 482, 827, 653, 744, 1325, 2820, 3, 1566, 2, 13, 24, 1097, 17, 6, 11011, 884, 1008, 511, 1232, 2073, 1264, 1660, 1217, 1212, 306, 369, 666, 1, 1078, 2761, 914, 5, 569, 1155, 7, 271, 737, 4618, 2885, 969, 3, 177, 5, 5366, 4223, 1974, 5661, 1722, 5775, 1430, 7317, 887, 786, 1901, 2226, 3117, 8968, 1380, 985, 3060, 1840, 3424, 2997, 2801, 5136, 5, 1264, 1241, 570, 554, 1730, 2892, 2606, 341, 3609, 680, 372, 4224, 912, 816, 2132, 1975, 988, 4581, 1036, 1081, 1721, 2097, 2, 1241, 659, 1124, 978, 1009, 554, 4025, 2300, 1971, 529, 483, 1087, 915, 3462, 718, 512, 1125, 1338, 4225, 1431, 1976, 828, 1, 1233, 3099, 1951, 2795, 3689, 4233, 1273, 492, 571, 464, 654, 888, 4, 793, 2385, 1658, 2370, 465, 516, 1323, 1261, 701, 4, 1902, 8, 3668, 3, 1419, 956, 793, 482, 3573, 5, 930, 8, 3, 732, 1254, 968, 921, 1114, 3, 2122, 2, 653, 15, 1164, 0, 7, 2, 967, 3, 0, 3825, 738, 6024, 18, 2979, 2, 811, 4, 1977, 1, 365, 2992, 1528, 6560, 7185, 1501, 1262, 2090, 2204, 2, 1, 978, 151, 360, 3788, 1414, 6869, 972, 1119, 922, 822, 851, 6693, 6, 1785, 1736, 2592, 1115, 1046, 2202, 870, 2595, 713, 1527, 2298, 1974, 9573, 7580, 2, 1805, 2374, 0, 3795, 5151, 664, 13186, 1550, 1214, 9, 1126, 4, 169, 0, 1, 8, 1950, 3425, 5, 272, 4, 15518, 2312, 6329, 4576, 3404, 5091, 5, 2098, 0, 1534, 7, 0, 0, 9381, 3461, 4932, 38467, 4059, 3998, 6028, 4, 912, 3, 956, 492, 4, 0, 722, 1, 885, 11469, 1396, 1736, 1395, 1279, 640, 8, 11, 0, 2, 2127, 2836, 1342, 719, 7597, 884, 4, 824, 2133, 725, 0, 57306, 7143, 2206, 655, 24546, 3582, 9540, 4919, 3531, 1490, 1, 1, 10, 1, 1, 231, 2, 0, 0, 0, 4, 0, 2, 13179, 2121, 3070, 1004, 37524, 3287, 9503, 5116, 1926, 589, 1323, 0, 6, 0, 0, 0, 1, 3242, 1228, 19488, 1268, 2118, 895, 3494, 6, 0, 0, 0, 2, 515, 6507, 542, 447, 3, 3866, 823, 603, 434, 1519, 1265, 651, 1, 24010, 56547, 16185, 9804, 674, 2940, 409, 1114, 1976, 5, 625, 0, 21, 4, 24951, 7679, 9831, 519, 1069, 10, 645, 8, 2, 1, 0, 72963, 32143, 1340, 4470, 1814, 2221, 701, 8, 2071, 1, 15, 676, 2, 75510, 15522, 14636, 7296, 3561, 1109, 662, 1534, 556, 9, 0, 2, 21, 2, 3, 42128, 50193, 18794, 9056, 5887, 990, 8364, 1268, 884, 1662, 1657, 11, 1, 903, 3, 1, 2, 386, 108, 34610, 13891, 7831, 4068, 1136, 485, 5, 1758, 2, 836, 1, 8, 9, 49748, 16832, 11766, 12826, 6973, 4350, 1323, 400, 2483, 4, 1046, 1278, 730, 9, 1, 582, 3, 1323, 4, 457, 51, 24340, 23161, 14062, 6737, 6286, 5017, 1608, 3720, 2126, 1589, 616, 1574, 530, 947, 1685, 7, 659, 13, 10, 3, 18, 313, 22349, 23367, 1402, 6, 1751, 1625, 8894, 275, 3258, 1793, 8, 10, 958, 12, 30247, 8271, 3374, 2922, 1424, 7038, 2981, 2708, 1841, 5298, 1724, 359, 4, 1127, 712, 3, 4, 730, 533, 22374, 2638, 8464, 3133, 16032, 5046, 7578, 4353, 3356, 5243, 1329, 1241, 353, 12, 724, 7, 6, 648, 413, 4, 6, 1212, 68, 6789, 9754, 2662, 11115, 4738, 4969, 5513, 1129, 3031, 277, 5, 1223, 1037, 11, 561, 3, 8, 1314, 1571, 5464, 5333, 6676, 605, 1366, 4929, 14, 1108, 7, 9, 2535, 15294, 1941, 1261, 2772, 26, 7825, 2222, 1656, 966, 776, 3361, 875, 2292, 3740, 1942, 896, 918, 624, 11, 1098, 988, 3, 3103, 5, 5, 393, 6626, 9562, 11822, 20374, 9853, 3499, 1, 753, 2930, 1272, 735, 656, 1285, 1902, 963, 751, 5, 1736, 6698, 1214, 12185, 1412, 836, 833, 689, 1832, 1171, 647, 12601, 13750, 7425, 2394, 1034, 762, 18155, 13243, 1472, 1622, 512, 7, 1311, 2108, 376, 11, 2892, 3042, 39589, 14013, 2808, 8509, 2194, 7, 1166, 1320, 539, 1817, 538, 1273, 7, 665, 1957, 35, 1976, 3103, 1036, 754, 1384, 840, 273, 2128, 1576, 21486, 1776, 12675, 16732, 7, 3, 2828, 7190, 3713, 5, 1659, 3385, 358, 886, 911, 906, 8, 3, 19, 556, 1724, 510, 1292, 4, 21, 180, 493, 4494, 12478, 3256, 4670, 6434, 1161, 2250, 1663, 3845, 1173, 1769, 1097, 3271, 992, 884, 921, 4140, 3591, 2825, 1171, 716, 1974, 3733, 834, 1776, 824, 1131, 647, 2307, 913, 927, 962, 7622, 2614, 1917, 3744, 7, 6175, 1224, 1224, 1672, 5051, 1812, 1428, 1583, 1090, 3137, 497, 2185, 2374, 1572, 521, 2449, 10, 705, 1128, 801, 3612, 4275, 1531, 563, 1805, 3, 13, 4395, 7494, 4, 655, 13, 6, 1417, 683, 9, 1167, 1171, 2613, 779, 552, 1467, 830, 1271, 1023, 5, 11, 3701, 2818, 914, 2299, 1001, 691, 4435, 2508, 3869, 1130, 488, 3636, 725, 1434, 2287, 3255, 1669, 488, 3976, 2612, 1086, 1316, 797, 1618, 535, 1043, 1246, 1668, 2684, 832, 655, 1666, 13, 898, 2540, 572, 258, 2289, 913, 1240, 10, 7, 4288, 4664, 571, 2164, 487, 4103, 1893, 1465, 2320, 1244, 554, 682, 1156, 1341, 1466, 1272, 1548, 5, 1318, 646, 2378, 5103, 2107, 856, 2682, 2087, 690, 1824, 257, 881, 520, 9, 1, 1446, 1819, 1301, 3807, 1127, 496, 4231, 1903, 2692, 7535, 796, 1223, 2949, 274, 650, 1875, 9, 19, 553, 3, 3624, 987, 681, 3872, 414, 1085, 1818, 1157, 1701, 1832, 549, 2523, 12, 835, 6804, 1394, 2147, 1335, 1313, 1819, 3218, 3229, 10438, 9347, 1, 3590, 1273, 7652, 5, 548, 1734, 3551, 1535, 2306, 1671, 1270, 4199, 8399, 2273, 1293, 829, 3763, 1490, 273, 2086, 9613, 9123, 1976, 5372, 1763, 0, 8189, 10523, 106179, 98870, 2711, 5, 1, 323, 168, 2, 135, 854, 1, 2, 545, 340, 0, 888, 451, 725, 1200, 2049, 328, 1511, 60, 332, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17378, 978, 2661, 476, 2898, 371, 1084, 2586, 6405, 814, 178, 253, 2242, 240, 264, 350, 486, 2084, 3702, 251, 1507, 1613, 1281, 1364, 900, 1818, 7588, 7808, 2619, 15729, 2333, 1612, 6068, 202, 120, 0, 0, 0, 384, 2733, 1696, 338, 686, 1436, 1199, 1031, 436, 470, 599, 578, 1867, 554, 393, 3127, 1198, 480, 849, 609, 383, 360, 12, 1540, 2107, 1232, 597, 520, 0, 477, 1143, 756, 275, 940, 1483, 324, 169, 372, 168, 1541, 339, 478, 440, 363, 284, 2106, 687, 1541, 1043, 1, 191, 607, 2108, 623, 1320, 602, 2262, 1024, 1994, 582, 1, 0, 190, 401, 411, 1142, 1540, 596, 177, 606, 252, 1707, 535, 853, 239, 263, 349, 2, 0, 485, 299, 898, 0, 1005, 1030, 338, 1, 1091, 5, 399, 604, 2392, 484, 519, 347, 852, 0, 1238, 479, 1778, 3564, 265, 1033, 11, 0, 0, 1540, 755, 250, 17, 274, 897, 1055, 450, 623, 398, 611, 502, 1377, 784, 469, 225, 660, 868, 622, 698, 664, 622, 395, 3421, 1757, 3745, 1075, 0, 2251, 577, 858, 1058, 166, 7472, 3334, 6733, 1621, 1113, 2516, 5040, 9655, 1655, 3613, 506, 212, 0, 15802, 911, 2088, 19825, 28245, 22153, 228, 650, 278, 14014, 12675, 47976, 621, 87, 58841, 44127, 2337, 0, 58007, 881, 103127, 178, 19, 1, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 1, 0, 2, 1, 4, 2, 3, 1, 2, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 38, 18, 5, 2, 3, 4, 2, 52, 27, 25, 11, 1, 1, 23, 8, 1, 7, 2, 27, 24, 4, 16, 3, 2, 2, 2, 16, 21, 39, 12, 1, 4, 2, 4, 30, 11, 11, 2, 7, 7, 1, 4, 4, 1, 4, 2, 3, 11, 4, 1, 1, 1, 3, 8, 7, 3, 1, 8, 1, 1, 3, 1, 3, 0, 0, 1, 23, 17, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 53, 10, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 27, 5, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 2, 0, 0, 1, 1, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 2, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 3, 0, 1, 1, 1, 1, 9, 2, 1, 1, 1, 2, 2, 21, 5, 3, 1, 1, 3, 2, 3, 2, 2, 1, 1, 7, 1, 1, 4, 1, 3, 2, 1, 5, 1, 1, 0, 0, 0, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 6, 2, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 3, 7, 10, 5, 10, 2, 2, 3, 1, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 6, 1, 3, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 5, 5, 5, 1, 5, 3, 2, 1, 32, 11, 11, 1, 17, 7, 4, 8, 54, 22, 2, 1, 3, 13, 11, 40, 5, 26, 45, 5, 9, 3, 11, 15, 21, 10, 18, 25, 6, 9, 9, 18, 13, 24, 34, 7, 28, 2, 5, 1, 1, 3, 2, 5, 3, 0, 0, 2, 5, 0, 0, 0, 0, 0, 5, 2, 4, 9, 4, 0, 0, 0, 0, 14, 1, 3, 8, 0, 0, 0, 0, 0, 0, 10, 18, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 27, 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 3, 1, 1, 1, 1, 1, 5, 4, 1, 1, 2, 5, 3, 4, 1, 19, 1, 8, 2, 1, 2, 1, 2, 2, 1, 1, 6, 2, 1, 1, 1, 3, 4, 3, 2, 1, 25, 1, 7, 1, 2, 5, 2, 2, 2, 2, 3, 22, 2, 1, 2, 1, 3, 4, 7, 2, 3, 26, 1, 1, 1, 3, 2, 2, 1, 3, 2, 1, 3, 9, 4, 1, 3, 2, 3, 5, 8, 1, 2, 1, 2, 3, 5, 20, 1, 2, 4, 52, 2, 1, 2, 1, 1, 4, 2, 1, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 0, 0, 0, 1, 0, 2, 1, 3, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 1, 1, 0, 1, 0, 3, 1, 0, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 0, 1, 0, 2, 4, 2, 0, 0, 2, 0, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 3, 1, 5, 2, 2, 11, 3, 4, 8, 1, 1, 1, 8, 9, 12, 14, 9, 4, 12, 15, 32, 5, 2, 5, 25, 1, 2, 4, 1, 1, 0, 0, 0, 2, 1, 0, 1, 0, 0, 0, 1, 3, 4, 0, 0, 0, 7, 3, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 2, 0, 1, 0, 2, 1, 1, 5, 2, 0, 0, 0, 0, 0, 0, 1, 5, 1, 2, 1, 8, 7, 2, 1, 1, 1, 57, 20, 256, 27, 1, 2, 3, 1, 529, 9, 10, 6, 2, 2, 2, 7, 3, 5, 71, 50, 28, 5, 10, 106, 51, 60, 87, 72, 61, 18, 14, 23, 9, 28, 7, 6, 3, 5, 7, 9, 6, 4, 15, 2, 4, 11, 5, 5, 4, 1, 14, 1, 1, 5, 15, 17, 7, 17, 74, 68, 23, 52, 43, 44, 84, 96, 68, 106, 81, 25, 23, 24, 3, 10, 8, 7, 1, 6, 1, 1, 3, 11, 3, 2, 26, 2, 7, 3, 3, 4, 3, 16, 6, 17, 8, 11, 8, 2, 25, 4, 19, 22, 16, 2, 4, 16, 14, 19, 62, 11, 3, 3, 2, 1, 2, 1, 0, 0, 9, 5, 4, 6, 4, 5, 4, 0, 5, 6, 1, 7, 2, 1, 0, 0, 15, 17, 4, 9, 13, 6, 1, 6, 3, 2, 2, 0, 8, 25, 30, 3, 2, 7, 0, 3, 35, 7, 16, 4, 2, 0, 36, 49, 36, 41, 23, 29, 2, 5, 2, 2, 1, 3, 1, 1, 0, 0, 71, 58, 13, 35, 1, 2, 6, 5, 15, 4, 7, 9, 1, 0, 0, 124, 44, 22, 26, 11, 30, 1, 6, 6, 2, 4, 5, 1, 1, 1, 0, 0, 0, 0, 184, 94, 61, 58, 20, 12, 14, 16, 3, 1, 28, 6, 2, 1, 4, 2, 3, 1, 1, 1, 0, 0, 0, 0, 0, 124, 87, 36, 42, 4, 16, 20, 13, 7, 1, 9, 1, 2, 2, 1, 2, 4, 2, 2, 1, 3, 1, 0, 0, 0, 0, 162, 41, 28, 28, 20, 13, 6, 11, 2, 10, 1, 1, 6, 4, 4, 0, 0, 0, 0, 0, 0, 83, 33, 68, 13, 39, 15, 13, 17, 10, 4, 29, 4, 6, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 34, 52, 32, 12, 15, 28, 25, 12, 3, 2, 24, 5, 4, 4, 1, 4, 1, 9, 1, 0, 0, 0, 0, 0, 60, 31, 13, 26, 3, 6, 5, 18, 2, 2, 4, 4, 3, 0, 0, 0, 0, 76, 35, 44, 5, 8, 11, 17, 13, 4, 2, 3, 2, 0, 0, 0, 0, 31, 40, 26, 37, 3, 11, 23, 14, 15, 6, 17, 5, 5, 2, 2, 5, 2, 2, 1, 0, 0, 0, 6, 15, 48, 19, 6, 13, 33, 14, 5, 2, 1, 3, 3, 3, 0, 0, 40, 33, 4, 6, 10, 34, 3, 2, 2, 7, 2, 2, 0, 0, 18, 40, 35, 9, 4, 15, 4, 9, 9, 3, 1, 0, 0, 0, 38, 39, 18, 16, 37, 6, 11, 5, 5, 2, 2, 1, 0, 0, 0, 0, 0, 0, 56, 18, 18, 9, 1, 2, 1, 0, 0, 0, 0, 0, 43, 65, 8, 7, 4, 12, 1, 2, 3, 8, 1, 0, 0, 0, 34, 37, 33, 4, 16, 10, 7, 5, 1, 0, 0, 0, 0, 81, 57, 22, 13, 2, 4, 3, 1, 0, 0, 0, 95, 49, 50, 34, 34, 8, 4, 10, 1, 0, 0, 0, 0, 0, 0, 0, 0, 69, 17, 13, 33, 13, 9, 5, 14, 5, 1, 0, 0, 0, 0, 0, 0, 41, 28, 22, 18, 10, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 59, 30, 20, 1, 3, 20, 2, 5, 1, 1, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 60, 32, 7, 2, 13, 10, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 84, 32, 5, 23, 10, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 16, 44, 37, 1, 1, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 27, 34, 3, 2, 2, 0, 0, 0, 0, 1, 25, 2, 0, 0, 0, 61, 2, 1, 1, 15, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 9, 5, 4, 31, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 0, 0, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 6, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 1, 0, 0, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 4, 0, 3, 1, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 9, 4, 1, 1, 1, 1, 1, 1, 3, 2, 1, 2, 2, 1, 1, 1, 1, 2, 2, 1, 2, 3, 1, 1, 1, 1, 4, 1, 4, 1, 1, 3, 1, 1, 2, 1, 1, 2, 1, 1, 3, 4, 2, 2, 1, 3, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 2, 2, 1, 1, 0, 0, 0, 5, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 16, 1, 0, 0, 1, 1, 15, 0, 0, 0, 0, 0, 1, 1, 3, 3, 1, 0, 0, 0, 0, 0, 0, 2, 3, 4, 5, 6, 1, 12, 2, 1, 6, 0, 0, 1, 0, 2, 4, 1, 0, 8, 2, 4, 3, 4, 3, 1, 4, 0, 0, 0, 0, 0, 1, 3, 6, 3, 1, 3, 2, 1, 1, 1, 2, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 3, 2, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 2, 4, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 2, 3, 3, 1, 1, 2, 7, 3, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 1, 1, 0, 0, 0, 0, 2, 6, 5, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 1, 3, 1, 3, 2, 5, 1, 1, 1, 4, 2, 4, 1, 4, 1, 1, 1, 9, 7, 1, 1, 1, 1, 1, 110, 8, 3, 4, 3, 22, 35, 14, 51, 7, 22, 15, 78, 147, 95, 4, 5, 2, 10, 11, 16, 5, 22, 37, 5, 4, 1, 1, 2, 0, 1, 4, 4, 3, 1, 0, 11, 6, 7, 0, 7, 15, 5, 0, 39, 32, 0, 0, 0, 98, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 2, 460, 78, 351, 102, 87, 76, 4, 35, 4, 92, 24, 19, 23, 33, 168, 58, 3507, 6119, 1, 70, 132, 280, 67, 14, 128, 306, 103, 87, 2, 78, 0, 1, 0, 0, 1, 0, 75, 15, 23, 102, 18, 24, 35, 145, 27, 61, 4447, 2413, 1148, 7, 37, 248, 5081, 2086, 2248, 240, 118, 201, 755, 384, 336, 105, 163, 36, 54, 182, 2, 91, 528, 38, 93, 62, 56, 66, 142, 21, 103, 226, 150, 153, 166, 39, 25, 46, 328, 4586, 286, 1186, 225, 101, 34, 59, 52, 75, 113, 320, 304, 208, 197, 362, 5, 48, 35, 1, 8, 287, 38, 226, 25, 959, 2381, 290, 33, 587, 236, 171, 81, 28, 118, 161, 56, 38, 113, 106, 334, 26, 432, 211, 89, 32, 133, 291, 794, 202, 155, 346, 228, 180, 176, 161, 120, 29, 99, 60, 214, 13, 28, 50, 72, 196, 40, 2, 376, 120, 368, 421, 993, 239, 232, 68, 68, 27, 271, 144, 72, 40, 114, 501, 297, 34, 288, 129, 130, 180, 159, 232, 145, 844, 57, 160, 29, 160, 163, 24, 24, 363, 6, 2, 2, 94, 153, 91, 30, 156, 291, 19, 44, 58, 81, 14, 211, 42, 93, 4, 70, 33, 31, 36, 465, 120, 119, 10, 199, 59, 38, 88, 197, 295, 103, 36, 54, 45, 18, 103, 184, 117, 374, 96, 290, 114, 37, 76, 30, 30, 2, 78, 111, 16, 276, 323, 109, 194, 134, 75, 66, 167, 121, 94, 87, 61, 97, 68, 4, 199, 51, 133, 212, 10, 84, 23, 59, 282, 291, 132, 95, 31, 82, 40, 448, 28, 5, 34, 42, 111, 15, 4, 26, 162, 164, 71, 83, 139, 21, 56, 39, 29, 108, 2, 2, 25, 441, 119, 6, 28, 1, 108, 49, 197, 138, 106, 142, 200, 6, 13, 13, 83, 161, 182, 29, 340, 38, 50, 292, 78, 133, 143, 37, 29, 39, 35, 73, 29, 96, 57, 255, 28, 379, 136, 23, 78, 35, 188, 0, 56, 100, 166, 110, 87, 80, 88, 137, 398, 114, 74, 224, 383, 82, 219, 21, 14, 77, 67, 5, 55, 333, 223, 3, 44, 14, 188, 147, 333, 321, 477, 269, 39, 1079, 83, 13, 494, 278, 162, 46, 40, 25, 498, 5, 25, 50, 66, 33, 109, 108, 483, 338, 278, 154, 361, 990, 517, 25, 11, 126, 816, 94, 79, 288, 476, 74, 357, 340, 71, 1662, 188, 47, 356, 1347, 62, 261, 1068, 0, 320, 1029, 0, 2454, 3372, 274, 64, 85, 18, 267, 45, 34, 83, 35, 207, 120, 29, 90, 127, 63, 25, 54, 67, 27, 17, 79, 9, 16, 26, 195, 23, 9, 17, 36, 27, 86, 21, 10, 7, 225, 66, 209, 123, 255, 4849, 0, 0, 0, 0, 0, 0, 34, 71, 30, 102, 84, 50, 155, 59, 38, 43, 72, 200, 75, 66, 34, 75, 42, 56, 68, 19, 51, 25, 137, 293, 1387, 85, 29, 45, 110, 33, 63, 51, 31, 86, 29, 38, 1, 142, 85, 84, 195, 48, 32, 34, 35, 82, 49, 36, 40, 41, 51, 112, 33, 118, 1, 71, 49, 0, 58, 81, 37, 28, 35, 83, 42, 23, 63, 1, 62, 128, 48, 39, 17, 46, 71, 96, 104, 24, 76, 65, 17, 95, 0, 33, 26, 79, 76, 16, 68, 37, 8, 15, 34, 16, 25, 77, 11, 107, 24, 78, 95, 87, 0, 18, 35, 17, 23, 25, 140, 41, 131, 64, 90, 9, 103, 144, 24, 22, 109, 160, 63, 106, 3, 210, 69, 748, 1353, 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 3, 1, 8, 2, 1, 1, 3, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 2, 0, 0, 1, 0, 4, 0, 1, 0, 1, 1, 18, 1529, 2641, 436, 179, 147, 219, 411, 135, 1117, 1189, 14095, 22057, 2, 149, 836, 560, 364, 75, 799, 1589, 70, 235, 135, 124, 128, 148, 365, 218, 216, 199, 138, 691, 432, 928, 347, 18573, 12599, 6827, 3255, 3302, 9088, 138, 239, 2685, 5511, 888, 45, 2014, 3308, 2078, 602, 2, 841, 415, 360, 152, 1769, 912, 336, 624, 514, 11, 406, 558, 1267, 531, 1257, 209, 806, 1495, 758, 758, 2156, 1486, 1206, 1465, 276, 725, 1030, 188, 3699, 947, 125, 862, 409, 19, 877, 105, 697, 187, 776, 75, 793, 19, 8, 19, 179, 68, 113, 3245, 2748, 694, 655, 261, 1866, 417, 697, 1272, 71, 125, 109, 201, 95, 5, 294, 64, 1080, 276, 568, 466, 158, 263, 153, 179, 527, 1755, 178, 468, 61, 864, 560, 163, 2, 209, 552, 683, 343, 308, 211, 356, 62, 257, 30, 589, 925, 2, 313, 185, 10, 1281, 368, 260, 369, 338, 332, 181, 135, 1173, 439, 1621, 353, 1153, 33, 141, 163, 42, 1, 391, 164, 14, 141, 4, 1086, 1404, 505, 675, 578, 261, 215, 481, 543, 60, 345, 295, 253, 466, 89, 1042, 67, 1063, 648, 301, 309, 53, 383, 162, 108, 737, 353, 366, 68, 3, 172, 139, 235, 5, 6, 631, 1002, 244, 364, 693, 283, 239, 370, 562, 95, 4, 179, 1267, 592, 573, 780, 267, 67, 1428, 151, 534, 423, 402, 799, 517, 126, 354, 968, 948, 3, 116, 41, 5, 96, 642, 495, 171, 43, 418, 344, 506, 168, 56, 324, 46, 91, 741, 541, 263, 321, 341, 562, 474, 276, 502, 355, 428, 262, 62, 195, 433, 143, 467, 548, 478, 318, 318, 363, 185, 677, 353, 573, 379, 1378, 125, 92, 542, 602, 6, 742, 434, 282, 347, 258, 985, 780, 4, 134, 228, 238, 41, 347, 228, 743, 229, 164, 226, 47, 104, 781, 435, 3, 262, 236, 245, 3, 144, 126, 353, 216, 490, 468, 744, 196, 482, 283, 187, 35, 348, 361, 549, 266, 153, 419, 397, 880, 259, 470, 542, 590, 307, 408, 646, 92, 68, 562, 1640, 499, 197, 105, 425, 640, 135, 36, 55, 781, 420, 459, 217, 101, 483, 214, 412, 398, 59, 178, 210, 129, 564, 345, 210, 56, 110, 349, 47, 12, 405, 344, 339, 484, 152, 319, 264, 154, 296, 97, 782, 349, 237, 116, 249, 744, 405, 3, 203, 725, 399, 4, 1186, 1639, 364, 89, 535, 157, 213, 217, 136, 480, 85, 65, 1471, 17, 1066, 590, 467, 340, 430, 60, 41, 94, 64, 857, 4, 609, 685, 366, 648, 241, 246, 745, 342, 3, 177, 409, 404, 198, 295, 786, 15, 921, 879, 2, 239, 386, 133, 832, 63, 198, 16, 78, 498, 625, 258, 37, 1336, 131, 660, 342, 229, 186, 474, 1389, 212, 745, 419, 334, 312, 473, 103, 489, 251, 109, 26, 202, 398, 616, 506, 596, 103, 319, 473, 48, 0, 355, 163, 1917, 161, 1140, 461, 444, 720, 1209, 2280, 884, 1374, 1380, 3, 340, 72, 272, 485, 2668, 142, 1916, 727, 944, 181, 226, 413, 175, 17, 61, 168, 187, 427, 218, 1891, 405, 1132, 733, 1487, 2233, 1373, 125, 225, 1222, 147, 160, 244, 392, 18, 74, 91, 1103, 686, 182, 2566, 1825, 184, 596, 276, 423, 85, 35, 300, 145, 50, 239, 1, 65, 1138, 626, 1, 167, 1267, 178, 90, 0, 798, 2060, 806, 422, 462, 530, 0, 0, 12, 114, 68, 2096, 1573, 738, 394, 2054, 94, 586, 250, 527, 40, 599, 38, 3043, 2447, 1697, 554, 2661, 394, 705, 412, 52, 7005, 3187, 3837, 4758, 2326, 517, 1232, 185, 1061, 243, 442, 468, 401, 67, 73, 54, 3083, 6231, 4330, 70, 139, 856, 262, 522, 370, 178, 640, 6424, 2406, 60, 497, 123, 111, 40, 75, 14111, 786, 3155, 243, 1591, 931, 1358, 251, 239, 21, 292, 186, 22, 272, 251, 285, 160, 58, 47, 584, 0, 1388, 6481, 2602, 3775, 7306, 4116, 340, 1227, 740, 1198, 1127, 163, 567, 199, 614, 592, 1006, 720, 36, 218, 901, 466, 388, 108, 727, 677, 103, 2579, 1183, 354, 304, 127, 108, 20, 397, 779, 3206, 2334, 2925, 160, 1723, 36, 912, 886, 18, 260, 659, 651, 493, 429, 585, 1226, 277, 783, 354, 140, 518, 607, 360, 160, 309, 2809, 2327, 161, 111, 2419, 564, 4, 864, 1448, 202, 19, 829, 137, 49, 694, 136, 358, 291, 164, 2597, 542, 5982, 724, 243, 3, 271, 955, 1672, 381, 188, 3, 422, 278, 475, 484, 116, 355, 649, 625, 591, 78, 2548, 228, 186, 118, 426, 220, 1996, 2486, 94, 2163, 2834, 218, 1643, 104, 384, 245, 5, 920, 250, 960, 736, 184, 151, 261, 772, 136, 408, 735, 88, 776, 8, 1087, 134, 267, 297, 3343, 221, 928, 307, 712, 373, 909, 367, 327, 390, 154, 2184, 757, 248, 663, 520, 409, 725, 135, 3, 392, 128, 3740, 74, 679, 272, 98, 741, 331, 2542, 263, 594, 240, 378, 296, 786, 264, 222, 325, 340, 302, 907, 2537, 355, 404, 374, 556, 641, 393, 6, 758, 344, 887, 17, 1482, 104, 582, 286, 127, 99, 273, 238, 220, 806, 538, 5054, 217, 161, 238, 475, 182, 551, 1040, 457, 671, 129, 257, 189, 247, 403, 474, 395, 491, 189, 155, 568, 274, 664, 320, 487, 198, 662, 183, 749, 371, 938, 740, 394, 246, 378, 591, 297, 18, 7, 154, 473, 550, 400, 787, 567, 212, 421, 343, 216, 182, 179, 61, 355, 1022, 661, 477, 441, 537, 1016, 16, 249, 485, 1426, 297, 184, 1356, 382, 1337, 467, 247, 2487, 393, 484, 273, 735, 250, 140, 374, 1699, 279, 261, 537, 221, 1863, 227, 889, 278, 150, 195, 743, 556, 734, 217, 399, 943, 262, 639, 391, 2511, 765, 601, 472, 1059, 4735, 181, 1126, 503, 358, 346, 242, 601, 244, 4152, 203, 2428, 356, 355, 372, 1735, 523, 840, 1025, 343, 1076, 114, 1285, 135, 936, 1982, 391, 1744, 10371, 1488, 228, 7016, 390, 407, 4078, 763, 1132, 8024, 22834, 434, 43, 706, 415, 19, 440, 111, 1039, 32, 61, 24, 4, 13, 10, 473, 334, 66, 79, 320, 323, 889, 207, 635, 96, 418, 658, 167, 256, 210, 300, 12674, 0, 0, 0, 0, 0, 0, 928, 251, 46, 1027, 1150, 1107, 207, 1307, 92, 42, 118, 121, 570, 146, 181, 294, 54, 932, 445, 258, 530, 389, 327, 159, 359, 448, 194, 30, 663, 420, 889, 451, 8387, 75, 272, 1001, 203, 48, 45, 42, 212, 16, 170, 35, 1289, 71, 152, 370, 176, 59, 106, 154, 260, 209, 20, 158, 280, 231, 157, 713, 318, 230, 239, 96, 339, 170, 1264, 213, 126, 41, 117, 231, 120, 88, 389, 158, 355, 23, 6, 180, 39, 238, 293, 157, 4, 53, 68, 366, 499, 243, 171, 795, 182, 956, 256, 87, 320, 255, 78, 237, 497, 334, 346, 389, 322, 388, 45, 169, 89, 367, 1434, 158, 433, 365, 92, 271, 1541, 537, 594, 168, 247, 1230, 363, 155, 245, 862, 2516, 1254, 595, 1346, 2067, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 1, 2, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 2, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 6, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 0, 0, 1, 1, 1, 1, 2, 3, 4, 16, 5, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 5, 2, 4, 0, 0, 0, 0, 0, 2, 0, 3, 1, 1, 0, 1, 0, 0, 0, 1, 0, 1, 2, 3, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 1, 1, 0, 0, 12, 6, 0, 1, 0, 1, 0, 2, 2, 0, 0, 0, 1, 0, 1, 1, 2, 0, 0, 0, 1, 1, 3, 12, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 2, 0, 2, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 5, 1, 8, 1, 98, 47, 1, 8, 2, 107, 18, 10, 3, 1, 2, 3, 1, 1, 5, 2, 2, 1, 1, 7, 1, 0, 13, 1, 25, 3, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 1, 3, 5, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 4, 10, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 2, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 2, 1, 0, 1, 2, 0, 0, 0, 1, 0, 2, 1, 0, 0, 0, 2, 0, 0, 3, 0, 0, 1, 0, 2, 1, 1, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 10, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 6, 0, 1, 1, 0, 0, 1, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 1, 2, 2, 0, 0, 0, 1, 0, 1, 2, 0, 0, 0, 4, 2, 1, 120, 72, 34, 27, 4, 1, 2, 1, 3, 3, 8, 2, 7, 2, 2, 2, 38, 30, 20, 5, 2, 71, 28, 19, 5, 4, 2, 4, 1, 3, 7, 6, 2, 9, 53, 53, 11, 1, 1, 1, 56, 28, 3, 37, 5, 14, 19, 40, 21, 35, 1, 1, 1, 1, 1, 22, 4, 13, 20, 6, 4, 9, 15, 19, 1, 49, 10, 4, 3, 3, 1, 1, 2, 14, 6, 28, 6, 4, 9, 39, 17, 8, 5, 3, 5, 1, 2, 5, 2, 5, 1, 7, 2, 9, 17, 5, 8, 10, 2, 6, 2, 6, 13, 12, 2, 14, 4, 2, 1, 1, 15, 2, 3, 6, 2, 1, 4, 2, 2, 6, 5, 3, 31, 9, 9, 3, 2, 1, 1, 0, 5, 5, 3, 1, 0, 3, 15, 2, 3, 3, 1, 0, 19, 12, 1, 1, 36, 18, 14, 1, 0, 0, 1, 14, 14, 3, 1, 0, 0, 127, 60, 5, 4, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 110, 4, 5, 6, 6, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 16, 11, 8, 9, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 8, 1, 1, 1, 88, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 1, 3, 1, 7, 4, 9, 3, 2, 1, 1, 19, 78, 8, 2, 3, 1, 1, 1, 63, 8, 1, 833, 16, 6, 5, 3, 3, 6, 24, 93, 55, 39, 43, 13, 9, 7, 1, 4, 1, 86, 18, 15, 15, 87, 82, 180, 367, 249, 156, 89, 31, 7, 9, 2, 1, 1, 1, 8, 8, 13, 48, 19, 6, 12, 6, 14, 6, 2, 7, 6, 1, 0, 0, 5, 8, 4, 7, 3, 3, 1, 15, 12, 29, 16, 7, 0, 0, 13, 24, 40, 13, 3, 0, 122, 44, 33, 5, 4, 1, 0, 0, 351, 121, 51, 5, 9, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 354, 168, 31, 19, 8, 2, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 381, 88, 10, 7, 5, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 279, 74, 27, 10, 1, 5, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 157, 55, 20, 11, 5, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 108, 14, 13, 7, 4, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 52, 26, 22, 2, 5, 2, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 22, 6, 5, 1, 3, 3, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 11, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 5, 7, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 2, 7, 2, 1, 10, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 4, 8, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 0, 2, 0, 0, 1, 0, 1, 2, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 3, 1, 1, 3, 3, 2, 1, 1, 27, 18, 1, 4, 2, 2, 1, 214, 7, 1, 2, 18, 19, 18, 5, 1, 3, 3, 1, 1, 136, 39, 17, 3, 18, 28, 5, 4, 7, 5, 12, 10, 3, 5, 8, 16, 5, 11, 1, 24, 15, 20, 51, 135, 147, 126, 42, 9, 15, 2, 2, 8, 1, 2, 29, 9, 4, 6, 5, 10, 20, 11, 11, 18, 32, 29, 14, 3, 1, 6, 4, 4, 4, 2, 6, 4, 5, 7, 19, 15, 12, 12, 3, 5, 4, 7, 10, 4, 2, 6, 8, 3, 3, 7, 5, 6, 6, 10, 8, 3, 9, 5, 7, 5, 5, 2, 13, 6, 8, 5, 5, 4, 5, 15, 6, 8, 3, 6, 1, 6, 6, 2, 5, 10, 1, 7, 13, 6, 6, 3, 5, 6, 11, 5, 6, 7, 18, 5, 6, 5, 8, 15, 20, 0, 8, 6, 2, 9, 9, 26, 10, 3, 1, 4, 1, 6, 11, 2, 11, 12, 5, 3, 0, 10, 30, 9, 2, 0, 14, 36, 26, 2, 3, 1, 0, 0, 0, 0, 122, 58, 27, 3, 5, 1, 0, 3, 0, 0, 0, 0, 0, 229, 78, 26, 14, 5, 7, 7, 0, 1, 3, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 197, 104, 40, 16, 17, 8, 6, 1, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 44, 43, 19, 18, 10, 1, 0, 2, 2, 2, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 25, 23, 16, 4, 3, 9, 1, 2, 1, 2, 1, 1, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 59, 35, 22, 11, 6, 7, 3, 5, 0, 1, 4, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 51, 32, 10, 4, 3, 1, 3, 1, 1, 3, 22, 1, 0, 0, 0, 0, 0, 0, 0, 33, 20, 19, 1, 2, 2, 1, 4, 5, 4, 1, 20, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 10, 12, 5, 2, 2, 4, 42, 1, 1, 0, 0, 0, 0, 0, 0, 0, 7, 9, 11, 6, 1, 2, 5, 27, 4, 0, 0, 0, 5, 2, 2, 28, 1, 0, 0, 8, 1, 1, 2, 3, 2, 4, 5, 2, 0, 0, 4, 6, 5, 1, 9, 2, 0, 3, 2, 2, 0, 0, 0, 4, 8, 0, 0, 0, 1, 1, 7, 0, 3, 1, 0, 4, 0, 1, 0, 2, 2, 3, 1, 0, 0, 4, 3, 0, 1, 1, 7, 0, 2, 1, 0, 0, 6, 0, 1, 0, 0, 0, 4, 3, 0, 10, 12, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 2, 2, 2, 5, 1, 10, 3, 90, 35, 3, 3, 3, 1, 1, 1, 2, 2, 2, 0, 1, 0, 8, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 2, 0, 0, 1, 0, 2, 0, 1, 2, 1, 3, 1, 1, 4, 1, 2, 1, 3, 2, 5, 1, 1, 2, 7, 2, 13, 3, 5, 9, 1, 2, 1, 2, 8, 9, 12, 7, 1, 2, 2, 2, 2, 1, 2, 1, 0, 1, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 2, 0, 0, 1, 1, 1, 3, 1, 2, 2, 1, 20, 7, 1, 1, 6, 5, 1, 6, 1, 1, 2, 1, 0, 1, 1, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 3, 0, 0, 0, 1, 1, 0, 0, 1, 2, 1, 5, 0, 0, 5, 0, 0, 0, 1, 0, 1, 1, 5, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 3, 4, 6, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 3, 24, 1, 1, 7, 3, 1, 2, 2, 2, 2, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 2, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 3, 3, 1, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 2, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2224, 24, 12898, 664, 541, 3988, 1790, 125, 262, 103, 319, 2825, 239, 2, 1, 130, 185, 172, 388, 75, 856, 1397, 7823, 1233, 273, 74, 48, 13, 2, 864, 508, 2998, 1593, 220, 154, 88, 762, 333, 326, 102, 982, 4033, 42, 178, 204, 662, 147, 229, 118, 66, 140, 724, 103, 203, 374, 155, 146, 84, 218, 23, 540, 2545, 3155, 174, 251, 253, 2276, 1466, 21, 126, 156, 67, 807, 104, 155, 87, 601, 86, 350, 940, 82, 315, 137, 546, 0, 335, 217, 456, 0, 1, 0, 0, 108, 5, 81, 0, 28, 1, 4, 1, 0, 0, 0, 0, 0, 0, 10, 0, 1, 0, 0, 332, 129, 1, 24, 184, 173, 245, 426, 47, 1, 15, 127, 192, 2101, 576, 103, 10644, 1, 2, 32840, 88, 22, 26, 15, 1, 1, 1, 34, 28688, 2524, 11110, 4962, 1562, 1040, 987, 3921, 1014, 527, 313, 891, 668, 192, 11, 468, 222, 4, 6, 257, 206, 2, 76, 1, 226, 1181, 4029, 11206, 4028, 921, 460, 442, 1860, 478, 270, 1128, 719, 600, 244, 344, 477, 278, 310, 376, 153, 27, 210, 37, 554, 566, 4375, 1279, 60, 296, 596, 13, 13, 5, 251, 53, 128, 93, 47, 4, 7507, 3800, 1586, 2457, 3752, 1659, 1128, 1216, 632, 576, 330, 46, 718, 310, 116, 15, 164, 122, 43, 96, 1050, 99, 4167, 1365, 1674, 4430, 1275, 773, 379, 359, 648, 8, 748, 391, 106, 19, 135, 105, 2, 3, 708, 789, 199, 2874, 1132, 4374, 669, 363, 117, 59, 555, 7, 150, 213, 97, 3, 2, 16, 20, 3529, 1312, 805, 441, 283, 308, 229, 79, 87, 1, 310, 168, 87, 4, 6215, 350, 1355, 27, 309, 2, 791, 95, 5, 671, 8, 1, 628, 1, 16, 92, 6369, 3063, 3967, 2099, 872, 1529, 2327, 649, 1014, 1179, 200, 185, 4, 3, 442, 217, 283, 5, 201, 191, 487, 4, 310, 9, 94, 163, 4, 5, 2, 4, 42, 57, 414, 176, 46, 1469, 2062, 894, 105, 488, 76, 1478, 1549, 40, 191, 1665, 131, 232, 281, 227, 6, 36, 209, 3, 2, 17, 2, 4, 244, 770, 519, 580, 4733, 1326, 397, 13, 209, 245, 477, 305, 2, 168, 90, 462, 6, 2, 246, 185, 2833, 1438, 943, 471, 2188, 4, 280, 242, 114, 342, 229, 2, 3, 5, 271, 296, 305, 3, 140, 4, 2765, 1547, 643, 41, 2374, 1480, 88, 161, 284, 140, 1083, 5, 358, 303, 250, 5, 668, 96, 2, 125, 12, 87, 158, 2, 6, 3, 305, 287, 4, 8, 38, 700, 20, 331, 2138, 357, 1880, 2, 3, 557, 232, 157, 346, 209, 288, 4, 6, 953, 57, 331, 366, 324, 934, 131, 170, 120, 861, 769, 457, 507, 401, 4, 448, 557, 357, 60, 2, 118, 198, 17, 252, 299, 212, 2, 2, 1328, 1263, 1244, 11, 268, 240, 1332, 154, 500, 240, 189, 16, 124, 876, 6, 808, 959, 359, 503, 243, 455, 219, 187, 1427, 484, 679, 371, 385, 1643, 502, 16, 3, 163, 3, 720, 197, 694, 431, 454, 228, 669, 468, 2, 1110, 589, 434, 259, 664, 403, 439, 16, 583, 356, 88, 487, 489, 287, 638, 1283, 23, 506, 262, 10, 561, 504, 23, 96, 124, 483, 1048, 228, 2, 6, 1974, 259, 3, 522, 267, 117, 89, 4, 276, 10, 7, 6, 43, 3, 4, 458, 204, 204, 84, 486, 1, 320, 115, 295, 132, 111, 20, 448, 586, 47, 153, 323, 1, 626, 20, 490, 672, 242, 285, 165, 402, 191, 123, 331, 282, 288, 287, 413, 359, 158, 98, 4, 6, 4, 1322, 334, 807, 864, 611, 1262, 211, 273, 247, 278, 350, 154, 934, 5, 345, 89, 596, 11, 8, 312, 232, 6, 252, 377, 122, 132, 4, 24, 115, 6, 356, 2, 412, 233, 304, 17, 507, 30, 293, 3, 261, 413, 91, 843, 341, 216, 3, 275, 218, 92, 162, 80, 478, 2, 4, 234, 2, 721, 3, 503, 644, 300, 211, 504, 387, 344, 53, 489, 1, 74, 391, 9, 5, 210, 690, 412, 22, 671, 3, 693, 280, 228, 209, 85, 304, 88, 4, 121, 638, 1327, 1115, 661, 140, 41, 77, 19, 584, 206, 583, 435, 0, 3, 503, 623, 120, 5, 5, 482, 492, 855, 637, 424, 5, 115, 271, 806, 2, 57, 281, 1558, 1635, 715, 150, 649, 37, 7, 3, 460, 395, 715, 302, 563, 1325, 415, 2163, 231, 458, 810, 420, 1923, 1029, 184, 447, 58, 202, 2, 127, 40, 51, 814, 562, 1, 0, 242, 578, 1410, 949, 488, 770, 719, 495, 2006, 1, 2753, 356, 1399, 116, 11, 657, 601, 0, 356, 965, 177, 109, 391, 79, 401, 2605, 1455, 1326, 209, 210, 231, 355, 0, 95, 671, 715, 1048, 29, 88, 3503, 398, 1, 0, 0, 4, 1181, 205, 590, 307, 1519, 1107, 303, 3, 274, 22, 1660, 88, 1794, 1027, 887, 221, 2539, 2570, 0, 0, 1860, 253, 10, 1108, 2611, 1, 1996, 1017, 3615, 2508, 7, 4, 0, 187, 3315, 1033, 15, 3270, 1611, 19, 36025, 144, 0, 3, 33748, 793, 43, 12, 2, 37, 29, 2, 2, 4, 2, 1, 1, 89, 4, 1, 49, 606, 0, 0, 0, 0, 11136, 511, 1742, 41, 223, 257, 127, 189, 326, 259, 77, 66, 134, 243, 317, 337, 1093, 91, 234, 103, 123, 62, 48, 120, 163, 112, 120, 104, 237, 279, 202, 24, 314, 72, 16, 187, 40, 275, 76, 99, 98, 202, 195, 455, 56, 454, 619, 1130, 7724, 0, 2181, 244, 206, 406, 174, 122, 872, 671, 200, 156, 96, 149, 241, 79, 43, 168, 333, 73, 645, 652, 570, 75, 337, 3095, 806, 218, 40, 244, 3, 61, 419, 662, 31, 620, 149, 135, 11, 251, 177, 67, 217, 992, 123, 83, 359, 79, 122, 240, 7, 128, 84, 415, 8, 148, 246, 204, 369, 173, 124, 12, 15, 330, 19, 205, 325, 270, 217, 68, 78, 65, 133, 242, 121, 48, 223, 43, 172, 305, 143, 9, 184, 0, 194, 80, 473, 177, 137, 238, 368, 345, 509, 0, 90, 1, 0, 0, 187, 269, 5, 167, 77, 103, 322, 0, 199, 102, 331, 155, 127, 123, 186, 0, 0, 332, 277, 70, 270, 136, 89, 0, 344, 47, 381, 148, 166, 161, 113, 472, 240, 213, 105, 236, 395, 216, 149, 271, 114, 137, 156, 134, 536, 176, 23, 169, 315, 410, 86, 114, 416, 1234, 1, 0, 120, 39, 274, 243, 101, 75, 95, 97, 222, 98, 682, 521, 221, 270, 672, 100, 88, 136, 180, 1290, 424, 270, 628, 220, 1530, 522, 2131, 6254, 36, 690, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 4, 2, 1, 1, 1, 1, 1, 8, 1, 1, 2, 2, 1, 2, 3, 1, 2, 2, 1, 1, 10, 6, 2, 2, 2, 2, 1, 3, 1, 2, 1, 1, 1, 2, 3, 2, 1, 1, 2, 1, 2, 1, 1, 1, 2, 1, 0, 0, 1, 3, 2, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 2, 0, 0, 0, 9, 2050, 366, 80, 188, 193, 21, 85, 17, 150, 146, 7, 33, 151, 345, 2309, 6294, 10501, 2741, 75, 58, 1, 3, 1, 85, 73, 596, 969, 348, 320, 52, 81, 50, 41, 100, 52, 144, 22, 86, 86, 16, 28, 125, 148, 8, 27, 8, 5, 107, 55, 52, 18, 2, 2, 274, 77, 62, 145, 5, 9, 22, 2, 2290, 346, 78, 123, 4, 2, 4, 9692, 551, 261, 96, 69, 7, 32, 40, 2, 23738, 34, 52, 37, 48, 16, 97, 6, 6, 78, 49, 42405, 1302, 12, 10, 874, 349, 137, 116, 204, 33, 32, 21, 6, 1, 1, 13, 73, 326, 9, 26, 257, 87, 1, 124, 1, 25, 42, 87, 7, 244, 672, 14342, 3640, 1260, 1873, 193, 362, 671, 454, 324, 505, 580, 559, 162, 279, 557, 494, 242, 16, 361, 114, 420, 366, 196, 55, 4677, 1432, 976, 841, 424, 872, 315, 148, 106, 448, 281, 256, 505, 387, 197, 237, 36, 104, 165, 453, 441, 2830, 501, 4661, 120, 1351, 666, 35, 206, 15, 321, 800, 154, 395, 139, 409, 420, 276, 1892, 365, 104, 555, 106, 801, 233, 14, 114, 105, 156, 302, 101, 1684, 186, 273, 833, 438, 650, 195, 272, 790, 583, 588, 1016, 272, 261, 502, 154, 163, 254, 182, 352, 118, 38, 44, 397, 23, 120, 143, 42, 4, 121, 222, 239, 177, 208, 135, 829, 372, 48, 291, 498, 106, 90, 10, 226, 58, 97, 222, 1005, 64, 81, 126, 5, 191, 101, 282, 158, 121, 339, 629, 247, 69, 133, 143, 12, 62, 100, 347, 194, 36, 75, 363, 81, 208, 117, 148, 1, 283, 177, 101, 274, 38, 168, 284, 16, 65, 178, 1101, 1, 135, 439, 340, 132, 194, 322, 132, 305, 195, 783, 34, 148, 34, 195, 113, 287, 608, 1031, 298, 318, 24, 16, 77, 173, 469, 6, 273, 115, 107, 23, 188, 373, 133, 396, 163, 1, 19, 271, 1, 122, 737, 63, 19, 185, 85, 122, 167, 91, 288, 199, 83, 115, 464, 16, 32, 508, 314, 77, 242, 139, 82, 162, 341, 3, 25, 323, 227, 115, 75, 174, 7, 131, 272, 0, 115, 200, 220, 738, 167, 201, 324, 197, 152, 24, 131, 90, 54, 287, 1469, 979, 1557, 298, 1416, 50, 228, 61, 387, 791, 375, 30, 409, 132, 200, 38, 259, 38, 630, 183, 509, 218, 197, 575, 441, 186, 294, 304, 1, 57, 1458, 521, 849, 243, 675, 198, 335, 563, 166, 372, 190, 58, 273, 43, 844, 273, 616, 1869, 129, 103, 342, 8, 3, 209, 389, 1426, 937, 729, 426, 221, 207, 328, 124, 146, 979, 59, 12, 171, 289, 212, 274, 40, 134, 782, 1582, 639, 224, 167, 238, 16, 190, 0, 169, 208, 892, 145, 53, 381, 190, 167, 815, 187, 1062, 863, 1524, 169, 786, 319, 106, 567, 69, 378, 725, 233, 8, 139, 14, 4, 178, 375, 13, 401, 2519, 104, 345, 51, 292, 339, 294, 412, 282, 23, 404, 218, 223, 227, 118, 234, 221, 95, 312, 68, 0, 43, 60, 364, 60, 421, 122, 763, 181, 610, 195, 237, 69, 222, 115, 639, 15, 69, 360, 893, 124, 468, 235, 386, 150, 1, 2, 147, 171, 1061, 125, 0, 428, 403, 123, 65, 283, 327, 280, 122, 177, 184, 1172, 786, 26, 396, 125, 429, 178, 478, 1, 543, 43, 59, 354, 749, 353, 129, 296, 131, 31, 11, 195, 346, 2955, 89, 381, 102, 44, 149, 107, 120, 1574, 271, 167, 202, 173, 177, 30, 2, 735, 1747, 79, 136, 80, 178, 291, 76, 9, 169, 2633, 80, 784, 130, 303, 482, 166, 607, 149, 550, 1136, 37, 165, 130, 30, 103, 167, 434, 226, 101, 342, 331, 234, 167, 608, 185, 2, 12, 508, 92, 208, 233, 117, 286, 232, 8, 326, 208, 196, 211, 210, 142, 968, 598, 567, 139, 166, 787, 405, 39, 272, 100, 79, 1, 254, 177, 428, 272, 18, 207, 355, 290, 342, 9, 71, 345, 605, 1594, 2, 0, 8, 146, 344, 1550, 76, 32, 816, 7, 35, 1246, 18, 9903, 7, 0, 33891, 112, 289, 22, 9, 14, 74, 68, 316, 149, 0, 0, 0, 0, 13793, 191, 233, 449, 29, 144, 383, 180, 26, 4, 72, 25, 363, 442, 96, 1, 84, 53, 531, 717, 1778, 562, 2709, 2140, 0, 0, 0, 513, 620, 352, 202, 135, 468, 102, 366, 258, 396, 900, 120, 46, 185, 80, 40, 1020, 505, 2729, 230, 2789, 1474, 29, 13, 20, 6, 160, 160, 102, 370, 18, 9, 99, 69, 103, 96, 134, 104, 240, 158, 107, 98, 84, 56, 146, 136, 297, 88, 41, 4, 43, 52, 414, 33, 4, 145, 31, 7, 384, 103, 181, 298, 27, 198, 170, 3, 73, 24, 116, 233, 320, 72, 199, 177, 497, 401, 225, 396, 48, 95, 2, 2, 7, 4, 8, 227, 4, 45, 383, 124, 197, 52, 79, 39, 64, 1011, 1173, 109, 522, 1294, 811, 1656, 4238, 1649, 2904, 480, 0, 16795, 0, 18, 2, 0, 0, 0, 0, 0, 0, 0, 0, 5, 19, 27109, 1076, 9974, 3604, 468, 588, 296, 58, 23, 8, 247, 10, 135, 166, 587, 219, 88, 286, 88, 70, 129, 118, 280, 336, 140, 355, 316, 751, 203, 1678, 8836, 10423, 1543, 67, 9, 5, 1008, 173, 11243, 1893, 459, 764, 793, 108, 580, 132, 288, 238, 198, 721, 6031, 2541, 81, 6, 766, 194, 54, 317, 124, 641, 114, 61, 3905, 386, 454, 676, 924, 335, 205, 342, 385, 363, 901, 577, 1191, 6650, 4729, 66, 109, 197, 279, 529, 396, 163, 253, 108, 302, 205, 1675, 2163, 3362, 470, 460, 585, 174, 1676, 714, 299, 59, 795, 24, 9, 248, 9, 134, 165, 0, 0, 677, 528, 107, 1388, 87, 50, 53, 579, 214, 7, 16, 74, 287, 87, 337, 69, 127, 203, 395, 341, 120, 137, 141, 249, 289, 281, 364, 1306, 337, 141, 326, 485, 254, 396, 233, 152, 327, 993, 864, 153, 701, 6789, 559, 39, 40576, 111, 2, 94532, 121, 2, 2, 20, 1, 2, 1, 52, 689, 103, 382, 1, 80140, 8275, 25266, 2997, 2061, 3522, 3175, 3171, 3810, 235, 44, 1060, 61, 190, 31, 4, 7, 155, 1, 1, 57, 207, 274, 19, 565, 24097, 33632, 4819, 4545, 5511, 2976, 3896, 720, 167, 32, 383, 386, 337, 1, 138, 257, 275, 98, 557, 37, 48, 39, 680, 24535, 2750, 241, 768, 1404, 997, 791, 620, 177, 139, 114, 194, 4, 274, 24572, 15449, 13334, 8781, 9261, 4526, 2029, 1825, 599, 543, 683, 893, 355, 25, 21, 41, 108, 466, 31, 219, 403, 9718, 10956, 2355, 4751, 998, 572, 21, 1483, 615, 94, 11, 1084, 950, 696, 563, 19, 195, 13, 38, 87, 11, 89, 8, 13278, 6884, 5380, 795, 1562, 191, 443, 97, 535, 429, 479, 148, 635, 300, 385, 262, 83, 27, 202, 18433, 14329, 5500, 2246, 899, 1405, 659, 599, 627, 290, 94, 37, 161, 4, 367, 278, 290, 45, 403, 279, 332, 6, 229, 19260, 10701, 3730, 1722, 1667, 460, 1168, 1766, 407, 328, 152, 32, 392, 433, 28, 88, 34, 18, 51, 511, 23, 1162, 26108, 6888, 3920, 2143, 572, 1645, 5808, 1432, 2815, 992, 292, 1351, 658, 216, 818, 985, 740, 715, 68, 205, 1256, 150, 196, 404, 144, 317, 12, 438, 11022, 7748, 7631, 4275, 2229, 1649, 2001, 878, 2501, 948, 1147, 2029, 6, 687, 475, 450, 738, 672, 672, 895, 1520, 1398, 747, 177, 1469, 40, 117, 5780, 5603, 3626, 1928, 938, 147, 2903, 2098, 540, 561, 181, 978, 201, 80, 787, 1005, 191, 568, 345, 10, 357, 47, 281, 14, 7885, 2182, 2963, 891, 3, 467, 2013, 297, 1512, 295, 9, 6, 56, 1079, 560, 120, 53, 476, 385, 1033, 5617, 5791, 241, 1595, 4961, 2540, 1577, 2415, 156, 403, 177, 187, 209, 207, 293, 462, 1120, 977, 90, 39, 55, 392, 2550, 2098, 1567, 1428, 974, 521, 828, 1472, 575, 930, 114, 459, 914, 1807, 69, 684, 1890, 316, 16, 157, 208, 18, 272, 690, 5558, 2634, 999, 3363, 473, 461, 179, 383, 459, 323, 192, 962, 309, 1468, 920, 317, 626, 1003, 1921, 2033, 242, 492, 1900, 754, 449, 628, 117, 330, 2028, 815, 2, 602, 518, 647, 19, 4124, 326, 1475, 563, 772, 1219, 137, 6, 381, 408, 139, 489, 38, 1319, 3617, 1203, 3125, 735, 1165, 308, 344, 1059, 2523, 1177, 12, 708, 2947, 2266, 837, 1725, 1052, 407, 568, 414, 1343, 1471, 1046, 199, 13, 804, 2036, 1466, 398, 1796, 610, 2613, 949, 1566, 1581, 1077, 2164, 306, 507, 1406, 2664, 450, 906, 204, 1138, 558, 790, 610, 618, 309, 59, 960, 866, 583, 277, 493, 2164, 4204, 715, 1589, 161, 152, 481, 188, 66, 1799, 1607, 380, 1474, 1587, 661, 38, 242, 1678, 19, 26, 200, 14, 494, 736, 261, 1829, 296, 1547, 2318, 760, 360, 636, 564, 486, 808, 310, 356, 167, 651, 1116, 779, 3959, 1528, 3355, 609, 384, 5, 854, 172, 716, 809, 392, 569, 964, 113, 576, 402, 156, 399, 1829, 1153, 436, 345, 810, 386, 7, 302, 448, 178, 931, 8, 10, 383, 1058, 355, 6, 549, 160, 40, 929, 319, 203, 303, 459, 1154, 734, 327, 808, 522, 584, 3101, 215, 584, 22, 36, 580, 161, 2012, 258, 217, 480, 545, 906, 501, 242, 1469, 197, 0, 7, 458, 739, 650, 449, 1990, 1222, 322, 467, 673, 127, 2666, 1691, 1326, 516, 541, 25, 677, 193, 613, 659, 1171, 948, 210, 986, 1348, 295, 79, 649, 915, 546, 331, 206, 4109, 9037, 7729, 1267, 464, 2329, 646, 730, 3427, 0, 1909, 8365, 5420, 2031, 3346, 271, 2178, 258, 1117, 0, 894, 2610, 190, 67, 85, 112, 23088, 5087, 2268, 2310, 1723, 334, 727, 2710, 1307, 23751, 1606, 16143, 5905, 2394, 2594, 3471, 8357, 1260, 608, 669, 998, 20096, 8151, 1798, 3455, 7478, 915, 831, 463, 193, 1360, 18051, 1083, 7783, 12445, 14997, 2008, 7791, 13572, 15137, 1911, 913, 7596, 13662, 10574, 52876, 53170, 662, 1144, 5450, 717, 1381, 169, 84, 579, 419, 651, 91, 244, 59, 40, 2, 334, 19, 1, 22, 189, 25, 1, 3, 12, 86, 109, 147, 549, 23, 88, 81, 45, 131, 32, 8, 0, 0, 73, 38, 76, 359, 173, 334, 233, 210, 2357, 0, 0, 0, 0, 2132, 6099, 17820, 1228, 9217, 463, 777, 1388, 965, 252, 1213, 425, 279, 992, 234, 77, 265, 339, 150, 187, 138, 319, 671, 164, 93, 1083, 200, 188, 239, 363, 193, 100, 69, 70, 489, 739, 1246, 90, 1540, 189, 808, 389, 271, 380, 494, 73, 171, 4619, 1372, 188, 342, 193, 305, 137, 144, 7, 98, 7127, 3368, 149, 461, 301, 3988, 1075, 1408, 146, 674, 137, 378, 96, 470, 202, 2, 299, 527, 676, 206, 249, 229, 7, 160, 335, 52, 112, 473, 428, 1066, 884, 805, 209, 1762, 0, 0, 1402, 2641, 1363, 181, 77, 189, 143, 215, 274, 215, 522, 139, 396, 203, 164, 324, 132, 500, 331, 2077, 1488, 2344, 1863, 395, 77, 270, 535, 200, 711, 366, 222, 749, 231, 1400, 5, 247, 142, 682, 181, 5, 2, 131, 2, 727, 17, 150, 699, 295, 285, 432, 0, 148, 593, 814, 516, 379, 187, 224, 394, 190, 332, 65, 28, 51, 81, 31, 216, 1, 2203, 1444, 39, 1337, 157, 534, 297, 526, 179, 311, 201, 129, 176, 214, 84, 75, 592, 185, 240, 419, 466, 302, 399, 0, 0, 2308, 315, 246, 407, 118, 137, 450, 839, 307, 239, 260, 469, 152, 359, 56, 141, 566, 1073, 319, 0, 1711, 1083, 195, 363, 116, 107, 955, 689, 310, 215, 175, 174, 255, 138, 670, 693, 572, 186, 169, 91, 201, 137, 218, 0, 0, 90, 285, 264, 231, 386, 343, 145, 40, 376, 244, 675, 1373, 136, 902, 1044, 452, 20, 171, 50, 222, 767, 6, 311, 75, 156, 48, 138, 150, 766, 301, 122, 245, 246, 91, 288, 194, 278, 362, 269, 377, 210, 96, 39, 5, 384, 94, 115, 182, 607, 525, 245, 3, 115, 284, 233, 765, 375, 536, 119, 445, 96, 245, 108, 201, 188, 20, 138, 378, 0, 712, 69, 112, 954, 263, 367, 676, 766, 23, 137, 231, 458, 76, 449, 312, 188, 223, 741, 142, 363, 448, 23, 214, 188, 282, 202, 600, 338, 459, 309, 0, 203, 149, 2, 711, 580, 599, 310, 1843, 344, 230, 131, 54, 945, 710, 174, 1172, 137, 262, 308, 213, 322, 0, 769, 1546, 535, 85, 90, 232, 273, 230, 2700, 371, 375, 317, 221, 200, 300, 135, 176, 54, 0, 901, 80, 173, 377, 146, 268, 5, 244, 229, 246, 137, 175, 633, 2300, 1192, 363, 236, 422, 179, 1181, 243, 298, 378, 96, 625, 1212, 1176, 1621, 564, 319, 253, 92, 867, 374, 181, 454, 165, 107, 327, 536, 234, 319, 157, 143, 362, 211, 532, 978, 811, 1494, 322, 1043, 1404, 305, 172, 316, 182, 402, 409, 687, 226, 423, 571, 683, 279, 574, 146, 138, 376, 85, 166, 393, 953, 449, 392, 765, 106, 362, 397, 351, 38, 307, 230, 4, 68, 252, 187, 89, 185, 326, 91, 76, 173, 189, 188, 135, 126, 114, 325, 423, 153, 537, 954, 313, 431, 784, 525, 145, 355, 230, 79, 898, 280, 795, 537, 130, 318, 156, 20, 192, 31, 452, 536, 342, 728, 362, 353, 230, 3, 307, 15, 2, 9, 24, 3, 2, 1284, 16, 90, 129, 142, 72, 199, 37, 99, 159, 242, 1052, 180, 134, 111, 401, 297, 312, 51, 245, 131, 299, 642, 96, 155, 179, 75, 813, 1448, 198, 529, 229, 139, 361, 225, 1014, 342, 499, 714, 1508, 2460, 2346, 1877, 2147, 6387, 5470, 4917, 8986, 1922, 8569, 3652, 26751, 8490, 76, 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 5, 2, 1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 0, 0, 1, 1, 1, 1, 1, 12, 1, 4, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 2, 24, 3, 2, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 1, 2, 7, 6, 1, 1, 1, 1, 5, 1, 3, 1, 6, 1, 2, 21, 11, 2, 4, 1, 1, 1, 1, 1, 1, 23, 14, 3, 2, 1, 1, 234, 73, 35, 1, 5, 12, 3, 2, 2, 1, 4, 2, 469, 136, 3, 1, 3, 3, 6, 3, 4, 14, 41, 14, 5, 3, 9, 1, 1, 1, 1, 1, 1, 612, 27, 8, 6, 5, 4, 3, 2, 5, 7, 10, 10, 5, 20, 50, 50, 45, 37, 13, 13, 11, 3, 4, 4, 1, 1, 65, 47, 9, 17, 4, 24, 13, 19, 5, 3, 3, 12, 8, 10, 18, 42, 36, 117, 94, 119, 202, 136, 155, 42, 33, 7, 1, 8, 10, 10, 14, 13, 14, 11, 13, 12, 4, 9, 4, 10, 25, 8, 4, 6, 5, 4, 2, 4, 4, 3, 22, 8, 8, 1, 6, 5, 5, 18, 12, 2, 24, 10, 1, 10, 7, 5, 6, 4, 8, 4, 9, 11, 4, 10, 3, 2, 9, 7, 4, 6, 2, 5, 7, 4, 3, 14, 7, 4, 24, 4, 10, 1, 7, 14, 13, 26, 9, 5, 1, 14, 34, 24, 23, 42, 11, 3, 1, 6, 2, 3, 0, 45, 46, 33, 24, 8, 14, 2, 0, 0, 92, 72, 56, 27, 5, 1, 2, 1, 0, 0, 0, 0, 0, 0, 172, 108, 72, 33, 9, 1, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 272, 87, 55, 11, 5, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 311, 109, 34, 13, 3, 10, 6, 2, 2, 3, 3, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 280, 40, 37, 23, 6, 4, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 177, 43, 30, 16, 8, 4, 4, 1, 2, 1, 1, 2, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 98, 36, 18, 11, 3, 8, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 51, 40, 8, 10, 8, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 27, 17, 9, 4, 1, 2, 6, 4, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 13, 9, 3, 1, 2, 3, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 4, 5, 2, 2, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 3, 1, 1, 1, 3, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 2, 4, 2, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 2, 0, 1, 0, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 6, 2, 2, 4, 3, 1, 1, 1, 1, 1, 1, 5, 5, 1, 2, 1, 2, 2, 1, 8, 3, 20, 25, 7, 2, 8, 1, 1, 3, 1, 2, 1, 1, 1, 2, 2, 1, 2, 3, 1, 1, 2, 0, 0, 5, 1, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 5, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 1, 0, 0, 2, 0, 0, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 13, 2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 4, 2, 1, 1, 1, 1, 1, 2, 1, 14, 1, 1, 1, 4, 1, 4, 22, 2, 10, 1, 3, 5, 4, 3, 1, 2, 1, 2, 7, 4, 4, 1, 2, 4, 2, 2, 1, 1, 1, 5, 8, 4, 2, 1, 2, 1, 0, 3, 1, 0, 0, 2, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 1, 0, 0, 1, 2, 0, 0, 2, 1, 0, 0, 0, 1, 2, 4, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 4, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 1, 1, 0, 0, 0, 0, 2, 0, 1, 0, 2, 0, 0, 1, 0, 1, 0, 1, 0, 3, 3, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 18, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 2, 2, 1, 4, 1, 2, 1, 4, 4, 2, 1, 1, 7, 3, 1, 1, 1, 2, 3, 15, 1, 1, 1, 1, 2, 1, 2, 6, 1, 1, 2, 4, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 2, 0, 2, 0, 1, 1, 0, 0, 2, 2, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 2, 4, 1, 1, 1, 2, 1, 2, 1, 3, 3, 1, 1, 1, 3, 6, 2, 1, 1, 2, 1, 5, 15, 25, 1, 4, 2, 9, 35, 7, 25, 1, 2, 3, 2, 1, 3, 30, 1, 1, 9, 5, 5, 2, 2, 76, 12, 4, 2, 3, 13, 5, 3, 3, 1, 2, 0, 1, 5, 2, 1, 0, 0, 3, 1, 1, 1, 0, 0, 0, 5, 1, 0, 0, 0, 38, 10, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 5, 1, 1, 1, 1, 1, 1, 4, 13, 3, 1, 1, 1, 1, 1, 1, 7, 1, 3, 1, 2, 1, 1, 1, 1, 17, 2, 2, 1, 4, 3, 2, 81, 61, 36, 16, 6, 2, 4, 1, 2, 5, 24, 22, 11, 16, 2, 14, 1, 61, 38, 13, 7, 6, 8, 36, 10, 5, 6, 1, 1, 107, 23, 12, 3, 2, 3, 3, 4, 32, 12, 15, 7, 17, 1, 6, 1, 140, 19, 11, 10, 5, 4, 21, 32, 18, 17, 8, 10, 2, 16, 1, 60, 12, 2, 8, 19, 4, 3, 19, 44, 28, 12, 16, 31, 4, 13, 7, 1, 2, 19, 4, 3, 5, 35, 2, 38, 5, 24, 6, 4, 3, 3, 4, 1, 10, 16, 2, 8, 2, 4, 2, 6, 3, 10, 21, 9, 3, 12, 5, 8, 11, 20, 0, 3, 4, 1, 0, 3, 0, 2, 4, 3, 2, 2, 0, 18, 14, 7, 1, 13, 4, 1, 0, 0, 0, 0, 0, 0, 37, 17, 30, 49, 5, 11, 8, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 2, 39, 6, 6, 8, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 60, 6, 38, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 5, 22, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 30, 87, 19, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 30, 4, 4, 0, 0, 0, 0, 0, 0, 0, 0, 65, 18, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 2, 6, 1, 1, 1, 1, 1, 1, 1, 1, 3, 2, 1, 2, 1, 2, 1, 1, 3, 1, 4, 19, 1, 4, 1, 9, 3, 23, 1, 16, 1, 3, 5, 8, 24, 4, 2, 2, 5, 2, 5, 17, 162, 9, 13, 31, 8, 2, 4, 4, 2, 2, 0, 1, 1, 0, 1, 0, 4, 0, 4, 0, 0, 0, 5, 1, 0, 0, 16, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 31, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 4, 2, 2, 1, 0, 0, 1, 2, 4, 3, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 2, 1, 0, 2, 1, 1, 2, 1, 1, 1, 0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 1, 3, 8, 4, 0, 0, 1, 1, 1, 8, 2, 3, 1, 1, 2, 5, 30, 12, 5, 5, 1, 1, 1, 2, 2, 26, 4, 1, 2, 2, 7, 7, 3, 1, 7, 5, 1, 4, 2, 4, 1, 1, 1, 1, 6, 1, 1, 1, 0, 1, 0, 0, 0, 0, 6, 6, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 2, 4, 3, 1, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 2, 1, 15, 1, 2, 3, 3, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 6, 9, 1, 1, 1, 1, 3, 1, 5, 2, 5, 1, 2, 1, 2, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 2, 2, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 1, 1, 9, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 3, 1, 1, 5, 2, 1, 21, 1, 2, 2, 3, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 2, 3, 9, 3, 2, 7, 23, 5, 1, 5, 1, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 5, 4, 0, 1, 2, 1, 0, 0, 0, 1, 0, 1, 3, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 2, 0, 1, 1, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 4, 4, 2, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 2, 0, 1, 1, 1, 1, 1, 2, 1, 5, 3, 5, 6, 5, 1, 1, 6, 3, 56, 147, 39, 5, 5, 2, 4, 4, 4, 4, 3, 6, 1, 2, 1, 1, 1, 1, 2, 2, 0, 3, 1, 2, 0, 30, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 4, 6, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 4, 1, 1, 2, 8, 10, 18, 71, 5, 54, 1, 2, 1, 1, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 0, 2, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 3, 5, 1, 42, 1, 7, 2, 7, 3, 3, 2, 7, 1, 1, 1, 19, 66, 28, 37, 22, 18, 7, 6, 1, 1, 5, 16, 14, 5, 3, 1, 3, 22, 3, 3, 9, 3, 1, 1, 4, 2, 38, 44, 27, 39, 7, 4, 1, 1, 5, 17, 6, 15, 3, 8, 4, 1, 61, 17, 14, 8, 2, 11, 5, 1, 5, 3, 5, 95, 50, 8, 4, 5, 7, 5, 3, 9, 17, 19, 16, 10, 14, 7, 5, 111, 10, 9, 13, 6, 4, 29, 20, 5, 2, 4, 27, 29, 14, 1, 43, 37, 4, 4, 2, 12, 36, 41, 33, 42, 11, 33, 27, 44, 1, 14, 10, 2, 15, 26, 10, 4, 13, 12, 12, 3, 1, 11, 36, 18, 7, 3, 11, 3, 9, 1, 5, 8, 7, 6, 3, 2, 1, 9, 4, 2, 5, 1, 6, 2, 5, 2, 1, 10, 1, 4, 4, 6, 8, 5, 0, 1, 3, 1, 4, 59, 13, 21, 23, 8, 11, 1, 0, 59, 36, 1, 25, 19, 12, 1, 0, 38, 17, 30, 12, 17, 3, 1, 0, 0, 14, 47, 15, 33, 1, 0, 0, 0, 0, 27, 6, 4, 0, 0, 99, 61, 6, 0, 0, 0, 0, 117, 2, 1, 1, 0, 0, 0, 0, 41, 5, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 3, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 4, 1, 3, 2, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 2, 1, 0, 1, 2, 1, 1, 0, 1, 0, 1, 0, 1, 4, 27, 122, 32, 0, 1, 1, 0, 0, 1, 0], "yaxis": "y"}], "layout": {"height": 300, "legend": {"tracegroupgap": 0}, "shapes": [{"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 927246, "x1": 927246, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 1274352, "x1": 1274352, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 1418209, "x1": 1418209, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 1571928, "x1": 1571928, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 1776347, "x1": 1776347, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 1947573, "x1": 1947573, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2380981, "x1": 2380981, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2381705, "x1": 2381705, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2388594, "x1": 2388594, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2391227, "x1": 2391227, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2399996, "x1": 2399996, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2403940, "x1": 2403940, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2408422, "x1": 2408422, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2408676, "x1": 2408676, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2414061, "x1": 2414061, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2416979, "x1": 2416979, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2422650, "x1": 2422650, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2422651, "x1": 2422651, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2425051, "x1": 2425051, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2425765, "x1": 2425765, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2429616, "x1": 2429616, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2429744, "x1": 2429744, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2429896, "x1": 2429896, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2430423, "x1": 2430423, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2430816, "x1": 2430816, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2430862, "x1": 2430862, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2430879, "x1": 2430879, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2430880, "x1": 2430880, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2430904, "x1": 2430904, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2431004, "x1": 2431004, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2431060, "x1": 2431060, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2432418, "x1": 2432418, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 2435580, "x1": 2435580, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 20288131, "x1": 20288131, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 25429234, "x1": 25429234, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 25429235, "x1": 25429235, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 25635972, "x1": 25635972, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 34073194, "x1": 34073194, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 34100757, "x1": 34100757, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 34118140, "x1": 34118140, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 34118259, "x1": 34118259, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}], "template": {"data": {"bar": [{"error_x": {"color": "rgb(36,36,36)"}, "error_y": {"color": "rgb(36,36,36)"}, "marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "baxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmapgl"}], "histogram": [{"marker": {"line": {"color": "white", "width": 0.6}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "rgb(237,237,237)"}, "line": {"color": "white"}}, "header": {"fill": {"color": "rgb(217,217,217)"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "colorscale": {"diverging": [[0.0, "rgb(103,0,31)"], [0.1, "rgb(178,24,43)"], [0.2, "rgb(214,96,77)"], [0.3, "rgb(244,165,130)"], [0.4, "rgb(253,219,199)"], [0.5, "rgb(247,247,247)"], [0.6, "rgb(209,229,240)"], [0.7, "rgb(146,197,222)"], [0.8, "rgb(67,147,195)"], [0.9, "rgb(33,102,172)"], [1.0, "rgb(5,48,97)"]], "sequential": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "sequentialminus": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]]}, "colorway": ["#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF"], "font": {"color": "rgb(36,36,36)"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "white", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "white", "polar": {"angularaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "radialaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "scene": {"xaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "zaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}, "shapedefaults": {"fillcolor": "black", "line": {"width": 0}, "opacity": 0.3}, "ternary": {"aaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "baxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "caxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}}, "title": {"text": "2L"}, "width": 750, "xaxis": {"anchor": "y", "domain": [0.0, 1.0], "title": {"text": "midpoint"}}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0], "title": {"text": "depth"}}}}, "text/html": ["<div>                            <div id=\"3955e89a-f718-405f-ab47-e7a8388e3c50\" class=\"plotly-graph-div\" style=\"height:300px; width:750px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"3955e89a-f718-405f-ab47-e7a8388e3c50\")) {                    Plotly.newPlot(                        \"3955e89a-f718-405f-ab47-e7a8388e3c50\",                        [{\"hovertemplate\":\"midpoint=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"\",\"marker\":{\"color\":\"lightsalmon\",\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"showlegend\":false,\"x\":[4275,4534,4536,4536,4538,4539,4540,4540,4541,4548,66954,66956,66959,68326,104749,104750,104789,104800,104805,135569,135570,135573,463523,637134,709085,709106,785868,1190816,1190855,1194218,1212426,1215344,24682162,8561,71244,9091,9085,9088,9089,9090,9091,9091,9092,9094,9096,9091,9094,9096,9097,9097,9100,9097,9110,109299,109302,109303,109304,109304,109305,109305,109306,109307,109307,109308,109308,109309,109312,133924,133928,133930,133931,171719,135890,171721,171722,136664,173088,137849,173680,209499,209500,209501,209502,209503,209505,209506,209510,209511,209521,209529,209529,209531,209533,209535,209536,209537,209538,209538,209539,209502,209503,209504,209506,209506,209507,209514,209521,209535,209536,209537,209538,209539,209539,209539,209540,209540,209541,209508,209541,209542,209510,209542,209511,209543,209544,209544,209544,209545,209545,209521,209549,209549,209550,209552,209559,209560,209568,209568,209570,209571,209573,209574,209574,209575,209576,209576,209576,209577,209577,209578,209579,209579,209580,209580,209581,209581,209582,209582,209583,209583,209584,209584,209585,209585,209587,209588,209588,209589,209589,209590,209591,209592,209593,209593,209594,209594,209595,209595,209596,209596,209597,209598,209602,209602,209604,209605,209609,209612,209614,209615,209579,209580,209580,209581,209582,209585,209585,209586,209589,209589,209590,209591,209594,209594,209596,209614,209615,209580,209581,209581,209582,209582,209585,209586,209588,209589,209590,209590,209591,209594,209594,209615,209581,209582,209582,209587,209590,209590,209591,209592,209597,209598,209582,209583,209583,209584,209585,209585,209586,209587,209587,209588,209589,209590,209591,209591,209592,209594,209595,209597,209597,209599,209599,209600,209602,209604,209605,209583,209584,209588,209591,209591,209596,209584,209586,209591,209592,209592,209593,209586,209588,209588,209589,209591,209592,209592,209593,209594,209597,209592,209606,209588,209593,209593,209594,209592,209593,209594,209594,209594,209595,209599,209602,209607,209610,209613,209620,209596,209595,209596,209597,209592,209594,209595,209596,209599,209601,209604,209595,209596,209596,209597,209598,209601,209603,209596,209596,209597,209598,209598,209599,209600,209603,209624,209599,209624,209599,209600,209601,209602,209603,209603,209604,209604,209605,209606,209607,209608,209612,209613,209614,209617,209617,209621,209622,209625,209600,209601,209601,209602,209603,209604,209604,209605,209606,209606,209607,209607,209608,209612,209613,209614,209614,209615,209615,209617,209618,209623,209625,209602,209602,209603,209604,209604,209605,209605,209606,209607,209607,209608,209608,209609,209610,209611,209612,209613,209613,209614,209615,209616,209617,209621,209624,209625,209626,209607,209603,209604,209604,209605,209605,209606,209606,209607,209608,209608,209609,209609,209610,209610,209612,209612,209614,209615,209615,209616,209616,209618,209619,209622,209623,209627,209605,209606,209615,209606,209607,209609,209609,209608,209611,209607,209608,209608,209610,209610,209611,209614,209615,209616,209627,209629,209608,209609,209610,209610,209612,209612,209613,209613,209617,209617,209621,209626,209629,209629,209609,209610,209611,209611,209612,209612,209613,209613,209614,209615,209616,209617,209618,209619,209621,209622,209626,209628,209630,209610,209611,209611,209612,209612,209613,209613,209614,209614,209615,209615,209616,209617,209618,209618,209619,209619,209621,209628,209630,209630,209613,209615,209618,209631,209612,209613,209613,209614,209615,209615,209617,209619,209619,209631,209613,209614,209614,209615,209615,209616,209616,209617,209617,209618,209618,209619,209619,209620,209620,209621,209621,209622,209623,209624,209624,209626,209627,209628,209628,209630,209630,209632,209615,209615,209616,209616,209617,209618,209620,209620,209622,209623,209624,209630,209615,209616,209617,209618,209620,209620,209621,209623,209628,209632,209633,209616,209617,209617,209618,209618,209619,209619,209620,209620,209621,209621,209622,209623,209623,209624,209625,209628,209631,209632,209633,209633,209617,209618,209619,209619,209621,209622,209625,209626,209626,209634,209618,209619,209620,209622,209622,209623,209623,209625,209634,209620,209622,209623,209623,209626,209629,209631,209634,209635,209623,209624,209624,209635,209623,209628,209634,209624,209624,209625,209636,209624,209625,209626,209637,209625,209629,209625,209627,209629,209630,209626,209627,209627,209628,209628,209629,209630,209631,209631,209632,209633,209633,209636,209637,209638,209638,209627,209628,209628,209629,209630,209631,209633,209637,209638,209639,720308,209628,209629,209629,209630,209631,209636,209639,209631,209632,209633,209634,209638,209639,209639,209640,209630,209631,209632,209633,209637,209638,209638,209640,209640,209632,209633,209635,209636,209637,209639,209640,209640,209641,209633,209634,209634,209635,209635,209636,209637,209637,209638,209638,209640,209640,209641,209641,209642,209634,209635,209636,209637,209637,209638,209638,209639,209640,209640,209641,209641,209642,209642,209643,209640,209641,209641,209643,209640,209644,209641,209643,209644,209644,209643,209643,209645,209641,209645,209645,209643,209644,209646,209643,209646,209646,209647,209645,209645,209647,209647,209646,209647,209648,209646,209648,209649,209647,209648,209648,209649,209648,209649,209649,209650,209650,209651,209655,209658,209661,209668,209677,209680,209688,209689,209689,209690,240394,240395,240395,240396,240399,346201,568349,568390,568394,568400,741980,890693,209652,209653,209653,209654,209654,209655,209655,209656,209656,209657,209657,209658,209659,209659,209660,209660,209661,209661,209662,209663,209663,209664,209666,209666,209667,209667,209668,209669,209671,209673,209674,209674,209675,209679,209681,209681,209683,209684,209686,209686,209687,209687,209688,209688,209689,209689,209690,209690,240394,240397,240397,240398,209653,209654,209655,209656,209657,209657,209658,209659,209662,209663,209664,209668,209671,209679,209687,209689,209689,209690,209690,209691,209657,209676,209691,209691,209660,209657,209659,209660,209662,209663,209664,209669,209678,209687,209691,209692,209692,209658,209692,209693,209691,209692,209692,209693,209661,209662,209666,209676,209693,209694,209694,209691,209695,209664,209665,209666,209667,209692,209693,209695,209695,209667,209667,209692,209695,209665,209696,209696,209667,209669,209697,209668,209681,209694,209695,209697,209669,209695,209696,209697,209670,209681,209696,209698,209698,209671,209696,209698,209671,209695,209699,209671,209690,209698,209672,209673,209677,209677,209685,209692,209695,209697,209698,209699,209699,209700,209700,209696,209697,209680,209686,209691,209699,209700,209701,209701,209699,209691,209698,209700,209704,209703,209704,209705,209692,209705,209706,209695,209707,209707,209708,209705,209708,209709,209709,209709,209711,209712,209708,209709,209698,209703,209709,209710,209711,209712,209712,209707,209712,209713,209708,209712,209713,209714,209715,209716,209715,209716,209717,209716,209718,209718,209717,209719,209719,209719,209722,209720,209721,209722,209724,209722,209724,209724,209722,209722,209723,209723,209724,209724,209725,209723,209724,209724,209725,209723,209724,209724,209725,209725,209726,209724,209725,209725,209726,209726,209725,209726,209726,209727,209726,209727,209727,741997,209727,209728,568387,209728,209729,240431,240432,240432,240433,240433,240434,240434,240435,240435,240436,240436,240437,240437,240438,240438,240439,269852,330278,346237,346238,346239,346240,346241,346242,351093,391561,479113,479178,520693,568387,568387,568388,568429,568436,568444,568445,741998,813949,890732,1078630,240432,240433,240433,240434,240435,240436,240437,568387,568388,271137,271135,271136,271136,271137,271137,271138,271139,271150,271150,271151,271151,271136,271137,271137,271138,271139,271151,271151,271152,271152,271137,271138,271138,271139,271140,271140,271151,271151,271152,271152,271153,271138,271139,271140,271152,271153,271153,271139,271140,271140,271141,271153,271153,271154,271154,271156,271140,271141,271141,271143,271143,271153,271153,271154,271154,271155,271156,271156,271158,271159,271141,271154,271154,271155,271155,271156,271142,271143,271144,271144,271154,271154,271155,271155,271156,271156,271157,271157,271158,271158,271159,271160,271161,271145,271154,271155,271155,271156,271156,271158,271158,271159,271160,271160,271156,271158,271159,271159,271160,271160,271161,271157,271158,271159,271160,271163,271156,271159,271162,271162,271163,271161,271163,271162,271166,271167,376959,599105,271166,271167,271167,271171,376960,599105,271167,271168,271168,271169,271170,599107,271168,271169,271170,271170,271171,271173,376961,599106,599107,772718,271169,271170,271170,271171,271171,271172,271172,271173,271173,300572,376957,376961,376961,422279,599107,599108,599149,751077,921452,271171,271171,271172,271173,271173,271174,376958,376962,422282,599107,599108,599108,271172,271172,271174,599109,599153,271172,271174,271175,376962,376962,422283,493843,599108,599109,271173,271174,271174,271175,271175,300574,357439,376959,376962,376963,376966,422283,509952,599109,599110,599151,599164,271175,271176,300574,376963,376964,509905,599109,599110,376964,599110,599110,599152,271177,376965,422285,599111,271177,299727,376965,376965,422285,509905,599111,599112,376966,599111,599112,599112,376962,599112,599155,599155,328350,627735,330050,406440,539378,628585,628586,443717,685387,450843,688951,482750,482763,482763,482764,482764,482765,482750,482765,482753,482767,482767,482769,482766,482768,482768,482768,482769,482769,482770,482771,704912,704913,704913,704914,482783,704913,704914,704956,482783,704914,704915,487621,528089,704914,704915,704915,704916,704916,492521,492521,709814,709815,573406,573405,573406,573409,573409,750231,750232,750231,923843,750234,750234,750235,750236,716524,821790,748563,748629,748639,748704,748705,748636,748661,748660,748714,748682,837864,837866,748756,748780,837913,837914,831702,831768,831836,879465,927045,927046,927046,927047,927048,927048,927049,927050,927050,927051,927052,927053,927054,927058,927063,927067,927074,927075,927076,927081,927083,927086,927087,927087,927088,927088,927113,927050,927050,927084,927088,927088,927050,927088,927089,927089,927090,927053,927066,927089,927090,927090,927091,927090,927091,927070,927091,927056,927092,927066,927092,927094,927095,927099,927102,927104,927105,927107,927108,927115,927116,927105,927117,927117,927121,927122,927124,927124,927127,927127,927128,927129,927129,927163,927130,927131,927131,927132,927132,927133,927133,927134,927134,927135,927135,927136,927136,927137,927138,927139,927140,927140,927141,927142,927143,927144,927145,927145,927146,927148,927149,927149,927150,927151,927153,927156,927157,927163,927163,927164,927131,927132,927132,927133,927133,927134,927135,927136,927137,927138,927138,927140,927140,927141,927143,927143,927148,927152,927153,927159,927163,927164,927164,927134,927136,927138,927139,927141,927143,927144,927147,927136,927139,927141,927142,927144,927144,927140,927142,927158,927136,927137,927139,927142,927136,927138,927143,927143,927146,927167,927138,927141,927143,927146,927146,927159,927139,927144,927146,927142,927144,927167,927140,927141,927142,927142,927143,927144,927145,927145,927146,927147,927148,927148,927150,927151,927155,927158,927159,927161,927169,927141,927145,927148,927144,927146,927146,927170,927146,927146,927147,927163,927164,927145,927147,927147,927150,927171,927148,927148,927150,927151,927164,927149,927150,927155,927162,927165,927173,927150,927151,927151,927152,927152,927153,927154,927154,927155,927155,927156,927157,927157,927159,927160,927160,927161,927161,927162,927162,927163,927166,927166,927167,927169,927170,927170,927172,927172,927173,927173,927174,927151,927152,927152,927153,927153,927155,927155,927156,927156,927158,927159,927160,927161,927161,927162,927163,927163,927164,927165,927166,927167,927168,927170,927173,927173,927174,927153,927156,927154,927154,927157,927174,927154,927170,927155,927156,927156,927157,927157,927158,927158,927160,927160,927161,927162,927163,927163,927164,927164,927165,927165,927166,927166,927167,927167,927168,927169,927169,927170,927170,927171,927172,927173,927175,927176,927157,927157,927158,927158,927159,927159,927161,927162,927163,927163,927164,927164,927165,927165,927166,927166,927167,927167,927169,927169,927170,927171,927172,927172,927173,927174,927174,927175,927175,927176,927176,927177,927158,927166,927166,927168,927178,927160,927160,927162,927163,927164,927165,927165,927166,927167,927168,927168,927169,927171,927172,927173,927173,927176,927177,927177,927178,927161,927164,927168,927168,927169,927178,927179,927161,927162,927164,927165,927166,927166,927167,927168,927168,927171,927172,927173,927173,927176,927178,927178,927179,927163,927164,927165,927165,927166,927166,927167,927168,927168,927169,927170,927171,927172,927172,927173,927173,927174,927177,927178,927178,927179,927179,927180,927179,927181,927180,927181,927168,927168,927169,927170,927174,927178,927181,927172,927168,927170,927175,927175,927182,927183,927171,927172,927175,927179,927180,927183,1100775,927170,927171,927172,927172,927173,927174,927176,927180,927183,927184,927171,927172,927173,927173,927174,927175,927176,927177,927177,927178,927179,927180,927182,927183,927184,927173,927173,927174,927175,927177,927177,927178,927180,927181,927184,927184,927185,927175,927176,927180,927182,927174,927175,927175,927176,927178,927178,927179,927179,927180,927181,927183,927185,927186,927175,927176,927176,927177,927178,927179,927179,927180,927181,927182,927184,927185,927186,927177,927179,927179,927180,927181,927182,927182,927183,927183,927185,927186,927187,927177,927179,927180,927186,927187,927187,927179,927180,927180,927181,927184,927185,927187,927188,927182,927184,927187,927188,927181,927181,927182,927188,927182,927183,927183,927184,927184,927185,927186,927187,927188,927188,927189,927190,1079084,927183,927184,927184,927185,927186,927187,927188,927188,927189,927190,927184,927185,927186,927187,927187,927188,927188,927189,927189,927190,927190,927191,927185,927186,927187,927187,927190,927190,927191,927191,1100726,927187,927188,927190,927191,927192,927188,927191,927192,927189,927192,927192,927193,927189,927191,927192,927193,927191,927191,927192,927193,927193,927194,927192,927193,927194,927193,927194,927194,927195,927194,927195,927195,927194,927195,927196,927195,927196,927196,927197,927197,927198,927199,927199,927200,927201,927201,927202,927203,927204,927204,927205,927206,927207,927207,927208,927209,927209,927210,927210,927211,927211,927212,927212,927213,927213,927215,927216,927216,927218,927220,927222,927222,927223,927223,927226,927228,927229,927229,927231,927234,927234,927235,927235,927236,927236,927237,927237,927238,927238,927239,927239,1079092,1079095,1079095,1100733,1100753,1100754,1172684,1172705,1249467,927199,927200,927200,927201,927202,927202,927203,927203,927204,927205,927206,927206,927207,927207,927208,927209,927210,927210,927211,927213,927215,927216,927222,927223,927224,927224,927226,927228,927230,927231,927232,927233,927234,927235,927236,927237,927237,927238,927239,927239,927240,927201,927207,927208,927209,927227,927232,927236,927240,927240,927214,927240,927204,927205,927207,927211,927212,927213,927215,927219,927230,927231,927233,927238,927239,927240,927241,927205,927204,927213,927216,927210,927213,927227,927240,927243,927211,927212,927214,927220,927235,927236,927238,927241,927242,927242,927243,927211,927217,927239,927244,927218,927242,927214,927234,927239,927240,927242,927244,927212,927226,927240,927242,927243,927212,927213,927215,927235,927245,927245,927232,927237,927244,927215,927221,927228,927231,927245,927215,927218,927220,927229,927231,927237,927244,927245,927246,927248,1079103,927218,927219,927220,927225,927230,927240,927246,927247,927248,927248,927217,927232,927236,927241,927246,927248,927249,927219,927241,927249,927220,927247,927225,927227,927238,927242,927246,927247,927248,927250,927221,927222,927233,927240,927245,927247,927223,927228,927231,927232,927243,927249,927250,927251,927251,927249,927252,927241,927244,927247,927250,927233,927235,927246,927248,927253,927251,927235,927244,927247,927249,927252,927253,927254,927242,927248,927255,927246,927256,927239,927253,927255,927257,927249,927255,927255,927257,927258,927256,927259,927250,927249,927246,927255,927258,927258,927260,927262,927260,927255,927261,927261,927263,927256,927261,927262,927264,927259,927260,927262,927262,927262,927263,927265,927257,927263,927259,927260,927268,927267,927268,927264,927269,927261,927269,927262,927263,927266,927269,927270,927267,927268,927269,927270,927270,927263,927268,927269,927271,927268,927264,927270,927267,927267,927268,927268,927269,927269,927270,927270,927271,927271,927272,927272,927273,927268,927273,927274,927274,927272,927274,927271,927272,927273,927274,927275,927275,927272,927273,927274,927275,927275,927276,927274,927276,927273,927274,927274,927275,927276,927277,927274,927275,927276,927276,927277,927275,927276,927276,927277,927277,927278,1100771,927276,927277,927277,927278,927278,927277,927278,927278,927279,927278,927279,927279,927279,927280,927280,927281,997029,1016341,1041603,1076637,1079130,1079130,1079131,1079131,1079132,1079132,1079133,1079133,1079134,1079134,1079135,1079135,1079136,1079136,1079137,1079137,1079138,1100774,1100774,1100795,1100830,1172725,1172747,1249508,927284,1016341,1079131,1079131,1079133,1079134,1079134,1079135,1079135,1079136,1079136,1079137,1100775,1079133,1066796,1148901,1105411,1105413,1105414,1105504,1105506,1105507,1105598,1119859,1168301,1189938,1134126,1134183,1134238,1182619,1155938,1193473,1225998,1226072,1226147,1228569,1230980,1230980,1230981,1230982,1230984,1230997,1230982,1230983,1230984,1230984,1230985,1230986,1230987,1230996,1230997,1230997,1230998,1230998,1230999,1230984,1230986,1230986,1230984,1230985,1230987,1230988,1230985,1231002,1231003,1230985,1230986,1230986,1230987,1230988,1230988,1230989,1231002,1231004,1231005,1231006,1230986,1230987,1230987,1230988,1230988,1230989,1230990,1230999,1231003,1231004,1231004,1230987,1230988,1230988,1230989,1230989,1230990,1230990,1230991,1231000,1231002,1231003,1231004,1231004,1231005,1231005,1230988,1230989,1230989,1230990,1230990,1230991,1230992,1231002,1231004,1231005,1231005,1231006,1231006,1231007,1230989,1230990,1230990,1230991,1230991,1230992,1230993,1231000,1231000,1231001,1231003,1231005,1231005,1231006,1231006,1231007,1230990,1230991,1230991,1230992,1230992,1231004,1231005,1231006,1231006,1231007,1230991,1230992,1230992,1231002,1231006,1231006,1231007,1231007,1230992,1230993,1231001,1231001,1231002,1231002,1231003,1231004,1231005,1231006,1231007,1231007,1231008,1231008,1231009,1230993,1230994,1231002,1231002,1231003,1231006,1231007,1231007,1231008,1231008,1231009,1231010,1231002,1231007,1231008,1231008,1231009,1231009,1231008,1231008,1231009,1231010,1231009,1231010,1231016,1231017,1231013,1231016,1231016,1231017,1231017,1231018,1252640,1231015,1231017,1231018,1231017,1231018,1231019,1252641,1231018,1324592,1231017,1231020,1231020,1401376,1324593,1231020,1231020,1231021,1252643,1324594,1231021,1231021,1231022,1231021,1231022,1231022,1231023,1252644,1324595,1324619,1231022,1231023,1231023,1231027,1252644,1252645,1252701,1231023,1231024,1231024,1252645,1252645,1252666,1324596,1324618,1401379,1806366,1231024,1231025,1252645,1252646,1324597,1324655,1401380,1401432,1231025,1252646,1252647,1252647,1252648,1252650,1274267,1274268,1274269,1274269,1274270,1274270,1274271,1274275,1274277,1274278,1274288,1274288,1274289,1274343,1274288,1274289,1274289,1274271,1274272,1274289,1274290,1274290,1274290,1274291,1274291,1274295,1274288,1274288,1274289,1274290,1274290,1274299,1274332,1274333,1274354,1346230,1346251,1423013,1274300,1274302,1346251,1274308,1274363,1274309,1274310,1274310,1274311,1274313,1274313,1274314,1274314,1274315,1274318,1274320,1274321,1274322,1274325,1274325,1274326,1274328,1274329,1274329,1274330,1274330,1274333,1274334,1274335,1274336,1274337,1274338,1274338,1274339,1274339,1274340,1274340,1274341,1274342,1274342,1274343,1274344,1274345,1274345,1274346,1274347,1274351,1274356,1274358,1274360,1274361,1274363,1274364,1274321,1274325,1274326,1274331,1274337,1274338,1274339,1274343,1274343,1274364,1274364,1274361,1274365,1274338,1274332,1274317,1274326,1274368,1274341,1274368,1274344,1274366,1274370,1274344,1274348,1274354,1274356,1274375,1274342,1274350,1274350,1274351,1274351,1274376,1274351,1274377,1274354,1274350,1274352,1274358,1274347,1274356,1274359,1274380,1274355,1274361,1274357,1274383,1274363,1274384,1274360,1274365,1274360,1274361,1274363,1274356,1274360,1274361,1274361,1274363,1274364,1274364,1274367,1274388,1274389,1274364,1274367,1274368,1274368,1274364,1274366,1274366,1274367,1274368,1274368,1274369,1274391,1274365,1274366,1274392,1274367,1274368,1274369,1274370,1274375,1274389,1274393,1274369,1274375,1274392,1274393,1274370,1274371,1274372,1274372,1274373,1274374,1274391,1274391,1274394,1274370,1274372,1274372,1274373,1274373,1274375,1274378,1274391,1274373,1274374,1274376,1274386,1274391,1274392,1274392,1274394,1274395,1274373,1274381,1274395,1274374,1274396,1274374,1274381,1274384,1274389,1274394,1274396,1274376,1274376,1274383,1274397,1274378,1274379,1274380,1274382,1274393,1274394,1274397,1274397,1274377,1274378,1274383,1274385,1274397,1274398,1274398,1274382,1274394,1274396,1274397,1274399,1274384,1274395,1274396,1274397,1274400,1274382,1274400,1274398,1274401,1274393,1274399,1274402,1274400,1274403,1274403,1274404,1274405,1423063,1274406,1274406,1274407,1274410,1274408,1274411,1274412,1274413,1274410,1274414,1274410,1274415,1274415,1274415,1274415,1274416,1346291,1274414,1274416,1274416,1274417,1274418,1274418,1274439,1346315,1274419,1274420,1274424,1274424,1274429,1274432,1274433,1274437,1274437,1274438,1274438,1274439,1274439,1346294,1346316,1346347,1423077,1423119,1525353,1610975,1274424,1274432,1274438,1274439,1274439,1274440,1274440,1274444,1274445,1274450,1274452,1274453,1274453,1274457,1274458,1274458,1274458,1274459,1274459,1346314,1274460,1295375,1295435,1306878,1306893,1346314,1346315,1346336,1423098,1423139,1525340,1832798,1346315,1316305,1316365,1316429,1316423,1367303,1367309,1339318,1339338,1378755,1378759,1418169,1418170,1418171,1418171,1418172,1418173,1418188,1418189,1418189,1418190,1418190,1418191,1418191,1418192,1418211,1418245,1418245,1418185,1418191,1418192,1418192,1418192,1418194,1418194,1418205,1418209,1418210,1418210,1418211,1418211,1418211,1418212,1418212,1418213,1418214,1418214,1418215,1418215,1418216,1418216,1418217,1418217,1418218,1418218,1418219,1418221,1418221,1418222,1418222,1418224,1418224,1418225,1418226,1418228,1418228,1418229,1418230,1418231,1418232,1418232,1418233,1418234,1418234,1418235,1418235,1418236,1418237,1418238,1418238,1418239,1418240,1418240,1418241,1418241,1418242,1418242,1418243,1418243,1418244,1418244,1418245,1418246,1418247,1418248,1418248,1418250,1418251,1418253,1418254,1418255,1418259,1418262,1418264,1418265,1418266,1418267,1418214,1418216,1418216,1418217,1418217,1418218,1418219,1418222,1418222,1418232,1418232,1418233,1418235,1418236,1418236,1418238,1418238,1418239,1418241,1418242,1418243,1418244,1418246,1418265,1418266,1418267,1418267,1418218,1418229,1418230,1418233,1418233,1418235,1418235,1418239,1418241,1418242,1418267,1418268,1418221,1418248,1418224,1418233,1418235,1418237,1418240,1418243,1418251,1418269,1418227,1418236,1418240,1418241,1418228,1418239,1418242,1418242,1418246,1418223,1418225,1418235,1418236,1418239,1418242,1418271,1418245,1418225,1418237,1418272,1418237,1418254,1418234,1418245,1418238,1418246,1418233,1418243,1418249,1418243,1418247,1418250,1418251,1418252,1418276,1418241,1418244,1418245,1418243,1418246,1418247,1418250,1418260,1418277,1418244,1418255,1418260,1418248,1418259,1418281,1418250,1418265,1418282,1418256,1418251,1418251,1418255,1418258,1418258,1418261,1418265,1418251,1418252,1418256,1418250,1418254,1418256,1418259,1418252,1418253,1418257,1418257,1418259,1418262,1418267,1418260,1418283,1418286,1418253,1418254,1418254,1418257,1418258,1418258,1418260,1418264,1418265,1418267,1418286,1418255,1418255,1418257,1418258,1418287,1418307,1418259,1418261,1418268,1418288,1418256,1418257,1418257,1418258,1418259,1418259,1418260,1418261,1418262,1418262,1418263,1418264,1418265,1418265,1418266,1418266,1418268,1418268,1418270,1418270,1418271,1418288,1418288,1494996,1418258,1418260,1418262,1418265,1418266,1418268,1418269,1418289,1418258,1418260,1418263,1418266,1418266,1418267,1418289,1418289,1418261,1418261,1418261,1418266,1418267,1418268,1418290,1418264,1418265,1418262,1418268,1418272,1418275,1418263,1418264,1418265,1418266,1418266,1418267,1418267,1418268,1418269,1418270,1418272,1418275,1418276,1418278,1418291,1418292,1494999,1418266,1418266,1418267,1418267,1418268,1418269,1418270,1418272,1418274,1418275,1418276,1418290,1418292,1418266,1418267,1418293,1418269,1418274,1418268,1418269,1418270,1418271,1418271,1418272,1418273,1418274,1418274,1418276,1418278,1418280,1418294,1418269,1418270,1418270,1418271,1418272,1418273,1418275,1418275,1418276,1418277,1418277,1418294,1418295,1418271,1418295,1495003,1418271,1418272,1418273,1418274,1418275,1418276,1418277,1418278,1418279,1418279,1418293,1418295,1418295,1418296,1418273,1418273,1418274,1418274,1418275,1418276,1418276,1418277,1418277,1418278,1418279,1418279,1418280,1418281,1418285,1418288,1418289,1418291,1418292,1418296,1418296,1418274,1418275,1418276,1418297,1418275,1418277,1418279,1418281,1418286,1418292,1418297,1418297,1418275,1418276,1418277,1418278,1418278,1418280,1418285,1418286,1418290,1418293,1418295,1418297,1418298,1418278,1418278,1418279,1418298,1418278,1418279,1418279,1418280,1418280,1418281,1418282,1418283,1418296,1418297,1418297,1418298,1418299,1418279,1418280,1418281,1418282,1418289,1418292,1418299,1418300,1495007,1495059,1418280,1418283,1418290,1418294,1418300,1418300,1418282,1418282,1418283,1418284,1418291,1418294,1418296,1418300,1418301,1418282,1418283,1418283,1418284,1418291,1418293,1418299,1418301,1418301,1418283,1418294,1418301,1418302,1418285,1418296,1418298,1418300,1418302,1418302,1418290,1418292,1418295,1418296,1418300,1418302,1418303,1418288,1418303,1418303,1418294,1418300,1418303,1418304,1418295,1418298,1418299,1418304,1418304,1418304,1418305,1418305,1418303,1418306,1418306,1418307,1418308,1418301,1418308,1418309,1418309,1418299,1418304,1418309,1418310,1418301,1418306,1418311,1418312,1418312,1418312,1418313,1418306,1418313,1418313,1418311,1418314,1418314,1418310,1418315,1418315,1418315,1418316,1418316,1418316,1418316,1418317,1418317,1418318,1418317,1418318,1418318,1418319,1418319,1418319,1418319,1418320,1418320,1418321,1418340,1418341,1418342,1495028,1418321,1418322,1418322,1418324,1418325,1418325,1418327,1418333,1418334,1418335,1418336,1418336,1418337,1418339,1418340,1418341,1418341,1418342,1418342,1495028,1495080,1495085,1903379,1418322,1418323,1418323,1418324,1418327,1418336,1418336,1418337,1418338,1418339,1418339,1418340,1418341,1418341,1418342,1418342,1418343,1418342,1418343,1418343,1418344,1418344,1418339,1418346,1418345,1418346,1418347,1418348,1418351,1418353,1418355,1418357,1418357,1418357,1418357,1418358,1418358,1418356,1418358,1418359,1418359,1418359,1418360,1418361,1418360,1418361,1418361,1418362,1418361,1418362,1418362,1418362,1418363,1418363,1418364,1486805,1488057,1495049,1495050,1495103,1495104,1597292,1682948,1899649,1899998,1900037,1495050,1555259,1563504,1557759,1564752,1571735,1571736,1571737,1571738,1571738,1571739,1571740,1571742,1571746,1571747,1571755,1571758,1571759,1571772,1571773,1571776,1571776,1571777,1571777,1571786,1571811,1571738,1571739,1571739,1571747,1571776,1571777,1571777,1571778,1571778,1571749,1571761,1571779,1571779,1571779,1571758,1571780,1571780,1571759,1571782,1571757,1571787,1571788,1571788,1571795,1571797,1571799,1673989,1674023,1759684,1976396,1976734,1571796,1571797,1571800,1571800,1571799,1571813,1571814,1571816,1571817,1571817,1571817,1571818,1571818,1571826,1571828,1571828,1571829,1571829,1571832,1571852,1571818,1571828,1571819,1571820,1571820,1571821,1571821,1571822,1571822,1571823,1571823,1571824,1571824,1571825,1571825,1571826,1571826,1571827,1571827,1571828,1571829,1571829,1571830,1571830,1571831,1571832,1571832,1571833,1571833,1571834,1571834,1571835,1571836,1571836,1571837,1571837,1571838,1571838,1571839,1571840,1571840,1571841,1571843,1571843,1571844,1571844,1571850,1571852,1571853,1571820,1571821,1571821,1571822,1571822,1571823,1571823,1571824,1571824,1571825,1571826,1571827,1571827,1571828,1571829,1571829,1571830,1571832,1571833,1571853,1571853,1571821,1571822,1571822,1571823,1571823,1571825,1571826,1571827,1571828,1571828,1571829,1571830,1571831,1571834,1571837,1571841,1571843,1571854,1571822,1571823,1571828,1571829,1571830,1571830,1571842,1571823,1571824,1571824,1571826,1571827,1571829,1571829,1571830,1571830,1571831,1571832,1571833,1571834,1571835,1571836,1571836,1571838,1571853,1571855,1571824,1571825,1571826,1571829,1571830,1571836,1571838,1571855,1571825,1571826,1571826,1571827,1571828,1571828,1571829,1571829,1571830,1571830,1571831,1571832,1571833,1571835,1571856,1571827,1571828,1571831,1571832,1571833,1571834,1571836,1571856,1571828,1571828,1571830,1571831,1571832,1571833,1571834,1571834,1571829,1571831,1571832,1571836,1571831,1571831,1571832,1571832,1571833,1571834,1571835,1571835,1571838,1571858,1571833,1571834,1571834,1571836,1571858,1571832,1571833,1571859,1571832,1571833,1571834,1571835,1571835,1571836,1571838,1571834,1571836,1571834,1571835,1571836,1571836,1571837,1571838,1571841,1571842,1571843,1571846,1571847,1571855,1571860,1571835,1571836,1571837,1571838,1571837,1571837,1571838,1571838,1571839,1571839,1571840,1571840,1571841,1571841,1571842,1571844,1571845,1571846,1571847,1571848,1571849,1571852,1571853,1571853,1571854,1571855,1571856,1571856,1571859,1571861,1571861,1571860,1571838,1571839,1571839,1571840,1571841,1571842,1571843,1571843,1571844,1571846,1571847,1571848,1571849,1571853,1571853,1571854,1571856,1571857,1571858,1571862,1571839,1571840,1571840,1571841,1571842,1571842,1571843,1571843,1571844,1571844,1571845,1571846,1571846,1571847,1571847,1571848,1571849,1571850,1571850,1571851,1571852,1571853,1571853,1571854,1571854,1571856,1571857,1571858,1571860,1571861,1571861,1571862,1571863,1571840,1571841,1571841,1571842,1571842,1571843,1571844,1571844,1571850,1571852,1571854,1571854,1571855,1571857,1571863,1571841,1571842,1571843,1571843,1571844,1571844,1571845,1571846,1571846,1571847,1571847,1571850,1571851,1571852,1571853,1571854,1571855,1571855,1571857,1571858,1571861,1571864,1571843,1571843,1571844,1571844,1571845,1571845,1571846,1571846,1571847,1571848,1571849,1571850,1571851,1571852,1571852,1571853,1571855,1571855,1571856,1571856,1571858,1571859,1571862,1571864,1571865,1571844,1571845,1571845,1571846,1571846,1571848,1571850,1571851,1571852,1571853,1571853,1571854,1571856,1571856,1571857,1571860,1571862,1571863,1571865,1571845,1571846,1571846,1571847,1571849,1571849,1571850,1571851,1571852,1571853,1571854,1571856,1571857,1571860,1571866,1571846,1571847,1571847,1571848,1571849,1571850,1571851,1571852,1571853,1571854,1571854,1571855,1571857,1571857,1571866,1571847,1571848,1571848,1571849,1571851,1571853,1571853,1571854,1571854,1571855,1571857,1571858,1571859,1571862,1571864,1571865,1571867,1571848,1571849,1571849,1571851,1571852,1571854,1571855,1571855,1571856,1571858,1571859,1571861,1571863,1571864,1571867,1571867,1571849,1571850,1571851,1571852,1571853,1571853,1571854,1571854,1571855,1571855,1571856,1571857,1571858,1571859,1571860,1571861,1571864,1571865,1571867,1571868,1571850,1571852,1571856,1571859,1571860,1571866,1571868,1571868,1571853,1571854,1571856,1571857,1571858,1571858,1571859,1571863,1571868,1571869,1571852,1571857,1571854,1571855,1571856,1571857,1571857,1571860,1571861,1571870,1571855,1571855,1571858,1571859,1571860,1571861,1571864,1571865,1571868,1571870,1571860,1571862,1571871,1571857,1571859,1571859,1571862,1571863,1571863,1571866,1571866,1571871,1571858,1571859,1571859,1571860,1571861,1571862,1571863,1571863,1571870,1571871,1571872,1571863,1571866,1571872,1571860,1571862,1571863,1571863,1571864,1571865,1571867,1571867,1571868,1571870,1571871,1571873,1571860,1571861,1571864,1571861,1571863,1571864,1571865,1571865,1571867,1571868,1571874,1759696,1571862,1571863,1571863,1571864,1571865,1571865,1571866,1571868,1571869,1571872,1571874,1571874,1571864,1571864,1571865,1571866,1571866,1571867,1571868,1571875,1571864,1571870,1571866,1571866,1571867,1571867,1571870,1571874,1571875,1571876,1571868,1571870,1571876,1571867,1571868,1571868,1571875,1571877,1571868,1571869,1571871,1571872,1571873,1571875,1571877,1571877,1571869,1571870,1571871,1571872,1571873,1571873,1571874,1571875,1571877,1571878,1571870,1571872,1571873,1571876,1571876,1571877,1571877,1571878,1571878,1571872,1571873,1571877,1571879,1571879,1571875,1571875,1571876,1571877,1571877,1571878,1571879,1571880,1571880,1571881,1571879,1571879,1571880,1571880,1571881,1571881,1571881,1571882,1571882,1571879,1571882,1571882,1571882,1571883,1571881,1571883,1571881,1571883,1571884,1571882,1571884,1571884,1571884,1571885,1571885,1571885,1571886,1571886,1571887,1571888,1571888,1571889,1571889,1571890,1571892,1571892,1571893,1571893,1571894,1571894,1571895,1571895,1571896,1571896,1571897,1571899,1571900,1571903,1571905,1571907,1571908,1571912,1571916,1571916,1571917,1571918,1571923,1571924,1571926,1571927,1571927,1571928,1571928,1674054,1674076,1674087,1674087,1674106,1674107,1759709,1759748,1759751,1759759,1759768,1976410,1976453,1976464,1976468,1976798,1571888,1571889,1571889,1571890,1571890,1571891,1571892,1571892,1571893,1571894,1571895,1571895,1571896,1571897,1571897,1571899,1571900,1571900,1571901,1571902,1571904,1571906,1571907,1571910,1571912,1571913,1571914,1571918,1571919,1571923,1571926,1571926,1571927,1571928,1571928,1571929,1674054,1759750,1976760,1571889,1571896,1571899,1571901,1571902,1571914,1571925,1571929,1571929,1571892,1571904,1571930,1571892,1571930,1571930,1571930,1571931,1571931,1571898,1571902,1571914,1571927,1571930,1571933,1571900,1571933,1571933,1571934,1571934,1571901,1571903,1571909,1571924,1571934,1571935,1571935,1571902,1571936,1571904,1571904,1571905,1571906,1571906,1571907,1571907,1571911,1571935,1571936,1571936,1571909,1571936,1571937,1571905,1571918,1571937,1571909,1571909,1571935,1571937,1571938,1571938,1571938,1571911,1571939,1571911,1571939,1571940,1571911,1571912,1571939,1571940,1571941,1571923,1571924,1571941,1571941,1571942,1571943,1571943,1571944,1571944,1571944,1571938,1571946,1571947,1571948,1571949,1571950,1571950,1571950,1571951,1571946,1571952,1571950,1571953,1571953,1571951,1571954,1571955,1571946,1571946,1571958,1571947,1571948,1571958,1571958,1571959,1571959,1571959,1571963,1571963,1571964,1571965,1571965,1571963,1571966,1571967,1571965,1571967,1571967,1571967,1571968,1571968,1571968,1571969,1571969,1571970,1571971,1571971,1571972,1571972,1571973,1674095,1674129,1674132,1674145,1674149,1759751,1759790,1759800,1759806,1976452,1976504,1976801,1976840,1990311,1997272,1998453,1571973,1674096,1976452,1571974,1653857,1674096,1674097,1674097,1571975,1674098,1674098,1759795,1735755,1735831,1735906,1756070,1776220,1776221,1776222,1776222,1776223,1776223,1776225,1776228,1776230,1776230,1776231,1776241,1776243,1776244,1776252,1776253,1776254,1776254,1776296,1776223,1776224,1776254,1776255,1776255,1776255,1776226,1776255,1776255,1776255,1776256,1776256,1776256,1776257,1776258,1776261,1776263,1776263,1776265,1776274,1776318,1776276,1776277,1776285,1776286,1776286,1776287,1776287,1776305,1776305,1776288,1776289,1776289,1776290,1776291,1776291,1776292,1776292,1776293,1776293,1776294,1776294,1776295,1776296,1776297,1776299,1776300,1776301,1776301,1776302,1776303,1776304,1776304,1776305,1776306,1776306,1776307,1776307,1776308,1776308,1776309,1776309,1776310,1776310,1776311,1776312,1776313,1776314,1776315,1776321,1776323,1776323,1776326,1776328,1776328,1776329,1776330,1776289,1776290,1776291,1776297,1776303,1776304,1776305,1776306,1776306,1776307,1776308,1776330,1776293,1776297,1776302,1776304,1776305,1776307,1776311,1776331,1776292,1776293,1776294,1776301,1776304,1776304,1776305,1776306,1776307,1776309,1776293,1776305,1776306,1776307,1776309,1776312,1776307,1776309,1776312,1776297,1776307,1776310,1776311,1776297,1776306,1776307,1776309,1776313,1776334,1776308,1776309,1776309,1776310,1776312,1776312,1776314,1776301,1776307,1776312,1776314,1776336,1776307,1776313,1776332,1776337,1776313,1776314,1776324,1776313,1776324,1776314,1776314,1776315,1776316,1776342,1776343,1776318,1776319,1776331,1776343,1776343,1776318,1776319,1776344,1776319,1776319,1776320,1776321,1776321,1776322,1776324,1776329,1776330,1776340,1776341,1776345,1776320,1776321,1776322,1776323,1776325,1776325,1776327,1776330,1776331,1776332,1776333,1776337,1776341,1776344,1776346,1776322,1776322,1776323,1776324,1776325,1776326,1776326,1776327,1776327,1776328,1776328,1776331,1776332,1776332,1776333,1776342,1776346,1776323,1776324,1776325,1776325,1776326,1776326,1776327,1776330,1776332,1776333,1776334,1776343,1776346,1776347,1776325,1776325,1776326,1776327,1776327,1776328,1776329,1776329,1776331,1776332,1776333,1776337,1776339,1776343,1776345,1776348,1776327,1776328,1776331,1776331,1776333,1776343,1776344,1776346,1776348,1776326,1776328,1776328,1776329,1776330,1776330,1776331,1776333,1776334,1776328,1776328,1776329,1776329,1776330,1776331,1776331,1776332,1776334,1776336,1776344,1776345,1776346,1776348,1776349,1776334,1776350,1776329,1776330,1776332,1776348,1776350,1776330,1776331,1776331,1776333,1776334,1776335,1776336,1776345,1776346,1776351,1776331,1776332,1776332,1776333,1776336,1776337,1776338,1776339,1776351,1776351,1776333,1776336,1776337,1776338,1776338,1776351,1776352,1776335,1776337,1776352,1776334,1776337,1776338,1776340,1776353,1776336,1776338,1776352,1776353,1776353,1776338,1776347,1776348,1776354,1776337,1776339,1776340,1776354,1776339,1776342,1776355,1776342,1776342,1776343,1776344,1776344,1776352,1776354,1776355,1776356,1776356,1776343,1776344,1776349,1776352,1776354,1776355,1776355,1776357,1776357,1776355,1776357,1776358,1776358,1776347,1776354,1776358,1776359,1776359,1776360,1776361,1776361,1776363,1776365,1776365,1776389,1776366,1776362,1776366,1776363,1776367,1776367,1776368,1776367,1776369,1776369,1776370,1776369,1776370,1776371,1776371,1776371,1776372,1776373,1776376,1776377,1776379,1776380,1776381,1776382,1776388,1776390,1776393,1776394,1776395,1776396,1776398,1776399,1776402,1776403,1776403,1776404,1776404,1776405,1776405,1861952,1861991,1861992,1861996,1861997,1862001,1862003,1862004,1862007,2078653,2078760,2079041,2082426,1776373,1776374,1776375,1776376,1776376,1776377,1776380,1776382,1776389,1776390,1776390,1776394,1776395,1776395,1776399,1776402,1776403,1776404,1776404,1776405,1776405,1776406,1776404,1776405,1776406,1776406,1776407,1776407,1776408,1776408,1776409,1776394,1776398,1776407,1776409,1776409,1776410,1776410,1776412,1776410,1776403,1776414,1776415,1776421,1776422,1776421,1776421,1776422,1776423,1776426,1776418,1776427,1776428,1776426,1776428,1776429,1776429,1776430,1776425,1776431,1776431,1776430,1776432,1776432,1776433,1776434,1776434,1776435,1776436,1776436,1776436,1776436,1776437,1776437,1776437,1776437,1776438,1776438,1861985,1776439,1847397,1861985,1861985,1862024,1862024,1862026,1862035,1862037,1862039,1862043,1862044,2078686,2078729,2079035,1861985,1861986,1918368,1918370,1918372,1932956,2149657,1932958,1932961,1947531,1947532,1947533,1947534,1947534,1947541,1947542,1947543,1947549,1947553,1947556,1947566,1947569,1947570,1947570,1947571,1947607,1947571,1947571,1947572,1947573,1947573,1947580,1947581,1947582,1947588,1947592,1947594,1947605,1947608,1947608,1947609,1947609,1947610,1947611,1947611,1947612,1947612,1947613,1947613,1947614,1947615,1947615,1947616,1947617,1947617,1947618,1947618,1947619,1947619,1947620,1947621,1947622,1947622,1947623,1947624,1947624,1947625,1947625,1947626,1947626,1947627,1947628,1947629,1947629,1947630,1947631,1947636,1947645,1947646,1947646,1947648,1947611,1947612,1947612,1947621,1947622,1947623,1947636,1947645,1947647,1947612,1947613,1947614,1947615,1947618,1947620,1947621,1947623,1947623,1947624,1947625,1947626,1947626,1947627,1947628,1947629,1947629,1947632,1947646,1947647,1947613,1947614,1947615,1947616,1947617,1947620,1947621,1947622,1947623,1947624,1947625,1947626,1947627,1947628,1947633,1947637,1947644,1947646,1947646,1947647,1947648,1947614,1947615,1947616,1947616,1947617,1947618,1947621,1947622,1947624,1947625,1947625,1947626,1947627,1947628,1947629,1947630,1947647,1947648,1947615,1947618,1947622,1947623,1947625,1947625,1947626,1947631,1947619,1947621,1947622,1947623,1947625,1947627,1947649,1947627,1947630,1947623,1947624,1947626,1947621,1947625,1947627,1947624,1947625,1947627,1947651,1947624,1947626,1947628,1947632,1947634,1947630,1947634,1947633,1947646,1947653,1947627,1947631,1947636,1947653,1947652,1947628,1947630,1947630,1947629,1947629,1947631,1947655,1947630,1947632,1947633,1947634,1947636,1947639,1947644,1947645,1947645,1947649,1947654,1947655,1947656,1947634,1947632,1947633,1947634,1947635,1947635,1947636,1947637,1947637,1947638,1947639,1947639,1947640,1947640,1947641,1947642,1947644,1947646,1947646,1947647,1947647,1947648,1947649,1947655,1947657,1947635,1947634,1947635,1947636,1947636,1947637,1947638,1947639,1947643,1947643,1947645,1947647,1947649,1947657,1947658,1947635,1947636,1947636,1947637,1947637,1947638,1947639,1947640,1947640,1947641,1947641,1947642,1947642,1947643,1947644,1947645,1947646,1947646,1947647,1947648,1947648,1947649,1947649,1947653,1947656,1947657,1947658,1947659,1947659,1947641,1947641,1947654,1947637,1947638,1947638,1947639,1947640,1947641,1947643,1947648,1947649,1947657,1947658,1947638,1947639,1947639,1947640,1947640,1947642,1947642,1947643,1947643,1947644,1947645,1947647,1947648,1947649,1947649,1947650,1947651,1947657,1947660,1947639,1947640,1947641,1947641,1947642,1947642,1947643,1947643,1947644,1947644,1947648,1947649,1947650,1947661,1947640,1947641,1947642,1947643,1947643,1947644,1947644,1947645,1947648,1947650,1947650,1947651,1947652,1947658,1947659,1947661,1947641,1947642,1947643,1947644,1947644,1947645,1947645,1947646,1947647,1947649,1947650,1947651,1947651,1947653,1947655,1947658,1947660,1947662,1947645,1947647,1947643,1947644,1947644,1947645,1947646,1947646,1947647,1947647,1947650,1947651,1947652,1947653,1947658,1947659,1947660,1947663,1947645,1947646,1947648,1947652,1947653,1947660,1947646,1947646,1947647,1947648,1947651,1947653,1947659,1947664,1947646,1947649,1947652,1947657,1947664,1947647,1947648,1947648,1947649,1947649,1947650,1947652,1947653,1947654,1947655,1947661,1947663,1947664,1947665,1947648,1947649,1947649,1947650,1947652,1947655,1947656,1947658,1947660,1947662,1947664,1947665,1947649,1947650,1947650,1947651,1947653,1947653,1947654,1947655,1947655,1947656,1947660,1947663,1947664,1947665,1947666,2164640,1947651,1947653,1947654,1947655,1947656,1947657,1947658,1947660,1947662,1947666,1947651,1947654,1947655,1947656,1947662,1947665,1947666,1947667,1947652,1947653,1947654,1947654,1947655,1947656,1947656,1947657,1947657,1947658,1947667,1947667,1947655,1947656,1947657,1947658,1947658,1947667,1947668,1947668,1947658,1947658,1947657,1947658,1947659,1947659,1947660,1947660,1947662,1947666,1947669,1947670,1947659,1947660,1947661,1947670,1947671,1947660,1947661,1947661,1947670,1947671,1947661,1947662,1947662,1947663,1947667,1947669,1947670,1947671,1947671,1947672,1947662,1947663,1947663,1947664,1947666,1947671,1947672,1947672,1947669,1947671,1947672,1947673,1947667,1947668,1947671,1947672,1947673,1947673,1947672,1947672,1947674,1947675,1947675,1947674,1947676,1947675,1947673,1947677,1947677,1947675,1947676,1947677,1947678,1947678,1947678,1947679,1947680,1947679,1947680,1947679,1947681,1947680,1947681,1947681,1947681,1947682,1947682,1947683,1947684,1947684,1947685,1947686,1947688,1947688,1947689,1947689,1947690,1947691,1947692,1947693,1947693,1947694,1947697,1947700,1947704,1947705,1947708,1947710,1947711,1947712,1947715,1947719,1947719,1947720,1947720,1947721,1947721,1947722,2112320,2164308,2164331,2164351,2164359,2164361,2164362,2164364,2164657,2164696,2164696,1947684,1947685,1947686,1947687,1947688,1947701,1947712,1947720,1947720,1947721,1947721,1947722,1947722,1947723,2164351,1947685,1947689,1947699,1947716,1947723,1947689,1947691,1947692,1947693,1947694,1947695,1947699,1947700,1947702,1947703,1947704,1947709,1947713,1947714,1947715,1947718,1947719,1947720,1947721,1947721,1947722,1947722,1947723,1947723,1947717,1947724,1947725,1947724,1947694,1947695,1947697,1947725,1947726,2164314,1947695,1947697,1947727,1947728,1947725,1947727,1947728,1947699,1947729,1947729,2164665,1947729,1947729,1947717,1947731,2164361,1947731,2164361,1947732,1947733,1947735,1947736,1947737,1947737,1947732,1947733,1947738,1947739,1947740,1947743,1947744,1947737,1947745,1947747,1947749,1947750,1947749,1947750,1947751,1947747,1947752,1947753,1947754,2164340,1947754,1947755,1947756,1947756,1947755,1947757,1947758,1947757,1947758,1947758,1947758,1947759,1947758,1947759,1947759,1947760,1947760,1947761,1947762,1947776,1983042,1987338,2112358,2112360,2164347,2164347,2164389,2164390,2164391,2164395,2164398,2164398,2164400,2164400,2164401,2164401,2164403,2164696,2178056,2164348,2164348,2164363,2018338,2018356,2199643,2199662,2026947,2203957,2276970,2276970,2276972,2276975,2329001,2328960,2328962,2380933,2380934,2380935,2380935,2380936,2380943,2380944,2380944,2380945,2380946,2380956,2380966,2380967,2380972,2380974,2380974,2380975,2380975,2380976,2380976,2381009,2380936,2380936,2380937,2380944,2380945,2380976,2380977,2380946,2380976,2380977,2380977,2380945,2380976,2380977,2380978,2380952,2380978,2380978,2380953,2380954,2381292,2380954,2380955,2380986,2380994,2380955,2380956,2380957,2380957,2380987,2381294,2380988,2380958,2380987,2380989,2380997,2380992,2380998,2381006,2381008,2381008,2381009,2381014,2381016,2381017,2381017,2381017,2381018,2381018,2381022,2381094,2381019,2381020,2381020,2381021,2381021,2381022,2381022,2381023,2381023,2381024,2381024,2381025,2381025,2381026,2381027,2381027,2381028,2381028,2381029,2381029,2381030,2381030,2381031,2381031,2381032,2381033,2381034,2381034,2381035,2381035,2381037,2381037,2381038,2381039,2381040,2381040,2381041,2381044,2381048,2381049,2381050,2381051,2381052,2381056,2381094,2381020,2381021,2381021,2381022,2381024,2381024,2381026,2381027,2381027,2381028,2381029,2381030,2381031,2381031,2381032,2381052,2381052,2381026,2381027,2381028,2381032,2381053,2381027,2381028,2381028,2381029,2381030,2381031,2381041,2381044,2381053,2381028,2381029,2381032,2381028,2381029,2381054,2381029,2381055,2381029,2381055,2381056,2381031,2381034,2381037,2381044,2381056,2381031,2381032,2381032,2381033,2381034,2381035,2381049,2381050,2381057,2381057,2381033,2381033,2381033,2381034,2381035,2381036,2381036,2381037,2381048,2381052,2381054,2381058,2381034,2381035,2381035,2381036,2381036,2381037,2381037,2381038,2381040,2381042,2381042,2381044,2381045,2381049,2381054,2381055,2381056,2381057,2381059,2381059,2381035,2381036,2381036,2381037,2381037,2381038,2381038,2381039,2381040,2381041,2381042,2381042,2381045,2381046,2381047,2381048,2381049,2381049,2381052,2381053,2381054,2381055,2381055,2381057,2381059,2381060,2381036,2381037,2381037,2381038,2381038,2381039,2381039,2381040,2381042,2381042,2381043,2381043,2381044,2381046,2381046,2381048,2381049,2381050,2381050,2381051,2381052,2381053,2381054,2381054,2381055,2381056,2381058,2381060,2381060,2381038,2381039,2381044,2381055,2381058,2381061,2381039,2381039,2381040,2381041,2381044,2381045,2381047,2381049,2381051,2381053,2381058,2381061,2381061,2381039,2381040,2381040,2381042,2381045,2381048,2381049,2381050,2381051,2381052,2381053,2381054,2381055,2381057,2381059,2381062,2381040,2381041,2381043,2381044,2381045,2381045,2381050,2381050,2381051,2381053,2381054,2381055,2381060,2381062,2381041,2381043,2381043,2381044,2381046,2381047,2381048,2381048,2381049,2381050,2381051,2381052,2381053,2381053,2381055,2381056,2381058,2381061,2381061,2381062,2381063,2381042,2381043,2381043,2381044,2381045,2381045,2381046,2381046,2381047,2381049,2381049,2381050,2381051,2381051,2381052,2381052,2381053,2381053,2381055,2381056,2381057,2381057,2381059,2381060,2381061,2381061,2381063,2381063,2381046,2381054,2381055,2381056,2381064,2381045,2381047,2381057,2381064,2381064,2381046,2381047,2381050,2381054,2381054,2381060,2381062,2381065,2381051,2381053,2381053,2381055,2381061,2381062,2381064,2381065,2381047,2381049,2381060,2381066,2381052,2381056,2381063,2381049,2381057,2381060,2381067,2381050,2381053,2381053,2381055,2381055,2381061,2381065,2381067,2381053,2381053,2381055,2381056,2381057,2381057,2381058,2381059,2381061,2381066,2381068,2381055,2381055,2381056,2381062,2381068,2381058,2381069,2381063,2381070,2381058,2381059,2381060,2381061,2381062,2381063,2381069,2381070,2381070,2381066,2381070,2381071,2381344,2381063,2381071,2381072,2381060,2381061,2381061,2381064,2381067,2381070,2381072,2381072,2381346,2381061,2381062,2381064,2381065,2381065,2381066,2381067,2381070,2381073,2381063,2381065,2381066,2381067,2381073,2381073,2381064,2381066,2381068,2381073,2381074,2381347,2381066,2381067,2381069,2381070,2381071,2381072,2381074,2381065,2381067,2381072,2381074,2381075,2381068,2381069,2381073,2381075,2381076,2381069,2381070,2381069,2381070,2381076,2381077,2381071,2381071,2381072,2381073,2381074,2381077,2381077,2381390,2381078,2381072,2381073,2381074,2381076,2381077,2381078,2381079,2381074,2381074,2381076,2381077,2381077,2381079,2381077,2381078,2381079,2381080,2381078,2381080,2381080,2381354,2381081,2381081,2381124,2381081,2381082,2381081,2381082,2381082,2381356,2381082,2381083,2381083,2381357,2381083,2381084,2381084,2381085,2381086,2381086,2381087,2381088,2381088,2381089,2381089,2381091,2381091,2381094,2381094,2381098,2381099,2381100,2381110,2381116,2381118,2381122,2381123,2381124,2381124,2381125,2381126,2381126,2381127,2381127,2381358,2381358,2381397,2384761,2381086,2381087,2381088,2381088,2381089,2381089,2381090,2381090,2381091,2381092,2381093,2381094,2381095,2381096,2381097,2381100,2381110,2381110,2381117,2381122,2381123,2381124,2381125,2381125,2381126,2381126,2381127,2381127,2381128,2381089,2381128,2381096,2381128,2381129,2381129,2381130,2381092,2381097,2381098,2381101,2381128,2381130,2381361,2381361,2381116,2381129,2381131,2381097,2381129,2381131,2381362,2381128,2381129,2381130,2381132,2381363,2381402,2381096,2381132,2381133,2381133,2381364,2381134,2381132,2381135,2381135,2381136,2381367,2381108,2381135,2381137,2381109,2381138,2381139,2381140,2381372,2381125,2381133,2381141,2381142,2381143,2381152,2381152,2381152,2381153,2381155,2381159,2381160,2381160,2381164,2381164,2381164,2381165,2381166,2381164,2381166,2381166,2381167,2381397,2381166,2381166,2381167,2381167,2381168,2381167,2381168,2381168,2381169,2381169,2381170,2381400,2381401,2381440,2384803,2384825,2381401,2381631,2381632,2381633,2381633,2381634,2381634,2381635,2381635,2381636,2381636,2381637,2381641,2381642,2381643,2381643,2381647,2381653,2381654,2381659,2381662,2381666,2381666,2381668,2381669,2381670,2381670,2381671,2381633,2381634,2381635,2381635,2381636,2381636,2381643,2381650,2381670,2381671,2381671,2381634,2381635,2381671,2381671,2381635,2381636,2381671,2381672,2381672,2381643,2381672,2381638,2381638,2381641,2381642,2381661,2381672,2381672,2381673,2381673,2381638,2381672,2381657,2381673,2381674,2381674,2381674,2381675,2381675,2381670,2381678,2381652,2381652,2381680,2381653,2381654,2381681,2381654,2381682,2381655,2381656,2381676,2381682,2381656,2381666,2381683,2381686,2381688,2381692,2381693,2381697,2381698,2381701,2381702,2381703,2381704,2381705,2381706,2381707,2381708,2381708,2381708,2381709,2381709,2381710,2381711,2381711,2381712,2381712,2381713,2381713,2381714,2381714,2381715,2381715,2381716,2381717,2381717,2381718,2381719,2381720,2381720,2381721,2381721,2381722,2381722,2381723,2381723,2381725,2381726,2381726,2381727,2381727,2381728,2381728,2381729,2381730,2381733,2381734,2381734,2381737,2381737,2381742,2381746,2381779,2381711,2381712,2381712,2381713,2381713,2381714,2381714,2381715,2381715,2381716,2381717,2381717,2381718,2381719,2381720,2381721,2381722,2381722,2381723,2381724,2381725,2381727,2381747,2381712,2381713,2381713,2381714,2381715,2381716,2381717,2381720,2381721,2381723,2381723,2381724,2381713,2381714,2381714,2381716,2381716,2381717,2381718,2381719,2381720,2381721,2381722,2381725,2381727,2381714,2381715,2381716,2381716,2381717,2381717,2381718,2381719,2381720,2381721,2381722,2381722,2381723,2381724,2381725,2381725,2381727,2381735,2381717,2381717,2381718,2381720,2381722,2381723,2381725,2381726,2381737,2381716,2381718,2381718,2381722,2381723,2381723,2381724,2381748,2381718,2381719,2381720,2381722,2381723,2381723,2381724,2381727,2381719,2381719,2381720,2381723,2381724,2381724,2381726,2381727,2381719,2381720,2381721,2381722,2381724,2381725,2381726,2381739,2381720,2381721,2381721,2381722,2381722,2381723,2381724,2381725,2381725,2381726,2381727,2381728,2381728,2381730,2381722,2381722,2381723,2381723,2381724,2381725,2381726,2381727,2381727,2381728,2381729,2381725,2381724,2381725,2381726,2381727,2381728,2381729,2381730,2381725,2381726,2381727,2381727,2381728,2381729,2381729,2381730,2381725,2381727,2381728,2381729,2381734,2381727,2381728,2381728,2381729,2381731,2381733,2381727,2381728,2381729,2381729,2381730,2381731,2381731,2381732,2381734,2381745,2381746,2381755,2381755,2381729,2381730,2381730,2381731,2381732,2381732,2381733,2381733,2381735,2381752,2381731,2381732,2381732,2381733,2381733,2381734,2381734,2381735,2381735,2381736,2381737,2381737,2381738,2381739,2381739,2381740,2381740,2381741,2381743,2381745,2381747,2381747,2381751,2381756,2381757,2381734,2381736,2381733,2381734,2381734,2381735,2381736,2381737,2381737,2381738,2381738,2381739,2381740,2381740,2381744,2381745,2381748,2381751,2381734,2381735,2381735,2381736,2381737,2381737,2381738,2381740,2381740,2381742,2381742,2381746,2381747,2381748,2381749,2381749,2381751,2381752,2381758,2381735,2381736,2381736,2381737,2381737,2381738,2381738,2381739,2381740,2381740,2381741,2381742,2381742,2381743,2381745,2381746,2381747,2381747,2381749,2381749,2381754,2381736,2381737,2381738,2381739,2381741,2381742,2381743,2381745,2381746,2381737,2381738,2381738,2381739,2381739,2381740,2381740,2381741,2381741,2381742,2381742,2381743,2381743,2381744,2381745,2381746,2381747,2381748,2381748,2381750,2381750,2381751,2381754,2381754,2381755,2381759,2381759,2381760,2381739,2381740,2381740,2381742,2381747,2381750,2381739,2381740,2381741,2381747,2381748,2381749,2381751,2381740,2381741,2381741,2381742,2381742,2381743,2381744,2381744,2381745,2381745,2381746,2381746,2381747,2381748,2381748,2381749,2381750,2381751,2381752,2381752,2381755,2381756,2381756,2381757,2381757,2381760,2381761,2381761,2381741,2381742,2381743,2381744,2381747,2381747,2381749,2381752,2381742,2381743,2381744,2381745,2381745,2381747,2381749,2381750,2381751,2381752,2381753,2381758,2381743,2381744,2381744,2381745,2381745,2381746,2381746,2381747,2381748,2381748,2381749,2381749,2381750,2381751,2381753,2381753,2381754,2381755,2381756,2381757,2381757,2381758,2381762,2381763,2381744,2381745,2381746,2381746,2381747,2381752,2381753,2381759,2381763,2381745,2381746,2381746,2381747,2381747,2381748,2381749,2381750,2381751,2381752,2381753,2381754,2381754,2381759,2381764,2381746,2381747,2381747,2381748,2381749,2381749,2381751,2381752,2381753,2381754,2381755,2381756,2381758,2381747,2381748,2381751,2381753,2381755,2381755,2381759,2381748,2381749,2381749,2381750,2381752,2381752,2381753,2381753,2381754,2381755,2381756,2381756,2381758,2381759,2381760,2381765,2381765,2381750,2381751,2381752,2381753,2381753,2381754,2381754,2381756,2381760,2381764,2381765,2381750,2381751,2381751,2381752,2381753,2381754,2381755,2381756,2381758,2381760,2381761,2381761,2381762,2381762,2381766,2381766,2381751,2381752,2381753,2381753,2381754,2381755,2381757,2381752,2381754,2381755,2381756,2381763,2381754,2381754,2381755,2381756,2381758,2381758,2381759,2381759,2381762,2381763,2381767,2381768,2381755,2381758,2381755,2381756,2381757,2381760,2381756,2381757,2381757,2381758,2381759,2381760,2381760,2381763,2381763,2381764,2381765,2381768,2381769,2381769,2381757,2381758,2381760,2381760,2381769,2381758,2381759,2381760,2381761,2381761,2381762,2381764,2381765,2381766,2381770,2381770,2381759,2381761,2381766,2381771,2381760,2381761,2381761,2381762,2381762,2381763,2381764,2381765,2381765,2381766,2381766,2381769,2381769,2381771,2381771,2381762,2381762,2381762,2381766,2381770,2381763,2381764,2381766,2381766,2381767,2381767,2381768,2381769,2381770,2381772,2381773,2381764,2381765,2381765,2381767,2381767,2381768,2381768,2381769,2381769,2381770,2381771,2381771,2381772,2381772,2381773,2381773,2403760,2381765,2381766,2381766,2381767,2381767,2381768,2381768,2381769,2381770,2381771,2381771,2381772,2381772,2381773,2381773,2381774,2381767,2381768,2381768,2381769,2381770,2381774,2381774,2381767,2381768,2381768,2381769,2381769,2381770,2381775,2381769,2381775,2381775,2381769,2381770,2381770,2381771,2381771,2381774,2381775,2381776,2381770,2381771,2381771,2381772,2381773,2381773,2381774,2381774,2381775,2381775,2381776,2381776,2381771,2381772,2381772,2381773,2381774,2381774,2381776,2381776,2381777,2381772,2381773,2381773,2381774,2381775,2381775,2381776,2381776,2381777,2381777,2381773,2381774,2381775,2381776,2381777,2381777,2381778,2381774,2381775,2381776,2381776,2381777,2381777,2381778,2381778,2381775,2381777,2381778,2381778,2381779,2381777,2381778,2381779,2381779,2381778,2381779,2381780,2381778,2381779,2381779,2381780,2381780,2381779,2381780,2381780,2381781,2381780,2381781,2381781,2381781,2381782,2381782,2381783,2381784,2381784,2381785,2381786,2381788,2381788,2381789,2381789,2381790,2381790,2381791,2381791,2381792,2381792,2381793,2381793,2381794,2381795,2381797,2381798,2381799,2381801,2381807,2381807,2381808,2381809,2381811,2381812,2381812,2381815,2381817,2381817,2381818,2381818,2381819,2381819,2381820,2381820,2381821,2381821,2381822,2385110,2385131,2385131,2385132,2385133,2386543,2381784,2381785,2381785,2381786,2381786,2381787,2381787,2381788,2381788,2381789,2381789,2381790,2381790,2381791,2381791,2381792,2381792,2381793,2381793,2381794,2381795,2381796,2381797,2381797,2381798,2381801,2381805,2381806,2381807,2381808,2381810,2381810,2381811,2381812,2381812,2381813,2381813,2381815,2381816,2381817,2381817,2381818,2381818,2381819,2381819,2381820,2381820,2381821,2381821,2381822,2381822,2385132,2385196,2381785,2381786,2381787,2381788,2381790,2381790,2381791,2381792,2381793,2381793,2381798,2381806,2381812,2381816,2381819,2381820,2381821,2381822,2381823,2381788,2381790,2381791,2381792,2381793,2381793,2381794,2381806,2381807,2381810,2381816,2381817,2381819,2381820,2381821,2381823,2381791,2381791,2381792,2381823,2381792,2381792,2381793,2381794,2381824,2381793,2381793,2381792,2381793,2381793,2381794,2381795,2381813,2381792,2381796,2381804,2381823,2381794,2381794,2381797,2381800,2381824,2385115,2381795,2381797,2381804,2381817,2381825,2381795,2381797,2381797,2381798,2381799,2381801,2381808,2381812,2381814,2381821,2381825,2381827,2381828,2381796,2381797,2381797,2381798,2381798,2381799,2381799,2381800,2381801,2381820,2381821,2381824,2381825,2381825,2381826,2381827,2381827,2381828,2385138,2390840,2381798,2381802,2381822,2381827,2381828,2385117,2381799,2381800,2381817,2381825,2381827,2381828,2381799,2381800,2381800,2381801,2381827,2381829,2381830,2381800,2381801,2381801,2381802,2381806,2381808,2381813,2381818,2381818,2381820,2381820,2381823,2381825,2381827,2381828,2381828,2381829,2381829,2381830,2381801,2381802,2381802,2381803,2381804,2381808,2381808,2381815,2381824,2381826,2381827,2381828,2381829,2381829,2381830,2385140,2381802,2381803,2381804,2381804,2381807,2381812,2381815,2381816,2381828,2381828,2381829,2381830,2381830,2381831,2381804,2381805,2381806,2381807,2381822,2381827,2381829,2381829,2381831,2381831,2381832,2381804,2381805,2381805,2381807,2381808,2381809,2381815,2381822,2381825,2381825,2381826,2381827,2381828,2381828,2381829,2381829,2381831,2381831,2381808,2381816,2381826,2381830,2381832,2381833,2381806,2381830,2381807,2381808,2381819,2381821,2381823,2381824,2381829,2381831,2381833,2381834,2381809,2381823,2381826,2381831,2381819,2381827,2381834,2381816,2381827,2381829,2381812,2381821,2381829,2381833,2381814,2381828,2381835,2381835,2381821,2381829,2381834,2381836,2381825,2381831,2381835,2381826,2381832,2381834,2381836,2381835,2381834,2381838,2381835,2381837,2381832,2381839,2381839,2381840,2381841,2381829,2381838,2381841,2381842,2381844,2381838,2381840,2381836,2381838,2381841,2381842,2381842,2381843,2381845,2381846,2381844,2381835,2381838,2381840,2381842,2381845,2381847,2381848,2381846,2381846,2381846,2381847,2381847,2381840,2381841,2381844,2381847,2381849,2381848,2381848,2381849,2381850,2381851,2381848,2381848,2381849,2381850,2381851,2381846,2381848,2381849,2381847,2381849,2381852,2381846,2381850,2381852,2381851,2381852,2381853,2381848,2381849,2381850,2381851,2381851,2381853,2381853,2381851,2381852,2381853,2381854,2390866,2381852,2381852,2381852,2381852,2381853,2381854,2381852,2381853,2381853,2381854,2381855,2381856,2385166,2381853,2381854,2381854,2381855,2381856,2381854,2381855,2381855,2381856,2381856,2381857,2381857,2381855,2381856,2381856,2381857,2381857,2381858,2385167,2381856,2381857,2381857,2381858,2381857,2381858,2381859,2381858,2381859,2381859,2381859,2381860,2381860,2395058,2381861,2381862,2381865,2381868,2381905,2381921,2381945,2382129,2385148,2385149,2385170,2385170,2386498,2395257,2385149,2385149,2385150,2385153,2385156,2385193,2385209,2382043,2385246,2382467,2385487,2388436,2388437,2388438,2388438,2388439,2388440,2388440,2388441,2388442,2388443,2388444,2388444,2388448,2388449,2388450,2388454,2388455,2388456,2388457,2388457,2388458,2388458,2388438,2388439,2388443,2388457,2388458,2388458,2388439,2388458,2388459,2388459,2388441,2388442,2388442,2388443,2388445,2388458,2388458,2388459,2388459,2388460,2388459,2388460,2388460,2388460,2388460,2388461,2388461,2388461,2388462,2388461,2388463,2388463,2388464,2388464,2388464,2388465,2388462,2388470,2388470,2388470,2388472,2388475,2388477,2388477,2388477,2388477,2388478,2388478,2388479,2388479,2388480,2388481,2388481,2388482,2388482,2388483,2388484,2388484,2388485,2388485,2388486,2388486,2388487,2388487,2388488,2388488,2388489,2388489,2388490,2388490,2388491,2388491,2388492,2388493,2388493,2388494,2388494,2388495,2388496,2388496,2388497,2388497,2388498,2388498,2388499,2388500,2388500,2388501,2388501,2388502,2388502,2388503,2388503,2388504,2388504,2388505,2388505,2388506,2388506,2388507,2388508,2388509,2388509,2388510,2388510,2388511,2388512,2388514,2388516,2388516,2388517,2388517,2388522,2388525,2388526,2388530,2388534,2388555,2388481,2388482,2388483,2388485,2388485,2388486,2388486,2388487,2388487,2388488,2388488,2388489,2388489,2388490,2388490,2388491,2388492,2388493,2388494,2388495,2388496,2388497,2388497,2388498,2388499,2388500,2388501,2388502,2388503,2388504,2388506,2388506,2388508,2388508,2388510,2388516,2388534,2388482,2388483,2388483,2388486,2388486,2388489,2388490,2388491,2388491,2388493,2388496,2388497,2388499,2388501,2388502,2388503,2388505,2388506,2388508,2388509,2388485,2388485,2388487,2388487,2388488,2388488,2388491,2388492,2388492,2388493,2388494,2388495,2388496,2388497,2388497,2388500,2388501,2388502,2388503,2388504,2388504,2388505,2388505,2388507,2388509,2388509,2388511,2388512,2388484,2388486,2388487,2388491,2388491,2388492,2388498,2388503,2388507,2388487,2388488,2388488,2388492,2388493,2388498,2388502,2388503,2388506,2388509,2388487,2388504,2388505,2388488,2388490,2388500,2388509,2388512,2388491,2388494,2388496,2388499,2388505,2388509,2388490,2388494,2388500,2388504,2388505,2388506,2388507,2388508,2388508,2388510,2388491,2388495,2388501,2388505,2388507,2388508,2388512,2388513,2388513,2388515,2388492,2388494,2388495,2388496,2388498,2388501,2388502,2388504,2388504,2388509,2388510,2388510,2388512,2388520,2388498,2388503,2388507,2388508,2388509,2388512,2388515,2388495,2388503,2388506,2388508,2388508,2388511,2388515,2388515,2388497,2388501,2388509,2388510,2388515,2388517,2388501,2388505,2388508,2388510,2388510,2388516,2388498,2388499,2388511,2388513,2388500,2388504,2388507,2388507,2388508,2388509,2388510,2388511,2388512,2388513,2388517,2388519,2388522,2388503,2388507,2388509,2388509,2388510,2388511,2388512,2388517,2388519,2388502,2388503,2388507,2388509,2388511,2388513,2388514,2388516,2388517,2388518,2388522,2388514,2388525,2388519,2388506,2388508,2388512,2388513,2388515,2388515,2388517,2388520,2388509,2388508,2388508,2388509,2388510,2388514,2388515,2388527,2388508,2388510,2388516,2388518,2388519,2388520,2388523,2388514,2388516,2388518,2388520,2388524,2388511,2388511,2388512,2388515,2388516,2388517,2388517,2388522,2388513,2388519,2388524,2388513,2388515,2388517,2388518,2388519,2388521,2388523,2388550,2388513,2388514,2388515,2388516,2388517,2388518,2388518,2388519,2388519,2388520,2388520,2388522,2388524,2388524,2388526,2388526,2388540,2388550,2388518,2388519,2388520,2388520,2388521,2388518,2388519,2388520,2388521,2388522,2388523,2388526,2388529,2388516,2388519,2388520,2388521,2388526,2388518,2388519,2388520,2388520,2388521,2388521,2388522,2388522,2388524,2388526,2388519,2388520,2388520,2388521,2388522,2388522,2388523,2388525,2388526,2388527,2388527,2388520,2388524,2388526,2388527,2388522,2388523,2388523,2388524,2388524,2388525,2388525,2388526,2388526,2388527,2388528,2388529,2388530,2388533,2388537,2388554,2388522,2388526,2388528,2388529,2388523,2388524,2388524,2388525,2388525,2388526,2388526,2388527,2388527,2388528,2388529,2388529,2388531,2388532,2388535,2388535,2388536,2388537,2388539,2388555,2388555,2388565,2388524,2388525,2388526,2388528,2388533,2388525,2388526,2388526,2388527,2388528,2388528,2388529,2388529,2388530,2388530,2388531,2388536,2388539,2388539,2388556,2388526,2388527,2388527,2388528,2388529,2388529,2388530,2388531,2388532,2388533,2388534,2388534,2388538,2388527,2388528,2388528,2388529,2388529,2388530,2388531,2388531,2388533,2388533,2388535,2388537,2388538,2388541,2388541,2388542,2388550,2388528,2388529,2388529,2388530,2388530,2388531,2388532,2388533,2388534,2388535,2388558,2388529,2388530,2388530,2388531,2388532,2388532,2388534,2388534,2388558,2388530,2388531,2388532,2388533,2388531,2388532,2388533,2388533,2388534,2388534,2388535,2388535,2388536,2388536,2388537,2388538,2388539,2388539,2388540,2388541,2388541,2388542,2388544,2388551,2388559,2388559,2388532,2388533,2388534,2388535,2388536,2388536,2388537,2388537,2388538,2388534,2388534,2388535,2388536,2388536,2388537,2388537,2388539,2388541,2388543,2388560,2388534,2388535,2388541,2388535,2388536,2388536,2388537,2388537,2388538,2388538,2388539,2388539,2388540,2388540,2388541,2388541,2388544,2388557,2388561,2394301,2388536,2388537,2388537,2388538,2388538,2388539,2388539,2388540,2388540,2388541,2388541,2388542,2388542,2388543,2388543,2388544,2388544,2388546,2388547,2388549,2388551,2388552,2388553,2388555,2388561,2388562,2388537,2388538,2388538,2388539,2388538,2388539,2388539,2388540,2388540,2388541,2388542,2388543,2388543,2388544,2388546,2388546,2388547,2388548,2388563,2388539,2388540,2388540,2388541,2388542,2388543,2388544,2388544,2388545,2388545,2388546,2388546,2388547,2388548,2388548,2388551,2388554,2388556,2388562,2388563,2388563,2388540,2388541,2388541,2388542,2388542,2388543,2388543,2388544,2388544,2388545,2388545,2388546,2388546,2388547,2388547,2388548,2388549,2388549,2388552,2388553,2388555,2388555,2388556,2388556,2388559,2388562,2388563,2388563,2388564,2388541,2388542,2388543,2388543,2388544,2388544,2388545,2388546,2388546,2388547,2388549,2388553,2388554,2388554,2388555,2388556,2388558,2388564,2388542,2388543,2388543,2388544,2388544,2388545,2388545,2388546,2388546,2388547,2388547,2388548,2388548,2388550,2388552,2388553,2388554,2388558,2388564,2388565,2388543,2388544,2388544,2388545,2388545,2388546,2388546,2388547,2388547,2388548,2388548,2388549,2388549,2388550,2388550,2388553,2388553,2388555,2388556,2388557,2388558,2388559,2388561,2388562,2388564,2388565,2388565,2388544,2388545,2388546,2388546,2388548,2388549,2388565,2388566,2388545,2388546,2388547,2388548,2388549,2388549,2388551,2388566,2388546,2388547,2388547,2388548,2388548,2388549,2388549,2388550,2388550,2388551,2388551,2388552,2388554,2388555,2388556,2388557,2388562,2388563,2388566,2388567,2388547,2388548,2388548,2388549,2388550,2388550,2388551,2388552,2388552,2388555,2388557,2388558,2388559,2388566,2388567,2388567,2388548,2388549,2388549,2388550,2388550,2388551,2388551,2388552,2388552,2388553,2388554,2388555,2388556,2388557,2388557,2388558,2388562,2388565,2388567,2388567,2388568,2388549,2388550,2388550,2388551,2388551,2388552,2388552,2388553,2388553,2388554,2388556,2388557,2388558,2388558,2388560,2388561,2388564,2388565,2388568,2388568,2388550,2388551,2388551,2388552,2388552,2388553,2388556,2388558,2388559,2388567,2388568,2388569,2388551,2388552,2388552,2388553,2388553,2388554,2388556,2388558,2388560,2388562,2388566,2388569,2388569,2388552,2388553,2388553,2388555,2388556,2388557,2388557,2388558,2388558,2388559,2388559,2388560,2388560,2388570,2388553,2388554,2388554,2388555,2388555,2388558,2388558,2388559,2388560,2388560,2388562,2388563,2388564,2388566,2388566,2388569,2388570,2388570,2389844,2388554,2388555,2388555,2388556,2388557,2388558,2388558,2388559,2388559,2388560,2388561,2388562,2388563,2388566,2388567,2388569,2388570,2388571,2388555,2388556,2388556,2388557,2388558,2388558,2388559,2388560,2388561,2388561,2388562,2388562,2388563,2388563,2388564,2388567,2388570,2388570,2388571,2388571,2388556,2388557,2388558,2388558,2388560,2388561,2388562,2388563,2388564,2388566,2388567,2388568,2388569,2388571,2388571,2388572,2388558,2388560,2388561,2388562,2388563,2388571,2388572,2388572,2388558,2388559,2388559,2388560,2388560,2388561,2388561,2388562,2388563,2388563,2388564,2388565,2388566,2388567,2388568,2388569,2388569,2388570,2388570,2388571,2388572,2388573,2388560,2388563,2388572,2388573,2388561,2388563,2388565,2388573,2388574,2388562,2388563,2388564,2388565,2388570,2388573,2388574,2388563,2388565,2388566,2388568,2388574,2388575,2388564,2388564,2388565,2388565,2388566,2388566,2388568,2388570,2388570,2388571,2388575,2388575,2388565,2388575,2388576,2388565,2388566,2388566,2388567,2388567,2388568,2388575,2388576,2388576,2388566,2388567,2388569,2388577,2388567,2388568,2388568,2388569,2388569,2388570,2388570,2388572,2388573,2388574,2388576,2388577,2388577,2388568,2388569,2388569,2388570,2388570,2388571,2388577,2388577,2388578,2388569,2388570,2388570,2388571,2388571,2388572,2388573,2388574,2388578,2388578,2388570,2388571,2388571,2388572,2388578,2388578,2388579,2388571,2388572,2388572,2388573,2388574,2388574,2388575,2388576,2388576,2388578,2388579,2388579,2388572,2388573,2388576,2388577,2388577,2388579,2388579,2388580,2388573,2388574,2388575,2388577,2388577,2388580,2388580,2388574,2388575,2388576,2388577,2388578,2388579,2388580,2388581,2388579,2388580,2388581,2388577,2388579,2388581,2388582,2388578,2388581,2388582,2388582,2388582,2388583,2388579,2388580,2388582,2388583,2388583,2388581,2388583,2388584,2388584,2388584,2388584,2388585,2388584,2388585,2388585,2388586,2388586,2388586,2388586,2388587,2389861,2388587,2388588,2388589,2388591,2388592,2388593,2388593,2388594,2388595,2388595,2388596,2388597,2388598,2388598,2388599,2388600,2388602,2388604,2388605,2388606,2388607,2388607,2388608,2388608,2388609,2388609,2389862,2389880,2389880,2389915,2394235,2394328,2396227,2388589,2388590,2388590,2388591,2388592,2388593,2388594,2388594,2388595,2388595,2388596,2388596,2388597,2388597,2388598,2388598,2388599,2388599,2388600,2388600,2388601,2388601,2388602,2388602,2388603,2388605,2388605,2388606,2388606,2388607,2388608,2388608,2388609,2388609,2388610,2388591,2388593,2388594,2388596,2388599,2388601,2388609,2388610,2388610,2388600,2388608,2388610,2388602,2388603,2388610,2388611,2388596,2388601,2388598,2388604,2388610,2388614,2388599,2388605,2388613,2388614,2388614,2388604,2388605,2388608,2388611,2388614,2388606,2388615,2388605,2388606,2388612,2388614,2388614,2388615,2388616,2388613,2388616,2388615,2388616,2388617,2396235,2388608,2388605,2388617,2388618,2388618,2388607,2388609,2388608,2388609,2388609,2388610,2388615,2388619,2388610,2388616,2388620,2388611,2388615,2388620,2388611,2388621,2388614,2388614,2388615,2388615,2388616,2388616,2388617,2388618,2388618,2388619,2388619,2388620,2388620,2388621,2388621,2389874,2396239,2388617,2388621,2388622,2388622,2388615,2388622,2388621,2388623,2388623,2388620,2388622,2388623,2388624,2388623,2388624,2388624,2388623,2388621,2388625,2388625,2388624,2388626,2388624,2388625,2388624,2388625,2388626,2388627,2388625,2388626,2388627,2388627,2388626,2388628,2388627,2388627,2388628,2388628,2388627,2388628,2388628,2388629,2388628,2388629,2388629,2388629,2388630,2388630,2388631,2388632,2389874,2389882,2389883,2389883,2389902,2389904,2389912,2394257,2394285,2394349,2396212,2396263,2398443,2398497,2409444,25876478,2388632,2389883,2389884,2389902,2394258,2396249,2389884,2389884,2391126,2391134,2391135,2391136,2391137,2391137,2391138,2391138,2391139,2391139,2391140,2391140,2391141,2391141,2391142,2391144,2391145,2391146,2391147,2391153,2391153,2391154,2391154,2391137,2391139,2391139,2391140,2391142,2391147,2391152,2391153,2391153,2391154,2391154,2391155,2391139,2391140,2391141,2391143,2391149,2391154,2391155,2391155,2391155,2391156,2391156,2391155,2391156,2391157,2391148,2391157,2391157,2391157,2391157,2391157,2391158,2391158,2391159,2391159,2391159,2391159,2391160,2391160,2391161,2391163,2391164,2391164,2391165,2391167,2391170,2391170,2391170,2391171,2391171,2391172,2391172,2391229,2391173,2391174,2391174,2391175,2391175,2391176,2391176,2391177,2391177,2391178,2391178,2391179,2391179,2391180,2391180,2391181,2391182,2391182,2391183,2391183,2391184,2391185,2391188,2391188,2391189,2391189,2391190,2391190,2391191,2391192,2391192,2391193,2391193,2391194,2391195,2391195,2391197,2391198,2391198,2391199,2391200,2391201,2391201,2391202,2391202,2391203,2391203,2391204,2391205,2391205,2391206,2391206,2391207,2391207,2391208,2391208,2391209,2391210,2391211,2391211,2391212,2391212,2391213,2391217,2391222,2391222,2391223,2391226,2391229,2391230,2391174,2391175,2391176,2391177,2391177,2391178,2391179,2391181,2391181,2391182,2391182,2391185,2391190,2391191,2391192,2391193,2391193,2391195,2391198,2391198,2391199,2391201,2391201,2391203,2391204,2391204,2391206,2391208,2391209,2391212,2391216,2391218,2391230,2391230,2391177,2391179,2391183,2391188,2391193,2391198,2391199,2391209,2391216,2391230,2391231,2391179,2391199,2391201,2391194,2391197,2391199,2391206,2391231,2391180,2391180,2391195,2391200,2391184,2391198,2391200,2391180,2391195,2391201,2391202,2391207,2391207,2391224,2391233,2391233,2391181,2391186,2391195,2391196,2391197,2391207,2391184,2391185,2391187,2391196,2391202,2391202,2391203,2391204,2391205,2391208,2391208,2391234,2391184,2391188,2391197,2391203,2391208,2391235,2391234,2391203,2391204,2391207,2391205,2391206,2391210,2391197,2391202,2391204,2391205,2391205,2391206,2391207,2391215,2391215,2391191,2391200,2391206,2391209,2391197,2391206,2391206,2391216,2391238,2391200,2391201,2391204,2391206,2391202,2391207,2391209,2391202,2391203,2391205,2391206,2391195,2391202,2391208,2391214,2391240,2391215,2391203,2391216,2391218,2391218,2391223,2391218,2391224,2391219,2391213,2391221,2391223,2391209,2391211,2391212,2391222,2391246,2391246,2391207,2391210,2391215,2391216,2391217,2391223,2391211,2391216,2391217,2391218,2391222,2391222,2391224,2391248,2391211,2391214,2391217,2391217,2391222,2391223,2391228,2391231,2391232,2391248,2391249,2391214,2391217,2391217,2391219,2391223,2391223,2391226,2391227,2391233,2391249,2391217,2391218,2391220,2391221,2391224,2391250,2391250,2391220,2391225,2391227,2391238,2391251,2391219,2391220,2391225,2391226,2391228,2391230,2391231,2391245,2391220,2391224,2391226,2391229,2391226,2391222,2391223,2391224,2391225,2391228,2391228,2391230,2391230,2391231,2391231,2391232,2391232,2391233,2391233,2391237,2391237,2391244,2391254,2391254,2391223,2391225,2391225,2391226,2391228,2391229,2391230,2391231,2391232,2391233,2391234,2391237,2391254,2391255,2391225,2391226,2391227,2391227,2391228,2391229,2391229,2391231,2391231,2391232,2391233,2391233,2391234,2391234,2391236,2391237,2391255,2391255,2391226,2391230,2391226,2391227,2391228,2391228,2391230,2391230,2391231,2391235,2391236,2391250,2391256,2391257,2395647,2391228,2391231,2391229,2391230,2391231,2391231,2391232,2391233,2391235,2391237,2391248,2391231,2391232,2391232,2391234,2391240,2391233,2391259,2391233,2391259,2391233,2391234,2391236,2391237,2391238,2391239,2391241,2391234,2391236,2391236,2391238,2391238,2391239,2391239,2391242,2391243,2391256,2391260,2391260,2391236,2391237,2391237,2391238,2391238,2391239,2391239,2391240,2391240,2391241,2391242,2391243,2391243,2391244,2391244,2391245,2391246,2391247,2391248,2391250,2391251,2391254,2391256,2391257,2391259,2391259,2391260,2391261,2391262,2391238,2391239,2391240,2391240,2391241,2391243,2391243,2391245,2391247,2391251,2391257,2391260,2391262,2391262,2391240,2391240,2391241,2391241,2391242,2391243,2391245,2391246,2391246,2391253,2391261,2391262,2391263,2391242,2391244,2391246,2391253,2391263,2391263,2391242,2391242,2391243,2391245,2391247,2391263,2391264,2391242,2391243,2391244,2391244,2391246,2391247,2391249,2391251,2391262,2391263,2391264,2391264,2391243,2391244,2391244,2391245,2391245,2391246,2391247,2391247,2391248,2391254,2391258,2391260,2391260,2391264,2391265,2391244,2391245,2391245,2391246,2391247,2391248,2391248,2391252,2391259,2391260,2391261,2391265,2391265,2391247,2391247,2391248,2391248,2391249,2391251,2391253,2391254,2391255,2391261,2391264,2391265,2391265,2391266,2391246,2391249,2391266,2391266,2391247,2391248,2391249,2391249,2391250,2391266,2391267,2391250,2391251,2391252,2391253,2391256,2391267,2391249,2391250,2391250,2391252,2391267,2391268,2391251,2391255,2391262,2391267,2391268,2391268,2391252,2391265,2391268,2391269,2391252,2391254,2391262,2391264,2391266,2391268,2391269,2391269,2391254,2391255,2391259,2391260,2391262,2391267,2391268,2391269,2391270,2391264,2391270,2391256,2391271,2391258,2391271,2391259,2391261,2391262,2391268,2391271,2391272,2391271,2391267,2391272,2391273,2391262,2391270,2391271,2391272,2391273,2391274,2391274,2391264,2391275,2391275,2391266,2391267,2391275,2391275,2391276,2391276,2391276,2391267,2391276,2391277,2391277,2391277,2391278,2391279,2391279,2391274,2391279,2391280,2391280,2391280,2391277,2391280,2391281,2391281,2391281,2391282,2391282,2391282,2391283,2391282,2391283,2391283,2391284,2391284,2391284,2391285,2391285,2391285,2391285,2391286,2391286,2391287,2391288,2391288,2391289,2391295,2391299,2391300,2391300,2391301,2391301,2391302,2391303,2391303,2391304,2391304,2391305,2391305,2395585,2395585,2395613,2395615,2395641,2395677,2399771,2391288,2391289,2391291,2391292,2391293,2391293,2391294,2391295,2391295,2391296,2391298,2391298,2391299,2391300,2391300,2391301,2391301,2391302,2391302,2391303,2391304,2391304,2391305,2391305,2391306,2391289,2391290,2391303,2391304,2391304,2391305,2391305,2391306,2391306,2391295,2391306,2391307,2391306,2391306,2391306,2391307,2391308,2391309,2391307,2391310,2391311,2391311,2391312,2391308,2391304,2391313,2391313,2391313,2391314,2391315,2391315,2391316,2391317,2391314,2391314,2391316,2391317,2391318,2391317,2391318,2391318,2391317,2391319,2391319,2391317,2391319,2391319,2391318,2391318,2391319,2391319,2391320,2391320,2391319,2391319,2391320,2391321,2391320,2391321,2391321,2391322,2391321,2391322,2391322,2391322,2391323,2391323,2395603,2399841,2391324,2395231,2395603,2395604,2395607,2395631,2395631,2395654,2395658,2395696,2397558,2397558,2397595,2397600,2397609,2397612,2399790,2399988,2406949,2408088,2410436,2395604,2395604,2395632,2397596,2397612,2399204,2399577,2399883,2399884,2399885,2399885,2399886,2399886,2399887,2399888,2399889,2399892,2399893,2399894,2399895,2399910,2399910,2399911,2399911,2399917,2399959,2399886,2399890,2399911,2399912,2399911,2399912,2399913,2399889,2399891,2399913,2399913,2399892,2399914,2399895,2399911,2399913,2399914,2399914,2399914,2399915,2399917,2399919,2399920,2399902,2399903,2399903,2399903,2399904,2399905,2399921,2399926,2399986,2401848,2401885,2401950,2404079,2399922,2399986,2399987,2399988,2401900,2399936,2399937,2399937,2399938,2399938,2399960,2399939,2399940,2399940,2399941,2399941,2399942,2399943,2399943,2399944,2399944,2399946,2399946,2399947,2399948,2399950,2399950,2399952,2399953,2399953,2399954,2399954,2399955,2399955,2399956,2399957,2399957,2399958,2399959,2399960,2399960,2399961,2399961,2399962,2399962,2399963,2399963,2399964,2399964,2399965,2399965,2399966,2399966,2399967,2399967,2399968,2399968,2399969,2399970,2399976,2399976,2399981,2399983,2399984,2399984,2399985,2399985,2399986,2399987,2399987,2399941,2399952,2399954,2399962,2399964,2399968,2399985,2399986,2399987,2399987,2399961,2399962,2399942,2399963,2399985,2399987,2399988,2399948,2399962,2399963,2399963,2399965,2399964,2399990,2399965,2399968,2399969,2399991,2399965,2399992,2399966,2399969,2399970,2399971,2399965,2399995,2399994,2399983,2399972,2399980,2399970,2400000,2400001,2399976,2399974,2400002,2399976,2399977,2400003,2399978,2400003,2400000,2400004,2399988,2399983,2399985,2399991,2399981,2399989,2399982,2399992,2400007,2399986,2399987,2399997,2400006,2399982,2399983,2399985,2399986,2399987,2399992,2399993,2400008,2399983,2399986,2399987,2399988,2399992,2400009,2399984,2399985,2399985,2399986,2399986,2399987,2399987,2399988,2399989,2399989,2399991,2399992,2399993,2399999,2400000,2400003,2400005,2400006,2400006,2400007,2400007,2400009,2400009,2399986,2399987,2399989,2400010,2399987,2399989,2399991,2399997,2400010,2400010,2399988,2399988,2399989,2399989,2399991,2400010,2400011,2399988,2399990,2399991,2399994,2400009,2400011,2399989,2399990,2399990,2399992,2399994,2400007,2400009,2400010,2400012,2399990,2399992,2399993,2399995,2399998,2400006,2400008,2400009,2400011,2400012,2400012,2399993,2399994,2399996,2400008,2400010,2400013,2400000,2400011,2400012,2400013,2400003,2400010,2400014,2399994,2399996,2399998,2400004,2400014,2399996,2400011,2400014,2400015,2400015,2399999,2400013,2400014,2400014,2400016,2400016,2400014,2400017,2400010,2400014,2400017,2400013,2400015,2400018,2400003,2400018,2400014,2400018,2400019,2400020,2400020,2400018,2400019,2400017,2400021,2400024,2400024,2400024,2400026,2400021,2400027,2400026,2400027,2400029,2400027,2400029,2400030,2400028,2400029,2400031,2400031,2400030,2400031,2400032,2400059,2400030,2400031,2400032,2400032,2400049,2400031,2400032,2400033,2400032,2400033,2400033,2400034,2400034,2400035,2400036,2400036,2400037,2400048,2400051,2400057,2400060,2400060,2400061,2400061,2400062,2400062,2401914,2401951,2402015,2404145,2404198,2400036,2400037,2400038,2400042,2400053,2400061,2400061,2400062,2400062,2400063,2400037,2400059,2400063,2400059,2400061,2400063,2400064,2400064,2400065,2400068,2400074,2400076,2400068,2400077,2400078,2400079,2400079,2400079,2400080,2400082,2400085,2400085,2400087,2400087,2400088,2400088,2401939,2400089,2400089,2400090,2401708,2401941,2401941,2401978,2401999,2404172,2404173,2404221,2404221,2404224,2404371,2408499,2411332,2401942,2403401,2403635,2403792,2403793,2403794,2403794,2403795,2403795,2403796,2403796,2403797,2403804,2403815,2403821,2403822,2403828,2403828,2403829,2403829,2403830,2403832,2403865,2403868,2403795,2403829,2403830,2403830,2403798,2403830,2403831,2403798,2403831,2403831,2403832,2403832,2403833,2403833,2403833,2403833,2403834,2403816,2403842,2406085,2406235,2403851,2403858,2403859,2403865,2403865,2403866,2403866,2403905,2403867,2403868,2403868,2403869,2403869,2403870,2403870,2403871,2403871,2403872,2403873,2403874,2403875,2403876,2403877,2403878,2403879,2403879,2403880,2403880,2403881,2403881,2403882,2403882,2403883,2403885,2403885,2403886,2403887,2403887,2403888,2403890,2403891,2403891,2403892,2403892,2403893,2403893,2403898,2403903,2403904,2403905,2403905,2403906,2403868,2403873,2403877,2403879,2403880,2403880,2403881,2403881,2403884,2403887,2403888,2403893,2403905,2403906,2403871,2403880,2403881,2403881,2403882,2403884,2403888,2403906,2403874,2403879,2403880,2403882,2403883,2403873,2403874,2403878,2403881,2403882,2403882,2403883,2403883,2403884,2403885,2403890,2403904,2403908,2403875,2403883,2403884,2403890,2403882,2403883,2403884,2403876,2403878,2403883,2403885,2403883,2403884,2403885,2403887,2403883,2403884,2403885,2403892,2403893,2403910,2403887,2403911,2403911,2403881,2403886,2403886,2403888,2403889,2403889,2403890,2403889,2403891,2403891,2403891,2403892,2403892,2403894,2403895,2403908,2403912,2403913,2403917,2403893,2403894,2403895,2403898,2403899,2403904,2403908,2403917,2403892,2403893,2403893,2403896,2403900,2403904,2403906,2403907,2403908,2403909,2403893,2403894,2403895,2403898,2403899,2403900,2403900,2403901,2403902,2403905,2403906,2403906,2403908,2403909,2403915,2403916,2403918,2403918,2403894,2403895,2403895,2403896,2403897,2403901,2403902,2403906,2403906,2403910,2403916,2403918,2403919,2403896,2403896,2403897,2403897,2403898,2403899,2403899,2403900,2403900,2403901,2403901,2403902,2403903,2403904,2403905,2403905,2403906,2403906,2403907,2403907,2403908,2403912,2403914,2403916,2403916,2403917,2403917,2403919,2403919,2403897,2403911,2403916,2403898,2403898,2403907,2403910,2403917,2403920,2403899,2403901,2403902,2403908,2403908,2403909,2403921,2403899,2403908,2403908,2403909,2403918,2403901,2403902,2403902,2403903,2403904,2403904,2403905,2403908,2403909,2403909,2403910,2403914,2403917,2403921,2403922,2403922,2403904,2403904,2403905,2403906,2403921,2403922,2403923,2403905,2403906,2403912,2403924,2406080,2403906,2403906,2403907,2403911,2403914,2403924,2403906,2403907,2403907,2403911,2403912,2403913,2403925,2403907,2403908,2403912,2403912,2403913,2403921,2403923,2403923,2403925,2403925,2403908,2403912,2403912,2403913,2403913,2403918,2403922,2403923,2403924,2403926,2403912,2403913,2403913,2403914,2403914,2403917,2403919,2403921,2403921,2403923,2403924,2403924,2403925,2403926,2403926,2403914,2403914,2403927,2403915,2403928,2403916,2403916,2403916,2403929,2403929,2403916,2403917,2403917,2403919,2403925,2403930,2403917,2403918,2403920,2403921,2403927,2403928,2403928,2403930,2403918,2403919,2403920,2403921,2403922,2403924,2403926,2403927,2403928,2403928,2403930,2403931,2403919,2403920,2403921,2403922,2403928,2403929,2403929,2403930,2403931,2403921,2403930,2403932,2403923,2403930,2403930,2403933,2403928,2403929,2403930,2403931,2403933,2403934,2403934,2403929,2403931,2403934,2403935,2403936,2403937,2403937,2403938,2403938,2403938,2403935,2403939,2403939,2403937,2403940,2403938,2403938,2403939,2403940,2403976,2403977,2406096,2403939,2403940,2403941,2403941,2403941,2403967,2403978,2406097,2403941,2403942,2406098,2403942,2403943,2403943,2403944,2403945,2403945,2403946,2403947,2403948,2403948,2403949,2403949,2403950,2403951,2403951,2403952,2403952,2403954,2403956,2403957,2403965,2403969,2403970,2403972,2403972,2403974,2403976,2403978,2403978,2403979,2403979,2403980,2403980,2403981,2406100,2406148,2406148,2406150,2406162,2406298,2406318,2406319,2410426,2410426,2413308,2403947,2403948,2403949,2403949,2403950,2403953,2403953,2403970,2403973,2403975,2403976,2403978,2403979,2403979,2403980,2403980,2403981,2403981,2403980,2403981,2403982,2406101,2403951,2403983,2403983,2403984,2403955,2403983,2403985,2406104,2403954,2403982,2403984,2403985,2406104,2403955,2403986,2403955,2403982,2403985,2403985,2403986,2403987,2403986,2403987,2403988,2403986,2403986,2403988,2403987,2403989,2403988,2403989,2403990,2403990,2403993,2403993,2403998,2404001,2404006,2403997,2403997,2404007,2403998,2404007,2404008,2404008,2404007,2404009,2404010,2404011,2404011,2404012,2404011,2404012,2404013,2404013,2404012,2404013,2404014,2404013,2404014,2404014,2404015,2404014,2404015,2404016,2406135,2404015,2404016,2404016,2404017,2406136,2404017,2406136,2404018,2406136,2406136,2406137,2406170,2406185,2406185,2406187,2406188,2406191,2406335,2410505,2406137,2406137,2408254,2408255,2408256,2408257,2408257,2408259,2408261,2408262,2408263,2408264,2408265,2408267,2408271,2408271,2408275,2408276,2408276,2408284,2408285,2408287,2408288,2408289,2408291,2408293,2408294,2408294,2408296,2408296,2408297,2408298,2408301,2408301,2408302,2408303,2408303,2408304,2408304,2408308,2408331,2408332,2408257,2408258,2408259,2408264,2408273,2408290,2408296,2408302,2408303,2408304,2408304,2408304,2408304,2408305,2408265,2408305,2408305,2408266,2408266,2408269,2408269,2408273,2408276,2408277,2408285,2408292,2408299,2408301,2408304,2408309,2408309,2408310,2408311,2408311,2408312,2408311,2408313,2408313,2408316,2408516,2408314,2408315,2408315,2408317,2408317,2408317,2408319,2408319,2408303,2408323,2408324,2408324,2408324,2408326,2408332,2408332,2408333,2408333,2408334,2408335,2408336,2408336,2408337,2408337,2408339,2408339,2408331,2408339,2408341,2408342,2408341,2408343,2408344,2408344,2408344,2408343,2408348,2408349,2408348,2408349,2408349,2408349,2408350,2408349,2408350,2408350,2408351,2408351,2408352,2408357,2408379,2408352,2408353,2408353,2408354,2408354,2408355,2408355,2408356,2408356,2408357,2408358,2408359,2408360,2408361,2408361,2408362,2408365,2408366,2408368,2408369,2408379,2408379,2408380,2408384,2408385,2408353,2408354,2408354,2408355,2408355,2408356,2408357,2408358,2408358,2408359,2408360,2408362,2408362,2408366,2408367,2408370,2408376,2408377,2408379,2408380,2408380,2408381,2408385,2408386,2408354,2408355,2408355,2408356,2408356,2408357,2408360,2408361,2408362,2408366,2408375,2408380,2408355,2408356,2408356,2408357,2408358,2408359,2408359,2408360,2408361,2408364,2408367,2408368,2408369,2408378,2408381,2408381,2408356,2408357,2408357,2408358,2408358,2408359,2408359,2408360,2408361,2408361,2408362,2408362,2408363,2408368,2408368,2408369,2408371,2408379,2408381,2408381,2408382,2408357,2408358,2408358,2408359,2408359,2408360,2408360,2408362,2408362,2408363,2408363,2408364,2408364,2408368,2408372,2408380,2408381,2408382,2408382,2408358,2408359,2408359,2408360,2408360,2408361,2408362,2408362,2408363,2408364,2408364,2408366,2408368,2408369,2408370,2408373,2408376,2408378,2408380,2408382,2408382,2408383,2408359,2408360,2408360,2408361,2408361,2408362,2408363,2408363,2408364,2408364,2408365,2408365,2408369,2408370,2408372,2408372,2408377,2408380,2408381,2408381,2408382,2408383,2408383,2408360,2408361,2408362,2408365,2408370,2408362,2408362,2408363,2408364,2408364,2408365,2408366,2408366,2408370,2408370,2408371,2408377,2408378,2408380,2408381,2408382,2408383,2408384,2408384,2408363,2408365,2408367,2408384,2408363,2408365,2408365,2408366,2408367,2408367,2408369,2408369,2408371,2408374,2408376,2408378,2408379,2408380,2408381,2408383,2408383,2408384,2408385,2408385,2408386,2408364,2408365,2408365,2408366,2408367,2408367,2408368,2408370,2408371,2408372,2408373,2408375,2408376,2408379,2408380,2408381,2408383,2408384,2408385,2408385,2408386,2408386,2408366,2408368,2408367,2408368,2408373,2408376,2408376,2408378,2408380,2408380,2408382,2408384,2408386,2408386,2408367,2408368,2408368,2408369,2408369,2408373,2408376,2408377,2408380,2408385,2408386,2408387,2408368,2408369,2408369,2408370,2408371,2408373,2408374,2408376,2408377,2408377,2408385,2408387,2408387,2408388,2408371,2408374,2408381,2408387,2408387,2408370,2408371,2408374,2408375,2408377,2408378,2408382,2408383,2408384,2408386,2408388,2408388,2408389,2408371,2408375,2408383,2408385,2408385,2408387,2408388,2408389,2408373,2408375,2408376,2408377,2408378,2408379,2408379,2408383,2408384,2408385,2408385,2408386,2408387,2408389,2408389,2408380,2408388,2408390,2408390,2408386,2408388,2408391,2408378,2408379,2408392,2408382,2408389,2408391,2408392,2408393,2408395,2408380,2408381,2408382,2408382,2408383,2408383,2408384,2408384,2408387,2408389,2408390,2408391,2408391,2408392,2408393,2408393,2408394,2408399,2408399,2408381,2408384,2408384,2408392,2408394,2408394,2408399,2408383,2408384,2408387,2408394,2408383,2408384,2408395,2408385,2408393,2408395,2408396,2408385,2408395,2408396,2408386,2408387,2408388,2408389,2408390,2408392,2408393,2408394,2408396,2408396,2408397,2408388,2408389,2408390,2408391,2408395,2408396,2408397,2408394,2408397,2408397,2408396,2408397,2408392,2408394,2408398,2408399,2408399,2408395,2408398,2408400,2408400,2408397,2408399,2408400,2408401,2408401,2408397,2408399,2408400,2408401,2408402,2408402,2408400,2408400,2408401,2408402,2408403,2408403,2408403,2408401,2408403,2408404,2408404,2408404,2408403,2408404,2408404,2408405,2408405,2408405,2408405,2408405,2408406,2408406,2408407,2408409,2408529,2408407,2408408,2408409,2408411,2408411,2408412,2408413,2408417,2408421,2408450,2408455,2408530,2408550,2411252,2408408,2408409,2408410,2408410,2408411,2408412,2408412,2408413,2408413,2408414,2408415,2408415,2408416,2408417,2408417,2408418,2408418,2408421,2408422,2408423,2408424,2408425,2408425,2408426,2408426,2408427,2408427,2408445,2408447,2408451,2408452,2408453,2408453,2408454,2408454,2408455,2408455,2408456,2408530,2408553,2408582,2416672,2408409,2408410,2408410,2408411,2408411,2408412,2408412,2408413,2408413,2408414,2408415,2408416,2408417,2408417,2408418,2408418,2408419,2408420,2408421,2408422,2408423,2408423,2408425,2408427,2408427,2408428,2408429,2408432,2408439,2408439,2408440,2408446,2408448,2408449,2408449,2408451,2408452,2408453,2408454,2408454,2408455,2408455,2408456,2408456,2408531,2411288,2408410,2408411,2408411,2408412,2408413,2408413,2408414,2408414,2408416,2408416,2408417,2408418,2408430,2408440,2408440,2408454,2408454,2408455,2408455,2408456,2408456,2408457,2408411,2408413,2408414,2408415,2408415,2408419,2408420,2408424,2408429,2408441,2408455,2408456,2408457,2408458,2408532,2408414,2408415,2408416,2408418,2408420,2408426,2408457,2408458,2408416,2408459,2408416,2408417,2408421,2408421,2408424,2408428,2408458,2408459,2408416,2408417,2408417,2408419,2408420,2408421,2408422,2408443,2408457,2408458,2408459,2408460,2408534,2408417,2408418,2408459,2408460,2408460,2408418,2408420,2408461,2408419,2408420,2408420,2408421,2408422,2408423,2408423,2408427,2408427,2408432,2408433,2408442,2408444,2408454,2408455,2408456,2408459,2408459,2408460,2408461,2408461,2408536,2408559,2412705,2408423,2408426,2408428,2408460,2408460,2408461,2408462,2408422,2408460,2408462,2408422,2408424,2408430,2408446,2408463,2408423,2408425,2408425,2408435,2408438,2408461,2408462,2408463,2408425,2408432,2408464,2408464,2408427,2408445,2408460,2408464,2408465,2408427,2408429,2408430,2408432,2408433,2408435,2408437,2408437,2408439,2408448,2408463,2408463,2408464,2408465,2408465,2415550,2408431,2408432,2408432,2408435,2408437,2408437,2408438,2408460,2408463,2408464,2408465,2408465,2408466,2408435,2408438,2408465,2408466,2408442,2408433,2408467,2408436,2408466,2408469,2408458,2408467,2408469,2408544,2408468,2408469,2408441,2408442,2408468,2408469,2408470,2408440,2408442,2408471,2408441,2408469,2408445,2408463,2408471,2408472,2408471,2408472,2408443,2408446,2408468,2408471,2408473,2408474,2408548,2408474,2408474,2408455,2408458,2408467,2408473,2408475,2408468,2408471,2408473,2408474,2408474,2408475,2408474,2408475,2408476,2408459,2408473,2408471,2408476,2408477,2408476,2408478,2408477,2408479,2408484,2408485,2408486,2408485,2408485,2408486,2408487,2408484,2408486,2408487,2408487,2408492,2408493,2408494,2408488,2408494,2408496,2408493,2408494,2408496,2408495,2408495,2408496,2408496,2408496,2408494,2408497,2408498,2408495,2408496,2408498,2408499,2408497,2408499,2408498,2408498,2408499,2408500,2408498,2408499,2408499,2408501,2408499,2408500,2408501,2408501,2408500,2408501,2408501,2408502,2408501,2408502,2408502,2408502,2408503,2408503,2408504,2408578,2408578,2408601,2408602,2408602,2408603,2408604,2408628,2408631,2411251,2412706,2412706,2412748,2416678,2408578,2408579,2408603,2408652,2408653,2408654,2408654,2408655,2408656,2408656,2408657,2408658,2408661,2408662,2408664,2408665,2408669,2408671,2408671,2408672,2408672,2408673,2408673,2408674,2408674,2408675,2408675,2408676,2408676,2408677,2408677,2408678,2408694,2408658,2408664,2408671,2408671,2408672,2408673,2408673,2408674,2408676,2408677,2408671,2408673,2408664,2408674,2408660,2408678,2408675,2408661,2408676,2408676,2408676,2408676,2408677,2408677,2408678,2408678,2408680,2408680,2408681,2408681,2408672,2408673,2408683,2408688,2408692,2408673,2408674,2408675,2408683,2408684,2408684,2408687,2408687,2408688,2408717,2411356,2411359,2411361,2408684,2412847,2408683,2408689,2408690,2408689,2408689,2408690,2408690,2408691,2408690,2408691,2408691,2408692,2408692,2408693,2408695,2408695,2408693,2408694,2408695,2408695,2408696,2408696,2408697,2408697,2408699,2408717,2408720,2408726,2408694,2408695,2408695,2408696,2408696,2408697,2408697,2408698,2408714,2408717,2408718,2408720,2408723,2408749,2408695,2408696,2408696,2408697,2408697,2408698,2408698,2408699,2408699,2408702,2408703,2408706,2408708,2408709,2408712,2408714,2408719,2408720,2408722,2408723,2408725,2408727,2408749,2408696,2408697,2408697,2408698,2408698,2408699,2408701,2408704,2408704,2408707,2408708,2408712,2408712,2408714,2408715,2408717,2408718,2408724,2408727,2408730,2408733,2408739,2408750,2408697,2408698,2408698,2408699,2408704,2408705,2408706,2408707,2408712,2408713,2408717,2408722,2408724,2408724,2408729,2408729,2408731,2408735,2408750,2408750,2408698,2408699,2408699,2408703,2408720,2408721,2408727,2408751,2408699,2408700,2408700,2408708,2408719,2408719,2408720,2408723,2408751,2408772,2408700,2408701,2408702,2408702,2408703,2408704,2408706,2408706,2408710,2408712,2408714,2408714,2408715,2408716,2408716,2408717,2408717,2408719,2408720,2408720,2408721,2408721,2408722,2408723,2408724,2408725,2408725,2408726,2408728,2408731,2408735,2408752,2408773,2408701,2408702,2408702,2408703,2408704,2408705,2408706,2408707,2408708,2408708,2408709,2408710,2408711,2408712,2408713,2408714,2408715,2408715,2408717,2408717,2408718,2408718,2408720,2408720,2408721,2408721,2408722,2408722,2408723,2408723,2408724,2408724,2408725,2408725,2408726,2408728,2408729,2408730,2408736,2408748,2408749,2408750,2408751,2408752,2408752,2408702,2408703,2408703,2408704,2408705,2408705,2408706,2408707,2408707,2408708,2408709,2408709,2408710,2408711,2408712,2408713,2408715,2408716,2408717,2408718,2408718,2408719,2408719,2408720,2408720,2408721,2408721,2408722,2408723,2408724,2408724,2408725,2408725,2408726,2408726,2408727,2408727,2408729,2408729,2408730,2408730,2408732,2408735,2408736,2408746,2408749,2408750,2408750,2408752,2408753,2408774,2408703,2408704,2408705,2408705,2408706,2408707,2408707,2408708,2408709,2408710,2408713,2408713,2408716,2408718,2408719,2408720,2408721,2408722,2408723,2408724,2408724,2408725,2408725,2408727,2408729,2408730,2408730,2408731,2408733,2408734,2408735,2408735,2408751,2408753,2408753,2408704,2408705,2408706,2408707,2408708,2408708,2408710,2408712,2408715,2408715,2408717,2408718,2408719,2408722,2408723,2408725,2408726,2408730,2408734,2408751,2408751,2408754,2408705,2408706,2408707,2408707,2408709,2408709,2408710,2408712,2408717,2408719,2408720,2408720,2408721,2408722,2408723,2408725,2408727,2408728,2408730,2408732,2408733,2408738,2408754,2408775,2408706,2408707,2408709,2408709,2408719,2408722,2408724,2408724,2408726,2408709,2408755,2408709,2408710,2408715,2408722,2408723,2408730,2408732,2408716,2408719,2408721,2408729,2408730,2408746,2408756,2408714,2408716,2408719,2408723,2408726,2408733,2408711,2408713,2408724,2408713,2408714,2408714,2408718,2408720,2408721,2408723,2408726,2408726,2408727,2408732,2408735,2408718,2408719,2408722,2408723,2408724,2408727,2408729,2408730,2408731,2408734,2408758,2408758,2408721,2408735,2408719,2408722,2408725,2408732,2408733,2408733,2408735,2408716,2408718,2408722,2408724,2408725,2408726,2408730,2408723,2408726,2408729,2408734,2408736,2408738,2408739,2408760,2408723,2408724,2408720,2408724,2408733,2408762,2408722,2408723,2408725,2408726,2408728,2408735,2408736,2408739,2408762,2408762,2408726,2408727,2408727,2408728,2408729,2408732,2408740,2408751,2408763,2408734,2408738,2408745,2408764,2408726,2408733,2408736,2408764,2408734,2408743,2408765,2408728,2408732,2408734,2408738,2408743,2408761,2408766,2408730,2408732,2408732,2408733,2408733,2408734,2408735,2408736,2408736,2408737,2408738,2408740,2408744,2408752,2408766,2408732,2408733,2408735,2408740,2408732,2408733,2408733,2408767,2408733,2408737,2408738,2408741,2408744,2408768,2408734,2408737,2408738,2408739,2408741,2408742,2408744,2408735,2408735,2408736,2408738,2408739,2408740,2408741,2408742,2408743,2408745,2408746,2408748,2408749,2408750,2408769,2408735,2408736,2408737,2408738,2408738,2408739,2408740,2408742,2408742,2408743,2408743,2408745,2408746,2408746,2408747,2408747,2408751,2408765,2408769,2408737,2408738,2408739,2408740,2408742,2408743,2408744,2408746,2408747,2408750,2408751,2408753,2408770,2408737,2408739,2408739,2408740,2408741,2408742,2408744,2408745,2408770,2408738,2408740,2408747,2408748,2408754,2408771,2408739,2408740,2408740,2408741,2408742,2408742,2408743,2408744,2408745,2408748,2408749,2408754,2408767,2408771,2408741,2408742,2408746,2408748,2408749,2408751,2408755,2408772,2408741,2408742,2408743,2408744,2408744,2408745,2408746,2408746,2408749,2408749,2408750,2408751,2408755,2408772,2408772,2408743,2408744,2408744,2408745,2408746,2408746,2408747,2408747,2408749,2408749,2408750,2408750,2408751,2408752,2408754,2408755,2408773,2408743,2408744,2408745,2408746,2408747,2408747,2408749,2408751,2408751,2408773,2408744,2408746,2408748,2408751,2408751,2408755,2408769,2408774,2408745,2408747,2408750,2408751,2408751,2408752,2408754,2408754,2408756,2408757,2408772,2408774,2408746,2408747,2408748,2408748,2408749,2408751,2408751,2408752,2408775,2411392,2408747,2408748,2408748,2408749,2408749,2408751,2408753,2408754,2408773,2408775,2411456,2408749,2408750,2408752,2408752,2408753,2408753,2408776,2408750,2408750,2408752,2408753,2408754,2408757,2408759,2408750,2408751,2408753,2408753,2408754,2408754,2408755,2408756,2408771,2408776,2408777,2408751,2408753,2408754,2408754,2408755,2408756,2408757,2408759,2408760,2408771,2408777,2408753,2408754,2408754,2408755,2408755,2408756,2408757,2408758,2408760,2408761,2408763,2408763,2408765,2408768,2408769,2408771,2408771,2408772,2408773,2408773,2408775,2408775,2408776,2408776,2408778,2408755,2408756,2408761,2408778,2408755,2408764,2408756,2408757,2408757,2408759,2408761,2408762,2408763,2408763,2408764,2408766,2408770,2408771,2408773,2408775,2408775,2408777,2408777,2408778,2408778,2408779,2408780,2408758,2408759,2408760,2408762,2408763,2408764,2408766,2408767,2408773,2408773,2408777,2408778,2408780,2408780,2408758,2408760,2408761,2408761,2408763,2408764,2408764,2408765,2408767,2408776,2408778,2408778,2408780,2408781,2408759,2408760,2408760,2408761,2408762,2408763,2408763,2408764,2408764,2408765,2408765,2408766,2408767,2408768,2408768,2408769,2408770,2408771,2408772,2408773,2408773,2408774,2408774,2408775,2408777,2408778,2408779,2408779,2408780,2408781,2408781,2408761,2408775,2408778,2408779,2408782,2408762,2408763,2408764,2408782,2408762,2408764,2408764,2408765,2408765,2408766,2408766,2408768,2408769,2408770,2408772,2408773,2408774,2408774,2408775,2408775,2408778,2408780,2408782,2408783,2408764,2408770,2408782,2408782,2408783,2408765,2408765,2408766,2408767,2408768,2408770,2408777,2408778,2408782,2408784,2408766,2408784,2408767,2408771,2408780,2408780,2408782,2408785,2408768,2408768,2408769,2408772,2408774,2408777,2408783,2408785,2408770,2408774,2408776,2408783,2408785,2408786,2408769,2408772,2408775,2408777,2408780,2408781,2408784,2408786,2408772,2408773,2408774,2408775,2408778,2408778,2408782,2408784,2408785,2408785,2408786,2408787,2408772,2408774,2408776,2408778,2408782,2408787,2408779,2408784,2408788,2408776,2408778,2408785,2408788,2408786,2408787,2408789,2408780,2408789,2408777,2408779,2408785,2408785,2408788,2408789,2408790,2408781,2408782,2408785,2408788,2408790,2408780,2408782,2408791,2408784,2408784,2408788,2408789,2408791,2408782,2408789,2408785,2408791,2408792,2408784,2408788,2408789,2408785,2408786,2408788,2408793,2408785,2408793,2408789,2408791,2408792,2408794,2408794,2408786,2408792,2408794,2408795,2408791,2408793,2408794,2408795,2408795,2411477,2408788,2408791,2408793,2408795,2408791,2408792,2408796,2408794,2408795,2408797,2408797,2408795,2408798,2408795,2408796,2408798,2408796,2408798,2408799,2408795,2408796,2408799,2408799,2411416,2408796,2408798,2408800,2408800,2408800,2408798,2408799,2408799,2408801,2408799,2408801,2408801,2408800,2408801,2408802,2408802,2412855,2416869,2408803,2408803,2408804,2408805,2408805,2408806,2408806,2408807,2408808,2408808,2408809,2408810,2408810,2408811,2408811,2408817,2408817,2408819,2408819,2408820,2408821,2408821,2408822,2408822,2408823,2408823,2408824,2408824,2408825,2411401,2411417,2411418,2411421,2411457,2411486,2412856,2412898,2415738,2416828,2408805,2408806,2408806,2408807,2408807,2408809,2408810,2408811,2408811,2408812,2408813,2408817,2408818,2408819,2408821,2408822,2408823,2408823,2408824,2408824,2408825,2408825,2408806,2408810,2408812,2408823,2408807,2408808,2408808,2408809,2408810,2408810,2408811,2408812,2408818,2408819,2408820,2408821,2408824,2408824,2408825,2408825,2408826,2408826,2408808,2408811,2408813,2408821,2408824,2408825,2408826,2408826,2408827,2408810,2408811,2408819,2408824,2408825,2408826,2408826,2408827,2408827,2408820,2408822,2408826,2408826,2408827,2408827,2408828,2408821,2408826,2408827,2408826,2408813,2408827,2408828,2408828,2408829,2408829,2408815,2408822,2408826,2408826,2408827,2408828,2408829,2408829,2408830,2408826,2408830,2408831,2408829,2408830,2408831,2408818,2408824,2408826,2408829,2408830,2408830,2408831,2408831,2408832,2408832,2408832,2408832,2408835,2408837,2408835,2408837,2408837,2408832,2408834,2408836,2408837,2408838,2408836,2408837,2408837,2408839,2408840,2408836,2408839,2408841,2408839,2408840,2408840,2408841,2408841,2408842,2408840,2408841,2408842,2408843,2408841,2408842,2408842,2408843,2408843,2408842,2408843,2408843,2408844,2408843,2408844,2408844,2408844,2408845,2411421,2408845,2412918,2408846,2408847,2411421,2411422,2411439,2411442,2411475,2412877,2412877,2412919,2415710,2416849,2416891,2411422,2411423,2413997,2413998,2413999,2413999,2414000,2414000,2414001,2414003,2414011,2414013,2414014,2414015,2414016,2414017,2414018,2414018,2414073,2414076,2413999,2414000,2414001,2414014,2414015,2414015,2414018,2414018,2414015,2414016,2414016,2414012,2414016,2414017,2414019,2414020,2414017,2414017,2414016,2414023,2414030,2414028,2414030,2414030,2414031,2414057,2414032,2414033,2414034,2414034,2414035,2414037,2414038,2414039,2414040,2414043,2414045,2414047,2414048,2414050,2414055,2414056,2414057,2414058,2414060,2414062,2414064,2414065,2414066,2414068,2414068,2414070,2414071,2414072,2414073,2414076,2414091,2414093,2414093,2414033,2414035,2414042,2414068,2414094,2414036,2414094,2414036,2414036,2414037,2414037,2414056,2414038,2414039,2414040,2414041,2414041,2414042,2414043,2414046,2414047,2414048,2414050,2414051,2414052,2414053,2414053,2414054,2414054,2414055,2414055,2414056,2414056,2414057,2414057,2414058,2414058,2414059,2414060,2414061,2414061,2414062,2414063,2414063,2414064,2414065,2414066,2414067,2414067,2414068,2414069,2414069,2414070,2414070,2414071,2414072,2414073,2414074,2414074,2414075,2414075,2414076,2414076,2414079,2414085,2414086,2414087,2414093,2414093,2414061,2414093,2414094,2414067,2414045,2414061,2414045,2414059,2414065,2414068,2414076,2414095,2414096,2414099,2414099,2414062,2414064,2414064,2414069,2414097,2414062,2414065,2414066,2414068,2414072,2414076,2414101,2414066,2414070,2414071,2414073,2414074,2414076,2414079,2414098,2414067,2414072,2414085,2414075,2414060,2414075,2414081,2414064,2414071,2414109,2414084,2414071,2414107,2414108,2414075,2414082,2414109,2414109,2414085,2414086,2414110,2414110,2414079,2414092,2414076,2414077,2414078,2414082,2414083,2414111,2414077,2414093,2414112,2414115,2414084,2414081,2414094,2414113,2414080,2414084,2414085,2414088,2414092,2414093,2414113,2414081,2414082,2414095,2414095,2414114,2414117,2414096,2414097,2414114,2414084,2414086,2414088,2414089,2414093,2414094,2414096,2414097,2414116,2414119,2415496,2414085,2414086,2414087,2414088,2414089,2414090,2414097,2414097,2414106,2414116,2414119,2414094,2414094,2414098,2414117,2414088,2414094,2414094,2414096,2414098,2414100,2414117,2415497,2414099,2414091,2414092,2414093,2414095,2414100,2414102,2414119,2414122,2415499,2414091,2414093,2414094,2414095,2414096,2414097,2414102,2414104,2414112,2414119,2414093,2414094,2414094,2414095,2414095,2414096,2414097,2414097,2414098,2414099,2414102,2414121,2414124,2414101,2414121,2414099,2414102,2414103,2414107,2414108,2414122,2414098,2414101,2414099,2414104,2414113,2414123,2414126,2414098,2414100,2414100,2414101,2414104,2414123,2414101,2414102,2414124,2414127,2414102,2414103,2414104,2414105,2414106,2414112,2414115,2414116,2414117,2414125,2414103,2414103,2414104,2414106,2414125,2414104,2414107,2414109,2414115,2414126,2414104,2414105,2414105,2414106,2414107,2414109,2414110,2414112,2414118,2414119,2414124,2414126,2414129,2414106,2414108,2414127,2414106,2414108,2414123,2414127,2414127,2414108,2414109,2414110,2414128,2414131,2414109,2414110,2414114,2414128,2414131,2414129,2414110,2414120,2414122,2414126,2414129,2414112,2414113,2414115,2414116,2414116,2414117,2414121,2414122,2414129,2414130,2414132,2414132,2414133,2414113,2414130,2414133,2414131,2414131,2414131,2414132,2414134,2414135,2414132,2414133,2414133,2414134,2414135,2414137,2414137,2414133,2414135,2414135,2414130,2414136,2414138,2414139,2414133,2414140,2414150,2414141,2414141,2414144,2414142,2414142,2414143,2414145,2414145,2414147,2414151,2414148,2414149,2414150,2414151,2414152,2414157,2414158,2414162,2414163,2414164,2414165,2414167,2414168,2414169,2415528,2415529,2415570,2418362,2418414,2414152,2414152,2414168,2414169,2414169,2414153,2414154,2414154,2414155,2414156,2414161,2414166,2414167,2414167,2414168,2414170,2414170,2414171,2414171,2414172,2415531,2415532,2415572,2419504,2419546,2414163,2414165,2414169,2414171,2414172,2414172,2414173,2414166,2414167,2414177,2414178,2414168,2414169,2414178,2414179,2414179,2414182,2414183,2414183,2414184,2414184,2414184,2414185,2414186,2414186,2414187,2414187,2414188,2414188,2414189,2415548,2415549,2415572,2415587,2415589,2415590,2415590,2415604,2415606,2415608,2418382,2418433,2419521,2415549,2415549,2415591,2416908,2416919,2416909,2416910,2416911,2416911,2416912,2416918,2416919,2416932,2416946,2416947,2416947,2416948,2416949,2416949,2416950,2416950,2416984,2416911,2416912,2416920,2416927,2416929,2416948,2416949,2416950,2416950,2416951,2416912,2416949,2416952,2416952,2416950,2416952,2416953,2416953,2416954,2416929,2416929,2416930,2416961,2416962,2416966,2416973,2419801,2419805,2420933,2420933,2416931,2416961,2416969,2419802,2419806,2416962,2416968,2416970,2416973,2416973,2416988,2416988,2416988,2416988,2416989,2416999,2416989,2416990,2416990,2416991,2417016,2416991,2417026,2416992,2416993,2416993,2416994,2416994,2416995,2416996,2416996,2416997,2416997,2416998,2416999,2416999,2417000,2417001,2417001,2417002,2417002,2417003,2417003,2417004,2417005,2417007,2417008,2417009,2417009,2417010,2417011,2417012,2417012,2417013,2417015,2417017,2417018,2417018,2417019,2417019,2417020,2417023,2417025,2417026,2416993,2416994,2416994,2417000,2417000,2417002,2417002,2417004,2417004,2417018,2417026,2417000,2417001,2417002,2417002,2417003,2417011,2416996,2417001,2417001,2417003,2417009,2417014,2417002,2417004,2417004,2417002,2417002,2417007,2417003,2417007,2417002,2417002,2417007,2417013,2417005,2417008,2417006,2417008,2417008,2417006,2417007,2417008,2417009,2417010,2417011,2417024,2417033,2417007,2417008,2417009,2417009,2417010,2417011,2417012,2417013,2417015,2417017,2417018,2417019,2417021,2417025,2417033,2417009,2417009,2417010,2417010,2417011,2417011,2417012,2417013,2417015,2417015,2417016,2417017,2417020,2417021,2417022,2417022,2417023,2417024,2417025,2417026,2417027,2417027,2417028,2417028,2417031,2417033,2417034,2417010,2417011,2417012,2417014,2417017,2417019,2417021,2417021,2417022,2417026,2417027,2417028,2417029,2417032,2417011,2417012,2417013,2417013,2417014,2417015,2417017,2417018,2417019,2417021,2417022,2417023,2417024,2417027,2417028,2417028,2417029,2417029,2417033,2417035,2417012,2417013,2417013,2417014,2417015,2417016,2417017,2417017,2417018,2417019,2417019,2417021,2417022,2417022,2417023,2417024,2417024,2417025,2417027,2417027,2417028,2417028,2417029,2417029,2417030,2417031,2417032,2417034,2417036,2417013,2417014,2417014,2417015,2417018,2417020,2417023,2417024,2417028,2417030,2417034,2417036,2417036,2417016,2417021,2417023,2417026,2417029,2417030,2417030,2417034,2417036,2417037,2417037,2417015,2417016,2417016,2417017,2417019,2417020,2417021,2417023,2417025,2417025,2417028,2417030,2417033,2417035,2417037,2417017,2417018,2417019,2417020,2417020,2417021,2417021,2417023,2417024,2417024,2417025,2417025,2417026,2417029,2417030,2417031,2417031,2417032,2417034,2417036,2417037,2417038,2417030,2417020,2417021,2417021,2417022,2417022,2417023,2417024,2417025,2417025,2417026,2417027,2417027,2417028,2417030,2417031,2417031,2417032,2417032,2417033,2417038,2417039,2417033,2417021,2417022,2417023,2417026,2417040,2417022,2417034,2417037,2417041,2417024,2417025,2417026,2417028,2417030,2417033,2417034,2417038,2417041,2417041,2417026,2417028,2417030,2417030,2417033,2417034,2417035,2417037,2417042,2417028,2417029,2417034,2417029,2417029,2417031,2417031,2417034,2417036,2417043,2417029,2417030,2417030,2417032,2417035,2417035,2417037,2417038,2417043,2417043,2417033,2417036,2417038,2417044,2417030,2417037,2417038,2417044,2420983,2417032,2417033,2417033,2417038,2417042,2417045,2419852,2417033,2417033,2417034,2417034,2417035,2417039,2417039,2417043,2417046,2417034,2417034,2417037,2417038,2417039,2417039,2417040,2417044,2417046,2417034,2417035,2417036,2417035,2417036,2417036,2417039,2417039,2417040,2417041,2417045,2417047,2417047,2419805,2417037,2417039,2417040,2417040,2417041,2417041,2417042,2417046,2417048,2417040,2417041,2417042,2417043,2417045,2417048,2417038,2417040,2417042,2417043,2417043,2417044,2417049,2417041,2417043,2417049,2417045,2417049,2417042,2417044,2417043,2417044,2417044,2417045,2417045,2417046,2417046,2417047,2417048,2417049,2417049,2417051,2417051,2419809,2417044,2417045,2417045,2417046,2417047,2417049,2417051,2417052,2417045,2417046,2417046,2417051,2417052,2417052,2417046,2417047,2417047,2417048,2417052,2417052,2417053,2417047,2417048,2417048,2417049,2417049,2417050,2417051,2417051,2417052,2417053,2417053,2417048,2417049,2417051,2417052,2417053,2417054,2417049,2417050,2417053,2417054,2417050,2417055,2417055,2417053,2417055,2417054,2417055,2417056,2417056,2419863,2417057,2417057,2417057,2417056,2417057,2417058,2417058,2417058,2417058,2417059,2417059,2417060,2417061,2417063,2417063,2417064,2417064,2417065,2417066,2417066,2417067,2417067,2417068,2417068,2417069,2417069,2417070,2417071,2417072,2417072,2417073,2417073,2417076,2417077,2417083,2417085,2417088,2417090,2417091,2417091,2417094,2417095,2417097,2417099,2417099,2417100,2417100,2417101,2417101,2419817,2419863,2419866,2419867,2419868,2419869,2419875,2420956,2420998,2417061,2417062,2417064,2417064,2417065,2417066,2417066,2417067,2417068,2417068,2417069,2417069,2417070,2417071,2417072,2417072,2417073,2417074,2417079,2417080,2417084,2417090,2417091,2417092,2417097,2417099,2417100,2417101,2417101,2417102,2417070,2417075,2417101,2417102,2417103,2417069,2417105,2417069,2417072,2417093,2417104,2417105,2417077,2419822,2421017,2417074,2417077,2417078,2417092,2417106,2417107,2419872,2417073,2417074,2417079,2417106,2417107,2419872,2417076,2417078,2417106,2417108,2417075,2417080,2417108,2419873,2417076,2417080,2417109,2419825,2417077,2417077,2417079,2417099,2417103,2417105,2417108,2417109,2417109,2419825,2417078,2417081,2417092,2417095,2417099,2417110,2420965,2421007,2417080,2417081,2417082,2417100,2417109,2417110,2419875,2417080,2417082,2417083,2417092,2417099,2417100,2417110,2417111,2417081,2417110,2417111,2417112,2417083,2417111,2417113,2417103,2417112,2417113,2419878,2417085,2417107,2417097,2417104,2417111,2417113,2417113,2417114,2417114,2419830,2417090,2417114,2417115,2417115,2417117,2417116,2417118,2417120,2417110,2417124,2417124,2417125,2417121,2417124,2417116,2417127,2417117,2417128,2417119,2417131,2417121,2417127,2417130,2417131,2417129,2417130,2417131,2417132,2417132,2419848,2417128,2417133,2417136,2417136,2417137,2417137,2417138,2417138,2417139,2417139,2417140,2417140,2417140,2417141,2417140,2417141,2417141,2417142,2417142,2417143,2417144,2419858,2419859,2419908,2420998,2419859,2419860,2422574,2422575,2422576,2422576,2422577,2422579,2422581,2422590,2422599,2422599,2422604,2422604,2422607,2422608,2422620,2422621,2422622,2422622,2422623,2422623,2422624,2422650,2422579,2422623,2422624,2422624,2422625,2422625,2422580,2422581,2422621,2422626,2422626,2422626,2422627,2422627,2422628,2422630,2422639,2422647,2422648,2422653,2422653,2422655,2422657,2422667,2422668,2422669,2422669,2422670,2422671,2422671,2422671,2422671,2422672,2422672,2422673,2422674,2422674,2422675,2422675,2422676,2422676,2422677,2422677,2422678,2422678,2422679,2422680,2422680,2422681,2422681,2422682,2422682,2422683,2422684,2422685,2422688,2422690,2422691,2422692,2422693,2422694,2422697,2422699,2422699,2422674,2422675,2422675,2422676,2422677,2422677,2422678,2422679,2422682,2422684,2422691,2422694,2422696,2422697,2422699,2422700,2422676,2422679,2422681,2422676,2422677,2422678,2422678,2422680,2422683,2422696,2422697,2422697,2422700,2422701,2422677,2422678,2422678,2422679,2422680,2422680,2422681,2422682,2422683,2422683,2422684,2422696,2422698,2422701,2422678,2422679,2422679,2422681,2422682,2422683,2422683,2422684,2422685,2422685,2422689,2422692,2422693,2422693,2422694,2422696,2422696,2422698,2422698,2422699,2422699,2422701,2422702,2422680,2422686,2422698,2422680,2422682,2422682,2422683,2422683,2422684,2422699,2422699,2422703,2422681,2422682,2422683,2422684,2422685,2422685,2422686,2422686,2422687,2422688,2422688,2422689,2422692,2422693,2422694,2422696,2422697,2422698,2422699,2422700,2422700,2422701,2422703,2422703,2422685,2422686,2422686,2422691,2422704,2422704,2422685,2422686,2422687,2422687,2422688,2422688,2422694,2422695,2422696,2422696,2422697,2422697,2422698,2422699,2422699,2422701,2422701,2422702,2422702,2422704,2422705,2422705,2422687,2422688,2422690,2422698,2422698,2422699,2422700,2422700,2422702,2422703,2422705,2422706,2422689,2422699,2422703,2422706,2422690,2422692,2422696,2422699,2422700,2422701,2422701,2422703,2422704,2422706,2422707,2422689,2422691,2422699,2422700,2422704,2422705,2422707,2422707,2422690,2422691,2422700,2422700,2422702,2422704,2422704,2422707,2422708,2422691,2422693,2422701,2422701,2422702,2422705,2422706,2422706,2422708,2422708,2422699,2422700,2422700,2422703,2422709,2422703,2422704,2422709,2422709,2422710,2422704,2422705,2422707,2422710,2422705,2422710,2422711,2422711,2422703,2422713,2422714,2422715,2422707,2422708,2422715,2422716,2422707,2422716,2422708,2422717,2422712,2422714,2422717,2422717,2423781,2422712,2422718,2422711,2422718,2422716,2422718,2422719,2423782,2422714,2422716,2422717,2422717,2422719,2422720,2422715,2422716,2422717,2422720,2422720,2422721,2422721,2422718,2422722,2422719,2422720,2422722,2422722,2422720,2422723,2422723,2422723,2422724,2422725,2422726,2422727,2422727,2422728,2422728,2422729,2422730,2422731,2422732,2422732,2422735,2422735,2422736,2422737,2422741,2422743,2422743,2422744,2422744,2422745,2422745,2422746,2422747,2422753,2422753,2422759,2422760,2422765,2422768,2422768,2422772,2422773,2422773,2422774,2422774,2422775,2423789,2423831,2424236,2422728,2422728,2422729,2422729,2422730,2422731,2422732,2422732,2422734,2422735,2422735,2422736,2422736,2422737,2422737,2422740,2422741,2422745,2422745,2422746,2422752,2422754,2422767,2422773,2422773,2422774,2422774,2422775,2422776,2422729,2422730,2422733,2422733,2422751,2422769,2422773,2422774,2422774,2422775,2422776,2422776,2423833,2422738,2422770,2422775,2422777,2423833,2422733,2422739,2422745,2422750,2422775,2422777,2422776,2422778,2423834,2422778,2422779,2422750,2422777,2422779,2422778,2422780,2422780,2422738,2422742,2422744,2422752,2422752,2422777,2422780,2422781,2423795,2422748,2422781,2422783,2422783,2422772,2422778,2422784,2422783,2422752,2422753,2422755,2422778,2422784,2422785,2422755,2422786,2422770,2422789,2422788,2422760,2422790,2422768,2422763,2422792,2422792,2422793,2422785,2422789,2422791,2422793,2422764,2422794,2422792,2422794,2422792,2422794,2422795,2422793,2422795,2422790,2422794,2422796,2422796,2422793,2422801,2422802,2422802,2422807,2422808,2422809,2422812,2422814,2422811,2422815,2422816,2422817,2422816,2422817,2422818,2422818,2422820,2422818,2422820,2422819,2422820,2422821,2422821,2422820,2422821,2422821,2422822,2422821,2422822,2422822,2422823,2422823,2422824,2423838,2423838,2423880,2423881,2423889,2424239,2424294,2426186,2423839,2424852,2424853,2424854,2424854,2424855,2424855,2424856,2424856,2424857,2424859,2424863,2424863,2424874,2424875,2424877,2424883,2424885,2424887,2424889,2424892,2424893,2424893,2424894,2424894,2424895,2424854,2424855,2424855,2424856,2424856,2424858,2424874,2424883,2424883,2424886,2424889,2424891,2424892,2424892,2424894,2424894,2424895,2424895,2424855,2424856,2424857,2424858,2424884,2424895,2424895,2424856,2424857,2424857,2424865,2424877,2424892,2424893,2424895,2424895,2424896,2424896,2424857,2424895,2424896,2424858,2424859,2424866,2424870,2424876,2424876,2424877,2424877,2424878,2424880,2424881,2424882,2424885,2424885,2424886,2424888,2424889,2424893,2424894,2424895,2424896,2424896,2424897,2424897,2424860,2424860,2424877,2424882,2424896,2424897,2424897,2424898,2424871,2424887,2424897,2424897,2424898,2424896,2424897,2424898,2424898,2424899,2424900,2424904,2424898,2424905,2424909,2424914,2424915,2424915,2424915,2424915,2424916,2424899,2424916,2424917,2424900,2424916,2424918,2424919,2424908,2424919,2424920,2424920,2424921,2424924,2424923,2424924,2424925,2424927,2424926,2424927,2424928,2424929,2424930,2424931,2424931,2424932,2424933,2424933,2424934,2424933,2424934,2424934,2424934,2424935,2424935,2424936,2424937,2424938,2424938,2424939,2424939,2424940,2424941,2424941,2424943,2424943,2424944,2424944,2424945,2424945,2424946,2424947,2424948,2424948,2424949,2424950,2424951,2424951,2424952,2424955,2424958,2424959,2424959,2424961,2424969,2424970,2424970,2424938,2424939,2424939,2424940,2424940,2424941,2424942,2424942,2424943,2424943,2424944,2424944,2424945,2424945,2424946,2424947,2424947,2424948,2424951,2424953,2424966,2424970,2424971,2424939,2424940,2424940,2424941,2424942,2424942,2424943,2424944,2424944,2424945,2424946,2424946,2424947,2424969,2424940,2424941,2424941,2424942,2424944,2424945,2424945,2424946,2424947,2424941,2424942,2424942,2424943,2424943,2424944,2424944,2424945,2424945,2424946,2424947,2424947,2424948,2424949,2424950,2424951,2424951,2424952,2424953,2424958,2424942,2424943,2424943,2424944,2424944,2424945,2424945,2424946,2424946,2424947,2424947,2424948,2424949,2424949,2424951,2424962,2424943,2424944,2424944,2424945,2424945,2424946,2424946,2424947,2424948,2424948,2424949,2424951,2424952,2424955,2424944,2424946,2424947,2424948,2424946,2424946,2424947,2424947,2424948,2424948,2424949,2424949,2424951,2424974,2424946,2424947,2424948,2424948,2424953,2424947,2424948,2424948,2424949,2424949,2424950,2424950,2424954,2424948,2424949,2424949,2424950,2424951,2424952,2424949,2424950,2424950,2424951,2424951,2424952,2424953,2424954,2424955,2424950,2424951,2424951,2424952,2424953,2424956,2424956,2424957,2424951,2424952,2424952,2424953,2424954,2424954,2424955,2424956,2424957,2424959,2424960,2424961,2424969,2424952,2424953,2424954,2424956,2424953,2424954,2424954,2424955,2424956,2424957,2424958,2424959,2424960,2424978,2424954,2424955,2424955,2424956,2424956,2424957,2424957,2424958,2424958,2424959,2424959,2424960,2424960,2424961,2424963,2424964,2424965,2424968,2424970,2424971,2424972,2424973,2424979,2424955,2424956,2424957,2424958,2424959,2424956,2424957,2424957,2424958,2424958,2424959,2424959,2424960,2424961,2424962,2424962,2424963,2424965,2424966,2424968,2424972,2424977,2424957,2424958,2424958,2424959,2424959,2424960,2424960,2424961,2424961,2424962,2424963,2424964,2424965,2424965,2424968,2424970,2424972,2424972,2424974,2424980,2424958,2424959,2424959,2424960,2424961,2424961,2424963,2424972,2424959,2424960,2424960,2424961,2424962,2424962,2424964,2424968,2424968,2424960,2424961,2424961,2424962,2424962,2424963,2424963,2424964,2424964,2424966,2424966,2424967,2424968,2424969,2424971,2424971,2424973,2424975,2424982,2424961,2424962,2424962,2424963,2424963,2424964,2424964,2424965,2424966,2424966,2424967,2424968,2424968,2424969,2424969,2424970,2424971,2424972,2424973,2424976,2424962,2424963,2424963,2424964,2424964,2424965,2424966,2424966,2424967,2424967,2424968,2424968,2424969,2424971,2424972,2424972,2424974,2424975,2424963,2424964,2424964,2424965,2424965,2424966,2424967,2424968,2424968,2424969,2424969,2424970,2424970,2424971,2424972,2424973,2424973,2424975,2424983,2424964,2424965,2424965,2424966,2424967,2424968,2424968,2424970,2424971,2424972,2424975,2424983,2424965,2424966,2424966,2424967,2424967,2424968,2424968,2424969,2424970,2424971,2424972,2424973,2424975,2424975,2424976,2424978,2424984,2424966,2424967,2424967,2424968,2424968,2424969,2424969,2424970,2424970,2424971,2424972,2424972,2424973,2424974,2424975,2424985,2424967,2424968,2424968,2424969,2424969,2424970,2424970,2424971,2424971,2424972,2424972,2424973,2424974,2424975,2424976,2424977,2424977,2424979,2424981,2424983,2424984,2424985,2424968,2424969,2424969,2424970,2424971,2424972,2424973,2424975,2424975,2424986,2424969,2424970,2424970,2424971,2424971,2424972,2424972,2424973,2424973,2424974,2424974,2424975,2424975,2424976,2424976,2424977,2424978,2424978,2424979,2424979,2424980,2424984,2424984,2424985,2424986,2424986,2424970,2424971,2424972,2424973,2424973,2424975,2424976,2424978,2424979,2424971,2424972,2424972,2424973,2424973,2424974,2424974,2424975,2424976,2424977,2424977,2424979,2424980,2424981,2424987,2424972,2424973,2424973,2424974,2424974,2424975,2424976,2424976,2424977,2424977,2424978,2424979,2424979,2424980,2424980,2424983,2424984,2424985,2424985,2424988,2424973,2424974,2424974,2424975,2424975,2424976,2424977,2424978,2424978,2424979,2424980,2424980,2424982,2424985,2424988,2424974,2424975,2424975,2424976,2424976,2424977,2424978,2424978,2424981,2424982,2424986,2424988,2424989,2424975,2424976,2424976,2424977,2424978,2424978,2424979,2424981,2424982,2424983,2424984,2424986,2424987,2424988,2424988,2424989,2424989,2424976,2424977,2424977,2424978,2424979,2424979,2424977,2424978,2424978,2424979,2424979,2424980,2424980,2424981,2424982,2424983,2424983,2424984,2424988,2424988,2424989,2424989,2424990,2424990,2424978,2424979,2424979,2424980,2424980,2424981,2424981,2424982,2424982,2424983,2424984,2424987,2424988,2424989,2424990,2424991,2424979,2424980,2424981,2424982,2424985,2424980,2424981,2424981,2424982,2424983,2424983,2424984,2424984,2424985,2424988,2424990,2424991,2424992,2424981,2424982,2424982,2424983,2424984,2424988,2424992,2424982,2424983,2424983,2424984,2424984,2424985,2424985,2424986,2424986,2424987,2424988,2424989,2424990,2424990,2424991,2424991,2424992,2424993,2425318,2424983,2424984,2424984,2424985,2424985,2424986,2424986,2424987,2424987,2424988,2424989,2424991,2424992,2424993,2424993,2424984,2424985,2424985,2424986,2424986,2424987,2424987,2424992,2424993,2424994,2424985,2424986,2424986,2424988,2424988,2424989,2424994,2424994,2424986,2424987,2424987,2424988,2424988,2424989,2424990,2424990,2424991,2424992,2424994,2424994,2424995,2427349,2424987,2424988,2424988,2424989,2424989,2424990,2424991,2424993,2424994,2424994,2424995,2424988,2424989,2424989,2424990,2424991,2424992,2424992,2424993,2424994,2424995,2424995,2424996,2424989,2424990,2424990,2424992,2424992,2424994,2424995,2424996,2424996,2424990,2424991,2424992,2424992,2424993,2424993,2424994,2424994,2424995,2424995,2424996,2424997,2424991,2424992,2424992,2424993,2424993,2424994,2424994,2424995,2424995,2424996,2424996,2424997,2424997,2424992,2424993,2424993,2424994,2424994,2424995,2424995,2424996,2424996,2424997,2424997,2424998,2424993,2424998,2424994,2424995,2424996,2424996,2424997,2424997,2424998,2424998,2424999,2424995,2424996,2424997,2424997,2424998,2424998,2424999,2424999,2424996,2424997,2424997,2424998,2424998,2424999,2424999,2425000,2424997,2424998,2424998,2424999,2425000,2425000,2424998,2424999,2425000,2425000,2425001,2424999,2425000,2425000,2425001,2425001,2425326,2425000,2425001,2425001,2425002,2425001,2425002,2425002,2425002,2425003,2425003,2425004,2425005,2425005,2425006,2425006,2425007,2425008,2425008,2425009,2425010,2425010,2425011,2425011,2425012,2425012,2425013,2425013,2425014,2425014,2425015,2425015,2425016,2425017,2425017,2425020,2425021,2425021,2425022,2425028,2425029,2425033,2425035,2425037,2425038,2425038,2425041,2425042,2425043,2425043,2425044,2425044,2425045,2425045,2425046,2425329,2425375,2425439,2430230,2425005,2425006,2425006,2425007,2425007,2425008,2425009,2425009,2425010,2425010,2425011,2425011,2425012,2425012,2425013,2425014,2425014,2425015,2425015,2425016,2425016,2425017,2425017,2425018,2425020,2425020,2425021,2425022,2425025,2425028,2425030,2425030,2425032,2425034,2425034,2425035,2425036,2425038,2425039,2425040,2425041,2425042,2425042,2425043,2425044,2425044,2425045,2425045,2425046,2425046,2425006,2425007,2425007,2425008,2425009,2425009,2425010,2425011,2425013,2425014,2425015,2425016,2425017,2425017,2425018,2425028,2425031,2425043,2425044,2425044,2425045,2425046,2425047,2425007,2425008,2425008,2425009,2425010,2425011,2425011,2425012,2425013,2425013,2425014,2425014,2425015,2425016,2425016,2425017,2425019,2425024,2425027,2425031,2425034,2425035,2425038,2425038,2425043,2425045,2425045,2425046,2425046,2425047,2425047,2425008,2425009,2425010,2425013,2425015,2425016,2425020,2425021,2425042,2425046,2425048,2425009,2425010,2425011,2425011,2425012,2425012,2425013,2425014,2425014,2425015,2425015,2425016,2425016,2425017,2425018,2425018,2425019,2425019,2425030,2425030,2425031,2425032,2425044,2425045,2425046,2425046,2425047,2425047,2425048,2425048,2425011,2425011,2425012,2425014,2425017,2425018,2425020,2425038,2425046,2425049,2425012,2425013,2425013,2425014,2425015,2425016,2425016,2425017,2425018,2425019,2425020,2425021,2425026,2425029,2425032,2425039,2425048,2425050,2425333,2425014,2425014,2425015,2425016,2425017,2425018,2425018,2425020,2425048,2425050,2425050,2425014,2425033,2425051,2425015,2425016,2425016,2425017,2425017,2425018,2425018,2425019,2425020,2425021,2425022,2425023,2425028,2425037,2425039,2425048,2425051,2425051,2425016,2425017,2425017,2425018,2425018,2425019,2425019,2425020,2425021,2425022,2425022,2425023,2425036,2425040,2425047,2425052,2425018,2425019,2425019,2425023,2425044,2425018,2425019,2425019,2425020,2425024,2425041,2425050,2425053,2425019,2425020,2425020,2425021,2425023,2425025,2425051,2425053,2425020,2425021,2425021,2425022,2425022,2425023,2425023,2425024,2425025,2425025,2425026,2425027,2425035,2425039,2425051,2425051,2425052,2425053,2425054,2425021,2425022,2425023,2425023,2425024,2425024,2425025,2425025,2425026,2425031,2425036,2425036,2425050,2425051,2425052,2425053,2425054,2425022,2425023,2425023,2425024,2425024,2425026,2425028,2425053,2425055,2425023,2425024,2425024,2425025,2425025,2425026,2425026,2425029,2425031,2425031,2425032,2425033,2425037,2425046,2425051,2425052,2425055,2427285,2425024,2425025,2425025,2425026,2425046,2425050,2425051,2425053,2425339,2425025,2425026,2425026,2425027,2425028,2425028,2425029,2425033,2425041,2425043,2425050,2425053,2425055,2425056,2425056,2425026,2425027,2425027,2425028,2425028,2425034,2425037,2425040,2425041,2425050,2425055,2425056,2425027,2425028,2425028,2425029,2425039,2425039,2425040,2425054,2425055,2425057,2425057,2425028,2425029,2425029,2425030,2425032,2425033,2425039,2425040,2425042,2425045,2425048,2425053,2425055,2425055,2425057,2425058,2425029,2425035,2425057,2425058,2425058,2425030,2425031,2425031,2425032,2425032,2425033,2425034,2425034,2425036,2425036,2425037,2425037,2425039,2425040,2425040,2425041,2425042,2425043,2425046,2425047,2425047,2425049,2425050,2425051,2425052,2425053,2425053,2425054,2425056,2425056,2425057,2425057,2425058,2425058,2425059,2425031,2425032,2425033,2425035,2425036,2425037,2425039,2425041,2425042,2425043,2425043,2425047,2425047,2425048,2425050,2425051,2425051,2425052,2425053,2425054,2425055,2425055,2425056,2425057,2425057,2425058,2425059,2425059,2425388,2425037,2425041,2425045,2425050,2425054,2425059,2425060,2425042,2425051,2425057,2425059,2425043,2425058,2425038,2425054,2425055,2425061,2425038,2425039,2425058,2425060,2425061,2425062,2425059,2425063,2425045,2425061,2425062,2425063,2425063,2425045,2425052,2425058,2425046,2425054,2425056,2425063,2425064,2425043,2425046,2425047,2425061,2425062,2425063,2425064,2425064,2425060,2425062,2425065,2425046,2425047,2425061,2425062,2425063,2425060,2425065,2425066,2425055,2425064,2425066,2425051,2425051,2425060,2425051,2425055,2425064,2425066,2425066,2425068,2425069,2425069,2425054,2425055,2425056,2425060,2425061,2425063,2425065,2425067,2425067,2425068,2425069,2425070,2425066,2425067,2425070,2425055,2425055,2425056,2425062,2425064,2425065,2425067,2425068,2425070,2425070,2425071,2425071,2425063,2425068,2425069,2425070,2425071,2425072,2425063,2425070,2425071,2425072,2425073,2425062,2425065,2425068,2425072,2425073,2425073,2425074,2425072,2425073,2425074,2425075,2425069,2425071,2425072,2425073,2425074,2425075,2425067,2425074,2425075,2425076,2425076,2425067,2425072,2425072,2425077,2425070,2425078,2425075,2425076,2425077,2425077,2425078,2425071,2425073,2425076,2425077,2425078,2425079,2425071,2425072,2425079,2425079,2425074,2425077,2425078,2425080,2425073,2425076,2425078,2425080,2425080,2425074,2425077,2425077,2425078,2425079,2425080,2425081,2425078,2425081,2425077,2425078,2425078,2425079,2425080,2425080,2425081,2425081,2425082,2425079,2425080,2425081,2425082,2425079,2425081,2425082,2425082,2425083,2425079,2425080,2425081,2425081,2425082,2425083,2425081,2425081,2425082,2425083,2425083,2425084,2425081,2425082,2425083,2425084,2425084,2425082,2425083,2425083,2425084,2425084,2425085,2425083,2425084,2425084,2425085,2425085,2425084,2425085,2425085,2425086,2425085,2425086,2425086,2425086,2425087,2425087,2425088,2425089,2425132,2425370,2425371,2425417,2425424,2427318,2427332,2427372,2425089,2425095,2425133,2425371,2425371,2425372,2425378,2425415,2425653,2425654,2425655,2425655,2425656,2425656,2425657,2425658,2425659,2425661,2425664,2425664,2425665,2425666,2425667,2425669,2425675,2425676,2425676,2425678,2425685,2425686,2425687,2425689,2425694,2425695,2425696,2425697,2425698,2425698,2425699,2425699,2425700,2425655,2425656,2425656,2425657,2425657,2425658,2425660,2425662,2425664,2425675,2425688,2425690,2425693,2425697,2425698,2425699,2425699,2425700,2425700,2425666,2425690,2425700,2425700,2425659,2425701,2425663,2425701,2425702,2425664,2425701,2425702,2425702,2425702,2425663,2425702,2425703,2425663,2425665,2425703,2425704,2425704,2425704,2425705,2425705,2425705,2425679,2425706,2425707,2425707,2425674,2425675,2425687,2425709,2425675,2425676,2425676,2425710,2425711,2425711,2425712,2425712,2425712,2425713,2425690,2425716,2425720,2425721,2425721,2425722,2425722,2425723,2425724,2425729,2425732,2425732,2425733,2425734,2425735,2425738,2425739,2425740,2425741,2425741,2425742,2425743,2425742,2425743,2425743,2425743,2425744,2425744,2425744,2425745,2425745,2425746,2425747,2425747,2425748,2425748,2425749,2425749,2425750,2425750,2425751,2425751,2425752,2425752,2425753,2425753,2425754,2425755,2425758,2425759,2425760,2425762,2425775,2425775,2425776,2425747,2425748,2425748,2425749,2425749,2425750,2425751,2425753,2425748,2425749,2425749,2425750,2425750,2425752,2425753,2425756,2425749,2425750,2425750,2425751,2425752,2425756,2425750,2425751,2425751,2425754,2425751,2425752,2425752,2425753,2425757,2425752,2425753,2425753,2425754,2425754,2425755,2425776,2425778,2425753,2425754,2425754,2425755,2425755,2425756,2425756,2425757,2425758,2425759,2425759,2425761,2425767,2425768,2425770,2425773,2425775,2425776,2425777,2425779,2425754,2425755,2425755,2425759,2425755,2425756,2425756,2425757,2425757,2425758,2425758,2425759,2425759,2425760,2425760,2425761,2425762,2425762,2425763,2425763,2425764,2425771,2425771,2425772,2425774,2425775,2425776,2425776,2425777,2425778,2425778,2425756,2425757,2425757,2425758,2425758,2425759,2425760,2425773,2425778,2425757,2425758,2425758,2425759,2425759,2425760,2425760,2425761,2425761,2425762,2425763,2425764,2425770,2425772,2425772,2425773,2425775,2425776,2425777,2425777,2425778,2425779,2425779,2425780,2425780,2425781,2425758,2425759,2425759,2425760,2425761,2425762,2425762,2425763,2425764,2425764,2425771,2425773,2425775,2425777,2425759,2425760,2425760,2425761,2425761,2425762,2425762,2425763,2425764,2425764,2425765,2425765,2425766,2425769,2425770,2425771,2425773,2425773,2425774,2425775,2425777,2425781,2425760,2425761,2425761,2425762,2425762,2425763,2425763,2425764,2425764,2425765,2425766,2425767,2425768,2425769,2425771,2425772,2425773,2425774,2425775,2425776,2425776,2425777,2425778,2425779,2425779,2425782,2425782,2425761,2425762,2425762,2425763,2425763,2425764,2425764,2425765,2425765,2425766,2425766,2425767,2425767,2425768,2425768,2425769,2425769,2425770,2425771,2425771,2425772,2425774,2425774,2425775,2425775,2425776,2425777,2425778,2425778,2425779,2425779,2425781,2425782,2425783,2425762,2425763,2425763,2425764,2425764,2425766,2425774,2425775,2425778,2425763,2425764,2425764,2425765,2425765,2425766,2425766,2425767,2425767,2425768,2425769,2425769,2425773,2425775,2425775,2425776,2425776,2425777,2425778,2425780,2425781,2425784,2425764,2425765,2425765,2425766,2425766,2425767,2425767,2425768,2425768,2425769,2425771,2425771,2425772,2425774,2425775,2425776,2425777,2425778,2425779,2425780,2425765,2425766,2425766,2425767,2425767,2425768,2425768,2425769,2425770,2425771,2425772,2425774,2425774,2425776,2425776,2425777,2425778,2425781,2425782,2425784,2425785,2425766,2425767,2425767,2425768,2425768,2425769,2425770,2425770,2425771,2425772,2425774,2425776,2425778,2425780,2425781,2425785,2425768,2425768,2425769,2425769,2425770,2425771,2425771,2425772,2425774,2425775,2425775,2425777,2425777,2425779,2425780,2425782,2425768,2425769,2425772,2425776,2425779,2425782,2425786,2425769,2425770,2425770,2425771,2425771,2425772,2425773,2425773,2425774,2425775,2425776,2425776,2425778,2425778,2425779,2425779,2425782,2425783,2425783,2425784,2425785,2425786,2425770,2425771,2425771,2425772,2425772,2425773,2425773,2425774,2425775,2425776,2425777,2425777,2425778,2425778,2425779,2425779,2425780,2425780,2425781,2425782,2425782,2425783,2425784,2425784,2425785,2425785,2425787,2425771,2425772,2425773,2425773,2425774,2425774,2425775,2425776,2425776,2425777,2425777,2425778,2425779,2425779,2425780,2425781,2425782,2425783,2425785,2425787,2425788,2425772,2425773,2425774,2425774,2425775,2425775,2425776,2425777,2425777,2425778,2425779,2425780,2425781,2425782,2425783,2425785,2425786,2425787,2425788,2425773,2425774,2425778,2425778,2425780,2425783,2425786,2425788,2425774,2425775,2425775,2425777,2425777,2425779,2425780,2425781,2425781,2425782,2425783,2425784,2425786,2425787,2425775,2425776,2425778,2425779,2425781,2425786,2425789,2425776,2425778,2425778,2425779,2425779,2425780,2425781,2425781,2425782,2425782,2425786,2425778,2425779,2425779,2425780,2425782,2425782,2425783,2425785,2425786,2425787,2425789,2425779,2425780,2425781,2425782,2425783,2425783,2425784,2425791,2425781,2425783,2425783,2425784,2425789,2425780,2425782,2425783,2425785,2425788,2425788,2425781,2425782,2425782,2425784,2425784,2425785,2425786,2425787,2425789,2425782,2425783,2425784,2425785,2425785,2425786,2425792,2425792,2425793,2425793,2425783,2425784,2425785,2425785,2425786,2425787,2425788,2425789,2425784,2425785,2425785,2425786,2425786,2425787,2425787,2425788,2425789,2425789,2425790,2425791,2425791,2425792,2425792,2425794,2425794,2425785,2425786,2425788,2425789,2425786,2425787,2425787,2425788,2425788,2425791,2425787,2425788,2425788,2425789,2425790,2425790,2425791,2425791,2425792,2425792,2425793,2425794,2425794,2425795,2425795,2425796,2425788,2425789,2425789,2425790,2425791,2425792,2425792,2425793,2425793,2425794,2425796,2425796,2425789,2425790,2425791,2425791,2425792,2425793,2425793,2425794,2425794,2425795,2425796,2425796,2425790,2425791,2425791,2425792,2425792,2425793,2425793,2425794,2425794,2425795,2425796,2425792,2425792,2425793,2425793,2425794,2425794,2425795,2425796,2425796,2425797,2425798,2425792,2425793,2425795,2425793,2425794,2425794,2425795,2425795,2425796,2425797,2425797,2425798,2425798,2425799,2425794,2425795,2425796,2425799,2425795,2425796,2425796,2425797,2425797,2425798,2425799,2425799,2425800,2425796,2425797,2425798,2425799,2425800,2425797,2425798,2425798,2425799,2425799,2425800,2425800,2425801,2425798,2425799,2425799,2425800,2425800,2425801,2425801,2425799,2425800,2425800,2425801,2425801,2425802,2425800,2425801,2425801,2425802,2425802,2425801,2425802,2425802,2425803,2425802,2425803,2425803,2425803,2425804,2425804,2425850,2425805,2425806,2425807,2425807,2425808,2425809,2425813,2425814,2425814,2425815,2425816,2425817,2425819,2425819,2425820,2425821,2425821,2425826,2425829,2425831,2425834,2425836,2425837,2425839,2425839,2425842,2425848,2425848,2425849,2425850,2425850,2425851,2427676,2427691,2427758,25895065,2425806,2425807,2425807,2425808,2425808,2425809,2425809,2425810,2425810,2425811,2425812,2425812,2425813,2425813,2425814,2425814,2425815,2425815,2425817,2425818,2425818,2425819,2425820,2425820,2425821,2425822,2425823,2425823,2425824,2425825,2425826,2425826,2425827,2425827,2425829,2425829,2425833,2425834,2425835,2425837,2425839,2425839,2425840,2425840,2425841,2425841,2425842,2425843,2425844,2425845,2425846,2425847,2425847,2425848,2425848,2425849,2425850,2425850,2425851,2425851,2427759,2425807,2425808,2425809,2425810,2425811,2425814,2425815,2425816,2425820,2425823,2425826,2425835,2425843,2425848,2425852,2425809,2425809,2425815,2425818,2425829,2425836,2425838,2425851,2425852,2425812,2425815,2425840,2425852,2425853,2425811,2425811,2425812,2425813,2425816,2425817,2425820,2425827,2425853,2425811,2425812,2425825,2425812,2425813,2425814,2425815,2425817,2425817,2425820,2425825,2425826,2425854,2425814,2425814,2425816,2425817,2425818,2425819,2425821,2425826,2425827,2425843,2425846,2425848,2425851,2425852,2425854,2425854,2425855,2425852,2425816,2425817,2425817,2425818,2425819,2425822,2425822,2425823,2425825,2425827,2425819,2425843,2425845,2425856,2425818,2425819,2425821,2425820,2425819,2425820,2425849,2425821,2425821,2425829,2425858,2425855,2425822,2425823,2425823,2425824,2425824,2425825,2425825,2425826,2425827,2425828,2425829,2425829,2425831,2425843,2425856,2425858,2425859,2425823,2425824,2425824,2425827,2425828,2425829,2425829,2425830,2425831,2425843,2425850,2425855,2425857,2425858,2425860,2425824,2425825,2425825,2425826,2425826,2425827,2425827,2425828,2425829,2425830,2425832,2425840,2425856,2425856,2425858,2425859,2425860,2425860,2425826,2425827,2425827,2425830,2425832,2425857,2425861,2425826,2425828,2425829,2425830,2425861,2427687,2425828,2425836,2425861,2425862,2425828,2425831,2425829,2425831,2425833,2425834,2425838,2425851,2425862,2425831,2425832,2425833,2425833,2425835,2425846,2425847,2425861,2425861,2425863,2425832,2425833,2425835,2425851,2425834,2425834,2425835,2425836,2425840,2425844,2425864,2425865,2425835,2425837,2425851,2425865,2425865,2427745,2425835,2425836,2425836,2425837,2425865,2425865,2425866,2425836,2425838,2425838,2425839,2425865,2425866,2425866,2425838,2425838,2425839,2425840,2425847,2425851,2425855,2425864,2425866,2425867,2425849,2425851,2427693,2425839,2425857,2425868,2425840,2425841,2425842,2425842,2425843,2425844,2425846,2425850,2425851,2425852,2425852,2425853,2425857,2425860,2425864,2425864,2425865,2425865,2425866,2425866,2425867,2425867,2425868,2425868,2425843,2425853,2425866,2425866,2425869,2425843,2425845,2425852,2425868,2425869,2425869,2425844,2425846,2425855,2425870,2425847,2425855,2425866,2425871,2425847,2425870,2425871,2425848,2425870,2425872,2425854,2425872,2425872,2425850,2425851,2425857,2425858,2425871,2425872,2425873,2425854,2425854,2425871,2425854,2425855,2425875,2425856,2425857,2425874,2425876,2425857,2425876,2425859,2425860,2425862,2425871,2425877,2425861,2425869,2425874,2425875,2425878,2425863,2425865,2425875,2425877,2425879,2425879,2425880,2425868,2425876,2425877,2425880,2425880,2425869,2425878,2425879,2425880,2425881,2425866,2425868,2425869,2425882,2425869,2425878,2425879,2425880,2425882,2425870,2425883,2425871,2425883,2425875,2425882,2425883,2425872,2425875,2425884,2425873,2425874,2425874,2425876,2425884,2425885,2425874,2425875,2425875,2425885,2425885,2425876,2425882,2425885,2425885,2425886,2425878,2425886,2425885,2425886,2425887,2425883,2425887,2425880,2425884,2425881,2425884,2425887,2425888,2425888,2425882,2425889,2425882,2425889,2425883,2425886,2425886,2425886,2425887,2425890,2425888,2425889,2425888,2425890,2425891,2425891,2425892,2425892,2425889,2425890,2425891,2425892,2425892,2425893,2425890,2425891,2425891,2425892,2425893,2425893,2425891,2425892,2425893,2425893,2425894,2425892,2425893,2425893,2425894,2425894,2425894,2425894,2425895,2425894,2425895,2425895,2425895,2425896,2425896,2425897,2427722,2427722,2427736,2427737,2427762,2427772,2427774,2427775,2427777,2427804,2428077,2427723,2429547,2429548,2429549,2429549,2429550,2429550,2429551,2429551,2429552,2429552,2429553,2429553,2429554,2429558,2429559,2429560,2429561,2429561,2429562,2429562,2429597,2429598,2429599,2429602,2429603,2429603,2429605,2429623,2429549,2429550,2429550,2429551,2429552,2429553,2429556,2429561,2429561,2429562,2429562,2429563,2429561,2429562,2429562,2429563,2429563,2429562,2429563,2429563,2429564,2429554,2429555,2429556,2429562,2429563,2429563,2429564,2429554,2429563,2429564,2429564,2429565,2429565,2429566,2429565,2429566,2429566,2429565,2429566,2429567,2429567,2429566,2429568,2429570,2429572,2429573,2429574,2429574,2429574,2429575,2429575,2429576,2429576,2429621,2429577,2429578,2429578,2429579,2429579,2429581,2429581,2429582,2429583,2429583,2429584,2429584,2429585,2429585,2429586,2429586,2429587,2429588,2429589,2429589,2429590,2429590,2429591,2429591,2429592,2429592,2429593,2429594,2429594,2429595,2429595,2429597,2429597,2429598,2429599,2429599,2429600,2429601,2429601,2429602,2429602,2429603,2429603,2429604,2429605,2429606,2429606,2429607,2429607,2429608,2429608,2429609,2429609,2429611,2429611,2429612,2429612,2429613,2429613,2429614,2429615,2429615,2429616,2429617,2429621,2429635,2429636,2429637,2429638,2429578,2429579,2429579,2429580,2429580,2429582,2429582,2429583,2429583,2429584,2429584,2429586,2429589,2429589,2429590,2429592,2429593,2429594,2429595,2429595,2429596,2429597,2429598,2429599,2429599,2429601,2429601,2429602,2429603,2429605,2429606,2429607,2429611,2429611,2429612,2429612,2429613,2429617,2429579,2429580,2429590,2429595,2429600,2429601,2429602,2429603,2429605,2429607,2429609,2429612,2429613,2429581,2429590,2429593,2429602,2429602,2429612,2429614,2429581,2429596,2429599,2429600,2429602,2429604,2429607,2429610,2429582,2429583,2429583,2429584,2429585,2429586,2429586,2429589,2429591,2429592,2429592,2429596,2429597,2429598,2429600,2429601,2429601,2429602,2429602,2429603,2429603,2429604,2429605,2429605,2429606,2429607,2429607,2429608,2429613,2429614,2429614,2429615,2429618,2429619,2429591,2429600,2429603,2429605,2429592,2429600,2429602,2429594,2429600,2429607,2429612,2429605,2429589,2429616,2429603,2429606,2429612,2429600,2429604,2429605,2429611,2429593,2429597,2429598,2429603,2429605,2429606,2429607,2429613,2429618,2429624,2429605,2429612,2429606,2429610,2429607,2429609,2429617,2429620,2429598,2429621,2429604,2429610,2429610,2429621,2429621,2429625,2429604,2429611,2429611,2429612,2429616,2429621,2429603,2429609,2429612,2429613,2429618,2429623,2429624,2429605,2429614,2429615,2429624,2429605,2429606,2429611,2429613,2429615,2429623,2429620,2429615,2429628,2429608,2429613,2429620,2429625,2429613,2429616,2429616,2429633,2429614,2429616,2429617,2429618,2429619,2429622,2429628,2429613,2429614,2429615,2429617,2429634,2429612,2429613,2429615,2429624,2429629,2429630,2429618,2429619,2429620,2429629,2429630,2429619,2429620,2429621,2429630,2429617,2429619,2429620,2429623,2429630,2429631,2429620,2429631,2429630,2429618,2429619,2429621,2429621,2429622,2429623,2429626,2429627,2429630,2429631,2429632,2429632,2429634,2429619,2429622,2429620,2429621,2429622,2429622,2429623,2429624,2429626,2429627,2429629,2429632,2429633,2429633,2429635,2429637,2429638,2429638,2429639,2429639,2429622,2429623,2429623,2429624,2429625,2429625,2429626,2429626,2429628,2429631,2429634,2429627,2429634,2429644,2429624,2429627,2429634,2429624,2429625,2429625,2429626,2429626,2429628,2429629,2429631,2429632,2429635,2429635,2429636,2429637,2429638,2429639,2429640,2429661,2429625,2429626,2429626,2429627,2429628,2429630,2429630,2429631,2429632,2429633,2429635,2429635,2429636,2429637,2429637,2429638,2429640,2429626,2429627,2429627,2429629,2429632,2429634,2429635,2429636,2429636,2429637,2429638,2429627,2429629,2429631,2429633,2429637,2429628,2429629,2429630,2429630,2429631,2429632,2429634,2429634,2429635,2429636,2429637,2429637,2429638,2429639,2429639,2429641,2429641,2429630,2429634,2429635,2429637,2429638,2429650,2429638,2429638,2429636,2429638,2429639,2429632,2429633,2429635,2429635,2429637,2429637,2429638,2429639,2429639,2429640,2429641,2429634,2429636,2429638,2429639,2429640,2429642,2429640,2429635,2429636,2429637,2429637,2429639,2429639,2429640,2429640,2429641,2429642,2429642,2429643,2429636,2429638,2429638,2429640,2429641,2429641,2429646,2429641,2429644,2429639,2429642,2429642,2429643,2429639,2429640,2429641,2429642,2429643,2429644,2429641,2429642,2429643,2429643,2429652,2429661,2429641,2429643,2429643,2429644,2429644,2429644,2429644,2429644,2429645,2429645,2429645,2429646,2429649,2429646,2429647,2429647,2429648,2429648,2429649,2429650,2429650,2429651,2429651,2429652,2429647,2429648,2429648,2429649,2429649,2429650,2429650,2429651,2429651,2429652,2429652,2429653,2429654,2429656,2429656,2429661,2429672,2429673,2429648,2429649,2429649,2429652,2429649,2429650,2429651,2429651,2429652,2429652,2429653,2429653,2429654,2429654,2429665,2429667,2429673,2429674,2429650,2429651,2429651,2429652,2429652,2429653,2429653,2429654,2429654,2429655,2429656,2429657,2429658,2429669,2429672,2429673,2429674,2429674,2429651,2429652,2429652,2429653,2429653,2429654,2429654,2429655,2429655,2429659,2429659,2429660,2429669,2429671,2429674,2429675,2429652,2429653,2429653,2429654,2429654,2429655,2429653,2429654,2429654,2429655,2429655,2429656,2429657,2429675,2429654,2429655,2429655,2429656,2429656,2429657,2429658,2429659,2429668,2429672,2429676,2429655,2429656,2429656,2429657,2429657,2429659,2429660,2429677,2429656,2429657,2429657,2429658,2429658,2429659,2429660,2429661,2429663,2429663,2429664,2429666,2429670,2429670,2429671,2429672,2429675,2429676,2429677,2429657,2429658,2429658,2429659,2429659,2429660,2429660,2429661,2429661,2429662,2429663,2429663,2429664,2429667,2429668,2429669,2429671,2429673,2429675,2429675,2429676,2429676,2429677,2429677,2429678,2429658,2429659,2429659,2429660,2429661,2429661,2429662,2429662,2429663,2429663,2429664,2429664,2429666,2429667,2429668,2429668,2429670,2429671,2429672,2429672,2429673,2429673,2429675,2429676,2429677,2429677,2429678,2429678,2429659,2429660,2429660,2429661,2429661,2429662,2429662,2429663,2429663,2429664,2429664,2429665,2429667,2429668,2429669,2429669,2429670,2429671,2429671,2429672,2429673,2429674,2429674,2429675,2429676,2429677,2429677,2429678,2429678,2429679,2429660,2429661,2429661,2429662,2429662,2429663,2429663,2429664,2429665,2429665,2429668,2429669,2429671,2429672,2429674,2429675,2429675,2429676,2429676,2429677,2429678,2429678,2429679,2429679,2429661,2429662,2429662,2429663,2429663,2429664,2429664,2429665,2429669,2429670,2429675,2429676,2429677,2429679,2429679,2429680,2429663,2429663,2429664,2429664,2429665,2429666,2429666,2429667,2429668,2429669,2429670,2429670,2429672,2429672,2429673,2429673,2429677,2429678,2429678,2429679,2429679,2429680,2429680,2429665,2429671,2429676,2429681,2429664,2429666,2429667,2429667,2429673,2429674,2429675,2429676,2429676,2429677,2429679,2429681,2429681,2429665,2429666,2429666,2429667,2429667,2429668,2429668,2429669,2429670,2429671,2429671,2429672,2429674,2429674,2429675,2429676,2429677,2429677,2429678,2429679,2429679,2429680,2429680,2429681,2429681,2429682,2429666,2429668,2429668,2429670,2429670,2429672,2429672,2429673,2429674,2429674,2429675,2429675,2429677,2429679,2429680,2429681,2429681,2429682,2429682,2429667,2429668,2429671,2429672,2429673,2429673,2429674,2429675,2429675,2429676,2429678,2429678,2429679,2429680,2429680,2429681,2429681,2429682,2429682,2429683,2429669,2429669,2429673,2429675,2429676,2429678,2429679,2429681,2429669,2429670,2429672,2429675,2429677,2429678,2429681,2429681,2429683,2429684,2429670,2429671,2429672,2429673,2429674,2429675,2429676,2429679,2429679,2429682,2429683,2429683,2429684,2429684,2429671,2429672,2429672,2429673,2429674,2429675,2429676,2429678,2429680,2429680,2429681,2429681,2429683,2429684,2429684,2429685,2429676,2429677,2429681,2429683,2429684,2429684,2429685,2429685,2429677,2429678,2429677,2429682,2429685,2429686,2429677,2429678,2429683,2429684,2429686,2429687,2429678,2429679,2429680,2429680,2429685,2429685,2429686,2429687,2429687,2429682,2429679,2429680,2429682,2429683,2429683,2429684,2429685,2429687,2429688,2429688,2429681,2429682,2429684,2429685,2429686,2429687,2429688,2429688,2429689,2429681,2429683,2429686,2429687,2429688,2429689,2429689,2429683,2429682,2429683,2429684,2429685,2429688,2429689,2429689,2429690,2429690,2429683,2429684,2429684,2429685,2429686,2429686,2429687,2429688,2429689,2429690,2429690,2429691,2429684,2429685,2429685,2429686,2429687,2429688,2429689,2429689,2429690,2429691,2429691,2429689,2429691,2429691,2429692,2429686,2429687,2429689,2429690,2429692,2429692,2429687,2429689,2429690,2429692,2429692,2429693,2429688,2429692,2429693,2429689,2429690,2429691,2429691,2429692,2429692,2429693,2429693,2429694,2429691,2429692,2429692,2429693,2429693,2429694,2429694,2429692,2429693,2429694,2429695,2429692,2429693,2429694,2429695,2429695,2429693,2429694,2429695,2429696,2429694,2429695,2429695,2429696,2429696,2429695,2429696,2429696,2429697,2429711,2429696,2429697,2429697,2429697,2429698,2429698,2429699,2429700,2429700,2429701,2429701,2429702,2429702,2429703,2429705,2429713,2429749,2429700,2429701,2429701,2429702,2429702,2429703,2429704,2429705,2429706,2429702,2429706,2429750,2429702,2429707,2429704,2429707,2429707,2429705,2429708,2429708,2429709,2429710,2429711,2429712,2429713,2429713,2429714,2429714,2429715,2429716,2429716,2429717,2429717,2429718,2429718,2429719,2429719,2429720,2429720,2429721,2429722,2429722,2429723,2429723,2429755,2429756,2429762,2429766,2429713,2429714,2429714,2429715,2429716,2429716,2429717,2429717,2429718,2429718,2429719,2429719,2429720,2429720,2429723,2429714,2429717,2429717,2429718,2429719,2429720,2429720,2429715,2429717,2429718,2429719,2429719,2429720,2429720,2429721,2429721,2429724,2429718,2429720,2429721,2429721,2429722,2429723,2429725,2429718,2429720,2429722,2429719,2429721,2429722,2429723,2429720,2429721,2429721,2429722,2429722,2429723,2429723,2429724,2429721,2429722,2429724,2429724,2429722,2429723,2429724,2429724,2429725,2429723,2429724,2429724,2429725,2429725,2429724,2429725,2429725,2429726,2429725,2429726,2429726,2429726,2429727,2429727,2429730,2429763,2429728,2429729,2429729,2429730,2429730,2429731,2429731,2429732,2429735,2429740,2429743,2429743,2429746,2429746,2429747,2429747,2429750,2429752,2429753,2429755,2429755,2429758,2429759,2429760,2429760,2429761,2429761,2429762,2429762,2429763,2429763,2429764,2429993,25897026,2429730,2429731,2429733,2429761,2429763,2429763,2429764,2429733,2429757,2429764,2429731,2429732,2429732,2429765,2429732,2429733,2429765,2429733,2429734,2429750,2429734,2429755,2429766,2429766,2429767,2429735,2429767,2429737,2429744,2429747,2429761,2429764,2429765,2429766,2429767,2429767,2429768,2430038,2429768,2429769,2429769,2429775,2429776,2429776,2429778,2429778,2429779,2429781,2429782,2429782,2429782,2429783,2429786,2429777,2429780,2429787,2429788,2429789,2429790,2429790,2429791,2429791,2429793,2429794,2429794,2429795,2429795,2429795,2429796,2429796,2429797,2429797,2429797,2429798,2429798,2429799,2429799,2429831,2429800,2429801,2429801,2429802,2429802,2429803,2429803,2429804,2429804,2429805,2429805,2429806,2429806,2429807,2429810,2429810,2429811,2429811,2429812,2429812,2429814,2429817,2429819,2429826,2429829,2429831,2429831,2429833,2429875,2429801,2429802,2429802,2429803,2429803,2429804,2429804,2429805,2429805,2429806,2429806,2429807,2429808,2429811,2429831,2429802,2429803,2429803,2429804,2429805,2429805,2429806,2429806,2429807,2429807,2429819,2429803,2429804,2429804,2429805,2429805,2429806,2429806,2429807,2429807,2429808,2429809,2429812,2429819,2429804,2429805,2429805,2429806,2429806,2429807,2429807,2429808,2429808,2429805,2429806,2429806,2429807,2429807,2429808,2429813,2429806,2429807,2429807,2429808,2429808,2429809,2429807,2429808,2429808,2429809,2429809,2429811,2429808,2429809,2429809,2429810,2429810,2429811,2429814,2429820,2429809,2429810,2429810,2429811,2429811,2429812,2429814,2429814,2429818,2429819,2429836,2429810,2429811,2429811,2429812,2429814,2429815,2429815,2429816,2429817,2429819,2429820,2429811,2429812,2429813,2429813,2429814,2429815,2429815,2429816,2429818,2429819,2429819,2429820,2429823,2429823,2429824,2429832,2429834,2429837,2429812,2429813,2429813,2429814,2429815,2429816,2429816,2429817,2429818,2429819,2429819,2429820,2429820,2429821,2429822,2429823,2429825,2429837,2429813,2429814,2429814,2429815,2429815,2429816,2429816,2429817,2429817,2429818,2429818,2429819,2429819,2429820,2429820,2429821,2429821,2429822,2429823,2429823,2429824,2429824,2429825,2429826,2429826,2429828,2429832,2429833,2429835,2429838,2429814,2429816,2429817,2429815,2429816,2429816,2429817,2429817,2429818,2429818,2429819,2429819,2429820,2429820,2429821,2429821,2429822,2429822,2429823,2429823,2429824,2429824,2429825,2429825,2429826,2429826,2429827,2429828,2429834,2429836,2429839,2429816,2429817,2429818,2429818,2429821,2429822,2429822,2429823,2429827,2429817,2429818,2429818,2429819,2429819,2429822,2429830,2429835,2429818,2429819,2429820,2429820,2429821,2429823,2429823,2429824,2429835,2429838,2429819,2429820,2429820,2429821,2429821,2429822,2429822,2429823,2429823,2429824,2429826,2429826,2429827,2429828,2429828,2429833,2429836,2429838,2429838,2429820,2429821,2429821,2429822,2429822,2429823,2429823,2429824,2429824,2429825,2429825,2429826,2429826,2429827,2429827,2429828,2429828,2429829,2429834,2429836,2429840,2429841,2429821,2429822,2429822,2429823,2429823,2429824,2429824,2429825,2429825,2429826,2429827,2429827,2429828,2429828,2429829,2429830,2429833,2429834,2429835,2429837,2429841,2429842,2429822,2429823,2429823,2429824,2429824,2429825,2429825,2429826,2429826,2429827,2429828,2429828,2429829,2429830,2429832,2429833,2429835,2429837,2429839,2429840,2429841,2429842,2429842,2429823,2429824,2429824,2429825,2429825,2429826,2429826,2429827,2429827,2429828,2429829,2429830,2429835,2429838,2429839,2429840,2429840,2429843,2429824,2429825,2429825,2429826,2429826,2429827,2429827,2429828,2429828,2429829,2429829,2429831,2429833,2429838,2429841,2429843,2429825,2429826,2429826,2429827,2429827,2429828,2429829,2429829,2429830,2429830,2429831,2429831,2429832,2429832,2429833,2429836,2429839,2429826,2429827,2429827,2429828,2429828,2429830,2429832,2429842,2429827,2429828,2429828,2429829,2429830,2429830,2429831,2429831,2429832,2429834,2429834,2429835,2429837,2429840,2429842,2429828,2429829,2429829,2429830,2429830,2429831,2429831,2429832,2429832,2429833,2429835,2429838,2429840,2429840,2429843,2429845,2429829,2429830,2429830,2429831,2429831,2429832,2429832,2429833,2429833,2429834,2429834,2429838,2429841,2429841,2429842,2429843,2429843,2429846,2429830,2429831,2429831,2429832,2429832,2429833,2429833,2429834,2429834,2429835,2429836,2429838,2429839,2429839,2429841,2429844,2429846,2429831,2429832,2429832,2429833,2429833,2429834,2429834,2429835,2429835,2429836,2429839,2429842,2429844,2429845,2429847,2429832,2429833,2429833,2429834,2429834,2429835,2429835,2429840,2429842,2429844,2429845,2429833,2429834,2429834,2429835,2429835,2429836,2429837,2429837,2429838,2429840,2429843,2429844,2429845,2429847,2429848,2429834,2429835,2429835,2429836,2429838,2429838,2429840,2429843,2429845,2429846,2429848,2429835,2429836,2429836,2429837,2429837,2429838,2429839,2429840,2429840,2429841,2429843,2429844,2429844,2429845,2429846,2429846,2429847,2429848,2429849,2429836,2429837,2429837,2429838,2429839,2429839,2429840,2429842,2429844,2429846,2429847,2429848,2429849,2429849,2429837,2429838,2429838,2429839,2429839,2429840,2429841,2429842,2429842,2429843,2429844,2429845,2429845,2429846,2429847,2429849,2429850,2429838,2429839,2429840,2429840,2429841,2429842,2429843,2429843,2429844,2429845,2429845,2429848,2429850,2429839,2429840,2429841,2429841,2429843,2429844,2429845,2429845,2429846,2429848,2429850,2429851,2429841,2429843,2429844,2429846,2429847,2429848,2429849,2429851,2429845,2429847,2429849,2429842,2429844,2429846,2429847,2429849,2429850,2429845,2429845,2429846,2429847,2429848,2429850,2429850,2429852,2429848,2429849,2429850,2429851,2429849,2429847,2429848,2429850,2429851,2429852,2429853,2429854,2429855,2429848,2429849,2429850,2429852,2429852,2429855,2429850,2429851,2429853,2429851,2429852,2429851,2429852,2429857,2429852,2429854,2429854,2429855,2429857,2429853,2429854,2429854,2429855,2429855,2429856,2429857,2429857,2429858,2429855,2429856,2429855,2429856,2429856,2429856,2429857,2429857,2429858,2429859,2429859,2429857,2429858,2429859,2429859,2429860,2429858,2429859,2429859,2429860,2429860,2429859,2429860,2429860,2429861,2429860,2429861,2429861,2429861,2429862,2429862,2429863,2429864,2429864,2429865,2429867,2429867,2429868,2429869,2429869,2429871,2429871,2429872,2429872,2429873,2429873,2429874,2429875,2429876,2429876,2429877,2429878,2429879,2429886,2429891,2429896,2429896,2429898,2429901,2429902,2429903,2429904,2429905,2429905,2429906,2429907,2430060,2430100,2430120,2429864,2429865,2429865,2429866,2429866,2429867,2429867,2429868,2429868,2429869,2429869,2429870,2429870,2429871,2429871,2429872,2429872,2429873,2429874,2429874,2429875,2429875,2429876,2429876,2429877,2429877,2429878,2429878,2429879,2429882,2429883,2429885,2429890,2429891,2429893,2429893,2429900,2429901,2429902,2429903,2429905,2429905,2429906,2429907,2429907,2430101,2429865,2429866,2429866,2429867,2429867,2429868,2429868,2429869,2429869,2429870,2429870,2429871,2429872,2429872,2429873,2429874,2429874,2429875,2429876,2429876,2429877,2429877,2429878,2429878,2429879,2429879,2429884,2429885,2429892,2429893,2429894,2429896,2429897,2429902,2429903,2429904,2429905,2429905,2429906,2429906,2429907,2429907,2429908,2430061,2430101,2429866,2429867,2429868,2429868,2429869,2429870,2429870,2429871,2429872,2429873,2429873,2429874,2429875,2429875,2429877,2429878,2429878,2429879,2429879,2429881,2429891,2429897,2429904,2429906,2429906,2429907,2429908,2430102,2429867,2429869,2429869,2429870,2429871,2429871,2429873,2429874,2429875,2429878,2429878,2429879,2429881,2429883,2429893,2429906,2429907,2429909,2429868,2429870,2429871,2429871,2429873,2429876,2429887,2429909,2429870,2429872,2429873,2429880,2429906,2429870,2429871,2429871,2429873,2429875,2429879,2429879,2429871,2429872,2429873,2429876,2429877,2429881,2429881,2429883,2429900,2429906,2429911,2429872,2429873,2429873,2429874,2429874,2429875,2429875,2429876,2429876,2429877,2429877,2429878,2429878,2429879,2429879,2429880,2429881,2429882,2429895,2429896,2429908,2429909,2429909,2429910,2429911,2429911,2430065,2429873,2429874,2429875,2429878,2429910,2429912,2429874,2429876,2429877,2429878,2429879,2429880,2429882,2429883,2429883,2429892,2429911,2429912,2429876,2429877,2429877,2429878,2429878,2429879,2429879,2429880,2429881,2429881,2429882,2429882,2429883,2429883,2429884,2429887,2429891,2429901,2429902,2429905,2429908,2429909,2429909,2429910,2429911,2429911,2429912,2429913,2429877,2429878,2429880,2429880,2429882,2429883,2429912,2429878,2429880,2429883,2429879,2429880,2429881,2429883,2429901,2429914,2429879,2429880,2429881,2429882,2429882,2429883,2429883,2429884,2429884,2429885,2429885,2429886,2429894,2429895,2429899,2429905,2429910,2429911,2429913,2429915,2430068,2429880,2429881,2429882,2429882,2429883,2429884,2429884,2429885,2429885,2429886,2429915,2429881,2429882,2429882,2429883,2429885,2429885,2429886,2429888,2429899,2429912,2429914,2429915,2429883,2429884,2429885,2429885,2429886,2429887,2429891,2429912,2429916,2429883,2429884,2429886,2429886,2429887,2429888,2429915,2429884,2429885,2429885,2429886,2429886,2429887,2429887,2429888,2429889,2429890,2429892,2429894,2429896,2429906,2429915,2429915,2429916,2429917,2430111,2430120,2429885,2429886,2429887,2429887,2429888,2429888,2429914,2429916,2429918,2429886,2429887,2429887,2429888,2429888,2429889,2429903,2429916,2429917,2429887,2429888,2429888,2429889,2429889,2429896,2429911,2429917,2429919,2429888,2429889,2429889,2429890,2429891,2429892,2429913,2429889,2429890,2429890,2429891,2429891,2429894,2429896,2429898,2429908,2429910,2429913,2429914,2429915,2429916,2429917,2429917,2429918,2429919,2429920,2430113,2429890,2429891,2429891,2429892,2429892,2429893,2429894,2429895,2429896,2429898,2429904,2429906,2429908,2429909,2429913,2429915,2429916,2429917,2429918,2429918,2429919,2429920,2429891,2429892,2429892,2429893,2429893,2429894,2429895,2429898,2429910,2429914,2429917,2429917,2429918,2429918,2429919,2429919,2429920,2429921,2430114,2429892,2429893,2429893,2429894,2429895,2429896,2429897,2429899,2429900,2429901,2429901,2429903,2429905,2429909,2429910,2429910,2429913,2429913,2429914,2429915,2429915,2429916,2429917,2429917,2429918,2429918,2429919,2429919,2429920,2429921,2429921,2430075,2430115,2429893,2429894,2429898,2429899,2429900,2429901,2429906,2429909,2429910,2429911,2429915,2429917,2429917,2429918,2429918,2429919,2429920,2429920,2429922,2430115,2429894,2429895,2429895,2429896,2429897,2429897,2429901,2429902,2429906,2429907,2429911,2429912,2429913,2429913,2429914,2429915,2429915,2429918,2429919,2429919,2429920,2429920,2429921,2429896,2429905,2429907,2429912,2429915,2429918,2429919,2429920,2429920,2429921,2429921,2430116,2429896,2429903,2429910,2429918,2429919,2429920,2429921,2429922,2429897,2429898,2429902,2429904,2429905,2429910,2429912,2429920,2429921,2429922,2429923,2429899,2429923,2429902,2429908,2429921,2429922,2429923,2429923,2429925,2429905,2429907,2429908,2429909,2429917,2429921,2429921,2429922,2429923,2429923,2429925,2429904,2429912,2429920,2429916,2429924,2429924,2429925,2429917,2429922,2429927,2429913,2429925,2429916,2429921,2429922,2429927,2429913,2429915,2429916,2429920,2429927,2429927,2429912,2429918,2429927,2429917,2429928,2429920,2429921,2429927,2429928,2429930,2429928,2429928,2429929,2429931,2429926,2429925,2429923,2429931,2429917,2429929,2429931,2429932,2429933,2429923,2429930,2429919,2429923,2429925,2429931,2429932,2429932,2429933,2429935,2429922,2429925,2429929,2429933,2429935,2429933,2429934,2429931,2429933,2429934,2429932,2429933,2429934,2429936,2429926,2429936,2429936,2429927,2429934,2429935,2429937,2429932,2429933,2429937,2429939,2429928,2429929,2429932,2429933,2429933,2429935,2429936,2429938,2429929,2429930,2429932,2429933,2429936,2429936,2429937,2429938,2429938,2429940,2429930,2429933,2429937,2429937,2429938,2429938,2429939,2429937,2429938,2429939,2429939,2429941,2429936,2429939,2429940,2429938,2429942,2429939,2429940,2429941,2429939,2429941,2429943,2429939,2429940,2429941,2429942,2429939,2429940,2429941,2429942,2429942,2430137,2429940,2429942,2429943,2429941,2429942,2429943,2429943,2429945,2429943,2429944,2429941,2429942,2429942,2429943,2429944,2429944,2429942,2429943,2429943,2429944,2429944,2429945,2429946,2429943,2429944,2429944,2429945,2429945,2429947,2429944,2429945,2429945,2429946,2429947,2429947,2429945,2429946,2429946,2429947,2429946,2429947,2429947,2429948,2429948,2429947,2429948,2429949,2429948,2429949,2429949,2430103,2429949,2429950,2429950,2430104,2429951,2430045,2430085,2430104,2430104,2430126,2430144,2430157,2430319,2430320,2430443,18265339,2430086,2430104,2430105,2430198,2430238,2430239,2430257,2430258,2430259,2430259,2430260,2430260,2430261,2430261,2430262,2430262,2430264,2430265,2430266,2430266,2430267,2430268,2430270,2430271,2430274,2430274,2430276,2430277,2430278,2430281,2430283,2430287,2430288,2430289,2430290,2430293,2430294,2430296,2430296,2430297,2430297,2430298,2430316,2430333,2430260,2430261,2430263,2430265,2430277,2430289,2430296,2430297,2430297,2430298,2430261,2430262,2430263,2430267,2430277,2430297,2430298,2430298,2430299,2430264,2430278,2430299,2430278,2430298,2430299,2430299,2430300,2430300,2430279,2430300,2430300,2430280,2430285,2430301,2430280,2430281,2430300,2430301,2430301,2430302,2430302,2430283,2430303,2430304,2430283,2430304,2430306,2430285,2430306,2430286,2430288,2430309,2430310,2430313,2430314,2430297,2430298,2430299,2430309,2430310,2430311,2430313,2430315,2430315,2430316,2430316,2430317,2430317,2430318,2430317,2430320,2430320,2430320,2430321,2430315,2430326,2430328,2430327,2430330,2430330,2430330,2430331,2430331,2430331,2430332,2430334,2430334,2430335,2430334,2430334,2430335,2430335,2430335,2430336,2430336,2430336,2430337,2430337,2430338,2430339,2430339,2430340,2430340,2430341,2430341,2430342,2430342,2430343,2430343,2430344,2430344,2430345,2430345,2430346,2430346,2430347,2430347,2430348,2430348,2430349,2430350,2430350,2430351,2430352,2430352,2430353,2430353,2430354,2430355,2430356,2430357,2430357,2430358,2430358,2430361,2430373,2430373,2430388,2430339,2430340,2430340,2430341,2430341,2430342,2430342,2430343,2430343,2430344,2430345,2430345,2430346,2430347,2430347,2430348,2430349,2430349,2430350,2430351,2430352,2430353,2430340,2430341,2430342,2430342,2430343,2430344,2430345,2430347,2430348,2430349,2430350,2430351,2430351,2430341,2430342,2430342,2430344,2430345,2430346,2430348,2430351,2430351,2430352,2430355,2430343,2430344,2430345,2430345,2430346,2430347,2430348,2430349,2430350,2430352,2430352,2430344,2430344,2430345,2430346,2430346,2430347,2430348,2430349,2430349,2430350,2430351,2430352,2430352,2430353,2430354,2430373,2430346,2430346,2430347,2430349,2430350,2430351,2430352,2430353,2430353,2430355,2430346,2430350,2430350,2430353,2430354,2430361,2430377,2430346,2430347,2430348,2430351,2430352,2430353,2430354,2430354,2430350,2430351,2430355,2430348,2430350,2430350,2430351,2430352,2430353,2430353,2430355,2430355,2430362,2430363,2430350,2430351,2430352,2430352,2430353,2430355,2430356,2430351,2430356,2430351,2430352,2430352,2430353,2430356,2430356,2430357,2430352,2430353,2430354,2430357,2430357,2430354,2430354,2430356,2430357,2430357,2430358,2430355,2430358,2430358,2430355,2430356,2430357,2430358,2430359,2430356,2430357,2430357,2430358,2430359,2430359,2430360,2430361,2430361,2430362,2430362,2430365,2430382,2430359,2430359,2430360,2430358,2430359,2430359,2430360,2430360,2430359,2430360,2430360,2430361,2430362,2430363,2430361,2430361,2430361,2430362,2430363,2430363,2430364,2430368,2430362,2430363,2430364,2430364,2430365,2430365,2430366,2430367,2430368,2430369,2430371,2430373,2430374,2430363,2430364,2430364,2430365,2430365,2430366,2430366,2430367,2430367,2430368,2430369,2430369,2430370,2430371,2430372,2430373,2430374,2430376,2430377,2430383,2430384,2430385,2430386,2430364,2430365,2430366,2430366,2430376,2430365,2430366,2430366,2430367,2430367,2430368,2430369,2430369,2430370,2430375,2430387,2430366,2430367,2430367,2430368,2430368,2430369,2430369,2430370,2430370,2430371,2430371,2430375,2430376,2430377,2430378,2430381,2430386,2430387,2430367,2430368,2430368,2430369,2430369,2430370,2430370,2430371,2430371,2430372,2430372,2430373,2430375,2430376,2430377,2430378,2430379,2430379,2430381,2430382,2430385,2430387,2430388,2430368,2430369,2430369,2430370,2430370,2430371,2430371,2430372,2430372,2430373,2430373,2430376,2430376,2430378,2430381,2430388,2430369,2430370,2430370,2430371,2430371,2430372,2430372,2430373,2430373,2430374,2430374,2430376,2430377,2430377,2430378,2430378,2430379,2430380,2430381,2430382,2430382,2430383,2430384,2430385,2430385,2430386,2430388,2430389,2430370,2430371,2430371,2430372,2430372,2430373,2430374,2430374,2430375,2430375,2430377,2430377,2430378,2430378,2430383,2430388,2430389,2430371,2430372,2430372,2430373,2430373,2430374,2430375,2430377,2430378,2430378,2430381,2430383,2430387,2430389,2430390,2430372,2430373,2430373,2430374,2430375,2430375,2430376,2430378,2430378,2430379,2430380,2430382,2430382,2430373,2430374,2430374,2430375,2430375,2430376,2430378,2430379,2430379,2430380,2430381,2430382,2430382,2430386,2430388,2430390,2430390,2430391,2430374,2430375,2430375,2430376,2430376,2430377,2430379,2430379,2430380,2430380,2430381,2430381,2430382,2430383,2430383,2430384,2430385,2430386,2430390,2430390,2430391,2430391,2430375,2430376,2430376,2430377,2430377,2430378,2430379,2430379,2430380,2430380,2430381,2430382,2430383,2430383,2430386,2430387,2430389,2430389,2430391,2430392,2430376,2430377,2430377,2430378,2430378,2430379,2430379,2430380,2430380,2430381,2430381,2430382,2430382,2430383,2430384,2430384,2430385,2430385,2430386,2430387,2430387,2430389,2430390,2430391,2430392,2430392,2430377,2430378,2430378,2430379,2430379,2430380,2430381,2430381,2430383,2430384,2430387,2430387,2430389,2430390,2430392,2430392,2430393,2430378,2430379,2430381,2430381,2430382,2430383,2430383,2430384,2430384,2430385,2430390,2430392,2430393,2430379,2430380,2430380,2430381,2430382,2430382,2430384,2430385,2430385,2430386,2430393,2430394,2430380,2430382,2430382,2430383,2430384,2430386,2430387,2430390,2430394,2430382,2430383,2430383,2430387,2430389,2430390,2430390,2430391,2430392,2430394,2430395,2430383,2430383,2430385,2430392,2430384,2430384,2430385,2430385,2430386,2430386,2430387,2430388,2430392,2430395,2430395,2430396,2430396,2430385,2430386,2430386,2430387,2430388,2430388,2430390,2430391,2430394,2430396,2430396,2430397,2430386,2430387,2430388,2430388,2430389,2430390,2430391,2430392,2430392,2430394,2430396,2430397,2430397,2430387,2430388,2430389,2430389,2430391,2430391,2430393,2430394,2430397,2430398,2430388,2430389,2430390,2430394,2430395,2430398,2430389,2430390,2430390,2430392,2430392,2430393,2430395,2430396,2430397,2430398,2430398,2430399,2430390,2430391,2430395,2430396,2430391,2430392,2430393,2430393,2430394,2430395,2430395,2430396,2430397,2430398,2430398,2430399,2430399,2430400,2430392,2430393,2430394,2430394,2430395,2430395,2430396,2430396,2430397,2430398,2430399,2430399,2430400,2430400,2430394,2430395,2430395,2430396,2430396,2430397,2430398,2430400,2430401,2430397,2430398,2430395,2430396,2430397,2430397,2430398,2430398,2430399,2430399,2430400,2430401,2430401,2430402,2430397,2430398,2430399,2430399,2430401,2430402,2430402,2430398,2430403,2430398,2430399,2430399,2430400,2430400,2430401,2430401,2430402,2430402,2430403,2430403,2430399,2430400,2430400,2430401,2430401,2430402,2430403,2430404,2430400,2430401,2430401,2430402,2430403,2430404,2430404,2430401,2430402,2430402,2430403,2430403,2430404,2430404,2430405,2430402,2430404,2430405,2430405,2430403,2430404,2430404,2430405,2430405,2430406,2430404,2430405,2430405,2430406,2430406,2430406,2430406,2430407,2430406,2430407,2430407,2430407,2430408,2430408,2430409,2430410,2430410,2430411,2430411,2430414,2430414,2430415,2430416,2430417,2430417,2430418,2430419,2430420,2430423,2430424,2430427,2430429,2430430,2430431,2430435,2430438,2430439,2430441,2430442,2430443,2430443,2430444,2430444,2430445,2430446,2430446,2430447,2430448,2430448,2430449,2430548,2430549,2430581,2430604,2430710,2430410,2430411,2430411,2430412,2430412,2430413,2430414,2430414,2430415,2430415,2430416,2430416,2430417,2430417,2430418,2430418,2430419,2430419,2430420,2430420,2430421,2430421,2430423,2430424,2430425,2430426,2430426,2430430,2430431,2430432,2430433,2430434,2430435,2430435,2430437,2430437,2430438,2430441,2430442,2430443,2430443,2430444,2430444,2430445,2430445,2430446,2430446,2430447,2430447,2430448,2430448,2430449,2430449,2430549,2430411,2430412,2430412,2430413,2430413,2430414,2430414,2430417,2430418,2430418,2430419,2430420,2430420,2430421,2430422,2430425,2430428,2430430,2430432,2430434,2430440,2430442,2430443,2430444,2430447,2430447,2430449,2430450,2430412,2430414,2430416,2430417,2430418,2430418,2430419,2430420,2430421,2430421,2430434,2430445,2430450,2430413,2430414,2430414,2430415,2430416,2430418,2430421,2430422,2430441,2430443,2430447,2430448,2430449,2430449,2430451,2430417,2430421,2430422,2430428,2430447,2430449,2430451,2430551,2430418,2430423,2430428,2430428,2430435,2430449,2430449,2430420,2430422,2430423,2430450,2430452,2430421,2430424,2430443,2430419,2430420,2430421,2430453,2430422,2430425,2430426,2430420,2430422,2430422,2430424,2430425,2430427,2430437,2430451,2430452,2430454,2430423,2430423,2430426,2430455,2430424,2430440,2430449,2430454,2430423,2430424,2430425,2430426,2430427,2430429,2430436,2430450,2430454,2430455,2430456,2430456,2430556,2430426,2430426,2430427,2430427,2430428,2430442,2430443,2430452,2430454,2430456,2430427,2430427,2430428,2430435,2430451,2430452,2430453,2430456,2430457,2430429,2430430,2430431,2430454,2430456,2430429,2430429,2430431,2430436,2430455,2430458,2430430,2430450,2430454,2430454,2430456,2430430,2430432,2430435,2430445,2430448,2430456,2430459,2430431,2430432,2430432,2430433,2430433,2430434,2430435,2430435,2430437,2430437,2430438,2430439,2430441,2430442,2430443,2430445,2430446,2430447,2430448,2430450,2430451,2430451,2430452,2430452,2430453,2430453,2430454,2430454,2430455,2430455,2430456,2430456,2430457,2430457,2430458,2430458,2430459,2430460,2430433,2430433,2430439,2430451,2430458,2430458,2430460,2430433,2430441,2430455,2430457,2430458,2430459,2430434,2430440,2430441,2430442,2430445,2430447,2430449,2430452,2430456,2430457,2430458,2430460,2430460,2430446,2430452,2430454,2430457,2430446,2430460,2430460,2430444,2430438,2430446,2430458,2430463,2430450,2430456,2430459,2430461,18820849,2430445,2430457,2430462,2430442,2430445,2430453,2430457,2430447,2430450,2430458,2430462,2430458,2430463,2430464,2430463,2430464,2430465,2430466,2430449,2430451,2430455,2430457,2430452,2430452,2430462,2430465,2430466,2430466,2430469,2430452,2430459,2430461,2430464,2430464,2430466,2430467,2430468,2430469,2430469,2430469,2430470,2430454,2430456,2430463,2430466,2430467,2430468,2430471,2430460,2430469,2430471,2430462,2430463,2430465,2430466,2430469,2430470,2430470,2430471,2430472,2430470,2430471,2430468,2430470,2430472,2430472,2430468,2430468,2430469,2430466,2430468,2430471,2430472,2430474,2430465,2430475,2430475,2430466,2430473,2430474,2430475,2430466,2430474,2430475,2430468,2430473,2430474,2430477,2430477,2430478,2430471,2430472,2430475,2430476,2430478,2430478,2430479,2430472,2430476,2430476,2430479,2430479,2430472,2430473,2430477,2430474,2430474,2430475,2430478,2430479,2430473,2430474,2430477,2430477,2430478,2430478,2430479,2430480,2430481,2430475,2430475,2430476,2430477,2430478,2430480,2430477,2430478,2430479,2430479,2430480,2430476,2430477,2430478,2430479,2430480,2430480,2430482,2430482,2430478,2430479,2430480,2430480,2430481,2430481,2430483,2430480,2430480,2430481,2430481,2430482,2430482,2430483,2430479,2430480,2430480,2430481,2430481,2430482,2430483,2430484,2430584,2430480,2430481,2430481,2430482,2430482,2430483,2430484,2430481,2430482,2430482,2430483,2430483,2430484,2430484,2430485,2430482,2430483,2430483,2430484,2430484,2430485,2430483,2430484,2430484,2430485,2430485,2430486,2430484,2430485,2430485,2430486,2430486,2430485,2430486,2430486,2430487,2430586,2430486,2430487,2430487,2430487,2430488,2430488,2430489,2430527,2430529,2430529,2430555,2430587,2430588,2430589,2430589,2430621,2430642,2430712,2431423,11359288,18274293,25897407,2430530,2430589,2430589,2430627,2430629,2430590,2430629,2430629,2430649,2430649,2430655,2430687,2430688,2430689,2430690,2430690,2430692,2430695,2430698,2430699,2430700,2430701,2430701,2430702,2430703,2430704,2430704,2430705,2430706,2430712,2430715,2430717,2430718,2430719,2430720,2430721,2430721,2430764,2430690,2430691,2430694,2430695,2430698,2430699,2430700,2430702,2430704,2430716,2430720,2430721,2430721,2430722,2430699,2430701,2430722,2430700,2430701,2430723,2430724,2430725,2430706,2430726,2430730,2430708,2430709,2430709,2430731,2430709,2430710,2430731,2430732,2430711,2430712,2430712,2430713,2430713,2430714,2430715,2430716,2430722,2430723,2430725,2430726,2430731,2430732,2430732,2430775,2430823,2430712,2430713,2430713,2430733,2430714,2430715,2430732,2430733,2430733,2430734,2430754,2430762,2430825,2430862,2430734,2430734,2430735,2430717,2430735,2430864,2430719,2430735,2430736,2430737,2430736,2430736,2430737,2430737,2430737,2430738,2430743,2430744,2430746,2430747,2430748,2430750,2430750,2430751,2430752,2430752,2430753,2430753,2430754,2430755,2430755,2430756,2430756,2430757,2430758,2430758,2430759,2430759,2430760,2430760,2430761,2430761,2430762,2430762,2430763,2430765,2430765,2430766,2430766,2430767,2430768,2430769,2430770,2430770,2430771,2430771,2430772,2430773,2430773,2430774,2430775,2430775,2430776,2430776,2430777,2430777,2430778,2430778,2430779,2430779,2430780,2430780,2430781,2430781,2430782,2430782,2430784,2430787,2430789,2430790,2430791,2430792,2430795,2430795,2430796,2430797,2430755,2430756,2430756,2430757,2430758,2430758,2430759,2430759,2430763,2430766,2430766,2430767,2430770,2430770,2430771,2430771,2430772,2430772,2430774,2430775,2430777,2430780,2430781,2430797,2430797,2430757,2430757,2430758,2430771,2430771,2430773,2430757,2430758,2430760,2430772,2430773,2430776,2430780,2430798,2430758,2430760,2430764,2430765,2430767,2430770,2430771,2430772,2430773,2430774,2430777,2430782,2430759,2430768,2430772,2430772,2430773,2430773,2430774,2430774,2430775,2430763,2430774,2430774,2430775,2430775,2430775,2430776,2430779,2430781,2430783,2430764,2430771,2430774,2430775,2430775,2430776,2430776,2430777,2430779,2430780,2430802,2430767,2430770,2430775,2430776,2430776,2430777,2430777,2430775,2430772,2430778,2430778,2430779,2430782,2430778,2430787,2430788,2430797,2430778,2430779,2430779,2430805,2430778,2430779,2430781,2430782,2430781,2430782,2430783,2430788,2430782,2430783,2430785,2430792,2430783,2430784,2430788,2430781,2430783,2430784,2430807,2430785,2430785,2430786,2430789,2430806,2430785,2430786,2430786,2430787,2430787,2430790,2430792,2430792,2430795,2430808,2430812,2430897,2430786,2430787,2430787,2430788,2430790,2430794,2430798,2430806,2430787,2430788,2430788,2430790,2430790,2430791,2430792,2430796,2430803,2430808,2430813,2430788,2430789,2430790,2430791,2430791,2430792,2430793,2430793,2430796,2430797,2430798,2430798,2430807,2430809,2430812,2430813,2430814,2430789,2430790,2430791,2430791,2430792,2430792,2430793,2430794,2430794,2430795,2430796,2430797,2430798,2430814,2430790,2430791,2430791,2430792,2430792,2430793,2430793,2430794,2430794,2430795,2430795,2430796,2430796,2430797,2430797,2430798,2430798,2430799,2430799,2430800,2430802,2430803,2430805,2430807,2430809,2430810,2430811,2430812,2430812,2430813,2430813,2430814,2430815,2430791,2430792,2430799,2430792,2430793,2430794,2430797,2430798,2430800,2430811,2430816,2430794,2430794,2430795,2430796,2430797,2430797,2430798,2430799,2430799,2430800,2430812,2430814,2430816,2430902,2430794,2430795,2430795,2430796,2430796,2430797,2430797,2430799,2430799,2430800,2430800,2430801,2430801,2430810,2430810,2430811,2430811,2430815,2430816,2430816,2430817,2430795,2430796,2430796,2430797,2430797,2430798,2430798,2430799,2430799,2430800,2430801,2430810,2430815,2430817,2430817,2430796,2430797,2430797,2430798,2430798,2430799,2430799,2430800,2430800,2430801,2430801,2430802,2430803,2430810,2430811,2430812,2430816,2430817,2430818,2430798,2430798,2430799,2430800,2430802,2430818,2430798,2430799,2430799,2430801,2430801,2430802,2430802,2430803,2430812,2430812,2430813,2430813,2430819,2430799,2430800,2430800,2430801,2430801,2430802,2430803,2430804,2430804,2430805,2430810,2430813,2430814,2430815,2430815,2430819,2430819,2430800,2430801,2430801,2430802,2430802,2430803,2430803,2430804,2430804,2430805,2430809,2430813,2430814,2430815,2430817,2430818,2430819,2430819,2430820,2430801,2430802,2430802,2430803,2430803,2430804,2430804,2430814,2430815,2430816,2430818,2430820,2430820,2430802,2430803,2430803,2430804,2430804,2430805,2430807,2430807,2430808,2430809,2430812,2430814,2430815,2430816,2430818,2430819,2430820,2430821,2430803,2430804,2430804,2430805,2430817,2430821,2430821,2430804,2430805,2430805,2430806,2430807,2430808,2430813,2430813,2430818,2430819,2430821,2430822,2430870,2430805,2430806,2430806,2430807,2430807,2430808,2430808,2430809,2430809,2430810,2430811,2430811,2430813,2430814,2430815,2430815,2430816,2430816,2430817,2430817,2430818,2430820,2430821,2430822,2430822,2430806,2430807,2430807,2430808,2430809,2430812,2430814,2430815,2430816,2430817,2430821,2430823,2430807,2430808,2430808,2430809,2430811,2430811,2430812,2430812,2430814,2430814,2430815,2430817,2430818,2430819,2430820,2430821,2430821,2430822,2430822,2430823,2430808,2430809,2430809,2430810,2430811,2430812,2430812,2430816,2430816,2430818,2430820,2430823,2430824,2430809,2430813,2430817,2430817,2430819,2430821,2430822,2430822,2430823,2430824,2430824,2430811,2430812,2430813,2430818,2430819,2430819,2430820,2430822,2430823,2430823,2430825,2430825,2430817,2430820,2430824,2430825,2430821,2430826,2430813,2430814,2430826,2430826,2430821,2430822,2430825,2430827,2430815,2430821,2430820,2430821,2430825,2430827,2430828,2430820,2430820,2430821,2430826,2430828,2430828,2430821,2430828,2430829,2430823,2430829,2430823,2430830,2430830,2430823,2430824,2430824,2430826,2430827,2430828,2430830,2430831,2430826,2430827,2430831,2430831,2430826,2430830,2430832,2430825,2430826,2430827,2430830,2430830,2430832,2430826,2430827,2430828,2430829,2430831,2430832,2430833,2430827,2430829,2430829,2430832,2430833,2430834,2430828,2430829,2430829,2430830,2430831,2430831,2430832,2430833,2430833,2430834,2430832,2430832,2430834,2430834,2430834,2430835,2430831,2430833,2430835,2430835,2430833,2430834,2430835,2430836,2430834,2430836,2430836,2430834,2430837,2430835,2430836,2430837,2430837,2430836,2430837,2430838,2430838,2430838,2430838,2430839,2430839,2430840,2430841,2430841,2430842,2430842,2430843,2430843,2430844,2430844,2430845,2430845,2430847,2430848,2430849,2430850,2430852,2430854,2430854,2430855,2430855,2430856,2430857,2430857,2430858,2430859,2430859,2430860,2430861,2430861,2430862,2430863,2430865,2430865,2430866,2430867,2430868,2430868,2430869,2430869,2430870,2430870,2430871,2430871,2430872,2430872,2430888,2430925,2430940,2430841,2430842,2430842,2430843,2430843,2430844,2430844,2430845,2430845,2430846,2430848,2430848,2430849,2430849,2430853,2430854,2430855,2430855,2430856,2430857,2430859,2430860,2430860,2430861,2430862,2430863,2430864,2430865,2430866,2430867,2430868,2430868,2430869,2430869,2430870,2430870,2430871,2430871,2430872,2430872,2430873,2430888,2430926,2430842,2430843,2430844,2430844,2430845,2430849,2430850,2430851,2430856,2430858,2430860,2430862,2430862,2430868,2430872,2430873,2430889,2430843,2430844,2430853,2430872,2430874,2430844,2430846,2430857,2430873,2430845,2430846,2430846,2430850,2430852,2430853,2430854,2430857,2430859,2430859,2430867,2430870,2430872,2430873,2430874,2430874,2430875,2430846,2430849,2430852,2430868,2430871,2430872,2430875,2430875,2430847,2430849,2430850,2430852,2430857,2430859,2430870,2430872,2430875,2430876,2430852,2430853,2430853,2430858,2430861,2430863,2430864,2430869,2430871,2430872,2430873,2430875,2430876,2430876,2430876,2430877,2430859,2430877,2430860,2430865,2430867,2430878,2430879,2430861,2430879,2430880,2430860,2430862,2430862,2430863,2430864,2430867,2430870,2430876,2430879,2430880,14033387,2430861,2430859,2430866,2430870,2430874,2430876,2430876,2430878,2430881,2430866,2430864,2430880,2430879,2430883,2430865,2430871,2430873,2430879,2430880,2430882,2430884,2430884,2430885,2430869,2430870,2430871,2430875,2430878,2430879,2430881,2430881,2430882,2430883,2430884,2430885,2430886,2430869,2430872,2430878,2430886,2430886,2430887,2430871,2430871,2430873,2430874,2430874,2430876,2430876,2430877,2430880,2430883,2430886,2430887,2430887,2430888,2430875,2430877,2430878,2430883,2430885,2430887,2430888,2430878,2430881,2430883,2430886,2430886,2430887,2430888,2430889,2430877,2430878,2430889,2430889,2430882,2430886,2430890,2430886,2430879,2430891,2430882,2430883,2430884,2430884,2430886,2430886,2430890,2430892,2430881,2430887,2430889,2430892,2430892,2430888,2430889,2430889,2430890,2430892,2430893,2430893,2430946,2430883,2430885,2430891,2430893,2430894,2430889,2430893,2430894,2430894,2430895,2430894,2430895,2430895,2430896,2430896,2430892,2430895,2430890,2430892,2430893,2430894,2430895,2430895,2430896,2430897,2430897,2430895,2430897,2430898,2430895,2430898,2430899,2430894,2430896,2430898,2430899,2430895,2430896,2430896,2430897,2430897,2430898,2430899,2430899,2430900,2430898,2430900,2430900,2430897,2430900,2430900,2430901,2430899,2430900,2430901,2430901,2430899,2430900,2430901,2430902,2430900,2430901,2430902,2430901,2430902,2430902,2430903,2430902,2430903,2430903,2430903,2430904,2430904,2430905,2430906,2430918,2430920,2430920,2430958,2430972,2431023,2431631,18274501,2430920,2430921,2430921,2430934,2430935,2430936,2430937,2430937,2430938,2430938,2430939,2430939,2430942,2430942,2430943,2430944,2430951,2430952,2430953,2430954,2430956,2430957,2430958,2430961,2430962,2430964,2430967,2430968,2430969,2430970,2430971,2430971,2430972,2430972,2430973,2430973,2431011,2430937,2430939,2430943,2430954,2430959,2430962,2430972,2430973,2430973,2430974,2430942,2430974,2430974,2430974,2430967,2430942,2430976,2430976,2430977,2430978,2430977,2430979,2430980,2430980,2430968,2430989,2430979,2430990,2430990,2430991,2430991,2430993,2430994,2430994,2430995,2430998,2430999,2430998,2430999,2431001,2431001,2431004,2431005,2431006,2431007,2431008,2431007,2431008,2431008,2431008,2431009,2431008,2431009,2431009,2431009,2431010,2431010,2431011,2431012,2431012,2431013,2431013,2431014,2431014,2431015,2431015,2431016,2431016,2431017,2431017,2431018,2431018,2431019,2431020,2431020,2431021,2431021,2431022,2431022,2431023,2431024,2431024,2431025,2431025,2431026,2431026,2431027,2431027,2431028,2431028,2431029,2431030,2431031,2431031,2431032,2431032,2431033,2431035,2431035,2431036,2431037,2431038,2431038,2431042,2431049,2431012,2431013,2431013,2431014,2431014,2431015,2431015,2431016,2431016,2431017,2431017,2431018,2431018,2431019,2431019,2431021,2431022,2431022,2431023,2431023,2431024,2431025,2431025,2431026,2431027,2431029,2431031,2431035,2431036,2431047,2431049,2431049,2431013,2431014,2431014,2431015,2431016,2431017,2431018,2431019,2431019,2431022,2431022,2431023,2431024,2431026,2431031,2431050,2431014,2431015,2431016,2431017,2431017,2431019,2431020,2431021,2431023,2431024,2431025,2431026,2431036,2431017,2431017,2431018,2431020,2431021,2431024,2431025,2431027,2431018,2431020,2431020,2431021,2431024,2431025,2431026,2431028,2431018,2431019,2431021,2431022,2431025,2431026,2431028,2431021,2431026,2431028,2431030,2431020,2431022,2431024,2431026,2431026,2431027,2431029,2431029,2431020,2431021,2431022,2431023,2431025,2431025,2431026,2431027,2431028,2431029,2431030,2431033,2431053,2431021,2431022,2431022,2431023,2431023,2431024,2431025,2431026,2431026,2431027,2431027,2431028,2431029,2431030,2431030,2431023,2431027,2431029,2431030,2431042,2431024,2431025,2431026,2431028,2431029,2431032,2431025,2431025,2431027,2431028,2431029,2431030,2431031,2431032,2431033,2431033,2431025,2431026,2431026,2431027,2431029,2431029,2431030,2431031,2431032,2431033,2431036,2431038,2431028,2431029,2431029,2431030,2431031,2431032,2431032,2431033,2431034,2431036,2431038,2431043,2431056,2431028,2431029,2431030,2431031,2431032,2431033,2431033,2431034,2431032,2431032,2431033,2431038,2431040,2431032,2431033,2431040,2431032,2431032,2431033,2431033,2431034,2431032,2431033,2431034,2431035,2431035,2431038,2431033,2431034,2431035,2431036,2431036,2431037,2431034,2431035,2431036,2431036,2431037,2431037,2431038,2431038,2431039,2431040,2431040,2431043,2431046,2431047,2431048,2431060,2431035,2431037,2431036,2431037,2431037,2431038,2431038,2431039,2431039,2431041,2431041,2431042,2431043,2431043,2431044,2431046,2431047,2431048,2431049,2431050,2431051,2431052,2431053,2431061,2431061,2431037,2431038,2431038,2431041,2431038,2431039,2431039,2431040,2431040,2431042,2431042,2431044,2431048,2431048,2431049,2431052,2431039,2431040,2431040,2431041,2431042,2431043,2431044,2431044,2431045,2431045,2431046,2431047,2431048,2431049,2431049,2431050,2431051,2431051,2431053,2431055,2431056,2431058,2431059,2431061,2431062,2431063,2431040,2431041,2431041,2431042,2431042,2431043,2431043,2431045,2431046,2431046,2431047,2431048,2431049,2431049,2431050,2431051,2431051,2431063,2431041,2431042,2431043,2431045,2431046,2431048,2431049,2431050,2431050,2431051,2431052,2431055,2431042,2431043,2431044,2431044,2431045,2431045,2431046,2431046,2431047,2431047,2431049,2431049,2431050,2431050,2431051,2431052,2431052,2431053,2431057,2431060,2431043,2431044,2431044,2431045,2431046,2431046,2431047,2431047,2431048,2431048,2431049,2431050,2431050,2431051,2431051,2431052,2431053,2431054,2431054,2431055,2431057,2431058,2431061,2431063,2431063,2431065,2431045,2431047,2431051,2431065,2431045,2431046,2431048,2431049,2431054,2431056,2431046,2431047,2431048,2431048,2431049,2431049,2431050,2431051,2431051,2431052,2431052,2431053,2431054,2431054,2431059,2431064,2431066,2431047,2431048,2431048,2431049,2431049,2431050,2431050,2431051,2431051,2431052,2431053,2431053,2431054,2431055,2431056,2431060,2431061,2431065,2431066,2431067,2431049,2431049,2431054,2431049,2431050,2431051,2431054,2431054,2431055,2431061,2431068,2431050,2431051,2431051,2431052,2431054,2431055,2431056,2431057,2431057,2431061,2431068,2431051,2431052,2431052,2431053,2431053,2431054,2431054,2431055,2431055,2431056,2431056,2431057,2431059,2431061,2431062,2431063,2431067,2431069,2431052,2431053,2431053,2431055,2431056,2431057,2431058,2431059,2431060,2431062,2431064,2431067,2431069,2431053,2431054,2431055,2431056,2431056,2431058,2431058,2431060,2431063,2431067,2431069,2431070,2431054,2431056,2431056,2431057,2431058,2431058,2431059,2431070,2431056,2431057,2431057,2431057,2431057,2431058,2431060,2431066,2431072,2431058,2431059,2431065,2431059,2431060,2431060,2431061,2431061,2431062,2431062,2431063,2431063,2431064,2431065,2431066,2431067,2431068,2431069,2431071,2431072,2431073,2431099,2431060,2431061,2431061,2431062,2431062,2431063,2431063,2431064,2431064,2431065,2431066,2431066,2431068,2431068,2431069,2431069,2431070,2431072,2431073,2431073,2431061,2431063,2431067,2431062,2431063,2431063,2431064,2431064,2431065,2431067,2431067,2431069,2431070,2431071,2431072,2431072,2431073,2431074,2431074,2431063,2431064,2431064,2431065,2431065,2431066,2431066,2431067,2431067,2431068,2431069,2431070,2431072,2431072,2431073,2431073,2431074,2431075,2431064,2431065,2431065,2431066,2431066,2431068,2431069,2431070,2431071,2431073,2431073,2431074,2431075,2431075,2431065,2431066,2431066,2431067,2431067,2431068,2431069,2431070,2431071,2431071,2431072,2431072,2431073,2431074,2431074,2431075,2431076,2431066,2431067,2431067,2431069,2431070,2431071,2431072,2431073,2431073,2431074,2431074,2431075,2431075,2431076,2431076,2431067,2431068,2431068,2431069,2431071,2431072,2431073,2431073,2431074,2431074,2431075,2431075,2431076,2431076,2431077,2431068,2431069,2431069,2431070,2431070,2431071,2431072,2431073,2431074,2431075,2431075,2431076,2431077,2431077,2431069,2431070,2431071,2431071,2431072,2431073,2431074,2431074,2431075,2431076,2431077,2431077,2431078,2431071,2431071,2431075,2431076,2431076,2431077,2431078,2431078,2431072,2431073,2431074,2431077,2431078,2431079,2431072,2431073,2431074,2431076,2431077,2431077,2431079,2431074,2431074,2431075,2431075,2431076,2431077,2431078,2431078,2431079,2431080,2431076,2431076,2431076,2431077,2431079,2431079,2431080,2431080,2431081,2431078,2431078,2431079,2431080,2431080,2431081,2431081,2431078,2431078,2431079,2431081,2431082,2431078,2431080,2431082,2431082,2431079,2431080,2431081,2431082,2431083,2431080,2431081,2431081,2431082,2431083,2431083,2431081,2431082,2431083,2431084,2431082,2431083,2431084,2431084,2431083,2431084,2431084,2431085,2431085,2431085,2431085,2431086,2431086,2431087,2431088,2431088,2431089,2431089,2431091,2431091,2431092,2431092,2431093,2431093,2431094,2431095,2431096,2431096,2431097,2431099,2431101,2431102,2431104,2431108,2431110,2431112,2431113,2431114,2431115,2431115,2431116,2431117,2431118,2431119,2431120,2431121,2431122,2431123,2431123,2431124,2431124,2431722,2433271,3758471,2431088,2431089,2431089,2431090,2431090,2431091,2431091,2431092,2431092,2431093,2431093,2431094,2431094,2431095,2431095,2431096,2431096,2431097,2431097,2431098,2431099,2431100,2431101,2431103,2431105,2431105,2431108,2431108,2431109,2431110,2431110,2431113,2431114,2431114,2431115,2431115,2431116,2431117,2431119,2431120,2431120,2431121,2431121,2431122,2431123,2431123,2431124,2431124,2431125,2431089,2431090,2431090,2431092,2431093,2431094,2431095,2431095,2431096,2431097,2431097,2431099,2431101,2431102,2431108,2431110,2431112,2431115,2431116,2431120,2431121,2431124,2431125,2431125,2431090,2431091,2431092,2431094,2431097,2431097,2431115,2431124,2431126,2431091,2431093,2431093,2431094,2431098,2431099,2431100,2431101,2431106,2431106,2431110,2431126,2431126,2431092,2431093,2431098,2431107,2431117,2431118,2431126,2431126,2431127,2431094,2431096,2431097,2431098,2431099,2431121,2431124,2431094,2431127,2431127,2431128,2431095,2431096,2431097,2431098,2431098,2431099,2431100,2431101,2431104,2431112,2431122,2431122,2431126,2431127,2431128,2431128,2431097,2431098,2431100,2431100,2431106,2431109,2431119,2431128,2431129,2431108,2431129,2431098,2431099,2431100,2431101,2431102,2431107,2431108,2431119,2431120,2431122,2431125,2431126,2431127,2431129,2431129,2431130,2431101,2431101,2431102,2431110,2431117,2431130,2431130,2431102,2431130,2431131,2431103,2431115,2431122,2431123,2431126,2431129,2431130,2431131,2431131,2431103,2431106,2431109,2431112,2431124,2431131,2431103,2431104,2431119,2431104,2431105,2431106,2431107,2431109,2431128,2431132,2431133,2431105,2431106,2431106,2431107,2431108,2431109,2431110,2431114,2431117,2431118,2431118,2431122,2431123,2431124,2431125,2431126,2431127,2431128,2431130,2431131,2431132,2431132,2431133,2431133,2431107,2431120,2431122,2431124,2431126,2431132,2431133,2431133,2431134,2431116,2431118,2431125,2431132,2431134,2431113,2431118,2431119,2431127,2431127,2431132,2431134,2431120,2431132,2431135,2431132,2431112,2431114,2431125,2431125,2431127,2431128,2431129,2431131,2431133,2431135,2431114,2431125,2431126,2431127,2431128,2431131,2431132,2431137,2431127,2431130,2431132,2431133,2431133,2431137,2431138,2431138,2431119,2431129,2431136,2431136,2431119,2431139,2431132,2431136,2431140,2431129,2431132,2431140,2431134,2431135,2431137,2431138,2431141,2431133,2431140,2431141,2431132,2431143,2431144,2431145,2431143,2431145,2431138,2431145,2431145,2431146,2431138,2431132,2431141,2431147,2431135,2431147,2431147,2431139,2431139,2431140,2431149,2431144,2431147,2431140,2431148,2431149,2431149,2431143,2431149,2431141,2431143,2431145,2431151,2431142,2431143,2431150,2431151,2431142,2431144,2431147,2431152,2431143,2431144,2431144,2431145,2431147,2431149,2431150,2431151,2431151,2431152,2431152,2431153,2431152,2431153,2431153,2431147,2431148,2431149,2431150,2431151,2431152,2431152,2431153,2431153,2431154,2431752,2431152,2431153,2431153,2431154,2431154,2431150,2431155,2431150,2431153,2431154,2431155,2431155,2431153,2431156,2431151,2431156,2431156,2431153,2431154,2431154,2431155,2431155,2431156,2431157,2431153,2431155,2431156,2431157,2431155,2431157,2431158,2431156,2431157,2431158,2431158,2431157,2431158,2431158,2431159,2431157,2431158,2431159,2431159,2431158,2431159,2431159,2431160,2431159,2431160,2431160,2431160,2431161,2431161,2431162,2431163,2431169,2431224,2431759,2431760,2431760,2431780,2431783,2431810,2431811,2433308,2433309,2433358,2433360,3758505,3758513,4717461,4717462,6272435,6763064,8230377,11359602,11359625,13930140,25897743,2431163,2431760,2431780,2431781,2433309,2433330,2433358,3115667,2431761,2431781,2431784,2433309,2433310,2433359,2433360,3758512,4717463,4968789,7930601,2431252,2431301,2431359,2431837,2431843,2431894,2432357,2432358,2432359,2432359,2432360,2432361,2432364,2432367,2432368,2432373,2432377,2432377,2432378,2432378,2432359,2432360,2432361,2432378,2432378,2432379,2432365,2432379,2432380,2432362,2432364,2432381,2432380,2432381,2432382,2432384,2432385,2432377,2432378,2432388,2432379,2432387,2433918,2432394,2432397,2432397,2432398,2432453,2432398,2432454,2432399,2432400,2432400,2432401,2432401,2432403,2432403,2432406,2432408,2432408,2432409,2432411,2432412,2432414,2432414,2432415,2432415,2432416,2432417,2432417,2432418,2432419,2432420,2432420,2432421,2432421,2432422,2432423,2432423,2432424,2432424,2432425,2432425,2432426,2432427,2432427,2432428,2432428,2432429,2432430,2432430,2432431,2432432,2432435,2432436,2432436,2432437,2432438,2432439,2432441,2432442,2432443,2432444,2432445,2432445,2432446,2432446,2432447,2432447,2432448,2432449,2432450,2432451,2432452,2432452,2432453,2432453,2432454,2432454,2432401,2432402,2432414,2432415,2432419,2432422,2432425,2432429,2432439,2432441,2432445,2432454,2432454,2432430,2432403,2432419,2432421,2432447,2432405,2432405,2432413,2432423,2432427,2432429,2432430,2432456,2432442,2432410,2432424,2432443,2432457,2432456,2432430,2432435,2432452,2432438,2432448,2432448,2432426,2432449,2432461,2432433,2432435,2432454,2432465,2432469,2432454,2432436,2432447,2432438,2432471,2432471,2432467,2432437,2432440,2432441,2432442,2432443,2432445,2432448,2432457,2432472,2432473,2432444,2432452,2432465,2432474,2432452,2432453,2432453,2432444,2432449,2432450,2432455,2432475,2433949,2432476,2432445,2432446,2432450,2432451,2432453,2432454,2432455,2432476,2433950,2433999,2432447,2432451,2432452,2432453,2432455,2432474,2432477,2432448,2432448,2432451,2432452,2432454,2432456,2432475,2432478,2433951,2432452,2432453,2432455,2432458,2432476,2432478,2433952,2432451,2432453,2432479,2433952,2432450,2432453,2432454,2432455,2432457,2432464,2432474,2432477,2432479,2433952,2433953,2432453,2432461,2433953,2432455,2432455,2432456,2433955,2432461,2432466,2432474,2432475,2432477,2432456,2432457,2432459,2432459,2432461,2432464,2432465,2432466,2432467,2432470,2432471,2432472,2432477,2432482,2432457,2432483,2432459,2432459,2432460,2432461,2432462,2432464,2432465,2432466,2432468,2432469,2432474,2432475,2432476,2432478,2432478,2432480,2432481,2432483,2432483,2432462,2432465,2432472,2432474,2432484,2432461,2432462,2432466,2432474,2432475,2432477,2432482,2432485,2432464,2432465,2432468,2432470,2432474,2432485,2432486,2433959,2432479,2432486,2432475,2432476,2432484,2432486,2432487,2432480,2432487,2432472,2432488,2432489,2432471,2432490,2433963,2432482,2432490,2432473,2432491,2432477,2432478,2432491,2433965,2432492,2432477,2432490,2432493,2432493,2432479,2432480,2432483,2432484,2432484,2432487,2432487,2432489,2432494,2432486,2432487,2432490,2432494,2432492,2432489,2432495,2432496,2432491,2432497,2432493,2432495,2432497,2432498,2432490,2432497,2432499,2432494,2432496,2432497,2432499,2432499,2432499,2432500,2432497,2432499,2432500,2432494,2432496,2432501,2432501,2433975,2432497,2432498,2432502,2432502,2432503,2433977,2432499,2432501,2432501,2432504,2432503,2432504,2432504,2432504,2432505,2433979,2432503,2432506,2432505,2432506,2432506,2432507,2432507,2432508,2432508,2432509,2432510,2432511,2432513,2432514,2432517,2432520,2432522,2432525,2432525,2432526,2432526,2432527,2432527,2432528,2432529,2432529,2433982,2433982,2434031,2434036,2432510,2432511,2432514,2432514,2432515,2432524,2432526,2432528,2432528,2432529,2432530,2432527,2432528,2432530,2432523,2432531,2432533,2432531,2432533,2432534,2432532,2432538,2432541,2432541,2432542,2432544,2432545,2432546,2432546,2432546,2432547,2432547,2432548,2432548,2432549,2432549,2432550,2434002,2434003,2434003,2434023,2434052,2434056,2434056,3524040,3759199,3759202,3759202,4969481,4969489,8543676,10473581,14034234,25898437,2434003,2434003,2435455,2435456,2435457,2435457,2435458,2435458,2435459,2435461,2435462,2435467,2435467,2435487,2435490,2435491,2435492,2435494,2435497,2435498,2435502,2435502,2435503,2435503,2435504,2435504,2435505,2435508,2435458,2435459,2435489,2435502,2435504,2435504,2435505,2435505,2435459,2435468,2435505,2435506,2435460,2435461,2435462,2435504,2435506,2435507,2435461,2435462,2435465,2435469,2435481,2435484,2435496,2435496,2435505,2435506,2435506,2435507,2435507,2435507,2435508,2435508,2435509,2435509,2435510,2435511,2435515,2435516,3760662,2435516,2435525,2435527,2435531,2435536,2435535,2435539,2435532,2435540,2435540,2435541,2435542,2435542,2435543,2435545,2435546,2435544,2435550,2435551,2435551,2435551,2435551,2435551,2435552,2435552,2435552,2435553,2435553,2435554,2435555,2435555,2435556,2435556,2435557,2435557,2435558,2435558,2435559,2435559,2435560,2435560,2435561,2435563,2435564,2435567,2435567,2435570,2435571,2435572,2435572,2435573,2435573,2435574,2435575,2435575,2435577,2435577,2435578,2435578,2435579,2435580,2435580,2435581,2435555,2435556,2435556,2435557,2435558,2435559,2435560,2435560,2435561,2435562,2435567,2435575,2435576,2435577,2435578,2435580,2435581,2435556,2435558,2435559,2435559,2435581,2435557,2435558,2435559,2435559,2435560,2435561,2435561,2435562,2435567,2435571,2435573,2435576,2435576,2435578,2435578,2435579,2435580,2435581,2435581,2435582,2435558,2435559,2435560,2435562,2435563,2435569,2435573,2435582,2435582,2435560,2435560,2435561,2435561,2435562,2435562,2435563,2435564,2435566,2435567,2435568,2435577,2435580,2435580,2435582,2435582,2435583,2435566,2435561,2435562,2435563,2435564,2435565,2435566,2435567,2435568,2435572,2435576,2435578,2435578,2435580,2435581,2435583,2435583,2435584,2435562,2435563,2435564,2435564,2435565,2435566,2435568,2435571,2435578,2435579,2435579,2435580,2435583,2435583,2435584,2435584,2435585,2435563,2435564,2435564,2435565,2435565,2435567,2435569,2435570,2435571,2435572,2435574,2435575,2435576,2435576,2435577,2435579,2435579,2435580,2435581,2435582,2435582,2435584,2435584,2435585,2435564,2435565,2435565,2435583,2435585,2435566,2435566,2435569,2435572,2435573,2435577,2435579,2435580,2435580,2435582,2435583,2435585,2435585,2435586,2435566,2435567,2435568,2435569,2435571,2435572,2435578,2435580,2435582,2435583,2435585,2435586,2435586,2435567,2435568,2435571,2435576,2435578,2435579,2435580,2435581,2435581,2435582,2435583,2435584,2435584,2435585,2435586,2435586,2435587,2435573,2435575,2435576,2435578,2435579,2435580,2435581,2435582,2435584,2435584,2435586,2435587,2435575,2435588,2435582,2435585,2435588,2435588,2435573,2435588,2435583,2435589,2435589,2435577,2435581,2435583,2435584,2435585,2435585,2435589,2435590,2435578,2435585,2435588,2435591,2435582,2435583,2435591,2435579,2435587,2435588,2435591,2435592,2435587,2435587,2435592,2435593,2435584,2435591,2435593,2435588,2435589,2435591,2435593,2435594,2435591,2435593,2435594,2435595,2435585,2435590,2435590,2435591,2435593,2435596,2435597,2435596,2435597,2435592,2435592,2435595,2435595,2435597,2435598,2435591,2435593,2435597,2435598,2435598,3760724,2435598,2435599,2435593,2435597,2435598,2435594,2435598,2435599,2435600,2435595,2435596,2435597,2435597,2435598,2435598,2435599,2435600,2435600,2435601,2435598,2435599,2435600,2435600,2435601,2435601,2435598,2435602,11361842,2435598,2435602,2435602,2435600,2435601,2435602,2435603,2435600,2435601,2435602,2435603,2435603,2435603,2435604,2435603,2435604,2435604,2435604,2435604,2435605,2435604,2435605,2435605,2435605,2435606,2435607,2435626,2435606,3760727,2435607,2435608,2435608,2435609,2435609,2435610,2435610,2435611,2435612,2435613,2435613,2435614,2435614,2435616,2435616,2435618,2435618,2435620,2435620,2435621,2435622,2435622,2435623,2435623,2435624,2435624,2435626,2435626,2435627,2435627,2435630,2435634,2435635,2435636,2435640,2435647,2435649,2435651,2435652,2435652,2435653,2435654,2435654,2435655,2435655,2435656,2596753,2667969,2722933,3760734,4719684,4719685,6976632,7932822,8545203,9354225,10475106,2435608,2435609,2435609,2435610,2435611,2435611,2435612,2435613,2435613,2435614,2435616,2435617,2435618,2435620,2435621,2435623,2435624,2435624,2435625,2435626,2435628,2435628,2435633,2435636,2435637,2435639,2435650,2435653,2435654,2435654,2435655,2435656,2435656,2464827,4719682,2435610,2435610,2435612,2435617,2435623,2435624,2435628,2435635,2435654,2435655,2435656,2435657,5109467,2435612,2435657,2435611,2435613,2435615,2435618,2435622,2435623,2435626,2435627,2435629,2435638,2435653,2435655,2435656,2435657,2435658,3760738,6626946,6765289,2435620,2435621,2435626,2435639,2435641,2435654,2435657,2435658,2997373,2435617,2435659,2435620,2435627,2435659,2435636,2435660,2435619,2435656,2435660,2435660,2435661,2435626,2435661,2435622,2435626,2435631,2435662,2435623,2435662,2435633,2435663,2435631,2435663,2435625,2435629,2435632,2435635,2435636,2435637,2435663,2435665,2435627,2435633,2435634,2435634,2435636,2435637,2435639,2435642,2435650,2435651,2435664,2435665,2435665,2435662,2435666,2435667,2435667,2435667,2435640,2435666,2435637,2435639,2435641,2435668,2435669,2435636,2435661,2435670,2435671,3117904,2435671,2435643,2435645,2435672,2435672,2435644,2435644,2435673,2435645,2435657,2435670,2435673,2435646,2435673,2435674,2435646,2435670,2435673,2435675,2435647,2435676,3760748,2435649,2435661,2435670,2435672,2435673,2435674,2435676,2435677,2435675,2435677,2435678,2435678,2435679,2435679,2435682,3760754,2435664,2435681,2435684,2435684,2435682,2435685,2435680,2435683,4075574,2435689,2435689,2435690,2435686,2435695,2435689,2435694,2435695,2435698,2435697,2435698,2435699,2435698,2435699,2435699,2435700,3851669,2435701,2435699,2435700,2435701,2435701,2435702,2435701,2435701,2435702,2435701,2435702,2435702,2435703,2435702,2435703,2435703,2435704,2435704,2435705,2435765,2464876,2567248,2567249,2567253,2596804,2668018,2706760,2780397,2831599,2831668,2925406,2954550,2954942,2975915,2997366,2997419,2997420,2997421,2997421,3099185,3099188,3117938,3117938,3117939,3169646,3193214,3193216,3193280,3252463,3291724,3324861,3525617,3525618,3525618,3525619,3533050,3533051,3533051,3533052,3533052,3534532,3534532,3544630,3595828,3595838,3597467,3597469,3705835,3705835,3705836,3747454,3760775,3760776,3760776,3760777,3760777,3760778,3760779,3760780,3760780,3760781,3760781,3760782,3760782,3760783,3760783,3760784,3760784,3760785,3760785,3760786,3851674,3851712,3851715,3851736,3951757,3995795,4002891,4002892,4075591,4115354,4224364,4224390,4363169,4363170,4363172,4363173,4363174,4622747,4719729,4719729,4719730,4719730,4719731,4719731,4719732,4719732,4719733,4719733,4719734,4719734,4719735,4784935,4971056,4971057,4971061,4971063,4971064,4971066,5078677,5109514,5109515,5109516,5806757,6255576,6765334,6765334,6765335,6765335,6976681,7141419,7184362,7337692,7404889,7932874,8545252,8545253,8545254,8545254,8632145,8692646,9354274,9760382,10475155,11307289,11361873,13932411,14035812,25900015,2685705,3117938,3533051,3597470,3760778,3760785,3851674,4719730,4719734,2435853,3525706,2494062,2494062,2494064,3789963,3789964,3789971,2698808,2698809,2698812,3128980,3892343,3892344,3983284,2757913,2757915,2990451,3695644,2900344,3186876,3765378,3993103,2935722,4101691,2977832,10031454,3010271,3284715,3125165,3462706,3222986,5113378,3227513,4156693,3227644,4247650,3415176,3607708,3473410,3473411,4279637,3636799,3474195,3516672,4052303,5238986,3516172,3516317,3516474,4301196,3559050,4322461,5281415,5346619,3559149,3559152,3559152,3559151,3559153,3559157,3679668,4094780,4322514,4413403,4892030,3679029,4322506,4322509,4717225,3762681,3762683,3781433,4424276,3798901,4207222,3800171,3800184,3800185,3800185,3800186,3800186,3800187,3800187,3800190,3800185,3800186,3800187,3800187,3800188,3800188,3800188,4215298,4443024,5401978,7447581,3800200,4207866,4443023,4533921,3800205,4207865,4215298,4215298,4443025,4443025,4443030,5401979,5401982,7447582,7447583,8615117,4207867,4215299,4215299,4216782,4443025,4532673,4533922,4533969,5401981,7447584,4207866,4443025,4443026,4443026,4533923,5045422,4279719,4443026,4517219,4533923,5401982,4226884,4443033,3903602,3927170,3950734,3950734,3950799,3950801,3950744,4290571,5477250,3950865,3951003,3951148,3951151,7899151,3951929,3952726,4519306,4519306,4069236,4349824,4147755,4616811,4214030,5608901,4615543,4615544,4615544,4615545,4622976,4622977,4622978,4850702,4850703,4850703,4850706,4850708,4850709,4850709,4850711,4941600,4941662,5453099,5809659,7855261,4630409,4630409,4630409,4630410,4630410,4630411,4630411,4858135,4803195,4858135,4858136,4858136,4858138,4858139,4858141,4858142,4858143,4949033,4949075,5460531,5817088,5817088,5817089,5817090,6068416,6206875,6206876,7862694,12459255,4633374,4633375,4633376,4633377,4859619,4859625,4696312,4950564,4653571,4653573,4960614,6218456,4755966,4755982,4920915,4876032,4759244,4759246,4759247,4759249,4759250,4759252,4922554,4922555,5013451,5013496,5881511,4922556,4922557,4922561,5013453,5881510,4922558,4922560,4975978,4975968,4975979,4975979,4975990,5030921,5989872,8035479,4996084,5040973,5059219,6031497,5085860,5085854,5085863,5085848,5085864,5085848,5085849,5085851,5085853,5085855,5085859,5085863,5085864,5085865,5085867,5085849,5085850,5085852,5085852,5085854,5085854,5085855,5085855,5085856,5085856,5085857,5085862,5085863,5085864,5085864,5085865,5085865,5085866,5085866,5085867,5085868,5085850,5085851,5085852,5085852,5085853,5085853,5085854,5085854,5085855,5085855,5085856,5085857,5085858,5085864,5085865,5085865,5085866,5085866,5085867,5085867,5085868,5085868,5085869,5085871,5085872,5085855,5085855,5085856,5085856,5085865,5085866,5085867,5085868,5085871,5085856,5085856,5085854,5085856,5085860,5085875,5085856,5085856,5085857,5085857,5085859,5085861,5085868,5085875,5085876,5085856,5085858,5085860,5085876,5085876,5085857,5085858,5085858,5085859,5085859,5085876,5085876,5085877,5085858,5085859,5085859,5085860,5085869,5085873,5085877,5085859,5085860,5085860,5085861,5085863,5085869,5085872,5085877,5085878,5085860,5085861,5085861,5085862,5085863,5085864,5085870,5085870,5085873,5085874,5085877,5085878,5085861,5085862,5085862,5085863,5085863,5085864,5085870,5085875,5085878,5085878,5085879,5085862,5085863,5085863,5085864,5085864,5085871,5085872,5085872,5085873,5085878,5085879,5085879,5085863,5085864,5085864,5085865,5085871,5085871,5085872,5085873,5085873,5085874,5085877,5085879,5085879,5085880,5085864,5085865,5085865,5085871,5085873,5085874,5085875,5085879,5085880,5085880,5085865,5085866,5085873,5085874,5085875,5085875,5085880,5085881,5085866,5085867,5085874,5085875,5085879,5085880,5085881,5085881,5085873,5085874,5085874,5085875,5085876,5085881,5085881,5085882,5085876,5085882,5176756,5327976,5176759,5085879,6044819,5085883,5085887,5085887,5176761,6296143,5085880,5085881,5085882,5085882,5085883,5085885,5085887,5085887,5085888,5085888,5176761,6044818,6044820,8090422,5085882,5085882,5085885,5085886,5085888,5085888,5176762,5320877,5688259,6044820,6044820,6044821,6044822,6296143,6296145,6296145,6327862,7426330,8090422,8090423,8090423,5085882,5085883,5085889,5176762,5266420,5400679,6044817,6044821,6044822,6110023,9870342,5085883,5085885,5085889,5085890,5176763,5400680,5688262,5688262,5688264,6044821,6044823,6122584,6434604,5085885,5085885,5085886,5085889,5085890,5085890,5176763,5176763,5320879,5425167,6044820,6044822,6044822,6044823,5085886,5085888,5085891,5085891,5176764,6044819,6044820,6044823,8090425,5085886,5085888,5085890,5085891,5085891,5176764,6044822,5085891,5085892,5176765,6044824,5085891,5085892,5085892,5688264,6044824,6434605,5085893,5085893,5085893,6044825,5085893,5085893,5085894,8090427,5085894,6044826,6044826,5176768,5085895,5085896,5176769,5176830,5264633,5276853,6044824,6044824,6044825,6044826,6044828,6044829,8090429,8090430,11085477,5085896,5085897,5176769,5505621,6044824,6044828,6044828,6296154,5085897,5085898,5144301,5176770,5176817,5276853,5327988,5549486,5688268,5954738,6044824,6044825,6044825,6044826,6044826,6044828,6044828,6044829,6044829,6044830,6044832,6044833,6044834,6296152,6296156,6296158,6296159,6296160,6296161,6296161,6296162,8090431,8090431,9870348,11085478,12686992,5085898,5176770,5327990,5327990,5400687,5549487,5674746,6044825,6044826,6044827,6044828,6044829,6296153,6296158,6296158,6434614,5176833,6044826,6044830,6296155,5202731,5202742,6103255,5337718,5234259,5250963,5265154,6597008,5267642,5267644,5267644,5267645,5267645,5267646,5267681,5267686,5267704,5267704,5267705,5267706,5267706,5267707,5267707,5267708,5267743,5267754,5267757,5267747,5267748,5267750,5267751,5267752,5267767,5267777,5267777,5267790,5267776,5267777,5267777,5267778,5267778,5267790,5267791,5267791,5267787,5267852,5267788,5267789,5267792,5267801,5267802,5267802,5267804,5267851,5267853,5267853,6135775,6200977,5267791,5267854,5633025,5267855,5267856,5267866,6135785,6135787,5267866,5608593,6135784,6135785,5267867,6135788,5267868,5779228,6135789,8043050,6387170,6135838,5355645,5357438,5411895,5411896,5411902,5418998,5491697,5519454,5519544,5633089,5754273,5779275,5779275,5779276,5779276,5779277,5779280,5779280,5779281,5779281,5815091,6049622,6135834,6135835,6135835,6135836,6135836,6135837,6135837,6135838,6135838,6135839,6135839,6135840,6135840,6135841,6135842,6135843,6213601,6387162,6387166,6387171,6393559,6525621,6525622,6525622,6918171,8181441,8181442,8181442,8392788,8557528,10770381,11176489,12777980,12778003,5443386,5443385,6223580,5831799,5446981,5446982,5868822,5508541,8270985,5467820,5467824,5467824,6235794,8281400,6235797,5472688,5475322,5477957,6240870,5555898,5555899,5555899,5555906,5555905,5923279,5923283,6279840,6279842,6279839,6279842,8325445,5570092,5570093,5570093,5570094,5570095,5570095,5895151,5916851,6286931,6286934,6286935,6538262,6676716,8332536,5715487,5715499,6359630,6003081,6359636,6359638,6359638,6359640,6359640,6359641,6424843,5764465,6384120,5770999,5771099,5771186,5771198,6387480,6387484,5795014,6399392,5875300,6439539,5925362,6464569,5949397,5981224,5998276,6501025,6501026,6013034,6013060,6013077,6013080,6013118,6013121,6013120,6013122,6013164,6151905,6508460,6508462,6508465,6573666,6759794,6766184,13096020,6220205,6220208,6611989,6611990,6224907,6614336,6240644,6873540,6263603,6593410,6885010,6290652,6290652,6290652,6290653,6290638,6290638,6290652,6290654,6290655,6290655,6290655,6290656,6290656,6290656,6290656,6290657,6290657,6290657,6290656,6290658,6290658,6290659,6290671,6647215,6647214,6647216,8692818,6647212,6647213,6647214,6647215,6647216,6647216,6647213,6647213,6647214,6647215,6647216,6647216,6647217,6647218,7036999,7103092,7429549,7908826,8692819,6362274,6683022,6809799,6809899,6809998,6906885,6823591,6823650,6913727,6831368,6917586,6923220,6963497,7003756,7003772,7003754,7003755,7003757,7003757,7003754,7003755,7003756,7003756,7003757,7003757,7003758,7003760,7003762,7003771,7003772,7003772,7003773,7003774,7003754,7003755,7003756,7003756,7003757,7003758,7003769,7003771,7003772,7003774,7003755,7003756,7003757,7003757,7003758,7003759,7003770,7003771,7003772,7003774,7003775,7003776,7003756,7003757,7003758,7003759,7003759,7003771,7003772,7003773,7003774,7003774,7003775,7003776,7003776,7003758,7003758,7003759,7003759,7003760,7003764,7003764,7003772,7003772,7003774,7003775,7003776,7003759,7003760,7003774,7003776,7003759,7003760,7003760,7003761,7003763,7003764,7003774,7003774,7003775,7003775,7003776,7003776,7003777,7003777,7003778,7003778,7003760,7003761,7003761,7003774,7003775,7003775,7003776,7003776,7003777,7003777,7003778,7003778,7003779,7003761,7003762,7003762,7003763,7003764,7003765,7003766,7003766,7003767,7003774,7003775,7003775,7003776,7003776,7003777,7003777,7003778,7003778,7003779,7003779,7003762,7003763,7003764,7003765,7003765,7003766,7003775,7003776,7003777,7003777,7003778,7003778,7003779,7003780,7003763,7003765,7003767,7003776,7003776,7003777,7003777,7003778,7003778,7003779,7003779,7003780,7003780,7003778,7003778,7003779,7003780,7003782,7003783,7003767,7003768,7003778,7003782,7003784,7003769,7003770,7003779,7003781,7003781,7003784,7003769,7003780,7003781,7003781,7003782,7003783,7003783,7003786,7003779,7003780,7003781,7003786,7003771,7003781,7003786,7003787,7003772,7003781,7003782,7003783,7003785,7003787,7003780,7003781,7003782,7003785,9049374,7068975,7003795,7393556,7393558,7003790,7255098,7393555,10829293,7003790,7003790,7003791,7003791,7003792,7003793,7255104,8635174,7003790,7003791,7003791,7003792,7003793,7003796,7081537,7255098,7255105,7255108,7393558,7940768,8911035,9425463,12044425,7003791,7003792,7003792,7003793,7003793,7003794,7003794,7003797,7010984,7068978,7255103,7255109,8002966,9049377,9049378,9049378,9425463,10505297,10916188,12044425,12759198,7003792,7003793,7003793,7003794,7003794,7003795,7003796,7003796,7003797,7068978,7081538,7081538,7255106,7255107,7255109,7393559,8319706,9049378,9049378,9049379,9049379,7003793,7003794,7003794,7003795,7003795,7003796,7003797,7068979,7081539,7255100,7255100,7255101,7255101,7255105,7255107,7393557,7393559,7393560,7459652,7786109,7786110,7831988,7853913,7893165,7940769,7940770,8197805,8265336,8265388,8314280,8487983,9049378,9049379,9049379,9049381,11638320,20538408,7003794,7003795,7003795,7003796,7003797,7003798,7068979,7081539,7081542,7255100,7255100,7255101,7255101,7255106,7255108,7261497,7393559,7393560,7393560,7459653,7578769,7940770,8090801,8539622,9049379,9049379,9049380,9049380,9425464,9621736,10296785,10829296,11638319,12044426,12044427,12759199,7003795,7003796,7003796,7003797,7003798,7003799,7068980,7081540,7255101,7255107,7255108,7255109,7255111,7393558,7393561,8911039,9049380,9049380,9425464,10216917,7003796,7003797,7003799,7003799,7068980,7081540,7255101,7255102,7255105,7255107,7255108,7255108,7255109,7261498,7393561,8539620,9049380,9049381,10829298,7003797,7003799,7003800,7068981,7255103,7255104,7255105,7255108,7255110,7255111,7255111,7261499,7393563,7681010,7786111,7926520,7940772,8197809,8229005,8911039,9049380,9049381,9049381,10829298,7003799,7003800,7003800,7068941,7068981,7081541,7255101,7255103,7255104,7255105,7255106,7255106,7255107,7255107,7255108,7255109,7255110,7255111,7255112,7255113,7255113,7393560,7393561,7786111,7786112,7786112,8635178,9049380,9049381,9049381,9049382,9425465,10829298,11629149,7255107,7003802,7255110,7255110,7255111,9049382,9049383,7068983,7003802,7068923,7255104,7255105,7255106,7255109,7255110,7255110,7255111,7255112,7459657,7786113,9049383,9049384,10829301,11638323,7003804,7068984,7255107,7255108,7255108,7255109,7255110,7255111,7255115,7393566,7683103,8265394,8487997,8911043,9049383,9049384,9049384,9049384,7255110,7018214,7088768,7134051,7134057,7134127,7134146,7134167,7134185,7134186,7134186,7134188,7134202,7134206,9114584,7134207,7134208,7146746,7191102,7320308,7320308,7320309,7320311,7320311,7320312,7320314,7320316,7326704,7458768,8959694,9114586,9114586,9114587,9114587,10894504,12109633,7320317,7159295,7159296,7159296,7159297,7159297,7159298,7159299,7159301,7159301,7332857,7332858,7332858,7339254,7471314,7471316,8423265,8738897,9127134,9127135,9127136,9127136,8988794,11716076,7471315,9100185,8605731,7332859,7332869,7471321,7248065,7248168,7248276,7515838,7506422,7506421,7506420,7506421,7506423,7506426,7506410,7506422,7506423,7506425,7506409,7506411,7506414,7506415,7506416,7506416,7506417,7506421,7506423,7506423,7506424,7506424,7506425,7506426,7506431,7506413,7506415,7506424,7506425,7506425,7506426,7506413,7506416,7506417,7506425,7506426,7506431,7506432,7506432,7506433,7506416,7506435,7506415,7506416,7506418,7506436,7506415,7506416,7506418,7506436,7506421,7506437,7506440,7506417,7506419,7506422,7506437,7506439,7506417,7506418,7506418,7506419,7506419,7506427,7506438,7506418,7506419,7506420,7506423,7506438,7506419,7506420,7506421,7506422,7506422,7506424,7506439,7506420,7506421,7506421,7506422,7506422,7506423,7506439,7506440,7506421,7506422,7506422,7506423,7506423,7506424,7506425,7506430,7506440,7506440,7506422,7506423,7506424,7506425,7506431,7506432,7506440,7506441,7506441,7506423,7506424,7506425,7506425,7506441,7506424,7506425,7506426,7506432,7506441,7506443,7506425,7506426,7506427,7506429,7506432,7506442,7506442,7506426,7506427,7506428,7506432,7506434,7506442,7506444,7506427,7506432,7506435,7506442,7506443,7506443,7506444,7506428,7506429,7506434,7506443,7506431,7506432,7506444,7506444,7506430,7506444,7506437,7506446,7506446,9300700,9300699,7506447,7639576,7644883,9300700,9300701,11080619,7506439,7506448,10468237,7506449,7506450,9300702,7506449,7710975,9300702,9300703,9873055,11080620,7506450,9162361,9300703,9300703,7506450,8037434,7506451,7644884,9162362,9300704,10468241,9300704,11889645,7639585,8037440,9300709,9300709,9300711,7506458,7506459,7506460,7506460,7506461,7512830,7644889,7644892,7644892,7644893,7644894,7644894,7644895,7644895,7664316,7739142,8037442,8037442,8037443,8037443,8144789,8192103,8342134,8516670,8516720,8516721,8596841,8809568,8904701,9161674,9300711,9300711,9300712,9300712,9300713,9678907,10540491,11080630,7506460,7506461,7512830,7644892,8083164,8886509,9300712,9300712,9300713,13010533,7506461,7644895,8083165,8330789,9300713,9300713,13014881,7506462,7644893,7644893,7644894,7644895,7644896,8037443,8037445,8516673,9300713,13010534,7644894,9300714,11080634,7519201,7519213,7519213,7519216,7519213,9307094,9307095,7651275,7651277,8348520,8523107,9307097,9307098,9307098,11896037,7569854,9332416,7721661,12403366,7772732,7772737,8325247,8170591,7783337,7783338,7783323,7783338,7783340,7783341,7783338,7783339,7783339,7783339,7783340,7783327,7783340,7783341,7783342,7783327,7783328,7783338,7783339,7783341,7783328,7783342,7783340,7783341,7783342,7783343,7783343,7783344,7783331,7783342,7783343,7783344,7783345,7783345,7783346,7783344,7783346,7783347,9439158,7783353,9439159,8175891,9439160,7783356,7783358,7849433,8330551,8580558,9300818,9439159,9439160,9439160,14035721,7783358,7783359,7849435,8175891,8330552,8668435,9284268,9300819,9351631,9439160,9439160,9439161,9439161,9439162,10606698,11219077,12028100,7928420,9439161,9439162,10606697,12434209,8175892,8366280,7783361,8175892,8330553,8655169,8735294,9300821,9439162,9439163,9439163,7783361,8330554,9439162,9439163,9439163,9815248,8839574,9439163,7822178,7822200,7822384,7822603,7822660,9458813,7915512,7915524,7915513,7915524,7915524,7915525,7915525,7915526,8241980,7915537,8653677,9505251,9091048,9505251,7928864,8465507,7971839,9533408,8073497,9584239,8153756,8361096,8358258,9726630,8362415,9728696,8568436,8568426,8568437,8568437,8568438,8568438,8636241,8723097,8723098,9047715,9322121,9693365,9831706,9831706,9831707,9831707,10861798,12420646,8659869,8659879,8659880,8679517,9877428,8660259,12872697,8699154,9897064,8704046,8704048,9899511,9899514,8782555,9938769,8783145,11106605,8849256,8849326,8849401,9972193,8877746,8877758,8877758,8877747,8877758,8877759,8877759,8877770,9134794,9986368,9703328,9848026,9986368,9986368,10362453,10558724,8949212,9460707,9002154,9002156,10048567,10048569,9155193,9155306,9155415,10125226,9177826,9177826,9177827,10136404,10512489,10136405,9377772,10236374,9391832,9391833,9391834,9459365,10243406,10243407,9454228,10274604,9526896,9526897,9526898,9607070,9801182,10310938,13305986,9526993,9526995,9526997,9526998,9526999,9526998,9526999,9526999,9527000,12090905,10310987,10310989,9749602,10310990,10310989,10310990,10310990,10310990,9553516,9553571,9553647,10185975,9624789,9624864,9624935,10359959,9635630,9635717,9635805,11703420,9687239,9687241,9687241,9743081,10391109,10391110,9766837,9766905,9766981,10431005,9798921,10446949,9895805,10495394,9972192,9972202,9972202,10533588,10533589,10533589,10533590,10052157,10052233,10052308,10949726,10075446,10075461,10075463,10075463,10075467,10075476,10585221,10585220,11825001,10585224,10075803,10075866,10075928,10585451,10112689,10603834,10113721,10604350,10266573,10680776,10680776,10303004,10303079,10303153,10560747,10318500,10706739,10528897,10811938,10785207,10940099,10816901,13544876,10818290,10818292,10818293,10818293,10818294,10818292,10818293,10818294,10818292,10818386,10818387,10818387,10956635,10956635,10956635,10818385,10956635,10956636,10956635,10956636,12736553,10818477,10818482,10818482,10818483,10818483,10956727,10956728,10956729,10956729,11332816,10956730,10919945,11007474,11041070,11444107,11094963,11094963,11094964,11094964,11094965,11094981,11094964,11094965,11094965,11094979,11094980,11094981,11094965,11094966,11094978,11094980,11094980,11094981,11094981,11094982,11094982,11094983,11094983,11094984,11094985,11094966,11094977,11094978,11094978,11094979,11094979,11094980,11094980,11094981,11094981,11094982,11094982,11094983,11094983,11094984,11094984,11094985,11094986,11094987,11094989,11094968,11094978,11094978,11094979,11094980,11094981,11094981,11094982,11094982,11094983,11094983,11094984,11094985,11094985,11094986,11094987,11094988,11094982,11094992,11094992,11094993,11094994,11094992,11094993,11094996,11094993,11094993,11094994,11094995,12874895,11094994,11094995,11094996,11094994,11094996,11094994,11094995,11094996,11094996,12874896,11094995,11094996,11094996,11094997,11094997,11094998,12262515,14090027,11094996,11094997,11094997,11094998,11094998,11094999,11095000,11095001,11095003,11095004,11306326,11427473,11471067,11471068,11667337,11667337,11667339,12262517,12262518,12874896,12874898,12874898,12874899,12874899,13683920,14090028,14142908,11094997,11094998,11094998,11094999,11095000,11095000,11095001,11095001,11095004,11471065,11471067,11473176,11667334,11667335,11667336,12262517,12262518,12262519,12762672,12874898,12874898,12874899,12874900,12874900,13022291,13683920,14090028,14804817,11094998,11094999,11094999,11095000,11095000,11095001,11095002,11095003,11095004,11095006,11306328,11427472,11471067,11471068,11471069,11667335,11667337,11667338,11667338,12262517,12262517,12262518,12262519,12733783,12874898,12874899,12874899,12874900,12874900,13683921,13683921,14090028,14090029,11094999,11095000,11095000,11095001,11095001,11095002,11095002,11095003,11095004,11095004,11095006,11182932,11202749,11202749,11306328,11306329,11415525,11471066,11471067,11471067,11471068,11471069,11471069,11471070,11524479,11524480,11667337,11667337,11667338,11667339,11667339,11671067,12262517,12262519,12262520,12262522,12376121,12874899,12874899,12874900,12874900,12874901,12874901,13683921,13811587,13811588,14090028,14090029,14090029,11095000,11095001,11095001,11095002,11095002,11095003,11095004,11095004,11095005,11137329,11279977,11306327,11306329,11471067,11471067,11471068,11471068,11473177,11473179,11667336,11667338,11667340,12262518,12262518,12262519,12262519,12262520,12874899,12874899,12874900,12874900,12874901,13683922,13683922,13683923,13683924,14090029,14090030,14804802,15691521,11095001,11095002,11095002,11095003,11095003,11095004,11095005,11095006,11306328,11427472,11471067,11473178,11524481,11667338,11667340,12262519,12262519,12262520,12262521,12610783,12874899,12874900,12874902,13683922,13683923,13811589,14090029,11095002,11095003,11095003,11095005,11095005,11306328,11306330,11306330,11427473,11435511,11471069,11667340,12262519,12262520,12874902,12961793,13683923,13683924,14090031,14090033,15691522,11095003,11095004,11095005,11095005,11095006,11095007,11471068,11471070,11471071,11473179,11473180,11484839,11516989,11667339,11667341,11667342,12262521,12262523,12874900,12874901,12874901,12874902,12874902,12874903,13683923,13683925,14090031,11095004,11095005,11471068,11471069,11471071,11471071,11516989,11524482,11667340,12262521,12874901,12874901,12874902,13683924,14090032,14470639,11095005,11095006,11095006,11095007,11095008,11306329,11471069,11471071,11471072,11667339,11667341,11836172,12262519,12262520,12262521,12262522,12262523,12262523,12262524,12874902,12874902,12874903,12961795,13683924,13683925,11095007,11471072,11667341,11667344,11671069,12262519,12262521,12262522,12262525,12262526,12874903,12874903,13683925,11095007,11427474,11667342,11667343,13683925,13683925,11095009,11427481,11471073,12262522,12262527,12874904,12961797,13683926,11095009,11297517,11484842,12262523,12711927,12874905,13022298,13683927,12262524,13683927,11095011,11471072,11667344,12262524,12262525,12874905,13683927,13811594,12262525,12262525,12576476,11306335,15691527,14142918,14090037,11179673,11709683,11270917,11559052,11310510,11310511,11414090,11632241,11464969,12447511,11500041,11673597,11517669,11517668,11517670,11517669,11517672,11517670,11517671,11517671,11517673,11517660,11517672,11517673,11517674,11517674,12473860,11878680,11682409,11684518,12385995,12473860,12473861,12473861,12974019,13895264,11638814,11682409,11682409,13895264,11735824,12473861,13086243,14301374,11682413,15016161,11736067,11736139,14004522,11759957,11759956,11759957,11759960,11759961,11759962,11759965,11803551,11803552,11760051,13207387,11803557,11803557,13207389,11760140,11803643,11776087,11811645,11847148,11847150,11847135,11847136,11847149,11847149,11847150,11847150,11847151,11847150,11847151,11847151,11847136,11847137,11847151,11847152,11847137,11847151,11847152,11847152,11847138,11847139,11847151,11847152,11847152,11847153,11847153,11847152,11847152,11847153,11847153,11847152,11847152,11847153,11847153,11847154,11847153,11847154,13250980,11847165,12043420,12043423,12638601,14060004,11847166,11849260,12043418,12043421,12638601,12638601,13250984,14060004,14466112,11847167,12043420,12638600,12638601,12638602,13250982,13250983,14060005,14060006,11847167,12043421,12609381,13250982,13250983,13250984,13250985,13398377,14060005,14060006,14187674,12043420,12043422,12043423,12043424,12047150,12210171,12388080,12638600,12638602,12638603,12638603,12638606,13250983,13250983,13250984,13250985,14278542,14466113,14466114,15180886,15187878,13250986,11851369,11851370,11851368,11851370,11851371,11851371,11851371,13253090,12640711,12045530,12045531,12045532,13253092,14468222,14613143,15183010,11874690,11874690,12652372,12207877,11933033,13380816,11938986,12972899,15226815,11953972,11953972,11953972,11953973,12096829,12692010,13304394,12692009,13304392,14113414,12239675,12239675,12239675,12239687,12239689,12239674,12239687,12239689,12239676,12239688,12239692,12239687,12239689,12239690,12239690,12239691,12239691,12239692,12239692,12239677,12239678,12239679,12239690,12239692,12239693,12239693,12239694,12239692,12239693,12239693,12239694,12239694,12239695,12239693,12239694,12239695,12239694,12239695,12239693,12239694,12239695,12239701,12614106,13447251,13447251,13447252,12239706,12239705,14256274,14662382,12834872,14256274,14595611,12239707,12239708,12834870,13447252,13447253,13447253,14256275,14256276,12239707,12239708,12834872,12834873,13447252,13447253,13447253,13447254,13447256,14116442,14256275,14662383,12239708,12239709,12834871,12834873,12834873,13447253,13447253,14662384,12834868,12834873,12834874,12834876,13447253,13447254,13447254,13447255,13447256,13594648,13618114,14256276,16263875,12686695,12834871,13447255,13447255,13447256,13447257,14256277,14662385,14715266,16263929,12361054,12834876,12247145,12247145,12247146,12838598,12838599,13450980,12374084,14323469,12482413,13456388,12541064,13597939,12573189,13001621,12577352,13616084,12929009,14600934,12988523,13682643,13133726,14065214,13155161,13904985,13254318,13508762,13371606,13400828,13430049,13430034,13430035,13430036,13430050,13430051,13430038,13430051,13430035,13430037,13430039,13430050,13430051,13430036,13430037,13430048,13430050,13430051,13430051,13430052,13430037,13430038,13430038,13430050,13430052,13430052,13430053,13430055,13430038,13430039,13430051,13430053,13430053,13430054,13430039,13430040,13430041,13430053,13430053,13430054,13430053,13430054,13430055,13430057,13430042,13430055,13430056,13430057,13430057,13430058,13430043,13430057,13430054,13430058,13430056,13430058,13430059,13430059,13430060,13430060,13430060,13430061,14851452,13430066,13430066,13430069,14851456,15976684,16859105,14042432,13430068,14042432,14042433,14042434,14042440,14851455,15972349,13430068,14042433,14042433,14042434,14042434,14042435,14042435,14042436,14851456,15257564,13430069,13430071,13430071,13430072,13596651,13870520,13939404,14042433,14042434,14042434,14042435,14042435,14042436,14042436,14851456,14851456,14851457,14851458,14979120,15257564,15257564,15310446,15972348,13430070,14851457,13430071,14042435,13430072,14002886,14851458,15972347,13430073,13430074,14042436,14042437,13841744,14042436,14042437,14042437,14851458,15972343,15972354,13430075,14042437,14367085,14851459,15257567,16859058,14042438,14851460,14851460,15257571,15972340,15972354,13574536,14114675,16044581,13589789,15337430,13657258,14965058,13763204,13763228,13763248,13763253,14209030,14209031,13771037,14212923,14006802,14006812,14330811,15139833,14029612,15557345,14057953,14356382,14126580,14390698,14253423,14253524,14253625,14454217,14310981,15698025,14328863,16419988,14372587,15322724,14376762,14515785,14430362,14430361,14430365,14542586,14907396,14542588,14448751,15360802,14575711,14615261,14654799,14654800,14654813,14654798,14654799,14654799,14654800,14654800,14654801,14654813,14654814,14654815,14654799,14654800,14654800,14654801,14654801,14654811,14654811,14654812,14654812,14654814,14654814,14654815,14654815,14654816,14654800,14654801,14654801,14654802,14654814,14654814,14654815,14654815,14654816,14654816,14654817,14654801,14654802,14654802,14654803,14654813,14654814,14654815,14654815,14654816,14654816,14654817,14654817,14654818,14654802,14654803,14654804,14654814,14654815,14654816,14654816,14654817,14654817,14654803,14654804,14654805,14654814,14654815,14654816,14654816,14654817,14654818,14654818,14654814,14654815,14654816,14654816,14654817,14654817,14654818,14654818,14654819,14654820,14654813,14654819,14654819,14654818,14654820,14654828,14654822,14654826,14654827,14654827,14654828,14654827,14654827,15463836,14654829,15869943,14654827,14654829,14654830,14654828,14654830,15463836,14654829,14654830,14654831,14802208,15463836,15463836,16584717,16584718,16584723,14654831,14654831,14654832,14741708,15019622,15463837,15591503,15591503,15869945,16584721,16584732,14654831,14654832,15463837,15463838,16584726,16584732,14654832,14654833,15454666,15463835,15463837,15463838,15463838,15591504,16584719,16584720,16584723,14654833,14654835,14741709,14741709,14802207,14802207,14802210,14816302,14883900,15324006,15324007,15454666,15463837,15463837,15463838,15463838,15463839,15463840,15491699,15591504,15591505,15591506,15774080,15869945,15869946,15869946,16584719,16584719,16584731,16584731,16584734,16584735,16589068,16589069,16591710,16882303,17416853,17471437,17471459,17471460,17526616,17526617,20042031,14681448,14727953,15019624,15463837,15463839,15463839,15463840,15591503,15591505,15591507,15869946,15869947,16584720,16584734,15463840,15591506,15463840,15869948,15463843,14708096,15490486,14801089,15536976,14828600,14828601,14828601,15151347,15550730,15680584,15956838,16671611,16671612,15678398,14949598,14949582,14949598,14949597,14949600,14949598,14949601,14949603,15611226,14949613,15611229,15738895,16017336,16017337,16070218,15611231,15611232,14977784,15625320,14996578,14996736,14996680,15634775,14996878,15634883,15112980,15692918,15304110,15788484,15384428,15384430,15384431,16956514,15828644,16234753,15474131,15474206,15474282,16994481,15993191,15993192,15993192,16133024,16539132,16254512,16254514,16254516,16263684,16669793,18271340,16272841,16272842,16272856,16272859,16272842,16272843,16272844,16272858,16272843,16272844,16272858,16272859,16272844,16272845,16272845,16272846,16272858,16272858,16272859,16272859,16272860,16272860,16272861,16272861,16272846,16272857,16272859,16272859,16272860,16272861,16272861,16272862,16272861,16272862,16272863,16272848,16272860,16272861,16272862,16272862,16272863,16272863,16272864,16272864,16272873,17107366,16272875,16272875,16272875,16400524,16272875,16272875,16272876,16272876,16678966,16678966,16678967,17393740,17393754,17398089,18280458,16272875,16272876,16400525,16678967,17393749,16272876,16272877,16272877,16272878,16400524,16400525,16400526,16595027,16678967,16678968,16678969,16678970,16731847,16731848,16731849,16731849,16731850,17393741,17393753,16272877,16400526,16678967,16678968,16678968,16731849,16731850,17393740,17393746,17393753,16272878,16272879,16272879,16272880,16380411,16400527,16400527,16400528,16400528,16508017,16531996,16560076,16678968,16678968,16678969,16678973,16731847,16731848,16731849,16731849,16731850,16731850,16731851,16731856,16923352,17059575,17225344,17391987,17393740,17393741,17393743,17393744,17393745,17393749,17393750,17393752,17393753,17393753,17393754,17393755,17393756,17393757,17398090,17400732,17400733,18280460,18280518,16272879,16272880,16400527,16400528,16400529,16400530,16678968,16678969,16731849,16731849,17393742,17393746,17393748,17393758,18280460,18280483,16400529,16678969,16678969,16678970,16731851,17393743,17393753,16678970,17393746,16731851,17393758,16328578,16759706,16487959,16786517,16528174,16528187,16528188,16528175,16528175,16528176,16528188,16528188,16528190,16528191,16528191,16528194,16528188,16528189,16528190,16528191,16528191,16528192,16528191,16528195,16528193,16528193,16528193,16528193,16528194,16528198,16528202,17519648,17521416,16528204,17521418,16806631,16806631,16806632,16859513,16806632,16528206,16705908,16806633,16859513,17521406,17528397,16528210,16615342,16806632,16806633,16806633,16859513,17521406,17521421,16806636,17521409,17521424,16806637,16532568,16808821,16702536,16893827,16709990,16710065,16710119,17612388,16743172,17628907,16791131,17652876,16847284,16966177,16883625,16984350,16893342,16989208,16917191,17001132,16951528,16951606,16951684,17737499,17085058,17085059,17085074,17085059,17085063,17085074,17085060,17085061,17085062,17085063,17085072,17085072,17085073,17085073,17085074,17085074,17085075,17085075,17085075,17085064,17085076,17085077,17085078,17085080,17085067,17085067,17085078,17085078,17085078,17085079,17085076,17085084,17085085,17085085,17085087,17085085,17085086,17085087,17085086,17085087,17085087,17085088,17085087,17085088,17137953,17085088,17085089,17085089,17085090,17137955,17085090,17137953,17137954,17137954,17137955,17137955,17137956,17137956,17137957,17137957,17329459,17394275,17408786,17414268,17675439,17712016,17771872,17788161,17798093,17799847,17799847,17799848,17799849,17799850,17799850,17799851,17799852,17799852,17799853,17799854,17799854,17799855,17799855,17799856,17799856,17799857,17799857,17799858,17799859,17799860,17799860,17799861,17799861,17799862,17799862,17799863,17799863,17803439,17804195,17804196,17804197,17806838,17806839,17806840,17831606,18025736,18330235,18330238,18476014,18519055,18606576,18631981,18658033,18658034,18686565,18686566,18686584,18686588,18686589,18686589,20295007,17085092,17137953,17137955,17137956,17137956,17137957,17137957,17585391,17799848,17799848,17799851,17799855,17799856,17799860,17799861,17799863,17799863,17799864,17804196,17804197,17806839,17806840,18658034,18686566,17137958,17799864,17190818,17190820,17190834,17190835,17190820,17190820,17190821,17190821,17190833,17190834,17190835,17190835,17190836,17190821,17190821,17190834,17190835,17190836,17190836,17190821,17190822,17190835,17190836,17190836,17190837,17190822,17190823,17190835,17190836,17190837,17190837,17190824,17190835,17190836,17190837,17190838,17190836,17190838,17190838,17190838,17190839,17190849,17190849,17190850,17190850,17824922,17852726,18739445,17190850,17852727,17852728,17852743,18739445,17190851,17382338,17774779,17852728,17852732,17852739,17852741,17852743,17857076,17859719,18150311,17190852,17852728,17852731,17852734,17852734,17852740,17190852,17794034,17852728,17852729,17852729,17852731,17852732,17852735,17852741,17852742,17852744,17859719,18078614,18794627,17190855,17202390,17320113,17382340,17382340,17382341,17774768,17774778,17850974,17852728,17852729,17852729,17852730,17852731,17852732,17852733,17852733,17852734,17852734,17852736,17852736,17852737,17852740,17852740,17852742,17852742,17852743,17852744,17852744,17852745,17859721,18528893,18739447,18739470,19453696,17850976,17852740,17213945,17864283,17374912,17944772,17449384,17982000,17573838,17573839,17573842,17573844,17573845,17573844,17573847,18044228,18044228,18720396,18044240,18044233,18044233,18044239,17703478,18109050,17732492,19010295,17743457,18129049,17846287,17846287,18180462,18180460,17941876,18228249,18085709,18300181,18177886,18178014,18178141,18346424,18265800,18390212,18338952,18338967,18338987,18426803,18358707,18358723,18358725,18436668,18436678,18436674,18397227,18454167,18458731,18458868,18459003,18459037,18486842,18486846,18491242,18491356,18491470,18503042,18511107,18511107,18511111,18512863,18512866,18512876,18512877,18517211,18512877,18512865,18514605,18514604,18514605,18514605,18514619,18514622,18514605,18514606,18514606,18514608,18514608,18514609,18514609,18514610,18514611,18514611,18514612,18514612,18514614,18514615,18514615,18514616,18514617,18514617,18514618,18514618,18514619,18514619,18514620,18514620,18514621,18514621,18514622,18514623,18514623,18514624,18514624,18514625,18514625,18514626,18514627,18514636,18514606,18514607,18514608,18514608,18514609,18514610,18514610,18514611,18514611,18514612,18514612,18514613,18514614,18514615,18514617,18514617,18514618,18514618,18514619,18514619,18514620,18514621,18514621,18514622,18514622,18514623,18514623,18514624,18514624,18514625,18514626,18514636,18514610,18514614,18514617,18514618,18514619,18514621,18514624,18514625,18514633,18514610,18514612,18514617,18514617,18514618,18514618,18514619,18514620,18514621,18514622,18514623,18514636,18514616,18514619,18514637,18514623,18514623,18514638,18514611,18514613,18514613,18514614,18514615,18514615,18514621,18514621,18514623,18514624,18514626,18514627,18514628,18514638,18514612,18514613,18514613,18514615,18514615,18514616,18514617,18514618,18514618,18514620,18514620,18514621,18514621,18514622,18514622,18514623,18514623,18514624,18514627,18514628,18514639,18514615,18514619,18514621,18514624,18514625,18514639,18514616,18514617,18514619,18514621,18514623,18514624,18514625,18514640,18514617,18514620,18514621,18514623,18514624,18514626,18514640,18514616,18514618,18514621,18514625,18514623,18514626,18514626,18514628,18514628,18514642,18514619,18514619,18514622,18514622,18514624,18514626,18514627,18514627,18514629,18514642,18514642,18514624,18514626,18514627,18514627,18514628,18514642,18514621,18514622,18514623,18514625,18514627,18514628,18514628,18514630,18514643,18514622,18514623,18514625,18514626,18514627,18514628,18514628,18514629,18514643,18514623,18514624,18514625,18514626,18514628,18514628,18514629,18514644,18514626,18514627,18514627,18514644,18514624,18514625,18514626,18514627,18514628,18514628,18514629,18514630,18514627,18514629,18514630,18514630,18514631,18514645,18514626,18514627,18514628,18514628,18514629,18514629,18514630,18514632,18514633,18514633,18514646,18514646,18514629,18514629,18514630,18514631,18514645,18514646,18514647,18514742,18514629,18514630,18514630,18514631,18514631,18514632,18514632,18514637,18514647,18514647,18514630,18514630,18514631,18514631,18514632,18514632,18514635,18514647,18514648,18514630,18514631,18514632,18514632,18514633,18514633,18514639,18514641,18514647,18514648,18514648,18514631,18514632,18514632,18514633,18514633,18514634,18514635,18514636,18514648,18514649,18514744,18514632,18514633,18514633,18514634,18514634,18514636,18514637,18514649,18514649,18514650,18514745,18514633,18514634,18514634,18514635,18514635,18514636,18514637,18514639,18514649,18514650,18514634,18514635,18514635,18514636,18514638,18514640,18514648,18514650,18514650,18514635,18514636,18514636,18514637,18514637,18514638,18514638,18514639,18514650,18514650,18514651,18514652,18514654,18514636,18514637,18514637,18514638,18514638,18514639,18514639,18514640,18514640,18514641,18514641,18514650,18514651,18514651,18514652,18514653,18740507,19401339,18514637,18514638,18514638,18514639,18514639,18514640,18514640,18514641,18514647,18514651,18514651,18514652,18514652,18514653,18514654,18518969,18812204,19401362,18514638,18514639,18514639,18514640,18514652,18514652,18514653,19401340,19401363,18514639,18514640,18514641,18514642,18514652,18514640,18514641,18514641,18514642,18514646,18514653,18514653,18514654,18518970,18518972,19321352,19401341,19401363,19401364,18514641,18514642,18514642,18514643,18514644,18514645,18514649,18514653,18514653,18514654,18518972,18518972,18521613,18812207,19386446,19401341,19401364,18514642,18514643,18514644,18514654,18514654,18521614,18700399,18775121,19190788,19401342,19401365,18514643,18514644,18514644,18514651,18514654,18514655,18518973,18521615,18812207,19401342,19401365,18514644,18514645,18514648,18514654,18514655,18514655,18514751,18518973,18521615,19401366,18514647,18514648,18514654,18514655,18514655,18514656,18514659,19372810,19401343,18514651,18514656,18514656,19401367,18514655,18514656,18514657,19346760,19401367,18514657,18514658,18514652,19401346,18514653,18514659,18514660,18514660,18514661,18514662,18514662,19401350,19401374,18514664,18514665,18514665,18521626,18514665,18514666,18518984,18521627,19401353,18514666,18514667,18514667,18514670,18514762,18518984,18518984,18518985,18518985,18518986,18521626,18521627,18521627,18521628,18812216,18812219,19321365,19346769,19372821,19372822,19401354,19401377,19401410,18514667,18514668,18514668,18514669,18514669,18514670,18514762,18514762,18518228,18518984,18518984,18518985,18518985,18521626,18521626,18521627,18521627,18521628,18521628,18521629,18756270,18786063,18812218,18812219,18812219,18812220,18812220,18812221,18841211,18867345,18986516,19190800,19190801,19190802,19190802,19290594,19321365,19346770,19346770,19372821,19372822,19401354,19401377,19401377,19401406,19671137,21925014,18514668,18518985,18518985,18518986,18521627,18521628,18521628,18681283,18796669,18812220,18997934,19045024,19190802,19190803,19346770,19372822,19372823,19401354,19401355,19401405,20164331,18514763,18518985,18518986,18521627,18521628,18521628,18812219,18812221,19190802,19321366,19321366,19346771,19401355,19401355,19401378,18518987,19401356,18518987,18521629,19401356,19401379,19401380,18518988,19401380,18521631,18514867,18514867,18519090,18519090,18519091,18521732,18521734,18812322,19190905,19346875,19401459,19401482,18521803,18521804,19324941,19404930,18523301,18523302,18523316,18523317,18523302,18523303,18523316,18523317,18523318,18523303,18523316,18523317,18523318,18523318,18523305,18523316,18523316,18523317,18523318,18523319,18523317,18523319,18523320,18523331,18523331,18523332,18525958,18525959,18525959,18685614,18760600,18816552,19345917,18523331,18523332,18525936,19405709,18523333,18525959,18525960,18525960,18760603,18790395,19325698,19351102,19377155,19405687,19405710,19405738,18525961,18525960,18525960,18525961,18525961,18525962,18525963,18538340,18574367,18685616,18760602,18816552,18816552,18816553,18816554,18816554,18816555,18930154,19049337,19171203,19325699,19351103,19377155,19377156,19405687,19405688,19405709,19405710,19405711,19405736,19405737,19405738,18528551,18528575,18528600,18528587,18528601,18528601,18528587,18528588,18528598,18528600,18528601,18528602,18528603,18528588,18528600,18528601,18528601,18528602,18528602,18528603,18528603,18528602,18528603,18528604,18528603,18528604,18528604,18528605,18528607,19328337,19353743,19408327,18819193,18819195,19353743,18528616,18528617,18819194,19328339,19353744,19379796,19379797,19408328,19408351,19408351,18747494,19408329,19408352,19408417,18528618,18688257,18747495,18819195,19197776,19353745,19408329,19408352,19408352,18819195,19328341,19408330,18763246,18819195,18819196,18819197,18931019,19051980,19051990,19051999,19129400,19197777,19197778,19353746,19353757,19371605,19379798,19379798,19379799,19408330,19408330,19408353,19408359,18819197,18553356,19340715,18578135,19378510,18625418,18625480,18625551,19456810,18847910,18847911,18847911,19567982,18907151,18978849,19487998,18886203,21195586,18966390,18966391,18966393,18966393,18966394,18966396,19627225,19270895,19547236,19627225,18997872,18997882,18997886,18997885,18997888,18997888,19027677,18997897,19642969,19432417,19562982,19053837,19642972,19035614,19661886,19057476,19057483,19057486,19102641,19644243,19413466,19078681,19078753,19078819,19683456,19109784,19109784,19109787,19109771,19109785,19109786,19109786,19109787,19109774,19109787,19109787,19109788,19109787,19109789,19109788,19109788,19109790,19109788,19109789,19109789,19109802,19342571,19342590,19342591,19342592,19488367,19488368,19531411,19644337,19670389,19698921,19698921,19698944,19223388,19342592,19488368,19488371,19644337,19698922,19109804,19644338,19284085,19639154,19644338,19164911,19644339,19698924,19147809,19717936,19167766,19517356,19220030,19220035,19543490,19674055,19333446,19782224,19336990,19336994,19732535,19757943,19458381,19873219,19873245,19481212,19884632,19575396,19575404,19575414,19575416,19575424,19575425,19575407,19575427,19931736,19931746,19877163,19851766,19877170,19931755,19730193,19730326,19730457,20009254,19769432,19861232,19819091,20053576,19866948,19866947,19866949,19866950,19866950,19866951,19866937,19866949,19866949,19866949,19866951,19866952,19866952,19866953,19866953,19866953,19866952,19866952,19866953,19866954,20077524,20077502,19997512,19997513,20022918,20077503,20077503,19866967,20022919,20077504,20077526,20022920,20048972,20077527,20022920,20077505,20022921,20077505,19953033,19953036,20120543,20120546,20066536,20122712,20128076,20128078,20128077,20128079,20128083,20153482,20208066,20153483,20179534,20179536,20179536,20208068,20208091,20168516,20173700,20178873,20178874,20178874,20178892,20178896,20178897,20178898,20178899,20178899,20178915,20178917,20178899,20178917,20178899,20178900,20178918,20178917,20178918,20233476,20233480,20233482,20178924,20178942,20204951,20204951,20204952,20218587,20233482,20233483,20233505,20233506,20233510,21841922,21841922,20178943,20204951,20204951,20218588,20233472,20233483,20233506,20233484,20233492,20233499,20233501,20233501,20233524,20214603,20222796,20230989,20230991,20230992,20230992,20230979,20230992,20230993,20230993,20230991,20230992,20230993,20230993,20230993,20230995,20230992,20231006,20259523,20259523,20259524,20259547,20259524,20259570,20259524,20259525,20259547,20259548,20259548,20259526,20258263,20258264,20273159,20288030,20288041,20288042,20288043,20288043,20288044,20288044,20288045,20288045,20288051,20288053,20288058,20288062,20288063,20288064,20288064,20288065,20288067,20288118,20288043,20288044,20288044,20288045,20288052,20288058,20288064,20288064,20288065,20288044,20288045,20288045,20288046,20288059,20288065,20288065,20288045,20288046,20288059,20288063,20288065,20288066,20288046,20288066,20288047,20288048,20288049,20288050,20288055,20288057,20288062,20288063,20288063,20288064,20288065,20288066,20288066,20288067,20288067,20288048,20288063,20288067,20288067,20288065,20288067,20288068,20288069,20288056,20288063,20288070,20288073,20288061,20288062,20288065,20288062,20288063,20288074,20288065,20288075,20288076,20288141,20288077,20288077,20288078,20288080,20288080,20288081,20288078,20288082,20288083,20288083,20288083,20288083,20288084,20288084,20288085,20288085,20288086,20288086,20288086,20288087,20288087,20288117,20288088,20288089,20288089,20288090,20288090,20288091,20288091,20288092,20288092,20288093,20288093,20288094,20288096,20288097,20288097,20288099,20288100,20288101,20288103,20288103,20288104,20288104,20288105,20288105,20288106,20288106,20288107,20288107,20288108,20288108,20288109,20288110,20288110,20288111,20288111,20288112,20288112,20288113,20288114,20288114,20288115,20288115,20288116,20288117,20288118,20288139,20288140,20288089,20288090,20288090,20288091,20288091,20288092,20288092,20288093,20288093,20288094,20288094,20288096,20288097,20288098,20288100,20288102,20288103,20288106,20288107,20288107,20288108,20288109,20288109,20288110,20288111,20288114,20288115,20288115,20288141,20288090,20288091,20288091,20288092,20288093,20288093,20288103,20288104,20288108,20288109,20288112,20288116,20288091,20288092,20288092,20288093,20288094,20288095,20288099,20288102,20288104,20288106,20288108,20288108,20288110,20288110,20288112,20288116,20288092,20288093,20288094,20288094,20288095,20288096,20288099,20288102,20288105,20288106,20288107,20288109,20288110,20288110,20288111,20288112,20288115,20288116,20288117,20288093,20288094,20288094,20288095,20288096,20288097,20288098,20288101,20288102,20288103,20288105,20288106,20288106,20288107,20288107,20288108,20288108,20288109,20288109,20288110,20288110,20288111,20288111,20288112,20288112,20288113,20288113,20288114,20288116,20288116,20288117,20288117,20288118,20288118,20288119,20288119,20288121,20288126,20288143,20288095,20288096,20288105,20288108,20288109,20288109,20288110,20288113,20288095,20288096,20288096,20288097,20288097,20288098,20288100,20288101,20288103,20288104,20288106,20288107,20288108,20288110,20288110,20288111,20288112,20288114,20288114,20288117,20288096,20288097,20288100,20288101,20288101,20288104,20288107,20288108,20288109,20288110,20288111,20288112,20288113,20288114,20288118,20288097,20288098,20288102,20288106,20288107,20288108,20288111,20288112,20288115,20288098,20288099,20288108,20288111,20288115,20288120,20288099,20288100,20288100,20288101,20288101,20288103,20288104,20288105,20288106,20288107,20288107,20288108,20288110,20288110,20288111,20288111,20288112,20288112,20288113,20288113,20288114,20288116,20288116,20288118,20288119,20288120,20288137,20288106,20288111,20288114,20288114,20288116,20288117,20288122,20288105,20288113,20288114,20288116,20288106,20288114,20288116,20288116,20288118,20288111,20288118,20288116,20288124,20288106,20288107,20288115,20288119,20288124,20288111,20288114,20288114,20288115,20288116,20288116,20288117,20288118,20288119,20288119,20288117,20288116,20288117,20288117,20288116,20288117,20288131,20288115,20288117,20288117,20288118,20288120,20288120,20288121,20288126,20288127,20288114,20288116,20288119,20288121,20288121,20288116,20288119,20288121,20288122,20288124,20288124,20288117,20288120,20288120,20288122,20288118,20288119,20288120,20288120,20288121,20288122,20288123,20288123,20288125,20288125,20288126,20288128,20288129,20288130,20288119,20288121,20288121,20288122,20288123,20288124,20288125,20288126,20288130,20288132,20288121,20288123,20288124,20288125,20288139,20288121,20288122,20288123,20288123,20288125,20288127,20288127,20288128,20288130,20288131,20288132,20288122,20288123,20288124,20288125,20288125,20288126,20288127,20288128,20288130,20288131,20288132,20288135,20288140,20288123,20288124,20288124,20288125,20288126,20288127,20288130,20288132,20288124,20288126,20288126,20288127,20288128,20288129,20288129,20288131,20288132,20288132,20288133,20288134,20288125,20288126,20288127,20288129,20288129,20288130,20288133,21051056,20288127,20288127,20288128,20288129,20288130,20288130,20288132,20288133,20288134,20288134,20288135,20288135,20288136,20288127,20288128,20288128,20288129,20288130,20288128,20288129,20288130,20288131,20288133,20288134,20288134,20288135,20288135,20288136,20288137,20288138,20288143,20288129,20288130,20288130,20288131,20288131,20288132,20288134,20288134,20288135,20288135,20288136,20288137,20288137,20288138,20288139,20288172,20288131,20288131,20288132,20288132,20288134,20288135,20288136,20288136,20288137,20288144,20288161,20288131,20288132,20288135,20288137,20288132,20288133,20288133,20288135,20288136,20288136,20288138,20288133,20288134,20288134,20288135,20288136,20288136,20288137,20288137,20288138,20288138,20288139,20288139,20288140,20288141,20288141,20288142,20288143,20288143,20288145,20288145,20288146,20288148,20288157,20288134,20288135,20288135,20288136,20288136,20288137,20288137,20288138,20288138,20288139,20288139,20288140,20288140,20288141,20288141,20288142,20288148,20288135,20288136,20288137,20288137,20288138,20288138,20288139,20288139,20288140,20288140,20288141,20288142,20288137,20288137,20288139,20288139,20288142,20288138,20288139,20288139,20288140,20288138,20288139,20288140,20288140,20288139,20288140,20288140,20288141,20288141,20288142,20288142,20288143,20288143,20288144,20288146,20288148,20288149,20288151,20288140,20288141,20288141,20288142,20288142,20288143,20288143,20288144,20288150,20288151,20343270,20288141,20288142,20288142,20288143,20288143,20288144,20288144,20288145,20288146,20288147,20288149,20288150,20288167,20288142,20288143,20288143,20288144,20288144,20288145,20288145,20288146,20288147,20288148,20288148,20288150,20288150,20288163,20288167,20288143,20288144,20288144,20288145,20288145,20288146,20288146,20288147,20288148,20288149,20288149,20288150,20288150,20288151,20288151,20288153,20288161,20288167,20288168,20288144,20288145,20288145,20288146,20288146,20288148,20288149,20288149,20288151,20288151,20288152,20288167,20288168,20288145,20288146,20288146,20288147,20288147,20288148,20288148,20288149,20288149,20288150,20288150,20288151,20288152,20288152,20288153,20288154,20288159,20288166,20288167,20288167,20288169,20288146,20288147,20288147,20288148,20288148,20288149,20288149,20288150,20288150,20288151,20288151,20288152,20288152,20288153,20288154,20288154,20288155,20288159,20288162,20288164,20288167,20288169,20288147,20288148,20288148,20288149,20288149,20288150,20288150,20288152,20288152,20288153,20288154,20288155,20288157,20288170,20288148,20288149,20288149,20288150,20288150,20288151,20288151,20288152,20288152,20288153,20288153,20288154,20288154,20288155,20288160,20288163,20288165,20288168,20288170,20288149,20288150,20288150,20288151,20288151,20288152,20288152,20288153,20288153,20288154,20288154,20288155,20288156,20288157,20288158,20288159,20288160,20288162,20288164,20288166,20288169,20288170,20288171,20288150,20288151,20288151,20288152,20288152,20288153,20288153,20288154,20288154,20288155,20288155,20288156,20288156,20288160,20288161,20288162,20288165,20288171,20288171,20288151,20288152,20288152,20288153,20288154,20288154,20288155,20288155,20288157,20288172,20288152,20288153,20288153,20288154,20288154,20288155,20288155,20288156,20288157,20288166,20288172,20288153,20288154,20288155,20288155,20288156,20288156,20288157,20288158,20288161,20288164,20288166,20288166,20288168,20288171,20288171,20288173,20288154,20288155,20288155,20288156,20288156,20288157,20288157,20288158,20288158,20288160,20288161,20288162,20288163,20288165,20288168,20288171,20288173,20288173,20288155,20288156,20288156,20288157,20288157,20288158,20288160,20288162,20288168,20288174,20288156,20288157,20288157,20288158,20288162,20288164,20288157,20288158,20288158,20288159,20288159,20288160,20288163,20288165,20288166,20288169,20288174,20288175,20288158,20288159,20288159,20288160,20288160,20288161,20288161,20288162,20288163,20288164,20288165,20288165,20288166,20288167,20288167,20288168,20288170,20288171,20288172,20288173,20288173,20288174,20288174,20288175,20288175,20288159,20288160,20288160,20288161,20288161,20288162,20288163,20288163,20288164,20288164,20288165,20288165,20288166,20288167,20288167,20288168,20288168,20288169,20288170,20288170,20288171,20288172,20288173,20288173,20288174,20288174,20288175,20288175,20288176,20288160,20288161,20288161,20288162,20288163,20288163,20288165,20288165,20288166,20288166,20288168,20288168,20288170,20288170,20288171,20288171,20288172,20288174,20288175,20288176,20288176,20288161,20288162,20288163,20288164,20288167,20288173,20288175,20288176,20288177,20288162,20288164,20288164,20288165,20288167,20288169,20288169,20288170,20288173,20288177,20288177,20288164,20288164,20288165,20288165,20288166,20288166,20288167,20288168,20288169,20288169,20288170,20288170,20288171,20288171,20288172,20288172,20288173,20288174,20288176,20288176,20288177,20288177,20288178,20288165,20288178,20288178,20288165,20288166,20288169,20288172,20288178,20288179,20288166,20288167,20288168,20288169,20288169,20288174,20288177,20288178,20288179,20288167,20288168,20288169,20288170,20288179,20288180,20288168,20288169,20288169,20288170,20288170,20288171,20288177,20288178,20288180,20288180,20288169,20288170,20288171,20288172,20288174,20288175,20288177,20288180,20288181,20288170,20288171,20288171,20288172,20288173,20288174,20288176,20288178,20288181,20288181,20288171,20288173,20288173,20288176,20288176,20288180,20288181,20288181,20288172,20288176,20288177,20288180,20288182,20288182,20288173,20288174,20288175,20288175,20288176,20288176,20288177,20288177,20288178,20288180,20288180,20288181,20288182,20288182,20288183,20288176,20288176,20288177,20288181,20288182,20288183,20288175,20288182,20288183,20288184,20288197,20288176,20288178,20288178,20288179,20288180,20288180,20288181,20288183,20288184,20288184,20288177,20288179,20288179,20288183,20288184,20288184,20288185,20288183,20288184,20288184,20288185,20288180,20288181,20288186,20288180,20288181,20288183,20288186,20288186,20288181,20288182,20288184,20288185,20288186,20288186,20288187,20288182,20288183,20288183,20288185,20288186,20288186,20288187,20288187,20288210,20288186,20288187,20288187,20288188,20288186,20288187,20288188,20288188,20288187,20288187,20288188,20288189,20288189,20288189,20288189,20288189,20288190,20288190,20288189,20288190,20288190,20288191,20288190,20288191,20288191,22858654,20288191,20288192,20288192,20288193,20288194,20288194,20288195,20288196,20288197,20288199,20288200,20288203,20288204,20288205,20288205,20288206,20288206,20288210,20288211,20288211,20288212,20288213,20288214,20288214,20288215,20288216,20326165,20343296,20343297,20343297,20343298,20343299,20343299,20397529,20416447,20575659,20575662,20733821,20733822,20733822,20733824,21001461,21001461,21002365,21002366,21002366,21002367,21002367,21051090,21051090,21051091,21051092,21051092,21051094,21051094,21051095,21550463,21550464,21550464,21550465,21896558,21896581,22056963,22182615,22278321,22497423,22733761,22811777,22811777,22858655,22962078,34826259,20288194,20288195,20288195,20288196,20288197,20288197,20288198,20288199,20288200,20288201,20288202,20288202,20288203,20288203,20288204,20288204,20288205,20288206,20288206,20288207,20288208,20288209,20288210,20288210,20288211,20288211,20288212,20288212,20288213,20288213,20288214,20288214,20288215,20288216,20288216,20343298,21002368,21550466,20288195,20288196,20288197,20288199,20288199,20288201,20288205,20288206,20288207,20288210,20288211,20288212,20288212,20288213,20288213,20288214,20288214,20288215,20288215,20288196,20288207,20288214,20288217,20288200,20288200,20288202,20288203,20288207,20733824,20288201,20288204,20288210,20288210,20288215,20288216,20288218,20288201,20288215,20288218,20288206,20288210,20288210,20288215,20288218,20288219,20288205,20288218,20288212,20288219,20288222,20288207,20288209,20288213,20288217,20288217,20288218,20288218,20288219,20288220,20288221,20288223,21002373,20288222,20288213,20288214,20288218,20288220,20288222,20288223,20288214,20288219,20288220,20288222,20288215,20288224,20288222,20288216,20288217,21550475,20288217,20288217,20288219,22278333,20288217,20288224,20288225,20288228,20288218,20288219,20288221,20288223,20288224,20288225,20288225,20288226,20288227,21896571,20288222,20288222,20288225,20288226,20288227,20288227,20288229,20343309,21002379,20288224,20288225,20288227,20288229,20288227,20288227,20288224,20288229,20288226,20288226,20288227,20288227,20288229,20288230,20288227,20288228,20288229,20288231,20288227,20288228,20288229,20288231,20288228,20288229,20288230,20288230,20288232,20343314,20288229,20288230,20288230,20288231,20288232,20288230,20288231,20288231,20288232,20288232,20288233,20288231,20288232,20288233,20288233,20288234,20288235,20343315,20288232,20288233,20288234,20288233,20288234,20288234,20288235,20288235,20288236,20288234,20288235,20288235,20288236,20288237,20288236,20288237,20288237,20343318,20288237,20288238,20288238,20288239,20288240,20288240,20288241,20288277,20288295,20324624,20324683,20343316,20343318,20343319,20343320,20343320,20343321,20343321,20343322,20343322,20343323,20449262,20548371,20575683,20575684,20603574,20733842,20733844,20733845,20733845,20943320,20943321,21001482,21001482,21001484,21001485,21002388,21002389,21002389,21002390,21002390,21051112,21051113,21051113,21051114,21051115,21051116,21051118,21125702,21550487,21550488,21550488,21896580,21896581,21896581,21896582,22087348,22278351,22623338,22811801,22858678,22962079,20288240,20288278,20299528,20324625,20343320,20343320,20343321,20343321,20343322,20343323,20343324,20349933,20454048,20575685,20733845,20733846,20733848,20943321,21002389,21002389,21002390,21002390,21002391,21051113,21051115,21051118,21550488,21896581,21896582,22858679,20343320,20343321,20343322,20343322,20343323,20397557,20733845,20733846,20943322,21002389,21002389,21002391,21051114,21051117,21896582,20343323,20361710,20288391,20343376,20343430,20343433,21051229,20310829,20354622,20361064,20361068,20361140,20361142,20361198,20361213,20361215,20379835,20379835,20379836,21038903,21087629,20364147,20381279,20398408,20398409,20398399,20398400,20398401,20398401,20398402,20398402,20398403,20398403,20398415,20398415,20398416,20398416,20398417,20398417,20398401,20398402,20398402,20398403,20398405,20398415,20398416,20398416,20398402,20398403,20398404,20398404,20398415,20398416,20398416,20398417,20398417,20398418,20398403,20398404,20398416,20398417,20398417,20398418,20398418,20398417,20398417,20398418,20398418,20398419,20398419,20398405,20398406,20398417,20398418,20398418,20398419,20398420,20398406,20398418,20398418,20398419,20398419,20398421,20398418,20398419,20398422,20398419,20398420,20398420,21057481,20788941,20398431,20398430,20398431,20398431,20398432,20529066,20582981,20658670,20788940,20788940,20788941,20954538,21056579,21057482,21057484,21057485,21057485,21057486,21106209,21106211,21106213,21605582,21605584,21951677,22913819,20398431,20398432,20398433,20398435,20452652,20471565,20658515,20783441,20788940,20788941,20788942,20954935,20985832,20998417,20998417,20998418,21057484,21057485,21057485,21057486,21106210,21106211,21106214,21605583,21605584,21951677,22913774,22913820,20398432,20398433,20398433,20405782,20416804,20452652,20532080,20630779,20788941,20788941,20788942,20954936,20991724,20998417,20998418,20998419,21056580,21056581,21057484,21057485,21057485,21057486,21057486,21057487,21106209,21106210,21106211,21106211,21106213,21605583,21605584,21605585,21951675,21951676,21951677,21951678,22472078,22725522,22866897,22913775,20398433,20398434,20398434,20405783,20471567,20613020,20630781,20677865,20788941,20788942,20788942,20788943,20998418,20998418,21056580,21057485,21057486,21057486,21057487,21057487,21106209,21106210,21106211,21106211,21106212,21106212,21605585,21951676,21951677,21951678,21951696,22913775,22913821,20452653,20788943,20788945,20998418,20998418,21050732,21056582,21057484,21057487,21106213,21106213,21951679,21951679,20788943,21050733,21057486,21057487,21057488,21951679,21605586,21057488,21106215,21951680,20411641,21005030,20413142,20413146,20413259,21005781,20413376,21959170,20435186,20435307,20435308,20435431,20435431,21075990,21075991,20506879,20506885,20506885,20506885,20843172,21009168,20843175,21160445,21160447,20544712,20544713,20544717,21130632,21130631,22406593,20610303,20894883,20619875,21216940,20659713,21188132,20665748,20811534,20767547,21182983,20808517,21262535,20827620,21272086,22166278,20863141,20863140,20863141,20863143,20863143,21289847,21289847,21021304,21338573,21338575,23146137,20918611,21317581,20918925,20918925,21865838,21865839,20957311,20957312,21068389,21336931,21168521,21174021,21179462,21179463,21179453,21179464,21179465,21179466,21179468,21179469,21179469,21179451,21179453,21179466,21179466,21179467,21179467,21179468,21179469,21179466,21179467,21179467,21179468,21179468,21179469,21179469,21179454,21179467,21179468,21179470,21179468,21179469,21179469,21179471,21179470,21179472,21179500,22342200,21448010,21179482,21179483,21179484,21193623,21382249,21388942,21388943,21447105,21447105,21448009,21448009,21448010,21448010,21496734,21496734,21496735,21496736,21496738,21496739,21996110,22342202,22342202,22342225,21388942,21448008,21448010,21448011,21448012,21496734,21179484,21179485,21388943,21388944,21448011,21448011,21448012,21496736,21496737,21996110,22342203,21448011,21448012,21448013,22978145,21179486,21448013,21448013,21179486,21388944,21448011,21448012,21496741,22342205,21179489,21345463,21388945,21448013,21448013,21448014,21462989,22342205,21388946,21448013,21448014,21448014,21448016,21179533,21448042,21207780,21510893,21510722,21613667,21511441,21511478,21511479,21554856,21554959,21614026,21662752,21573245,21693622,21585031,21585032,21650790,21699519,21598207,21598316,21598402,21598417,21598417,21598403,21598418,21598418,21598418,21598419,21598419,21598419,21598419,21598422,21598424,21657486,21598433,21656581,21657485,21657486,21706212,22205585,22551677,22551678,21656582,21657484,21657485,21657486,21657486,21657487,21657487,21657488,21706211,21706212,21706212,22551679,21657488,22551679,21657488,21703042,21703046,21758522,21709801,21714737,21714735,21714737,21714738,21714739,21714740,21714741,21714742,21714742,21714742,21714805,21714806,21714806,21714805,21714807,21714807,21714808,21714808,21714809,21714809,22609839,21714873,21714873,21714874,21714874,21715709,21715711,21715711,21715712,21715713,21764436,21764437,21764438,22609904,21716536,21716537,21716549,21716537,21716537,21716552,21716538,21716553,21716538,21716551,21716552,21716552,21716554,21716554,21716538,21716539,21716539,21716540,21716553,21716553,21716554,21716555,21716539,21716540,21716540,21716553,21716554,21716554,21716555,21716555,21716540,21716541,21716552,21716552,21716553,21716553,21716554,21716555,21716555,21716556,21716541,21716552,21716553,21716553,21716554,21716554,21716555,21716555,21716556,21716556,21716553,21716553,21716554,21716554,21716555,21716555,21716556,21716556,21716557,21716564,21716566,21716567,21716567,21716566,21716567,21716567,21716568,22264650,22610743,21716567,21716569,21765276,21765277,21765279,22610743,23572842,21716567,21716568,21716568,21716569,21716569,21765278,22264651,22264652,22610745,21716568,21716569,21716569,21716570,21765278,21765279,22264651,22264651,22610745,22610746,21716569,21716570,21716570,21765277,21765278,21765279,21765279,21765280,21765281,21765283,22264651,22264653,22264653,22382119,22610746,23525966,23572843,23572901,23676244,21716570,21716571,21765278,21765279,21765279,21765280,21765280,21765281,21765281,21765282,21765283,22264650,22264652,22264653,22264653,22476070,22610746,22610747,23281187,23572844,23572889,21716571,21765279,21765280,21765281,21765282,21765284,22254589,22264651,22264652,22264654,22264654,22429211,22610747,22610747,22610769,23572844,21758124,21765278,21765279,21765279,21765280,21765280,21765281,21765281,21765282,21765282,21765283,21765283,21765284,21765284,21765285,21855606,22264651,22264653,22264653,22264654,22264654,22264655,22264655,22444790,22536729,22536730,22536731,22610746,22610747,22610747,22610748,22610769,22992510,22992513,23525967,23525967,23525968,23572845,21746502,21780250,21799689,21806844,22306219,21813986,21814002,21813987,21813988,21813989,21814002,21814003,21813987,21813989,21813989,21814003,21814004,21814006,21814007,21813989,21813989,21813990,21813990,21813991,21813991,21813992,21813992,21813993,21814003,21814004,21814005,21814005,21814006,21814006,21814007,21814007,21813990,21813990,21814007,21814008,21813990,21813991,21813992,21813992,21813993,21813993,21814004,21814005,21814008,21814008,21814009,21813991,21813992,21813993,21813994,21814005,21814006,21814006,21814007,21814008,21814009,21814009,21814010,21813992,21813993,21813993,21813994,21814005,21814006,21814008,21814009,21814010,21814010,21813994,21813994,21814008,21814010,21814010,21814011,21814011,21813995,21814007,21814010,21814011,21814011,21813995,21813996,21814008,21814010,21814011,21814011,21814012,21814013,21813996,21813997,21814007,21814011,21814012,21814008,21814009,21814012,21814012,21814013,21814010,21814013,21814014,21814013,21814019,21814020,21814023,22313377,22313377,22313378,22659470,22659471,22659471,23574691,23621568,23621614,23724991,21814021,21814024,21814025,22313378,22659472,22659494,21814024,23041237,21814022,21814023,21814024,21814026,21859727,22313379,22659472,22659472,22659473,21814025,21814026,22659473,23574692,21814025,21814026,21814026,22659473,21814025,22659474,21814027,21814027,22313381,22313381,22659473,22659474,21814027,21814028,21814029,21950383,22074043,22270407,22313378,22313379,22313380,22313380,22313381,22313381,22313382,22313382,22313383,22493518,22585458,22659473,22659474,22659475,22659475,22712597,22714175,22802708,22819880,23041246,23574694,23574695,23621572,23621618,21814028,21814029,22313381,22313382,22313383,22313386,22659474,22659474,22659475,22659475,22659476,21814029,22313382,22313382,22313384,22659475,22659475,22659476,23329916,23574695,22313382,22313384,22659475,22659476,22313384,22493520,22659476,22659496,21905444,22359097,21963181,22734061,21994665,22403713,22086768,22086843,22086919,22449838,22449841,22334074,22919506,23881603,22726802,23115870,22792620,23201895,22812744,22812744,22812733,22812749,22812747,22812734,22812748,22812750,22812735,22812736,22812749,22812751,22812735,22812736,22812748,22812750,22812750,22812751,22812736,22812737,22812737,22812750,22812750,22812751,22812751,22812752,22812737,22812751,22812751,22812752,22812752,22812750,22812752,22812752,22812753,22812752,22812753,22812753,22812754,22812759,23158841,24224339,23158842,22812763,22812765,23158843,22812766,23084826,23158843,23158844,22812765,22812766,22812766,23158843,23158844,23158867,22812766,22812767,23158843,23158844,23158844,23158845,23213546,22812767,23084827,23084828,23158844,23158844,23158845,23158845,23158846,23158864,24074064,26168955,22812769,22946053,23080741,23084828,23158844,23158844,23158845,23158845,23158846,23158846,23158868,23227942,23476583,23719636,24074065,24120943,23158845,24120944,23158849,23047681,23276308,23079358,23292151,23141863,23323398,23173020,23173021,23264960,23338978,23338978,23235638,23370315,23348730,23426834,23356901,23356901,23356901,23356902,23356902,23430918,23430919,23430919,23430920,23430942,24346137,23504920,23504921,23504921,23504922,23504944,23504921,23504922,23504922,23504939,23504939,23504943,23504922,23504923,23504923,23504924,23504939,23504942,23504944,23504948,23504924,23504925,23504925,23504927,23504931,23504932,23504934,23504937,23504938,23504938,23504939,23504939,23504940,23504940,23504941,23504941,23504942,23504942,23504943,23504943,23504944,23504944,23504945,23504945,23504946,23504946,23504947,23504947,23504948,23504948,23504949,23504949,23504950,23504950,23504951,23504951,23504952,23504952,23504953,23504953,23504954,23504954,23504955,23504956,23504956,23504925,23504926,23504937,23504938,23504938,23504939,23504939,23504940,23504940,23504941,23504941,23504942,23504942,23504943,23504943,23504944,23504944,23504945,23504945,23504946,23504946,23504947,23504947,23504949,23504950,23504953,23504958,23504933,23504943,23504944,23504955,23504943,23504954,23504946,23504950,23504947,23504953,23504952,23504950,23504954,23504956,23504958,23504952,23504954,23504965,23504953,23504954,23504956,23504957,23504958,23504963,23504955,23504955,23504956,23504957,23504958,23504959,23504960,23504961,23504963,23504966,23504967,23504968,23886709,24116849,23504956,23504956,23504957,23504957,23504958,23504958,23504959,23504960,23504962,23504963,23504964,23504966,23504968,23504977,24420158,24467036,23504957,23504957,23504958,23504959,23504959,23504960,23504961,23504962,23504964,23504968,23504969,24467037,23504958,23504959,23504959,23504960,23504961,23504965,24420159,23504958,23504959,23504960,23504960,23504963,23504968,24467038,23504959,23504960,23504960,23504961,23504961,23504962,23504963,23504963,23504964,23504965,23504966,23504968,23504971,23504979,23817855,24467038,23504960,23504961,23504961,23504962,23504962,23504963,23504964,23504965,23504965,23504967,23504968,23504970,23504973,24105807,24175382,23504961,23504962,23504962,23504963,23504963,23504964,23504964,23504965,23504966,23504969,23504970,23504971,23504972,23504974,23504980,23886704,24420161,24420162,24467039,23504962,23504963,23504963,23504964,23504964,23504965,23504966,23504966,23504967,23504968,23504969,23504970,23504970,23504971,23504972,23504972,23504973,23504974,23504975,23504981,24420160,24420162,24420162,24467040,24467085,23504963,23504964,23504964,23504965,23504965,23504966,23504966,23504967,23504968,23504968,23504969,23504970,23504970,23504971,23504971,23504972,23504972,23504973,23504973,23504974,23504975,23504981,23565984,24420162,24420163,24467040,23504964,23504965,23504965,23504966,23504966,23504967,23504968,23504968,23504969,23504970,23504971,23504972,23504973,23504975,23504976,23886708,24087088,24278788,24420163,24467041,24570441,23504965,23504966,23504966,23504967,23504967,23504968,23504968,23504969,23504970,23504971,23504971,23504973,23504973,23504974,23504975,23504982,23504982,23806362,23817861,23886712,23886716,24420162,24420164,24467041,23504966,23504967,23504967,23504968,23504968,23504969,23504969,23504970,23504971,23504971,23504972,23504972,23504973,23504973,23504974,23504976,23504977,23504983,23504984,23886706,24175385,24420162,24420164,24420164,23504967,23504968,23504968,23504969,23504971,23504971,23504972,23504972,23504973,23504974,23504975,23504977,23504983,23695732,24420163,24420165,24467042,23504968,23504969,23504969,23504970,23504970,23504972,23504972,23504973,23504974,23504975,23504976,23504984,24175386,24420162,24420165,24420165,23504969,23504970,23504970,23504971,23504971,23504972,23504972,23504973,23504973,23504974,23504975,23504975,23504976,23504978,23504978,23504984,23504985,23504985,23504986,23817845,23886717,24420165,23504970,23504971,23504971,23504972,23504972,23504973,23504973,23504974,23504975,23504975,23504976,23504977,23504978,23504985,24467044,24510063,23504971,23504972,23504972,23504973,23504974,23504974,23504975,23504975,23504976,23504977,23504978,23504979,23817851,23886707,23504972,23504973,23504973,23504974,23504974,23504975,23504976,23504976,23504977,23504979,23504980,23695734,23817851,24467045,23504973,23504974,23504974,23504975,23504975,23504976,23504977,23504977,23504979,23504980,23504982,23504986,23695717,23886707,23886708,24420168,24467045,24570446,23504974,23504975,23504976,23504976,23504978,23504981,23504987,23665354,23731825,23886612,23886714,23886721,23504975,23504976,23504976,23504977,23504977,23504978,23504978,23504979,23504979,23504981,23504987,23886714,23886714,24467046,23504976,23504977,23504977,23504978,23504978,23504979,23504979,23504980,23504981,23886719,24219982,24420169,24467047,23504977,23504978,23504978,23504979,23504979,23504980,23504980,23504989,23886714,24420170,24467047,23504978,23504979,23504979,23504980,23504980,23504981,23504981,23504982,23504985,23817858,23817863,23886694,23886712,23886717,23886720,24231707,24467048,23504979,23504980,23504980,23504981,23504981,23504982,23504982,23504983,23504983,23504989,24420169,24420170,24420171,24420171,24467048,24570449,23504980,23504981,23504981,23504982,23504982,23504983,23504990,23559654,23665357,23782198,23817848,23886716,24467049,24570449,24648290,23504981,23504982,23504982,23504983,23504983,23504984,23504984,23504985,23504985,23504989,23504990,23504991,23559657,23665357,23695736,23886711,23886722,23886725,24065700,24105818,24108602,24175392,24420171,24420171,24420172,24465839,24467049,24467108,24570450,23504982,23504983,23504983,23504984,23504984,23504985,23504991,23504991,23504992,23695742,23886710,23886713,23886713,23886714,23886722,24420170,24420171,24420172,24467050,23504983,23504984,23504984,23504985,23504985,23504991,23504992,23886664,23886714,24000656,24025353,24087069,24420172,24420172,24420173,24467106,23504984,23504985,23504985,23504986,23504986,23504991,23504992,23886713,23886715,23886720,23886723,24000657,24116864,24140900,24175394,24420173,24467096,24570451,23504985,23504986,23504986,23504987,23504988,23504992,23886719,23886729,24278797,24420174,23504986,23504987,23504993,24420174,24420174,24467052,23504987,23504988,23504989,23504992,23504993,23504994,23504994,23559656,23638165,23817848,23817860,23817862,23886517,23886608,23886666,23886715,23886715,23886716,23886717,23886717,23886723,23886725,23886727,24000658,24087065,24087099,24105820,24140898,24140901,24140902,24140902,24175394,24175395,24420172,24420173,24420174,24420175,24420175,24467052,24467098,24570475,23504988,23504989,23504989,23504990,23504994,23504994,23558073,23558074,23692828,23886619,23886717,23886719,23886726,23886728,24000703,24025355,24140901,24140902,24420174,24420174,24420175,24420175,24420176,24467053,23504994,23559658,23695746,23886722,24105821,24305551,24420175,24420176,23504991,23504995,23504996,23695743,23886719,24467054,23504995,23665364,23886718,24105823,24467054,23504996,23796893,24420177,24420177,23558078,23559662,23505000,23886724,23505000,23505001,23505001,23558079,23558081,23559662,23559664,23695751,23782206,23813472,23817859,23817871,23817874,23817876,23817879,23886675,23886677,23886718,23886722,23886723,23886726,23886726,23886727,23886729,23886731,23886734,23980024,24000665,24025361,24086979,24087051,24105826,24116872,24140908,24175400,24175401,24175402,24278804,24278806,24420179,24420180,24420180,24420181,24420181,24420182,24467058,24467059,24467104,24467111,23559663,23695752,23817855,23817875,23886726,23886727,23886733,24025361,24105827,24175401,24420181,24420181,24420182,24467059,23559665,23648195,23886724,24105828,24420179,24420183,24467060,24467060,23886733,23611174,23611174,23611174,23611174,23611180,24473272,24158921,24520153,23612759,23939823,24473278,23614339,23614339,23614341,23614340,23614341,23614341,23614342,23614343,23614345,23614345,23868150,24474858,24474859,23836886,24055343,24171551,24474860,24474860,24521738,24474863,23627020,24528076,23643127,24174896,23771358,24019811,23791410,23791412,24563396,24610276,23825744,23825746,23825747,23825749,24730889,23978255,24047103,24335781,24730861,24047080,23880681,23994789,23886513,23886521,23886538,23886533,23886541,23886543,23886534,23886543,23886544,24610965,24657843,24657844,24610972,24299292,24008655,24366194,24610973,24657851,23958688,24647032,24059424,24059426,24059428,24095086,24163950,24383046,24077054,24706216,24088817,24178625,24107777,24721579,24108900,24188582,24121959,24121962,24728668,24775547,24130717,24130731,24130756,24130743,24130747,24130733,24130746,24130754,24130755,24130758,24130765,24130755,24130761,24130747,24130763,24130764,24130769,24130766,24130765,24130768,24130765,24130771,24544595,24130776,24130776,24418710,24779942,24779945,24733067,24199620,24199612,24779948,24779949,24199627,24733073,24488293,24199616,24199581,24733076,24199627,24733078,24453806,24733079,24140420,24737901,24268062,24801720,24268255,24268325,24268361,24268421,24268410,24268427,24268440,24268449,24487527,24522608,24801881,24268457,24268458,24268440,24268469,24268455,24268471,24268471,24268456,24268472,24268445,24268450,24268472,24268472,24268473,24268449,24268473,24268474,24268473,24268448,24268449,24268473,24268474,24268474,24268482,24268453,24268474,24268475,24268450,24268453,24268475,24268475,24268454,24268475,24268476,24268458,24268476,24268478,24268476,24268477,24268478,24268478,24268477,24268478,24268478,24268478,24268479,24268478,24268478,24268478,24268480,24268480,24268479,24268460,24268479,24268480,24268481,24268481,24268463,24268481,24268481,24268482,24268482,24268483,24268482,24268482,24268483,24268483,24268482,24268484,24268483,24268484,24268484,24268485,24268485,24268486,24268489,24268484,24268485,24268485,24268486,24268492,24801929,24801930,24848807,24268500,24268501,24268501,24463185,24522657,24522658,24557151,24557152,24660554,24801929,24801930,24801931,24801931,24848809,24952209,24952296,24268501,24361774,24407111,24487577,24487577,24488718,24557151,24801929,24801930,24801931,24801932,24848809,24268503,24557152,24557153,24613470,24680873,24801932,24801932,24848810,24361775,24487579,24557153,24801932,24801933,24801933,24848810,24487578,24557152,24557153,24801933,24801933,24848811,24801933,24468773,24848814,24500305,24455060,24455062,24455063,24455172,24895220,24895220,24455282,24895327,24496400,24496444,24496520,24496521,24496642,24496588,24496642,24915984,24612730,24916038,24916038,24962916,24545723,24545734,24545735,24545736,24545740,24940553,24695778,24940552,24940555,24987433,24987436,24626421,24626423,24626424,24626431,24626471,24626505,24626528,24626529,24626553,24626570,24666603,24980973,24657881,25146928,24668961,24669023,24669057,25002220,24669094,24669104,24669169,24669114,24669177,24669188,24669195,24669223,24687943,24757517,25002298,25002298,25049176,24706653,24706665,24706665,24706666,24706664,24706666,24706667,24706669,24706667,24706668,24706668,24706763,25021020,25067897,24706678,25021019,25021020,25067898,25067943,24706679,24741747,25021020,25067898,25018522,25021021,25021021,25021022,25021023,24706863,24741845,24708948,25022161,24712011,24712129,24712239,24712247,25023809,24779033,24728759,24728759,24728760,25032068,25032068,24732107,24788961,24776826,24776827,24776827,24776830,24776830,24776831,24776831,24776834,24776832,24776835,25056102,25056102,24811325,25056104,25056104,25102982,24867642,25056104,25056104,25056105,25056107,24845815,24845813,24845814,24845816,24845817,24845803,24845813,24845815,24845816,24845817,24845817,24845818,24845818,24845818,24845815,24845818,24845819,24845820,24845825,24845826,25090594,25090594,25090595,25090595,25090596,25137474,24845833,24949206,24949222,25090597,25137475,25090596,25090597,25090598,25137475,25090595,25090596,25090596,25090597,25090598,25090598,25137476,25090597,25090598,25137476,25137479,25090602,24935064,24935170,24935276,25135354,24958451,24958452,24958449,24958451,25193789,25146912,25146913,25146914,25052621,25052631,25052637,25194008,25240886,25194010,25194011,25194012,25240889,25093258,25214316,25106124,25220747,25179339,25304279,25330376,25332875,25335358,25335359,25335358,25335359,25335360,25335375,25335360,25335360,25335361,25335375,25335376,25335359,25335360,25335361,25335373,25335376,25335360,25335361,25335361,25335362,25335373,25335375,25335376,25335376,25335361,25335362,25335362,25335375,25335376,25335377,25335377,25335362,25335363,25335374,25335376,25335376,25335377,25335377,25335378,25335363,25335376,25335376,25335377,25335377,25335378,25335378,25335364,25335375,25335376,25335376,25335377,25335377,25335378,25335378,25335379,25335379,25335388,25335388,25335388,25335390,25382252,25335391,25335390,25335390,25335391,25335391,25382253,25335391,25335391,25335392,25382254,25335391,25335392,25335392,25382254,25335392,25335393,25382254,25382255,25485678,25335393,25382255,25382301,25485656,25485678,25335395,25367979,25375570,25377244,25381046,25382256,25382301,25382303,25485656,25382257,25400579,25414856,25415766,25422452,25419105,25424117,25426713,25426714,25427923,25429117,25429118,25429119,25429119,25429120,25429120,25429121,25429128,25429129,25429129,25429148,25429149,25429150,25429161,25429161,25429162,25429162,25429163,25429163,25429176,25429120,25429163,25429164,25429164,25429164,25429164,25429165,25429152,25429165,25429166,25429167,25532528,25429174,25429180,25532529,25429141,25429175,25429193,25429193,25429194,25429195,25429195,25429206,25429206,25429207,25429207,25429208,25429208,25429209,25429210,25429211,25429212,25429212,25429213,25429213,25429214,25429215,25429215,25429216,25429216,25429217,25429218,25429218,25429219,25429219,25429220,25429220,25429221,25429221,25429222,25429224,25429227,25429227,25429228,25429229,25429229,25429231,25429231,25429233,25429233,25429234,25429234,25429236,25429237,25429237,25429238,25429239,25429212,25429213,25429214,25429214,25429217,25429219,25429222,25429228,25429238,25429239,25429214,25429215,25429215,25429216,25429218,25429223,25429239,25429240,25429215,25429216,25429242,25429216,25429223,25429217,25429218,25429219,25429220,25429220,25429221,25429223,25429224,25429224,25429225,25429226,25429231,25429232,25429234,25429235,25429238,25429238,25429240,25429240,25429241,25429241,25429242,25429243,25429218,25429219,25429220,25429220,25429221,25429222,25429223,25429224,25429226,25429232,25429234,25429235,25429236,25429237,25429239,25429239,25429240,25429241,25429241,25429242,25429243,25429220,25429221,25429221,25429222,25429223,25429224,25429224,25429225,25429225,25429227,25429229,25429230,25429234,25429234,25429235,25429236,25429238,25429239,25429239,25429240,25429241,25429241,25429242,25429243,25429244,25429222,25429222,25429223,25429224,25429226,25429227,25429235,25429239,25429240,25429240,25429241,25429244,25429245,25429223,25429243,25429245,25429223,25429224,25429225,25429225,25429226,25429226,25429228,25429228,25429237,25429240,25429240,25429241,25429243,25429246,25429225,25429225,25429226,25429228,25429228,25429229,25429236,25429237,25429238,25429239,25429240,25429241,25429241,25429244,25429244,25429245,25429245,25429246,25429246,25429226,25429227,25429228,25429231,25429231,25429233,25429235,25429235,25429236,25429238,25429239,25429240,25429241,25429242,25429242,25429243,25429244,25429245,25429247,25429247,25429228,25429231,25429238,25429238,25429239,25429240,25429240,25429242,25429245,25429247,25429248,25429229,25429239,25429241,25429232,25429233,25429234,25429239,25429241,25429242,25429244,25429249,25429231,25429232,25429235,25429239,25429240,25429241,25429242,25429243,25429245,25429240,25429242,25429247,25429250,25429233,25429241,25429245,25429249,25429250,25429235,25429241,25429243,25429243,25429251,25429244,25429246,25429250,25429251,25429235,25429240,25429241,25429242,25429242,25429243,25429244,25429246,25429247,25429247,25429248,25429249,25429249,25429252,25429238,25429245,25429244,25429253,25429254,25429247,25429249,25429251,25429245,25429255,25429246,25429251,25429257,25429248,25429257,25429253,25429258,25429251,25429253,25429256,25429258,25429259,25532584,25429251,25429252,25429253,25429254,25429254,25429255,25429258,25429259,25429259,25429258,25429260,25429252,25429253,25429254,25429255,25429255,25429256,25429256,25429257,25429258,25429258,25429260,25429258,25429259,25429261,25429255,25429255,25429256,25429256,25429257,25429257,25429258,25429259,25429261,25429262,25429257,25429258,25429258,25429260,25429260,25429261,25429261,25429263,25429258,25429259,25429259,25429260,25429262,25429262,25429263,25429263,25429261,25429261,25429262,25429263,25429264,25429261,25429262,25429263,25429263,25429264,25429262,25429263,25429264,25429265,25429265,25429263,25429264,25429265,25429266,25429264,25429265,25429266,25429266,25429266,25429266,25429267,25532614,25429267,25429268,29751144,25429268,25429269,25429270,25429270,25429271,25429272,25429274,25429275,25429276,25429276,25429277,25429278,25429278,25429280,25429281,25429282,25429283,25429284,25429285,25429286,25429286,25429287,25429287,25429288,25429290,25429296,25429296,25429298,25429298,25429303,25429304,25429304,25429307,25429308,25429309,25429311,25429312,25429312,25429313,25429313,25429314,25429314,25532594,25532615,25532616,25532618,25532619,25532646,25429271,25429273,25429273,25429275,25429276,25429277,25429278,25429280,25429280,25429281,25429284,25429284,25429285,25429286,25429286,25429299,25429307,25429310,25429311,25429312,25429312,25429313,25429314,25429314,25429315,25429276,25429288,25429315,25429315,25429277,25429283,25429277,25429317,25429318,25429317,25429283,25429307,25429310,25429319,25429287,25429320,25429314,25429319,25429321,25429321,25429287,25429289,25429289,25429292,25429295,25429295,25429322,25429323,25429323,25429288,25429317,25429319,25532604,25429325,25429325,25429325,25429326,25429305,25429325,25429326,25429324,25429326,25429327,25429298,25429327,25429327,25429328,25429310,25429328,25429329,25429313,25429329,25429329,25429330,25429324,25429330,25429331,25532633,25429329,25429330,25429331,25429332,25429332,25429332,25429333,25429333,25429335,25429338,25429331,25429341,25429325,25429341,25429342,25429333,25429339,25429343,25429344,25532650,25429349,25429349,25429348,25429349,25429350,25429350,25429351,25429353,25429353,25429353,25429354,25429355,25429356,25429357,25429355,25429356,25429357,25429357,25429358,25429357,25429358,25429358,25429359,25429359,25429360,25429521,25451207,25462798,25462798,25508799,25519248,25532453,25532530,25532638,25532639,25532639,25532662,26730470,29751191,25462798,25532640,25429753,25532871,25473065,25554497,25496249,25496250,25496250,25496251,25496251,25496249,25496251,25496252,25566090,25566090,25496264,25566091,25566092,25566092,25566093,25515168,26773380,25588260,25588313,25612101,25612154,25609149,25622540,25635621,25635808,25635776,25635885,25635917,25635918,25635918,25635919,25635923,25635923,25635924,25635926,25635932,25635939,25635939,25635940,25635940,25635941,25635941,25635944,25635923,25635941,25635942,25635930,25635944,25635945,25635945,25635928,25635945,25635946,25635946,25635946,25635948,25635948,25635954,25635961,25635961,25635962,25635962,25635962,25635962,25635963,25635963,25635964,25635965,25635965,25635966,25635966,25635967,25635967,25635968,25635968,25635969,25635969,25635970,25635970,25635971,25635971,25635972,25635973,25635973,25635974,25635974,25635975,25635976,25635976,25635977,25635978,25635978,25635979,25635980,25635981,25635982,25635982,25635983,25635983,25635984,25635984,25635985,25635986,25635986,25635987,25635987,25635988,25635988,25635989,25635989,25635990,25635990,25635991,25635991,25635992,25635992,25635993,25635993,25635994,25635994,25635995,25635997,25635999,25636004,25636012,25636014,25636014,25636015,25636016,25636017,25635965,25635966,25635967,25635968,25635969,25635969,25635970,25635971,25635971,25635973,25635979,25635982,25635982,25635983,25635983,25635984,25635984,25635986,25635987,25635988,25635990,25635992,25635992,25635995,25635967,25635967,25635969,25635969,25635971,25635971,25635972,25635972,25635973,25635979,25635982,25635983,25635983,25635984,25635986,25635987,25635987,25635988,25635990,25635991,25635992,25635995,25635998,25636000,25636018,25635967,25635968,25635970,25635976,25635980,25635987,25635988,25635991,25635968,25635970,25635970,25635972,25635972,25635978,25635983,25635985,25635986,25635988,25635988,25635989,25635991,25635992,25635970,25635970,25635971,25635971,25635973,25635973,25635974,25635975,25635976,25635977,25635980,25635981,25635982,25635984,25635984,25635986,25635987,25635987,25635988,25635989,25635990,25635990,25635991,25635992,25635992,25635993,25635994,25635994,25635999,25636001,25636001,25636019,25635979,25635976,25635985,25636020,25635972,25635974,25635976,25635986,25635989,25635990,25635991,25635991,25635992,25635993,25635994,25635999,25635974,25635975,25635975,25635976,25635978,25635979,25635980,25635984,25635986,25635986,25635987,25635988,25635989,25635989,25635990,25635990,25635991,25635991,25635992,25635994,25635995,25635996,25635996,25635997,25635998,25636021,25635980,25635983,25635986,25635991,25635992,25635995,25635984,25635976,25635977,25635981,25635985,25635987,25635988,25635989,25635990,25635992,25635993,25635994,25635995,25635996,25635997,25636001,25635977,25635979,25635979,25635980,25635982,25635983,25635986,25635988,25635989,25635990,25635992,25635993,25635994,25635996,25635997,25635998,25635998,25636002,25636023,25635978,25635979,25635980,25635981,25635982,25635983,25635983,25635990,25635990,25635997,25635998,25636012,25636018,25636024,25635981,25635983,25635993,25635994,25636001,25636024,25635990,25635992,25635995,25636000,25635989,25635991,25635992,25635996,25635998,25635984,25635990,25635993,25636026,25635984,25635985,25635987,25635991,25635993,25636026,25635988,25635992,25635998,25636009,25635990,25635987,25635989,25635992,25635997,25635998,25635999,25636000,25636001,25636002,25636003,25636006,25636028,25635990,25635993,25635996,25635996,25635999,25636001,25636001,25636007,25636029,25635990,25635993,25635997,25635998,25636000,25636004,25635993,25635995,25636001,25635995,25635996,25635997,25636000,25636000,25636001,25636004,25636006,25636012,25635999,25636006,25636007,25636010,25635996,25636000,25636004,25635998,25636001,25636003,25636005,25636017,25636000,25636000,25636002,25636003,25636004,25636007,25635999,25636000,25636000,25636001,25636001,25636002,25636002,25636003,25636004,25636004,25636006,25636007,25636007,25636008,25636009,25636009,25636011,25636016,25636028,25636034,25636000,25636001,25636004,25636004,25636005,25636006,25636012,25636013,25636015,25636017,25636033,25636002,25636003,25636004,25636006,25636007,25636008,25636010,25636011,25636013,25636035,25636002,25636005,25636005,25636006,25636008,25636017,25636003,25636004,25636005,25636006,25636007,25636008,25636009,25636010,25636011,25636015,25636034,25636036,25636004,25636006,25636008,25636009,25636009,25636010,25636010,25636011,25636011,25636012,25636013,25636005,25636006,25636007,25636007,25636008,25636009,25636010,25636010,25636012,25636013,25636014,25636018,25636019,25636037,25636007,25636008,25636010,25636011,25636012,25636013,25636014,25636015,25636022,25636010,25636011,25636008,25636009,25636009,25636010,25636010,25636011,25636011,25636012,25636012,25636013,25636014,25636016,25636016,25636017,25636036,25636039,25636009,25636010,25636011,25636012,25636012,25636013,25636013,25636014,25636014,25636015,25636016,25636016,25636017,25636018,25636039,25636010,25636011,25636011,25636012,25636012,25636013,25636013,25636014,25636014,25636015,25636016,25636017,25636017,25636018,25636022,25636040,25636011,25636012,25636012,25636013,25636013,25636014,25636015,25636015,25636017,25636017,25636018,25636018,25636019,25636021,25636038,25636040,25636012,25636013,25636013,25636014,25636014,25636015,25636016,25636018,25636041,26347659,25636013,25636014,25636014,25636015,25636015,25636016,25636016,25636018,25636019,25636020,25636041,25636014,25636015,25636015,25636016,25636017,25636017,25636018,25636019,25636019,25636020,25636022,25636024,25636015,25636016,25636016,25636017,25636017,25636018,25636020,25636021,25636042,25636016,25636017,25636017,25636018,25636019,25636019,25636020,25636021,25636021,25636023,25636024,25636027,25636030,25636037,25636040,25636043,25636017,25636018,25636018,25636019,25636020,25636020,25636021,25636022,25636025,25636032,25636036,25636018,25636019,25636021,25636022,25636025,25636026,25636037,25636044,25636019,25636020,25636020,25636021,25636021,25636022,25636023,25636023,25636027,25636027,25636029,25636030,25636033,25636034,25636035,25636038,25636038,25636041,25636042,25636044,28648997,25636020,25636021,25636021,25636022,25636022,25636023,25636024,25636025,25636026,25636026,25636027,25636027,25636029,25636030,25636030,25636031,25636034,25636035,25636036,25636037,25636038,25636039,25636040,25636042,25636042,25636043,25636044,25636045,25636022,25636023,25636024,25636025,25636027,25636042,25636045,25636022,25636023,25636023,25636024,25636025,25636026,25636027,25636028,25636030,25636036,25636037,25636039,25636039,25636040,25636045,25636046,25636023,25636024,25636025,25636025,25636026,25636028,25636039,25636040,25636045,25636046,25636024,25636025,25636026,25636026,25636027,25636027,25636028,25636028,25636029,25636030,25636031,25636037,25636038,25636039,25636041,25636044,25636044,25636045,25636045,25636047,25636025,25636026,25636027,25636027,25636028,25636028,25636029,25636029,25636030,25636031,25636033,25636035,25636039,25636039,25636040,25636040,25636042,25636044,25636045,25636045,25636047,25636047,25636026,25636029,25636038,25636041,25636027,25636028,25636028,25636029,25636030,25636030,25636031,25636031,25636033,25636034,25636034,25636036,25636037,25636038,25636038,25636039,25636040,25636040,25636041,25636041,25636042,25636042,25636043,25636043,25636045,25636045,25636046,25636046,25636047,25636048,25636048,25636030,25636049,25636029,25636031,25636031,25636032,25636041,25636047,25636049,25636049,25636031,25636032,25636033,25636039,25636041,25636042,25636043,25636045,25636046,25636047,25636049,25636050,25636032,25636050,25636032,25636033,25636037,25636042,25636033,25636034,25636036,25636037,25636037,25636038,25636039,25636041,25636043,25636044,25636047,25636049,25636049,25636051,25636035,25636035,25636036,25636037,25636037,25636038,25636039,25636039,25636040,25636041,25636041,25636042,25636043,25636045,25636046,25636046,25636047,25636049,25636049,25636050,25636050,25636051,25636052,25636041,25636050,25636052,25636037,25636038,25636042,25636043,25636044,25636046,25636047,25636053,25636037,25636051,25636053,25636041,25636047,25636053,25636054,25636041,25636042,25636045,25636047,25636054,25636054,25636054,25636055,25636044,25636045,25636051,25636055,25636046,25636046,25636050,25636056,25636046,25636056,25636045,25636056,25636057,25636046,25636047,25636050,25636054,25636055,25636057,25636057,25636058,25636051,25636052,25636055,25636058,25636049,25636050,25636052,25636052,25636053,25636058,25636059,25636057,25636059,25636050,25636051,25636052,25636052,25636053,25636055,25636057,25636058,25636059,25636060,25636052,25636056,25636058,25636053,25636055,25636061,25636054,25636054,25636055,25636058,25636059,25636059,25636061,25636055,25636056,25636057,25636060,25636062,25636055,25636056,25636057,25636060,25636062,25636057,25636058,25636058,25636059,25636060,25636061,25636061,25636062,25636062,25636063,25636060,25636061,25636063,25636060,25636061,25636061,25636062,25636063,25636064,25636063,25636064,25636061,25636065,25636062,25636063,25636065,25636063,25636064,25636064,25636065,25636066,25636066,25636064,25636067,25636065,25636066,25636067,25636067,25636066,25636067,25636068,25636067,25636068,25636068,25636068,25636069,25636069,25636070,25636071,25636072,25636073,25636074,25636075,25636075,25636076,25636076,25636077,25636079,25636080,25636080,25636081,25636082,25636082,25636083,25636083,25636084,25636085,25636085,25636087,25636088,25636088,25636089,25636089,25636090,25636090,25636091,25636091,25636092,25636092,26347688,26609077,27615713,27787425,28649024,29854545,25636071,25636072,25636072,25636073,25636075,25636076,25636076,25636077,25636077,25636078,25636078,25636079,25636079,25636080,25636081,25636082,25636082,25636083,25636083,25636084,25636085,25636087,25636087,25636088,25636089,25636089,25636090,25636090,25636091,25636091,25636092,25636092,25636093,25636084,25636089,25636093,25636090,25636094,25636094,25636095,25636080,25636085,25636090,25636094,25636095,25636083,25636084,25636087,25636089,25636093,25636095,25636096,25636096,25636097,25636097,25636087,25636088,25636093,25636094,25636098,25636098,25636085,25636088,25636095,25636096,25636097,25636099,25636098,25636099,25636100,25636100,25636099,25636100,25636092,25636097,25636101,25636102,25636102,25636093,25636103,25636093,25636096,25636102,25636104,25636094,25636097,25636104,25636095,25636097,25636101,25636102,25636105,25636096,25636105,25636097,25636102,25636106,25636104,25636106,25636101,25636102,25636104,25636105,25636107,25636108,25636109,25636105,25636106,25636107,25636108,25636109,25636108,25636110,25636108,25636109,25636110,25636111,25636108,25636111,25636109,25636110,25636112,25636110,25636111,25636112,25636112,25636113,25636113,25636113,25636114,25636114,25636115,25700934,25718138,25780804,25781953,25781956,25781957,25806129,25841220,25841221,25841222,25841222,25868043,25949396,25954340,26013966,26099784,26099784,26347708,26347709,26347710,26347710,26347711,26347711,26361568,26363342,26364629,26364629,26364630,26364630,26408860,26408862,26479028,26479028,26479029,26479029,26489493,26497112,26549344,26570177,26600204,26600207,26609097,26609098,26609099,26609100,26611218,26650954,26757052,26782124,26833845,26833847,26833850,26833851,26886703,26992435,27097235,27188458,27206245,27233152,27298067,27337701,27337705,27353411,27353414,27468810,27533657,27571623,27580629,27585699,27585702,27615734,27615734,27615735,27615735,27615736,27615736,27615738,27615738,27615847,27731070,27787446,27787446,27787447,27787447,27787448,27970029,28649045,28649046,28649046,28920472,28920475,28987719,29095562,29108957,29324384,29355420,29461103,29854568,29854569,29868389,29877106,33388855,26347712,26833848,27615735,25765754,25765766,25765767,25765769,25765767,27680566,27852279,25846789,27680567,26898682,25791612,26911602,25800172,25800174,26446665,26915884,25925565,27932209,25927807,25927810,25927810,25927811,26979701,26033235,26493564,26979701,25976153,25976271,25976388,26436051,26046340,26046341,26046342,26046342,27038967,27091822,27820855,27820856,26100039,26100170,26100282,27065955,26138672,26645058,26262690,27912566,26272582,27933977,26391853,26643796,27211734,26563465,26563466,26563468,26563469,28251128,28079418,27297532,28251132,26895719,27463657,28245544,27059317,27059304,27059318,27059319,27059318,27059318,27059319,27059319,27059320,27059319,27059320,27059321,27059330,27201101,27307864,27545455,28327343,27059332,28499056,28499056,30579998,27073177,27076238,27221059,27320709,27320709,27493733,27545456,28327343,28327343,28499056,28499057,28645750,28681638,29360655,30172712,27362563,27087036,27087037,27559316,27559317,27090583,27561088,27093155,27093156,27093156,27093157,27137386,27207556,27484405,27562374,28344261,27151466,27591546,27181617,27181618,27181618,27181675,27181630,27606604,27267275,27396728,27181732,28388548,27321956,27321957,27321955,27321956,27321957,27321957,27673104,27676774,28076079,27676775,28458662,27676775,28630375,27676776,27342883,27687238,28469125,27352931,27467514,27358121,27358122,27853294,27521740,27382794,27382805,28489080,27462582,27462651,27462719,28529041,27504250,27504263,27767920,28549820,29583130,27556410,27794001,27564308,27564315,27564316,28170350,27624840,27797956,27582095,27582096,27582097,27582097,27582098,27755117,27806843,27806845,28519420,28588732,28588733,28760445,27806845,27586337,28762566,27611834,27821712,27665807,27665808,27848701,27848701,27685361,27685364,27858478,27858479,27875654,27953623,27878013,27954808,27928139,27928145,27928146,27928148,27979867,27979869,28761757,27979871,28024262,28809819,28031578,28031578,28031581,28031582,28031591,28031592,28031592,28031593,28031593,28031594,28031594,28031595,28031595,28031596,28031596,28031597,28031597,28031598,28031598,28031601,28031594,28031596,28031594,28031599,28031597,28031604,28031604,28985192,28031605,28031607,28031607,28031608,28031608,28031610,28031612,28031726,28513361,28535452,28551156,28694930,28813479,28813480,28813480,28813481,28813481,28928815,28985191,28985192,29846790,28031606,28031607,28031607,28031608,28031608,28031609,28031609,28031610,28219921,28551157,28804939,28813480,28813480,28813481,28813481,28813482,28813482,28813484,28985193,29846804,30637536,28031607,28031608,28031727,28813482,28031611,28084449,28634427,28813480,28813481,28813481,28985192,28985194,28031609,28535448,28813481,28031610,28031611,28031612,28031612,28031616,28190179,28294981,28493869,28535454,28551159,28731407,28783449,28804941,28813482,28813482,28813483,28813484,28813484,28813485,28985193,28985194,28985194,28985195,28985195,29846793,29846793,30839856,28031611,28031615,28403992,28493869,28551159,28813482,28813482,28813483,28813483,28985195,28985196,28031612,28031613,28413872,28535449,28735310,28777986,28813483,28813483,28985196,28985196,28813483,28813484,28813485,29846794,28813484,28495817,28813484,28813485,28985197,28985198,28783453,28813485,28813486,28985198,28813485,28985200,29846798,28813488,28813488,28031858,28031861,28813611,28813614,28137303,28137304,28682122,28866336,28866337,28348464,28348614,28348763,28348765,28348767,28972066,29143778,30005378,28408251,29001812,28558364,28558366,29076864,29076866,28740829,28740904,28740980,29168180,28776389,28776391,29357592,29185880,29357593,28796151,29195762,28830204,28830205,29065866,31451620,29212787,28956138,29092036,29275751,28960035,29277702,29277702,28995130,29295248,29039298,29039302,29039311,29039311,29039312,29039312,29039314,29039316,29317332,29489042,29317335,29489053,29489053,29317341,29317342,29317341,29317345,29070720,29070720,29070725,29333043,29333043,29255463,29333043,29504755,29333045,29226937,29381118,29227936,29583364,29237264,29416318,29301520,29301527,29448444,29448447,29358293,30848827,29431215,29431222,29513292,29513297,29439011,29439081,29517251,29440206,29517787,29456749,29526061,29507141,29507217,29507293,29521296,29524378,29559875,29525156,29560262,31799094,29535298,29535301,29535301,29535301,29565333,29565334,29565335,29562440,30958130,29578284,29578285,29586825,29586825,29586826,29595353,29595354,29595354,29595354,29595355,29595355,29595356,29595356,29595357,29595357,29595358,29595363,29595364,29595365,29595366,29595366,29595367,29595367,29595368,29595369,29595369,29595370,29595370,29595371,29595355,29595356,29595356,29595357,29595357,29595358,29595358,29595359,29595359,29595366,29595366,29595367,29595369,29595369,29595370,29595370,29595371,29595371,29595372,29595356,29595357,29595357,29595366,29595368,29595368,29595369,29595370,29595370,29595371,29595371,29595372,29595372,29595373,29595374,29595357,29595358,29595358,29595359,29595367,29595367,29595368,29595368,29595369,29595370,29595370,29595371,29595371,29595372,29595372,29595374,29595374,29595358,29595359,29595360,29595367,29595368,29595369,29595370,29595371,29595371,29595372,29595373,29595373,29595374,29595374,29595375,29595359,29595360,29595368,29595368,29595371,29595372,29595372,29595360,29595361,29595368,29595369,29595372,29595373,29595375,29595369,29595370,29595371,29595372,29595372,29595373,29595373,29595376,29595377,29595371,29595374,29595375,29595370,29595372,29595374,29595373,29595379,29595380,29595378,29595378,29595379,29595380,29595381,29595381,29595382,29595382,29595383,29595384,29595480,29595379,29595381,29595381,29595382,29595480,29595380,29595381,29595382,29595382,29595383,29595385,29595481,29595380,29595382,29595384,29595382,29595382,29595383,29595383,29595384,29595480,29595482,29595384,29595383,29595384,29595384,29595387,29595483,29767081,29595384,29595385,29595385,29595386,29595386,29595387,29595387,29595483,29767080,29767081,29767081,29767082,29767082,30628680,30628680,30628681,30967353,29595385,29595386,29595386,29595387,29595387,29595388,29595390,29595484,29714978,29767081,29767081,29767082,29767082,29767083,30628680,30628680,30628681,31440738,31834204,31848024,29595386,29595387,29595387,29595388,29595388,29595389,29595390,29595482,29595483,29595484,29595504,29767081,29767081,29767082,29767082,29767083,29767083,30628680,30628681,31419425,31834203,29595387,29595388,29595389,29595391,29595484,29595485,29767082,29767082,29767083,29767083,30628682,31834205,29595389,29595389,29595485,29595489,29767080,29767081,29767082,29767083,29767083,29767084,29767084,31088594,31834205,29595389,29595484,29595486,29657866,29767082,29767083,29767084,29767084,29767085,29595390,29595391,29595485,29595486,29767082,29767083,29767084,29767084,29767085,29767085,29595391,29595392,29595485,29595487,29767084,29767084,29767085,29767085,29904907,29595485,29595487,29767084,29767085,29767086,29767086,30628684,30628685,29767086,29767087,29595489,29767085,29595581,29595590,29595582,29595591,29595592,29595592,29595599,29660202,29746188,29767189,29767190,29767190,29767191,29767191,29905011,30628788,30628789,30628789,30900218,30900221,31834362,29767194,29595631,29767209,29720368,29720438,29720485,29829633,29724816,29831806,29826038,29826038,29882414,30744032,29834583,29886687,29896796,29917799,29938788,29938777,29938776,29938777,29938778,29938777,29938778,29938778,29938779,29938792,29938792,29938794,29938778,29938779,29938779,29938780,29938793,29938794,29938796,29938796,29938779,29938780,29938794,29938780,29938781,29938786,29938791,29938792,29938793,29938794,29938794,29938795,29938795,29938796,29938796,29938797,29938797,29938798,29938798,29938799,29938803,29938781,29938782,29938793,29938793,29938794,29938794,29938795,29938795,29938796,29938796,29938797,29938797,29938798,29938798,29938799,29938799,29938800,29938803,29938794,29938795,29938795,29938796,29938796,29938797,29938797,29938798,29938797,29938797,29938800,29938801,29938807,29938808,30522000,32005969,29938807,29938808,29938807,29938808,29938808,29938809,29938809,29938807,29938808,29938808,29938809,29938809,30121375,32019771,29938808,29938809,29938809,29938810,29938810,30800408,29938809,29938810,29938810,29938811,29938811,29938812,30800393,31139066,29938810,29938811,29938811,29938812,29938812,29938814,29938814,30076616,30800391,30800393,30800393,30800401,30800408,31071822,32005916,32028453,29938811,29938812,29938812,29938813,29938813,29938814,29938814,29938815,29938817,30076616,30076617,30800393,30800393,30800394,30800394,31071823,31612451,32005917,32019737,29938812,29938813,29938813,29938814,29938814,29938815,29938816,29938817,30076617,30076618,30085487,30121377,30121378,30723136,30800392,30800393,30800393,30800394,30800394,30800411,30890211,31139068,31242530,31908948,32005917,29938813,29938814,29938814,29938815,29938815,29938816,29938817,29938819,30076618,30076618,30121378,30560725,30626067,30698921,30800392,30800393,30800394,30800394,30800395,30800395,31071824,31139067,32005917,32005918,32005964,32005967,32019738,29938814,29938815,29938815,29938816,29938816,29938817,29938819,29938822,29938822,30076617,30076620,30323752,30698921,30800393,30800394,30800394,30800395,30800395,31071815,31071824,31071827,32005917,32005918,29938815,29938816,29938816,29938817,29938817,29938818,29938819,29938820,29938820,30018154,30076619,30076619,30076620,30109845,30121379,30767866,30800271,30800395,30800395,30800396,30800396,30800411,30800414,31071825,31107524,31139067,31139068,31139069,31139069,32005918,32005919,32005964,32005965,32014468,29938816,29938817,29938817,29938818,29938818,29938819,29938820,29938820,30076619,30076620,30800392,30800395,30800396,30800396,31612454,32014468,29938817,29938818,29938818,29938819,29938819,29938820,29938820,29938821,29938821,30076620,30121380,30800395,30800396,30800396,30800397,30800397,30800411,31139069,31139070,32005920,32005970,32005974,29938818,29938819,29938819,29938820,29938821,29938826,30085491,30323755,30800396,30800397,30800397,30800412,31071826,31675709,29938819,29938820,29938820,29938823,30076621,30076621,30083145,30085492,30111879,30121379,30121381,30800396,30800396,30800397,30800397,30800398,30800399,32005921,32005966,32005972,29938820,29938821,29938821,29938822,29938823,29938827,30109847,30698909,30800396,30800398,30800398,29938822,29938823,29938825,29938828,30800397,30800398,30800399,31139072,29938822,30121382,30800398,30800399,30800399,30800403,29988140,30800399,30800400,30800419,29938826,30800400,30800409,30560731,30800399,30800399,30800400,30800400,30800401,30085493,30800401,30800401,30800401,30800401,30800402,30800401,29938832,30800403,30800404,30085499,30800405,30800406,30800406,30037491,30849750,30097548,30097623,30097679,30879844,30214435,30214436,30214436,30214437,30214436,30214437,30214437,30214438,30214438,30938212,30259196,30836740,30938212,30938213,30938213,31781275,30938213,30938213,30227481,30944733,30232180,30232180,30232179,30232181,30232168,30232179,30232189,31285757,30268069,30947086,30947086,30947087,30947088,30280889,30280891,30971440,31310114,30284951,30284968,30284988,30973489,30303941,30303954,30303955,30303957,30303957,30303958,30303957,30303958,30982971,30982971,30982971,30982972,30982972,31321645,30982973,30982974,31321646,32188496,30982975,32188498,30708702,30708703,31185345,31185348,31105243,31843545,31182656,31422325,32627896,31313337,31487663,31459027,31459052,31459053,31560515,31560525,31560525,31507534,31507634,31507735,32044803,31596936,31968139,31661736,31661861,31661971,31661974,31661990,31661974,31661975,31661988,31661988,31661974,31661975,31661975,31661987,31661989,31661975,31661976,31661989,31661990,31661990,31661991,31661992,31661976,31661977,31661984,31661988,31661991,31661991,31661992,31661992,31661993,31661993,31661994,31661994,31661996,31661977,31661978,31661978,31661979,31661979,31661980,31661980,31661981,31661982,31661983,31661984,31661985,31661985,31661986,31661987,31661987,31661988,31661988,31661989,31661989,31661990,31661990,31661991,31661991,31661992,31661992,31661993,31661993,31661994,31661994,31661995,31661995,31661996,31661997,31661978,31661980,31661982,31661983,31661986,31661988,31661990,31661990,31661991,31661992,31661992,31661993,31661993,31661994,31661996,31661980,31661981,31661982,31661983,31661985,31661987,31661989,31661990,31661992,31661993,31661993,31661994,31661983,31661992,31661994,31661995,31661982,31661983,31661988,31661989,31661992,31661995,31661995,31661998,31661985,31661989,31661991,31661993,31661995,31661997,31661989,31661991,31661985,31661987,31661995,31661996,31662015,31661996,31661997,31661991,31661992,31661994,31661998,31661995,31661994,31661998,31661997,31661999,31662000,31662001,31661996,31661997,31662000,31661995,31662001,31662019,31662000,31662000,31662001,31662001,31662004,31662002,31662002,31662003,31662000,31662002,31662002,31662003,31662003,31662003,31662003,31662003,31662003,31662004,32867511,31662003,31662004,31662008,31662002,31662003,31662004,31662005,31662005,31662006,31662007,31662023,31662003,31662004,31662004,31662005,31662005,31662006,31662006,32867513,31662005,31662005,31662006,31662007,31933419,31662005,31662006,31662006,31662007,31662007,31662025,31779224,32000664,32573111,32867567,31662006,31662007,31662007,31662008,31662008,31662009,31662010,31662025,31933420,32121903,32452737,32867514,32890100,31662007,31662008,31662008,31662009,31662009,31662010,31662010,31662011,31662012,31662020,31662022,31662023,31662024,31662026,31751806,31933421,32000664,32000665,32121904,32414934,32474049,32867514,32867515,32867566,32881335,32890052,31662008,31662009,31662009,31662010,31662010,31662011,31662011,31662012,31662013,31662026,31779226,31933412,31933421,32000664,32000666,32121904,32121905,32121906,32335631,32414934,32671143,32867515,32867561,32867565,32867570,32876066,32881336,31662009,31662010,31662010,31662011,31662011,31662012,31662012,31662013,31662013,31662014,31662023,31662027,31751809,31933419,31933422,32000666,32000666,32000667,32000668,32121905,32121905,32121906,32122636,32291202,32414935,32452738,32474050,32474050,32867297,32867515,32867516,32867562,32867564,32867566,32881336,31662010,31662011,31662011,31662012,31662012,31662013,31662013,31662014,31662017,31662022,31662023,31662024,31662025,31662027,31662029,31933422,32000666,32000666,32000667,32121905,32452737,32452739,32867516,32867562,32867565,32881337,31662011,31662012,31662012,31662013,31662013,31662014,31662015,31662015,31662016,31662025,31662025,31662028,31662028,31933420,31933423,32000667,32000667,32121906,32121906,32452741,32474051,32867517,32867568,32881337,31662012,31662013,31662013,31662014,31662014,31662015,31662016,31662016,31662018,31662019,31662028,31662029,31933423,32000667,32414936,32452739,32474051,32867517,32867565,31662013,31662014,31662014,31662015,31662015,31662016,31662016,31662017,31662017,31662020,31662020,31662029,31662030,31933424,31933426,32000667,32000668,32000668,32121907,32452739,32474052,32585474,32867517,32867518,32867564,32881338,31662014,31662015,31662015,31662016,31662017,31662018,31662026,31662029,31662030,31662030,31933415,31933424,32000667,32000668,32121907,32867517,32867518,31662015,31662016,31662016,31662017,31662020,31662021,31662023,31662030,31662030,32867519,32867562,31662016,31662017,31662018,31662019,31662030,31662031,32867519,32867565,31662017,31662018,31662018,31662019,31662020,31662028,31662030,31662031,31662032,31933426,32452741,31662018,31662019,31662030,31662030,31662031,31662032,31933426,31662019,31662026,31662032,31892543,32867521,32881341,31662029,31662032,31933427,32000671,32000672,31662021,31662031,31662033,32000675,31662024,31662034,32000672,31662034,31751819,31662027,31933431,31662031,31662033,31662033,31662036,32414943,31933432,31662035,31662039,31933435,31662042,31662041,31662041,31933436,31662042,31662043,32121920,32867531,31662042,31933437,31662043,31933438,32000681,32121921,31662043,31662044,32867533,31662045,31662046,31662046,31662047,31751826,31751829,31751829,31751831,31933437,31933440,31933441,31969139,31997777,32000682,32000684,32000684,32007464,32104143,32121922,32121923,32121924,32121925,32368363,32368385,32414953,32452752,32452755,32452756,32452757,32474068,32537323,32573131,32723227,32867533,32867533,32867534,32867580,32867581,32867589,32881354,32890071,31662046,31933440,32000684,32000685,32452756,32474068,32867534,32867555,32867581,32867584,32881355,32881404,32890120,31662047,31933441,32000685,32000685,32337347,32867534,32867535,32867589,32890072,31751830,31933432,31933441,32000685,32121926,32452757,32867535,32867581,32867585,32881356,32867535,31841620,31841621,31841622,31841623,31841615,31841628,31841626,31841626,31841630,31841626,31841636,32957327,32054553,32169976,32971150,32369393,32023237,32090481,32211722,32957333,31896459,31896460,32050655,32123082,33098106,32204825,32204851,32204832,32204858,32204836,32204854,32204860,32204860,32204861,32204871,32204879,32204862,32204880,32204880,32204881,32204882,32204879,32204880,33138948,32204885,32393342,32204886,32204904,32236178,32272104,32272104,32272105,32272105,32313675,32375563,32393343,32393343,32393344,32545620,32686373,32724175,32724177,32724178,32745488,32745490,32776493,32808745,33138953,33138954,33138954,33139000,33139000,33139004,32204905,32246133,32272105,32272105,32272106,32272107,32607071,32607072,32724177,32724184,32745489,32745489,32783275,32808744,32844552,33138955,33139000,33152775,32272115,33138965,33152786,32272123,32272123,32379966,32393362,32724200,33138973,33139019,33152793,32267481,32267573,32267574,32267665,32267668,32303499,33170400,32276244,32892598,33174639,32287390,32434601,32333557,33203366,32339321,32339336,32339339,32339322,32339334,32339337,32339337,32339338,32339338,32339339,32339339,32339340,32339323,32339324,32339335,32339337,32339338,32339338,32339339,32339339,32339340,32339340,32339324,32339336,32339336,32339338,32339339,32339339,32339340,32339340,32339341,32339339,32339340,32339341,32339341,32339342,32339344,32339346,33206185,32339351,32812719,33220059,32339353,33206187,32339355,32674305,32812722,33206187,33206188,33206234,32339354,32339355,32791410,32791411,33206188,33220009,32339355,32339356,32339356,32460579,32551909,32791410,32791412,32791415,33206188,33206189,33206235,33220009,32339357,32460578,32478000,32753608,32791410,32812723,33206188,33206189,33206189,33206240,32382241,32418838,32460578,32460579,32791411,32791412,32875980,33206190,33206236,33206236,33206245,33220010,32460579,32460580,32674308,32791412,32812724,33206189,33206190,33220011,33206191,32460580,33206191,33206192,32352893,33213018,32353822,32819963,32422540,32422841,32423141,33248119,32425143,32855626,32498331,32498332,32540073,33285684,32546256,32546256,32546260,33309646,33309647,32555024,32920565,33327851,32581814,32581814,32581814,32581815,32581815,32581801,32581802,32581815,32581816,32581816,32581817,32581803,32581816,32581817,32581817,32581817,32581818,32581817,32581818,32581818,33327426,32581830,32581831,32828278,32912649,32933960,33327426,32581831,32581832,32795544,32933961,32997216,33327426,33327426,33327427,33327472,33327473,33327476,33349964,32582548,32713759,32912649,32912650,32933961,33327427,33327427,33327473,33327476,33341248,32828279,33327428,32583282,32583283,32934695,33328162,32616687,33344877,32764475,32956718,32845703,33459372,32886372,33479706,32897159,33091631,32920407,33496720,33009270,33009269,33009270,33009271,33541152,33554974,33541154,33012666,33012664,33542848,33542854,33074689,33074710,33074729,33074743,33573877,33074812,33074875,33159176,33159177,33573954,33148961,33196220,33167875,33167875,33167876,33167873,33620452,33205678,33290246,33620457,33620502,33620503,33629008,33243477,33243476,33243481,33243480,33243483,33243467,33243481,33243482,33243482,33243483,33243483,33243484,33243485,33243482,33243484,33243485,33243479,33243480,33243483,33243483,33243484,33243485,33243485,33243484,33243489,33243491,33243492,33243495,33243494,33243496,33658255,33658257,33658258,33363856,33658259,33246265,33658260,33658306,33658260,33264795,33363858,33658260,33658261,33672081,33658307,33243502,33398609,33658261,33658262,33666812,33658262,33658263,33658309,33264797,33264800,33658267,33658267,33658313,33658268,33658269,33249045,33674860,33286091,33286103,33286104,33286104,33286105,33286106,33286106,33286107,33286108,33286104,33286104,33286105,33286107,33286109,33679568,33679569,33286119,33679568,33679569,33679570,33679616,33679619,33693390,33349359,33679570,33679616,33679571,33286121,33679571,33679572,33693392,33679572,33679573,33679574,33348111,33348111,33348245,33348242,33348371,33348378,33710702,33710705,33361674,33717354,33412612,33412613,33412613,33412614,33412615,33742822,33765409,33742824,33742870,33742823,33742824,33484229,33484229,33484241,33778632,33778631,33778632,33778678,33778682,33508950,33508953,33791040,33553732,33813436,33648177,33648389,33648601,33860850,33680289,33680375,33680460,33876746,33784424,33928731,33879107,33976076,34072649,34072867,34073020,34073021,34073022,34073022,34073023,34073024,34073024,34073025,34073025,34073026,34073027,34073028,34073031,34073032,34073033,34073034,34073034,34073043,34073050,34073065,34073066,34073067,34073067,34073068,34073068,34073069,34073069,34073070,34073070,34073071,34073071,34073024,34073025,34073025,34073026,34073028,34073028,34073032,34073033,34073038,34073067,34073068,34073068,34073069,34073069,34073025,34073026,34073026,34073032,34073033,34073069,34073028,34073033,34073034,34073069,34073070,34073027,34073028,34073029,34073034,34073035,34073047,34073069,34073070,34073070,34073030,34073035,34073070,34073070,34073071,34073071,34073070,34073071,34073072,34073073,34073072,34073073,34073040,34073041,34073041,34073042,34073043,34073043,34073077,34073077,34073078,34073085,34073043,34073044,34073079,34073079,34073092,34073144,34073145,34073045,34073046,34073079,34073080,34073046,34073080,34073080,34073081,34073082,34073084,34073086,34073089,34073145,34073146,34073080,34073081,34073081,34073088,34073146,34073082,34073087,34073096,34073091,34073095,34073110,34073111,34073111,34073112,34073112,34073111,34073112,34073112,34073112,34073113,34073114,34073113,34073114,34073119,34073114,34073115,34073116,34073116,34073117,34073118,34073119,34073123,34073144,34073115,34073116,34073116,34073117,34073117,34073118,34073118,34073119,34073119,34073120,34073120,34073121,34073121,34073122,34073122,34073123,34073124,34073125,34073127,34073127,34073130,34073132,34073135,34073137,34073144,34073144,34073116,34073117,34073117,34073118,34073118,34073119,34073119,34073120,34073120,34073121,34073121,34073122,34073122,34073123,34073123,34073124,34073124,34073125,34073127,34073135,34073137,34073143,34073144,34073145,34073117,34073118,34073118,34073119,34073120,34073120,34073121,34073122,34073123,34073124,34073125,34073131,34073136,34073145,34073118,34073119,34073119,34073120,34073120,34073121,34073121,34073122,34073122,34073123,34073124,34073124,34073125,34073125,34073126,34073126,34073127,34073127,34073137,34073145,34073145,34073146,34073119,34073120,34073120,34073121,34073121,34073122,34073122,34073123,34073123,34073124,34073124,34073125,34073126,34073127,34073134,34073134,34073137,34073137,34073146,34073146,34073147,34073120,34073121,34073121,34073122,34073122,34073123,34073123,34073124,34073125,34073126,34073126,34073129,34073140,34073145,34073147,34073147,34073121,34073122,34073122,34073123,34073123,34073124,34073126,34073126,34073127,34073127,34073144,34073147,34073148,34073148,34073122,34073123,34073123,34073124,34073124,34073125,34073125,34073127,34073127,34073129,34073140,34073143,34073144,34073145,34073146,34073148,34073123,34073124,34073124,34073125,34073125,34073126,34073126,34073127,34073127,34073128,34073128,34073129,34073130,34073131,34073132,34073134,34073136,34073138,34073139,34073139,34073141,34073141,34073142,34073142,34073143,34073144,34073144,34073145,34073146,34073146,34073147,34073147,34073148,34073148,34073149,34073124,34073125,34073125,34073126,34073126,34073127,34073128,34073128,34073129,34073130,34073131,34073132,34073133,34073138,34073139,34073140,34073140,34073141,34073142,34073142,34073143,34073144,34073146,34073147,34073148,34073149,34073125,34073126,34073126,34073127,34073127,34073128,34073129,34073132,34073139,34073142,34073143,34073144,34073145,34073145,34073146,34073149,34073149,34073126,34073127,34073128,34073128,34073129,34073130,34073131,34073132,34073133,34073135,34073139,34073141,34073143,34073145,34073147,34073147,34073148,34073149,34073149,34073150,34073127,34073128,34073128,34073129,34073129,34073130,34073130,34073131,34073131,34073132,34073133,34073133,34073134,34073134,34073138,34073138,34073139,34073142,34073143,34073143,34073144,34073144,34073145,34073146,34073146,34073147,34073147,34073148,34073148,34073149,34073150,34073150,34073151,34073128,34073129,34073129,34073130,34073130,34073131,34073131,34073132,34073133,34073133,34073134,34073135,34073136,34073142,34073144,34073145,34073146,34073149,34073150,34073150,34073151,34073129,34073130,34073130,34073131,34073131,34073132,34073132,34073133,34073134,34073139,34073142,34073143,34073145,34073145,34073146,34073147,34073148,34073149,34073150,34073151,34073152,34073130,34073131,34073131,34073132,34073134,34073140,34073142,34073143,34073144,34073144,34073145,34073147,34073150,34073151,34073152,34073131,34073132,34073135,34073143,34073144,34073145,34073152,34073152,34073132,34073133,34073133,34073134,34073135,34073135,34073136,34073137,34073137,34073138,34073139,34073140,34073141,34073142,34073143,34073145,34073145,34073146,34073146,34073147,34073147,34073148,34073149,34073149,34073150,34073150,34073151,34073152,34073152,34073153,34073133,34073134,34073134,34073135,34073136,34073136,34073137,34073137,34073138,34073139,34073139,34073141,34073142,34073143,34073144,34073144,34073145,34073146,34073146,34073147,34073147,34073150,34073151,34073153,34073153,34073134,34073137,34073138,34073139,34073142,34073143,34073145,34073146,34073146,34073147,34073147,34073150,34073152,34073153,34073154,34073154,34073136,34073144,34073145,34073146,34073146,34073147,34073148,34073149,34073150,34073153,34073154,34073154,34073137,34073137,34073143,34073144,34073147,34073149,34073149,34073154,34073155,34073155,34073155,34073138,34073144,34073147,34073148,34073149,34073151,34073156,34073140,34073145,34073145,34073147,34073147,34073148,34073149,34073149,34073150,34073151,34073152,34073153,34073154,34073156,34073156,34073142,34073143,34073145,34073146,34073147,34073148,34073148,34073151,34073152,34073154,34073154,34073155,34073155,34073157,34073144,34073146,34073148,34073148,34073152,34073158,34073143,34073144,34073148,34073151,34073157,34073158,34073149,34073154,34073158,34073147,34073149,34073154,34073158,34073150,34073152,34073155,34073156,34073159,34073159,34073149,34073152,34073160,34073152,34073156,34073159,34073160,34073161,34073149,34073155,34073161,34073150,34073153,34073154,34073154,34073155,34073155,34073156,34073158,34073162,34073156,34073157,34073157,34073160,34073162,34073155,34073155,34073159,34073161,34073162,34073163,34073156,34073156,34073160,34073163,34073154,34073155,34073156,34073156,34073157,34073157,34073158,34073160,34073160,34073161,34073161,34073163,34073164,34073164,34086909,34073156,34073157,34073157,34073158,34073161,34073163,34073164,34073165,34073157,34073158,34073158,34073160,34073161,34073162,34073162,34073164,34073165,34073165,34073158,34073159,34073159,34073160,34073161,34073162,34073164,34073165,34073166,34073159,34073160,34073160,34073161,34073161,34073162,34073163,34073164,34073165,34073166,34073166,34073160,34073161,34073161,34073162,34073163,34073163,34073164,34073164,34073165,34073165,34073166,34073167,34073167,34086912,34073161,34073162,34073163,34073163,34073164,34073165,34073165,34073167,34073167,34073168,34073162,34073163,34073164,34073165,34073165,34073167,34073168,34086913,34073164,34073164,34073165,34073166,34073166,34073167,34073167,34073168,34073168,34073166,34073167,34073168,34073168,34073169,34086914,34073165,34073166,34073166,34073167,34073168,34073168,34073169,34073169,34073170,34081643,34086914,34073166,34073167,34073167,34073168,34073169,34073169,34073170,34073167,34073168,34073168,34073169,34073170,34073170,34073168,34073169,34073169,34073170,34073170,34073171,34081645,34086916,34073169,34073170,34073170,34073171,34073171,34073172,34073170,34073171,34073171,34073172,34073172,34073175,34086917,34073171,34073172,34073172,34073173,34073172,34073173,34073219,34073173,34073174,34073209,34073219,34073174,34073175,34073175,34073176,34073176,34073178,34073178,34073186,34073186,34073187,34073187,34073189,34073190,34073205,34073209,34073210,34073219,34073220,34081648,34086739,34086919,34095635,34073175,34073176,34073176,34073177,34073178,34073179,34073179,34073180,34073181,34073182,34073182,34073183,34073183,34073185,34073185,34073186,34073187,34073187,34073188,34073189,34073189,34073191,34073192,34073192,34073193,34073195,34073196,34073197,34073198,34073202,34073206,34073206,34073208,34073208,34073210,34073210,34073211,34073213,34073214,34073215,34073216,34073216,34073217,34073218,34073218,34073219,34073219,34073220,34073220,34086919,34073176,34073177,34073179,34073179,34073180,34073185,34073187,34073188,34073189,34073190,34073193,34073193,34073196,34073197,34073206,34073207,34073209,34073218,34073218,34073219,34073219,34073220,34073220,34073221,34073177,34073183,34073189,34073215,34073217,34073218,34073220,34073221,34073221,34073178,34073180,34073192,34073198,34073204,34073207,34073221,34073221,34073222,34073179,34073184,34073218,34073222,34073223,34073182,34073190,34073193,34073224,34073183,34073184,34073191,34073194,34073224,34073184,34073190,34073224,34073225,34073185,34073194,34073225,34073226,34073222,34073194,34073217,34073227,34073225,34073194,34073229,34073196,34073202,34073203,34073227,34073231,34073229,34073231,34073198,34073220,34073229,34086931,34073200,34073203,34073207,34073228,34073230,34073231,34073231,34073232,34073232,34086931,34073203,34073223,34081661,34086932,34073202,34073204,34073204,34073206,34073215,34073227,34073233,34086932,34073205,34073204,34073205,34073219,34073234,34073234,34073235,34081659,34081661,34073221,34073235,34073236,34073220,34073221,34073236,34086935,34073237,34073237,34073238,34073222,34073235,34073238,34073225,34073241,34073241,34073242,34073242,34073242,34073245,34073248,34073249,34073247,34073248,34073249,34073250,34073251,34073251,34073251,34073252,34073252,34073253,34073254,34073245,34073246,34073255,34073256,34073257,34081684,34073256,34073257,34073259,34073255,34073257,34073260,34073260,34073260,34073259,34073260,34073261,34073262,34073261,34073262,34073263,34073261,34073262,34073262,34073263,34073263,34073263,34073263,34073264,34073263,34073264,34073264,34073265,34073265,34073266,34073267,34073268,34073300,34081691,34081692,34081693,34081693,34081694,34081694,34081695,34081695,34081696,34081696,34081698,34081703,34081704,34086785,34086964,34086965,34086996,34095681,34073268,34081694,34081695,34081696,34081697,34086965,34086965,34081692,34081694,34081695,34081696,34081697,34086966,34086997,34086997,34086998,34087002,34087007,34087007,34087018,34087018,34087023,34087062,34095682,34095730,34095731,34095795,34642263,40782803,34086966,34086967,34081737,34086999,34090135,34090130,34090137,34090129,34090136,34090137,34090135,34090121,34090121,34090129,34090132,34090135,34090135,34090136,34090137,34090139,34090136,34090136,34090140,34090141,34090144,34090122,34090123,34090137,34090137,34090138,34090138,34090123,34090125,34090134,34090134,34090135,34090135,34090136,34090137,34090137,34090138,34090138,34090139,34090139,34090140,34090135,34090137,34090139,34090139,34090140,34090140,34090141,34090136,34090138,34090140,34090140,34090141,34090141,34090141,34090142,34090146,34090142,34090145,34090145,34090143,34090145,34090226,34090226,34090153,34090153,34090153,34095404,34095436,34090149,34090151,34090154,34095405,34095405,34095406,34090152,34095407,34095407,34090152,34090157,34095407,34095408,34090156,34095408,34095409,34095409,34095410,34095441,34095410,34090158,34095411,34095411,34095412,34095412,34095413,34095234,34095414,34095415,34095415,34090322,34090323,34095498,34095498,34100376,34100378,34100379,34100556,34100558,34100559,34100663,34100664,34100665,34100665,34100666,34100666,34100667,34100671,34100677,34100685,34100690,34100691,34100692,34100693,34100693,34100694,34100694,34100695,34100695,34100696,34100696,34100697,34100698,34100739,34100668,34100694,34100695,34100695,34100696,34100696,34100696,34100696,34100696,34100696,34100697,34100696,34100697,34100699,34100698,34100702,34100709,34100714,34100716,34100721,34100723,34100721,34100722,34100723,34100722,34100724,34100724,34100725,34100768,34100770,34100723,34100724,34100724,34100725,34100725,34100726,34100728,34100770,34100724,34100725,34100725,34100726,34100733,34100769,34100771,34100725,34100726,34100726,34100727,34100744,34100760,34100770,34100770,34100771,34100726,34100727,34100727,34100728,34100734,34100744,34100746,34100749,34100770,34100770,34100771,34100727,34100728,34100728,34100729,34100729,34100730,34100730,34100731,34100731,34100734,34100734,34100736,34100741,34100742,34100743,34100744,34100745,34100745,34100746,34100747,34100747,34100748,34100749,34100750,34100750,34100751,34100752,34100752,34100770,34100771,34100771,34100728,34100729,34100729,34100730,34100730,34100731,34100731,34100732,34100733,34100734,34100735,34100736,34100736,34100737,34100738,34100738,34100739,34100740,34100741,34100742,34100743,34100744,34100744,34100745,34100745,34100746,34100747,34100747,34100748,34100748,34100749,34100750,34100751,34100751,34100752,34100752,34100753,34100753,34100754,34100756,34100756,34100757,34100768,34100769,34100771,34100771,34100772,34100729,34100730,34100730,34100731,34100731,34100732,34100732,34100735,34100735,34100736,34100737,34100738,34100739,34100739,34100745,34100746,34100746,34100747,34100748,34100748,34100749,34100750,34100751,34100752,34100753,34100753,34100756,34100771,34100772,34100772,34100731,34100733,34100734,34100735,34100736,34100736,34100738,34100740,34100746,34100747,34100747,34100748,34100749,34100749,34100750,34100751,34100751,34100754,34100754,34100757,34100772,34100772,34100773,34100732,34100736,34100736,34100746,34100747,34100749,34100749,34100753,34100769,34100773,34100732,34100733,34100733,34100736,34100737,34100737,34100740,34100742,34100743,34100747,34100748,34100749,34100750,34100751,34100757,34100766,34100772,34100773,34100774,34100733,34100734,34100735,34100735,34100737,34100748,34100749,34100750,34100765,34100772,34100774,34100734,34100735,34100737,34100738,34100747,34100748,34100749,34100749,34100749,34100750,34100751,34100752,34100754,34100768,34100774,34100749,34100750,34100753,34100775,34100776,34100750,34100752,34100755,34100774,34100740,34100745,34100747,34100756,34100747,34100750,34100752,34100752,34100754,34100755,34100760,34100776,34100777,34100742,34100745,34100750,34100752,34100753,34100754,34100756,34100757,34100762,34100774,34100778,34100779,34100750,34100757,34100779,34100752,34100754,34100756,34100779,34100754,34100764,34100756,34100776,34100748,34100755,34100757,34100758,34100760,34100761,34100755,34100756,34100758,34100758,34100770,34100755,34100756,34100758,34100760,34100774,34100782,34100782,34100756,34100757,34100758,34100759,34100760,34100777,34100782,34100759,34100760,34100783,34100757,34100758,34100760,34100761,34100767,34100785,34100760,34100762,34100763,34100785,34100763,34100768,34100761,34100766,34100770,34100762,34100762,34100765,34100766,34100772,34100788,34100762,34100764,34100763,34100764,34100765,34100765,34100766,34100766,34100767,34100767,34100768,34100768,34100769,34100769,34100770,34100770,34100771,34100772,34100772,34100773,34100774,34100775,34100778,34100780,34100782,34100786,34100787,34100788,34100788,34100789,34100789,34100765,34100765,34100766,34100766,34100768,34100768,34100769,34100771,34100771,34100772,34100773,34100781,34100781,34100783,34100789,34100789,34100765,34100766,34100767,34100770,34100772,34100772,34100773,34100774,34100781,34100790,34100767,34100768,34100769,34100769,34100770,34100770,34100771,34100771,34100772,34100774,34100774,34100775,34100776,34100778,34100782,34100783,34100784,34100790,34100791,34100768,34100769,34100769,34100770,34100770,34100771,34100771,34100772,34100773,34100773,34100775,34100775,34100786,34100791,34100791,34100792,34100770,34100770,34100771,34100771,34100772,34100772,34100773,34100773,34100774,34100775,34100775,34100776,34100777,34100780,34100781,34100784,34100789,34100789,34100790,34100790,34100791,34100791,34100792,34100792,34100774,34100775,34100776,34100771,34100772,34100772,34100773,34100773,34100774,34100776,34100778,34100779,34100782,34100785,34100790,34100792,34100793,34100793,34109434,34100772,34100773,34100774,34100777,34100780,34100780,34100793,34100773,34100774,34100777,34100777,34100778,34100781,34100784,34100785,34100790,34100791,34100793,34100794,34100774,34100776,34100777,34100778,34100778,34100783,34100789,34100792,34100793,34100794,34100795,34109435,34100775,34100776,34100778,34100778,34100780,34100786,34100787,34100790,34100792,34100792,34100794,34100795,34100795,34100778,34100779,34100791,34100793,34100795,34100796,34100777,34100778,34100779,34100784,34100796,34100778,34100779,34100780,34100782,34100782,34100785,34100787,34100794,34100796,34100797,34100782,34100784,34100784,34100795,34100796,34100796,34100797,34100781,34100783,34100787,34100788,34100794,34100795,34100796,34100797,34100798,34100783,34100790,34100793,34100794,34100795,34100796,34100797,34100798,34100798,34100799,34100799,34100799,34100799,34100799,34100785,34100788,34100797,34100799,34100800,34100800,34100800,34100800,34100793,34100801,34100794,34100801,34100801,34100797,34100802,34100802,34100793,34100796,34100803,34100803,34100804,34100802,34100803,34100803,34100804,34100795,34100805,34100805,34100805,34100806,34100798,34100799,34100803,34100806,34100804,34100806,34100806,34100805,34100807,34100807,34100804,34100807,34100808,34100807,34100808,34100809,34100809,34100810,34100810,34100808,34100810,34100810,34100812,34100811,34100811,34100809,34100811,34100812,34100812,34100810,34100812,34100812,34100813,34109502,34100811,34100812,34100812,34100813,34100813,34100812,34100813,34100813,34100813,34100814,34100814,34100814,34100815,34109455,34100815,34100816,34100816,34100821,34100836,34100844,34100845,34100845,34100846,34100846,34109456,34109504,34109504,34109567,34100816,34100817,34100818,34100821,34100823,34100823,34100826,34100828,34100828,34100829,34100829,34100831,34100833,34100834,34100835,34100836,34100842,34100842,34100844,34100845,34100845,34100846,34100846,34100847,34109456,34109504,34109505,34100817,34100818,34100819,34100819,34100821,34100823,34100827,34100829,34100833,34100834,34100834,34100837,34100838,34100842,34100844,34100844,34100845,34100845,34100846,34100846,34100847,34100847,34100818,34100822,34100824,34100826,34100846,34100847,34100847,34100848,34100848,34100848,34100820,34100846,34100847,34100847,34100848,34100848,34100849,34100836,34100839,34100847,34100849,34100845,34100848,34100849,34100833,34100838,34100851,34100851,34100852,34100840,34100851,34100830,34100854,34100852,34100854,34100856,34100851,34100856,34100857,34100858,34100858,34100858,34100859,34100860,34100859,34100862,34100861,34100863,34100863,34100863,34100864,34100864,34100862,34100863,34100863,34100864,34100865,34100865,34100856,34100857,34100867,34100867,34100867,34100867,34100868,34100868,34100872,34100871,34100872,34100873,34100874,34100873,34100873,34100874,34100875,34100875,34100874,34100875,34100876,34100875,34100876,34100876,34100876,34100877,34109486,34100877,34109487,34100878,34100879,34109456,34109487,34109487,34109535,41732601,34109488,34109536,34109488,34118065,34118096,34118097,34118098,34118099,34118099,34118100,34118100,34118101,34118102,34118104,34118104,34118106,34118107,34118107,34118108,34118111,34118119,34118119,34118121,34118124,34118126,34118127,34118136,34118137,34118139,34118140,34118141,34118142,34118142,34118143,34118144,34118144,34118145,34118145,34118146,34118146,34118147,34118098,34118099,34118099,34118100,34118100,34118101,34118104,34118111,34118119,34118137,34118137,34118138,34118142,34118144,34118145,34118145,34118146,34118146,34118100,34118100,34118119,34118145,34118145,34118146,34118100,34118146,34118101,34118102,34118102,34118110,34118113,34118127,34118130,34118132,34118138,34118139,34118139,34118144,34118146,34118146,34118147,34118147,34118148,34118102,34118103,34118113,34118131,34118140,34118144,34118144,34118145,34118146,34118146,34118147,34118147,34118103,34118144,34118147,34118147,34118148,34118148,34118149,34118150,34118151,34118152,34118152,34118154,34118118,34118156,34118156,34118157,34118220,34118155,34118158,34118158,34118158,34118159,34118159,34118166,34118166,34118166,34118167,34118167,34118168,34118169,34118172,34118173,34118174,34118174,34118175,34118174,34118178,34118183,34118183,34118184,34118184,34118183,34118184,34118184,34118185,34118187,34118188,34118186,34118189,34118189,34118189,34118190,34118189,34118189,34118190,34118190,34118190,34118191,34118191,34118192,34118192,34118192,34118193,34118198,34118193,34118194,34118194,34118195,34118195,34118196,34118196,34118197,34118199,34118200,34118205,34118208,34118210,34118194,34118195,34118195,34118196,34118196,34118197,34118197,34118198,34118198,34118199,34118199,34118200,34118201,34118201,34118203,34118204,34118206,34118207,34118214,34118215,34118216,34118216,34118217,34118220,34118221,34118195,34118196,34118196,34118197,34118197,34118198,34118198,34118199,34118199,34118200,34118200,34118201,34118201,34118202,34118202,34118203,34118203,34118204,34118204,34118210,34118219,34118221,34118221,34118196,34118197,34118197,34118198,34118198,34118199,34118199,34118200,34118201,34118204,34118217,34118218,34118220,34118222,34118197,34118198,34118198,34118199,34118199,34118200,34118200,34118201,34118201,34118202,34118203,34118204,34118204,34118206,34118207,34118210,34118212,34118213,34118216,34118219,34118222,34118198,34118199,34118199,34118200,34118200,34118201,34118201,34118202,34118202,34118203,34118203,34118204,34118204,34118205,34118205,34118212,34118214,34118215,34118216,34118218,34118218,34118219,34118223,34118199,34118200,34118200,34118201,34118201,34118202,34118202,34118203,34118203,34118205,34118206,34118206,34118208,34118208,34118210,34118212,34118217,34118219,34118223,34118200,34118201,34118201,34118202,34118202,34118203,34118203,34118204,34118205,34118206,34118206,34118207,34118209,34118212,34118213,34118215,34118218,34118219,34118219,34118221,34118223,34118223,34118224,34118201,34118202,34118202,34118203,34118203,34118204,34118204,34118205,34118205,34118206,34118206,34118207,34118207,34118209,34118218,34118218,34118219,34118220,34118222,34118223,34118224,34118224,34118202,34118203,34118203,34118204,34118204,34118205,34118205,34118206,34118206,34118207,34118207,34118208,34118210,34118214,34118216,34118217,34118218,34118219,34118219,34118220,34118220,34118221,34118221,34118222,34118222,34118223,34118224,34118225,34118203,34118204,34118204,34118205,34118205,34118206,34118206,34118207,34118207,34118208,34118208,34118210,34118213,34118214,34118215,34118215,34118216,34118216,34118217,34118219,34118219,34118220,34118221,34118222,34118223,34118225,34118225,34118204,34118205,34118205,34118206,34118206,34118207,34118207,34118208,34118208,34118209,34118210,34118211,34118215,34118218,34118219,34118220,34118220,34118221,34118221,34118222,34118223,34118224,34118225,34118226,34118205,34118206,34118206,34118207,34118207,34118208,34118208,34118209,34118209,34118211,34118214,34118217,34118218,34118220,34118220,34118221,34118222,34118223,34118224,34118226,34118206,34118207,34118207,34118208,34118208,34118209,34118209,34118210,34118212,34118213,34118216,34118218,34118219,34118220,34118220,34118221,34118222,34118222,34118223,34118224,34118226,34118227,34118207,34118208,34118208,34118209,34118209,34118210,34118210,34118212,34118213,34118215,34118216,34118217,34118220,34118221,34118221,34118222,34118223,34118225,34118225,34118226,34118227,34118227,34118208,34118209,34118209,34118210,34118210,34118211,34118212,34118213,34118215,34118217,34118218,34118219,34118219,34118221,34118222,34118223,34118223,34118224,34118225,34118209,34118210,34118210,34118211,34118211,34118213,34118213,34118216,34118220,34118221,34118221,34118222,34118222,34118223,34118224,34118225,34118226,34118228,34118210,34118211,34118211,34118213,34118218,34118219,34118220,34118222,34118223,34118223,34118224,34118224,34118225,34118229,34118211,34118212,34118212,34118214,34118214,34118215,34118216,34118217,34118218,34118220,34118221,34118221,34118223,34118223,34118224,34118224,34118225,34118225,34118226,34118227,34118229,34118212,34118213,34118213,34118214,34118214,34118215,34118216,34118216,34118218,34118221,34118221,34118222,34118223,34118224,34118225,34118225,34118226,34118227,34118230,34118213,34118215,34118215,34118219,34118219,34118220,34118220,34118221,34118222,34118224,34118225,34118225,34118226,34118227,34118230,34118215,34118215,34118216,34118216,34118218,34118219,34118220,34118220,34118221,34118222,34118224,34118225,34118225,34118226,34118226,34118227,34118228,34118229,34118230,34118231,34118223,34118225,34118217,34118225,34118217,34118218,34118219,34118221,34118224,34118226,34118226,34118227,34118229,34118230,34118231,34118219,34118220,34118221,34118221,34118224,34118224,34118225,34118226,34118228,34118228,34118229,34118229,34118230,34118233,34118227,34118227,34118221,34118226,34118227,34118228,34118228,34118229,34118229,34118234,34118229,34118230,34118223,34118225,34118230,34118230,34118233,34118223,34118224,34118226,34118228,34118229,34118230,34118231,34118235,34118225,34118227,34118230,34118231,34118231,34118232,34118233,34118235,34118225,34118230,34118231,34118232,34118226,34118227,34118228,34118230,34118232,34118232,34118233,34118234,34118234,34118235,34118235,34118229,34118231,34118231,34118233,34118235,34118230,34118231,34118232,34118233,34118235,34118238,34485867,34118232,34118234,34118238,34118231,34118232,34118233,34118234,34118234,34118235,34118239,34118233,34118233,34118234,34118235,34118235,34118236,34118236,34118237,34118238,34118239,34118239,34118233,34118234,34118235,34118236,34118240,34118234,34118234,34118235,34118237,34118238,34118234,34118236,34118235,34118236,34118237,34118238,34118238,34118239,34118239,34118241,34118241,34664747,34118236,34118237,34118237,34118238,34118239,34118240,34118240,34118241,34118242,37635291,34118237,34118238,34118240,34118240,34118242,34118242,34118238,34118239,34118240,34118241,34118241,34118242,34118242,34118243,34118239,34118240,34118240,34118241,34118241,34118242,34118242,34118243,34118243,34118240,34118241,34118243,34118244,34118242,34118242,34118243,34118244,34118244,34118242,34118243,34118243,34118244,34118245,34118243,34118244,34118244,34118245,34118245,34118244,34118245,34118245,34118246,34118245,34118246,34118246,34118246,34118247,34118247,34118248,34118249,34118249,34118250,34118250,34118251,34118252,34118252,34118253,34118253,34118254,34118254,34118255,34118255,34118257,34118257,34118258,34118259,34118259,34118261,34118262,34118262,34118263,34118264,34118264,34118265,34118266,34118266,34118267,34118268,34118269,34118281,34118281,34118282,34118283,34118284,34118285,34118286,34118287,34118287,34118292,34118294,34118294,34118295,34118295,34118296,34118296,34664753,34664753,35105875,41741286,34118249,34118250,34118250,34118251,34118251,34118252,34118253,34118254,34118254,34118255,34118255,34118256,34118257,34118257,34118258,34118262,34118263,34118264,34118264,34118265,34118265,34118266,34118266,34118268,34118268,34118269,34118269,34118277,34118279,34118281,34118284,34118288,34118292,34118294,34118295,34118295,34118296,34118296,34118297,34118250,34118251,34118251,34118252,34118253,34118254,34118256,34118295,34118251,34118252,34118253,34118256,34118264,34118269,34118271,34118282,34118297,34118298,34118252,34118253,34118253,34118254,34118254,34118255,34118255,34118256,34118256,34118257,34118257,34118259,34118260,34118265,34118266,34118268,34118270,34118270,34118271,34118280,34118282,34118283,34118285,34118290,34118291,34118292,34118294,34118295,34118296,34118296,34118297,34118297,34118298,34118298,34664755,34664756,34118253,34118255,34118256,34118257,34118258,34118261,34118265,34118265,34118268,34118270,34118271,34118271,34118274,34118284,34118296,34118296,34118297,34118298,34118299,34118255,34118256,34118256,34118257,34118257,34118258,34118260,34118261,34118262,34118263,34118264,34118265,34118267,34118268,34118269,34118269,34118270,34118270,34118271,34118272,34118274,34118275,34118281,34118286,34118287,34118288,34118296,34118297,34118298,34118298,34118299,34176273,34118271,34118257,34118258,34118258,34118263,34118269,34118272,34118274,34118284,34118290,34118298,34118300,34118269,34118271,34118272,34118298,34118301,34118258,34118259,34118259,34118260,34118260,34118261,34118262,34118262,34118265,34118267,34118268,34118271,34118272,34118274,34118274,34118281,34118285,34118294,34118299,34118299,34118300,34118300,34118301,34664759,41691752,34118259,34118260,34118261,34118262,34118264,34118265,34118267,34118269,34118270,34118271,34118273,34118274,34118285,34118287,34118298,34118298,34118300,34118301,34118302,34664655,34118261,34118261,34118262,34118263,34118264,34118265,34118266,34118267,34118269,34118270,34118271,34118271,34118272,34118273,34118273,34118274,34118275,34118281,34118286,34118293,34118300,34118301,34118302,34664759,34664759,34118263,34118264,34118267,34118271,34118274,34118290,34118298,34118303,34118265,34118266,34118268,34118271,34118273,34118273,34118274,34118275,34118301,34118302,34118303,34118303,34118263,34118264,34118272,34118275,34118276,34118301,34118303,34118304,34118266,34118273,34118275,34118302,34118266,34118274,34118302,34118303,34118305,34118271,34118275,34118276,34118277,34118278,34118281,34118292,34118302,34118303,34118303,34118304,34118304,34118304,34118305,34118306,34118268,34118272,34118275,34118271,34118275,34118276,34118276,34118306,34118307,34118278,34118279,34118303,34118306,34118307,34118273,34118278,34189220,34118276,34118285,34118301,34118277,34118277,34118277,34118280,34118284,34118309,34118278,34118279,34118279,34118310,34118276,34118294,34118309,34118278,34118282,34118283,34118299,34118309,34118311,34118280,34118290,34118308,34118311,34118280,34118280,34118281,34118283,34664769,34118287,34118309,34118312,34118281,34118282,34118282,34118285,34118285,34118297,34118309,34118311,34118312,34118313,34118282,34118283,34118284,34118295,34118298,34118302,34118311,34118312,34664770,34118283,34118285,34118286,34118286,34118292,34118298,34118312,34118285,34118285,34118286,34118286,34118287,34118302,34118305,34118309,34118313,34118313,34118314,34664770,34118286,34118287,34118287,34118288,34118290,34118313,34118315,34118286,34118288,34118311,34118313,34118315,34118287,34118288,34118288,34118291,34118292,34118298,34118300,34118301,34118308,34118309,34118310,34118313,34118313,34118314,34118314,34118315,34118316,34118289,34118294,34118296,34118315,34118315,34118316,34118289,34118290,34118291,34118296,34118301,34118302,34118302,34118303,34118307,34118313,34118314,34118314,34118315,34118315,34118316,34118316,34118317,34118291,34118293,34118298,34118304,34118305,34118311,34118312,34118313,34118314,34118315,34118315,34118316,34118316,34118317,34118317,34118305,34118316,34118317,34118318,34118292,34118302,34118317,34118315,34118318,34118319,34118316,34118317,34118320,34118319,34118320,34118319,34118321,34118322,34118321,34118304,34118320,34118323,34118322,34118324,34118324,34118313,34118325,34118321,34118320,34118325,34118325,34118327,34118323,34118326,34118316,34118319,34118322,34118326,34118326,34118327,34118328,34118329,34118326,34118329,34118328,34118328,34118329,34118330,34118321,34118327,34118327,34118321,34118330,34118331,34118332,34118330,34118331,34118325,34118330,34118332,34118333,34118322,34118331,34118333,34118323,34118324,34118334,34118324,34118334,34118333,34118335,34118333,34118334,34118334,34118335,34118335,34118336,34118336,34118334,34118335,34118335,34118336,34118336,34118338,34118334,34118335,34118337,34118338,34118336,34118339,34118338,34118339,34118340,34118338,34118339,34118340,34118338,34118339,34118340,34118341,34118339,34118339,34118340,34118341,34118339,34118340,34118340,34118341,34118342,34118340,34118341,34118341,34118342,34118341,34118342,34118343,34118342,34118343,34118343,34118343,34118344,34118344,34118345,34118346,34119686,34138067,34165832,34165834,34172405,34176318,34189256,34189257,34189257,34189258,34189260,34189260,34189261,34189261,34189262,34189265,34189266,34189268,34189269,34269984,34284390,34293710,34302562,34302562,34424044,34424044,34424045,34424046,34449998,34485917,34485917,34485919,34523168,34631052,34631187,34664699,34664700,34664700,34664707,34664712,34664713,34664714,34664798,34664799,34664799,34664800,34664800,34664801,34664801,34664802,34664802,34664803,34664808,34687987,34851745,35008984,35105922,35105922,35105923,35126829,35566328,35566329,35566329,35566331,35566331,35984894,36008077,37338135,37338136,37629970,37632230,37632231,37632231,37632232,37635345,37635347,37786900,38195784,38639617,39122452,39321443,39399254,40263730,41741335,34189257,34189258,34664714,34664799,34664801,34664801,34664802,34664802,34664803,34664803,35105924,38195782,41741335,34189258,34631188,34664800,34664801,34664802,34664802,34664803,34664803,34664804,41691796,34121084,34666196,34157802,41761070,34213341,34213343,34236766,35153432,34226476,34718874,34234304,34234307,34722787,34722789,34260183,34260183,34260184,34260186,34260169,34260184,34260186,34260186,34260187,34260187,34260189,34260192,34260193,34260195,34260182,34260183,34260184,34260184,34260185,34260185,34260186,34260187,34260188,34260190,34260186,34260191,34260199,34260200,34260200,34260199,34260201,34260203,34260205,34260207,34260209,34735726,34735728,34735727,34735728,34260199,34494971,34735728,34735641,34735726,34735728,34735729,34735730,34735727,34735729,34735730,34494973,34735730,34494974,34594099,34735729,34735731,34735731,34735729,34735732,34735732,34735733,34702121,34735633,34735735,34735737,34735738,34700324,34735739,34702126,34735740,34735741,34735741,34735741,34735741,34421635,34816452,34450447,34830859,34469085,34599420,34486794,34486795,34849033,34849034,34729758,34729758,34729757,34729758,34729758,34729759,34729758,34729759,34729759,34729761,34729759,34729762,34970514,34970515,34970427,34970512,34970513,34970514,34970516,38945331,34970428,34970515,34970428,34970513,34970514,34970515,34970515,34970516,34970517,34970517,34970518,34781724,34996527,34853506,34853507,34853514,34853518,35032389,35032304,35032306,35032308,34928003,34928004,34928007,35069637,35069637,35069549,35069638,35140440,35175854,35143770,35143905,35144040,35144042,35144042,35144043,35144044,35177654,35177656,35177656,35177657,35618778,38145087,35211065,35211062,35211064,35211066,35211066,35211081,35211165,35211163,35211168,35211167,35211169,35211081,35211092,35211091,35211092,35211093,35211093,35211095,35211176,35211101,35211102,35211177,35211178,35211178,35211179,35211180,35211180,35211180,35211181,35211181,35211184,35211183,35211254,35211254,35211255,35211272,35211254,35211254,35211255,35211255,35211256,35211270,35211271,35211274,35211255,35211256,35211257,35211255,35211256,35211256,35211257,35211258,35211257,35211257,35211258,35211258,35211271,35211272,35211272,35211273,35211274,35211277,35211257,35211258,35211258,35211259,35211274,35211274,35211258,35211259,35211259,35211264,35211272,35211273,35211273,35211274,35211274,35211275,35211275,35211276,35211259,35211260,35211261,35211261,35211262,35211270,35211272,35211272,35211273,35211273,35211274,35211274,35211275,35211275,35211276,35211276,35211277,35211278,35211278,35211279,35211281,35211260,35211261,35211261,35211262,35211263,35211264,35211264,35211269,35211271,35211271,35211272,35211272,35211273,35211273,35211274,35211274,35211275,35211275,35211276,35211276,35211277,35211277,35211278,35211278,35211279,35211281,35211261,35211262,35211262,35211263,35211264,35211265,35211266,35211266,35211267,35211268,35211268,35211269,35211271,35211271,35211272,35211272,35211273,35211273,35211274,35211274,35211275,35211275,35211276,35211276,35211277,35211278,35211279,35211263,35211269,35211273,35211274,35211274,35211275,35211275,35211276,35211277,35211278,35211269,35211273,35211274,35211274,35211275,35211276,35211276,35211277,35211273,35211276,35211278,35211279,35211275,35211276,35211277,35211277,35211281,35211279,35211277,35211280,35211270,35211277,35211279,35211279,35211280,35211289,35211281,35211281,35211282,35211277,35211284,35211276,35211283,35211281,35211282,35211282,35211282,35211284,35211283,35211286,35211287,35211283,35211285,35211286,35211283,35211284,35211285,35211285,35211286,35211285,35211286,35211287,35211287,35211288,35211288,35211285,35211286,35211287,35211287,35211288,35211288,35211289,35211286,35211287,35211287,35211288,35211288,35211289,35211289,35211290,35211290,35211291,35211291,41411108,35211287,35211288,35211288,35211289,35211289,35211290,35211293,35652394,36112800,35211288,35211289,35211289,35211290,35211290,35211291,35211291,35211292,35398217,35652394,36112804,36515381,38178703,38181818,35211289,35211290,35211290,35211291,35211291,35211292,35211293,35211295,35211296,35211299,35652395,36112801,36112802,38176442,38178701,38178702,38178703,38178703,38181818,42287807,35211290,35211291,35211291,35211292,35211292,35211293,35211295,35211295,35211296,35652395,35652396,36027279,36112801,37772662,38176443,38178704,38181819,38181820,38742254,35211291,35211292,35211292,35211293,35211293,35211294,35211294,35211295,35211295,35211296,35211297,35211298,35211299,35211302,35302294,35555457,35652395,35652396,35652396,35749421,36062406,36112802,36112803,36112804,36112804,37061950,37884607,37884611,38176444,38176444,38178702,38178703,38178704,38178707,38181818,38181819,38181820,38181820,38742254,39668926,42287808,35211292,35211293,35211293,35211294,35211294,35211295,35211296,35211298,35211299,35211300,35211302,35349877,35517238,35652397,35673304,36112804,36112806,36112808,36199222,36911522,37089775,37841476,38176444,38178702,38178703,38178703,38178704,38178704,38178705,38181820,38181821,38994577,39186091,39668926,40810203,41411109,35211293,35211294,35211294,35211295,35211295,35211296,35211296,35211297,35211297,35211298,35211298,35211299,35211299,35492869,35652395,35652396,35652397,35652397,35658989,35673307,35744879,35844579,36112803,36112804,36112804,36112805,36112806,36112807,36199224,36334910,37089776,37101804,37604644,37772664,37884607,37884608,37884609,37884610,37884612,38176442,38176443,38176444,38176444,38176445,38178704,38178704,38178705,38178705,38178706,38178708,38178708,38181820,38181821,38333935,38742255,38742256,39085737,39095432,39186091,39438944,39668927,39867917,40812441,41411109,42287809,35211294,35211295,35211295,35211296,35211296,35211297,35211297,35211298,35211300,35398219,35555459,35652397,35652398,35652398,35652404,35673304,36002964,36027277,36112803,36112805,36112806,36501739,37884610,37884612,38176445,38176445,38176446,38178703,38178705,40810204,41928622,35211295,35211296,35211296,35211297,35211297,35211298,35211300,35211301,35652396,35652397,35652398,35652398,36112799,36112804,36112805,36112809,36199223,36531369,36911524,37608220,37884616,38176444,38176445,38176446,38178705,38178706,38181822,38742257,40810205,41411112,41411112,35211296,35211297,35211297,35211298,35211298,35211299,35211299,35211300,35211302,35211303,35211304,35652398,35652398,35652399,35733170,35749424,36112804,36112805,37604645,37772665,37828989,37884611,38176445,38176446,38176447,38178704,38178704,38178706,38178707,38178707,38178708,38178708,35211297,35211298,35211298,35211299,35211299,35211300,35211300,35211301,35211301,35211302,35507107,35652320,35652398,35652399,35749424,36062409,36112804,36112807,36112810,36515385,37089778,37772666,38176444,38176445,38176447,38178706,38178707,38178707,38178708,38178708,38181823,39065909,41411114,35211298,35211299,35211299,35211300,35211300,35211302,35211303,35349879,35398225,35555461,35652399,35652399,35652400,35673306,36112804,36112807,36112809,37280406,37772666,37884613,37884613,38176446,38176448,38178707,38181824,35211299,35211300,35211300,35211301,35211301,35211302,35211302,35211303,35652399,35652400,35652400,36112806,36112807,36112807,36199225,37884611,38176449,38178706,38178707,39668930,35211300,35211301,35211301,35211302,35211303,35211304,35268555,35652407,35673310,36112807,36112808,37089779,37772667,37884613,38176448,38176449,38178708,38178709,35211302,35211303,35652322,35652401,35652401,35749426,36112808,36112809,36112809,36199226,36515387,36531372,36769669,38176448,38176449,38178710,38181825,38333358,39353334,35398224,35652402,36112808,36112809,36199229,37884614,38178709,38181826,39095437,35211303,35211304,35211305,35652401,35652402,35652402,35652403,36112809,37884615,38176449,38176449,38178709,38454140,39095437,35211305,35652401,36112808,37844057,37884614,38066263,38176449,38178710,35211305,35652402,35652403,36112808,36112809,36112810,36112810,36112811,36112812,36824199,36911629,35211307,35349883,35398225,35652403,35652403,35652404,35669164,36112810,36112811,36112813,36334916,36554551,37884615,38176452,38178710,38178711,35302301,35555467,35652404,35652405,35673310,35673312,36112812,36419230,37884616,38178712,38178712,38178713,38178714,38178715,40810211,35652405,36112813,36112814,37884620,38178714,35257663,36136008,35325822,36170074,35393306,35393309,35743409,38269720,35488474,35488477,35488475,35790993,36557821,38317305,35585157,35585158,35585158,35585159,35585162,35585165,35989818,36949170,38365642,36743449,35860074,36299750,35774462,38166203,35802988,35803097,35803212,36408801,35823194,36418759,35899636,35899636,35899637,35899639,39086433,35996575,36466339,39086433,36456977,35996576,36093353,36093354,36093434,36093429,36093499,36093515,36093518,36093500,36093514,36093500,36093501,36093515,36093515,36093516,36093516,36093517,36093517,36093518,36093518,36093519,36093502,36093516,36093516,36093517,36093518,36093520,36093520,36093504,36093512,36093516,36093516,36093517,36093517,36093518,36093518,36093519,36093519,36093520,36093520,36093521,36093521,36093522,36093522,36093525,36093519,36093521,36093516,36093518,36093520,36093539,36093540,36093527,36553921,38325727,36093531,36093532,38617564,38619824,40386847,36093532,36093532,36553923,36553925,36995660,38325728,38619823,36093532,36093533,36093534,36093536,36093537,36093548,36553922,36553923,36553923,37071465,37369544,37883545,38325727,38325728,38619824,38619825,38619828,38622941,39536552,39627211,41251323,41852230,36093533,36114424,36553923,36553925,36553926,37640315,37895549,38213784,38325727,38325730,38617564,38617564,38619824,38622941,38622941,39627211,39880066,42679389,36093549,36190543,36242576,36396111,36553923,36553924,36553928,36661417,38325735,38617565,38617565,38617566,38619825,38619826,36093539,36553925,38213785,38617564,36093536,36190544,36775970,36776031,38325731,38617566,38619825,38619826,38617563,38619827,38619827,42728931,36114428,36553925,38619826,36108340,36553928,38617567,38619827,36114428,36553930,38325734,38617565,38617568,38619827,36553931,38619827,36093553,40309042,38325734,38325735,38619832,36154354,36553940,36553941,38619840,36106707,36560522,36123152,36568738,36127034,36570680,36134986,36796764,36135329,36135329,36135329,36135330,36135330,36135331,36135332,36135332,36135333,36370524,36574832,38638470,36306719,36574829,36574830,36574831,38346634,38346635,38638470,38640730,36215161,36614747,36255058,38406499,36278495,36646422,36287564,36287566,36382832,38714585,38714586,38714586,38716846,36408727,36391629,36702979,36394477,38768040,36477875,36477991,36478102,36478105,36478107,36746219,38518019,38809855,36529897,36529972,36530040,38543991,36605716,36605800,36605885,38873747,36698722,36856537,36794648,36904487,36843273,36843279,37727522,38994704,36913534,36963932,39027571,37014309,37014319,37014329,37014313,37014313,37014316,37014329,37014314,37014316,37014316,37014318,37014328,37014329,37014329,37014330,37014330,37014331,37014332,37014334,37014315,37014317,37014317,37014323,37014329,37014329,37014330,37014331,37014316,37014317,37014318,37014319,37014321,37014330,37014330,37014331,37014316,37014317,37014318,37014319,37014320,37014331,37014331,37014331,37014332,37014332,37014319,37014332,37014333,37014333,37014332,37014334,37014321,37014332,37014333,37014333,37014334,37014334,37014336,37014332,37014334,37014334,37014336,37014336,37014335,37014337,37014335,37014335,37014338,37014340,37014337,37014340,39017064,37014344,37014348,39077970,39080230,37014346,39080229,39643783,41713967,42312636,37014347,37014348,37014349,37100751,37403263,37432894,37671192,37991302,39077969,39077970,39080233,40087614,42312638,37014347,37014349,37100748,37144145,37236437,37269628,37432893,37432895,37456068,37456070,37724712,37829952,38472883,38674191,38786134,38786135,38786135,38786136,38786136,38786137,38786138,39077969,39077970,39077971,39077972,39077972,39080229,39080230,39080230,39080231,39080231,39080232,39080232,39080233,39080234,39083348,39235462,39996959,40087618,40570454,41711731,41713968,37014350,37639416,37671195,38674191,38786134,38786136,39077971,39077972,39080232,40087618,41711731,37014350,37559664,39077972,39080229,39080233,39643783,39080232,39080233,37026825,37262743,37991305,38372623,38578915,38674193,38786138,39077973,39077974,39080232,39080232,39080234,39080234,39080235,40087620,42312639,39080235,40769449,37033045,39089589,37039352,39095876,37187165,37187167,37187168,37187169,38872557,39164389,39166648,38872554,39103488,39164389,39166649,40855862,37229310,37510752,37273964,37585886,37458419,37947764,37458544,39008240,39008243,39008250,39302338,39302339,39302341,37511147,39328637,37524929,38218943,37627168,37627168,39386650,39386651,37792194,37792195,39175064,39469161,37819485,37819486,39309236,39482806,39482805,37851454,37851455,37851456,39498793,39498793,39204699,39496533,40415520,42130292,43607897,37897804,37897810,37897811,37897819,37897824,37897821,39521968,37897843,39458811,38052812,39521977,41211192,38254812,37901738,43633037,38049410,38343365,38104996,39331469,38207838,39497025,38264496,39299271,38313207,38313291,38313374,39729763,38328052,38328053,38328055,39737091,38737020,40300645,38435090,39790609,38437105,38437108,39791616,40355170,38611770,38611773,38611774,39472911,39876692,39878952,42512688,38611978,39584965,38637333,38672000,38645569,39601751,39893589,38706656,39632297,38912624,40029377,38912952,40027282,38968270,38968271,38968271,39763103,40054937,40057199,39763105,40057198,40057199,40057200,38992328,42700728,39145985,39324338,39187109,40166617,39349557,40245598,39502692,40030321,39673572,40409850,39697578,40127759,39730904,41928736,39931432,40538780,39998010,39998011,40277981,40569811,40005160,40575645,40143495,40238773,40334050,40334051,40445995,40445996,40446001,40676930,40737830,40737831,40740086,40740087,40740088,40740090,40740091,40740092,40743207,41747478,43373828,40446695,40794151,40471675,40806642,40476823,40699029,40557938,40557924,40557938,40557937,40557938,40557939,40557939,40557938,40557939,40557939,40557940,40557926,40557940,40557940,40557941,40557943,40557928,40557941,40557941,40557928,40557929,40557932,40557940,40557941,40557942,40557941,40557941,40557945,40557941,40557942,40557943,40557943,40557944,40557947,40557948,40557947,40557949,40557950,40557950,40852035,40849775,40557955,40849774,40849775,40852035,40852036,43485772,40849774,40849775,40852034,40852035,41415586,42026661,40849774,40849776,40849777,40852034,40852034,40852036,40852036,40852037,41007376,41415589,43483535,44084442,44961140,40557959,40557959,40627691,40849773,40849774,40849774,40849775,40849775,40849776,40849776,40849777,40849777,40852034,40852035,40852036,40852037,40852037,42541249,44961141,40849778,40855155,40849778,40849779,40849779,40852037,40852039,41859425,42112280,40697436,41485333,40786175,40786246,40786310,40786322,40786402,40966295,40798997,40972567,40921235,40921237,41033681,45142788,41019810,41019813,41080712,41082971,41080714,41082973,41141593,41141608,41141593,41141594,41141594,41141594,41141595,41141609,41141594,41141594,41141595,41141595,41141608,41141609,41141609,41141610,41141594,41141595,41141595,41141596,41141596,41141610,41141595,41141596,41141596,41141597,41141608,41141609,41141610,41141611,41141596,41141597,41141597,41141609,41141610,41141611,41141611,41141612,41141597,41141598,41141607,41141608,41141609,41141610,41141611,41141612,41141612,41141613,41141598,41141610,41141611,41141611,41141612,41141612,41141613,41141613,41141599,41141611,41141613,41141613,41141614,41141613,41141622,41141623,41143868,41141624,41141625,41141625,41141626,41143868,41143870,41141625,41141626,41141626,41141626,41143870,41143874,41147634,41141626,41141627,41143869,41143870,41143871,41141627,41141628,41141629,41143869,41143870,41143870,41143871,41143871,41143872,41143872,41143873,41143874,41143875,41146986,41146987,41146988,41707423,41976043,43409160,43775371,44376275,45252976,41141628,41143869,41143869,41143870,41143871,41143871,41143872,41143872,41143873,41143873,41143874,41143875,41146988,41143870,41143871,41143872,41143872,41143873,41143873,41143874,41143874,41146989,43777608,41143875,41146112,41146112,41146113,41146130,41146129,41146112,41146114,41146114,41146116,41146125,41146130,41146131,41146113,41146114,41146114,41146115,41146116,41146116,41146117,41146129,41146133,41146114,41146115,41146115,41146116,41146116,41146117,41146127,41146130,41146131,41146132,41146115,41146116,41146117,41146129,41146130,41146132,41146133,41146116,41146117,41146117,41146118,41146118,41146119,41146119,41146120,41146128,41146129,41146131,41146131,41146132,41146132,41146133,41146133,41146134,41146117,41146118,41146118,41146119,41146120,41146131,41146132,41146132,41146133,41146134,41146135,41146135,41146118,41146119,41146119,41146120,41146120,41146131,41146131,41146132,41146132,41146133,41146133,41146134,41146134,41146135,41146135,41146136,41146119,41146120,41146121,41146121,41146129,41146132,41146132,41146133,41146133,41146134,41146134,41146135,41146135,41146136,41146136,41146120,41146121,41146122,41146122,41146123,41146130,41146132,41146133,41146133,41146134,41146134,41146135,41146135,41146136,41146136,41146137,41146137,41146122,41146122,41146123,41146132,41146133,41146134,41146134,41146135,41146135,41146136,41146137,41146137,41146138,41146135,41146135,41146138,41146123,41146135,41146135,41146136,41146136,41146137,41146138,41146139,41146124,41146135,41146135,41146136,41146136,41146137,41146139,41146137,41146138,41146137,45255232,41146144,41146144,41146145,41709681,41146145,42062857,41146146,41146147,41146146,41146146,41146148,41149246,41146146,41146147,41146147,41146148,41146148,41146149,41146150,41149248,41709682,43753182,44378536,44378538,45255235,41146147,41146148,41146148,41146149,41146149,41146150,41146150,41146151,41146151,41149246,41149247,41149247,41149248,41149249,41301362,41709682,41709683,41709684,42062859,42153518,42636354,43524644,43777631,44378535,41146148,41146149,41146149,41146150,41146150,41146151,41146151,41149247,41149248,41149249,41300781,41300781,41709683,42636354,42835345,43777631,43779868,44378536,44378537,44378539,45255236,41146149,41146150,41146150,41146151,41146151,41146152,41149247,41149247,41149248,41149249,41300801,41709684,41951140,42320756,42636355,43411421,43777632,44378537,41146150,41146151,41146151,41146152,41146152,41149249,41149249,41149250,41149250,41301363,41709684,42062861,42835346,43777632,43779868,43779869,44378537,44896049,41146151,41146152,41146152,41146153,41149248,41149248,41149249,41149249,41149250,41149251,41300782,41300783,41300802,41301471,41709682,41709684,41709685,42062861,42153520,42320758,42320760,42321794,42406375,42636356,42636356,42835346,43777633,43779869,43779870,43779871,44378538,44378539,45205698,45255238,41146152,41146153,41146153,41149251,41300802,41709685,41709685,43524646,43777633,43779870,44378540,41146153,41146154,41146154,41149249,41149249,41149250,41149250,41149251,41149251,41149252,41300797,41300800,41300804,41301473,41709685,41709686,41709688,42062864,42320760,42835347,43235518,43524647,43777633,43777634,43777636,44378539,44378541,45255239,41146154,41149248,41149249,41149249,41149250,41149250,41149251,41149251,41149252,41149252,41300801,41709686,41709686,42153520,42636357,42636357,42835348,43411422,43777634,44378539,44378540,44378542,45255239,41146155,41146156,41149248,41149250,41149251,41149251,41149252,41149252,41163591,41260506,41300804,41709686,41709687,41709688,42153522,42835348,43777635,43779871,43779873,43779874,44378540,44378545,45255240,41149252,41709687,41149253,41152345,41152346,41152344,41152347,41152346,41152347,41152347,41152357,41152360,41152361,41152347,41152347,41152348,41152348,41152359,41152361,41152362,41152362,41152363,41152363,41152347,41152348,41152362,41152362,41152363,41152348,41152349,41152349,41152350,41152360,41152363,41152363,41152364,41152364,41152349,41152350,41152360,41152363,41152364,41152350,41152351,41152360,41152361,41152362,41152363,41152363,41152364,41152365,41152365,41152364,41152365,41152366,41152366,41152364,41152364,41152366,41152366,43780742,41152376,41152376,42409486,41152376,41304586,41152377,41712796,41152378,41712797,42056279,42838460,41152378,41152379,41303914,43780746,41152379,41152379,41712798,41712798,41712799,41712799,42065975,42156633,42156634,42323873,42838460,43780746,43780746,43782983,43782984,44381651,45125747,41152379,43780745,44381653,41152380,41152381,41277148,41303896,41303897,41303917,41303917,41303918,41303918,41303920,41303920,41304478,41304585,41304588,41341543,41649848,41712799,41712799,41712800,41712801,41780785,41965119,41965119,41965122,42065975,42065976,42156634,42156635,42156636,42323873,42409489,42409490,42639469,42639470,42639471,42703422,42838461,42916271,43527758,43527760,43527761,43527762,43527763,43741977,43780747,43780749,43782984,43782985,44381651,44381652,44381652,44381653,44381654,44381655,44381655,45208813,45258352,41152381,41153012,41237367,41303916,41303917,41424561,41649848,41712799,41712800,41712800,41712801,41965122,41965123,42056282,42065976,42156635,42237033,42344901,42478358,42639471,42639471,42838461,43780748,43782985,43782985,44381652,44381653,45258353,41303918,41304588,41712800,41712801,41712802,41965123,41967961,42156636,43780748,44381653,44381653,41153667,41153686,41153742,41153761,41153818,41153832,41304648,42057026,41181030,41181036,41181058,41181128,41181181,43795149,41322366,41797798,41374871,43892000,41401933,41837584,41455442,41455430,41455435,41455444,41455434,41455435,41455442,41455465,42308168,41455467,41455468,41455470,41455470,41455469,41455470,41455471,41864336,41455471,41455471,41455472,41455471,41455472,41455471,41455473,41493081,41455473,41864337,43934523,41455475,41455476,43934530,41864345,41864343,41864352,42990014,41456139,41456142,41864353,41864355,42217530,42990015,43934538,44533209,41864353,42116676,44533208,41456033,42308190,42990016,43932302,43566092,42990017,41456586,41456587,41456587,41456588,41456591,41456700,41456701,41456698,41456699,41456695,41456702,41456703,41456704,41456803,41456808,41456809,41456810,41456811,41456811,41456812,41456812,41456814,41456815,41456817,41456816,41456816,43932965,43932969,43935207,41865020,41865023,42208503,42218199,42308857,43566759,43932970,43932970,45410575,43679983,41530719,41530720,41530722,41901975,42154299,41901979,41696752,41696873,41696991,41696994,41985111,41985111,42147318,42147367,42147369,42147442,42147515,42537200,42907078,42273216,42273230,42273216,42273218,42273219,42273219,42273220,42273221,42273232,42273233,42273233,42273234,42273234,42273235,42273236,42273219,42273220,42273220,42273233,42273234,42273234,42273235,42273235,42273222,42273234,42273235,42273235,42273237,42273235,42273236,42273236,42273235,42273236,42273237,42273235,42273236,42273236,42273238,42273237,42273237,42273248,42273251,43199904,42273249,42525556,42717069,44341181,44341181,42273249,42273250,42273250,42273251,42525557,42616714,42626410,42717069,42717069,43199905,43398895,43451359,43974971,44088193,44341181,44341182,44343418,44343419,44942086,44942086,44942088,44942088,44942089,42273250,42273251,42273252,42525557,42626411,42717070,42884306,42884309,43398896,43398897,44341182,44343419,44343419,44343420,44942087,44942088,44942088,44942089,45459599,45818787,42273251,42525558,42626411,42717070,42717071,42969925,43199905,43199906,43719578,44199665,44341181,44341183,44343420,44942091,45769248,45818788,42525558,42626410,42717070,42717071,42969926,43308613,43398897,43996762,44341183,44343420,44881522,44942091,45818788,44343421,44942089,42626413,43451362,43877223,44341185,43398899,42409202,44409164,42756146,44582638,42777874,42777876,42777875,42777878,42777876,42777877,42777877,42777879,42777879,43651215,44340496,44593502,44593503,44593502,45143337,46071107,43136627,45194407,43136630,44340517,45194409,42841426,42969391,44593504,44595742,42783555,43974738,42810471,42985686,42904976,43933946,42920537,46092899,42926853,42953220,42960195,42960196,42960199,42960199,42960197,45285567,42969890,43060548,43543386,43543388,45285571,42979570,42979582,42979585,42979583,42979584,42979585,42979585,42979586,42979586,42979587,42979587,42979597,43070243,43553078,43553079,43700917,43752068,44670325,44694355,44696592,45236840,45295259,45295261,45295263,43187682,43752070,44694356,42979599,43237483,44694357,43070244,43553080,43553081,43752071,44441371,44694357,43070245,43070245,43070246,43160898,43160898,43160900,43160902,43160903,43160904,43160904,43160905,43160906,43160906,43160891,43160903,43160903,43160904,43160904,43160905,43160906,43160906,43160906,43160906,43160905,43160905,43643736,44785013,43842728,43842729,43920540,44242899,44532029,43842729,43160920,43328143,43413758,43643739,44643499,44785016,45385921,45385924,43328142,44785016,44785017,44785018,44787254,46262622,43413759,43842731,43910676,44418806,44532030,44785017,44787254,45385922,46262622,44787255,43413760,44785018,44787255,45385924,46213084,43413761,45385924,45385926,45385924,43321697,45466317,43395781,43761177,43495378,43495379,43495380,43495380,43495380,43495380,43495380,43495381,43495381,43495384,44810735,44952253,44009967,46429859,43810977,43810978,44952254,44954491,43580997,44009968,44952255,44699270,43497457,44953296,43537431,44030992,43666609,43666610,43666600,43666612,43666612,43666613,43749290,44635663,44896352,45037870,45040106,45040107,45638775,46515475,43804359,45106749,43831972,46598156,44126574,44126575,44126561,44126571,44126575,44126573,44126573,44126576,44126575,44126575,44126576,44126576,44126577,44126576,45868753,44126588,45267850,44325565,45014864,45267852,46745457,45267850,45270090,44325566,44646248,44865646,44901642,45014865,45267852,45267852,45267853,45267854,45868757,45868758,45868759,45868760,45868761,45868763,46311168,46745458,45267853,44254477,45932707,44343986,44881723,44422258,44473409,44524542,44524554,44524554,44524555,44524555,44524556,44524556,44524557,44524557,44524558,44524557,44524558,44524558,46067745,46894906,45466841,46067745,46944446,44524569,45466840,45466841,46067747,46067749,46944446,44524570,45466842,46944447,44524572,45325330,45466842,45466843,45469079,45469080,46007181,46009328,46067747,46067751,46944448,44577021,44845239,44951444,45213854,45213855,45466843,45466845,45469080,45469081,46067749,46944448,45213857,45325331,45466844,45469081,46067751,45466844,45469081,44629484,44629485,45521544,46120212,46120213,44660455,44660483,45190364,44680175,44680176,44680176,45291665,45544651,45546888,44962907,45686016,45165919,45165921,45787523,45787524,45787525,45789762,45324897,45324898,45867013,45869250,45378331,45893730,45419462,46515199,45481203,45945165,45604776,45604933,45605090,46007140,45676705,45676706,45676708,46042917,46643822,45901401,46042919,46583258,46643822,46643826,47520524,45720256,45720298,45720298,45720397,45720372,45720445,46064792,46064792,45903114,45903137,45903152,45903153,45903154,45903154,45903155,45903153,45903155,45903156,45903156,45903155,45903157,45903157,45903157,45903159,47633746,46757045,47633746,46757047,47633747,46757047,47633747,46156143,46156144,46158379,46158380,46158380,46158381,46757047,46757048,46757051,46126094,46126096,46126097,46126096,46126098,46126104,46267612,46267613,46269850,47745220,46269852,46672818,46868525,46331602,46971276,46360289,46985644,46361065,46385095,46409128,46409127,46409128,46409113,46409114,46409128,46409129,46409114,46409129,46409130,46409115,46409116,46409118,46409118,46409129,46409129,46409130,46409130,46409131,46409131,46409132,46409132,46409130,46409131,46409132,46409132,46409131,46409132,46409133,46409133,46409134,46409134,46409135,46409134,46409134,46409134,46411365,46409144,46409144,46409145,46411366,46409145,46409146,46411367,46411367,47010034,47010034,47010035,47010037,47010038,47010038,47886735,46409146,46409147,46409147,46409148,46409149,46409149,46411366,46411367,46411367,46411368,46411369,46910518,46938198,47010033,47010034,47010035,47010035,47010036,47010037,47010037,47010038,47010038,47010039,47837196,47886735,46409148,46409149,46411367,46411368,46411368,47010035,47010036,47010037,47010038,47010039,47837196,47886736,46411368,46411369,47010036,47010037,47010038,47010039,47886736,46409150,46411368,46411369,46814334,47010036,47010037,47010038,47010038,47010039,47010040,47010037,47010038,47010039,47010039,47010040,47886737,47010038,47010039,46411370,47010038,47010041,47010042,46413603,46413603,46413588,46413589,46413603,46413603,46413604,46413589,46413604,46413604,46413604,46413605,46413605,46413606,46413607,46413606,46413608,47012271,46413619,46443943,46952973,46952976,47012271,47012272,47012273,47012273,47888972,46413620,46685400,46952975,46953372,46953853,46961197,47012270,47012271,47012272,47012272,47012273,47012273,47012274,47012274,47012275,47012275,47012276,47012276,47012277,47529784,47839433,47888972,46953853,47012273,47012274,47012274,47012277,46474282,47042613,46957191,47284063,47219535,47219541,47415239,47415245,47411930,47511448,47467279,47539117,47489803,47489805,47489808,47550370,47799925,47550376,47492343,47492346,47492348,47492351,47551642,47551644,47551644,47551648,47493133,47493228,47493323,47552129,47494098,47494099,47494100,47494100,47552517,47552519,47552520,47552522,47552521,47508791,47508796,47559867,47610922,47610923,47610924,47610926,47610923,47610924,47610925,47610924,47610925,47610925,47610926,47610926,47610927,47610927,47610938,47610939,47610940,47610941,47610942,47610925,47610926,47610926,47610927,47610927,47610928,47610928,47610929,47610929,47610930,47610939,47610940,47610940,47610941,47610941,47610942,47610943,47610926,47610927,47610927,47610928,47610928,47610929,47610929,47610941,47610941,47610927,47610928,47610928,47610929,47610929,47610930,47610931,47610939,47610940,47610941,47610942,47610943,47610943,47610944,47610944,47610945,47610928,47610929,47610929,47610930,47610939,47610941,47610942,47610943,47610943,47610944,47610944,47610929,47610930,47610930,47610931,47610931,47610932,47610932,47610938,47610940,47610941,47610942,47610942,47610943,47610944,47610944,47610945,47610930,47610931,47610931,47610932,47610932,47610940,47610942,47610942,47610943,47610943,47610944,47610944,47610945,47610945,47610946,47610931,47610932,47610932,47610933,47610939,47610941,47610942,47610943,47610943,47610944,47610944,47610945,47610945,47610946,47610946,47610932,47610941,47610942,47610943,47610943,47610944,47610944,47610945,47610946,47610946,47610947,47610947,47610941,47610943,47610944,47610944,47610945,47610946,47610946,47610947,47610947,47610943,47610944,47610945,47610946,47610946,47610947,47610948,47610944,47610947,47610947,47610948,47610951,47610945,47610945,47610947,47610953,47610954,47610953,47610955,47610951,47610953,47610955,47610955,47610956,47611069,47610953,47610956,47610957,47610953,47610954,47610955,47610955,47610956,47610957,47610957,47610958,48487639,47610955,47610956,47610956,47610957,47610957,47610958,47610961,48487640,47610956,47610957,47610957,47610958,47610958,47610959,47610959,48128452,48487640,47610957,47610958,47610958,47610959,47610959,47611068,47685299,47860493,48487641,47610958,47610959,47610959,47906042,48487641,47610959,47610960,47610960,47611074,48438102,48470589,48487642,47610960,47610961,47610961,47610963,47611064,47612521,48438103,48487642,47610961,47610962,47610962,47610963,47610964,47610966,47611067,47611071,47611071,47611072,47667885,47860493,47860494,48059382,48128455,48128455,48318981,48337595,48355038,48355040,48436642,48438091,48438103,48487643,47610962,47611071,47611072,47860496,47995398,48128455,48355039,48438104,48470590,48487643,47610963,48103462,48128456,48487644,47611074,48487644,48487645,48487646,48128458,48487648,47611181,47611184,47611188,47611192,47611182,47611191,47611192,47611193,47611196,47611197,47611201,48487759,48487761,48128575,48487764,48487766,47612646,47614093,47614094,48489215,48489216,47724823,48544580,47759655,48561997,48110042,48110043,48110044,48110044,48110045,48378004,48737191,48737192,48201137,48782736,48379858,48872103,48495818,48495905,48495995,48930198,48507815,48936076,48595974,48930237,48645961,48645961,48645963,48645963,48645964,48645964,48645965,48645968,48645962,48645965,48645966,49005149,48955610,49005149,49005151,49005151,49005152,49005152,49005153,49005154,49005156,49027066,49027146,49027189,49027233,49027257,49146256,49064235,49064311,49064386,49214358,49099130,49099131,49099131,49099132,49231735,49262342,49313342,49264564,49264878,49265191,49265244,49265246,49265256,49265257,49314796,49330227,49330234,49330283,49347286,49330340,49347337],\"xaxis\":\"x\",\"y\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,2,0,1,0,34,18971,183,136,620,88,376,20,2,141,105,114,50,22,41,126,223,461,9844,3757,25,1186,395,222,1588,80,201,218,225,113,228,697,12521,1548,50,135,26,138,226,1583,8,256,141,227,27,287,307,1673,485,81,2,6,0,0,200,249,114,106,115,49,23,228,42,241,229,175,51,1178,352,29630,16066,6904,5851,9054,636,2387,1174,139,173,835,979,294,551,704,3031,766,82,7142,3462,4095,1036,395,24,55,546,293,217,315,781,319,41,226,13,232,17,52,95,25,481,1762,2,1974,774,3486,193,1090,223,263,249,2722,1605,2930,210,8,283,98,43,27,1245,2477,230,397,250,641,266,3,1432,414,703,272,401,124,67,2490,637,164,709,1780,453,1363,60,173,76,108,1189,207,993,770,404,257,1294,1407,1348,1071,2537,1061,2765,434,355,163,196,248,372,2,119,69,134,97,81,194,456,747,270,65,346,322,1685,853,484,547,274,251,6,1157,265,448,270,128,68,216,317,19,481,229,286,175,199,1544,145,142,405,703,219,323,51,199,138,16,295,674,1034,224,296,7,1487,135,161,56,136,420,1029,4727,785,378,170,83,231,246,874,481,1088,749,201,451,9,247,83,9514,8339,1048,461,231,509,929,476,22,1568,3,360,57,125,284,300,42,183,89,202,15175,315,2166,195,288,176,916,1365,257,1111,521,173,705,42,293,156,483,204,194,199,12,399,36,16025,62,1037,879,2595,2622,3206,1701,2271,948,1379,1211,298,620,541,928,344,721,110,116,91,453,282,415,509,717,316,1119,453,428,717,2656,2288,5215,131,3475,219,283,1361,13,198,71,80,1769,617,461,216,435,39,253,29,183,410,517,1001,259,454,99,713,229,178,714,289,290,730,377,341,124,3,98,520,212,213,1713,1511,455,556,563,4,26,357,957,170,260,290,145,153,1407,454,3603,138,275,673,15,2,2,164,59,963,347,40,18,103,233,877,1466,725,422,4745,525,197,1192,809,221,227,2,257,157,12,3631,9,673,419,201,679,475,119,126,4,905,90,701,187,509,550,452,222,883,293,124,46,874,1107,4182,50,218,1607,351,181,586,331,1006,1010,4202,273,169,267,675,117,52,429,5,131,229,388,221,603,315,1337,321,282,277,653,188,494,256,410,96,363,342,627,407,349,123,346,648,1102,16,104,302,172,508,651,1169,953,115,1019,65,399,60,554,2130,683,507,57,498,333,523,138,821,144,1269,1120,798,282,17,57,3,46,281,361,3,328,6,8,370,1686,441,270,217,364,638,836,2525,120,74,126,426,512,202,227,302,122,350,13,1006,72,462,3638,14,48,854,1017,197,224,349,1064,97,2402,11,146,40,7631,4930,2449,1079,1542,5890,1420,138,257,262,6,6,601,444,665,4508,963,1540,379,1018,2201,975,56,317,114,3388,0,406,619,656,2506,2127,878,953,1844,653,147,369,296,624,98,3078,615,995,469,449,382,203,222,283,369,1112,359,470,423,575,198,522,611,833,514,6084,567,97,259,110,161,754,264,418,626,827,578,173,5472,514,287,431,1159,449,412,121,144,791,370,839,1013,898,2108,6370,286,214,4,1097,256,96,179,8,148,899,368,998,289,226,448,979,705,411,421,278,474,449,1107,228,842,464,2766,920,178,861,596,502,1,1251,776,1769,7299,314,1586,3163,4292,11874,40987,14,5,5,4,2,13,1,11,16,147,0,0,0,0,0,0,0,0,0,0,0,0,7073,303,134,1326,91,12,307,368,314,1635,338,307,416,291,618,200,230,124,1277,420,129,96,148,81,492,141,73,75,211,103,138,717,162,93,35,183,50,20,50,143,572,347,1117,940,1097,2510,5888,3635,0,0,0,0,240,1312,223,683,107,228,219,245,230,407,372,22,98,129,160,49,192,622,1001,468,239,95,179,26,135,112,319,201,238,116,668,70,105,111,210,90,375,222,92,11,141,24,111,139,149,238,521,149,238,103,117,177,242,434,163,227,153,370,113,343,200,112,224,318,220,227,237,78,244,200,4,227,76,133,102,6,587,68,226,66,316,172,131,168,68,130,162,68,451,63,409,123,111,115,122,220,137,111,201,252,46,122,488,261,789,1146,315,315,121,128,129,174,199,355,373,8,128,94,95,276,147,80,491,136,110,139,90,72,3,76,127,119,21,68,97,150,102,171,74,64,124,161,75,103,137,50,143,20,142,96,125,128,200,104,109,1,127,76,182,110,160,173,12,36,181,251,49,124,19,19,155,118,314,184,139,390,120,57,94,247,29,351,185,406,58,161,123,276,132,188,206,196,431,958,841,50,235,1454,1824,105,1700,1052,619,0,9442,1410,0,25001,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,7,1,2,1,1,1,2,2,1,1,11,2,5,4,2,5,3,1,2,5,22,15,5,12,1,3,5,3,5,9,9,3,2,2,2,4,39,7,7,5,8,20,24,10,1,5,16,8,3,2,4,23,17,35,19,14,8,1,2,3,6,2,4,3,1,6,2,1,1,3,5,14,15,6,5,8,15,2,3,3,2,1,1,3,15,12,4,8,18,4,2,2,3,2,4,5,1,1,1,1,3,2,1,2,1,3,2,2,1,1,2,1,1,2,2,0,0,2,4,4,2,0,0,21,14,1,2,3,0,44,4,4,3,1,1,0,0,0,0,26,1,12,9,3,1,1,1,1,0,0,0,0,0,0,0,0,0,0,5,14,1,2,2,3,0,0,0,0,0,0,1,1,1,0,0,3,1,2,0,0,0,0,0,0,4,1,2,4,1,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,0,0,0,0,1,0,1,0,1,2,6,3,2,1,1,1,1,1,1,1,1,4,6,5,11,4,1,1,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,5,2,2,3,0,0,0,0,0,0,0,0,1,0,2,4,4,8,1,1,1,2,2,1,0,0,2,4,0,0,1,2,1,0,22,313,46,1360,335,129,3606,195,204,99,148,140,62,110,267,256,41,70,78,311,50,64,174,3031,13168,7106,1,205,175,207,239,544,111,142,86,113,18,1484,144,120,288,940,971,176,196,78,128,1485,100,149,1486,141,63,109,150,260,161,103,234,42,71,51,27,64,156,153,206,51,65,1785,5548,622,22461,2,30592,1239,571,231,216,715,1148,74,484,5853,455,524,178,162,1078,673,8727,2252,287,1541,923,34,13,301,730,127,36,1,50,35,11,22,1,787,52,1409,1694,876,362,982,594,1630,9074,1027,37,407,1380,500,7041,2243,1243,721,14,36,31,50,409,300,152,276,1361,287,292,376,54,46,262,298,875,139,136,4,3,222,230,142,64,427,492,217,406,66,680,1,144,22,1847,97,1287,181,150,29,75,65,1,137,313,42,852,229,309,3604,1407,130,8012,2060,408,592,493,177,391,18,59,73,111,75,131,422,715,176,409,1482,227,92,179,1,799,493,2,2968,362,162,406,112,7736,566,340,210,40,729,439,214,56,2,238,15034,286,397,145,9266,3575,139,546,3019,1051,404,2,20,9,81,1054,124,42,289,916,236,114,353,188,10,217,141,135,312,531,69,598,321,252,997,7222,3211,2077,500,809,1701,545,102,3,1172,11,261,181,615,585,81,223,25,228,149,139,1016,694,323,287,288,576,407,76,1000,146,8228,466,37,2366,225,84,1876,18,204,231,24,887,896,125,451,1255,99,460,649,12,253,952,400,225,311,57,53,306,34,1035,415,329,2139,316,1207,1470,97,657,78,426,2555,535,179,515,768,1367,315,314,304,770,326,975,146,422,116,397,22,55,3,349,439,341,664,178,467,38,185,284,1157,911,883,2,478,12,170,230,403,164,38,319,390,81,369,115,201,107,700,471,2971,305,501,50,318,405,102,1221,20,40,51,929,240,103,408,172,174,44,121,616,432,288,62,1,204,100,262,228,108,699,247,1216,1241,1542,3203,149,386,180,172,83,506,101,244,19,602,263,495,98,22,224,16,257,138,205,882,181,15,759,99,4,41,103,258,51,218,8,3,32,304,77,196,0,279,23,145,107,2,477,80,255,17,32,76,1113,1085,172,489,139,1226,605,278,64,574,716,23,601,683,285,279,169,396,447,33,150,58,268,282,22,188,102,41,178,126,1356,1183,86,220,291,1030,216,33,235,5,35,616,94,1213,412,884,100,893,5,16,618,70,3,227,2177,1924,557,2186,435,173,95,225,260,347,153,206,1264,1134,163,824,8,445,98,346,1157,1549,917,192,110,465,3464,800,99,460,305,55,1058,256,239,80,1872,2588,1221,5,847,223,671,78,383,436,1936,1863,0,1605,475,980,88,431,177,109,235,1691,1313,850,409,31,90,634,256,211,827,492,1665,341,1057,334,148,83,726,82,1266,172,605,0,1432,227,216,1498,562,428,761,864,1026,961,51,1048,218,4,341,157,847,443,1227,2880,740,1252,78,795,777,125,196,726,276,519,210,1190,1112,1950,129,2532,1212,5213,29923,8555,15087,423,19,1099,114,362,690,345,269,202,19,149,476,485,113,371,113,342,21,128,31,68,15,55,29,79,424,53,245,279,161,125,107,41,90,194,31,182,824,195,39,50,406,9,118,1169,288,116,514,1181,3129,0,0,0,0,0,0,0,0,0,2361,250,560,181,153,340,160,181,99,365,61,571,662,461,198,292,285,391,112,130,57,107,265,208,51,115,81,28,63,151,1818,52,91,244,180,236,1192,465,80,572,1006,1483,10,141,145,153,436,51,128,230,249,18,244,44,31,320,137,110,203,15,71,1,195,89,87,75,39,1484,65,180,47,154,165,66,100,98,62,109,113,172,121,94,38,60,150,103,18,245,1485,134,28,119,64,45,102,118,117,7,106,63,3,71,78,57,56,83,136,133,89,66,18,30,60,57,367,11,203,64,196,194,120,56,153,110,69,244,37,100,0,63,195,467,94,58,142,75,68,154,88,144,68,10,115,67,155,111,112,143,108,135,144,117,46,126,279,43,33,373,133,163,81,120,111,62,112,72,179,112,194,366,366,102,141,98,290,20,127,109,80,71,360,109,32,90,99,14,204,1486,250,214,187,120,203,30,116,56,78,108,100,307,95,18,171,45,36,178,15,16,244,113,359,205,10,195,164,65,108,155,119,108,119,304,67,60,154,69,257,30,209,27,52,67,250,116,19,80,152,91,29,9,358,125,70,27,110,101,53,242,24,29,109,132,77,14,1547,226,29,65,150,170,435,1482,158,206,335,538,130,180,1102,79,403,683,480,820,249,193,51,40,1481,90,213,255,248,70,408,155,99,437,55,160,68,80,690,49,213,136,832,186,674,262,185,326,68,120,8,1853,243,186,218,323,186,0,1223,2367,1859,2640,2687,269,1416,931,360,2195,1058,858,5700,2533,16078,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,3,0,0,0,2,0,2,0,1,0,1,2,1,0,1,3,1,2,1,1,1,2,5,2,5,5,1,1,2,1,1,3,1,1,1,1,1,3,2,1,1,1,1,5,3,3,4,1,5,1,2,1,1,1,7,4,6,2,1,3,1,2,6,3,6,8,11,2,1,4,3,1,2,2,3,3,7,7,2,3,23,5,9,6,5,4,1,2,4,11,2,2,1,1,22,13,6,6,8,3,1,3,4,2,4,19,31,24,7,1,10,16,7,5,2,3,12,16,7,2,22,9,6,5,3,14,9,4,20,14,2,3,10,2,6,2,3,16,16,22,12,1,1,7,4,4,3,2,2,14,21,47,9,2,1,4,16,23,25,11,3,4,5,8,3,2,2,3,1,2,4,4,6,2,1,0,1,4,3,3,1,1,0,1,0,1,1,1,0,0,4,3,1,0,0,2,1,1,31,27,4,1,0,0,0,53,26,4,1,0,0,0,48,10,1,0,0,0,0,0,0,0,9,1,0,0,0,0,0,0,1,0,0,0,0,0,6,127,10,438,313,109,21,25,100,2,2414,4328,2,3,85,51,13,46,63,71,280,227,143,175,22,26,6,48,5,1,2,1,0,0,1,0,0,0,0,0,0,2959,2,798,144,60,138,49,123,151,11,263,1,28,434,294,250,202,91,54,61,49,116,110,52,130,52,310,56,330,297,425,33,703,100,260,276,373,222,455,52,44,134,29,77,58,80,38,253,252,6966,83,32,126,1,94,41,119,32,33,106,159,67,81,61,1,59,81,50,43,88,152,12,60,66,177,23,0,30,61,22,30,202,67,142,48,248,82,213,39,33,36,58,60,180,29,64,2,54,32,27,0,47,96,18,0,37,35,40,0,16,10,60,0,51,212,64,36,64,51,42,52,254,38,0,88,50,8,43,67,148,30,28,99,66,97,50,117,93,32,43,251,212,1,65,66,45,45,129,55,655,3,68,25,59,97,41,94,37,237,128,117,83,26,153,90,1,345,97,1,5,65,90,2,69,58,43,9,259,82,34,26,607,207,60,11,48,31,127,56,447,17,29,8,34,215,413,54,63,38,27,29,499,206,42,101,53,17,61,45,62,267,2,1,105,95,227,68,54,27,0,76,33,57,1,82,57,42,79,39,41,32,97,37,223,92,760,0,81,28,212,80,133,734,1,0,2285,104,17,10,6,13,88,34,23,155,57,340,4636,0,0,0,0,0,0,0,27,100,55,64,164,1771,100,46,11,5,99,12,86,33,22,62,139,116,629,0,14,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,10,1287,19,235,25,47,82,72,75,137,671,9870,6834,111,2,5,1,120,800,385,22,236,26,48,121,81,71,75,104,35,493,188,12081,6314,1385,241,104,1207,641,169,594,436,104,355,1,116,356,962,99,22,138,348,876,267,213,52,452,94,210,219,790,202,2970,507,976,340,119,2975,1174,117,121,965,923,44,488,550,336,186,575,203,192,113,168,138,98,162,248,96,68,252,111,97,202,13,679,4865,47,8,838,201,143,197,240,396,309,139,100,156,624,54,135,90,1455,186,158,56,14,5,170,337,51,236,496,41,354,3,8,99,31,220,115,29,355,161,42,242,105,151,291,190,47,9,145,257,136,475,355,485,168,372,208,156,234,144,139,2,95,42,336,11,59,105,356,90,51,2,241,243,357,3,117,331,397,28,384,405,104,152,142,244,100,23,476,333,139,169,214,203,137,695,79,105,242,177,90,71,140,355,51,2,85,378,190,94,41,44,696,1,2,331,138,91,95,329,28,98,78,129,99,20,87,98,130,847,127,693,76,276,69,695,56,6,2,10,163,331,10,86,14,2,126,109,0,123,305,384,112,63,88,1258,910,97,466,370,318,674,56,130,383,78,45,46,138,137,10,17,633,0,332,157,166,24,83,145,49,176,661,292,355,207,53,173,91,84,111,798,119,333,62,221,9,11,106,559,87,89,92,3238,122,986,312,1,1256,307,86,233,50,170,112,56,43,112,1691,0,2732,1327,140,891,872,260,55,46,114,28,133,115,472,121,33,84,122,98,2510,1731,1161,156,329,151,130,121,261,95,0,232,434,582,1242,1702,435,181,850,159,186,167,96,50,29,627,600,263,0,1104,354,613,611,566,169,429,398,484,85,44,46,389,1016,217,777,80,1537,154,238,170,271,139,20,215,27,119,75,4,76,49,145,695,644,1956,148,98,136,49,216,57,143,187,595,25,295,497,65,202,118,60,312,440,4,149,122,357,332,19,1352,202,176,38,486,222,319,980,669,1,583,496,121,136,164,7,2,777,135,153,110,104,221,129,5,281,0,0,146,122,46,218,442,544,170,123,190,1,235,158,3,269,643,332,97,185,6,203,318,101,504,673,662,169,137,469,76,351,98,206,823,955,248,184,189,147,95,128,1547,141,214,249,113,11,4,705,188,2,476,364,91,3,363,57,74,142,44,328,3,247,67,399,3,354,220,183,239,353,146,445,541,151,165,75,121,48,840,157,266,568,475,219,144,474,382,97,241,10,694,135,99,203,43,1303,275,208,136,168,46,6522,24,7,54,121,0,9245,168,35,102,44,418,16,175,47,92,197,35,55,174,186,624,482,2562,4325,0,0,0,0,106,101,29,15,365,45,117,51,20,81,55,320,959,1189,414,2196,2993,54,105,110,134,28,16,103,43,418,367,17,174,46,41,93,116,211,34,50,54,19,80,72,173,165,132,235,40,172,403,773,244,1035,816,377,1072,7587,15,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,23,8115,328,461,56,319,56,37,38,438,286,18,12,168,80,766,1496,10650,8210,1,3,115,145,73,253,74,1203,4311,2040,329,58,71,452,146,57,231,91,74,57,38,34,6,293,6,0,0,0,0,0,0,0,0,519,56,19,70,13,169,81,137,692,36,2211,964,3,6,8,188,10,2,53,217,20200,8,17187,2290,785,5308,3767,3687,365,442,451,1235,149,179,360,149,1867,76,7489,2017,4344,687,343,1311,205,518,252,53,915,181,104,349,74,192,82,5,46,12,22,1,59,71,131,235,9,310,278,50,2961,2035,123,4515,1294,1487,581,811,392,1529,94,134,613,112,692,438,1041,728,24,66,44,553,334,786,239,902,7,147,105,2,588,320,256,155,182,3,64,143,72,52,124,297,45,248,140,307,88,1682,1519,205,347,534,842,2941,146,137,1031,190,159,51,5,140,161,227,133,340,2383,585,1195,127,2079,315,119,199,271,704,159,1281,420,213,299,649,778,1465,464,2900,321,188,225,586,272,611,179,8,10,203,157,10,57,18,1512,238,53,2,81,313,218,253,225,171,1387,657,2224,148,1001,145,30,7,587,273,314,150,95,58,421,45,136,233,306,218,2,461,1,135,706,150,1101,2436,28,923,191,402,128,201,20,19,74,60,99,2011,1249,827,77,8170,6619,2355,1709,1048,35,196,278,376,578,348,253,163,20,215,36,63,214,332,161,215,534,221,136,163,824,445,147,9682,141,599,613,188,171,214,3,91,159,861,121,64,29,2,82,166,2,99,388,4000,4230,3624,1444,1313,747,919,2134,1540,486,208,921,852,64,74,57,15,186,130,473,325,342,168,521,338,278,1111,2,94,659,314,13,2305,3037,1193,73,499,525,332,1067,298,297,72,4,216,117,122,441,3022,604,1823,12,328,1405,93,248,321,908,521,67,278,23,289,221,122,91,84,198,2,177,1515,53,926,163,1010,502,158,599,104,154,77,177,228,873,629,132,669,633,316,196,578,456,353,1303,110,76,311,385,35,126,58,323,110,17,982,48,385,847,747,136,48,426,125,43,947,1074,568,782,189,4,247,232,184,4,153,77,3,83,251,440,647,639,301,347,28,228,10,53,156,124,199,370,519,306,1262,205,344,7,6,187,149,340,188,447,63,55,8,253,135,77,317,2080,1776,600,97,66,450,1089,1076,194,428,333,127,309,102,745,235,791,300,427,51,98,316,322,641,299,1090,20,98,79,554,129,186,141,223,254,261,1101,258,1333,137,158,783,691,244,779,150,128,8,960,40,429,251,163,723,320,301,41,1035,180,18,52,257,1372,800,337,153,27,223,401,610,162,238,228,341,83,65,52,40,65,394,105,76,73,535,248,88,792,154,328,177,910,168,234,45,5,71,322,10,2,315,217,221,120,194,6,791,14,18,117,126,68,551,306,148,335,655,35,298,194,258,274,185,746,0,814,523,1249,150,1148,2002,190,707,14,212,492,669,605,154,1519,1442,257,22,156,304,131,522,144,227,2593,904,183,350,386,1218,39,106,46,306,121,341,143,798,3072,1177,284,141,264,152,143,1731,8668,660,535,1807,436,406,20,583,310,2596,2230,3948,2372,96,21,62,466,932,4038,1584,1534,7,1132,216,2088,94,735,414,227,1027,206,1617,3361,13,716,507,4,520,2776,6725,135,1902,1,405,263,308,734,259,332,490,425,277,1391,107,759,1592,1772,2384,659,984,205,14578,17936,638,161,418,39,121,17,64,60,252,5,64,397,318,160,231,223,211,278,58,35,51,29,2,2,3,0,3,3,64,269,88,358,1546,6928,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2877,294,75,320,91,916,79,154,174,832,230,457,352,99,265,153,189,401,93,262,197,113,34,102,109,34,181,39,16,76,38,364,662,315,1198,5895,0,0,0,81,329,54,529,73,53,393,614,1371,124,155,257,272,74,146,88,268,89,270,394,116,447,198,78,81,87,111,124,61,173,166,126,56,323,232,4,201,262,258,20,65,119,80,328,119,207,76,101,349,48,121,494,257,146,12,19,98,255,165,229,456,92,118,53,270,185,167,327,210,269,517,132,256,23,436,910,211,260,154,125,206,56,198,34,112,33,50,30,147,72,30,257,118,24,110,1,35,52,179,3,1,5,4,2,4,38,10,60,19,197,256,75,2,446,392,61,37,254,222,851,253,1117,347,375,580,8245,34,14,1,1,2,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,2,0,0,0,0,1,0,0,0,2,4,2,0,1,810,82,48,443,429,36,54,31,19,15,50,2,32,52,649,7689,1624,2,307,13,486,31,48,36,23,28,13,225,322,202,334,120,61,55,32,20,16,49,1,3,33,53,14,926,29,10873,4,1,2268,766,795,472,122,283,153,329,698,236,155,123,293,64,100,188,446,223,117,1,1176,1595,2427,359,1829,386,160,615,29,237,418,646,92,121,74,64,7,315,130,65,254,22,23,15,33,265,5081,127,90,360,96,106,197,195,148,267,203,91,417,55,63,26,119,287,218,122,18,91,279,208,60,61,94,90,2,6,5,151,40,63,187,75,55,123,362,152,284,83,280,72,56,144,8,96,51,36,112,266,274,73,53,96,99,237,285,64,93,124,120,95,60,22,64,238,65,101,97,189,61,137,121,312,225,284,27,0,20,98,145,2,62,189,953,117,188,136,29,49,218,41,112,84,41,535,122,95,209,81,336,110,74,64,78,58,60,118,1,489,866,967,178,557,184,480,148,54,103,29,122,337,571,116,89,291,728,152,119,159,47,93,54,3,185,267,308,53,65,111,164,188,826,162,432,590,52,115,176,96,546,216,66,105,93,49,796,65,281,55,111,107,9,18,49,184,225,268,193,195,23,76,46,169,82,41,197,105,529,6,58,92,210,407,28,198,91,148,162,355,193,48,96,58,120,52,199,101,174,316,23,63,244,367,129,7,504,157,131,77,71,823,400,94,43,81,833,121,426,3,49,255,97,780,63,36,523,22,76,216,109,78,28,120,119,57,270,91,121,63,70,53,104,48,212,217,95,202,1384,256,28,14,1,3,162,7,75,2766,44,127,42,286,191,267,88,514,2377,70,193,270,253,88,93,94,395,13,136,65,104,171,375,20,0,64,77,544,76,271,650,199,69,385,479,259,32,341,149,6,1648,6839,110,31,10,11,11,21,59,22,44,126,8,2,30,99,33,72,92,132,73,445,2521,1443,0,0,0,0,0,0,0,0,0,0,0,0,0,383,30,31,98,159,56,102,62,82,51,20,53,30,22,59,106,406,176,38,336,3262,1019,141,59,167,116,29,13,16,65,31,4,62,72,22,25,55,9,9,103,12,81,58,23,81,50,43,21,3,177,61,29,7,21,11,16,60,29,24,65,5,58,32,23,98,46,30,116,612,143,63,305,78,159,43,980,76,8082,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,1,0,0,0,0,7,1571,81,25,30,46,4,6,98,14,51,61,24,165,4464,11166,1,917,686,82,26,31,45,2,0,97,15,52,60,25,106,62,5642,2894,7676,4317,2698,1170,204,167,442,492,412,89,172,111,153,51,160,709,2586,2,991,2616,33,431,525,296,634,1,357,14,122,65,63,63,13,250,166,116,4202,2,858,678,121,79,39,559,294,107,183,2210,1437,268,78,63,657,1299,286,846,248,2,204,160,263,1,41,1,99,76,370,1661,180,88,186,232,186,212,1443,316,1222,186,193,78,65,6,320,70,122,294,54,155,618,164,682,61,287,170,314,1359,528,196,2,148,81,355,105,115,305,470,392,183,87,493,463,184,119,67,264,295,95,78,28,8,269,63,106,89,391,372,205,218,85,31,167,218,268,113,264,344,112,288,90,168,1,100,166,183,5,206,52,112,38,294,117,52,283,159,114,511,460,119,107,159,131,2,62,24,64,48,299,134,1,573,4172,829,380,260,109,638,250,76,85,231,409,75,259,78,2,14,78,148,297,16,56,105,409,3,247,42,98,453,193,124,224,9,7,314,35,22,146,611,18,1358,1752,938,619,670,396,72,188,806,603,491,131,649,332,170,283,53,25,86,488,317,98,136,63,431,31,1392,1,197,19,185,101,553,65,34,43,157,212,108,28,83,380,234,538,137,53,53,105,227,934,250,2,231,217,101,168,100,99,13,171,61,105,335,250,93,441,402,188,108,326,2,207,452,18,536,262,17,98,2,309,5,59,55,206,154,2,199,34,155,124,634,104,141,102,378,290,169,149,8,62,28,349,6,109,54,110,60,92,517,157,0,44,66,107,775,400,160,241,50,4,20,129,67,75,121,34,825,0,202,225,92,50,45,104,564,13,100,47,123,103,3,43,404,77,187,410,224,595,33,505,233,2,372,244,119,103,3,528,105,651,522,66,93,384,248,117,227,13,109,85,4,1179,85,317,365,172,3,135,68,610,348,207,147,80,88,8,1384,0,111,68,62,34,259,76,83,71,213,65,217,129,92,67,135,276,52,184,405,21,220,330,105,484,272,469,162,10,260,532,251,24,404,81,98,79,223,20,169,219,57,36,495,85,92,209,247,313,67,661,238,104,371,288,25,357,284,280,227,1365,382,68,232,50,114,168,235,103,257,1588,238,255,507,56,254,672,84,1781,144,64,97,1297,226,9,206,102,34,1649,54,53,514,438,12,208,251,70,135,477,338,102,108,134,74,327,120,933,683,205,79,373,302,167,1181,3750,102,366,2799,6394,468,4392,27,86,84,1,247,151,32,1,67,1,53,3,204,124,2,18,3,2,0,27,1,26,195,161,251,2706,69,2130,0,0,0,0,0,0,0,0,0,0,0,318,3264,65,121,60,38,146,181,47,160,1366,85,408,1,0,538,55,60,3,115,138,63,106,90,72,73,53,30,184,184,14,50,57,93,46,155,66,91,206,403,56,3289,62,2445,26,64,85,120,83,59,69,54,66,0,44,83,41,74,111,62,163,58,31,187,0,89,134,71,57,0,51,0,74,2,206,52,61,31,49,77,224,185,13,1,17,70,49,2,10,2,56,171,69,92,45,73,2,0,76,154,91,65,110,25,90,547,25,371,52,334,351,431,559,9593,814,10,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,2,0,1,1,1,1,0,0,0,4,1365,357,824,243,14,30,26,54,193,11,6,162,38,50,89,16,942,7319,5160,4,72,140,169,133,2,690,179,8,45,254,60,12,75,715,112,141,247,170,121,8,0,129,18,0,0,131,1,7,8,47,0,0,5,194,1,0,142,12,1,0,0,163,39,52,90,93,1223,147,11111,1,2,5466,491,470,448,332,113,251,95,143,463,46,10,2123,2667,4791,3970,229,738,1034,556,401,1073,185,36,324,132,284,84,18,1,47,5,1,117,62,20,32,76,2,49,1,304,4462,1,1,625,2,140,212,195,312,476,684,972,227,238,163,80,395,118,487,192,315,434,244,104,26,90,132,73,11,31,13,1,67,65,105,485,4,284,9,257,83,30,2,253,96,72,106,26,48,91,90,132,70,209,105,36,2,69,75,47,11,598,952,932,79,6,37,256,193,78,39,154,1156,1631,84,5,202,133,353,229,67,245,158,264,42,2,26,12,2,182,73,52,3076,452,38,463,86,689,1296,74,112,9,166,76,40,5,240,5,2,4,115,133,41,220,431,96,194,606,3,790,1523,1107,1122,880,69,190,79,105,398,94,75,347,120,298,12,170,168,78,20,95,128,166,150,390,286,150,1289,66,71,24,85,154,376,319,275,179,77,320,51,44,180,80,20,24,161,388,687,692,444,81,203,88,32,193,13,147,35,15,70,183,158,248,507,1112,24,67,593,191,133,119,16,33,7,62,107,239,1223,16,111,5,128,75,27,139,56,201,265,452,311,300,274,23,37,38,71,165,492,106,450,313,381,91,212,227,128,213,347,2,13,260,7,155,225,312,114,303,624,173,82,92,534,281,196,328,694,99,107,88,70,396,368,84,75,119,142,78,92,4,153,120,113,72,85,144,251,8,62,1,321,82,131,369,4,10,106,501,80,92,68,106,213,454,299,190,70,502,73,330,246,188,321,134,289,83,223,157,129,4,13,76,211,52,2,214,25,76,74,263,322,76,369,96,242,128,43,138,210,91,598,69,41,137,0,87,51,13,1011,209,297,103,132,40,213,872,0,543,5,72,118,369,82,70,3,578,46,107,210,371,172,304,222,160,152,208,289,0,108,321,132,119,3,102,994,94,432,56,221,273,128,93,232,545,153,71,5,101,5,125,1102,132,396,127,58,73,443,1642,0,69,434,159,438,212,4,817,3,9,320,84,151,4,958,217,131,128,795,1077,67,812,0,91,19,1,259,749,305,934,2204,0,130,558,366,0,212,350,5100,10180,131,21,16,258,39,279,3,48,46,115,13,2,49,3,18,0,66,47,53,75,15,66,171,302,335,3291,0,0,0,0,523,158,96,643,19,358,350,137,145,47,76,69,138,52,47,70,93,47,24,40,141,14,107,150,49,359,723,276,4911,41,604,20,91,65,27,81,43,41,56,47,86,652,0,0,11,25,22,113,44,468,0,66,1,93,225,0,0,40,95,57,171,0,91,112,75,83,96,0,19,40,148,55,53,46,46,0,54,50,18,69,2,94,48,19,55,10,27,67,49,39,45,22,168,13,33,104,111,118,0,78,70,59,47,165,112,742,143,1300,1008,3,0,0,0,0,0,0,16,21226,601,1669,95,2945,4,1495,289,102,373,105,2,202,1150,64,348,32,175,638,179,28,442,321,1089,15997,6914,1963,1680,3479,577,907,291,281,291,397,9507,2031,894,678,335,673,897,914,346,1776,335,898,96,771,364,209,173,360,642,730,4239,565,424,161,149,438,2261,767,949,103,375,210,174,102,896,0,202,173,0,1282,0,142,554,427,629,140,0,10,63,292,499,34,359,174,636,211,426,180,29,247,195,994,137,3417,187,44631,41641,6478,6419,9500,1190,2038,1165,2708,1585,4079,2270,1931,796,1110,437,3324,6704,11045,197,2542,1167,699,2,1150,701,29,565,34,3,23,28,112,40,146,9,7,279,25,70,640,1,570,3843,7214,1664,2458,950,2114,1418,649,2158,608,2292,836,2699,4162,5675,772,544,684,22,361,140,20,379,1278,1542,162,288,281,774,117,1524,261,422,62,1520,407,1068,1599,455,918,285,790,752,329,2192,346,9,740,1001,543,520,2841,1292,13,1838,1863,1546,1357,5334,273,5,7,23,115,274,620,947,1318,183,942,1101,364,38,46,279,1069,138,1468,591,1605,414,14,827,213,331,260,274,517,984,163,713,73,355,350,1455,2054,103,568,859,822,155,557,1025,1826,443,71,1517,617,705,699,770,1310,985,2210,2578,525,514,282,17,26,590,143,448,377,1167,3237,4365,346,11,57,7,618,1138,1078,630,1373,647,7,121,399,1307,1225,2640,143,97,286,463,362,1186,934,35,3,998,3939,3070,48,29,8,261,183,7745,6671,297,220,835,504,118,84,42,24,2,184,275,31947,2138,308,650,419,1268,602,250,225,43382,17432,12377,2382,4695,12,78,2409,439,161,603,30,386,1030,402,66,3,160,258,338,35,758,35,105,226,198,19526,14336,2861,9504,1435,149,560,1561,418,136,246,348,45,384,328,354,18542,3225,9542,8,4563,675,298,346,83,97,623,475,512,105,46,61,454,110,102,4564,29396,74,1920,4927,129,662,2617,1255,89,879,290,163,213,121,133,180,478,505,858,528,9777,253,2501,720,187,9,456,177,279,3767,3050,32565,1672,5083,5414,1363,775,1289,540,1106,2373,723,108,8,1243,2010,74,1093,1633,379,341,272,292,265,34,14,210,1461,932,395,630,625,75,2828,860,656,79,203,433,9,2051,5962,17118,1233,3426,1390,3666,278,646,39,407,461,25,6189,210,3103,1583,1043,1242,558,1850,216,13,799,607,596,27,217,658,2115,981,131,119,349,326,132,7005,1155,430,1183,9,1107,1110,1833,1080,49,538,461,586,4438,3395,1195,3894,2067,2638,1037,795,483,731,5526,1760,2447,1653,1367,397,467,439,845,1020,8,494,541,1050,472,890,345,748,219,134,351,32,1489,174,1333,1383,840,209,310,1746,2404,599,423,458,400,334,7,272,244,1941,1029,1136,2005,113,931,723,631,811,740,289,374,30,1080,143,387,29,886,131,1873,451,553,3475,347,58,258,3382,171,1723,215,535,839,470,475,245,59,1005,1865,782,2129,4,2259,38,475,215,423,300,403,756,403,2061,2287,983,113,473,97,363,473,8,67,215,349,629,214,32,148,804,31,45,6,317,2258,895,250,721,3243,785,1387,213,32,118,283,51,170,206,98,853,176,1765,86,80,31,755,10918,8,10631,3741,2035,90,91,1571,1069,483,69,351,132,306,1332,110,338,273,2296,23445,3261,1331,303,661,217,67,800,201,459,2681,563,5,6,1137,1851,31520,12481,2224,780,37,342,1794,1230,954,7,683,489,533,754,382,920,422,928,37513,3188,948,1483,2145,630,523,565,84,631,1059,24087,214,1812,7589,8872,1224,536,1315,352,924,1046,788,393,257,6354,5778,0,1793,1337,70,816,8335,5749,956,557,636,364,210,296,804,259,2452,6462,186,1570,261,741,779,168,495,288,427,2323,465,623,472,149,185,287,68,299,507,996,426,296,36,420,226,6866,1317,673,2304,89,288,308,737,615,1291,3982,5172,6787,1380,4392,1475,980,2662,760,4862,10420,2097,2757,3812,70,1986,622,275,435,1583,4332,2933,1075,220,1083,574,819,2257,3113,764,2150,1089,534,882,5026,5540,514,469,798,3335,4771,979,442,43,1171,505,1054,2040,1124,446,436,2357,4067,28,1278,3149,4392,214,2305,2285,2825,4453,44688,48010,834,337,55,239,171,4,109,915,35,39,73,62,312,20,62,141,41,74,473,171,93,86,134,33,96,36,19,1,29,521,45,83,262,18,1519,134,65,102,561,176,885,0,0,0,0,0,0,7069,4125,230,249,387,211,2065,976,1814,630,2044,7042,140,959,554,1231,1043,371,137,121,156,162,107,298,295,51,455,222,124,171,286,172,99,349,150,565,359,190,53,185,1024,156,444,875,3947,868,389,824,1616,152,1024,0,0,650,184,515,191,292,1816,109,1126,307,406,56,174,75,193,135,1070,253,81,229,158,522,1186,269,289,315,470,177,54,254,161,376,321,365,161,6,54,229,183,248,245,740,1,103,45,210,159,232,234,614,503,209,270,96,734,142,190,1215,470,106,201,307,0,147,205,127,3,153,2385,2,383,215,83,233,19,424,82,290,219,206,148,148,957,146,6022,2175,648,419,1667,138,209,52,571,323,1677,16,190,412,45,0,0,660,147,108,34,139,0,1048,207,440,143,71,38,268,183,180,321,1,70,11,2211,1828,1115,1903,91,115,510,438,278,289,0,166,526,1631,267,288,232,351,32,628,480,1108,450,459,171,371,303,268,281,746,659,10,252,428,0,277,1358,179,125,302,260,151,203,500,949,192,212,214,18,276,646,467,67,1,323,418,154,13,47,68,439,259,815,92,140,247,274,0,384,120,198,308,313,227,964,1405,101,373,439,142,474,40,87,16,258,178,444,458,514,257,124,137,232,200,114,43,645,272,170,73,468,82,82,457,106,91,646,231,206,352,66,35,486,249,645,170,441,90,92,126,416,372,143,67,116,52,87,18,261,458,175,511,234,97,578,141,55,223,1046,304,644,202,145,367,230,140,123,135,170,31,176,253,437,91,256,1561,69,19,448,176,98,271,123,2,74,724,347,17,136,149,5,144,45,360,203,30,358,73,208,90,105,366,169,34,217,893,354,687,51,272,260,125,289,493,724,167,360,142,920,435,659,0,184,365,581,1568,995,44,522,127,2113,27,81,51,0,456,1685,89,174,520,5046,261,797,252,903,2,129,6562,4692,5770,15942,380,690,0,953,3679,4397,53,3752,4915,125,15960,33,261,10678,38231,11393,0,87,3,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,15,6549,869,14339,642,584,383,702,397,62,225,790,332,507,300,202,179,704,2648,24610,18929,4899,341,1273,493,543,2035,1911,295,194,544,188,292,144,51,439,704,536,237,6959,6250,376,362,282,122,172,585,145,384,704,52,440,398,494,63,239,693,792,333,418,87,299,334,205,182,1581,207,2579,1000,41349,1908,73165,43452,13092,16040,2523,2612,1069,845,693,3245,2013,2272,723,1976,776,1547,1013,1150,1747,427,2207,402,375,1190,1291,1434,685,743,845,367,4596,1255,723,240,2755,1442,405,6460,495,5911,387,3354,2364,2014,973,1116,295,3566,1777,2287,2573,2883,58,1019,83,406,550,259,21,16,1,4,333,8,7,94,160,831,2,7407,4027,3796,808,1050,334,1304,1357,10,1800,884,221,977,1520,11,1360,611,1147,1055,2315,684,332,1598,1456,78,363,564,3160,780,609,714,333,122,28,423,287,100,2323,1613,408,414,784,1194,1165,980,1015,920,473,1070,1320,1629,1274,1470,163,1609,3,712,8,906,2894,2118,490,456,1146,536,681,789,1056,668,8,267,734,325,169,2512,1151,2,292,942,320,466,1020,512,1218,752,247,333,784,736,487,177,7,67,1308,562,409,1366,725,590,450,248,797,1124,806,593,9,478,907,594,427,21,400,334,126,447,908,809,123,415,4,675,18,859,1014,9,189,790,1311,1093,416,785,347,2293,437,192,964,335,785,487,1027,1092,811,595,1094,533,360,491,220,11,562,598,881,488,1336,335,491,21,704,23,457,650,915,423,440,570,777,793,458,1265,319,567,88,197,674,422,222,1115,482,547,737,384,979,768,840,459,393,1147,741,5,141,2480,304,44,555,1167,228,812,178,417,726,48,384,10,385,981,449,600,591,1165,56,1312,578,1130,210,314,158,403,680,988,594,1369,489,790,450,18,126,1049,1148,337,675,559,1266,1100,615,342,813,720,501,216,2,1053,669,686,595,392,3,351,438,345,2078,2243,860,676,1288,4,2,674,265,739,449,355,1469,437,3,649,6,6,291,487,2058,1040,592,560,567,423,534,426,922,298,2818,885,339,824,397,1342,2083,5,12,157,1452,1302,821,921,414,1,1168,13,1146,1611,133,107,361,2164,492,1350,324,1164,77,393,368,361,486,416,465,2480,2296,795,448,494,1018,137,65,311,346,247,107,298,9889,3081,2536,1039,1189,1264,599,1092,210,17,948,11,304,13,22,2,1143,494,1337,791,2154,7806,8794,4466,5171,517,737,4860,1979,953,648,3346,460,0,46,60,7,464,192,78,116,0,1705,2012,293,1074,483,5171,4786,4888,265,5912,1212,693,726,2618,2531,473,0,132,20,39,4611,4417,902,4785,1970,2211,1327,1168,2,0,0,129,447,6192,4,565,8813,1456,815,3214,2295,1398,419,9,82,73,28,34,740,791,1471,794,11893,3715,3184,2715,319,837,468,95,131,190,4621,366,413,1384,155,2,294,22,920,1477,175,598,18658,9488,13392,5683,25,1905,1164,963,21,826,2423,213,125,125,12,173,14,46,146,16,217,92,14192,13778,3093,351,398,610,407,1169,67,21867,7263,1004,800,2539,1285,50,236,351,263,492,727,1054,805,45135,278,4603,3181,11421,2125,164,2117,640,188,1007,114,356,22,277,285,0,803,30813,13216,19830,3592,3904,3345,396,108,727,268,1463,1450,1351,565,171,465,10,405,80,1056,161,3,180,43,1512,409,394,26,277,15392,16884,1973,1548,2265,473,1590,984,191,89,160,75,213,744,289,22937,3524,4607,2186,852,1473,1386,163,108,188,884,674,64,216,375,697,144,17,3,338,282,14782,10565,19123,1981,1048,7766,2946,5843,2792,1199,613,472,2209,1128,360,224,169,27,475,1097,14,244,123,300,387,115,123,623,2058,7510,7646,1973,981,766,2914,1193,921,208,4,1280,1052,339,473,94,389,422,218,7369,2172,738,4618,2797,2037,438,3452,823,1619,935,1040,1157,2,556,351,14,270,672,285,2245,1382,11983,2086,9281,4721,1560,644,512,2426,687,3067,808,175,309,594,1153,34,60,704,65,392,179,283,9,1916,1285,411,613,1649,2564,1220,242,641,93,1714,1224,2008,768,68,258,418,189,4618,5431,3519,4,500,1289,2501,3743,2610,2,557,1863,427,1123,402,111,746,320,791,2068,4789,2157,1876,738,989,175,272,411,397,527,620,786,770,208,124,245,11053,1586,1794,3024,4406,1667,3740,1485,178,1149,301,2,460,6,684,113,636,556,591,1586,2728,2287,4276,2088,3223,6434,3036,1737,61,3883,379,1838,175,1762,714,200,198,394,413,1229,760,4453,794,1784,1464,744,50,978,437,1508,279,914,530,1555,144,1187,2691,1851,2176,502,878,1166,174,799,1228,2195,2326,1673,3792,1907,784,270,17,52,631,210,49,290,1319,943,6423,2648,1012,931,2670,340,1127,891,563,661,388,728,289,623,586,251,731,1732,0,5866,1908,2247,2949,600,5,1379,954,2675,1661,1084,166,811,25,1392,1884,953,773,2808,487,6172,1076,2824,438,1261,678,2936,2939,242,2237,883,203,556,569,22,331,1417,2308,501,37,360,753,690,2678,1122,11,626,119,682,843,159,1003,1752,903,486,176,607,792,212,467,410,3622,14,986,1491,1093,1571,930,1511,1539,3101,1533,1071,949,1122,199,1143,789,60,596,311,1614,2502,2978,8,378,8,26,485,1384,1068,359,205,783,1795,1413,6,634,1139,378,503,269,6,1094,437,1,743,784,43,1913,1225,1362,1074,979,390,177,2071,961,3211,476,1004,1985,3334,2164,1959,1922,795,662,661,364,783,2226,209,653,7017,3173,4898,1920,567,492,784,863,1047,6,1089,2344,3763,3253,10855,2132,242,255,788,4,2705,3651,3950,2817,1148,41,1115,591,1165,31,1348,4708,13592,1724,4079,1093,485,2339,3269,2335,4031,4798,1214,209,806,1151,781,1551,618,3107,3800,2228,769,627,333,208,710,1995,1870,1693,974,560,481,299,8437,3523,269,446,782,444,940,595,2498,7705,590,787,1481,464,118,683,2202,1164,208,978,1421,3114,389,1789,178,689,2052,2567,947,4172,1429,1690,2411,3007,1174,546,1149,915,1892,3768,1267,5126,2354,0,74289,70735,718,0,143,39,190,101,23,53,79,0,18,7,61,1786,40,176,15,280,97,270,67,50,480,3639,0,0,0,0,0,0,0,10141,713,600,191,1384,1634,2628,243,2119,521,907,569,240,98,91,435,997,132,627,22348,591,104,210,320,777,141,392,348,543,1425,1458,1483,153,4824,10296,342,533,279,601,858,5070,221,822,2089,263,176,268,176,233,341,190,190,1,271,1333,306,142,565,290,297,241,560,661,1159,278,390,524,564,244,640,460,22,309,464,499,84,600,542,517,392,49,0,568,239,78,238,97,2,90,14,2,2,435,5,28,2530,244,51,515,254,66,625,4,193,791,490,342,432,421,851,1356,328,1385,2515,7058,597,9265,11312,0,0,244,84,435,103,232,209,231,319,190,402,358,305,39,188,166,908,339,253,431,173,140,419,391,243,124,1248,21,880,385,532,1216,585,653,272,569,123,1598,1128,1255,596,2233,1221,724,7325,7542,1115,1677,32314,92,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,5,24,5919,2207,532,284,302,46,132,901,130,441,53,106,77,11,4,120,574,1077,14132,3047,1285,232,83,46,84,41,161,165,74,164,3511,160,149,88,43,155,65,281,2548,200,348,190,286,233,400,54,89,125,7,51,83,353,642,131,394,49,54,107,85,157,78,90,1,0,163,64,162,169,234,846,2090,88,27369,2,16016,1924,100,718,1700,310,1662,632,1519,1562,8,500,2,739,132,261,324,19,342,636,170,374,7,1,537,962,119,315,998,1174,152,535,185,412,336,243,3552,1428,1122,159,1373,1572,403,11,660,278,762,4571,293,86,106,10,24,378,386,51,241,153,299,22,34,267,61,120,61,68,196,225,1797,3848,672,865,406,325,314,584,193,980,444,1528,311,809,427,4,280,119,739,254,1333,306,1041,4,110,133,146,1090,624,190,137,140,211,88,588,738,239,252,160,95,208,858,168,142,327,159,8,866,75,27,356,50,44,235,38,211,573,1,919,483,26,212,303,240,94,326,406,349,177,106,236,64,167,464,108,304,149,348,405,63,3,278,3,346,280,17,265,272,115,574,950,867,270,189,412,9,386,116,194,3,349,575,55,125,244,317,133,71,632,495,192,152,294,91,172,247,792,238,136,604,312,325,168,161,2,7,13,227,64,117,1,695,247,86,551,150,171,697,289,276,363,260,96,6,0,485,246,52,197,428,164,157,316,131,120,54,3,84,119,229,248,313,463,698,239,488,154,118,3,82,471,415,239,1389,295,2,355,148,338,118,121,1,53,226,353,0,7,0,20,101,955,375,114,269,14,186,253,0,117,145,263,434,543,47,78,80,49,64,25,126,165,82,38,0,2184,3001,587,165,64,1196,166,55,124,107,165,1156,90,558,84,130,125,189,527,988,1276,195,814,392,1140,20,38,498,150,149,0,32,251,1208,653,817,917,431,1066,1608,130,223,64,61,106,254,300,83,462,121,318,345,160,14,350,1178,405,223,1087,3173,69,98,118,213,38,0,5,531,339,427,655,1183,1434,228,203,185,389,279,1181,713,164,64,1342,10,149,508,194,1263,241,110,168,0,218,4480,297,70,7,764,275,601,60,225,97,146,767,3546,2262,1532,238,1190,2676,1972,3426,698,172,372,61,949,1470,129,190,679,301,336,427,374,23,108,19,9,175,2200,2596,294,303,425,485,193,261,366,701,285,242,148,75,111,586,787,387,466,440,183,318,348,556,268,165,116,157,714,762,857,332,120,426,692,136,89,151,108,92,1,295,25,431,337,627,130,496,111,154,121,68,137,479,1178,690,810,348,370,410,666,103,77,219,4,193,160,191,1204,1830,979,138,150,116,44,848,412,49,181,63,5,1078,625,359,269,299,772,149,324,206,661,196,178,866,212,1972,2279,385,315,189,913,347,171,149,152,692,131,61,64,301,346,333,279,129,847,93,219,192,1041,702,499,495,474,63,514,623,150,94,300,202,65,1,535,286,429,14,1063,2142,227,2,316,227,175,356,147,2389,1193,164,131,300,189,191,226,155,241,281,345,476,552,328,210,300,332,205,337,154,190,146,783,89,147,574,289,424,240,291,133,198,427,439,280,297,612,1050,16,241,61,245,536,197,339,636,22,180,211,535,74,285,328,463,336,97,181,568,446,465,153,865,75,212,676,180,828,26772,19527,694,304,263,1,11,32,19,219,163,224,238,181,263,2225,4091,1839,0,0,0,0,0,0,0,2982,156,48,161,56,79,79,70,21,55,71,161,145,240,104,86,417,262,684,370,1061,1037,3281,6256,1226,98,147,57,127,544,152,752,1293,476,97,110,190,46,110,250,146,13,47,160,55,78,78,96,69,5,58,25,54,6,70,159,144,10,94,58,85,102,31,85,68,18,104,340,187,90,80,342,102,147,188,175,242,155,159,150,167,599,589,498,520,553,1676,1329,84,8741,367,23516,0,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,371,30,16,488,57,509,11,267,26,74,52,2,98,67,721,3535,1,1,96,28,108,154,21,11,19,163,6,117,326,37,22,30,78,99,187,304,12,93,264,31,27,57,10,1,56,4,4,0,0,0,0,0,0,0,0,0,0,0,0,79,194,119,92,1408,1,1025,146,444,170,34,170,75,160,49,179,38,33,5,31,22,53,15,35,40,90,34,86,42,57,5,1,113,134,97,164,95,1651,97,37,124,127,234,128,12,22,53,71,191,4,101,54,94,34,27,41,66,91,689,12,213,197,355,4138,4,109,2,59,163,222,51,98,18,28,299,63,86,132,137,122,58,110,59,133,76,40,35,98,75,35,42,54,108,1,50,2,180,39,58,34,6,32,23,25,30,1,16,36,41,91,60,35,12,74,37,5,43,16,4,2,2,35,74,38,79,90,55,31,21,26,14,134,0,12,22,97,44,16,138,56,77,26,137,16,66,38,48,237,138,146,238,100,27,26,31,117,23,28,9,9,28,90,35,62,494,99,108,348,45,39,24,22,5,4,2,31,34,39,189,18,48,46,12,59,36,57,38,181,26,41,132,214,60,19,4,66,84,21,283,279,28,1,4,36,55,6,57,245,21,75,171,25,47,1,38,1,180,32,20,98,139,2,4,79,17,37,134,3,65,87,179,26,156,15,39,52,48,64,3,262,38,97,24,29,109,37,40,84,14,16,135,43,15,104,22,34,54,32,33,51,45,8,8,23,22,5,65,27,192,97,188,31,178,3,124,223,136,1006,1,149,35,257,267,0,88,79,756,134,100,829,322,1483,1710,48,108,22,34,1,9,125,6,56,114,231,3786,0,0,0,0,0,152,194,77,21,66,29,77,57,91,880,13,21,160,99,18,30,158,19,76,20,17,15,3,22,16,49,4,4,65,8,98,20,32,112,33,157,0,207,373,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,367,433,32,44,203,15,532,99,6,52,42,104,75,131,164,4211,5715,53,1,1,60,49,138,130,35,67,343,33,48,15,45,206,16,328,252,102,37,3,0,0,0,53,41,105,78,134,223,5353,2,2695,401,47,601,551,171,351,74,517,121,123,355,82,82,73,330,514,488,2707,1392,4749,153,216,64,774,164,198,119,15,317,173,40,25,71,400,329,86,51,177,72,208,597,3865,1,79,37,97,55,14,921,2,458,8,105,268,18,377,307,80,8,4,60,54,183,84,18,48,3,234,129,241,343,9,5,4,5,5,33,62,6,23,125,86,58,59,23,93,81,215,8,131,3,344,61,13,1,455,19,58,60,60,4,23,5,37,49,35,124,345,356,348,83,5,79,6,74,98,4,240,125,61,118,56,30,2,3,60,240,349,42,94,122,40,36,164,75,6,571,34,37,123,40,62,75,62,479,1862,99,57,284,89,221,298,90,5,312,177,155,6,12,15,92,456,974,132,20,66,157,3,186,180,209,94,137,42,171,278,37,52,1255,50,206,239,125,126,388,438,141,53,25,119,149,619,1920,700,239,32,123,12,63,37,145,2,73,2111,154,133,7,110,18,27,104,350,257,95,59,6,141,2,38,43,67,155,111,53,24,260,228,206,133,207,197,58,359,195,68,7,57,96,59,608,49,2,0,240,103,105,87,154,278,64,70,302,0,93,6,266,80,8,83,396,8,7,24,62,162,153,218,88,95,53,18,160,106,9,361,129,213,59,291,305,269,85,5,55,53,538,73,174,541,263,85,2,3,78,133,31,121,94,59,99,232,187,59,89,52,24,39,72,35,53,52,5,142,70,60,58,61,583,322,18,34,13,155,1,1086,521,286,42,380,423,159,118,101,22,394,190,2304,215,176,138,25,5,308,167,88,1402,355,37,1274,61,73,101,483,83,184,7,68,186,393,1,356,152,132,192,263,178,157,82,355,87,1,344,240,245,64,4,3,33,465,13,16,0,136,21,161,244,1567,0,2,0,164,141,0,450,207,3313,5043,166,97,25,26,67,80,48,454,19,20,50,104,76,26,53,24,52,1,5,23,9,187,43,99,102,135,417,1590,200,3076,0,0,0,0,0,0,0,0,0,0,0,51,191,50,33,74,46,53,0,42,22,77,39,28,469,378,1866,118,1353,40,33,87,0,95,24,50,25,157,61,30,0,49,14,54,6,0,2,76,48,73,64,93,383,48,18,14,3,95,1,106,46,56,74,45,52,25,54,23,25,27,2,22,2,11,19,6,5,28,22,48,21,185,50,25,72,42,24,38,13,31,66,50,94,84,71,139,271,257,0,633,637,275,4637,0,574,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,2,18,7473,456,1396,143,521,130,10721,127,6,204,117,102,2,61,56,435,311,82,77,143,132,19,97,272,190,125,21,132,201,40,160,254,8615,8608,666,2,33,1,160,315,333,2982,208,281,210,104,198,1662,1079,139,407,76,883,679,161,334,144,522,131,330,120,487,179,50,321,275,523,228,297,615,6032,6259,155,128,331,0,0,0,186,3,0,0,119,486,116,101,207,3,60,56,2,180,120,311,49,310,206,81,76,280,41,101,320,131,28,276,99,29,271,163,239,646,20,134,135,202,277,195,76,169,234,199,161,2020,31,23567,34,2,2,49173,476,708,2125,994,418,986,20,47,138,179,98,183,29,3,279,1,94,107,3,28,131,1785,1,132,27134,15169,9712,3745,1515,3096,1517,1546,194,87,62,168,1,201,144,124,226,96,1391,978,52,94,17,1,13648,8235,531,648,2284,787,313,234,571,98,186,210,18267,3125,1341,1305,1282,477,1762,98,8,406,221,258,71,244,679,107,9740,5880,9906,332,2277,239,2460,1238,420,247,68,753,363,459,144,222,70,362,1340,1653,407,5908,3171,118,594,217,117,1804,340,11,585,916,214,502,108,22,57,2216,1322,4,7242,165,1361,848,535,931,586,8,364,269,471,238,325,110,313,22,47,29,237,772,752,161,161,7575,1051,2640,4626,1780,12,848,391,7,602,1233,1684,27,66,205,13,432,519,978,1313,1692,295,163,166,119,21,333,1665,2139,249,706,1255,1554,494,695,198,2657,175,126,378,147,263,1099,422,1405,70,1639,218,380,124,2413,1304,216,113,114,1146,459,481,241,307,150,83,163,159,120,1102,115,740,246,120,11,453,617,1431,1392,1138,522,689,405,333,2717,221,356,368,179,229,203,1467,345,2382,1624,47,39,99,454,610,495,88,1122,235,250,294,123,9,45,293,509,704,624,1215,175,220,50,186,219,138,9,340,288,134,394,564,471,9,530,945,705,480,133,593,69,857,2,392,809,754,586,370,367,545,10,1298,187,1492,552,353,592,1014,524,136,26,628,979,338,228,169,239,437,714,546,123,1033,9,8,366,168,221,201,228,773,436,1180,1609,378,10,407,599,34,460,547,482,406,531,327,197,124,332,99,9,2,643,229,202,598,1065,1,282,285,339,329,86,472,1960,349,5795,2092,256,40,11,145,167,117,528,28,8,143,477,228,144,223,8,181,130,9,906,267,108,219,621,296,76,13,157,851,317,365,934,807,1645,1297,4,218,132,7,234,233,2,313,12,397,21,284,586,149,251,158,131,995,753,418,5,556,255,467,1566,364,47,754,408,204,352,158,686,255,242,791,1136,1957,168,87,546,1379,254,1145,1143,1245,290,7996,5515,336,2028,314,692,1077,42179,430,46,0,48415,1,34,6,8,159,344,38,1,21,17,0,0,0,25460,55,562,282,313,606,67,128,950,57,183,406,121,52,495,499,366,14,180,162,133,89,106,47,48,56,114,0,109,72,103,25,255,330,432,217,234,1593,0,0,0,0,6114,193,2145,50,274,497,1045,150,80,2337,281,40,170,449,1063,516,143,60,94,10,205,16,110,102,154,599,111,84,57,138,79,99,42,70,210,75,153,52,797,619,628,219,652,3350,0,0,152,188,54,803,491,93,119,890,19,109,75,208,163,271,528,105,96,193,292,241,250,859,192,151,362,45,536,242,304,109,136,106,57,275,171,785,0,61,20,71,86,3,49,52,35,240,32,134,435,44,396,60,240,99,261,161,249,498,114,65,315,504,110,134,41,83,359,0,91,66,46,160,234,956,79,16,475,48,53,22,268,1160,482,100,163,144,162,18,123,107,98,120,123,775,298,418,1435,0,0,0,14,5,40,75,68,48,201,56,43,3,147,223,18,86,56,167,78,93,146,113,163,64,222,184,166,74,171,262,158,181,107,54,1054,237,105,96,200,155,139,43,108,157,157,260,119,144,1056,0,189,62,261,443,395,225,132,358,221,87,565,142,1003,199,123,169,20,236,6,61,104,188,152,5,99,22,0,162,61,77,204,101,108,394,161,103,34,48,199,167,132,198,348,47,88,105,160,75,154,365,149,0,47,101,52,102,394,90,419,224,145,113,144,245,672,159,42,132,166,110,159,162,107,114,237,85,159,53,8,56,591,122,43,93,35,80,197,707,7,2,97,131,108,41,393,69,106,209,130,223,97,158,357,119,167,514,71,144,332,355,157,392,51,102,109,69,198,551,162,1324,149,218,992,1006,864,903,2842,1098,976,3237,1019,3116,7273,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,2993,86,666,110,31,341,61,3235,28,42,298,66,120,315,127,2216,6244,1524,802,194,142,48,566,1963,165,66,30,6,1,586,44,58,173,458,1055,493,14,136,26,63,25,497,172,69,43,32,203,125,20,62,167,617,2553,225,112,33,234,221,30,445,58,3,1,0,443,441,5,76,67,3,0,11,0,0,0,0,0,1,0,65,86,30,123,89,352,43,172,297,116,3843,230,14773,222,35,88,20572,109,7,516,255,4,3,2,11,3,1,5,28557,514,45,894,1082,43,10,10,2,1,1,1,1,32,18928,2195,1095,4311,982,210,3,131,91,117,46,298,352,194,122,53,236,167,37,157,70,134,354,4838,2461,5217,2915,1429,321,213,131,203,182,178,58,138,203,81,289,65,300,120,135,104,114,161,1111,1351,1049,409,287,95,262,248,77,334,171,87,282,570,226,92,160,92,46,281,5195,413,149,728,201,1,162,165,20424,12,4,85,162,1,141,194,71,1,28703,138,166,238,4,157,335,7,293,10,140,207,80,141,3,4,9,42,24,114,119,117,1,7,2,168,11,403,78,22,36,180,2,25989,594,1032,648,76,38,265,134,105,159,116,78,293,133,5,306,293,178,133,477,193,223,263,30,24,206,472,67,134,150,480,257,116,28,491,234,225,31,164,31,40,66,130,78,1125,12661,1865,1397,272,182,313,575,616,533,466,539,156,205,158,41,27,388,153,150,88,321,746,137,233,276,116,212,898,133,311,1,117,37,498,63,80,107,289,9,226,269,80,3,121,54,56,7,173,319,741,1,4380,698,329,406,225,266,206,138,202,323,438,80,1035,385,262,344,689,306,305,10,88,111,184,587,73,234,12,219,254,272,159,106,101,204,27,2139,167,261,447,196,42,643,367,350,50,462,260,777,735,133,168,78,71,91,126,37,34,91,222,134,657,1010,476,141,214,371,166,200,169,13,14,75,302,22,218,5,250,127,108,187,1,13,57,111,215,28,9,168,5,156,330,14,516,324,223,273,84,77,183,262,64,135,39,315,158,55,448,528,297,49,362,226,60,458,267,435,468,146,232,325,331,403,121,47,112,106,197,264,625,43,187,204,387,55,1,32,204,71,225,477,94,191,459,340,45,270,185,124,263,337,363,160,203,133,178,249,721,299,334,324,147,12,117,86,449,183,206,338,294,368,63,179,159,213,241,232,184,141,54,182,439,263,130,370,224,529,126,200,77,81,157,220,4,626,11,62,351,51,78,476,139,3,15,57,246,42,141,1013,598,614,207,372,87,298,45,208,680,180,460,416,140,450,514,79,154,332,438,226,238,404,44,142,149,204,160,349,2,186,169,93,29,386,265,27,4,497,129,139,156,333,279,136,141,93,87,212,16,433,146,736,500,208,200,50,124,794,451,271,198,199,211,88,184,249,146,14,138,1263,598,145,239,304,365,124,50,266,205,60,472,363,28,138,423,211,145,131,268,134,72,364,206,99,63,14,2,300,578,292,318,262,326,85,383,93,0,8,70,33,494,115,621,477,192,6,0,35,615,1,542,138,385,105,438,230,2,965,106,48,101,64,101,345,295,402,222,987,266,1443,119,438,4,0,324,1,234,169,391,25,281,318,493,293,43,770,422,206,192,291,174,114,132,0,172,104,176,66,173,720,81,249,0,8,67,114,51,9,310,76,722,467,427,160,774,282,70,8,637,0,243,190,645,54,1027,202,0,198,136,342,0,683,391,324,39,490,484,284,81,246,165,13,123,238,136,1553,2646,699,52,380,302,66,92,163,145,214,1178,1486,64,228,155,108,283,334,38,46,479,319,3993,665,589,3281,552,84,597,362,260,367,222,597,61,2,172,158,171,220,186,231,85,130,1,1735,82,269,120,106,96,221,619,912,2226,1469,453,6,726,237,2,705,138,461,191,143,82,61,622,28,1,393,1932,1080,3,450,95,250,101,207,205,124,65,32,120,112,445,1109,1402,278,6,132,333,185,132,175,1,238,103,650,231,1070,119,2246,376,207,511,98,283,1419,270,1,50,417,275,99,45,303,4,228,1,127,177,134,135,52,187,1079,27,55,252,2097,633,275,193,160,187,279,271,227,185,439,369,123,350,106,304,785,207,149,472,290,224,199,85,294,341,126,167,94,1877,278,282,231,208,322,267,136,295,146,230,377,159,59,184,555,239,5,279,368,272,208,474,973,217,356,69,454,118,333,137,708,240,133,302,99,470,107,2,109,278,176,296,499,125,142,142,339,639,407,171,56,137,374,269,187,172,1364,62,109,271,628,261,580,70,165,107,232,133,63,241,51,143,461,206,441,369,193,206,795,329,286,388,455,94,206,915,367,368,392,176,227,253,46,499,388,134,233,463,212,304,277,119,291,134,367,113,195,157,303,227,627,454,137,418,198,170,205,640,71,275,84,197,601,0,133,332,421,93,838,176,353,389,192,1035,451,295,207,114,365,966,689,704,828,187,207,83,1805,0,51,290,525,113,534,940,282,524,169,121,1914,7666,236,289,936,2168,0,0,207,8234,14830,355,3377,480,537,358,33,136,88,39,327,297,36,76,154,146,229,28,84,143,68,227,804,276,2173,624,4163,0,0,0,0,0,0,0,0,0,0,537,5314,463,1000,781,319,134,71,487,136,73,113,127,115,190,71,254,307,137,890,745,2355,481,278,44,81,1035,372,594,283,180,938,212,385,69,81,214,169,78,1090,308,1110,244,1906,649,106,141,129,289,108,145,280,138,185,92,452,213,464,60,459,194,455,136,247,262,254,429,182,235,124,161,186,32,173,321,91,67,46,35,107,279,79,93,34,425,263,25,286,211,40,133,159,117,223,43,152,180,140,132,104,64,66,459,135,76,72,307,255,278,68,75,36,261,151,70,45,80,123,81,569,159,61,412,168,27,81,317,259,83,138,374,94,47,66,716,291,270,231,717,1526,1545,788,1349,1373,705,998,2222,8359,0,6506,0,19,7,0,0,0,0,0,0,0,0,0,0,0,0,0,5,1165,28,17,476,192,24,3,50,522,2063,4534,74,450,1534,1,3,1,33,22,31,134,262,535,27,156,29,34,21,39,44,296,51,85,32,196,25,4,38,51,140,559,2658,1,1074,58,132,683,8344,110,403,110,95,56,147,47,75,1,63,126,32,250,3,59,24,97,144,216,56,145,278,61,258,46,51,134,2174,76,336,374,125,180,59,77,25,54,133,1234,46,301,171,26,485,288,198,182,156,76,191,93,30,42,20,21,35,200,104,83,407,251,14,3,214,150,90,1017,802,72,132,100,365,418,652,1,87,1,794,57,430,138,115,346,351,66,100,265,160,34,30,32,45,75,144,56,144,5358,61,96,152,172,27,111,130,24,1,55,398,143,66,40,40,35,73,71,45,69,2,103,131,68,21,27,94,28,1,21,9,60,71,96,26,375,157,57,77,151,42,148,150,92,48,76,31,151,43,21,0,20,34,12,130,57,105,57,28,95,3,75,57,3,168,23,237,10,45,13,1,30,2,13,117,33,17,1,94,26,61,84,0,63,147,110,2,125,88,93,4,252,410,108,226,24,259,335,86,0,92,136,70,42,114,27,109,132,219,147,48,130,22,0,48,37,91,54,61,34,83,88,0,98,112,50,96,17,45,20,70,149,0,68,192,124,40,0,19,8,56,53,283,12,193,0,38,393,115,410,67,58,44,56,194,20,22,13,23,375,115,172,2,88,1,88,20,38,2,320,23,220,178,85,98,76,790,219,11,116,56,113,61,67,410,75,18,118,1,53,355,2,47,0,246,179,220,194,84,47,58,12,8,102,147,303,23,77,16,103,20,33,318,201,60,331,70,2,28,9,30,307,165,66,1,97,272,244,65,104,21,93,399,393,374,25,276,211,116,183,1,21,3,166,133,159,359,1494,56,66,809,3,307,124,148,34,94,324,2,387,85,76,57,173,2,105,47,15,64,5,165,17,264,493,132,176,0,24,452,81,19,57,164,8,275,46,142,734,1998,187,228,7512,1,0,10,28,17,136,47,192,1798,0,0,0,0,0,210,1449,10,49,287,185,56,863,2521,24,25,31,64,85,171,66,245,24,215,4930,0,0,0,0,0,199,46,71,65,315,1749,20,5,8,24,4,2,14,4,10,213,54,27,30,63,100,169,135,70,65,71,444,96,953,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,1,3210,96,517,394,103,14,103,21,57,69,1505,56,79,152,2539,5964,1,385,347,2,57,39,118,84,92,787,1375,97,119,89,709,140,325,387,54,51,4,4,20,1,0,0,0,0,0,0,0,1,0,0,0,0,0,56,38,22,1,58,57,14,993,975,1,57,170,18,230,1,4994,5,1812,582,675,106,128,3,162,133,278,120,275,1348,3136,5868,1871,1366,3634,927,187,637,1113,1362,1,95,77,78,1,1,201,62,84,40,80,6,88,70,117,164,56,457,2586,186,160,278,382,292,92,73,54,97,43,180,202,84,151,187,104,48,161,50,246,37,181,168,279,33,75,162,80,50,4,163,134,279,1,1,401,135,102,174,3,147,437,29,466,144,5,28,110,2013,180,87,576,98,45,1,57,113,26,90,148,487,42,161,457,1062,3739,576,113,313,1151,114,257,54,104,5,2,107,91,51,220,41,159,12,242,239,16,2,134,209,476,451,549,18,429,53,344,321,2,44,89,61,231,37,60,842,93,467,50,227,30,10,107,42,188,80,96,24,246,61,440,26,84,37,338,1283,12,433,1030,1156,121,84,283,60,94,218,398,527,209,695,4,43,32,49,1132,592,62,34,345,87,74,106,235,929,76,156,1100,230,219,94,177,16,45,146,66,150,514,57,77,19,13,56,114,122,99,164,101,2,291,150,171,206,47,70,60,10,160,10,45,368,56,153,289,808,186,317,5,57,61,339,2,303,514,8,340,117,110,313,290,97,37,162,126,253,490,151,796,9,8,55,249,179,173,155,263,65,254,406,2,201,71,63,383,61,28,326,933,31,122,207,187,58,1,123,108,83,469,57,6,282,542,50,182,55,114,151,116,12,208,144,138,46,6,11,54,200,66,7,56,54,108,70,64,31,60,76,3,11,157,80,422,267,25,115,108,66,78,43,90,256,9,281,180,137,0,65,8,20,350,79,116,0,207,64,178,198,53,431,485,87,394,56,64,107,1016,41,9,213,94,656,7,206,158,143,6,88,455,176,216,175,49,131,181,0,65,208,205,141,231,537,149,3,322,62,24,5,171,237,424,32,77,36,48,4,12,424,157,31,70,40,106,44,48,464,625,557,228,81,81,37,97,1,56,5,507,1886,0,304,339,469,5,57,340,181,499,475,150,87,162,367,934,1468,228,54,61,138,412,2190,1038,60,102,60,242,338,381,62,284,243,2499,112,80,203,112,223,1597,80,111,56,212,249,508,566,241,105,161,113,173,245,0,653,840,786,125,234,411,229,54,40,650,5443,7069,83,38,51,144,2,59,221,132,29,68,392,275,340,174,50,127,1,10,252,70,77,28,21,122,17,139,415,23,58,64,44,23,55,209,327,181,3560,0,0,0,0,0,0,0,0,0,154,25,85,514,115,358,249,93,6,378,190,103,76,182,153,185,71,95,85,169,69,132,583,12,33,144,282,120,192,2023,44,37,99,53,26,37,134,140,48,56,137,267,114,0,0,150,99,19,18,157,103,0,162,3,19,87,191,0,60,17,36,51,161,39,79,0,7,59,4,0,149,149,160,27,92,27,68,124,165,0,56,120,48,92,37,257,0,0,55,46,94,74,117,236,0,2,59,55,50,50,146,24,118,49,48,181,1,159,59,286,67,157,213,0,45,11,18,58,113,66,70,20,526,0,54,48,113,36,76,53,27,84,170,51,22,47,17,68,53,69,91,17,16,55,104,22,108,82,47,55,109,339,1208,0,22,11,67,91,63,21,22,98,16,112,188,74,16,170,86,959,242,1095,1459,21,2,0,0,0,0,0,0,7,1423,121,40,618,186,23,32,29,10,14,7,140,20,359,129,51,774,1293,3447,8315,1,53,87,360,952,123,41,58,134,174,86,173,60,56,282,40,24,30,28,9,15,6,144,21,173,103,30,233,128,52,461,326,968,777,6201,8299,503,1945,1411,5468,257,959,3894,207,124,1194,729,389,264,419,192,252,164,53,276,179,70,24,1,1,73,43,71,858,5756,212,300,1585,1937,578,1800,118,178,72,53,137,121,46,48,228,980,346,213,159,714,447,147,117,379,74,46,8,101,176,55,1377,4,67,348,473,828,116,51,35,30,73,66,58,227,96,895,2259,640,191,168,328,126,41,338,173,123,76,8,388,495,94,87,46,116,93,427,2478,130,131,101,789,563,163,199,23,73,2,36,834,211,1751,301,969,98,320,391,77,145,81,438,6,152,207,260,112,201,559,228,295,141,113,173,2238,119,204,45,119,45,598,141,398,422,114,414,220,95,2,327,55,197,303,82,90,198,143,758,283,220,146,1214,165,27,180,21,109,107,2,84,57,117,59,531,399,175,2,62,178,28,289,4,160,42,37,213,3,22,120,1258,51,74,187,155,36,99,111,250,151,84,4,138,376,31,94,99,636,59,176,62,115,128,55,84,74,61,481,7,48,258,78,460,78,70,146,650,54,22,82,177,54,380,230,108,470,7,294,153,68,208,3,94,124,6,1,5,862,6,54,443,11,0,196,318,3,1148,229,111,166,0,375,127,67,465,379,538,374,29,57,472,1054,523,145,86,601,142,230,565,1010,180,694,338,1411,145,5559,8144,137,1114,166,225,1,59,154,142,86,12,2,163,22,12,29,78,52,59,61,9,59,178,83,11,29,87,24,36,19,561,364,252,368,226,4013,0,0,0,871,70,184,206,94,135,33,716,35,85,50,107,235,169,30,121,33,50,21,99,83,138,71,127,625,118,60,3382,134,122,246,95,167,186,78,51,20,134,67,35,745,0,95,69,22,165,0,55,128,65,190,54,154,58,144,0,93,58,69,64,54,94,32,153,83,30,75,190,126,91,166,251,0,82,84,34,84,51,13,106,234,44,94,65,30,103,242,11,38,76,122,34,11,42,81,64,123,77,51,51,64,58,20,60,20,69,94,189,63,68,166,18,128,191,54,187,84,80,85,144,77,30,86,50,22,70,50,83,140,68,143,12,69,63,90,50,92,201,123,1127,315,102,133,1190,129,966,46,993,638,3,0,0,0,0,0,0,0,0,0,26,59398,8241,19141,3096,31954,352,1598,760,811,3,272,187,111,15,575,387,405,39,6,439,487,2817,25138,1994,2121,15457,1687,23697,440,304,297,541,394,234,160,724,591,557,3051,1087,8149,180,3427,3313,350,673,429,649,1572,2917,26184,1103,266,864,621,442,655,287,4706,177,5849,583,1283,7192,2787,458,459,1653,322,2927,771,465,396,506,806,242,857,895,426,581,6157,599,867,7947,13593,40310,24,426,228,370,1398,232,1104,5665,36,1526,397,1132,595,747,427,590,847,229,305,812,1,267,732,1987,620,1333,323,1324,121,2045,85,773,28,865,466,866,16,397,86,507,1399,807,785,856,393,2694,385,427,233,580,670,201,1873,1032,4607,1033,1165,428,440,486,381,2975,18763,27346,161108,228885,15901,17134,24081,11885,3671,1823,35,1944,2189,4474,307,917,2627,350,336,38,78,440,10,6,64,7,211,9,121,1,1,29,13,529,57165,60425,47249,38054,8282,2416,650,221,54,5382,260,4466,80,1423,1596,1537,18,127,2,135,135,70,18,20106,28042,11149,4369,2297,100,1345,266,1601,1928,1780,16,160,1,62157,23954,3375,1083,2205,1300,1361,1631,716,100960,20388,559,5282,2245,313,3354,10840,4236,7252,3982,1915,7,19,56,66,147,100,37,15,93601,1754,16596,5719,4507,4065,14896,9360,18367,950,7581,6564,1853,4,445,67,7752,22121,4890,24976,8032,23064,6233,23082,6796,4771,331,5,1124,669,3134,5102,1158,674,4550,9268,13113,6043,12224,1790,4995,2792,40,4,3164,2402,2529,5517,36,5094,20165,4145,5236,1186,1404,222,309,19385,2823,3918,3575,3272,473,30484,44882,2155,26602,11389,135,857,81,132,43467,2652,20818,4410,6,904,6,188,18365,110067,40347,1493,1647,1349,689,1501,105,241,111,544,56,19797,6291,311,1112,195224,2825,6015,2675,2668,790,1160,641,409,19,17991,160410,50051,3267,1694,18349,13687,4754,1982,1533,3862,1335,1621,695,715,37,72,511,12,24,87,36,412,11961,7072,8,378,1418,113658,8049,3171,28382,16240,1318,7050,1591,1892,1324,1354,459,588,227,24,14,48,22590,17770,62378,43342,11624,6475,1894,2317,7,4726,843,956,433,406,224,71,194,231,195,32,2889,15247,9044,2734,3047,128,2282,50,8705,8957,2602,662,448,1412,2414,350,39,101570,11786,8848,3079,2162,24,2528,677,3292,114,1224,53,185,346,142,247,334,71,172,82393,41029,10186,12553,14988,15533,824,8315,1905,37,1146,2242,119,2384,2099,53,329,975,104,44,40231,19637,25520,5576,11135,9842,1750,275,626,138,534,120,1683,1499,753,344,148,968,16554,25952,18781,21721,2200,13869,2102,801,147,1728,822,932,567,789,266,41,47,7,473,9789,16085,13587,9068,982,2556,673,684,570,1838,154,1419,28850,20901,5008,17326,1691,397,3197,981,1055,1511,832,395,567,1274,23,588,30,44625,2225,20244,452,4969,388,231,2575,1589,1620,4326,888,891,2043,8,828,5500,77604,687,10706,6632,5029,4117,1402,179,9834,2936,2672,1748,2849,10,210,329,551,2415,1241,1382,687,11738,241,2409,1429,596,537,630,469,126,668,11541,16249,25139,14466,20242,13675,2572,30310,11283,1093,7179,20,7237,1949,1237,126,6120,105,1100,555,1420,916,3606,665,503,168,1690,6110,899,3324,2831,1172,175,453,688,9357,5447,1745,5175,1350,2383,1616,5377,1702,30,1543,8,1701,234,1429,6396,7645,8022,1950,19459,2843,1300,101,2745,796,1347,34,220,545,164,2259,364,430,2201,1035,7028,1035,2446,15488,2635,391,2149,2169,12,628,100,381,313,1136,49,7429,3455,14726,4681,4909,670,4117,3248,510,85,639,1446,293,3259,20323,1493,4124,337,2044,605,119,98,1964,1388,1331,3097,421,1499,2330,603,11547,4918,1154,118,1409,308,71469,3908,19756,829,15966,9788,2444,3943,39,805,477,649,1325,398,967,1101,894,2093,5458,45537,7810,23289,8023,2388,1366,4762,2767,3412,1470,2072,1420,720,1572,190,12861,1911,1258,1133,230,6566,55567,17266,7086,8073,5712,223,116,118,650,2618,2783,360,9740,4215,100,396,1578,19,122,69635,13892,905,15145,9979,4475,1785,802,10,365,1556,1953,2499,924,3050,1670,2368,3107,0,38363,11487,39375,13239,5674,96,2720,4394,284,399,3018,816,57,1942,1874,5189,29757,16099,6598,953,3975,3234,39,1935,586,4222,5472,8165,276,799,6,566,9,62352,28446,2149,3142,5648,1471,294,627,1462,1688,198,135,2123,0,77111,20403,14019,7525,14,101,6,3110,953,103,764,75425,36117,13336,2860,206,793,24,315,419,669,2769,3116,77347,16852,1891,848,959,967,1825,1420,2498,102294,13102,2416,2800,3700,773,1291,1235,590,1568,4933,7502,75236,265,12970,6428,2206,8579,3189,3736,5299,4564,382,13005,20899,1040,26255,1266,9934,152,1519,5922,4099,11248,4001,15633,17591,1039,664,4134,2454,2065,1881,4168,9175,3349,10202,9577,4795,1160,1344,2353,1382,1623,2262,2727,4809,2660,5194,1962,2115,1554,8208,7169,1135,2347,2812,1806,5924,7028,1430,3660,2494,3858,3326,14406,2403,2199,9501,13241,0,8890,2612,16217,18356,9645,18946,26510,16873,14556,147268,142647,2527,1274,471,2175,114,568,825,1103,833,46,83,24,32,18,89,85,213,281,70,31,25,150,10,438,67,99,0,593,106,183,2,160,3,86,28,128,440,108,49,224,65,1748,1481,0,0,0,0,21974,33283,3153,23464,4877,5115,1399,590,8041,3677,322,1252,1212,1833,689,1838,727,1511,2204,1467,336,844,316,530,187,228,126,325,254,636,150,291,130,495,288,469,1,602,68,1007,109,471,487,1498,1654,1520,2252,2394,2409,2583,4722,864,5096,104,2588,885,1841,589,140,710,62,351,1545,383,512,190,813,384,536,590,817,493,203,4037,9078,479,1579,2653,2672,994,894,60,2927,1545,328,722,2387,910,648,264,581,537,500,644,613,390,572,430,665,293,333,183,1142,38,3144,473,455,1052,681,863,513,826,41,434,31,1036,9025,778,19,6492,1420,2279,718,4184,3381,489,848,498,323,405,689,42,1028,459,366,231,1925,426,313,85,1534,1666,161,1107,925,1725,2124,1303,687,267,330,100,12,417,101,2759,454,4557,3840,20,1243,1239,653,854,273,1087,1410,923,189,132,577,268,80,0,3507,2605,702,1790,543,724,416,1182,320,15,47,743,300,18,11300,1228,1849,1940,4029,2733,334,2182,482,304,610,725,578,290,782,467,169,184,2311,2499,221,7967,1036,1947,2879,1528,211,1136,664,1279,828,440,131,132,1290,687,2173,610,47,1233,2177,557,2224,2712,1,424,5,1769,612,719,2399,1232,451,475,101,6514,2303,4769,1197,451,1506,869,3353,3593,4,393,500,280,15,305,885,3,843,98,2897,4856,623,1241,2654,578,396,1318,736,991,270,689,126,194,86,573,1420,4065,2253,707,718,1793,559,490,613,61,2902,6825,2570,4862,1322,1497,5090,551,836,571,709,66,257,652,67,609,176,0,270,2482,1371,1916,499,722,728,211,0,940,2158,2189,5597,450,596,781,120,150,862,329,444,863,920,511,2518,3464,91,2677,391,892,890,717,206,749,226,563,3175,397,7755,2385,1165,1019,649,350,950,1640,438,1848,9248,1365,231,953,1231,1389,381,723,409,248,413,592,684,2753,720,4879,382,763,92,43,18611,1075,814,446,326,687,189,460,658,815,910,683,611,700,335,2618,1558,1559,1317,842,1180,664,183,704,894,267,802,48,1204,452,2069,1007,929,2333,1360,696,247,1025,557,1082,849,18,770,225,3550,1191,1248,479,393,412,441,1101,1749,1130,270,390,1307,301,1023,734,215,3166,1028,0,678,512,395,263,695,595,230,392,780,813,246,445,825,489,325,499,186,550,1024,952,686,666,127,188,68,837,1230,324,459,98,556,570,924,992,1,551,710,607,582,553,657,579,1083,679,339,383,67,1023,814,911,848,581,684,253,190,536,17,910,889,610,847,511,699,968,552,269,191,555,334,2658,653,12,256,1187,836,690,1094,1144,1020,1661,1230,775,1362,512,658,872,232,1317,636,512,610,1046,501,1177,718,151,1742,107,1192,233,2147,292,814,737,637,1274,287,205,149,396,291,553,255,129,16,1188,430,1047,408,216,532,909,2532,480,439,2529,1181,470,392,964,2,4,576,13,33,837,6,781,636,262,498,2905,698,1191,636,571,670,182,303,550,1426,290,302,46,1100,2,648,890,1279,1165,84,647,67,1428,1094,189,931,13,748,1691,531,328,1190,531,498,863,721,844,1196,923,580,1376,66,552,108,268,530,308,600,425,1138,908,683,895,1080,1127,1033,2076,2802,1051,1797,1426,1801,190,127,2715,6998,4940,191,6849,1456,4046,5743,1211,8020,1631,5008,5840,15599,4915,4939,18325,8921,19159,4673,115448,677,3,2,0,0,0,0,0,0,0,13,2,1,0,0,0,0,0,106,35171,2637,420,2282,1567,1622,211,3024,1191,483,4,183,928,1074,574,947,64,579,38,136,240,96,989,572,6,649,469,1263,3245,7448,41583,8197,1146,332,763,472,343,1451,2699,2096,888,143,131,382,484,192,207,1656,5647,14754,1549,178,730,243,2651,149,607,1015,2006,33,984,399,586,75,344,651,94,885,718,212,735,150,872,1426,3817,338,652,647,1180,3687,17,4,35,889,439,3,2,2,179,130,13,0,929,980,96,575,648,1593,77,35,31,580,890,39,137,241,130,97,1292,813,485,280,292,7,650,470,193,391,479,738,2895,4858,229,20206,863,107286,69659,19208,16861,20205,26376,30070,50768,459,3063,149,349,173,206,609,156,43,1,18,41,31,25,277,275,2,13891,7802,8539,13670,13735,12118,1,66,2399,3822,10146,9388,6821,561,4,13,4251,3030,6497,13118,199,12,8080,7962,20836,3,38118,22602,106,534,20,102582,873,562,621,57,1109,107,48,29734,180947,3466,8241,2456,1622,1306,146,1714,66,58,52,93,98,174,10,44,105,11,95,28810,910,1394,107,68120,100964,10574,13169,6383,8229,146,1278,801,105,858,51,1555,242,320,311,197,311,139,129,13,103,108,282,118,647,68,53236,5619,6820,2412,4026,725,213,256,60,63201,41823,30721,17596,655,1159,1608,1305,143,882,526,986,180,2227,461,247,68,737,200,308,47,38,92,23,5,1,42541,21518,11192,2763,745,691,758,812,715,5,178,494,176,700,67421,23361,2112,1810,1492,1718,2201,581,1962,1307,533,36,6,851,55,393,88,145,89,114,113,21,93391,1027,9780,6482,1112,876,2306,1922,2315,4277,525,76,397,9,5,59,1550,586,420,536,126,1529,807,68,504,56,3,6805,44493,33684,14619,7606,4662,1535,7010,11198,3384,1487,2258,1003,538,795,1467,9,1011,36,101,3334,3824,1553,381,1980,65,439,493,307,725,7,210,1487,30,3458,1377,2008,690,612,585,1838,45,147,20545,4359,4030,7017,695,11613,5634,3425,101,281,375,1047,2982,2226,204,386,495,810,277,796,50,11,12079,5637,4971,3569,11455,6709,6198,1488,1100,4448,15,1437,583,966,3851,899,447,99,613,443,2643,6014,2774,6870,5034,421,676,3023,750,1413,406,707,2004,2269,1018,41,155,589,66,780,1,1046,1893,4908,3614,1447,556,1596,1341,1784,795,2127,2629,277,1227,74,144,5061,6958,2573,1979,759,1626,12,401,273,2530,602,3448,1278,52,545,269,8978,451,25,406,1923,694,495,15154,11035,1306,300,3545,1563,2709,13,2783,732,189,4399,8618,7480,555,201,103,157,614,633,41,498,9029,5352,1353,3884,2980,2661,1189,262,1564,273,3824,1704,935,7427,3384,1697,6161,1144,410,449,1971,496,450,132,902,788,2147,6412,2514,1683,2359,65,14,1824,1104,1573,1442,4284,252,6188,1695,2114,2612,2017,232,6,19,59,97,1199,2487,315,1278,526,1120,1472,933,994,5340,1464,880,541,1350,707,357,158,72,665,1368,301,1313,1172,437,296,42,27,2131,3225,526,467,2199,3991,5743,806,1578,924,198,897,56,1504,2453,442,1623,714,500,1342,2661,2047,39,373,963,751,1511,4870,620,1395,1487,1188,1615,988,3347,4198,1783,1047,715,402,827,557,15,1277,1412,12,14,20,794,24,261,917,520,2350,407,1027,1712,2552,2036,852,227,14,1163,433,2524,1121,35,1962,465,716,565,2459,1273,1395,25,375,4,39,358,13,2877,564,5591,11,885,1234,12,188,524,3771,15617,13476,2111,2034,1896,613,260,196,514,257,258,819,97,88,335,523,760,408,535,2871,1497,897,1512,253,524,22009,16475,8502,12441,12329,908,2629,2821,9171,4474,1363,627,2588,40,281,1043,13735,15557,11175,7381,2856,623,8957,4044,4009,1124,181,429,9668,7586,1492,1907,8653,6883,2545,1031,249,40,325,550,13822,2091,3686,3244,8638,532,8156,7245,5119,156,1801,17657,590,12621,3091,15641,5642,2670,505,260,1045,669,1203,1430,691,461,20106,1637,18635,4937,2320,1671,624,9,1066,37,2293,4507,984,42,2368,45985,12960,2770,481,2407,533,435,751,6348,4168,839,851,18,64284,38157,6225,16354,4367,973,3341,1034,67148,4726,14779,6862,4546,10033,7216,24834,63905,10873,6746,17029,3393,29616,4448,900,1774,1551,56602,24833,41561,11393,17755,45610,26286,47006,9671,172858,6,112318,34,73,252,63,282,416,39,844,1,3,47,38,1,207,4,1,120,6,29,144,24,33,3,116,54,446,89,292,230,269,5001,0,0,0,0,14786,1355,3311,4157,551,4981,7598,643,2697,1560,305,1774,287,497,6107,3899,1821,620,47,791,583,316,1443,1414,834,1215,1820,1157,236,943,374,616,667,232,434,217,466,770,1517,1415,404,140,133,300,455,995,275,1166,301,6,47,624,355,1188,726,407,352,4109,4539,19737,0,2529,784,498,2449,1886,1922,915,97,248,378,439,691,249,133,1524,962,405,157,664,352,338,628,372,33,1040,1050,818,399,74,1013,783,251,476,1742,503,391,783,202,2,549,404,625,356,239,924,1916,922,913,335,1,310,2852,305,671,2354,1470,624,150,511,394,1,455,403,247,110,245,590,902,644,1666,250,546,1813,454,814,182,1039,1811,489,781,229,441,896,778,238,888,304,722,1708,513,1497,547,670,287,498,4312,3048,549,1981,664,655,774,997,605,470,1557,188,3495,197,389,442,1617,4597,1053,902,197,163,714,185,453,1403,740,38,246,283,343,302,1335,720,371,1009,1016,1416,688,409,266,952,447,228,212,445,475,703,629,380,545,623,957,548,1865,180,345,719,405,901,1077,592,0,720,665,372,4,1202,1008,657,1318,1075,1765,565,5,663,1030,237,249,1139,1385,913,501,48,656,140,1380,540,404,584,1061,1348,308,1470,544,1037,315,62,1007,290,432,339,1108,0,1942,584,890,1727,902,368,153,4851,1729,547,246,184,813,28,452,4296,773,1046,1005,1073,3,243,160,486,334,891,0,1120,914,301,1744,1247,635,955,302,510,247,747,263,1646,1827,505,45,622,387,529,1016,1172,449,814,457,2393,1223,5186,546,667,481,593,1157,772,715,336,195,632,247,771,1047,942,634,770,782,1499,438,301,373,666,545,119,617,564,410,259,544,1016,509,769,1048,233,353,246,543,433,717,301,225,718,247,1038,229,544,1006,545,299,720,248,30,546,746,335,565,467,547,298,914,741,337,321,715,548,198,1648,692,647,510,1177,668,455,4805,721,722,299,1449,768,680,25,735,627,720,431,767,32,298,583,230,719,819,402,5,547,765,718,509,139,1238,313,235,86,979,1243,545,915,127,173,764,768,1245,538,733,818,274,717,745,763,297,248,454,1728,716,621,761,300,714,760,713,247,402,5,913,46,1738,953,215,211,930,449,1548,1547,759,246,1651,851,1455,707,179,1185,803,5070,1891,1181,480,242,1358,2084,1245,2294,395,1639,1949,1486,5994,2668,1244,2473,4407,17538,26411,13,0,0,0,0,0,0,0,0,0,0,0,0,27,30132,1705,1246,2024,1115,977,363,1189,762,1728,127,207,4,90,2178,1123,6137,31074,5342,5,2,1,2,1,1,6,10,1645,774,2171,1886,606,1286,272,201,264,3749,16896,531,129,67,737,2080,357,562,106,1172,190,229,949,325,172,47,511,1978,354,423,341,866,2011,667,53,389,1384,28,230,763,3970,128,208,326,273,2,91,440,2701,298,2199,13102,193,82715,4,34487,5185,2859,3005,20113,286,495,101,189,1172,2029,1145,570,471,560,853,6,1772,231,855,195,377,2,81,190,29,453,379,355,449,325,596,3033,4429,1951,6,5452,1899,2165,576,3110,218,119,1955,197,1734,438,135,43,689,49,15,1218,344,3236,6406,371,512,772,119,67,70,297,6,207,231,2,19,257,3342,773,712,9235,608,874,150,533,215,3,455,1031,221,250,1149,187,361,317,394,843,579,747,640,2584,774,2406,1143,545,519,663,1010,75,84,202,132,661,206,12,162,2272,822,712,691,208,189,97,204,427,939,853,980,1257,603,471,31,445,937,60,1702,184,165,377,366,127,369,441,1884,962,252,1180,554,637,798,669,3157,966,10,28,1381,1301,2633,1223,978,412,300,3434,2725,1225,586,1180,447,506,1133,137,541,1665,802,254,567,160,899,102,886,609,963,287,253,319,863,875,496,253,555,534,11,216,180,4,604,1000,210,799,1122,98,195,459,136,179,553,300,9,6,1141,534,38,407,1032,25,42,483,79,800,572,670,149,135,7,786,222,604,782,900,208,772,964,823,1901,232,365,858,325,378,1287,155,295,567,9,533,753,325,378,100,1,8,82,463,771,188,191,294,28,872,1,326,360,787,149,318,1,7,6,400,0,1259,925,713,395,354,185,141,338,1258,505,310,578,221,92,13,797,800,1273,506,194,0,147,600,595,963,2594,268,544,8,267,323,712,487,1348,667,19,10,1382,222,3149,303,2853,2721,1219,2160,554,670,787,375,1489,316,84,11,15,0,16,1,2087,408,1279,251,302,692,722,387,306,457,1206,413,221,5,299,302,603,5592,1251,337,3820,683,3124,1840,876,198,2004,1918,992,464,14,75,112,27,2747,334,6857,533,2841,925,106,886,289,1031,4,2671,1135,118,293,519,54,530,3899,356,1092,377,221,566,2044,2545,6,28,749,335,575,1259,339,929,826,8127,874,3789,287,114,365,965,199,4798,4346,523,4,198,12,0,1074,529,982,809,1539,42,565,693,721,347,480,1692,4804,730,646,1093,720,1235,7135,5891,78,209,792,898,873,197,1132,0,832,846,1657,492,1171,200,1564,580,6248,3309,98,726,8,711,791,100,294,1142,931,76,1390,134,362,414,2494,44,1870,234,1388,1362,3484,376,1086,1256,610,1493,115,26,233,722,1486,479,1053,5455,201,1591,4117,1286,5675,2990,5,51554,230,1988,729,1116,29,28,301,11,141,265,619,56535,26041,12292,485,1477,2036,2333,1098,2135,1140,537,31,1,31,146,66,985,575,725,217,15,33419,16101,183,3113,4587,2332,2086,119,420,140,80,155,62,9,37870,906,3675,6771,5371,4706,1690,742,648,153,257,123,29,375,2,186,121,32,5603,12075,13696,14533,12643,7496,1103,419,432,56,352,492,26,16,10,31,1283,980,1677,1267,1259,533,3536,9179,3653,2195,150,25,98,32,11960,9109,7118,517,660,439,20,321,8,180,29,34626,10516,2513,2102,607,333,54,315,43332,15681,4484,2075,154,1139,455,381,498,219,217,399,151,11,180,219,35,130,377,52143,12720,3295,203,1298,613,305,1472,966,1,7,8,806,48,161,686,394,425,48,14,292,313,342,759,1167,42797,8348,3728,4413,532,2868,1815,319,315,922,11,1692,251,1187,82,267,11,423,200,161,283,344,130,505,540,995,1066,1099,18399,5267,10700,11,2126,6936,722,1141,297,583,780,2137,195,203,1911,204,594,371,546,345,460,1281,254,179,2722,423,793,619,3126,1792,6119,6490,816,1884,3459,2214,692,1527,2063,586,154,242,228,671,870,12,1034,1181,354,1436,195,138,802,823,4005,57,1825,2381,823,1172,730,559,805,1355,565,155,618,85,264,96,3000,7610,535,2289,313,1702,455,1252,845,1296,249,383,688,139,33,243,720,1216,110,436,820,1048,3159,614,815,58,15,3391,1042,415,742,1144,560,332,306,1444,320,206,302,118,4236,2633,1304,612,2139,1490,2032,803,178,446,1031,3,1001,397,1056,248,597,783,302,964,183,384,298,2008,2465,1292,646,61,216,195,705,124,895,688,477,262,556,7,917,1400,1160,208,1708,946,502,1848,638,464,466,676,144,425,528,630,464,507,306,412,5,169,578,459,223,304,123,1770,926,1199,667,615,353,298,677,794,1510,15,981,301,296,334,8,323,48,2683,51,499,10,728,903,2073,30,545,857,374,1233,1040,249,968,1100,1146,1256,1298,1264,804,924,370,671,236,1034,133,752,469,215,489,496,548,261,663,1049,618,1250,489,609,1145,498,802,194,386,212,319,960,145,564,14,84,927,75,528,1346,816,395,315,445,47,81,241,727,1404,595,465,5,1360,337,1279,2068,845,312,446,738,884,1211,4,652,902,46,1144,648,1532,203,13,803,980,495,835,218,490,503,1085,630,1364,1063,665,825,188,778,893,1228,1368,78,371,1001,493,152,1362,152,228,1047,1043,258,650,1156,875,1593,422,871,349,129,1243,923,668,1981,1265,331,900,755,607,2048,578,1170,305,791,2118,366,1686,1099,2005,1911,1001,2530,1742,452,319,447,1442,1082,2528,514,1699,191,892,865,451,3575,2730,1600,695,760,495,2144,1069,5607,3028,3695,9925,3969,3208,4380,3296,896,1,4581,10252,3188,19759,12971,78108,29980,156,63,33,12,14,11,0,4583,10,0,1900,561,872,160,533,786,109,1136,23164,232,1801,0,62,553,309,73,812,2,172,848,807,110,1218,41660,3017,4368,1778,140,638,10265,798,1875,2007,5997,671,6496,15047,6311,16,78,42,94,234,79,1,42,1,1,2187,2417,1023,910,1235,7365,1017,1614,515,2337,3221,4923,11565,1490,10,867,1926,675,85,451,242,969,39,1698,503,1411,323,41,1374,1817,466,9,399,683,499,704,448,84,25,568,141,344,637,136,872,224,806,288,1340,5720,138,3816,9275,1388,730,2264,788,8,1420,287,805,1868,120,919,666,836,4335,140,3062,5908,8904,202,3328,5294,119,27857,1078,87663,12,5,1855,705,178,42,325,913,553,7277,60,795,19,759,601,657,19,204,569,224,423,222,624,99,84,457,337,1151,24,803,730,10623,33869,1937,0,0,235,14,98,184,320,282,719,58,421,224,25,91,64,149,43,59,236,271,42,229,797,136,433,118,21,463,485,8,0,111,389,139,69,491,2227,3800,100,0,97,7,61,791,7,1,20,483,384,600,656,20,228,203,569,165,135,59,424,164,223,475,149,558,390,98,83,456,476,220,611,585,25,246,1338,1053,17619,267,66624,4,110601,14995,12318,3958,3184,2273,2814,2539,7809,4769,6301,2680,1962,713,36,125,44,35,56,40,56,33,24,151,200,166,174,2,2,23908,24527,14959,3357,4836,4138,5075,12148,6110,8132,1590,1634,191,347,17,9194,6620,5218,432,1366,6276,4039,3360,2146,322,11,12030,7770,3444,1346,5050,7598,2886,4913,58,702,126,150,71,11152,2806,1319,2217,9821,6776,2062,1004,480,5499,2682,6504,9575,2765,3667,46,784,3432,8478,4522,1101,569,3392,7512,550,1107,975,6,16255,6120,4066,1411,904,610,206,59,46145,28472,8080,1646,199,528,270,53,282,16,11,62751,16221,4336,1120,324,29,31,33,8,48,21,95029,23169,5385,211,208,236,145,17,254,40,254,233,453,93,33,159,414,4,115790,82,9064,689,1219,1568,110,129,348,273,301,111,55,11,139,98,297,10,10045,103518,4072,910,4134,4781,8178,4471,1431,831,991,561,474,612,655,727,40,56,712,35,20,230,450,163,511,571,309,1387,578,136,9878,261,200,10000,7668,16967,26453,26571,9749,3683,5445,8130,1259,1204,1635,1592,2068,2618,1402,450,77,143,6,1034,426,832,180,256,1284,490,22,1474,5122,4125,904,361,338,870,94,1019,2580,1032,4531,1832,194,240,280,73,10217,7322,2574,1841,212,524,637,203,6,390,25476,10943,2233,325,2289,943,898,143,246,1729,407,219,529,1822,20,553,241,650,348,37126,6576,7122,2995,4311,1264,1606,3649,2651,2671,684,1339,545,760,1024,336,833,394,37,2177,11,307,9459,8255,9022,5386,5684,5840,6064,7322,406,1468,2262,54,1350,123,39,1070,46,535,180,1464,31,10,3187,1370,867,1031,3229,4203,1108,2090,1565,1920,214,168,700,732,230,67,885,871,1147,253,410,137,149,6708,2464,2416,2380,486,702,2166,1134,2057,529,2081,1040,549,353,928,521,578,36,4312,2155,6972,5420,3495,1533,1261,992,518,2175,273,1053,1143,816,23,41,1779,2643,4957,4019,1843,1215,370,173,47,387,702,493,173,944,336,41,307,1261,4854,3648,1814,1754,899,1993,971,8033,8898,3330,266,1215,1148,1279,157,542,630,608,372,41,743,31,13805,9207,2520,1659,3088,721,1827,3051,1337,1283,524,399,336,1939,31,13,13722,8239,2966,5906,1220,5313,2302,2733,2257,566,263,612,3798,173,383,575,641,512,5625,4048,9656,1609,5013,1960,2769,2178,340,603,614,479,518,309,4109,1867,26,2284,3245,3092,2358,3899,1182,3746,1235,815,1635,588,2441,5,508,34,1464,1406,2694,606,4005,166,567,1812,798,272,2324,5215,6698,4487,2593,3139,29,328,713,2421,1287,1846,1411,900,369,80,4332,681,3043,4612,1287,1367,818,1595,335,603,12,6500,6739,2844,1545,504,584,709,1247,1500,2473,1645,3783,406,1273,2013,1969,452,45,183,5935,1691,2088,902,2050,3158,759,631,5267,653,560,907,1213,70,4386,4896,719,103,796,2772,793,1624,1606,712,662,12283,889,447,2842,955,357,3203,2345,1122,421,314,1137,789,1705,897,844,15049,1668,1369,948,707,1392,172,916,1985,994,356,7674,339,1757,4,473,1543,505,1101,949,1071,2882,512,602,1223,91,741,1117,1636,4359,708,2910,2060,298,604,814,5739,569,3854,1368,765,758,66,1248,2336,2602,1118,6201,922,1540,819,694,445,693,478,7175,536,1813,38,567,6895,1117,1187,896,2630,1227,308,3826,335,816,813,827,3869,4853,13367,14444,71969,1153,741,570,1312,787,4542,2485,1881,2325,4960,16601,190,582,1821,499,21435,3653,1618,5545,1145,26268,10069,11262,64734,32887,1136,1217,17059,13057,777,10388,1443,13322,3255,122827,106878,1075,324,222,4,292,3,276,13,51,9,148,25,77,99,81,4,3,5,43,6,3,8,9,3,24,2,32,32,208,354,18,337,91,435,0,0,0,63131,10751,4248,547,499,439,2056,2179,101,1271,2372,549,201,132,2733,446,375,3,2643,216,356,253,318,616,81,1210,1287,396,235,76,203,210,266,151,293,80,164,33,97,226,528,586,2016,81,346,0,16214,5386,1392,2462,354,2418,8468,569,2521,6997,788,473,587,405,1110,287,1502,527,292,807,708,602,352,1121,416,420,331,222,329,239,783,59,455,8,283,260,315,391,820,1447,169,81,543,0,0,2340,1400,1847,1277,4734,1764,4368,758,1565,209,539,489,1624,1025,439,353,311,183,7,354,38,181,189,195,574,295,137,0,304,466,1473,2203,1800,175,1321,589,280,387,1231,72,595,191,304,368,304,99,6,822,568,1333,215,420,262,9,1259,1007,416,5,274,114,911,210,320,274,353,450,3119,679,861,200,465,416,360,113,11,85,3,786,1209,4630,562,677,91,1695,1563,602,293,1653,1928,1931,143,884,1053,1592,533,162,363,85,89,374,51,56,161,0,212,1032,785,209,102,2,1990,2658,435,444,1245,843,1243,202,232,56,129,243,551,1122,2667,62,790,1189,6558,2163,497,354,3381,637,1369,492,310,2,110,189,3,225,185,75,22,288,464,578,181,81,1483,557,2235,191,351,208,174,678,417,202,550,472,784,330,92,14,734,1507,1985,891,214,1380,495,1531,1204,776,670,221,316,2,192,0,225,593,193,48,0,549,1099,388,1296,3,555,485,2272,143,449,8,61,355,1954,538,551,434,598,46,273,84,263,81,647,572,694,789,1053,109,179,380,24,1113,1188,495,1553,18,26,76,4090,1296,1377,1183,3866,3756,4412,2220,701,272,317,464,306,279,783,366,701,29,0,0,1863,1094,5011,3459,1173,942,329,143,18,538,1186,1247,489,268,145,80,213,357,1265,1324,3095,506,423,99,275,152,3,1123,3793,229,544,261,554,693,10109,3162,2943,3010,1124,201,266,610,1,176,45,166,370,656,578,83,369,90,110,0,16807,10814,1693,1223,672,460,583,312,59,283,845,492,6,339,1,59,433,214,342,560,943,125,15541,4581,4237,1629,492,1004,140,142,544,189,526,510,332,260,71,797,42,80,0,11385,5297,450,348,2354,203,549,383,421,161,142,617,581,148,1425,1620,310,41,197,260,393,1357,1278,1219,521,405,2341,941,3026,250,311,0,0,12199,519,221,569,593,584,786,458,542,164,1353,199,220,431,1071,1935,290,266,61,0,1295,2907,5158,397,1585,1020,466,205,779,354,740,538,948,671,691,377,409,1904,511,348,2092,1597,701,672,792,596,576,4,402,764,107,560,132,428,0,549,331,447,736,753,553,491,603,346,1792,1073,671,849,351,565,2166,529,379,79,345,396,494,200,1169,582,688,139,1,342,190,1000,386,1176,344,313,270,313,378,75,1019,204,204,60,345,267,202,463,330,222,493,223,384,570,141,100,261,21,1018,109,587,1083,527,546,465,420,305,317,57,585,162,7,141,534,341,1,670,848,616,189,791,526,507,758,39,199,272,792,778,287,443,648,1426,595,344,352,260,791,674,8,238,362,292,493,492,203,20,782,79,797,350,91,1017,457,419,530,777,564,188,5,453,545,422,541,832,350,167,58,6,180,444,858,1016,1501,1523,278,590,23,8,544,537,316,23,163,521,615,259,175,9,2,947,56,465,670,1,309,1175,108,690,40,3,717,569,539,645,1399,1423,748,408,196,0,790,1645,220,501,563,1523,398,7,1238,244,197,2350,282,291,329,58,813,553,576,219,2606,1051,501,4668,2071,5691,2145,2405,157,1587,6866,5229,3000,410,21,2998,3352,4814,82,27819,9581,162,638,349,55294,1388,614,31895,49866,14640,0,30007,2337,82833,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,38,6639,4194,3949,540,700,495,2874,281,11543,777,361,99,521,209,269,955,127,159,154,17187,541,184,348,602,138,7,222,343,512,378,721,1435,5916,15104,4547,1,2,579,349,662,172,1645,446,357,166,1532,760,158,283,743,191,2157,393,139,117,33,2455,1004,498,334,420,210,161,159,702,284,350,496,1678,810,393,282,7005,556,941,1495,4650,822,535,185,234,184,179,100,716,208,270,695,262,126,158,155,253,823,426,374,787,910,59,1887,11238,15414,2003,542,185,254,824,1,427,811,347,603,137,6,670,693,250,373,786,910,203,307,377,825,58,358,558,451,273,1204,5319,553,24136,2220,73751,68274,6395,4295,4101,8534,2828,1915,1341,542,3268,1938,1703,1735,2360,2849,1185,2455,16950,7,3991,486,2500,8680,13686,57,652,156,113,70,36,40,62,28,10,18,149,37,112,250,1,9400,5347,5143,8388,727,2042,2027,1093,418,2056,680,1170,388,504,14958,1982,1728,289,4486,4842,415,383,2756,1122,4050,844,546,1545,1102,143,1588,130,724,497,789,2717,1834,159,598,687,995,4654,218,552,6,1,31,1985,1183,431,560,298,610,4314,223,149,2203,990,290,2378,361,6,879,1437,1262,4393,1917,1195,346,3320,881,142,120,3250,505,803,1662,426,728,6,32,360,4,828,809,1996,1446,712,32,13,1619,874,410,1042,291,232,1039,146,547,2740,1117,1425,1170,627,719,3065,1559,369,1627,1800,589,815,117,807,536,1387,536,2132,1903,1704,7,682,326,143,1362,781,2126,880,499,426,2641,801,2021,628,1906,3489,1339,630,955,437,546,887,4309,691,26,3566,1188,319,10547,2317,13821,19263,19661,689,779,582,38,250,92,1,312,9,8,2828,1173,4629,6960,6987,253,1830,7165,2465,728,27,1460,252,13588,12816,508,1136,185,7,74676,1405,1445,868,53,30,131,43,105,74,78,2,13,11471,32624,76554,10940,4402,8548,349,955,742,744,462,1379,453,20,715,116,326,204,2,722,105,42,603,3567,7019,234,337,333,31578,3527,1568,982,125,230,4,52,775,56,790,71312,11410,26029,840,1753,960,639,2229,1840,889,725,201,26,470,105,417,334,22,25985,34107,4072,2576,3395,3661,3094,3231,1875,1183,84,510,276,472,695,653,21,287,358,279,502,106,667,28674,3475,2860,878,2261,1789,2073,1200,398,8,98,38,38,39,26,249,21312,14390,7611,16162,11955,8893,6362,1086,1525,414,1077,417,159,359,504,338,438,1016,534,275,16,952,40,752,870,959,692,233,6103,2287,8068,4005,2942,2891,251,127,4,887,116,1516,126,252,298,58,448,4985,6997,6430,4445,2611,495,164,177,1069,578,3,37,541,296,132,3444,7693,1458,1844,496,879,547,866,1414,301,12,1105,827,12613,8541,13957,874,59,7,1008,1043,555,125,171,1626,389,673,101,165,211,23,16238,19435,2525,1383,704,1286,463,796,1149,90,431,391,647,370,1540,612,732,672,159,12,355,259,26306,4028,2413,1186,1601,633,209,3600,2797,1674,555,1872,551,37,14,57,1826,540,164,962,12111,4533,9158,1954,2626,1262,1186,14580,10147,4418,1965,954,3066,961,816,2,484,853,584,1008,482,3407,441,582,875,610,4941,2207,1274,1013,481,5370,2645,559,2179,501,271,817,1211,283,16,709,54,4898,736,1179,1311,270,939,1000,888,1660,651,1279,614,312,239,5554,1295,3236,1870,3941,919,2045,884,1109,112,150,238,625,859,1764,1158,12,250,1184,65,1950,2325,548,585,1705,728,649,944,2582,593,1010,1199,1016,823,714,1393,15150,8805,377,185,4840,3084,1755,243,127,274,176,85,14538,971,511,12682,9527,1708,98,952,976,245,730,1691,6412,17901,868,6405,1909,1559,694,1375,547,1332,39,882,881,534,5027,2904,402,250,386,1019,918,89,300,737,872,510,227,1445,779,1922,33352,5327,2816,822,1454,782,4232,7,1520,774,1691,1688,590,889,511,27390,559,8183,572,9457,1333,1113,280,5882,139,913,1262,495,9175,1644,4890,3903,1104,7476,826,356,3169,1718,1599,2136,2919,5340,5715,1099,1541,879,586,652,389,1421,372,1,483,1108,749,5475,988,570,1677,270,2708,726,46,2224,1178,4599,1700,823,1547,1064,1095,1184,1816,2642,283,1779,3325,492,824,3044,6928,273,1438,5846,1552,7948,692,755,1018,2525,1099,440,1421,1721,770,1306,4793,570,1447,1081,1859,120,3788,1034,2568,390,1220,493,754,4286,4012,604,901,10936,2796,1766,16838,8250,12898,3809,1246,9547,4446,5068,1677,5760,2576,3598,755,3963,28963,27094,67984,68883,1601,199,609,56,308,47,104,628,79,61,183,2,1706,47,242,41,28,119,386,219,41,3,142,128,164,232,158,307,64,495,645,188,658,27,2060,0,0,0,0,0,21507,4168,2709,1229,1345,994,1159,743,1336,675,311,174,1423,2662,1031,1462,683,945,4,7504,2062,561,335,171,208,99,214,386,179,148,46,148,142,292,407,180,0,134,60,648,367,314,1045,466,659,419,677,870,706,738,829,578,1945,0,209,3059,292,1009,1024,356,490,503,496,1118,944,754,418,7682,315,376,490,274,340,236,90,185,411,268,655,440,69,518,410,288,503,234,257,580,62,208,527,971,184,328,15,309,432,301,586,755,711,644,1079,268,935,143,228,234,50,95,308,451,504,275,80,210,54,0,343,769,265,433,70,107,799,600,340,1195,96,83,355,289,587,541,489,551,65,454,470,131,307,42,224,408,876,540,401,457,133,91,306,168,600,248,488,201,108,103,406,212,1246,787,661,172,157,2,197,244,203,75,0,308,244,337,1019,2529,629,3,211,352,76,967,741,1264,354,377,167,500,63,61,877,312,487,434,143,934,1775,434,341,100,184,2085,234,365,589,943,2116,250,419,227,1,526,3,458,1529,2052,807,268,792,361,229,807,224,390,1269,614,206,1399,121,174,368,225,423,527,388,901,268,264,717,177,1141,1130,793,1612,406,3227,3092,1421,1520,1444,2995,897,287,338,169,344,203,274,792,1072,311,94,179,260,817,539,220,453,433,254,248,336,130,514,137,758,410,297,563,286,760,486,267,334,48,479,165,149,170,377,360,478,241,0,420,230,209,264,274,432,98,304,501,265,215,342,353,225,491,42,339,391,934,538,335,156,735,337,273,273,219,419,29,177,452,239,390,303,935,44,118,145,47,102,77,56,205,176,328,164,339,400,734,592,147,760,487,338,154,217,434,185,69,320,235,296,200,500,204,147,120,431,337,226,173,229,253,437,218,5,369,431,247,334,406,179,224,733,52,451,178,12,6,207,430,257,217,759,164,54,5,562,1072,267,89,503,526,233,238,341,133,225,97,387,264,186,712,175,934,429,13,127,184,525,267,696,263,285,59,272,232,555,435,229,394,583,864,563,1194,409,107,1,295,75,389,651,533,393,85,1081,943,639,217,179,194,189,611,361,1028,951,695,1496,210,298,0,845,908,1805,752,133,455,505,1842,1450,807,150,808,2200,131,172,3123,2090,460,2120,991,414,7387,2918,3277,3259,636,3562,7245,7462,6802,1776,3153,5076,6931,1605,2511,0,13943,3475,7529,9125,31851,18395,28,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,3,27,0,0,0,1,411,259017,120,20,8,124,984,138,2301,15,474,180,87,67,76,63,102,45,49,27,56,8,228,3092,4132,6,18481,83121,90,66,53,147712,2721,341,78,107,97,40,4421,2578,18061,460,86,82895,190,73,9,91,67,125,54,238676,9698,112,76,238343,246909,28,108,26,19,251,214,376,7,124,159,56,63,77,54,7,2656,1736,1,0,3,10,12,15,2,3,116,159,242,515,0,0,0,0,213,461,89,3,0,0,37,77,46,0,65,146,50,122,132,103,57,106,78,108,103,28,55,9,216,127,564,12378,12801,819,1086,3015,2225,335,79,312,1014,1758,677,3,480,2,21,392,502,387,490,318,223,114,109,1659,1512,3428,3776,4320,6402,26,297,265,334,169,185,110,422,247,11,307,73,100,11,19,7,71,20,15,143,11,134,11,28,174,117,16,109,1273,150,713,1651,327,374,91,445,895,167,447,178,4,1015,187,352,1441,1735,1424,548,347,76,91,53,106,77,87,142,84,362,183,117,187,653,309,258,195,57,1,149,672,198,3,163,354,4,754,615,1242,758,11,194,9,90,169,1259,742,505,886,388,10,160,257,6,267,109,4,199,5,92,73,112,165,38,756,298,237,772,96,93,187,235,123,292,263,314,264,238,546,678,4,108,60,231,85,124,3,14,9,145,166,4,250,43,460,167,293,356,198,185,4,237,654,91,50,285,215,3,3,73,166,152,115,110,3,2,42,635,1364,1509,201,580,9,50,0,138,3,8,0,771,1434,1674,613,69,3,56,3,3384,2192,3556,21,227,26,89,174,183,86,162,5616,5751,212,163,78,504,144,416,211,104,94,90,12,245,79,207,455,15084,211,272,130,467,239,316,269,529,625,186,145,393,363,283,1157,1369,1909,3862,4364,744,1115,3844,2890,1489,1676,268,875,3349,529,703,165,898,119,194,371,563,253,463,329,441,215,554,145,56,1313,1140,24,261,212,10,637,18,174,25,252,66,23,802,730,263,284,162,4,9,267,162,167,29,179,15,0,101,236,130,135,87,142,32,180,217,64,18,47,129,23,75,201,311,106,74,137,70,1324,254,569,133,1171,390,682,27,198,408,7,922,62,197,20,75,1112,1591,953,631,646,25,512,585,289,332,96,336,13,188,98,177,59,747,242,74,429,231,207,180,855,641,526,273,266,133,123,244,223,90,296,87,199,1332,1851,252,284,506,1374,500,274,263,1,132,272,96,21,108,52,332,332,886,233,917,1249,131,1213,140,88,148,57,622,609,158,464,142,91,214,711,801,291,794,1884,855,504,5,202,9,184,99,363,194,577,773,1301,129,22,448,161,4,312,100,175,469,11,2,5,228,310,747,515,295,579,292,26,97,204,2822,314,752,246,271,238,184,108,211,24,182,742,0,1519,2738,2103,684,797,307,149,210,319,30,233,201,316,51,255,230,324,631,258,97,509,217,6,969,1695,2088,350,125,141,194,112,179,164,65,868,281,488,2825,479,349,17,73,1038,5,91,413,238,146,507,206,676,217,68,546,321,401,1244,314,477,111,49,364,67,76,646,141,90,211,2490,1475,124,124,122,105,237,447,139,339,110,625,1697,17,3,331,272,20,130,264,754,71,257,838,1,72,9,112,407,162,200,239,3,193,224,144,557,195,319,365,72,103,66,727,690,238,232,129,99,240,4,77,123,200,148,182,111,182,378,422,70,166,183,77,174,163,131,75,228,376,107,71,747,130,252,254,122,69,121,140,413,6,263,466,550,368,357,1245,470,507,91,5,339,2,365,72,1249,158,10,88,644,200,1607,1095,177,122,229,2153,263,167,840,65,1723,2948,245,90,183,1492,549,210,656,253,457,1547,87,296,2499,904,1458,3035,775,1734,599,168,16857,19865,538,251,32,927,105,71,90,37,3,49,102,478,3,122,148,423,116,502,89,96,370,25,2,177,175,40,69,83,57,51,218,75,93,403,216,46,82,91,84,14,71,612,540,2462,0,0,0,3123,184,393,1680,671,1123,1804,46,147,48,177,886,91,209,687,180,646,507,410,321,58,146,247,177,79,221,98,767,23,51,305,198,77,34,542,148,78,157,400,48,2270,0,0,122,753,649,103,400,104,61,168,76,113,139,166,54,49,61,610,0,62,183,121,73,117,61,77,314,31,4,243,797,64,352,80,161,67,229,97,210,333,126,78,72,155,502,193,2,553,8,91,108,228,231,410,247,282,157,51,84,192,88,70,138,115,341,101,474,49,266,191,443,100,112,445,310,76,526,36,45,146,2,246,48,47,1,281,101,62,113,103,16,59,298,217,259,92,63,146,375,0,90,60,112,227,354,155,52,355,2,100,351,167,123,138,160,120,173,67,113,181,102,61,321,118,159,60,181,350,354,57,145,50,170,115,121,8,58,223,141,38,113,304,291,84,117,313,114,1,274,149,75,72,169,105,333,171,98,118,244,216,54,58,122,69,132,15,158,164,127,83,229,112,113,59,398,24,111,223,116,312,466,134,89,34,231,130,100,157,240,153,84,129,119,409,67,67,112,165,172,114,330,0,117,78,46,294,407,91,56,116,133,391,50,220,140,165,97,349,33,23,353,477,59,232,175,308,131,1022,42,22,53,52,162,71,99,506,89,377,239,98,51,149,115,53,395,409,830,66,197,452,76,294,122,975,75,354,674,188,128,231,802,1172,261,293,726,113,143,146,400,850,239,1155,1108,3637,5214,15,1,0,0,1,0,0,0,0,0,0,0,0,1,104,10367,1093,814,619,253,1334,71,169,359,463,68,57,165,2609,310,256,7,924,194,375,137,774,200,57,13,884,1354,1637,8462,25297,3702,1,124,311,258,508,597,207,207,3511,4562,139,527,695,143,674,620,254,1650,327,528,171,259,361,464,69,56,164,145,1322,1409,247,309,257,8,596,924,195,146,206,374,136,619,773,198,58,260,14,870,13,386,975,10,1051,1399,74,17159,689,59591,79115,3677,2591,3716,1296,1337,827,786,3080,2984,460,232,904,32,2990,724,95,1288,264,623,975,4424,9140,241,782,2260,1175,28,515,1164,34,180,68,474,134,33,91,70,299,10,330,518,7,38,140,64,23,637,9840,5642,1546,2378,969,2214,515,4101,7592,523,1323,2975,3151,2672,3305,1407,1663,2353,7572,327,8736,1803,4812,164,420,73,469,15,188,98,403,215,657,463,789,452,964,1060,2958,770,1288,690,504,991,1271,521,17,169,1002,318,1166,286,1092,139,773,1509,1136,289,1175,6,19,1502,154,2000,660,398,488,1371,168,1395,146,1522,202,20,728,390,394,274,409,453,21,477,963,169,1917,336,793,3,516,659,1106,777,4,908,8,275,2048,729,938,93,268,183,883,205,1794,831,350,278,9,1958,1522,96,1449,2108,201,520,1521,357,608,1700,6075,198,42,787,731,1959,776,141,81,465,1973,253,790,2441,125,366,665,885,24,8,147,1428,732,510,97,637,643,384,1128,1114,1557,3672,1090,819,9,454,18,363,239,1294,3738,3788,220,722,203,165,13,82,345,650,1247,271,459,4679,5,1065,15,202,1895,772,4,73,24,1970,1827,1248,524,2321,886,1367,498,582,1137,1850,358,546,55,5096,4224,239,930,542,585,12,23397,577,4712,1234,98,585,940,141,336,834,143,321,6,137,450,1213,11,2513,19560,34780,9993,1686,4235,4333,1127,498,185,559,785,1352,264,518,384,7,166,83,127,509,339,235,1979,593,3,184,14491,4562,2310,3345,270,1550,6,546,312,295,909,208,26660,5011,16675,5717,2617,2219,500,10,887,204,55,22,582,2805,1264,193,580,329,91,29,742,11,585,13,839,51,2229,14123,12730,290,157,8455,1495,470,590,1976,345,2,4,3522,30,455,6,368,3470,3996,893,94,116,333,1012,1006,449,6,29,172,19371,3290,4934,4038,140,845,333,1196,538,1100,685,396,1017,3332,1569,726,29,55,795,125,2126,758,10377,9185,392,2730,3077,1305,824,1524,216,547,853,9187,1890,1382,168,929,42,366,440,273,35,2,391,228,2133,289,142,27,1939,1186,179,527,448,156,9695,1012,942,6093,854,1252,1419,415,472,1989,6069,610,991,279,470,334,19,2512,2328,2930,5404,1001,3411,655,8,714,310,7837,766,1285,248,733,456,227,345,526,706,1970,543,141,289,1261,1433,517,186,816,883,16,2828,496,3624,828,1659,1478,79,178,133,470,95,3133,1300,559,1649,252,211,838,6817,3632,659,1015,46,645,277,1345,487,360,102,539,1332,121,2648,1277,205,160,458,414,797,24,92,605,973,11,63,12314,885,394,214,540,574,1250,278,6,272,350,4426,1034,277,587,613,38,1522,1467,251,1810,14,2320,272,265,33,5959,1548,581,42903,500,8895,3485,3113,2755,3145,747,312,545,318,2202,14,733,603,1488,1728,1433,0,1794,19930,14354,6423,2837,1877,2364,588,208,789,9,929,1756,323,2045,288,309,33,2891,2007,1817,1449,498,11653,6051,5062,3392,677,2390,532,2141,184,517,78,794,25,354,1525,1971,7506,9057,3431,2314,278,539,25,5,6,1147,700,271,286,5,1429,395,3200,1351,11342,1436,1441,624,263,627,540,469,614,1603,1788,385,2074,1938,14244,7742,1551,1153,230,269,585,464,155,38,976,897,533,138,45,3965,1519,8196,3319,216,1731,1274,352,653,288,709,2920,1049,199,95,3250,3478,4569,3256,1615,2438,822,218,1420,1937,5,243,924,521,189,4170,2866,2087,480,559,539,329,277,125,1006,366,30,1536,392,5280,1124,336,1013,544,645,430,564,11,239,2854,426,191,857,847,197,508,463,24,828,120,646,396,1092,1104,927,558,4,721,8,531,839,439,196,538,445,1720,1756,1317,782,520,855,3611,406,6531,2200,644,440,446,1034,806,407,252,2514,248,840,786,1615,456,1105,1958,401,739,364,936,1406,1036,1795,1596,1442,599,10,611,1297,5099,1716,9,202,1999,473,3471,1861,290,4,1858,611,971,730,6464,4868,1104,1307,12759,7592,4488,2107,1347,2288,81566,59744,637,303,100,7,100,6,18,323,97,28,99,168,147,146,144,228,48,41,77,59,15,136,6,25,358,83,44,212,86,143,8,54,222,45,663,512,2847,0,0,0,11885,1849,3932,1572,1253,874,4034,503,507,3114,1746,517,997,159,237,263,2018,248,384,428,1270,642,1636,80,166,197,452,140,93,236,125,324,162,497,173,684,174,139,413,404,435,283,402,515,683,146,2177,2898,6731,603,1579,936,1416,125,764,561,114,571,976,401,217,87,104,503,113,84,0,307,213,101,348,560,1776,281,343,305,653,157,744,0,168,95,198,95,1085,1306,830,280,656,382,295,242,311,187,3,341,1011,581,281,260,98,111,86,269,98,342,566,307,148,57,73,345,231,253,41,802,67,534,336,826,353,750,236,77,577,167,196,9,433,136,358,786,777,913,608,428,200,0,180,4,508,19,405,181,423,1373,66,195,5,44,216,81,124,1005,986,558,336,352,211,404,532,475,228,763,924,452,339,91,1475,122,182,473,169,222,180,395,186,455,113,98,194,160,173,210,236,422,427,89,1068,258,570,496,329,98,1037,300,550,601,626,212,472,269,344,650,681,516,248,555,378,110,396,767,16,195,278,626,1210,667,372,217,300,182,145,65,61,300,247,90,153,301,173,59,281,208,342,1150,373,143,155,600,427,216,655,92,259,328,153,112,759,532,394,125,137,170,88,171,197,61,163,56,213,204,571,169,96,185,195,103,1003,99,139,429,333,258,194,282,40,79,4,507,294,767,78,476,201,193,282,198,270,91,216,504,238,141,358,688,121,672,368,1248,232,686,114,126,231,14,218,229,423,83,89,127,301,135,228,94,329,515,309,90,203,483,247,225,274,45,1970,198,300,173,339,368,699,339,63,300,654,217,300,1459,9773,1,97,823,373,259,246,570,648,343,483,42,1356,1716,3240,0,372,230,213,652,178,328,258,77,160,395,168,167,412,336,379,448,1006,184,402,514,195,187,1276,1541,299,197,7,236,298,321,747,953,200,183,1668,985,398,428,426,732,1380,565,1128,376,1892,1855,1330,191,1387,1231,5976,7773,26177,84,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,6,2648,458,44,9,36,11,12,2,8,30,222,2240,2897,397,150,520,139,1199,293,446,414,45,155,157,10,521,38,159,453,12,10,7,0,1,6,0,11,38,802,135,6,5477,2,4825,45,159,71,619,926,327,22,81,903,24,219,126,58,101,36,4,16,9,141,143,43,12,26,7,153,83,216,135,492,228,156,18,83,153,206,49,713,181,181,4,33,12,1,23,65,34,3,56,302,5,18,104,32,162,68,1,36,58,6,168,20,48,92,48,26,98,3936,12,1461,1039,487,21,318,279,31,28,675,16,5,64,448,46,1463,160,5,68,673,792,1040,23,375,1,1,227,674,179,2,793,748,328,5,19,180,37,46,904,25,1041,220,127,31,488,22,4,102,35,22,3,26,14,10,2,159,5,2,1,1,8,82,32,144,317,1,44,4,0,10,1,9,126,0,30,66,0,6,71,1,0,3,16,12,2,38,0,0,29,0,0,278,10,158,38,118,3,1,58,4,4,70,32,0,18,0,3,4,94,10,0,157,249,189,0,318,6,120,30,2,427,6,22,42,0,0,154,319,0,16,43,188,0,12,92,50,2,2,2,212,1,14,1,18,2,22,125,9,20,60,8,95,1,46,29,186,44,29,89,26,27,133,199,36,12,3,52,5,2,1,11,156,605,47,32,38,149,34,9,11,92,14,4,158,279,127,5,2,20,4,26,15,66,0,30,32,2,12,48,11,32,2,101,2,11,40,90,55,0,320,92,18,46,19,92,119,0,33,1042,21,3,299,673,375,901,101,1199,618,486,792,239,672,18,13,21,374,91,15,300,8,42,13,900,19,52,51,148,110,1041,13,160,37,244,31,4,67,50,204,319,671,223,145,0,617,318,36,632,27,0,791,616,1039,385,670,792,34,317,106,0,1561,81,327,1930,1806,97,1505,92,3853,5390,25,79,8,49,80,13,22,118,33,8,64,34,28,46,38,2835,0,0,0,0,553,374,309,62,396,522,192,451,59,107,2185,160,337,71,78,373,9,308,30,84,395,79,12,77,21,521,115,31,197,394,527,33,813,86,119,1043,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,1724,390,107,1049,5965,221,133,54,10,2,143,27,191,78,54,1,63,75,71,106,263,239,4845,4793,2,68,746,137,24,93,72,393,219,203,4,187,108,463,123,69,44,349,82,286,481,36,43,100,86,114,96,51,148,197,3470,2384,287,637,199,70,97,38,92,4,44,0,0,2,101,85,142,138,28,51,66,84,77,116,54,99,52,2,62,96,70,52,118,245,40,332,146,358,198,12142,5697,494,11654,1006,2459,149,1742,1553,3841,101,1353,893,1259,279,163,87,1,115,33,239,10,171,30,125,107,45,160,194,43,106,94,326,2320,5214,2,213,1744,314,226,142,515,197,470,194,414,176,48,31,216,128,200,513,137,214,55,239,65,556,2301,1904,904,2675,115,141,632,312,166,118,78,155,95,2,25,122,525,1398,1441,512,170,148,223,536,1,234,62,6,1116,1069,940,142,291,359,139,32,205,83,5,87,26,211,123,177,541,150,491,430,248,623,409,586,3,146,77,5,113,43,163,49,38,711,1204,1285,3,126,110,178,228,149,61,70,399,225,130,287,174,329,502,1,611,1287,285,859,458,1,226,201,240,222,9,72,71,568,13,335,400,325,942,109,565,560,208,1463,24,373,218,164,80,150,116,504,129,76,90,292,813,133,250,135,30,337,245,976,100,23,207,92,250,127,56,22,45,317,142,564,343,144,10,66,38,322,76,657,109,123,41,81,16,371,319,789,1937,128,269,120,18,537,6,102,193,98,133,59,363,408,33,213,22,145,203,74,156,2,585,208,83,124,151,124,4,12,339,197,9,147,224,85,147,84,75,6,118,101,200,184,6,127,241,429,0,2,130,7,77,10,409,178,223,206,149,76,8,119,9,167,67,32,73,19,241,123,119,70,146,233,37,563,83,126,89,11,0,536,495,576,4,29,5,291,150,199,47,130,3,540,111,174,118,438,475,1707,47,3,130,616,472,449,240,1092,0,41,129,117,21,162,94,41,7,325,1430,80,1048,495,541,636,119,682,383,195,241,578,292,370,3093,4568,1,1,14544,0,12173,1112,59,731,195,33,120,25,70,14,56,80,4,140,321,36,108,118,3,39,4,4,83,97,18,54,80,45,49,100,41,50,82,47,26,43,82,137,79,15,180,70,519,149,415,3196,0,0,0,0,0,0,0,0,0,0,0,1780,92,1279,292,88,47,181,115,253,59,926,578,199,92,74,64,34,58,109,98,509,83,1,36,169,70,71,44,222,183,326,230,3550,0,0,913,253,144,158,30,84,102,59,101,70,154,770,0,58,91,113,74,36,288,105,63,139,58,204,181,88,87,83,88,1265,0,0,0,29,251,86,82,1,37,38,312,0,26,4,115,87,3,57,69,51,75,52,216,71,75,38,92,118,13,75,55,57,79,25,50,3,287,109,2,77,77,65,103,335,54,7,272,58,10,125,195,106,114,287,86,63,493,28,27,256,107,250,91,117,117,108,73,104,2,40,76,62,43,0,36,70,11,63,415,49,57,246,180,108,90,53,57,14,159,76,185,79,53,48,124,0,241,56,75,159,70,52,964,82,123,235,10,194,42,56,107,0,58,49,81,217,45,132,168,69,0,107,137,57,286,75,42,41,30,50,70,74,167,74,284,90,596,0,78,40,69,14,160,132,61,168,656,119,69,69,167,21,78,1675,818,2083,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,2,1,0,0,0,0,1,1,0,0,3,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,1,1,0,0,3,0,0,0,1,0,1,0,4,0,0,0,3,2,1,2,1,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,4,3,1,13,7,2,5,1,1,2,6,3,1,1,3,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,2,3,1,1,0,0,1,0,1,4,0,0,4,0,0,1,0,1,0,1,0,16,2,3,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,21,7,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,0,0,1,1,0,0,1,3,1,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,1,0,0,0,1,0,1,0,1,1,1,1,1,6,5,1,2,1,1,1,2,1,1,15,2,1,4,3,4,1,1,1,3,1,1,2,2,1,2,7,4,3,3,1,3,1,5,3,2,3,7,4,10,3,4,3,2,2,17,14,7,5,6,8,1,2,1,1,2,1,2,3,2,2,3,1,1,1,1,2,6,1,1,1,2,8,4,3,3,1,3,1,1,3,7,1,1,1,4,3,3,1,2,2,1,2,14,6,5,6,2,2,1,6,10,14,3,2,6,2,7,1,19,14,5,1,2,5,5,3,6,3,2,2,13,16,19,8,1,1,7,2,3,3,6,38,5,4,1,9,4,6,9,2,7,3,6,28,12,5,9,3,3,4,4,3,5,2,6,8,1,26,4,19,2,2,17,4,4,3,4,30,11,9,4,10,5,6,5,20,2,4,11,3,11,5,7,20,30,6,6,3,8,5,17,5,7,0,0,0,1,0,1,1,2,0,0,4,1,6,3,3,2,1,8,4,6,0,0,0,0,20,8,1,2,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,6,0,0,0,0,0,0,0,0,21,5,1,3,0,0,0,0,0,0,0,0,0,24,4,5,12,8,13,0,0,0,0,0,0,0,0,8,1,10,1,0,0,0,0,0,17,3,5,5,7,0,0,16,3,0,0,10,2,1,0,0,0,4,1,1,0,2,1,1,0,2,0,0,0,40,31,0,0,0,0,0,0,0,0,0,0,0,0,0,57,2,0,0,0,0,0,0,25,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,5,0,1,0,1,1,1,3,2,2,3,2,1,5,206,2,2,4,3,3,5,1,1,1,1,1,2,1,1,2,10,1,3,2,8,449,4,1,1,1,2,1,6,19,4,2,5,2,6,1,3,200,0,0,4,14,0,3,3,1,0,0,2,0,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,4,0,0,0,1,1,1,0,0,0,1,0,1,0,1,2,2,1,1,0,0,0,0,0,0,0,1,3,1,1,1,1,0,0,0,0,0,0,0,0,2,20,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,1,0,1,0,2,0,0,3,0,5,8,4,8,6,9,16,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,8,0,0,1,1,2,1,1,1,1,1,1,2,2,1,2,1,1,3,3,3,2,5,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,2,0,4,0,1,0,1,1,1,1,1,1,3,1,5,1,5,2,3,2,1,1,1,1,1,1,1,1,1,3,6,1,1,1,1,1,1,2,3,4,3,1,1,1,2,1,1,1,2,6,3,2,3,1,1,1,1,1,3,2,1,5,2,5,1,5,1,1,1,1,2,1,2,1,2,1,2,9,23,4,7,3,2,3,9,7,2,3,3,2,2,3,1,19,3,21,2,8,3,5,2,3,1,2,1,1,27,43,1,6,5,1,1,1,2,2,8,8,46,21,19,21,3,3,3,5,27,1,1,9,3,2,1,14,12,9,6,4,5,1,5,3,7,10,12,26,47,73,28,17,2,4,3,2,3,3,2,1,2,4,3,5,2,1,2,2,5,4,2,2,7,2,3,3,2,5,2,1,3,5,8,1,2,5,1,1,10,3,2,3,5,2,3,9,3,3,0,0,2,0,0,1,0,0,0,13,7,1,2,1,1,0,0,5,4,5,2,2,2,0,0,0,0,0,0,0,0,0,16,16,12,3,9,5,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,20,10,6,5,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,38,11,4,10,4,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,13,4,9,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,7,4,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,4,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,4,5,2,4,12,15,85,6,2,7,0,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,16,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,1,1,1,1,3,1,1,1,1,1,1,1,1,4,1,1,1,1,1,1,1,1,1,1,1,3,1,1,2,1,1,2,1,1,1,1,1,1,3,2,1,1,1,3,1,1,2,1,5,1,1,3,2,1,1,1,2,1,3,2,3,1,1,2,4,1,4,1,3,2,1,1,1,7,2,1,3,3,3,2,9,1,3,3,4,3,2,2,4,2,8,1,4,1,4,2,4,3,2,3,1,10,13,2,2,8,8,3,12,2,15,1,12,2,2,1,3,10,1,2,3,13,4,3,25,3,9,3,3,3,12,1,1,9,2,6,17,4,7,14,2,10,16,11,5,2,0,0,6,0,0,0,0,0,2,2,0,1,1,0,3,0,0,0,0,0,9,0,0,0,2,0,14,0,0,0,0,0,0,0,0,0,0,0,2,11,7,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,7,2,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,1,1,1,1,1,1,2,2,1,1,6,4,1,2,2,1,1,14,1,6,2,2,1,4,1,1,3,2,4,2,7,8,2,3,2,1,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,2,0,2,1,0,1,1,1,1,2,1,2,2,0,1,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,16,3,5,4,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,0,0,1,0,2,0,1,1,0,0,1,0,1,0,1,2,1,0,2,1,1,1,4,12,2,1,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,1,1,2,0,0,0,1,0,1,2,1,0,0,0,1,0,1,2,1,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,1,2,1,0,1,2,1,0,1,0,1,0,2,1,1,0,0,0,1,2,1,0,1,0,2,0,1,1,2,0,0,0,0,1,2,1,0,1,2,1,1,1,1,0,0,0,0,1,0,1,0,1,0,1,0,4,0,0,1,2,1,0,1,0,1,0,4,0,1,0,1,2,2,3,3,2,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,0,0,0,0,0,0,1,0,2,0,1,3,5,5,1,1,26,20,1,1,4,2,242,11,3,13,6,4,1,13,6,1,1,1,2,275,15,9,14,14,8,15,89,201,155,51,59,14,7,2,8,1,1,1,1,8,2,3,5,25,60,128,77,43,22,13,2,7,1,2,1,2,9,1,9,3,1,2,5,2,2,2,1,6,0,8,5,2,5,1,15,8,7,3,0,72,39,8,4,11,1,0,0,171,55,43,16,5,2,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,101,28,3,3,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,125,32,15,2,6,2,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,23,12,19,3,2,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,9,11,11,12,7,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,3,5,1,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,3,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,1,1,1,1,11,2,1,1,1,1,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,1,0,2,0,1,2,1,1,5,2,2,2,6,3,1,4,2,1,1,2,3,3,5,3,1,1,3,3,3,9,1,1,6,2,2,1,1,2,1,1,1,1,0,1,0,0,0,0,2,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,3,1,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,24,0,0,1,1,3,1,0,0,0,0,0,0,1,1,1,3,1,1,1,1,1,1,1,3,1,1,1,8,10,2,1,1,2,2,2,2,2,6,5,2,2,3,6,2,1,3,1,1,2,1,1,1,1,2,0,0,0,0,1,1,0,0,0,0,0,1,1,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,1,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,2,1,2,1,1,2,2,2,2,3,2,1,2,4,4,1,1,8,2,1,7,4,1,6,2,1,4,7,44,2,8,1,1,1,4,5,1,3,1,1,1,2,2,2,2,1,2,1,3,2,2,0,1,1,1,0,0,0,0,3,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,3,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,2,0,0,0,2,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,0,1,0,1,0,1,1,0,0,1,0,1,16,0,0,2,0,1,0,1,0,1,0,1,0,2,0,1,0,1,0,1,0,1,1,1,0,0,0,1,0,1,0,1,1,1,5,5,4,2,2,1,2,4,2,10,14,11,3,3,2,2,3,2,7,8,3,1,5,15,13,11,6,2,2,2,2,3,16,1,33,19,8,1,3,3,5,5,1,8,10,1,1,49,22,3,8,6,4,5,14,42,19,3,1,5,5,36,13,10,59,2,3,2,3,14,4,3,25,36,7,1,7,6,2,4,2,1,6,1,4,1,2,5,2,0,1,0,3,1,1,2,7,0,4,9,38,0,0,0,0,0,0,3,14,2,0,0,0,0,0,0,0,0,10,3,0,0,0,0,37,3,0,0,0,0,0,0,0,0,0,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,6,1,4,0,0,0,0,0,0,0,1,1,1,2,1,1,3,2,0,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,2,1,0,0,0,1,2,1,0,1,1,1,0,0,1,1,1,0,0,0,1,2,1,1,1,1,1,2,5,2,1,1,23,5,15,1,3,5,47,17,105,46,74,8,5,2,2,14,5,7,39,2,7,1,1,1,6,10,4,24,3,2,1,2,1,0,2,1,2,0,13,3,18,1,0,0,0,0,0,0,0,4,4,0,0,0,10,38,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,0,0,0,0,0,0,15,5,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,1,1,1,1,2,1,1,1,8,1,1,2,2,1,1,2,15,2,1,1,1,1,1,1,1,1,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,5,21,2,37,1,2,7,6,3,10,61,50,27,8,127,125,740,5,10,2,8,4,1,1,3,11,1,2,5,1,12,27,22,1,12,41,8,10,14,15,7,35,16,7,0,19,108,122,3,0,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,1,2,2,1,2,2,2,2,3,2,2,1,7,1,3,2,2,2,2,2,8,5,1,3,3,15,23,1,4,9,6,29,2,6,1,1,5,1,2,1,1,0,0,0,1,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,0,0,1,0,1,0,1,2,0,0,1,0,1,0,5,2,1,0,0,0,0,0,0,0,1,4,1,1,2,1,55,4,6,5,4,2,2,2,1,2,1,1,1,3,4,5,5,1,3,3,1,4,19,6,3,4,1,3,6,2,2,1,1,2,1,1,1,1,6,18,19,1,4,3,3,2,1,2,1,4,9,2,6,3,9,4,16,8,13,1,2,6,1,4,2,1,2,1,3,1,2,2,2,2,1,2,1,1,1,1,3,1,2,1,4,1,2,3,1,1,1,1,7,1,1,3,2,8,5,1,1,6,2,2,1,2,4,1,4,6,1,1,5,1,2,1,3,3,1,1,1,2,6,1,5,10,2,2,2,6,5,1,3,2,2,2,2,4,1,2,4,1,2,3,1,6,1,8,1,4,3,4,1,11,1,1,6,2,3,2,1,5,2,6,1,2,3,5,1,8,4,1,2,2,1,3,1,5,2,3,3,2,4,1,3,2,4,2,1,3,1,1,4,1,3,1,1,1,1,1,1,4,1,2,2,1,3,1,2,1,1,1,2,3,3,8,2,7,2,7,3,2,1,2,11,2,2,2,2,4,2,4,4,2,12,2,4,2,1,3,1,0,4,9,3,4,6,3,0,3,1,1,6,1,5,2,13,4,2,5,1,3,9,5,5,7,9,2,3,3,5,3,20,6,3,9,2,3,2,3,11,3,0,16,3,27,27,28,5,4,5,5,1,0,4,37,17,5,4,4,5,3,7,5,17,8,6,8,3,3,5,11,6,92,51,1,2,31,15,4,4,3,33,55,1,1,59,15,3,28,20,15,12,10,2,9,6,7,47,51,1,1,0,0,16,4,33,29,3,13,4,3,4,2,63,53,2,1,2,0,0,0,11,11,10,4,13,9,1,0,0,2,12,3,4,3,41,3,12,3,3,21,11,1,0,0,0,0,0,0,28,11,11,6,3,2,3,1,27,11,0,0,0,0,0,0,0,3,5,7,20,13,0,0,0,0,0,0,20,4,8,1,8,7,0,0,0,0,0,4,3,3,10,11,5,0,0,0,0,4,5,2,2,3,10,1,0,0,7,6,5,0,5,6,4,0,0,1,1,3,0,2,8,1,2,6,3,2,0,0,4,4,1,0,6,14,0,0,0,153,9,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,10,3,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,4,1,2,3,3,9,8,13,4,3,1,44,4,2,4,5,7,57,2,2,7,1,2,2,0,0,0,0,0,0,0,1,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,3,2,3,1,1,2,3,8,7,8,2,1,11,2,4,3,26,3,8,41,1,1,4,2,1,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,2,1,0,1,2,1,0,0,0,0,2,0,1,2,1,1,1,1,0,0,0,0,1,2,1,3,1,1,0,1,0,0,0,0,0,1,0,1,1,1,0,0,0,1,2,1,0,1,1,1,1,1,3,5,1,2,23,3,2,3,1,1,1,1,2,4,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,1,0,1,1,0,0,1,0,1,1,0,0,2,0,0,1,0,1,2,1,1,4,3,1,1,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,2,1,2,2,1,1,1,1,2,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,2,1,0,0,1,0,1,4,2,18,1,0,0,0,0,0,0,0,0,2,0,2,5,2,16,1,1,71,22,1,1,1,4,1,8,3,1,5,1,0,0,0,3,5,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,2,7,1,1,15,1,1,1,1,1,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,1,29,36847,17649,10044,3343,29244,333,612,30,12,233,262,1642,4383,6898,354,11,1,14244,1976,1617,14376,52,616,363,1720,1961,2285,5973,18415,479,493,427,3886,302,8672,302,481,1040,3538,9178,2072,7543,4874,483,3381,406,1560,203,709,1635,658,398,1310,28215,28768,5,1548,639,2265,3914,1549,2891,2603,484,639,990,1763,640,44,8,1,34,32,407,15,0,0,0,0,1559,0,989,921,728,204,640,917,1,1636,482,1548,922,399,1339,1983,1,48995,1,116000,1,134328,5793,9297,13308,15341,549,4323,1917,564,1150,9338,1056,1,2653,2372,2,1061,792,37,4,5,394,2991,3,890,802,764,9,1572,3473,674,7,4246,1276,1,451,602,135,2,693,6,715,254,23,8,1,257,21160,21986,14204,14560,4382,5105,8479,2760,2271,10672,2565,1211,1240,2252,3520,3434,1326,821,945,647,4174,1231,895,823,536,1667,1460,271,26,4867,2948,8933,1838,1216,913,1954,1115,576,521,1165,964,7900,9449,2380,3023,1077,6377,2299,5,552,275,1290,3,1007,4,19,537,13526,3824,2116,1884,7424,911,724,3890,4,3,1090,9,9,491,11,14,1314,826,342,713,7553,6427,278,14087,2131,2022,1337,570,463,1453,25,8,945,1873,1816,4,15,43,1953,3306,2815,29,7,480,2556,34,972,816,1079,1225,1265,915,14,17,2832,2,2,4,2072,1251,7,1727,1770,688,518,1,1165,3,4149,9000,340,815,658,482,827,653,744,1325,2820,3,1566,2,13,24,1097,17,6,11011,884,1008,511,1232,2073,1264,1660,1217,1212,306,369,666,1,1078,2761,914,5,569,1155,7,271,737,4618,2885,969,3,177,5,5366,4223,1974,5661,1722,5775,1430,7317,887,786,1901,2226,3117,8968,1380,985,3060,1840,3424,2997,2801,5136,5,1264,1241,570,554,1730,2892,2606,341,3609,680,372,4224,912,816,2132,1975,988,4581,1036,1081,1721,2097,2,1241,659,1124,978,1009,554,4025,2300,1971,529,483,1087,915,3462,718,512,1125,1338,4225,1431,1976,828,1,1233,3099,1951,2795,3689,4233,1273,492,571,464,654,888,4,793,2385,1658,2370,465,516,1323,1261,701,4,1902,8,3668,3,1419,956,793,482,3573,5,930,8,3,732,1254,968,921,1114,3,2122,2,653,15,1164,0,7,2,967,3,0,3825,738,6024,18,2979,2,811,4,1977,1,365,2992,1528,6560,7185,1501,1262,2090,2204,2,1,978,151,360,3788,1414,6869,972,1119,922,822,851,6693,6,1785,1736,2592,1115,1046,2202,870,2595,713,1527,2298,1974,9573,7580,2,1805,2374,0,3795,5151,664,13186,1550,1214,9,1126,4,169,0,1,8,1950,3425,5,272,4,15518,2312,6329,4576,3404,5091,5,2098,0,1534,7,0,0,9381,3461,4932,38467,4059,3998,6028,4,912,3,956,492,4,0,722,1,885,11469,1396,1736,1395,1279,640,8,11,0,2,2127,2836,1342,719,7597,884,4,824,2133,725,0,57306,7143,2206,655,24546,3582,9540,4919,3531,1490,1,1,10,1,1,231,2,0,0,0,4,0,2,13179,2121,3070,1004,37524,3287,9503,5116,1926,589,1323,0,6,0,0,0,1,3242,1228,19488,1268,2118,895,3494,6,0,0,0,2,515,6507,542,447,3,3866,823,603,434,1519,1265,651,1,24010,56547,16185,9804,674,2940,409,1114,1976,5,625,0,21,4,24951,7679,9831,519,1069,10,645,8,2,1,0,72963,32143,1340,4470,1814,2221,701,8,2071,1,15,676,2,75510,15522,14636,7296,3561,1109,662,1534,556,9,0,2,21,2,3,42128,50193,18794,9056,5887,990,8364,1268,884,1662,1657,11,1,903,3,1,2,386,108,34610,13891,7831,4068,1136,485,5,1758,2,836,1,8,9,49748,16832,11766,12826,6973,4350,1323,400,2483,4,1046,1278,730,9,1,582,3,1323,4,457,51,24340,23161,14062,6737,6286,5017,1608,3720,2126,1589,616,1574,530,947,1685,7,659,13,10,3,18,313,22349,23367,1402,6,1751,1625,8894,275,3258,1793,8,10,958,12,30247,8271,3374,2922,1424,7038,2981,2708,1841,5298,1724,359,4,1127,712,3,4,730,533,22374,2638,8464,3133,16032,5046,7578,4353,3356,5243,1329,1241,353,12,724,7,6,648,413,4,6,1212,68,6789,9754,2662,11115,4738,4969,5513,1129,3031,277,5,1223,1037,11,561,3,8,1314,1571,5464,5333,6676,605,1366,4929,14,1108,7,9,2535,15294,1941,1261,2772,26,7825,2222,1656,966,776,3361,875,2292,3740,1942,896,918,624,11,1098,988,3,3103,5,5,393,6626,9562,11822,20374,9853,3499,1,753,2930,1272,735,656,1285,1902,963,751,5,1736,6698,1214,12185,1412,836,833,689,1832,1171,647,12601,13750,7425,2394,1034,762,18155,13243,1472,1622,512,7,1311,2108,376,11,2892,3042,39589,14013,2808,8509,2194,7,1166,1320,539,1817,538,1273,7,665,1957,35,1976,3103,1036,754,1384,840,273,2128,1576,21486,1776,12675,16732,7,3,2828,7190,3713,5,1659,3385,358,886,911,906,8,3,19,556,1724,510,1292,4,21,180,493,4494,12478,3256,4670,6434,1161,2250,1663,3845,1173,1769,1097,3271,992,884,921,4140,3591,2825,1171,716,1974,3733,834,1776,824,1131,647,2307,913,927,962,7622,2614,1917,3744,7,6175,1224,1224,1672,5051,1812,1428,1583,1090,3137,497,2185,2374,1572,521,2449,10,705,1128,801,3612,4275,1531,563,1805,3,13,4395,7494,4,655,13,6,1417,683,9,1167,1171,2613,779,552,1467,830,1271,1023,5,11,3701,2818,914,2299,1001,691,4435,2508,3869,1130,488,3636,725,1434,2287,3255,1669,488,3976,2612,1086,1316,797,1618,535,1043,1246,1668,2684,832,655,1666,13,898,2540,572,258,2289,913,1240,10,7,4288,4664,571,2164,487,4103,1893,1465,2320,1244,554,682,1156,1341,1466,1272,1548,5,1318,646,2378,5103,2107,856,2682,2087,690,1824,257,881,520,9,1,1446,1819,1301,3807,1127,496,4231,1903,2692,7535,796,1223,2949,274,650,1875,9,19,553,3,3624,987,681,3872,414,1085,1818,1157,1701,1832,549,2523,12,835,6804,1394,2147,1335,1313,1819,3218,3229,10438,9347,1,3590,1273,7652,5,548,1734,3551,1535,2306,1671,1270,4199,8399,2273,1293,829,3763,1490,273,2086,9613,9123,1976,5372,1763,0,8189,10523,106179,98870,2711,5,1,323,168,2,135,854,1,2,545,340,0,888,451,725,1200,2049,328,1511,60,332,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17378,978,2661,476,2898,371,1084,2586,6405,814,178,253,2242,240,264,350,486,2084,3702,251,1507,1613,1281,1364,900,1818,7588,7808,2619,15729,2333,1612,6068,202,120,0,0,0,384,2733,1696,338,686,1436,1199,1031,436,470,599,578,1867,554,393,3127,1198,480,849,609,383,360,12,1540,2107,1232,597,520,0,477,1143,756,275,940,1483,324,169,372,168,1541,339,478,440,363,284,2106,687,1541,1043,1,191,607,2108,623,1320,602,2262,1024,1994,582,1,0,190,401,411,1142,1540,596,177,606,252,1707,535,853,239,263,349,2,0,485,299,898,0,1005,1030,338,1,1091,5,399,604,2392,484,519,347,852,0,1238,479,1778,3564,265,1033,11,0,0,1540,755,250,17,274,897,1055,450,623,398,611,502,1377,784,469,225,660,868,622,698,664,622,395,3421,1757,3745,1075,0,2251,577,858,1058,166,7472,3334,6733,1621,1113,2516,5040,9655,1655,3613,506,212,0,15802,911,2088,19825,28245,22153,228,650,278,14014,12675,47976,621,87,58841,44127,2337,0,58007,881,103127,178,19,1,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,1,0,2,1,4,2,3,1,2,0,0,0,0,0,1,0,1,1,1,38,18,5,2,3,4,2,52,27,25,11,1,1,23,8,1,7,2,27,24,4,16,3,2,2,2,16,21,39,12,1,4,2,4,30,11,11,2,7,7,1,4,4,1,4,2,3,11,4,1,1,1,3,8,7,3,1,8,1,1,3,1,3,0,0,1,23,17,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,10,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,2,0,0,1,1,0,0,1,2,1,1,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,0,2,1,1,1,2,0,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,3,0,1,1,1,1,9,2,1,1,1,2,2,21,5,3,1,1,3,2,3,2,2,1,1,7,1,1,4,1,3,2,1,5,1,1,0,0,0,1,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,6,2,0,0,0,0,1,0,1,1,0,0,1,0,1,1,1,3,7,10,5,10,2,2,3,1,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,6,1,3,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,2,14,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,5,5,5,1,5,3,2,1,32,11,11,1,17,7,4,8,54,22,2,1,3,13,11,40,5,26,45,5,9,3,11,15,21,10,18,25,6,9,9,18,13,24,34,7,28,2,5,1,1,3,2,5,3,0,0,2,5,0,0,0,0,0,5,2,4,9,4,0,0,0,0,14,1,3,8,0,0,0,0,0,0,10,18,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,1,1,1,1,1,1,1,2,3,1,1,1,1,1,5,4,1,1,2,5,3,4,1,19,1,8,2,1,2,1,2,2,1,1,6,2,1,1,1,3,4,3,2,1,25,1,7,1,2,5,2,2,2,2,3,22,2,1,2,1,3,4,7,2,3,26,1,1,1,3,2,2,1,3,2,1,3,9,4,1,3,2,3,5,8,1,2,1,2,3,5,20,1,2,4,52,2,1,2,1,1,4,2,1,10,0,0,0,0,0,0,0,0,0,0,2,2,1,0,0,0,1,0,2,1,3,1,0,0,0,0,0,1,1,0,0,2,1,1,0,1,0,3,1,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,0,1,0,2,4,2,0,0,2,0,0,1,0,1,0,1,1,1,2,1,1,1,1,1,1,3,1,5,2,2,11,3,4,8,1,1,1,8,9,12,14,9,4,12,15,32,5,2,5,25,1,2,4,1,1,0,0,0,2,1,0,1,0,0,0,1,3,4,0,0,0,7,3,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,2,0,0,0,2,0,1,0,2,1,1,5,2,0,0,0,0,0,0,1,5,1,2,1,8,7,2,1,1,1,57,20,256,27,1,2,3,1,529,9,10,6,2,2,2,7,3,5,71,50,28,5,10,106,51,60,87,72,61,18,14,23,9,28,7,6,3,5,7,9,6,4,15,2,4,11,5,5,4,1,14,1,1,5,15,17,7,17,74,68,23,52,43,44,84,96,68,106,81,25,23,24,3,10,8,7,1,6,1,1,3,11,3,2,26,2,7,3,3,4,3,16,6,17,8,11,8,2,25,4,19,22,16,2,4,16,14,19,62,11,3,3,2,1,2,1,0,0,9,5,4,6,4,5,4,0,5,6,1,7,2,1,0,0,15,17,4,9,13,6,1,6,3,2,2,0,8,25,30,3,2,7,0,3,35,7,16,4,2,0,36,49,36,41,23,29,2,5,2,2,1,3,1,1,0,0,71,58,13,35,1,2,6,5,15,4,7,9,1,0,0,124,44,22,26,11,30,1,6,6,2,4,5,1,1,1,0,0,0,0,184,94,61,58,20,12,14,16,3,1,28,6,2,1,4,2,3,1,1,1,0,0,0,0,0,124,87,36,42,4,16,20,13,7,1,9,1,2,2,1,2,4,2,2,1,3,1,0,0,0,0,162,41,28,28,20,13,6,11,2,10,1,1,6,4,4,0,0,0,0,0,0,83,33,68,13,39,15,13,17,10,4,29,4,6,1,1,2,1,0,0,0,0,0,0,0,34,52,32,12,15,28,25,12,3,2,24,5,4,4,1,4,1,9,1,0,0,0,0,0,60,31,13,26,3,6,5,18,2,2,4,4,3,0,0,0,0,76,35,44,5,8,11,17,13,4,2,3,2,0,0,0,0,31,40,26,37,3,11,23,14,15,6,17,5,5,2,2,5,2,2,1,0,0,0,6,15,48,19,6,13,33,14,5,2,1,3,3,3,0,0,40,33,4,6,10,34,3,2,2,7,2,2,0,0,18,40,35,9,4,15,4,9,9,3,1,0,0,0,38,39,18,16,37,6,11,5,5,2,2,1,0,0,0,0,0,0,56,18,18,9,1,2,1,0,0,0,0,0,43,65,8,7,4,12,1,2,3,8,1,0,0,0,34,37,33,4,16,10,7,5,1,0,0,0,0,81,57,22,13,2,4,3,1,0,0,0,95,49,50,34,34,8,4,10,1,0,0,0,0,0,0,0,0,69,17,13,33,13,9,5,14,5,1,0,0,0,0,0,0,41,28,22,18,10,8,1,0,0,0,0,0,0,0,0,59,30,20,1,3,20,2,5,1,1,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,32,7,2,13,10,4,1,1,0,0,0,0,0,0,0,0,0,0,84,32,5,23,10,6,1,0,0,0,0,0,0,0,0,0,34,16,44,37,1,1,7,0,0,0,0,0,0,0,0,0,0,0,8,27,34,3,2,2,0,0,0,0,1,25,2,0,0,0,61,2,1,1,15,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,9,5,4,31,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,1,2,1,0,0,0,3,0,0,0,0,3,0,0,0,0,0,1,0,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,1,1,0,0,0,0,0,0,1,1,1,1,1,2,2,2,1,1,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,0,1,1,0,0,1,3,1,1,0,0,0,0,0,0,1,0,1,1,1,1,2,1,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,0,2,0,1,0,1,0,1,1,0,0,2,1,1,1,1,3,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,4,0,3,1,1,1,1,0,0,0,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,2,1,1,1,1,9,4,1,1,1,1,1,1,3,2,1,2,2,1,1,1,1,2,2,1,2,3,1,1,1,1,4,1,4,1,1,3,1,1,2,1,1,2,1,1,3,4,2,2,1,3,1,1,1,1,1,3,1,1,1,1,1,2,2,1,1,0,0,0,5,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,16,1,0,0,1,1,15,0,0,0,0,0,1,1,3,3,1,0,0,0,0,0,0,2,3,4,5,6,1,12,2,1,6,0,0,1,0,2,4,1,0,8,2,4,3,4,3,1,4,0,0,0,0,0,1,3,6,3,1,3,2,1,1,1,2,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,3,2,1,0,0,1,0,1,1,1,1,1,2,4,1,3,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,1,1,1,1,1,1,2,3,3,1,1,2,7,3,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,1,1,0,0,0,0,2,6,5,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,2,1,3,1,3,2,5,1,1,1,4,2,4,1,4,1,1,1,9,7,1,1,1,1,1,110,8,3,4,3,22,35,14,51,7,22,15,78,147,95,4,5,2,10,11,16,5,22,37,5,4,1,1,2,0,1,4,4,3,1,0,11,6,7,0,7,15,5,0,39,32,0,0,0,98,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,2,460,78,351,102,87,76,4,35,4,92,24,19,23,33,168,58,3507,6119,1,70,132,280,67,14,128,306,103,87,2,78,0,1,0,0,1,0,75,15,23,102,18,24,35,145,27,61,4447,2413,1148,7,37,248,5081,2086,2248,240,118,201,755,384,336,105,163,36,54,182,2,91,528,38,93,62,56,66,142,21,103,226,150,153,166,39,25,46,328,4586,286,1186,225,101,34,59,52,75,113,320,304,208,197,362,5,48,35,1,8,287,38,226,25,959,2381,290,33,587,236,171,81,28,118,161,56,38,113,106,334,26,432,211,89,32,133,291,794,202,155,346,228,180,176,161,120,29,99,60,214,13,28,50,72,196,40,2,376,120,368,421,993,239,232,68,68,27,271,144,72,40,114,501,297,34,288,129,130,180,159,232,145,844,57,160,29,160,163,24,24,363,6,2,2,94,153,91,30,156,291,19,44,58,81,14,211,42,93,4,70,33,31,36,465,120,119,10,199,59,38,88,197,295,103,36,54,45,18,103,184,117,374,96,290,114,37,76,30,30,2,78,111,16,276,323,109,194,134,75,66,167,121,94,87,61,97,68,4,199,51,133,212,10,84,23,59,282,291,132,95,31,82,40,448,28,5,34,42,111,15,4,26,162,164,71,83,139,21,56,39,29,108,2,2,25,441,119,6,28,1,108,49,197,138,106,142,200,6,13,13,83,161,182,29,340,38,50,292,78,133,143,37,29,39,35,73,29,96,57,255,28,379,136,23,78,35,188,0,56,100,166,110,87,80,88,137,398,114,74,224,383,82,219,21,14,77,67,5,55,333,223,3,44,14,188,147,333,321,477,269,39,1079,83,13,494,278,162,46,40,25,498,5,25,50,66,33,109,108,483,338,278,154,361,990,517,25,11,126,816,94,79,288,476,74,357,340,71,1662,188,47,356,1347,62,261,1068,0,320,1029,0,2454,3372,274,64,85,18,267,45,34,83,35,207,120,29,90,127,63,25,54,67,27,17,79,9,16,26,195,23,9,17,36,27,86,21,10,7,225,66,209,123,255,4849,0,0,0,0,0,0,34,71,30,102,84,50,155,59,38,43,72,200,75,66,34,75,42,56,68,19,51,25,137,293,1387,85,29,45,110,33,63,51,31,86,29,38,1,142,85,84,195,48,32,34,35,82,49,36,40,41,51,112,33,118,1,71,49,0,58,81,37,28,35,83,42,23,63,1,62,128,48,39,17,46,71,96,104,24,76,65,17,95,0,33,26,79,76,16,68,37,8,15,34,16,25,77,11,107,24,78,95,87,0,18,35,17,23,25,140,41,131,64,90,9,103,144,24,22,109,160,63,106,3,210,69,748,1353,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,3,1,8,2,1,1,3,0,0,1,0,0,0,0,1,0,1,2,0,0,1,0,4,0,1,0,1,1,18,1529,2641,436,179,147,219,411,135,1117,1189,14095,22057,2,149,836,560,364,75,799,1589,70,235,135,124,128,148,365,218,216,199,138,691,432,928,347,18573,12599,6827,3255,3302,9088,138,239,2685,5511,888,45,2014,3308,2078,602,2,841,415,360,152,1769,912,336,624,514,11,406,558,1267,531,1257,209,806,1495,758,758,2156,1486,1206,1465,276,725,1030,188,3699,947,125,862,409,19,877,105,697,187,776,75,793,19,8,19,179,68,113,3245,2748,694,655,261,1866,417,697,1272,71,125,109,201,95,5,294,64,1080,276,568,466,158,263,153,179,527,1755,178,468,61,864,560,163,2,209,552,683,343,308,211,356,62,257,30,589,925,2,313,185,10,1281,368,260,369,338,332,181,135,1173,439,1621,353,1153,33,141,163,42,1,391,164,14,141,4,1086,1404,505,675,578,261,215,481,543,60,345,295,253,466,89,1042,67,1063,648,301,309,53,383,162,108,737,353,366,68,3,172,139,235,5,6,631,1002,244,364,693,283,239,370,562,95,4,179,1267,592,573,780,267,67,1428,151,534,423,402,799,517,126,354,968,948,3,116,41,5,96,642,495,171,43,418,344,506,168,56,324,46,91,741,541,263,321,341,562,474,276,502,355,428,262,62,195,433,143,467,548,478,318,318,363,185,677,353,573,379,1378,125,92,542,602,6,742,434,282,347,258,985,780,4,134,228,238,41,347,228,743,229,164,226,47,104,781,435,3,262,236,245,3,144,126,353,216,490,468,744,196,482,283,187,35,348,361,549,266,153,419,397,880,259,470,542,590,307,408,646,92,68,562,1640,499,197,105,425,640,135,36,55,781,420,459,217,101,483,214,412,398,59,178,210,129,564,345,210,56,110,349,47,12,405,344,339,484,152,319,264,154,296,97,782,349,237,116,249,744,405,3,203,725,399,4,1186,1639,364,89,535,157,213,217,136,480,85,65,1471,17,1066,590,467,340,430,60,41,94,64,857,4,609,685,366,648,241,246,745,342,3,177,409,404,198,295,786,15,921,879,2,239,386,133,832,63,198,16,78,498,625,258,37,1336,131,660,342,229,186,474,1389,212,745,419,334,312,473,103,489,251,109,26,202,398,616,506,596,103,319,473,48,0,355,163,1917,161,1140,461,444,720,1209,2280,884,1374,1380,3,340,72,272,485,2668,142,1916,727,944,181,226,413,175,17,61,168,187,427,218,1891,405,1132,733,1487,2233,1373,125,225,1222,147,160,244,392,18,74,91,1103,686,182,2566,1825,184,596,276,423,85,35,300,145,50,239,1,65,1138,626,1,167,1267,178,90,0,798,2060,806,422,462,530,0,0,12,114,68,2096,1573,738,394,2054,94,586,250,527,40,599,38,3043,2447,1697,554,2661,394,705,412,52,7005,3187,3837,4758,2326,517,1232,185,1061,243,442,468,401,67,73,54,3083,6231,4330,70,139,856,262,522,370,178,640,6424,2406,60,497,123,111,40,75,14111,786,3155,243,1591,931,1358,251,239,21,292,186,22,272,251,285,160,58,47,584,0,1388,6481,2602,3775,7306,4116,340,1227,740,1198,1127,163,567,199,614,592,1006,720,36,218,901,466,388,108,727,677,103,2579,1183,354,304,127,108,20,397,779,3206,2334,2925,160,1723,36,912,886,18,260,659,651,493,429,585,1226,277,783,354,140,518,607,360,160,309,2809,2327,161,111,2419,564,4,864,1448,202,19,829,137,49,694,136,358,291,164,2597,542,5982,724,243,3,271,955,1672,381,188,3,422,278,475,484,116,355,649,625,591,78,2548,228,186,118,426,220,1996,2486,94,2163,2834,218,1643,104,384,245,5,920,250,960,736,184,151,261,772,136,408,735,88,776,8,1087,134,267,297,3343,221,928,307,712,373,909,367,327,390,154,2184,757,248,663,520,409,725,135,3,392,128,3740,74,679,272,98,741,331,2542,263,594,240,378,296,786,264,222,325,340,302,907,2537,355,404,374,556,641,393,6,758,344,887,17,1482,104,582,286,127,99,273,238,220,806,538,5054,217,161,238,475,182,551,1040,457,671,129,257,189,247,403,474,395,491,189,155,568,274,664,320,487,198,662,183,749,371,938,740,394,246,378,591,297,18,7,154,473,550,400,787,567,212,421,343,216,182,179,61,355,1022,661,477,441,537,1016,16,249,485,1426,297,184,1356,382,1337,467,247,2487,393,484,273,735,250,140,374,1699,279,261,537,221,1863,227,889,278,150,195,743,556,734,217,399,943,262,639,391,2511,765,601,472,1059,4735,181,1126,503,358,346,242,601,244,4152,203,2428,356,355,372,1735,523,840,1025,343,1076,114,1285,135,936,1982,391,1744,10371,1488,228,7016,390,407,4078,763,1132,8024,22834,434,43,706,415,19,440,111,1039,32,61,24,4,13,10,473,334,66,79,320,323,889,207,635,96,418,658,167,256,210,300,12674,0,0,0,0,0,0,928,251,46,1027,1150,1107,207,1307,92,42,118,121,570,146,181,294,54,932,445,258,530,389,327,159,359,448,194,30,663,420,889,451,8387,75,272,1001,203,48,45,42,212,16,170,35,1289,71,152,370,176,59,106,154,260,209,20,158,280,231,157,713,318,230,239,96,339,170,1264,213,126,41,117,231,120,88,389,158,355,23,6,180,39,238,293,157,4,53,68,366,499,243,171,795,182,956,256,87,320,255,78,237,497,334,346,389,322,388,45,169,89,367,1434,158,433,365,92,271,1541,537,594,168,247,1230,363,155,245,862,2516,1254,595,1346,2067,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,1,2,0,0,0,0,0,1,0,1,1,0,0,1,0,1,1,2,1,0,0,0,0,1,0,1,0,1,1,1,1,0,0,0,0,1,0,1,0,2,0,1,0,1,0,6,0,0,1,1,1,1,0,0,0,0,2,0,0,1,1,1,1,2,3,4,16,5,1,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,5,2,4,0,0,0,0,0,2,0,3,1,1,0,1,0,0,0,1,0,1,2,3,1,1,2,0,0,0,0,0,0,0,0,2,0,0,1,0,1,1,0,0,12,6,0,1,0,1,0,2,2,0,0,0,1,0,1,1,2,0,0,0,1,1,3,12,1,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,0,0,2,0,2,0,1,1,1,1,0,0,0,0,1,0,1,1,5,1,8,1,98,47,1,8,2,107,18,10,3,1,2,3,1,1,5,2,2,1,1,7,1,0,13,1,25,3,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,3,5,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,1,0,0,0,0,0,0,0,1,0,0,4,10,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,2,0,0,0,1,0,1,1,1,0,0,0,1,0,1,1,0,0,1,2,1,0,1,2,0,0,0,1,0,2,1,0,0,0,2,0,0,3,0,0,1,0,2,1,1,1,2,2,1,1,0,0,0,0,0,0,0,0,0,3,10,1,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,6,0,1,1,0,0,1,2,0,1,0,1,0,1,0,1,0,1,0,2,0,0,1,1,2,2,0,0,0,1,0,1,2,0,0,0,4,2,1,120,72,34,27,4,1,2,1,3,3,8,2,7,2,2,2,38,30,20,5,2,71,28,19,5,4,2,4,1,3,7,6,2,9,53,53,11,1,1,1,56,28,3,37,5,14,19,40,21,35,1,1,1,1,1,22,4,13,20,6,4,9,15,19,1,49,10,4,3,3,1,1,2,14,6,28,6,4,9,39,17,8,5,3,5,1,2,5,2,5,1,7,2,9,17,5,8,10,2,6,2,6,13,12,2,14,4,2,1,1,15,2,3,6,2,1,4,2,2,6,5,3,31,9,9,3,2,1,1,0,5,5,3,1,0,3,15,2,3,3,1,0,19,12,1,1,36,18,14,1,0,0,1,14,14,3,1,0,0,127,60,5,4,2,1,1,0,0,0,0,0,0,0,0,0,0,110,4,5,6,6,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,28,16,11,8,9,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,2,2,1,0,0,0,0,0,0,0,0,2,6,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,1,1,1,88,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,1,0,0,1,0,1,0,1,2,1,3,1,7,4,9,3,2,1,1,19,78,8,2,3,1,1,1,63,8,1,833,16,6,5,3,3,6,24,93,55,39,43,13,9,7,1,4,1,86,18,15,15,87,82,180,367,249,156,89,31,7,9,2,1,1,1,8,8,13,48,19,6,12,6,14,6,2,7,6,1,0,0,5,8,4,7,3,3,1,15,12,29,16,7,0,0,13,24,40,13,3,0,122,44,33,5,4,1,0,0,351,121,51,5,9,1,1,0,0,0,0,0,0,0,0,0,354,168,31,19,8,2,3,1,1,0,0,0,0,0,0,0,0,0,0,381,88,10,7,5,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,279,74,27,10,1,5,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,157,55,20,11,5,5,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,14,13,7,4,5,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,26,22,2,5,2,2,3,0,0,0,0,0,0,0,0,22,6,5,1,3,3,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,13,11,2,2,2,1,0,0,0,0,0,0,0,0,5,7,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,6,1,1,1,1,0,0,0,0,0,1,1,2,1,0,0,0,0,3,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,1,2,1,0,1,2,7,2,1,10,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,1,2,1,1,2,1,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,4,8,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,2,0,2,0,0,1,0,1,2,1,0,0,0,1,0,1,0,1,0,1,0,1,1,1,2,3,1,1,3,3,2,1,1,27,18,1,4,2,2,1,214,7,1,2,18,19,18,5,1,3,3,1,1,136,39,17,3,18,28,5,4,7,5,12,10,3,5,8,16,5,11,1,24,15,20,51,135,147,126,42,9,15,2,2,8,1,2,29,9,4,6,5,10,20,11,11,18,32,29,14,3,1,6,4,4,4,2,6,4,5,7,19,15,12,12,3,5,4,7,10,4,2,6,8,3,3,7,5,6,6,10,8,3,9,5,7,5,5,2,13,6,8,5,5,4,5,15,6,8,3,6,1,6,6,2,5,10,1,7,13,6,6,3,5,6,11,5,6,7,18,5,6,5,8,15,20,0,8,6,2,9,9,26,10,3,1,4,1,6,11,2,11,12,5,3,0,10,30,9,2,0,14,36,26,2,3,1,0,0,0,0,122,58,27,3,5,1,0,3,0,0,0,0,0,229,78,26,14,5,7,7,0,1,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,197,104,40,16,17,8,6,1,2,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,44,43,19,18,10,1,0,2,2,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,25,23,16,4,3,9,1,2,1,2,1,1,9,1,0,0,0,0,0,0,0,0,0,0,0,59,35,22,11,6,7,3,5,0,1,4,9,1,0,0,0,0,0,0,0,0,0,0,0,51,32,10,4,3,1,3,1,1,3,22,1,0,0,0,0,0,0,0,33,20,19,1,2,2,1,4,5,4,1,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,19,10,12,5,2,2,4,42,1,1,0,0,0,0,0,0,0,7,9,11,6,1,2,5,27,4,0,0,0,5,2,2,28,1,0,0,8,1,1,2,3,2,4,5,2,0,0,4,6,5,1,9,2,0,3,2,2,0,0,0,4,8,0,0,0,1,1,7,0,3,1,0,4,0,1,0,2,2,3,1,0,0,4,3,0,1,1,7,0,2,1,0,0,6,0,1,0,0,0,4,3,0,10,12,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,1,0,0,0,0,0,0,0,0,0,1,1,0,1,0,2,2,2,5,1,10,3,90,35,3,3,3,1,1,1,2,2,2,0,1,0,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,0,0,2,0,0,1,0,2,0,1,2,1,3,1,1,4,1,2,1,3,2,5,1,1,2,7,2,13,3,5,9,1,2,1,2,8,9,12,7,1,2,2,2,2,1,2,1,0,1,0,0,1,0,2,0,0,0,0,0,2,1,0,0,0,0,1,2,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,0,0,2,0,0,1,1,1,3,1,2,2,1,20,7,1,1,6,5,1,6,1,1,2,1,0,1,1,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,2,0,1,0,1,0,1,0,1,0,1,0,2,1,1,3,0,0,0,1,1,0,0,1,2,1,5,0,0,5,0,0,0,1,0,1,1,5,1,0,0,0,0,0,0,0,1,1,1,1,1,1,3,1,1,1,2,1,1,1,1,1,1,1,3,4,6,1,1,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,3,24,1,1,7,3,1,2,2,2,2,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,0,0,1,1,0,0,1,0,2,2,2,1,1,0,0,0,0,0,0,3,3,1,0,0,0,0,0,1,1,0,1,0,2,0,2,0,1,0,1,0,1,0,1,0,1,0,1,1,2224,24,12898,664,541,3988,1790,125,262,103,319,2825,239,2,1,130,185,172,388,75,856,1397,7823,1233,273,74,48,13,2,864,508,2998,1593,220,154,88,762,333,326,102,982,4033,42,178,204,662,147,229,118,66,140,724,103,203,374,155,146,84,218,23,540,2545,3155,174,251,253,2276,1466,21,126,156,67,807,104,155,87,601,86,350,940,82,315,137,546,0,335,217,456,0,1,0,0,108,5,81,0,28,1,4,1,0,0,0,0,0,0,10,0,1,0,0,332,129,1,24,184,173,245,426,47,1,15,127,192,2101,576,103,10644,1,2,32840,88,22,26,15,1,1,1,34,28688,2524,11110,4962,1562,1040,987,3921,1014,527,313,891,668,192,11,468,222,4,6,257,206,2,76,1,226,1181,4029,11206,4028,921,460,442,1860,478,270,1128,719,600,244,344,477,278,310,376,153,27,210,37,554,566,4375,1279,60,296,596,13,13,5,251,53,128,93,47,4,7507,3800,1586,2457,3752,1659,1128,1216,632,576,330,46,718,310,116,15,164,122,43,96,1050,99,4167,1365,1674,4430,1275,773,379,359,648,8,748,391,106,19,135,105,2,3,708,789,199,2874,1132,4374,669,363,117,59,555,7,150,213,97,3,2,16,20,3529,1312,805,441,283,308,229,79,87,1,310,168,87,4,6215,350,1355,27,309,2,791,95,5,671,8,1,628,1,16,92,6369,3063,3967,2099,872,1529,2327,649,1014,1179,200,185,4,3,442,217,283,5,201,191,487,4,310,9,94,163,4,5,2,4,42,57,414,176,46,1469,2062,894,105,488,76,1478,1549,40,191,1665,131,232,281,227,6,36,209,3,2,17,2,4,244,770,519,580,4733,1326,397,13,209,245,477,305,2,168,90,462,6,2,246,185,2833,1438,943,471,2188,4,280,242,114,342,229,2,3,5,271,296,305,3,140,4,2765,1547,643,41,2374,1480,88,161,284,140,1083,5,358,303,250,5,668,96,2,125,12,87,158,2,6,3,305,287,4,8,38,700,20,331,2138,357,1880,2,3,557,232,157,346,209,288,4,6,953,57,331,366,324,934,131,170,120,861,769,457,507,401,4,448,557,357,60,2,118,198,17,252,299,212,2,2,1328,1263,1244,11,268,240,1332,154,500,240,189,16,124,876,6,808,959,359,503,243,455,219,187,1427,484,679,371,385,1643,502,16,3,163,3,720,197,694,431,454,228,669,468,2,1110,589,434,259,664,403,439,16,583,356,88,487,489,287,638,1283,23,506,262,10,561,504,23,96,124,483,1048,228,2,6,1974,259,3,522,267,117,89,4,276,10,7,6,43,3,4,458,204,204,84,486,1,320,115,295,132,111,20,448,586,47,153,323,1,626,20,490,672,242,285,165,402,191,123,331,282,288,287,413,359,158,98,4,6,4,1322,334,807,864,611,1262,211,273,247,278,350,154,934,5,345,89,596,11,8,312,232,6,252,377,122,132,4,24,115,6,356,2,412,233,304,17,507,30,293,3,261,413,91,843,341,216,3,275,218,92,162,80,478,2,4,234,2,721,3,503,644,300,211,504,387,344,53,489,1,74,391,9,5,210,690,412,22,671,3,693,280,228,209,85,304,88,4,121,638,1327,1115,661,140,41,77,19,584,206,583,435,0,3,503,623,120,5,5,482,492,855,637,424,5,115,271,806,2,57,281,1558,1635,715,150,649,37,7,3,460,395,715,302,563,1325,415,2163,231,458,810,420,1923,1029,184,447,58,202,2,127,40,51,814,562,1,0,242,578,1410,949,488,770,719,495,2006,1,2753,356,1399,116,11,657,601,0,356,965,177,109,391,79,401,2605,1455,1326,209,210,231,355,0,95,671,715,1048,29,88,3503,398,1,0,0,4,1181,205,590,307,1519,1107,303,3,274,22,1660,88,1794,1027,887,221,2539,2570,0,0,1860,253,10,1108,2611,1,1996,1017,3615,2508,7,4,0,187,3315,1033,15,3270,1611,19,36025,144,0,3,33748,793,43,12,2,37,29,2,2,4,2,1,1,89,4,1,49,606,0,0,0,0,11136,511,1742,41,223,257,127,189,326,259,77,66,134,243,317,337,1093,91,234,103,123,62,48,120,163,112,120,104,237,279,202,24,314,72,16,187,40,275,76,99,98,202,195,455,56,454,619,1130,7724,0,2181,244,206,406,174,122,872,671,200,156,96,149,241,79,43,168,333,73,645,652,570,75,337,3095,806,218,40,244,3,61,419,662,31,620,149,135,11,251,177,67,217,992,123,83,359,79,122,240,7,128,84,415,8,148,246,204,369,173,124,12,15,330,19,205,325,270,217,68,78,65,133,242,121,48,223,43,172,305,143,9,184,0,194,80,473,177,137,238,368,345,509,0,90,1,0,0,187,269,5,167,77,103,322,0,199,102,331,155,127,123,186,0,0,332,277,70,270,136,89,0,344,47,381,148,166,161,113,472,240,213,105,236,395,216,149,271,114,137,156,134,536,176,23,169,315,410,86,114,416,1234,1,0,120,39,274,243,101,75,95,97,222,98,682,521,221,270,672,100,88,136,180,1290,424,270,628,220,1530,522,2131,6254,36,690,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,1,1,1,1,1,2,1,1,1,1,4,2,1,1,1,1,1,8,1,1,2,2,1,2,3,1,2,2,1,1,10,6,2,2,2,2,1,3,1,2,1,1,1,2,3,2,1,1,2,1,2,1,1,1,2,1,0,0,1,3,2,0,0,1,1,1,0,0,0,1,0,0,1,1,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,2,0,0,0,9,2050,366,80,188,193,21,85,17,150,146,7,33,151,345,2309,6294,10501,2741,75,58,1,3,1,85,73,596,969,348,320,52,81,50,41,100,52,144,22,86,86,16,28,125,148,8,27,8,5,107,55,52,18,2,2,274,77,62,145,5,9,22,2,2290,346,78,123,4,2,4,9692,551,261,96,69,7,32,40,2,23738,34,52,37,48,16,97,6,6,78,49,42405,1302,12,10,874,349,137,116,204,33,32,21,6,1,1,13,73,326,9,26,257,87,1,124,1,25,42,87,7,244,672,14342,3640,1260,1873,193,362,671,454,324,505,580,559,162,279,557,494,242,16,361,114,420,366,196,55,4677,1432,976,841,424,872,315,148,106,448,281,256,505,387,197,237,36,104,165,453,441,2830,501,4661,120,1351,666,35,206,15,321,800,154,395,139,409,420,276,1892,365,104,555,106,801,233,14,114,105,156,302,101,1684,186,273,833,438,650,195,272,790,583,588,1016,272,261,502,154,163,254,182,352,118,38,44,397,23,120,143,42,4,121,222,239,177,208,135,829,372,48,291,498,106,90,10,226,58,97,222,1005,64,81,126,5,191,101,282,158,121,339,629,247,69,133,143,12,62,100,347,194,36,75,363,81,208,117,148,1,283,177,101,274,38,168,284,16,65,178,1101,1,135,439,340,132,194,322,132,305,195,783,34,148,34,195,113,287,608,1031,298,318,24,16,77,173,469,6,273,115,107,23,188,373,133,396,163,1,19,271,1,122,737,63,19,185,85,122,167,91,288,199,83,115,464,16,32,508,314,77,242,139,82,162,341,3,25,323,227,115,75,174,7,131,272,0,115,200,220,738,167,201,324,197,152,24,131,90,54,287,1469,979,1557,298,1416,50,228,61,387,791,375,30,409,132,200,38,259,38,630,183,509,218,197,575,441,186,294,304,1,57,1458,521,849,243,675,198,335,563,166,372,190,58,273,43,844,273,616,1869,129,103,342,8,3,209,389,1426,937,729,426,221,207,328,124,146,979,59,12,171,289,212,274,40,134,782,1582,639,224,167,238,16,190,0,169,208,892,145,53,381,190,167,815,187,1062,863,1524,169,786,319,106,567,69,378,725,233,8,139,14,4,178,375,13,401,2519,104,345,51,292,339,294,412,282,23,404,218,223,227,118,234,221,95,312,68,0,43,60,364,60,421,122,763,181,610,195,237,69,222,115,639,15,69,360,893,124,468,235,386,150,1,2,147,171,1061,125,0,428,403,123,65,283,327,280,122,177,184,1172,786,26,396,125,429,178,478,1,543,43,59,354,749,353,129,296,131,31,11,195,346,2955,89,381,102,44,149,107,120,1574,271,167,202,173,177,30,2,735,1747,79,136,80,178,291,76,9,169,2633,80,784,130,303,482,166,607,149,550,1136,37,165,130,30,103,167,434,226,101,342,331,234,167,608,185,2,12,508,92,208,233,117,286,232,8,326,208,196,211,210,142,968,598,567,139,166,787,405,39,272,100,79,1,254,177,428,272,18,207,355,290,342,9,71,345,605,1594,2,0,8,146,344,1550,76,32,816,7,35,1246,18,9903,7,0,33891,112,289,22,9,14,74,68,316,149,0,0,0,0,13793,191,233,449,29,144,383,180,26,4,72,25,363,442,96,1,84,53,531,717,1778,562,2709,2140,0,0,0,513,620,352,202,135,468,102,366,258,396,900,120,46,185,80,40,1020,505,2729,230,2789,1474,29,13,20,6,160,160,102,370,18,9,99,69,103,96,134,104,240,158,107,98,84,56,146,136,297,88,41,4,43,52,414,33,4,145,31,7,384,103,181,298,27,198,170,3,73,24,116,233,320,72,199,177,497,401,225,396,48,95,2,2,7,4,8,227,4,45,383,124,197,52,79,39,64,1011,1173,109,522,1294,811,1656,4238,1649,2904,480,0,16795,0,18,2,0,0,0,0,0,0,0,0,5,19,27109,1076,9974,3604,468,588,296,58,23,8,247,10,135,166,587,219,88,286,88,70,129,118,280,336,140,355,316,751,203,1678,8836,10423,1543,67,9,5,1008,173,11243,1893,459,764,793,108,580,132,288,238,198,721,6031,2541,81,6,766,194,54,317,124,641,114,61,3905,386,454,676,924,335,205,342,385,363,901,577,1191,6650,4729,66,109,197,279,529,396,163,253,108,302,205,1675,2163,3362,470,460,585,174,1676,714,299,59,795,24,9,248,9,134,165,0,0,677,528,107,1388,87,50,53,579,214,7,16,74,287,87,337,69,127,203,395,341,120,137,141,249,289,281,364,1306,337,141,326,485,254,396,233,152,327,993,864,153,701,6789,559,39,40576,111,2,94532,121,2,2,20,1,2,1,52,689,103,382,1,80140,8275,25266,2997,2061,3522,3175,3171,3810,235,44,1060,61,190,31,4,7,155,1,1,57,207,274,19,565,24097,33632,4819,4545,5511,2976,3896,720,167,32,383,386,337,1,138,257,275,98,557,37,48,39,680,24535,2750,241,768,1404,997,791,620,177,139,114,194,4,274,24572,15449,13334,8781,9261,4526,2029,1825,599,543,683,893,355,25,21,41,108,466,31,219,403,9718,10956,2355,4751,998,572,21,1483,615,94,11,1084,950,696,563,19,195,13,38,87,11,89,8,13278,6884,5380,795,1562,191,443,97,535,429,479,148,635,300,385,262,83,27,202,18433,14329,5500,2246,899,1405,659,599,627,290,94,37,161,4,367,278,290,45,403,279,332,6,229,19260,10701,3730,1722,1667,460,1168,1766,407,328,152,32,392,433,28,88,34,18,51,511,23,1162,26108,6888,3920,2143,572,1645,5808,1432,2815,992,292,1351,658,216,818,985,740,715,68,205,1256,150,196,404,144,317,12,438,11022,7748,7631,4275,2229,1649,2001,878,2501,948,1147,2029,6,687,475,450,738,672,672,895,1520,1398,747,177,1469,40,117,5780,5603,3626,1928,938,147,2903,2098,540,561,181,978,201,80,787,1005,191,568,345,10,357,47,281,14,7885,2182,2963,891,3,467,2013,297,1512,295,9,6,56,1079,560,120,53,476,385,1033,5617,5791,241,1595,4961,2540,1577,2415,156,403,177,187,209,207,293,462,1120,977,90,39,55,392,2550,2098,1567,1428,974,521,828,1472,575,930,114,459,914,1807,69,684,1890,316,16,157,208,18,272,690,5558,2634,999,3363,473,461,179,383,459,323,192,962,309,1468,920,317,626,1003,1921,2033,242,492,1900,754,449,628,117,330,2028,815,2,602,518,647,19,4124,326,1475,563,772,1219,137,6,381,408,139,489,38,1319,3617,1203,3125,735,1165,308,344,1059,2523,1177,12,708,2947,2266,837,1725,1052,407,568,414,1343,1471,1046,199,13,804,2036,1466,398,1796,610,2613,949,1566,1581,1077,2164,306,507,1406,2664,450,906,204,1138,558,790,610,618,309,59,960,866,583,277,493,2164,4204,715,1589,161,152,481,188,66,1799,1607,380,1474,1587,661,38,242,1678,19,26,200,14,494,736,261,1829,296,1547,2318,760,360,636,564,486,808,310,356,167,651,1116,779,3959,1528,3355,609,384,5,854,172,716,809,392,569,964,113,576,402,156,399,1829,1153,436,345,810,386,7,302,448,178,931,8,10,383,1058,355,6,549,160,40,929,319,203,303,459,1154,734,327,808,522,584,3101,215,584,22,36,580,161,2012,258,217,480,545,906,501,242,1469,197,0,7,458,739,650,449,1990,1222,322,467,673,127,2666,1691,1326,516,541,25,677,193,613,659,1171,948,210,986,1348,295,79,649,915,546,331,206,4109,9037,7729,1267,464,2329,646,730,3427,0,1909,8365,5420,2031,3346,271,2178,258,1117,0,894,2610,190,67,85,112,23088,5087,2268,2310,1723,334,727,2710,1307,23751,1606,16143,5905,2394,2594,3471,8357,1260,608,669,998,20096,8151,1798,3455,7478,915,831,463,193,1360,18051,1083,7783,12445,14997,2008,7791,13572,15137,1911,913,7596,13662,10574,52876,53170,662,1144,5450,717,1381,169,84,579,419,651,91,244,59,40,2,334,19,1,22,189,25,1,3,12,86,109,147,549,23,88,81,45,131,32,8,0,0,73,38,76,359,173,334,233,210,2357,0,0,0,0,2132,6099,17820,1228,9217,463,777,1388,965,252,1213,425,279,992,234,77,265,339,150,187,138,319,671,164,93,1083,200,188,239,363,193,100,69,70,489,739,1246,90,1540,189,808,389,271,380,494,73,171,4619,1372,188,342,193,305,137,144,7,98,7127,3368,149,461,301,3988,1075,1408,146,674,137,378,96,470,202,2,299,527,676,206,249,229,7,160,335,52,112,473,428,1066,884,805,209,1762,0,0,1402,2641,1363,181,77,189,143,215,274,215,522,139,396,203,164,324,132,500,331,2077,1488,2344,1863,395,77,270,535,200,711,366,222,749,231,1400,5,247,142,682,181,5,2,131,2,727,17,150,699,295,285,432,0,148,593,814,516,379,187,224,394,190,332,65,28,51,81,31,216,1,2203,1444,39,1337,157,534,297,526,179,311,201,129,176,214,84,75,592,185,240,419,466,302,399,0,0,2308,315,246,407,118,137,450,839,307,239,260,469,152,359,56,141,566,1073,319,0,1711,1083,195,363,116,107,955,689,310,215,175,174,255,138,670,693,572,186,169,91,201,137,218,0,0,90,285,264,231,386,343,145,40,376,244,675,1373,136,902,1044,452,20,171,50,222,767,6,311,75,156,48,138,150,766,301,122,245,246,91,288,194,278,362,269,377,210,96,39,5,384,94,115,182,607,525,245,3,115,284,233,765,375,536,119,445,96,245,108,201,188,20,138,378,0,712,69,112,954,263,367,676,766,23,137,231,458,76,449,312,188,223,741,142,363,448,23,214,188,282,202,600,338,459,309,0,203,149,2,711,580,599,310,1843,344,230,131,54,945,710,174,1172,137,262,308,213,322,0,769,1546,535,85,90,232,273,230,2700,371,375,317,221,200,300,135,176,54,0,901,80,173,377,146,268,5,244,229,246,137,175,633,2300,1192,363,236,422,179,1181,243,298,378,96,625,1212,1176,1621,564,319,253,92,867,374,181,454,165,107,327,536,234,319,157,143,362,211,532,978,811,1494,322,1043,1404,305,172,316,182,402,409,687,226,423,571,683,279,574,146,138,376,85,166,393,953,449,392,765,106,362,397,351,38,307,230,4,68,252,187,89,185,326,91,76,173,189,188,135,126,114,325,423,153,537,954,313,431,784,525,145,355,230,79,898,280,795,537,130,318,156,20,192,31,452,536,342,728,362,353,230,3,307,15,2,9,24,3,2,1284,16,90,129,142,72,199,37,99,159,242,1052,180,134,111,401,297,312,51,245,131,299,642,96,155,179,75,813,1448,198,529,229,139,361,225,1014,342,499,714,1508,2460,2346,1877,2147,6387,5470,4917,8986,1922,8569,3652,26751,8490,76,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,1,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,5,2,1,4,1,2,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,2,0,0,1,1,1,1,1,12,1,4,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,0,0,0,0,2,1,1,0,0,0,0,1,0,1,0,1,1,1,2,1,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,1,1,2,24,3,2,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,1,1,2,7,6,1,1,1,1,5,1,3,1,6,1,2,21,11,2,4,1,1,1,1,1,1,23,14,3,2,1,1,234,73,35,1,5,12,3,2,2,1,4,2,469,136,3,1,3,3,6,3,4,14,41,14,5,3,9,1,1,1,1,1,1,612,27,8,6,5,4,3,2,5,7,10,10,5,20,50,50,45,37,13,13,11,3,4,4,1,1,65,47,9,17,4,24,13,19,5,3,3,12,8,10,18,42,36,117,94,119,202,136,155,42,33,7,1,8,10,10,14,13,14,11,13,12,4,9,4,10,25,8,4,6,5,4,2,4,4,3,22,8,8,1,6,5,5,18,12,2,24,10,1,10,7,5,6,4,8,4,9,11,4,10,3,2,9,7,4,6,2,5,7,4,3,14,7,4,24,4,10,1,7,14,13,26,9,5,1,14,34,24,23,42,11,3,1,6,2,3,0,45,46,33,24,8,14,2,0,0,92,72,56,27,5,1,2,1,0,0,0,0,0,0,172,108,72,33,9,1,2,2,2,1,0,0,0,0,0,0,0,0,0,0,272,87,55,11,5,1,1,1,1,0,0,0,0,0,0,0,0,0,0,311,109,34,13,3,10,6,2,2,3,3,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,280,40,37,23,6,4,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,43,30,16,8,4,4,1,2,1,1,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,36,18,11,3,8,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,40,8,10,8,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,17,9,4,1,2,6,4,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,13,9,3,1,2,3,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,4,5,2,2,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,1,1,1,3,2,2,0,0,0,0,0,0,0,0,0,0,0,0,4,2,4,2,4,2,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,1,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,1,0,2,0,2,0,1,0,1,3,1,1,0,0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,6,2,2,4,3,1,1,1,1,1,1,5,5,1,2,1,2,2,1,8,3,20,25,7,2,8,1,1,3,1,2,1,1,1,2,2,1,2,3,1,1,2,0,0,5,1,0,0,0,2,2,0,0,0,0,0,1,1,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,2,0,1,0,1,0,1,0,1,2,1,1,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,0,5,1,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,0,0,0,1,2,1,0,1,0,1,0,2,0,1,0,1,1,0,0,2,0,0,1,1,1,1,1,1,2,1,1,1,1,1,1,1,13,2,1,1,1,1,1,1,2,1,1,4,2,1,1,1,1,1,2,1,14,1,1,1,4,1,4,22,2,10,1,3,5,4,3,1,2,1,2,7,4,4,1,2,4,2,2,1,1,1,5,8,4,2,1,2,1,0,3,1,0,0,2,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,4,2,1,0,0,0,0,0,0,0,0,1,0,1,0,1,0,6,0,0,0,0,0,0,1,0,2,0,1,1,0,0,1,2,0,0,2,1,0,0,0,1,2,4,0,0,0,0,0,0,0,2,1,1,1,1,0,0,1,0,0,0,0,0,1,0,1,0,4,0,1,0,1,0,1,0,1,0,1,1,1,0,0,0,1,0,1,1,0,0,2,1,1,0,0,0,0,2,0,1,0,2,0,0,1,0,1,0,1,0,3,3,1,0,0,0,0,0,0,0,1,0,1,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,1,1,2,2,1,4,1,2,1,4,4,2,1,1,7,3,1,1,1,2,3,15,1,1,1,1,2,1,2,6,1,1,2,4,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,2,0,2,0,1,1,0,0,2,2,0,0,0,0,1,1,1,1,1,1,1,2,2,4,1,1,1,2,1,2,1,3,3,1,1,1,3,6,2,1,1,2,1,5,15,25,1,4,2,9,35,7,25,1,2,3,2,1,3,30,1,1,9,5,5,2,2,76,12,4,2,3,13,5,3,3,1,2,0,1,5,2,1,0,0,3,1,1,1,0,0,0,5,1,0,0,0,38,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,5,1,1,1,1,1,1,4,13,3,1,1,1,1,1,1,7,1,3,1,2,1,1,1,1,17,2,2,1,4,3,2,81,61,36,16,6,2,4,1,2,5,24,22,11,16,2,14,1,61,38,13,7,6,8,36,10,5,6,1,1,107,23,12,3,2,3,3,4,32,12,15,7,17,1,6,1,140,19,11,10,5,4,21,32,18,17,8,10,2,16,1,60,12,2,8,19,4,3,19,44,28,12,16,31,4,13,7,1,2,19,4,3,5,35,2,38,5,24,6,4,3,3,4,1,10,16,2,8,2,4,2,6,3,10,21,9,3,12,5,8,11,20,0,3,4,1,0,3,0,2,4,3,2,2,0,18,14,7,1,13,4,1,0,0,0,0,0,0,37,17,30,49,5,11,8,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,2,39,6,6,8,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,60,6,38,6,2,0,0,0,0,0,0,0,0,0,0,0,0,16,5,22,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,30,87,19,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,4,4,0,0,0,0,0,0,0,0,65,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,6,1,1,1,1,1,1,1,1,3,2,1,2,1,2,1,1,3,1,4,19,1,4,1,9,3,23,1,16,1,3,5,8,24,4,2,2,5,2,5,17,162,9,13,31,8,2,4,4,2,2,0,1,1,0,1,0,4,0,4,0,0,0,5,1,0,0,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,4,2,2,1,0,0,1,2,4,3,2,0,1,0,1,0,1,0,1,1,2,1,1,1,1,1,0,1,1,1,1,1,2,1,0,2,1,1,2,1,1,1,0,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,3,1,0,0,0,0,0,0,0,0,1,3,1,1,3,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,1,0,0,2,1,3,8,4,0,0,1,1,1,8,2,3,1,1,2,5,30,12,5,5,1,1,1,2,2,26,4,1,2,2,7,7,3,1,7,5,1,4,2,4,1,1,1,1,6,1,1,1,0,1,0,0,0,0,6,6,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,2,4,3,1,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,2,1,1,1,0,0,0,0,0,0,1,2,1,15,1,2,3,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,6,9,1,1,1,1,3,1,5,2,5,1,2,1,2,2,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,2,1,1,2,2,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,1,1,9,4,2,0,0,0,0,0,0,0,0,2,0,1,0,1,3,1,1,5,2,1,21,1,2,2,3,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,2,2,3,9,3,2,7,23,5,1,5,1,2,0,0,0,0,0,1,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,5,4,0,1,2,1,0,0,0,1,0,1,3,0,0,0,0,1,1,0,0,1,0,1,0,1,0,2,0,2,0,1,1,7,0,0,0,0,0,0,0,0,1,0,1,1,2,1,0,0,1,0,1,1,1,1,1,1,4,4,2,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,0,0,0,0,0,0,0,2,0,1,0,2,0,1,1,1,1,1,2,1,5,3,5,6,5,1,1,6,3,56,147,39,5,5,2,4,4,4,4,3,6,1,2,1,1,1,1,2,2,0,3,1,2,0,30,4,0,0,0,0,0,0,0,0,0,23,4,6,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,4,1,1,2,8,10,18,71,5,54,1,2,1,1,1,0,5,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,2,0,2,0,1,1,1,0,0,0,1,1,1,1,0,0,0,0,1,0,1,0,2,1,1,1,0,0,0,0,0,1,1,0,1,1,1,1,3,5,1,42,1,7,2,7,3,3,2,7,1,1,1,19,66,28,37,22,18,7,6,1,1,5,16,14,5,3,1,3,22,3,3,9,3,1,1,4,2,38,44,27,39,7,4,1,1,5,17,6,15,3,8,4,1,61,17,14,8,2,11,5,1,5,3,5,95,50,8,4,5,7,5,3,9,17,19,16,10,14,7,5,111,10,9,13,6,4,29,20,5,2,4,27,29,14,1,43,37,4,4,2,12,36,41,33,42,11,33,27,44,1,14,10,2,15,26,10,4,13,12,12,3,1,11,36,18,7,3,11,3,9,1,5,8,7,6,3,2,1,9,4,2,5,1,6,2,5,2,1,10,1,4,4,6,8,5,0,1,3,1,4,59,13,21,23,8,11,1,0,59,36,1,25,19,12,1,0,38,17,30,12,17,3,1,0,0,14,47,15,33,1,0,0,0,0,27,6,4,0,0,99,61,6,0,0,0,0,117,2,1,1,0,0,0,0,41,5,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,1,3,1,1,3,3,1,1,1,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,2,1,1,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,4,1,3,2,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,2,1,0,1,2,1,1,0,1,0,1,0,1,4,27,122,32,0,1,1,0,0,1,0],\"yaxis\":\"y\",\"type\":\"scattergl\"}],                        {\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"midpoint\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"depth\"}},\"legend\":{\"tracegroupgap\":0},\"title\":{\"text\":\"2L\"},\"height\":300,\"width\":750,\"shapes\":[{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":927246,\"x1\":927246,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":1274352,\"x1\":1274352,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":1418209,\"x1\":1418209,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":1571928,\"x1\":1571928,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":1776347,\"x1\":1776347,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":1947573,\"x1\":1947573,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2380981,\"x1\":2380981,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2381705,\"x1\":2381705,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2388594,\"x1\":2388594,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2391227,\"x1\":2391227,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2399996,\"x1\":2399996,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2403940,\"x1\":2403940,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2408422,\"x1\":2408422,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2408676,\"x1\":2408676,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2414061,\"x1\":2414061,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2416979,\"x1\":2416979,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2422650,\"x1\":2422650,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2422651,\"x1\":2422651,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2425051,\"x1\":2425051,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2425765,\"x1\":2425765,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2429616,\"x1\":2429616,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2429744,\"x1\":2429744,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2429896,\"x1\":2429896,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2430423,\"x1\":2430423,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2430816,\"x1\":2430816,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2430862,\"x1\":2430862,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2430879,\"x1\":2430879,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2430880,\"x1\":2430880,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2430904,\"x1\":2430904,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2431004,\"x1\":2431004,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2431060,\"x1\":2431060,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2432418,\"x1\":2432418,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":2435580,\"x1\":2435580,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":20288131,\"x1\":20288131,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":25429234,\"x1\":25429234,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":25429235,\"x1\":25429235,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":25635972,\"x1\":25635972,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":34073194,\"x1\":34073194,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":34100757,\"x1\":34100757,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":34118140,\"x1\":34118140,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":34118259,\"x1\":34118259,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"}]},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('3955e89a-f718-405f-ab47-e7a8388e3c50');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}, {"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"hovertemplate": "midpoint=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "", "marker": {"color": "lightsalmon", "symbol": "circle"}, "mode": "markers", "name": "", "showlegend": false, "type": "scattergl", "x": [2227, 12676, 12734, 12756, 43285, 43286, 43286, 43287, 43287, 43288, 43289, 43289, 43290, 43291, 73041, 86576, 88045, 106990, 183239, 183239, 183240, 183240, 183241, 183241, 183242, 183256, 183258, 183258, 183260, 183260, 183261, 183261, 183262, 183262, 183263, 183263, 183264, 183264, 272319, 306312, 431212, 431214, 431216, 431218, 431219, 454897, 454898, 454898, 622836, 622837, 622837, 622838, 622838, 622839, 622840, 622840, 622841, 622841, 622842, 622842, 622843, 787178, 787179, 787179, 787180, 791058, 869090, 869090, 869091, 869091, 869092, 869092, 869093, 869094, 869099, 869099, 869101, 869102, 869103, 869103, 869104, 869105, 869105, 869106, 869106, 869107, 869199, 869200, 869201, 869201, 869202, 869202, 869203, 869203, 869204, 869204, 869205, 1059579, 1181823, 1181824, 1181827, 1665943, 1745998, 2734160, 4184272, 5464868, 5464868, 5464869, 8358264, 8358319, 8358320, 8927043, 14246340, 14248692, 14248729, 14249109, 14249766, 30772552, 4469, 185482, 25383, 25459, 25491, 25534, 25539, 881959, 196023, 881874, 86587, 86587, 86587, 86587, 86587, 86588, 86588, 86590, 86588, 86589, 86588, 86591, 86588, 86589, 86589, 86589, 86590, 86593, 86590, 86593, 86594, 912392, 912503, 1102879, 86602, 86603, 226541, 226563, 666139, 666139, 912392, 912405, 912406, 226542, 226542, 226543, 226564, 226565, 666140, 912393, 912504, 1789299, 226563, 666140, 912393, 912406, 226543, 226563, 226564, 226567, 666146, 146094, 942142, 173163, 269827, 176102, 271297, 213992, 530378, 366479, 366480, 366486, 366497, 366499, 366501, 366480, 366481, 366482, 366488, 366494, 366496, 366496, 366497, 366499, 366502, 366512, 366481, 366482, 366486, 366496, 366496, 366497, 366497, 366498, 366498, 366499, 366500, 366501, 366505, 366510, 366511, 366512, 366482, 366496, 366497, 366498, 366499, 366499, 366500, 366501, 366502, 366503, 366504, 366504, 366505, 366507, 366507, 366508, 366510, 366513, 366516, 366517, 366517, 366518, 366502, 366503, 366504, 366505, 366507, 366509, 366511, 366511, 366512, 366514, 366517, 366504, 366505, 366516, 366501, 366502, 366503, 366512, 366518, 366523, 366512, 366517, 366518, 366512, 366517, 366519, 366530, 366534, 806094, 366514, 366514, 366515, 366518, 366534, 806094, 2900313, 366520, 806095, 366520, 366526, 806098, 1052349, 366518, 366525, 366526, 366536, 1052351, 366518, 366521, 366522, 366525, 366528, 366535, 366537, 806099, 1052350, 806097, 806102, 366522, 366523, 806098, 806099, 366538, 366540, 366522, 366523, 366527, 366539, 366539, 366540, 366522, 366523, 366539, 366540, 366524, 366524, 366540, 366540, 366541, 366541, 614476, 366525, 366525, 366530, 366535, 366540, 366540, 366541, 366525, 366526, 366529, 366534, 366541, 366541, 366542, 366526, 366529, 366530, 366535, 366536, 366538, 366540, 366541, 366541, 366542, 366533, 366538, 366540, 366542, 366542, 366543, 1052466, 366542, 366543, 366543, 366544, 366529, 366544, 638163, 806102, 806103, 806104, 366545, 614482, 366545, 614482, 1242846, 366546, 806105, 806106, 366539, 366548, 614487, 974326, 366540, 366548, 614483, 1052471, 1052368, 806108, 806108, 1052362, 1052474, 366550, 806109, 806110, 366544, 806110, 366551, 1052369, 1052376, 974331, 366552, 806112, 1929272, 366553, 806113, 806116, 1052368, 806115, 366555, 806114, 1052480, 366555, 614492, 638175, 1052381, 366556, 366557, 806115, 806116, 1929276, 366557, 366558, 455600, 593965, 614494, 614496, 638176, 806111, 806114, 806116, 806116, 806117, 806120, 806120, 970457, 974336, 1052369, 1052370, 1052370, 1052371, 1052375, 1052377, 1052378, 1052381, 1052383, 1052479, 1052480, 1052480, 1052481, 1052481, 1052482, 1052483, 1929276, 2917438, 806116, 806117, 806117, 806120, 806120, 970458, 974337, 974337, 1052370, 1052375, 1052479, 1052481, 806118, 1052370, 1052381, 1052484, 806117, 806118, 1052371, 1052484, 544653, 544656, 695709, 1141535, 612635, 929161, 821384, 834072, 846763, 846764, 854606, 878286, 1046231, 862443, 862444, 862444, 862445, 862445, 862445, 862446, 862446, 862449, 862449, 862451, 862452, 862449, 862450, 1300321, 1300337, 1054067, 1054068, 1054069, 1300321, 1300322, 1054069, 1218411, 1054070, 1054071, 1054072, 1300329, 1054072, 909807, 909808, 909808, 909809, 909810, 909811, 909808, 1077748, 1077748, 1077750, 1077747, 1077749, 1324015, 1077749, 1077750, 1324018, 1077751, 1245674, 1245688, 1245691, 1245674, 1245675, 1245675, 1245678, 1245679, 1245686, 1245690, 1245675, 1245676, 1245679, 1245690, 1245691, 1245691, 1245692, 1245693, 1245676, 1245677, 1245678, 1245679, 1245679, 1245691, 1245691, 1245692, 1245692, 1245693, 1245693, 1245677, 1245678, 1245679, 1245679, 1245680, 1245680, 1245681, 1245681, 1245688, 1245690, 1245691, 1245691, 1245692, 1245692, 1245693, 1245693, 1245694, 1245694, 1245695, 1245695, 1245693, 1245693, 1245694, 1245681, 1245696, 1245681, 1245682, 1245695, 1245696, 1245693, 1245696, 1245696, 1245697, 1245698, 1245694, 1245694, 1245695, 1245696, 1245697, 1245697, 1245698, 1245683, 1245693, 1245694, 1245694, 1245695, 1245697, 1245698, 1245698, 1245699, 1245699, 1245701, 1245694, 1245696, 1245698, 1245698, 1245699, 1245700, 1245698, 1245700, 1245699, 1245701, 1245700, 1245703, 1491942, 1245705, 1245708, 1245706, 1245707, 1245710, 1491943, 1491954, 1245706, 1245707, 1245707, 1245708, 1245709, 1245709, 1491944, 1492054, 1245707, 1245708, 1245709, 1245709, 1245710, 1245711, 1333716, 1410033, 1413911, 1413912, 1491944, 1491945, 1491954, 1491958, 1492056, 1492056, 1492057, 1492058, 1245708, 1245709, 1245710, 1245710, 1245711, 1413912, 1413912, 1491945, 1491945, 1491946, 1491960, 1492057, 1492058, 1245709, 1245710, 1245710, 1245711, 1245711, 1245712, 1245712, 1491946, 1491956, 1492056, 1492057, 1492058, 1245710, 1245711, 1245711, 1491946, 1491946, 1491950, 1492056, 1492058, 1492059, 1245711, 1245712, 1245712, 1245713, 1245713, 1410032, 1413913, 1413914, 1491944, 1491946, 1491946, 1491947, 1491948, 1491950, 1491956, 1491959, 1491960, 1491961, 1491963, 1492056, 1492058, 1492058, 1492059, 1492060, 1804679, 2368853, 1245712, 1245713, 1245715, 1410034, 1410035, 1413914, 1433403, 1491946, 1491947, 1491947, 1491948, 1491948, 1491950, 1491952, 1491957, 1491959, 1491960, 1491963, 1491963, 1492057, 1492058, 1492059, 1492060, 2368854, 1245713, 1245714, 1410035, 1413914, 1433403, 1491946, 1491947, 1491947, 1491948, 1491948, 1491949, 1491949, 1491951, 1491953, 1491962, 1491963, 1491963, 1491964, 1491964, 1492056, 1492057, 1492059, 1492059, 1492060, 1492060, 1492061, 1682436, 3357016, 3357017, 6087724, 1245714, 1245715, 1410036, 1410037, 1413915, 1491947, 1491948, 1491948, 1491957, 1491959, 1491960, 1492060, 1682435, 2368855, 1410036, 1413915, 1413916, 1491948, 1491949, 1491950, 1491954, 1491959, 1491962, 1492061, 1492062, 1410037, 1491949, 1491950, 1491950, 1491954, 1492061, 1491955, 1491951, 1421739, 1501934, 1574355, 1574369, 1574370, 1574358, 1574371, 1574371, 1574372, 1574372, 1578250, 1656283, 1656283, 1656284, 1656287, 1656293, 1656294, 1656295, 1656297, 1656393, 1656394, 1656395, 1656396, 2533190, 1582116, 1582128, 1582128, 1582129, 1582129, 1582130, 1582131, 1582129, 1582129, 1582130, 1582141, 1660171, 1582141, 1660162, 1660164, 1660161, 1660162, 1660162, 1660176, 1660177, 1660274, 1850650, 1660162, 1660163, 1660175, 2537069, 1660163, 1660164, 1621118, 1621119, 1679676, 1679684, 1738195, 1738181, 1738182, 1738196, 1738181, 1738182, 1738186, 1738187, 1738196, 1738197, 1738198, 1738182, 1738183, 1738183, 1738184, 1738184, 1738186, 1738187, 1738189, 1738190, 1738192, 1738192, 1738193, 1738194, 1738195, 1738195, 1738196, 1738196, 1738197, 1738197, 1738198, 1738198, 1738199, 1738199, 1738200, 1738202, 1738183, 1738184, 1738184, 1738185, 1738185, 1738186, 1738187, 1738187, 1738188, 1738188, 1738191, 1738192, 1738192, 1738193, 1738193, 1738194, 1738194, 1738195, 1738195, 1738196, 1738196, 1738197, 1738197, 1738198, 1738198, 1738199, 1738199, 1738200, 1738200, 1738201, 1738201, 1738202, 1738203, 1738204, 1738184, 1738185, 1738188, 1738195, 1738195, 1738196, 1738196, 1738197, 1738198, 1738198, 1738199, 1738199, 1738200, 1738185, 1738188, 1738189, 1738191, 1738194, 1738195, 1738196, 1738197, 1738198, 1738198, 1738199, 1738200, 1738200, 1738201, 1738203, 1738205, 1738208, 1738210, 1738212, 1738199, 1738200, 1738200, 1738201, 1738213, 1738194, 1738200, 1738202, 1738213, 1738190, 1738200, 1738209, 1738215, 1738216, 1738190, 1738217, 1738206, 1738217, 1738199, 1738199, 1738201, 1738211, 1738216, 1738199, 1738201, 1738202, 1738202, 1738203, 1738204, 1738204, 1738209, 1738218, 1738196, 1738197, 1738201, 1738204, 1738205, 1738205, 1738218, 1738219, 1738194, 1738201, 1738203, 1738204, 1738204, 1738196, 1738199, 1738200, 1738204, 1738221, 1738207, 1738201, 1738203, 1738205, 1738221, 1738221, 1738203, 1738204, 1738208, 1738202, 1738203, 1738204, 1738204, 1738207, 1738210, 1738210, 1738215, 1738223, 1738223, 1738204, 1738205, 1738206, 1738211, 1738223, 1738204, 1738205, 1738208, 1738209, 1738210, 1738211, 1738223, 1738223, 1738205, 1738206, 1738207, 1738208, 1738208, 1738211, 1738207, 1738208, 1738208, 1738209, 1738210, 1738210, 1738212, 1738213, 1738213, 1738215, 1738223, 1738227, 1738208, 1738209, 1738209, 1738210, 1738210, 1738212, 1738213, 1738213, 1738216, 1738224, 1738224, 1738225, 1738225, 1738226, 2615101, 1738209, 1738209, 1738210, 1738211, 1738211, 1738212, 1738212, 1738223, 1738225, 1738307, 1770490, 1738209, 1738210, 1738210, 1738211, 1738211, 1738212, 1738213, 1738215, 1738225, 1738226, 1738226, 1738227, 1738228, 1738307, 1738210, 1738211, 1738211, 1738212, 1738213, 1738215, 1738226, 1738226, 1738227, 1738227, 1738229, 1738308, 1738308, 1738211, 1738212, 1738212, 1738213, 1738214, 1738215, 1738216, 1738225, 1738226, 1738227, 1738227, 1738228, 1738309, 1738309, 1738212, 1738213, 1738213, 1738214, 1738214, 1738215, 1738217, 1738218, 1738222, 1738225, 1738226, 1738227, 1738227, 1738228, 1738229, 1738310, 1738213, 1738214, 1738214, 1738215, 1738215, 1738216, 1738217, 1738220, 1738227, 1738228, 1738228, 1738229, 1738230, 1738309, 1738309, 1738310, 1738310, 2615104, 1738214, 1738215, 1738215, 1738216, 1738217, 1738218, 1738219, 1738228, 1738228, 1738229, 1738308, 1738309, 1738310, 1738310, 1738311, 2050933, 1738215, 1738216, 1738216, 1738217, 1738218, 1738219, 1738220, 1738221, 1738223, 1738228, 1738229, 1738229, 1738230, 1738231, 1738231, 1738309, 1738310, 1738310, 1738312, 2050931, 2615105, 1738216, 1738217, 1738217, 1738218, 1738218, 1738220, 1738229, 1738229, 1738230, 1738230, 1738231, 1738231, 1738308, 1738309, 1738311, 1738312, 1738312, 1738217, 1738218, 1738218, 1738219, 1738219, 1738222, 1738222, 1738229, 1738229, 1738230, 1738230, 1738231, 1738310, 1738311, 1738311, 1738312, 1738312, 1738313, 1738219, 1738219, 1738220, 1738221, 1738228, 1738230, 1738230, 1738231, 1738311, 1738311, 1738312, 1738312, 1738313, 1738313, 2050932, 6333977, 1738219, 1738220, 1738226, 1738231, 1738232, 1738233, 1738312, 1738312, 1738221, 1738223, 1738223, 1738228, 1738231, 1738231, 1738232, 1738233, 1738311, 1738312, 1738313, 1738230, 1738231, 1738232, 1738233, 1738313, 1738314, 1738315, 1738222, 1738231, 1738232, 1738235, 1738313, 1738227, 1738235, 1738314, 1738233, 1738312, 1738315, 1738315, 1738230, 1738233, 1738234, 1738236, 1738314, 1738315, 1738235, 1738316, 2050936, 1738233, 1738234, 1738236, 1738235, 1738236, 1738316, 1738234, 1738238, 1738318, 1738237, 1738238, 1738238, 1738236, 1738240, 1738320, 1738239, 1738240, 1738242, 1738322, 1738324, 1738241, 1738242, 1738322, 1738323, 1738323, 1738241, 1738243, 1738320, 1738322, 1738323, 1738323, 1738242, 1738243, 1738243, 1738244, 1738245, 1738245, 1738322, 1738323, 1738324, 1738324, 1738325, 2615119, 2802082, 1738243, 1738244, 1738245, 1738245, 1738321, 1738323, 1738323, 1738324, 1738324, 1738325, 1738325, 1738326, 1928698, 2387377, 2615119, 3603282, 1738244, 1738246, 1738322, 1738323, 1738323, 1738324, 1738325, 1738325, 1738326, 1738326, 1928701, 1928701, 2050946, 2615120, 1738245, 1738246, 1738246, 1738322, 1738323, 1738323, 1738324, 1738324, 1738325, 1738325, 1738326, 1738326, 1738327, 1738327, 1928702, 2050946, 2502839, 2615120, 1738325, 1738326, 2615121, 1738247, 1738323, 1738326, 1738326, 1738327, 1738327, 1738328, 1738324, 1738325, 1738325, 1738326, 1738327, 1738328, 1738328, 2050949, 2615122, 6333993, 1738327, 1738418, 1738422, 1738402, 1738402, 1738403, 1738403, 1738402, 1738403, 1738403, 1738402, 1738403, 1738404, 1738404, 1738405, 1738418, 1738419, 1738403, 1738404, 1738404, 1738405, 1738406, 1738418, 1738404, 1738405, 1738405, 1738406, 1738419, 1738421, 1738424, 1738428, 1738405, 1738406, 1738406, 1738407, 1738420, 1738422, 1738423, 1738424, 1738424, 1738425, 1738406, 1738407, 1738407, 1738408, 1738419, 1738420, 1738420, 1738421, 1738421, 1738422, 1738422, 1738423, 1738423, 1738424, 1738424, 1738425, 1738425, 1738426, 1738427, 1738428, 1738407, 1738408, 1738408, 1738419, 1738420, 1738421, 1738422, 1738422, 1738423, 1738423, 1738424, 1738424, 1738425, 1738426, 1738427, 1738427, 1738429, 1738408, 1738416, 1738419, 1738421, 1738421, 1738422, 1738422, 1738423, 1738423, 1738424, 1738424, 1738425, 1738425, 1738426, 1738426, 1738427, 1738428, 1738409, 1738410, 1738410, 1738420, 1738421, 1738421, 1738422, 1738422, 1738423, 1738423, 1738424, 1738424, 1738425, 1738425, 1738426, 1738426, 1738427, 1738427, 1738431, 1738421, 1738422, 1738422, 1738423, 1738423, 1738424, 1738424, 1738425, 1738426, 1738428, 1738429, 1738423, 1738421, 1738431, 1738433, 1738435, 1738435, 1738435, 1738435, 1738436, 1738436, 2615214, 1738434, 1738435, 1738436, 1738436, 1738437, 1738435, 1738436, 1738436, 1738437, 1738437, 1738438, 1738439, 1928794, 1928797, 2615215, 5053532, 1738436, 1738437, 1738437, 1738438, 1738438, 1738439, 1738440, 2615216, 4946355, 1738437, 1738438, 1738438, 1738439, 1738439, 1738440, 1738444, 1770605, 1928797, 1928798, 2051042, 2615216, 6334085, 1738438, 1738439, 1738439, 1738440, 1738440, 1738443, 1738444, 1738446, 1928798, 1928803, 1981545, 2051046, 2615217, 3603378, 3603379, 4946357, 6334087, 1738439, 1738440, 1738440, 1738441, 1738441, 1738442, 1738442, 1738443, 1738443, 1738444, 1738444, 1738446, 1884142, 1928797, 1928798, 1928798, 1928799, 1928800, 1960714, 2051043, 2051043, 2051044, 2051045, 2615217, 2817589, 3603379, 5053526, 6334088, 1738440, 1738441, 1738441, 1738442, 1738442, 1738443, 1738443, 1738444, 1738446, 1738447, 1928798, 1928799, 1928799, 2051043, 2051046, 2077037, 2409458, 2535163, 2615218, 4946357, 5053492, 6334088, 1738441, 1738442, 1738442, 1738443, 1738443, 1738444, 1738444, 1738445, 1738445, 1738446, 1928797, 1928798, 1928799, 1928800, 1948868, 2051044, 2573596, 2606258, 2615218, 2615218, 2615306, 3586277, 3603380, 4946358, 5053531, 1738442, 1738443, 1738443, 1738444, 1738444, 1738445, 1738445, 1738446, 1738447, 1738447, 1738448, 1928795, 1928798, 1928798, 1928799, 1928800, 1992498, 2051044, 2051046, 2051046, 2615219, 3603381, 6334089, 1738443, 1738444, 1738444, 1738445, 1738445, 1738446, 1738447, 1928798, 1928799, 1928799, 1928800, 1928801, 2615219, 1738444, 1738445, 1738445, 1738446, 1738447, 1738448, 1738448, 1928799, 1928800, 1928801, 1928801, 2051045, 2615220, 3082886, 3586278, 3586280, 3603382, 1738445, 1738446, 1738446, 1738447, 1738447, 1738448, 1738449, 1740248, 1928797, 1928799, 1928799, 1928800, 1928801, 1928801, 1928802, 2010616, 2051046, 2051047, 2051048, 2077039, 2535166, 2615220, 3586278, 3603382, 5053494, 5053529, 1738446, 1738447, 1738447, 1738448, 1738449, 1738450, 1770608, 1928799, 1928800, 1928800, 1928801, 1928801, 1928802, 1928804, 2051046, 2051050, 2535167, 2615221, 1738447, 1738448, 1738448, 1738449, 1738450, 1928800, 1928801, 1928801, 1928802, 1928802, 1928803, 2051048, 2615221, 3603383, 5053495, 1738448, 1738449, 1738450, 1738450, 1738454, 1928797, 1928798, 1928801, 1928802, 1928803, 1928803, 2051047, 2051048, 2051048, 2051051, 2077041, 2387479, 2535167, 2615222, 2615245, 2615276, 2615279, 1738449, 1738450, 1738451, 1738451, 1738452, 1928801, 1928802, 1928803, 1928804, 1928804, 2461230, 2535168, 2615222, 3603384, 1738450, 1738451, 1738452, 1740250, 1928802, 1928803, 1928804, 1981551, 2051050, 2051051, 2387479, 2615223, 1928802, 1928804, 1928804, 1928805, 2051050, 2615223, 1738452, 1738454, 1928803, 1928804, 1928805, 1948874, 2051053, 2615224, 1738453, 1928802, 1928803, 1928804, 2051050, 2615224, 1738454, 1928801, 1928806, 2615225, 1928805, 1928805, 1928806, 2409466, 2615225, 1928805, 2051054, 1742054, 1742061, 1742109, 1742116, 1742192, 1930660, 2078928, 1802786, 1802788, 1960974, 2405995, 6094964, 2029861, 2760936, 2119152, 2119168, 2119153, 2119166, 2119168, 2119153, 2119169, 2119153, 2119154, 2119154, 2119155, 2119156, 2119156, 2119171, 2119172, 2119172, 2119155, 2119156, 2119156, 2119157, 2119171, 2119172, 2119172, 2119173, 2119174, 2119156, 2119157, 2119157, 2119173, 2119173, 2119157, 2119158, 2119159, 2119173, 2119173, 2119174, 2119158, 2119173, 2119174, 2119174, 2119175, 2119171, 2119172, 2119173, 2119174, 2119174, 2119175, 2119175, 2119175, 2119176, 2119177, 2119180, 2119187, 2796629, 2119188, 2119188, 2119189, 2805592, 2119189, 2119190, 2241416, 2241417, 2241418, 2241419, 2241420, 2241420, 2241421, 2267411, 2805592, 2805615, 2119190, 2119191, 2139243, 2241416, 2241417, 2241418, 2241419, 2241419, 2241421, 2241421, 2267412, 2487193, 2569171, 2725538, 2725539, 2805592, 2805593, 2805644, 6524463, 2151090, 2241419, 2241419, 2651260, 2667171, 2725536, 2805593, 2805593, 3793755, 6524463, 2241419, 2805594, 2805594, 2241424, 2159306, 2159307, 2159308, 2159436, 2159439, 2159439, 2159566, 2159568, 2159568, 2261614, 2825787, 2182999, 2183080, 2183080, 2183161, 2183161, 2837583, 5275857, 2224663, 2224665, 2858335, 2294162, 2246566, 2869287, 2282931, 2887535, 2363657, 2363645, 2363660, 2363647, 2363648, 2363649, 2363649, 2363651, 2363661, 2363662, 2363662, 2363663, 2363663, 2363664, 2363664, 2363667, 2363662, 2363663, 2363663, 2363664, 2363664, 2363665, 2363665, 2363666, 2363650, 2363664, 2363664, 2363665, 2363668, 2363670, 2363651, 2363665, 2363663, 2363666, 2363662, 2363664, 2363664, 2363665, 2363665, 2363666, 2363667, 2363668, 2363666, 2363669, 2363670, 2363666, 2363670, 2927834, 2363675, 2789413, 2927835, 2927836, 2927892, 2363677, 2363679, 2363681, 2847781, 2847782, 2927836, 2363679, 2363679, 2927837, 2363679, 2363680, 2363683, 2389656, 2722078, 2847783, 2927837, 3898895, 2363680, 2927838, 3915999, 3916000, 5366135, 2927838, 2927887, 2847784, 2927838, 2927839, 4163829, 2927839, 2927840, 2927840, 2927841, 2927834, 2927842, 6646712, 2927844, 2415695, 2415700, 2415761, 2415770, 2415844, 2415846, 2415917, 2953956, 2953957, 2855272, 3173672, 3009262, 3250666, 3019163, 3255585, 3036521, 3036522, 3036523, 3264264, 3109931, 3264265, 3080491, 3080491, 3080492, 6012391, 3286251, 3286252, 3183340, 3183342, 3257622, 3337675, 3184023, 3338016, 3215162, 3273530, 3353585, 3267439, 3267505, 3267579, 3267593, 3379795, 3331894, 3331900, 3331901, 3331901, 3331903, 3331900, 3331901, 3331900, 3331901, 3331902, 3411951, 3411954, 3411954, 4367851, 3331914, 3411955, 3411955, 3411955, 3411956, 5850230, 3411956, 3411958, 3408760, 3450383, 3474087, 3483047, 4471213, 3491988, 3491995, 3491996, 3491997, 3491998, 3491998, 3491999, 3492006, 3492007, 3492007, 3492017, 3492018, 3492018, 3492019, 3492071, 3491998, 3491998, 3492018, 3492019, 3492019, 3491999, 3492000, 3492020, 3492000, 3492009, 3492020, 3492021, 3492003, 3492020, 3492021, 3492021, 3492022, 3492023, 3492016, 3492029, 3492017, 3492018, 3492030, 3492030, 3492067, 5930281, 5930316, 3492040, 3492040, 3492041, 3492041, 3492042, 3492043, 3492043, 3492044, 3492044, 3492045, 3492046, 3492046, 3492047, 3492047, 3492048, 3492049, 3492049, 3492050, 3492051, 3492052, 3492054, 3492054, 3492058, 3492060, 3492061, 3492061, 3492062, 3492063, 3492063, 3492064, 3492064, 3492065, 3492065, 3492066, 3492067, 3492068, 3492068, 3492069, 3492069, 3492070, 3492070, 3492071, 3492071, 3492072, 3492072, 3492073, 3492073, 3492074, 3492075, 3492076, 3492077, 3492077, 3492078, 3492079, 3492081, 3492083, 3492085, 3492092, 3492092, 3492094, 3492094, 3492045, 3492045, 3492047, 3492049, 3492063, 3492063, 3492065, 3492067, 3492069, 3492069, 3492076, 3492077, 3492094, 3492095, 3492050, 3492070, 3492078, 3492095, 3492068, 3492054, 3492065, 3492068, 3492070, 3492071, 3492096, 3492051, 3492065, 3492068, 3492095, 3492097, 3492057, 3492061, 3492074, 3492098, 3492073, 3492072, 3492074, 3492099, 3492069, 3492074, 3492099, 3492073, 3492079, 3492069, 3492076, 3492101, 3492070, 3492075, 3492076, 3492102, 3492069, 3492103, 3492071, 3492104, 3492083, 3492106, 3492107, 3492080, 3492078, 3492110, 3492085, 3492089, 3492112, 3492083, 3492096, 3492113, 3492088, 3492091, 3492099, 3492114, 3492084, 3492088, 3492092, 3492088, 3492089, 3492090, 3492094, 3492096, 3492108, 3492110, 3492112, 3492115, 3492089, 3492092, 3492093, 3492099, 3492115, 3492097, 3492116, 3492092, 3492094, 3492095, 3492096, 3492097, 3492090, 3492092, 3492100, 3492116, 3492117, 3492092, 3492094, 3492096, 3492090, 3492091, 3492090, 3492094, 3492092, 3492094, 3492093, 3492096, 3492097, 3492093, 3492094, 3492095, 3492097, 3492103, 3492120, 3492094, 3492095, 3492096, 3492096, 3492097, 3492097, 3492102, 3492105, 3492112, 3492113, 3492118, 3492118, 3492120, 3492096, 3492098, 3492100, 3492120, 3492121, 3492096, 3492098, 3492098, 3492101, 3492103, 3492116, 3492118, 3492121, 3492121, 3492098, 3492099, 3492102, 3492103, 3492107, 3492108, 3492109, 3492113, 3492115, 3492121, 3492122, 3492098, 3492122, 3492122, 3492099, 3492100, 3492106, 3492117, 3492123, 3492101, 3492103, 3492121, 3492123, 3492123, 3492105, 3492115, 3492120, 3492121, 3492122, 3492123, 3492124, 3492124, 3492104, 3492119, 3492121, 3492121, 3492123, 3492125, 3492105, 3492117, 3492118, 3492119, 3492105, 3492116, 3492126, 3492126, 3492126, 3492118, 3492127, 3492128, 3492111, 3492123, 3492127, 3492128, 3492128, 3492129, 3492130, 3492130, 3492130, 3492131, 3492131, 3492131, 3492132, 3492133, 3492134, 3492135, 3492137, 3492138, 3492138, 4463121, 3492139, 3492140, 3492137, 3492140, 3492140, 3492141, 3492139, 3492142, 3492143, 3492143, 3492144, 3492144, 3492145, 3492145, 3492145, 3492145, 3492146, 5930444, 3492146, 3492147, 3492148, 3492148, 3492153, 3492156, 3492161, 3492163, 3492163, 3492164, 3492165, 3492165, 3492166, 3492167, 3492167, 3492168, 3492168, 3492169, 3492169, 3492170, 3492170, 3694442, 4480233, 4480234, 5417685, 5930345, 7210941, 3492149, 3492160, 3492161, 3492163, 3492164, 3492165, 3492167, 3492168, 3492169, 3492169, 3492170, 3492170, 3492171, 3492165, 3492171, 3492176, 3492179, 3492172, 3492183, 3492184, 3492184, 3492185, 3492186, 3492184, 3492186, 3492187, 3492187, 3492188, 3492188, 3492189, 3492189, 3492189, 3492190, 3492190, 3492191, 3492191, 3492191, 3492191, 3492192, 3492192, 3492193, 3492194, 3504012, 3504013, 3648547, 3679057, 3680754, 3694464, 3694465, 3780411, 3853590, 3904491, 3943087, 3959763, 4067883, 4109027, 4147363, 4163450, 4183436, 4217090, 4426353, 4463150, 4463151, 4463152, 4463152, 4463153, 4463153, 4463154, 4463154, 4480253, 4480255, 4480255, 4480256, 4480256, 4480257, 4480257, 4480258, 4480258, 4480259, 4480261, 4728084, 4959365, 4966839, 5091344, 5268949, 5417708, 5450932, 5823233, 5823234, 5823234, 5823235, 5823237, 5854631, 5930368, 5930368, 5930403, 7210964, 10104386, 10866241, 15992437, 32518649, 3492263, 4480257, 4480257, 4480259, 5823234, 5930369, 3680755, 4480258, 5823235, 5930369, 3492334, 5930439, 3515844, 3515844, 4492088, 4492088, 3804919, 3804920, 3804921, 3804925, 4619525, 4636629, 4636630, 4636631, 6086747, 3865937, 3865937, 4667135, 6117248, 3869330, 4916660, 6118944, 3896747, 3896748, 3896749, 3896750, 4682539, 6132651, 4987051, 6132653, 4068641, 4768487, 4214999, 4215000, 4841667, 6291778, 4316824, 4875485, 4394017, 4931186, 4427344, 4427350, 4930736, 4947843, 4643632, 5056005, 4725873, 5097103, 6547215, 4802544, 5135438, 4834723, 6601641, 4874731, 6621664, 4941998, 4942004, 6655276, 5188066, 5360525, 5397324, 5403802, 5436067, 5434123, 5434124, 5434125, 5434111, 5434121, 5434112, 5434124, 5434126, 5434127, 5434127, 5434128, 5434128, 5434127, 5434128, 5434128, 5434129, 5434126, 5434127, 5434128, 5434126, 5434129, 5434129, 5434217, 5434140, 5434219, 5434220, 5451229, 5434222, 5699058, 5434142, 6388682, 5434142, 5451231, 5451231, 5451232, 6794208, 6794209, 6901342, 6901343, 7128554, 8181939, 5434222, 5451231, 5451231, 5451232, 5451232, 5451233, 6794209, 6901343, 6901343, 7128554, 8181937, 8181938, 5451232, 6794209, 6901344, 5451233, 5434312, 5434312, 5434313, 5434315, 5451321, 5451321, 5451322, 6901433, 8182029, 5451322, 5468316, 5468319, 5468335, 5468319, 5468336, 5468319, 5468320, 5468321, 5468334, 5468334, 5468335, 5468335, 5468336, 5468336, 5468338, 5468320, 5468321, 5468322, 5468333, 5468334, 5468334, 5468335, 5468335, 5468336, 5468336, 5468337, 5468321, 5468322, 5468322, 5468323, 5468324, 5468333, 5468335, 5468335, 5468336, 5468336, 5468337, 5468337, 5468338, 5468322, 5468323, 5468336, 5468337, 5468337, 5468338, 5468338, 5468339, 5468324, 5468337, 5468337, 5468338, 5468338, 5468339, 5468339, 5468340, 5468341, 5468324, 5468327, 5468336, 5468337, 5468337, 5468338, 5468338, 5468339, 5468339, 5468338, 5468340, 5468339, 5468340, 5468341, 5468342, 5468339, 5468341, 5468345, 5468348, 5468349, 5716161, 6414836, 5468349, 5468351, 5468350, 5468351, 6811312, 6918446, 5468350, 5468351, 5468351, 5468352, 5468352, 6811312, 6918446, 6918447, 8199043, 5468351, 5468352, 5468352, 5468354, 5468356, 5716163, 5733288, 6405788, 6811313, 6811313, 6918447, 6918447, 6918484, 8199043, 5468352, 5468353, 5716164, 5810342, 6018615, 6405788, 6642843, 6811313, 6811314, 6918447, 6918448, 8199044, 5468353, 5468354, 5468355, 5716164, 6224282, 6811312, 6811314, 6811314, 6918448, 6918448, 6918483, 6918484, 8199044, 5468355, 5716165, 6079425, 6606642, 6811314, 6811315, 6828951, 6918448, 6918449, 6918503, 8199044, 5468356, 5468357, 5716165, 6811315, 6918449, 6918449, 6918450, 5468359, 5716166, 6811316, 6811316, 6918450, 7927741, 8199046, 5716167, 6918451, 6918452, 6918452, 6918452, 6811318, 5963988, 5963989, 5963990, 5963991, 5963991, 5963992, 7166272, 6854468, 7166273, 5964005, 6921251, 7059139, 7059140, 7166274, 6653615, 6807487, 7059140, 7166275, 7059141, 7166275, 5998236, 6703958, 6077353, 7222954, 6152347, 7260453, 6426548, 7397551, 6441497, 7297892, 6568888, 7468721, 6690508, 6690511, 6690580, 7422400, 6690652, 7529604, 6980226, 7674393, 7045715, 7707135, 7343239, 7343239, 7343240, 7343240, 7343240, 7855899, 7855937, 7855899, 7855900, 7855900, 7361336, 7757812, 7409686, 7781988, 7889122, 7650989, 8009777, 7744945, 7744947, 8056752, 8056752, 7817340, 7817416, 7817488, 7985884, 7878521, 8123543, 8154287, 8154289, 8154289, 8154275, 8154276, 8154289, 8154290, 8154290, 8154291, 8154291, 8154277, 8154290, 8154291, 8154291, 8154293, 8154291, 8154291, 8154292, 8154293, 8154294, 8154280, 8154293, 8154294, 8261423, 8261424, 8154305, 8154306, 8261424, 8261424, 8261459, 8350737, 9542019, 9542020, 8154306, 8261424, 8261425, 8407399, 9542021, 8261425, 8261425, 8261425, 8261426, 8261427, 8189563, 8279061, 8217081, 8292818, 8368543, 8368544, 8368545, 8368546, 8368556, 8368557, 8368558, 8368560, 8368563, 8368565, 8368569, 8368575, 8368577, 8368578, 8368578, 8368579, 8368580, 8368586, 8368594, 8368609, 8368611, 8368617, 8368619, 8368545, 8368546, 8368548, 8368573, 8368578, 8368578, 8368579, 8368578, 8368579, 8368580, 8368581, 8368582, 8368590, 8368592, 8368593, 8368586, 8368595, 8368597, 8368599, 8368615, 8368603, 8368604, 8368606, 8368610, 8368611, 8368612, 8368612, 8368613, 8368614, 8368614, 8368615, 8368616, 8368616, 8368617, 8368618, 8368618, 8368619, 8368619, 8368621, 8368621, 8368622, 8368622, 8368623, 8368624, 8368624, 8368625, 8368626, 8368627, 8368627, 8368628, 8368628, 8368629, 8368629, 8368630, 8368630, 8368631, 8368631, 8368632, 8368632, 8368633, 8368633, 8368634, 8368634, 8368635, 8368635, 8368636, 8368637, 8368637, 8368638, 8368639, 8368639, 8368640, 8368640, 8368642, 8368643, 8368644, 8368645, 8368645, 8368646, 8368646, 8368647, 8368648, 8368649, 8368651, 8368652, 8368652, 8368653, 8368653, 8368654, 8368656, 8368614, 8368615, 8368615, 8368616, 8368616, 8368617, 8368617, 8368618, 8368620, 8368620, 8368621, 8368622, 8368624, 8368624, 8368627, 8368628, 8368628, 8368629, 8368629, 8368630, 8368630, 8368631, 8368631, 8368632, 8368632, 8368633, 8368633, 8368634, 8368635, 8368635, 8368636, 8368636, 8368637, 8368638, 8368638, 8368639, 8368640, 8368642, 8368643, 8368644, 8368645, 8368646, 8368647, 8368648, 8368649, 8368650, 8368652, 8368654, 8368654, 8368616, 8368618, 8368619, 8368623, 8368629, 8368629, 8368630, 8368632, 8368632, 8368633, 8368635, 8368637, 8368648, 8368648, 8368653, 8368655, 8368618, 8368618, 8368626, 8368630, 8368632, 8368633, 8368636, 8368639, 8368619, 8368620, 8368621, 8368622, 8368626, 8368628, 8368630, 8368631, 8368631, 8368632, 8368633, 8368634, 8368634, 8368635, 8368635, 8368639, 8368640, 8368645, 8368647, 8368652, 8368619, 8368653, 8368620, 8368624, 8368627, 8368628, 8368633, 8368636, 8368646, 8368622, 8368632, 8368632, 8368633, 8368634, 8368635, 8368635, 8368636, 8368637, 8368639, 8368640, 8368643, 8368655, 8368655, 8368623, 8368624, 8368625, 8368626, 8368628, 8368629, 8368629, 8368630, 8368632, 8368633, 8368634, 8368635, 8368637, 8368637, 8368638, 8368641, 8368647, 8368648, 8368656, 8368624, 8368631, 8368633, 8368634, 8368635, 8368635, 8368636, 8368639, 8368639, 8368645, 8368659, 8368630, 8368630, 8368634, 8368636, 8368641, 8368660, 8368627, 8368628, 8368631, 8368635, 8368636, 8368636, 8368638, 8368640, 8368642, 8368642, 8368646, 8368655, 8368658, 8368660, 8368635, 8368630, 8368632, 8368635, 8368637, 8368638, 8368641, 8368642, 8368642, 8368643, 8368645, 8368652, 8368662, 8368648, 8368635, 8368638, 8368639, 8368639, 8368643, 8368661, 8368663, 8368663, 8368644, 8368659, 8368664, 8368635, 8368637, 8368637, 8368640, 8368640, 8368642, 8368643, 8368644, 8368648, 8368651, 8368658, 8368663, 8368663, 8368665, 8368665, 8368638, 8368638, 8368640, 8368642, 8368648, 8368640, 8368651, 8368643, 8368641, 8368641, 8368642, 8368644, 8368645, 8368646, 8368646, 8368647, 8368647, 8368649, 8368650, 8368651, 8368653, 8368657, 8368662, 8368642, 8368642, 8368643, 8368648, 8368655, 8368666, 8368643, 8368643, 8368655, 8368668, 8368643, 8368646, 8368648, 8368649, 8368651, 8368662, 8368644, 8368645, 8368646, 8368646, 8368647, 8368648, 8368649, 8368650, 8368651, 8368653, 8368654, 8368655, 8368655, 8368658, 8368661, 8368666, 8368668, 8368668, 8368669, 8368669, 8368645, 8368646, 8368646, 8368647, 8368647, 8368648, 8368648, 8368649, 8368650, 8368650, 8368651, 8368653, 8368654, 8368656, 8368656, 8368665, 8368668, 8368669, 8368670, 8368646, 8368647, 8368647, 8368649, 8368654, 8368656, 8368657, 8368662, 8368670, 8368648, 8368648, 8368649, 8368650, 8368651, 8368651, 8368652, 8368652, 8368653, 8368654, 8368655, 8368657, 8368660, 8368662, 8368662, 8368664, 8368664, 8368666, 8368669, 8368671, 8368705, 8368648, 8368649, 8368650, 8368651, 8368652, 8368653, 8368653, 8368654, 8368654, 8368655, 8368656, 8368657, 8368658, 8368665, 8368666, 8368667, 8368670, 8368671, 8368649, 8368650, 8368650, 8368651, 8368652, 8368652, 8368653, 8368653, 8368654, 8368654, 8368655, 8368655, 8368656, 8368657, 8368658, 8368662, 8368665, 8368669, 8368670, 8368672, 8368650, 8368651, 8368652, 8368652, 8368653, 8368653, 8368654, 8368654, 8368655, 8368656, 8368657, 8368658, 8368661, 8368664, 8368665, 8368667, 8368670, 8368652, 8368654, 8368656, 8368656, 8368657, 8368658, 8368669, 8368669, 8368670, 8368671, 8368673, 8368653, 8368654, 8368654, 8368655, 8368657, 8368660, 8368669, 8368673, 8368653, 8368654, 8368654, 8368655, 8368656, 8368657, 8368658, 8368659, 8368663, 8368666, 8368667, 8368672, 8368674, 8368654, 8368655, 8368656, 8368658, 8368659, 8368660, 8368660, 8368663, 8368666, 8368668, 8368674, 8368655, 8368656, 8368656, 8368657, 8368658, 8368658, 8368659, 8368660, 8368665, 8368668, 8368673, 8368674, 8368674, 8368675, 8368657, 8368658, 8368658, 8368659, 8368660, 8368661, 8368661, 8368664, 8368665, 8368665, 8368668, 8368670, 8368673, 8368674, 8368674, 8368675, 8368657, 8368658, 8368658, 8368659, 8368660, 8368665, 8368667, 8368668, 8368673, 8368674, 8368676, 8368658, 8368659, 8368660, 8368660, 8368662, 8368663, 8368665, 8368669, 8368671, 8368674, 8368676, 8368660, 8368660, 8368661, 8368662, 8368662, 8368675, 8368676, 8368676, 8368677, 8368660, 8368661, 8368662, 8368663, 8368674, 8368675, 8368676, 8368677, 8368662, 8368663, 8368664, 8368668, 8368673, 8368676, 8368677, 8368678, 8368662, 8368663, 8368664, 8368664, 8368665, 8368666, 8368667, 8368667, 8368670, 8368670, 8368671, 8368673, 8368674, 8368675, 8368675, 8368676, 8368677, 8368677, 8368678, 8368678, 8368691, 8368676, 8368677, 8368678, 8368665, 8368665, 8368666, 8368667, 8368670, 8368672, 8368673, 8368676, 8368676, 8368677, 8368677, 8368678, 8368678, 8368679, 8368679, 8368675, 8368680, 8368666, 8368668, 8368669, 8368673, 8368674, 8368676, 8368677, 8368678, 8368678, 8368679, 8368679, 8368680, 9649201, 8368667, 8368670, 8368671, 8368672, 8368673, 8368676, 8368677, 8368678, 8368679, 8368680, 8368680, 8368681, 8368668, 8368672, 8368673, 8368675, 8368676, 8368679, 8368681, 8368671, 8368673, 8368675, 8368677, 8368678, 8368681, 8368674, 8368676, 8368680, 8368682, 8368672, 8368674, 8368674, 8368677, 8368677, 8368679, 8368679, 8368681, 8368681, 8368682, 8368682, 8368683, 8368684, 9649204, 8368679, 8368682, 8368676, 8368676, 8368678, 8368683, 8368684, 8368685, 8368679, 8368679, 8368680, 8368681, 8368683, 8368683, 8368684, 8368685, 8368686, 8368679, 8368680, 8368681, 8368684, 8368686, 8368686, 8368685, 8368687, 8368680, 8368685, 8368682, 8368684, 8368685, 8368685, 8368686, 8368687, 8368687, 8368688, 8368683, 8368684, 8368686, 8368687, 8368688, 8368687, 8368688, 8368685, 8368687, 8368687, 8368689, 8368689, 8368686, 8368686, 8368688, 8368688, 8368689, 8368690, 9649208, 8368688, 8368688, 8368690, 8368687, 8368689, 8368690, 8368691, 8368689, 8368690, 8368691, 8368691, 8368689, 8368690, 8368690, 8368692, 9377907, 8368690, 8368691, 8368692, 8368692, 8368691, 8368692, 8368692, 8368693, 8368692, 8368693, 8368693, 8368693, 8368694, 8368694, 8368695, 8368696, 8368696, 8368697, 8368698, 8368700, 8368701, 8368701, 8368702, 8368702, 8368703, 8368704, 8368705, 8368706, 8368706, 8368707, 8368707, 8368708, 8368711, 8368712, 8368713, 8368724, 8368726, 8368727, 8368727, 8368728, 8368728, 8368729, 8368729, 9377910, 9649214, 9649215, 9649218, 8368696, 8368697, 8368698, 8368699, 8368700, 8368701, 8368701, 8368702, 8368702, 8368703, 8368704, 8368705, 8368706, 8368708, 8368713, 8368714, 8368717, 8368718, 8368720, 8368723, 8368724, 8368726, 8368726, 8368727, 8368727, 8368728, 8368728, 8368729, 8368729, 8368730, 8368703, 8368713, 8368719, 8368720, 8368728, 8368730, 8368699, 8368702, 8368703, 8368703, 8368704, 8368705, 8368707, 8368709, 8368730, 8368731, 8368703, 8368731, 8656488, 8368732, 8368704, 8368734, 8368707, 8368707, 8368709, 8368733, 8368734, 8368735, 8368734, 8368735, 8368708, 8368709, 8368710, 8368710, 8368715, 8368716, 8368717, 8368730, 8368733, 8368735, 8368736, 8368710, 8368725, 8368733, 8368734, 8368736, 8368736, 8368737, 8368712, 8368737, 8368713, 8368716, 8368717, 8368722, 8368736, 8368738, 8368738, 8368715, 8368716, 8368718, 8368718, 8368723, 8368739, 8368718, 8368720, 8368724, 8368740, 9649226, 8368741, 8368741, 8368721, 8368742, 11751791, 8368742, 8368743, 8368727, 8368743, 8368744, 8368745, 8368744, 8368741, 8368744, 8368745, 8368747, 8368731, 8368747, 8368745, 8368746, 8368748, 8368748, 8368747, 8368750, 8368752, 8368753, 8368754, 8368757, 8368758, 8368754, 8368758, 8368758, 8368760, 8368758, 8368759, 8368758, 8368761, 8368760, 8368760, 8368761, 8368761, 8368761, 8368762, 8368762, 8368763, 8368763, 8368764, 8368765, 8368797, 8457966, 8514626, 8514629, 8595860, 8595861, 8595862, 8595862, 8595863, 8595864, 8595864, 8595865, 8595865, 8595866, 8595866, 8595867, 8595868, 8635371, 8656520, 8656521, 8884941, 8884944, 8884944, 8888070, 8957354, 9239795, 9351419, 9351420, 9361214, 9377943, 9377944, 9377944, 9436361, 9436363, 9589037, 9596352, 9649247, 9649248, 9649248, 9649249, 9649249, 9649250, 9649250, 9649251, 9649252, 11559236, 11904431, 12542673, 12542687, 12542701, 12542702, 13111425, 18430722, 8368765, 8368797, 8483991, 8595860, 8595861, 8595862, 8595864, 8595865, 8595865, 8595866, 8595866, 8704197, 8861893, 9239797, 9361168, 9377944, 9377945, 9436361, 9436361, 9649246, 9649248, 9649249, 9649250, 9649250, 9649253, 12542703, 12542704, 8595862, 8595864, 8595866, 8900304, 9351421, 9377945, 9649251, 8368905, 9378053, 9649358, 8547180, 9738464, 8599232, 9493185, 8660503, 8660504, 8660506, 9030821, 9030821, 9795127, 8822971, 8822973, 8822973, 8822974, 8822974, 8822975, 8822975, 8822976, 8822964, 8822979, 8822965, 8822979, 8822980, 8822965, 8822966, 8822980, 8822966, 8822967, 8822967, 8822981, 8822981, 8822982, 8822967, 8822968, 8822981, 8822981, 8822982, 8822982, 8822983, 8822983, 8822968, 8822970, 8822982, 8822982, 8822983, 8822982, 8822983, 8822984, 8822970, 8822983, 8822983, 8822984, 8822985, 9605054, 9605057, 9663469, 9876362, 9876363, 9605058, 9876363, 8822996, 8822997, 9112060, 9876365, 9876365, 8822996, 8822997, 8822997, 8822998, 9605060, 9605061, 9876366, 8822997, 9112059, 9112061, 9605060, 9605061, 9876366, 9876366, 8822998, 8822999, 9067162, 9578536, 9578537, 9605061, 9605061, 9605062, 9605063, 9663477, 9761333, 9876365, 9876366, 9876367, 9605062, 9636382, 9876365, 9876366, 9876367, 9876366, 9876367, 9876368, 8901992, 9644565, 8944289, 8944290, 8944291, 8944289, 9665712, 9665713, 9937020, 9649096, 9039642, 9984695, 9311337, 10120542, 9355045, 9871097, 9401131, 9401133, 9401135, 9401136, 9401134, 9401136, 9401137, 9401137, 9401138, 9401138, 9401215, 9401216, 9401216, 9401217, 9401217, 9401219, 9894137, 10165442, 10165443, 9894138, 10165443, 9401298, 9401298, 9401299, 9401299, 9401300, 9894217, 10165522, 9894217, 9407422, 10168601, 9431855, 9909495, 9545970, 9966560, 10110840, 10110840, 10520294, 10248989, 10334090, 10334092, 10334093, 10631921, 10631922, 10631923, 10631923, 10353629, 10353677, 10353720, 10353721, 10353792, 10353831, 10641783, 10353898, 10370516, 10641822, 10387137, 10387138, 10387138, 10387124, 10387139, 10387139, 10387137, 10387138, 10387139, 10387139, 10387140, 10387141, 10387142, 10387143, 10658442, 10658443, 10658443, 10658444, 10658444, 10387154, 10658444, 10658445, 10445556, 10445556, 10658444, 10658444, 10658445, 10658445, 10658446, 10658446, 13551898, 10658446, 10658446, 10658445, 10449781, 10689766, 10503956, 10503971, 10503972, 10503972, 10503973, 10503974, 10503986, 10716861, 10716861, 10716861, 10699677, 10699729, 10699781, 10814763, 10809325, 10869538, 10823990, 10824044, 10876893, 10929732, 10929733, 10929734, 10929734, 10929734, 10929749, 10929735, 10929735, 10929736, 10929737, 10929737, 10929738, 10929739, 10929753, 10929737, 10929738, 10929738, 10929739, 10929751, 10929751, 10929752, 10929752, 10929753, 10929738, 10929739, 10929739, 10929740, 10929740, 10929751, 10929752, 10929752, 10929753, 10929753, 10929739, 10929740, 10929740, 10929741, 10929741, 10929751, 10929751, 10929752, 10929752, 10929753, 10929753, 10929754, 10929740, 10929741, 10929741, 10929742, 10929743, 10929751, 10929751, 10929752, 10929752, 10929753, 10929753, 10929754, 10929756, 10929741, 10929742, 10929742, 10929743, 10929752, 10929752, 10929753, 10929753, 10929754, 10929754, 10929755, 10929756, 10929742, 10929743, 10929743, 10929744, 10929752, 10929752, 10929753, 10929753, 10929754, 10929754, 10929755, 10929743, 10929753, 10929754, 10929754, 10929755, 10929755, 10929754, 10929755, 10929755, 10929754, 10929755, 10929756, 10929754, 10929756, 10929763, 10929763, 10929763, 10929764, 10929764, 10929765, 10929764, 10929765, 10929765, 10929765, 10929766, 10929766, 11156722, 13032314, 10929766, 10929767, 10929767, 10929767, 10929768, 10929768, 10929769, 11050594, 13823187, 30184136, 10929768, 10929769, 10929770, 10929772, 11083983, 12665251, 12665257, 12803305, 13032315, 13823148, 13823173, 10929769, 10929770, 10929771, 10929771, 10929772, 10929773, 11156724, 12803304, 12803305, 13032316, 13032317, 13823204, 10929770, 10929771, 10929771, 10929772, 10929772, 10929773, 10929773, 10929774, 10929774, 11035608, 11050595, 11050595, 11050596, 11105220, 11110639, 11149841, 11202958, 11230839, 11230840, 11581615, 11751562, 11765860, 11816183, 11841502, 12255826, 12309191, 12309191, 12309192, 12309192, 12309193, 12556148, 12607400, 12650975, 12665252, 12665253, 12680966, 12761017, 12803303, 12803304, 12803304, 12803305, 12803305, 12803306, 12803306, 12803307, 12803307, 12883768, 13032252, 13032314, 13032315, 13032315, 13032316, 13032317, 13106435, 13267640, 13823149, 13823174, 13823175, 13823190, 10929771, 10929772, 10929772, 10929773, 10929773, 10929774, 10929774, 11050596, 11050597, 11050598, 11105217, 12192809, 12221537, 12309191, 12665253, 12665259, 12680967, 12803305, 12803305, 12803306, 12803306, 12803307, 13032317, 13823149, 13823205, 10929772, 10929773, 10929773, 10929774, 10929774, 10929775, 10929775, 11039313, 11050595, 11050596, 11050596, 11050597, 11050597, 11050598, 11050599, 11086433, 11149844, 11154265, 11193877, 11230840, 11357795, 11557923, 11765861, 11841502, 11843376, 11903793, 12101108, 12223570, 12309192, 12309192, 12309193, 12309193, 12330443, 12463364, 12665253, 12665253, 12665254, 12680967, 12680968, 12803304, 12803305, 12803305, 12803306, 12803306, 12803307, 12803307, 12803308, 12839739, 12839740, 13032316, 13032316, 13032317, 13032317, 13032318, 13823150, 13823174, 13823175, 13823177, 13823207, 10929773, 10929774, 10929774, 10929775, 10929775, 11050596, 11050597, 11149845, 11156726, 11230841, 11557918, 11765862, 12316169, 12330443, 12665254, 12680967, 12680968, 12803305, 12803306, 12803306, 12803307, 12803307, 12803308, 12803310, 12839740, 13032317, 13823150, 10929774, 10929775, 10929775, 10929776, 11050598, 11050600, 11110639, 11152511, 11156727, 11184695, 11374434, 12309192, 12309193, 12309194, 12665254, 12665254, 12665255, 12680968, 12681085, 12803306, 12803307, 12803307, 12803308, 12803308, 12803309, 12803310, 13032317, 13032317, 13032318, 13823151, 10929775, 10929776, 10929776, 10929777, 11050597, 11149846, 11156727, 11196070, 11230843, 11557924, 12556152, 12665254, 12665255, 12665255, 12680969, 12680970, 12803306, 12803306, 12803307, 12803307, 12803308, 12803308, 12803309, 12803309, 12803311, 12839741, 13032317, 13032317, 13032318, 13823151, 10929776, 10929777, 10929777, 10964927, 11039312, 11039314, 11050598, 11050599, 11050599, 11086153, 11104915, 11105222, 11149846, 11156728, 11581618, 11841506, 12309194, 12309194, 12330445, 12665255, 12665256, 12665256, 12680969, 12680969, 12803306, 12803307, 12803308, 12803308, 12803309, 12803309, 12803310, 12803310, 12839742, 13032316, 13032318, 13032319, 13823152, 13823153, 13823177, 10929778, 11050600, 11050601, 11230843, 12309195, 12665256, 12680969, 12680970, 12803307, 12803308, 12803309, 12839742, 11050599, 11050600, 11105221, 11105222, 11156729, 11581618, 11581901, 12330446, 12665256, 12665262, 12680970, 12803307, 12803308, 12803310, 12803310, 12803311, 12839743, 13032319, 13032320, 13032320, 13823153, 11156729, 11841508, 12309195, 12803309, 12803310, 13032321, 13032322, 11000094, 12716136, 11141459, 13929001, 11148863, 11148865, 11148865, 12790520, 12912859, 12912860, 11171420, 11171434, 11171436, 11171436, 11171436, 11171422, 11171435, 11171436, 11171436, 11171437, 11171437, 11171437, 11171439, 11171437, 11171438, 11171440, 11171439, 11171441, 11171442, 11171450, 13153154, 11171452, 12451282, 12924146, 12430032, 12430033, 12786093, 12801807, 12924145, 12924146, 12924148, 12960580, 13943990, 11270684, 11270685, 11277566, 12213811, 12430034, 12441354, 12786094, 12786096, 12801805, 12801808, 12924145, 12924146, 12924146, 12924147, 13153157, 13153158, 11277567, 12924146, 12924148, 12924148, 12924149, 11238210, 12957531, 11242542, 12959698, 11243169, 11243334, 11243496, 12837981, 11280108, 12856162, 11280679, 11280680, 11280680, 11280681, 11280682, 11332187, 11325305, 12371252, 12856429, 12978766, 12978768, 11291517, 11291518, 11291664, 11411720, 11291809, 12984330, 11369926, 11369916, 11369928, 11369928, 11369918, 11369928, 11369929, 11369930, 12901051, 13023391, 11369942, 12885338, 13023389, 13023390, 11948161, 11375260, 12531942, 11378767, 12889756, 13027808, 11383692, 11383692, 11383693, 11383694, 11992827, 12068469, 12557409, 12892219, 12907933, 13030271, 12536158, 13030272, 13030273, 13030272, 13030273, 12907935, 11439634, 13058246, 11457984, 11457994, 11458004, 13067422, 11462385, 12931570, 11476157, 14096403, 11531922, 11531923, 11531922, 11531923, 11531923, 12966335, 12610273, 12966335, 13104387, 13104388, 13104390, 13333399, 12966336, 13104389, 11785834, 13231344, 11819109, 13125642, 12186087, 12186092, 12186093, 13309136, 13431475, 13431476, 12233473, 12233476, 12233476, 13317113, 13332827, 14475051, 13332827, 12234055, 13455460, 12526390, 13128758, 12573366, 13625109, 12601965, 12601966, 13145296, 13639410, 13639411, 12702655, 13689777, 12753248, 12753245, 12753247, 12753248, 12753248, 13715049, 13576997, 13715049, 13715049, 13715051, 12756989, 12757051, 12757115, 13588407, 12877860, 13304508, 13256185, 13828467, 13272462, 13974661, 13455861, 14066357, 13461863, 13931325, 13513334, 13513393, 13529613, 13517383, 14097118, 13545825, 14111343, 13581893, 14129372, 13688626, 13688627, 13688612, 13688613, 13688613, 13688624, 13688627, 13688627, 13688628, 13688628, 13688628, 13688628, 13688629, 13688628, 13688629, 13688629, 13688626, 13688629, 13688630, 13688631, 13688641, 14182740, 14060402, 14182739, 14182741, 14182741, 14182742, 13688644, 13709878, 13718276, 14182741, 14219174, 13709879, 13987973, 14044689, 14182743, 14411753, 13709879, 13966530, 14044690, 14060404, 14182741, 14182742, 14182742, 14182743, 14182744, 14182744, 14411754, 13702578, 14189716, 13711271, 13721200, 13731122, 13731123, 13731124, 13731125, 13731125, 14081647, 14081648, 14203986, 14203987, 14203987, 13731134, 14081648, 13731137, 13792953, 13877210, 14203988, 14203989, 14507118, 14203990, 13841250, 13747920, 14441397, 13854808, 13854883, 13854954, 14265912, 13951373, 14066956, 13996969, 14336911, 14023295, 14350074, 14182539, 14182539, 14182541, 14429695, 14429698, 14658709, 14244426, 14689650, 14285042, 14358608, 14287314, 14518518, 14372193, 14372195, 14386470, 14386472, 14400734, 14400750, 14400750, 14400736, 14400748, 14400749, 14400749, 14400750, 14400750, 14400751, 14400752, 14400752, 14400750, 14400751, 14400752, 14400753, 14400750, 14400752, 14400753, 14400753, 14400759, 14400760, 14538801, 14400764, 14400766, 14538801, 14538802, 14538802, 14400764, 14538801, 15225639, 14400767, 14400767, 14416464, 14538801, 14538802, 14538802, 14538803, 14538803, 14538804, 15558703, 14400766, 14400767, 14538801, 14538802, 14538802, 14538803, 14538803, 14538804, 15558647, 14416465, 14538803, 14538804, 14538804, 14538805, 14416465, 14538804, 14538805, 14400770, 14538803, 14538805, 14538805, 14538806, 14416466, 14538804, 14538807, 14538807, 14416463, 14538804, 14538806, 14767815, 14400878, 14400992, 14767931, 14419699, 14584709, 14432159, 14432167, 14432171, 14432171, 14432172, 14432172, 14432163, 14432164, 14432168, 14432172, 14432173, 14432173, 14432174, 14432173, 14432174, 14432173, 14432174, 14432176, 14432179, 14432286, 14432289, 14432183, 14432183, 14432287, 14432288, 14432288, 14432289, 14432289, 14432290, 14432290, 14432292, 14432293, 14432290, 14432291, 14432291, 14432293, 14432184, 14432187, 14432289, 14432289, 14432290, 14432290, 14432291, 14432291, 14432290, 14432291, 14432291, 14432292, 14432292, 14432292, 14432291, 14432403, 14432405, 14432395, 14432396, 14432404, 14432404, 14432405, 14432405, 14432406, 14432398, 14432406, 14432407, 14432396, 14432398, 14432406, 14432407, 14432407, 14432408, 14432398, 14432406, 14432406, 14432407, 14432407, 14432408, 14432408, 14432409, 14432400, 14432406, 14432408, 14432408, 14432409, 14432400, 14432408, 14432408, 14432409, 14432403, 14432409, 14432410, 14432412, 14432412, 14432410, 14432413, 14432414, 14554625, 14554628, 14783638, 14432416, 14432418, 14554627, 14554627, 14554627, 14554628, 14432418, 14432419, 14432420, 14554628, 14554629, 14432420, 14496671, 14554625, 14554628, 14554629, 14554629, 14554630, 14554630, 14554631, 14783639, 14783640, 14554628, 14554629, 14554629, 14554630, 14554630, 14554631, 14554631, 14554630, 14554631, 14783641, 14554629, 14554630, 14554632, 14554630, 14554630, 14554631, 14554632, 14554633, 14554633, 14560940, 14618897, 14592278, 14634565, 14676835, 14676837, 14676837, 14676838, 14676838, 14676839, 14676839, 14676840, 14676852, 14676854, 14676838, 14676839, 14676839, 14676840, 14676840, 14676841, 14676854, 14676856, 14676839, 14676840, 14676840, 14676841, 14676841, 14676843, 14676853, 14676854, 14676855, 14676856, 14676856, 14676840, 14676841, 14676841, 14676842, 14676842, 14676844, 14676853, 14676854, 14676855, 14676856, 14676856, 14676857, 14676857, 14676841, 14676842, 14676842, 14676843, 14676843, 14676844, 14676855, 14676856, 14676856, 14676857, 14676857, 14676858, 14676858, 14676859, 14676859, 14676842, 14676843, 14676843, 14676844, 14676844, 14676854, 14676855, 14676855, 14676856, 14676857, 14676857, 14676858, 14676858, 14676859, 14676843, 14676844, 14676844, 14676845, 14676845, 14676846, 14676854, 14676856, 14676856, 14676857, 14676857, 14676858, 14676858, 14676859, 14676859, 14676862, 14676844, 14676845, 14676845, 14676855, 14676855, 14676856, 14676856, 14676857, 14676857, 14676858, 14676858, 14676859, 14676859, 14676860, 14676861, 14676845, 14676856, 14676857, 14676857, 14676858, 14676859, 14676859, 14676860, 14676846, 14676858, 14676859, 14676859, 14676860, 14676858, 14676859, 14676860, 14676860, 14676859, 14676860, 14676861, 14676861, 14676867, 14676869, 14676867, 14676869, 14676870, 14905863, 14905865, 14676868, 14676869, 14676870, 14676870, 14676871, 14676870, 14676870, 14676871, 14676871, 14676872, 15696724, 14676871, 14676871, 14676871, 14676872, 14676872, 14905865, 14905866, 14905867, 14676872, 14676873, 14676873, 14713288, 14713290, 14713291, 14905865, 14905866, 14905866, 14905867, 14905867, 14905868, 14905869, 14914449, 15129746, 15320725, 15696700, 15696725, 15806956, 14676873, 14676874, 14676874, 14713289, 14713290, 14713290, 14905865, 14905865, 14905866, 14905867, 14905868, 14905868, 14905869, 15141192, 15696700, 15696727, 14676874, 14676875, 14676875, 14676876, 14713289, 14713290, 14713290, 14713291, 14713291, 14713292, 14757320, 14780496, 14867977, 14905865, 14905866, 14905866, 14905867, 14905867, 14905868, 14905868, 14905869, 14905869, 14905870, 14979987, 14979988, 15363691, 15363695, 15363697, 15696701, 15696721, 15696725, 15696726, 14676876, 14676878, 14713291, 14713291, 14713292, 14905867, 14905867, 14905868, 14905868, 14905869, 14905869, 14905870, 14979988, 15320727, 15696701, 15696702, 15696702, 14905867, 14905869, 14905869, 15363691, 14713292, 14905869, 14905869, 14905870, 14905870, 15696704, 14713294, 15696705, 14749720, 14749721, 14749721, 14749707, 14749722, 14749722, 14749708, 14749720, 14749721, 14749721, 14749722, 14749723, 14749721, 14749722, 14749723, 14749722, 14749723, 14749723, 14749724, 14942298, 14942296, 14942297, 14942298, 14942298, 14942299, 15733157, 14942298, 14942299, 14942299, 15733157, 14749737, 14942298, 14942298, 14942299, 14942300, 14942297, 14942298, 14942298, 14942299, 14942299, 14942300, 14942300, 14942301, 14942301, 15016419, 15016420, 15177624, 15733133, 15733158, 15733159, 15733161, 14837778, 14837779, 14837780, 14986324, 15777160, 14986329, 14884147, 15009518, 15059090, 15096980, 15134743, 15134809, 15134859, 15134858, 15134859, 15134859, 15134860, 15134874, 15134875, 15134859, 15134859, 15134860, 15134860, 15134861, 15134874, 15134878, 15134859, 15134860, 15134860, 15134861, 15134861, 15134874, 15134878, 15134879, 15134860, 15134861, 15134861, 15134862, 15134862, 15134863, 15134876, 15134876, 15134877, 15134861, 15134862, 15134862, 15134863, 15134876, 15134876, 15134877, 15134878, 15134879, 15134862, 15134863, 15134863, 15134864, 15134873, 15134874, 15134876, 15134877, 15134877, 15134878, 15134879, 15134880, 15134863, 15134864, 15134864, 15134875, 15134876, 15134876, 15134877, 15134877, 15134878, 15134878, 15134879, 15134879, 15134880, 15134880, 15134864, 15134865, 15134865, 15134875, 15134876, 15134876, 15134877, 15134877, 15134878, 15134878, 15134879, 15134879, 15134880, 15134880, 15134881, 15134865, 15134867, 15134876, 15134877, 15134877, 15134878, 15134878, 15134879, 15134879, 15134880, 15134880, 15134881, 15134881, 15134869, 15134878, 15134878, 15134879, 15134880, 15134880, 15134881, 15134881, 15134882, 15134883, 15134877, 15134883, 15134883, 15925707, 15134890, 15925707, 15925733, 15134889, 15134890, 15134890, 15134891, 15134892, 15134893, 15134889, 15134890, 15134891, 15134892, 15134893, 15134893, 15925734, 15134890, 15134891, 15134891, 15134892, 15134892, 15134893, 15134893, 15134894, 15925709, 15134891, 15134892, 15134892, 15134893, 15134893, 15134894, 15134894, 15208996, 15370200, 15592704, 15925710, 15134892, 15134893, 15134893, 15134894, 15134894, 15134895, 15592694, 15925710, 15925710, 15925735, 15925736, 15134893, 15134894, 15134894, 15134895, 15134895, 15208998, 15549736, 15549736, 15925710, 15925736, 15925737, 15134894, 15134895, 15134895, 15134896, 15549736, 15549737, 15592705, 15592707, 15789958, 15901569, 15925711, 15925711, 15925712, 15925718, 15925736, 15925736, 15925737, 15134895, 15134896, 15134896, 15208998, 15208999, 15292332, 15370203, 15549737, 15592697, 15592704, 15592706, 15925711, 15925712, 15925714, 15925735, 15925736, 15925736, 15925737, 15925767, 15134896, 15134897, 15134897, 15134898, 15136273, 15208998, 15208999, 15292332, 15292332, 15370203, 15370203, 15546497, 15549737, 15592701, 15592703, 15592706, 15592707, 15592707, 15592708, 15823165, 15925711, 15925712, 15925712, 15925713, 15925716, 15925736, 15925737, 15925737, 15925738, 15925769, 15925770, 15925867, 15134897, 15134898, 15208999, 15208999, 15209000, 15287498, 15370205, 15370205, 15549738, 15549738, 15549739, 15592698, 15592700, 15592701, 15592701, 15592702, 15592707, 15592707, 15592708, 15823165, 15925712, 15925713, 15925713, 15925714, 15925720, 15925736, 15925736, 15925737, 15925738, 15925738, 15925739, 15925752, 16138267, 15134898, 15134899, 15134899, 15134900, 15143461, 15143463, 15208999, 15209000, 15209000, 15209001, 15253644, 15292333, 15370203, 15370204, 15370204, 15370206, 15370206, 15388050, 15549738, 15549739, 15592702, 15592702, 15592703, 15592704, 15592705, 15592706, 15592706, 15592707, 15592708, 15592708, 15592709, 15688815, 15853361, 15901571, 15918570, 15925712, 15925713, 15925713, 15925714, 15925714, 15925721, 15925733, 15925736, 15925737, 15925737, 15925738, 15925738, 15925739, 15925767, 15925768, 15925770, 15925772, 16641845, 15134899, 15592703, 15925713, 15925739, 15925740, 15209001, 15592706, 15592709, 15925714, 15925740, 15925714, 15925741, 15925715, 15137663, 15371594, 15152042, 15152043, 15152044, 15212352, 15934294, 15601289, 15272717, 15272790, 15272824, 15272931, 15661756, 15283101, 15283113, 15283114, 15283116, 15283116, 15283116, 15283117, 15283103, 15283114, 15283115, 15283115, 15283116, 15283117, 15283117, 15283118, 15283118, 15283119, 15283119, 15283119, 15999827, 15999852, 15283130, 15620613, 15999828, 15283131, 15366449, 15623854, 15283131, 15444321, 15666825, 15975688, 15999829, 15999830, 15999830, 15999850, 15999854, 15999855, 15444322, 15462167, 15623855, 15666819, 15666822, 15666823, 15666826, 15758127, 15864075, 15999830, 15999855, 15666823, 15999830, 15999831, 15999832, 15999857, 15444323, 15666820, 15666827, 15864078, 15999831, 15999858, 15372407, 15488967, 15440111, 16078388, 16810291, 15449779, 15449780, 15449781, 15703944, 15750154, 16083159, 16083183, 15750156, 15582630, 16149584, 15605525, 15605523, 15605525, 15605526, 15605525, 15605526, 15605524, 15605526, 15605526, 15605527, 15605529, 15605529, 15605530, 15828026, 16153891, 16161032, 16161059, 16161033, 15828030, 16161058, 16161059, 15828025, 15828027, 15828028, 16161034, 16161042, 16161059, 16161060, 16055451, 15612745, 15828024, 15619954, 15835235, 15641217, 15641217, 15845875, 16043126, 15958110, 15958110, 15958113, 15961350, 16337381, 16337325, 16337352, 15964579, 15964591, 15964592, 15964592, 15964593, 15964594, 15964594, 15964595, 15964592, 15964592, 15964593, 15964593, 16007554, 16340573, 15964608, 16007554, 16007562, 16007564, 16340566, 16340567, 16340587, 16340590, 16340592, 16340592, 16007562, 16340593, 16007564, 16340568, 16340592, 16340593, 16340594, 16007562, 16007564, 16340569, 16340595, 16050501, 16050518, 16050509, 16050520, 16050522, 16050520, 16050524, 16050509, 16050512, 16050521, 16050524, 16050526, 16050521, 16050525, 16050525, 16050527, 16050528, 16050514, 16050513, 16050530, 16050515, 16050527, 16050530, 16050530, 16050531, 16050515, 16050516, 16050525, 16050529, 16050531, 16050515, 16050532, 16050516, 16050517, 16050517, 16050532, 16050517, 16050533, 16050518, 16050527, 16050530, 16050531, 16050533, 16050533, 16050521, 16050530, 16050534, 16050534, 16050535, 16050533, 16050538, 16050542, 16141829, 16383532, 16383532, 16383533, 16383539, 16383557, 16383558, 16383534, 16050544, 16050545, 16383543, 16050545, 16383535, 16383560, 16383536, 16383562, 16050547, 16383537, 16050547, 16383537, 16383538, 16383563, 16383563, 16050550, 16141836, 16359397, 16383538, 16383538, 16383539, 16383539, 16383541, 16383546, 16383546, 16383561, 16383563, 16383563, 16383564, 16383564, 16383565, 16383539, 16383539, 16383539, 16233137, 16233138, 16233138, 16474840, 16474840, 16474841, 16242744, 16479642, 16445034, 16445035, 16445036, 16580789, 16580814, 16580814, 16505369, 16610954, 16511444, 16613991, 16571850, 16571880, 16571963, 16644285, 16668257, 16668257, 16668381, 16692398, 16692399, 16692424, 16692400, 16692424, 16692424, 16668504, 16692547, 16702254, 16702261, 16709417, 16709402, 16716527, 16716527, 16716528, 16716531, 16716533, 16716536, 16716542, 16716543, 16716528, 16716529, 16716529, 16716530, 16716530, 16716531, 16716531, 16716532, 16716535, 16716536, 16716536, 16716537, 16716538, 16716538, 16716539, 16716539, 16716540, 16716540, 16716541, 16716541, 16716542, 16716542, 16716543, 16716543, 16716544, 16716529, 16716530, 16716536, 16716537, 16716538, 16716538, 16716539, 16716539, 16716540, 16716541, 16716541, 16716542, 16716542, 16716543, 16716543, 16716544, 16716544, 16716545, 16716530, 16716531, 16716531, 16716538, 16716539, 16716539, 16716540, 16716541, 16716541, 16716542, 16716542, 16716543, 16716543, 16716544, 16716544, 16716545, 16716531, 16716532, 16716533, 16716534, 16716537, 16716537, 16716539, 16716539, 16716540, 16716541, 16716542, 16716543, 16716543, 16716544, 16716544, 16716533, 16716539, 16716542, 16716545, 16716533, 16716540, 16716542, 16716544, 16716536, 16716542, 16716543, 16716544, 16716545, 16716546, 16716544, 16716545, 16716546, 16716550, 16716545, 16716545, 16716545, 16716547, 16716546, 16716546, 16716547, 16716547, 16716549, 16716549, 16716550, 16716550, 16716551, 16716552, 16716553, 16716553, 16716546, 16716547, 16716549, 16716550, 16716550, 16716553, 16716554, 16716554, 16716546, 16716547, 16716548, 16716551, 16716547, 16716548, 16716548, 16716550, 16716550, 16716551, 16716551, 16716552, 16716553, 16716563, 16716548, 16716549, 16716550, 16716551, 16716552, 16716553, 16716562, 16716562, 16716563, 16716563, 16716564, 16716549, 16716550, 16716551, 16716551, 16716553, 16716553, 16716556, 16716564, 16716550, 16716551, 16716551, 16716552, 16716553, 16716553, 16716556, 16716557, 16716559, 16716564, 16716551, 16716552, 16716552, 16716553, 16716553, 16716554, 16716557, 16716563, 16716565, 16716552, 16716553, 16716554, 16716554, 16716555, 16716564, 16716565, 16716566, 16716553, 16716554, 16716554, 16716555, 16716555, 16716556, 16716556, 16716564, 16716566, 16716567, 16716554, 16716555, 16716555, 16716556, 16716556, 16716565, 16716566, 16716566, 16716555, 16716556, 16716556, 16716557, 16716558, 16716559, 16716566, 16716566, 16716567, 16716568, 16716556, 16716557, 16716557, 16716558, 16716558, 16716559, 16716561, 16716562, 16716566, 16716567, 16716567, 16716568, 16716557, 16716558, 16716558, 16716561, 16716563, 16716566, 16716566, 16716567, 16716567, 16716568, 16716568, 16716569, 16716558, 16716559, 16716560, 16716560, 16716562, 16716563, 16716566, 16716567, 16716567, 16716568, 16716568, 16716569, 17432676, 16716559, 16716561, 16716561, 16716562, 16716563, 16716564, 16716566, 16716567, 16716567, 16716568, 16716568, 16716569, 16716569, 16716570, 16716570, 16716583, 16716600, 16716627, 17448508, 16716564, 16716567, 16716568, 16716569, 16716569, 16716570, 16716570, 16929099, 16716568, 16716571, 16716569, 16716570, 16716571, 16716566, 16716568, 16716570, 16716570, 16716571, 16716572, 16716569, 16716569, 16716570, 16716570, 16716571, 16716571, 16716571, 16716572, 16716571, 16716568, 16716572, 16716573, 16716574, 16716571, 16716572, 16716573, 16716573, 16716574, 16716575, 16716575, 16716576, 16716573, 16716575, 16716575, 16716576, 16716576, 16716576, 16716576, 16716577, 16716578, 16716576, 16716577, 16716577, 16716578, 16716578, 16716577, 16716578, 16716578, 16716579, 16716588, 16716578, 16716579, 16716589, 16716579, 16716580, 16716580, 16716581, 16716581, 16716582, 16716582, 16716583, 16716588, 16716589, 16716590, 16716580, 16716581, 16716582, 16716583, 16716590, 16716581, 16716582, 16716582, 16716583, 16716583, 16716584, 16716584, 16716588, 16716588, 16716589, 16716589, 16716590, 16716590, 16716591, 16716592, 16716592, 16716582, 16716583, 16716583, 16716584, 16716584, 16716588, 16716589, 16716589, 16716590, 16716591, 16716592, 16716583, 16716584, 16716584, 16716585, 16716588, 16716590, 16716590, 16716591, 16716592, 16716593, 16716593, 16716584, 16716585, 16716585, 16716589, 16716590, 16716590, 16716592, 16716592, 16716593, 16716593, 16716585, 16716586, 16716586, 16716589, 16716590, 16716591, 16716592, 16716592, 16716593, 16716594, 16716594, 16716586, 16716589, 16716590, 16716592, 16716592, 16716593, 16716593, 16716594, 16716594, 16716587, 16716588, 16716590, 16716591, 16716591, 16716592, 16716592, 16716593, 16716593, 16716594, 16716594, 16716595, 16716595, 16716593, 16716594, 16716594, 16716596, 16716595, 16716597, 16716594, 16716595, 16716597, 16716598, 16716596, 16716597, 16716598, 16716598, 16716597, 16716598, 16716598, 16716599, 16716600, 16716598, 16716599, 16716599, 16716600, 16716599, 16716600, 16716601, 16716601, 16716600, 16716601, 16716602, 16716604, 16716601, 16716602, 16716602, 16716603, 16716603, 16716604, 16716604, 16716605, 16716606, 16716606, 16716609, 16716617, 16716620, 16716621, 16716602, 16716603, 16716603, 16716604, 16716606, 16716607, 16716603, 16716604, 16716604, 16716605, 16716605, 16716606, 16716606, 16716608, 16716609, 16716618, 16716621, 16716622, 16716625, 16716604, 16716605, 16716605, 16716606, 16716606, 16716607, 16716607, 16716608, 16716609, 16716612, 16716619, 16716621, 16716622, 16716623, 16716605, 16716606, 16716606, 16716607, 16716607, 16716608, 16716608, 16716619, 16716621, 16716622, 16716606, 16716607, 16716607, 16716608, 16716608, 16716609, 16716610, 16716611, 16716614, 16716622, 16716607, 16716608, 16716609, 16716623, 16716608, 16716609, 16716609, 16716610, 16716610, 16716611, 16716611, 16716612, 16716612, 16716614, 16716614, 16716619, 16716619, 16716620, 16716620, 16716621, 16716621, 16716626, 16716609, 16716610, 16716610, 16716611, 16716611, 16716612, 16716612, 16716613, 16716616, 16716619, 16716620, 16716621, 16716625, 16716610, 16716611, 16716611, 16716612, 16716612, 16716613, 16716614, 16716615, 16716620, 16716620, 16716621, 16716621, 16716611, 16716612, 16716612, 16716613, 16716613, 16716614, 16716614, 16716615, 16716615, 16716616, 16716618, 16716619, 16716620, 16716621, 16716621, 16716622, 16716624, 16716612, 16716613, 16716613, 16716614, 16716614, 16716616, 16716616, 16716617, 16716618, 16716619, 16716620, 16716621, 16716621, 16716622, 16716622, 16716613, 16716614, 16716614, 16716615, 16716617, 16716621, 16716621, 16716622, 16716623, 16716623, 16716614, 16716615, 16716615, 16716616, 16716620, 16716621, 16716622, 16716622, 16716623, 16716623, 16716624, 16716615, 16716616, 16716619, 16716621, 16716622, 16716623, 16716623, 16716624, 16716625, 16716616, 16716617, 16716618, 16716619, 16716619, 16716623, 16716623, 16716624, 16716624, 16716617, 16716618, 16716618, 16716619, 16716619, 16716620, 16716620, 16716621, 16716621, 16716622, 16716622, 16716623, 16716623, 16716624, 16716624, 16716625, 16716625, 16716626, 16716627, 16716628, 16716619, 16716620, 16716624, 16716622, 16716624, 16716625, 16716620, 16716621, 16716623, 16716623, 16716624, 16716625, 16716626, 16716626, 16716629, 16716621, 16716623, 16716624, 16716625, 16716625, 16716626, 16716626, 16716622, 16716623, 16716625, 16716626, 16716630, 16716624, 16716625, 16716626, 16716628, 16716627, 16716628, 16716626, 16716627, 16716626, 16716628, 16716627, 16716628, 16716633, 16716628, 16716629, 16716629, 16716630, 16716630, 16716631, 16716631, 16716632, 16716632, 16716633, 16716634, 16716635, 16716635, 16716631, 16716632, 16716632, 16716633, 16716635, 16716632, 16716633, 16716633, 16716634, 16716634, 16716635, 16716635, 16716636, 16716636, 16716633, 16716634, 16716634, 16716635, 16716635, 16716636, 16716636, 16716637, 16716638, 16716634, 16716635, 16716635, 16716636, 16716636, 16716637, 16716637, 16716635, 16716636, 16716636, 16716637, 16716637, 16716638, 16716636, 16716637, 16716637, 16716638, 16716638, 16716637, 16716638, 16716638, 16716639, 16716638, 16716639, 16716639, 16716639, 16716640, 16716640, 16716641, 16716650, 16716640, 16716641, 16716641, 16716642, 16716642, 16716643, 16716643, 16716644, 16716644, 16716645, 16716645, 16716646, 16716650, 16716652, 16716653, 16716654, 16716654, 16716642, 16716643, 16716643, 16716643, 16716644, 16716644, 16716645, 16716645, 16716646, 16716646, 16716647, 16716648, 16716648, 16716651, 16716653, 16716655, 16716655, 16716658, 16716644, 16716645, 16716645, 16716646, 16716646, 16716647, 16716647, 16716649, 16716650, 16716651, 16716652, 16716654, 16716655, 16716658, 16716658, 16716645, 16716646, 16716646, 16716647, 16716647, 16716648, 16716649, 16716651, 16716652, 16716653, 16716654, 16716657, 16716646, 16716647, 16716647, 16716648, 16716648, 16716649, 16716650, 16716652, 16716653, 16716654, 16716647, 16716648, 16716648, 16716649, 16716649, 16716650, 16716651, 16716651, 16716652, 16716652, 16716653, 16716654, 16716655, 16716656, 16716648, 16716649, 16716649, 16716650, 16716650, 16716651, 16716651, 16716652, 16716652, 16716653, 16716653, 16716654, 16716654, 16716655, 16716655, 16716656, 16716657, 16716660, 16716649, 16716650, 16716650, 16716651, 16716651, 16716652, 16716652, 16716653, 16716653, 16716654, 16716654, 16716655, 16716655, 16716656, 16716656, 16716657, 16716657, 16716650, 16716651, 16716651, 16716652, 16716652, 16716653, 16716653, 16716654, 16716654, 16716655, 16716655, 16716656, 16716656, 16716651, 16716652, 16716652, 16716653, 16716653, 16716654, 16716654, 16716655, 16716655, 16716656, 16716657, 16716659, 16716652, 16716653, 16716653, 16716654, 16716654, 16716655, 16716655, 16716656, 16716656, 16716657, 16716657, 16716653, 16716654, 16716654, 16716655, 16716655, 16716656, 16716656, 16716657, 16716657, 16716658, 16716658, 16716659, 16716663, 16716654, 16716655, 16716655, 16716656, 16716656, 16716657, 16716657, 16716658, 16716658, 16716659, 16716660, 16716655, 16716656, 16716656, 16716657, 16716657, 16716658, 16716658, 16716659, 16716656, 16716657, 16716657, 16716658, 16716658, 16716659, 16716659, 16716661, 16716657, 16716658, 16716658, 16716659, 16716660, 16716662, 16716658, 16716659, 16716659, 16716660, 16716660, 16716661, 16716659, 16716660, 16716660, 16716661, 16716661, 16716662, 16716662, 16716663, 16716660, 16716661, 16716661, 16716662, 16716661, 16716662, 16716662, 16716663, 16716663, 16716664, 16716662, 16716663, 16716663, 16716664, 16716753, 16716663, 16716664, 16716664, 16716665, 16716754, 16716762, 16716664, 16716665, 16716665, 16716668, 16716754, 16716665, 16716666, 16716666, 16716667, 16716667, 16716669, 16716679, 16716755, 16716756, 16716762, 16716668, 16716669, 16716669, 16716670, 16716670, 16716671, 16716680, 16716681, 16716708, 16716740, 16716754, 16716754, 16716756, 16716756, 16716669, 16716670, 16716670, 16716671, 16716671, 16716681, 16716682, 16716739, 16716739, 16716754, 16716755, 16716756, 16716670, 16716671, 16716671, 16716672, 16716673, 16716674, 16716680, 16716682, 16716723, 16716724, 16716728, 16716729, 16716738, 16716739, 16716739, 16716740, 16716742, 16716755, 16716755, 16716756, 16716756, 16716757, 16716761, 16716671, 16716672, 16716672, 16716673, 16716673, 16716674, 16716674, 16716675, 16716676, 16716681, 16716682, 16716683, 16716684, 16716685, 16716723, 16716724, 16716724, 16716733, 16716739, 16716740, 16716741, 16716741, 16716745, 16716751, 16716755, 16716756, 16716756, 16716757, 16716672, 16716673, 16716673, 16716674, 16716674, 16716675, 16716676, 16716677, 16716681, 16716682, 16716682, 16716683, 16716683, 16716684, 16716684, 16716685, 16716686, 16716687, 16716700, 16716706, 16716707, 16716708, 16716709, 16716710, 16716710, 16716723, 16716724, 16716724, 16716725, 16716725, 16716728, 16716728, 16716729, 16716730, 16716739, 16716739, 16716740, 16716740, 16716741, 16716741, 16716742, 16716742, 16716743, 16716744, 16716745, 16716745, 16716755, 16716755, 16716756, 16716756, 16716757, 16716757, 16716758, 16716758, 16716673, 16716674, 16716674, 16716675, 16716675, 16716676, 16716676, 16716679, 16716679, 16716682, 16716683, 16716683, 16716684, 16716684, 16716685, 16716685, 16716688, 16716699, 16716701, 16716705, 16716705, 16716706, 16716706, 16716709, 16716710, 16716711, 16716723, 16716724, 16716725, 16716725, 16716726, 16716728, 16716728, 16716729, 16716730, 16716730, 16716736, 16716739, 16716740, 16716741, 16716741, 16716742, 16716742, 16716744, 16716744, 16716745, 16716752, 16716754, 16716755, 16716755, 16716756, 16716757, 16716757, 16716758, 16716758, 16716759, 17135154, 17285416, 16716674, 16716675, 16716675, 16716676, 16716676, 16716677, 16716677, 16716678, 16716679, 16716680, 16716684, 16716686, 16716687, 16716688, 16716688, 16716707, 16716708, 16716711, 16716711, 16716724, 16716724, 16716725, 16716725, 16716726, 16716727, 16716728, 16716730, 16716731, 16716736, 16716741, 16716741, 16716742, 16716742, 16716743, 16716745, 16716751, 16716756, 16716757, 16716757, 16716758, 16716758, 16716759, 16929155, 16716675, 16716676, 16716678, 16716680, 16716683, 16716684, 16716684, 16716685, 16716686, 16716707, 16716712, 16716725, 16716725, 16716726, 16716727, 16716730, 16716731, 16716742, 16716742, 16716753, 16716757, 16716758, 16716758, 16716759, 16716759, 16716676, 16716677, 16716677, 16716681, 16716684, 16716686, 16716688, 16716689, 16716709, 16716728, 16716730, 16716742, 16716742, 16716747, 16716748, 16716759, 16716759, 16716677, 16716679, 16716679, 16716681, 16716687, 16716713, 16716741, 16716743, 16716743, 16716744, 16716745, 16716747, 16716759, 16716679, 16716681, 16716685, 16716708, 16716711, 16716727, 16716728, 16716729, 16716739, 16716742, 16716743, 16716744, 16716759, 16716760, 16716679, 16716686, 16716728, 16716733, 16716744, 16716744, 16716745, 16716748, 16716760, 16716713, 16716729, 16716744, 16716745, 16716759, 16716715, 16716734, 16716745, 16716745, 16716761, 16716692, 16716746, 16716761, 16716763, 16716716, 16716710, 16716747, 16716717, 16716731, 16716734, 16716747, 16716748, 16716703, 16716692, 16716696, 16716703, 16716704, 16716694, 16716704, 16716695, 16716705, 16716696, 16716705, 16716695, 16716698, 16716705, 16716706, 16716696, 16716706, 16716697, 16716699, 16716706, 16716700, 16716707, 16716708, 16716711, 16716709, 16716710, 16716711, 16716712, 16716711, 16716712, 16716712, 16716710, 16716713, 16716716, 16716745, 16716764, 16716767, 16716778, 16929175, 16716717, 16716720, 16716733, 16716745, 16716747, 16716750, 16716762, 16716763, 16716763, 16716764, 16716770, 16716771, 16716778, 16716778, 16716779, 16716779, 16716780, 16716780, 16871673, 17285438, 16716761, 16716780, 16716765, 16716735, 16716782, 16716749, 16716751, 16716762, 16716765, 16716766, 16716766, 16716779, 16716782, 16716783, 16716737, 16716738, 16716769, 16716751, 16716752, 16716753, 16716753, 16716754, 16716754, 16716754, 16716755, 16716756, 16716757, 16716757, 16716758, 16716763, 16716765, 16716766, 16716778, 16716758, 16716772, 16716773, 16716775, 16716778, 16716787, 16716788, 16716788, 16716789, 16716789, 16716790, 16716790, 16716793, 16716794, 16716803, 16716804, 16716804, 16716805, 16716789, 16716781, 16716785, 16716785, 16716781, 16716784, 16716785, 16716786, 16716776, 16716777, 16716779, 16716786, 16716786, 16716787, 16716782, 16716782, 16716786, 16716787, 16716792, 16716787, 16716787, 16716788, 16716783, 16716788, 16716793, 16716793, 16716793, 16716793, 16716794, 16716790, 16716792, 16716793, 16716795, 16716796, 16716795, 16716795, 16716796, 16716796, 16716791, 16716792, 16716796, 16716797, 16716792, 16716797, 16716802, 16716796, 16716801, 16716802, 16716802, 16716803, 16716803, 16716811, 16716820, 16716797, 16716802, 16716802, 16716803, 16716803, 16716804, 16716804, 16716807, 16716808, 16716818, 16716819, 16716820, 16716820, 16716801, 16716802, 16716803, 16716804, 16716804, 16716806, 16716819, 16716820, 16716804, 16716802, 16716804, 16716806, 16716816, 16716805, 16716806, 16716807, 16716808, 16716808, 16716806, 16716807, 16716813, 16716823, 16716807, 16716808, 16716808, 16716809, 16716810, 16716812, 16716815, 16716819, 16716819, 16716821, 16716821, 16716822, 16716822, 16716823, 16716824, 16716824, 16716825, 16716808, 16716809, 16716809, 16716810, 16716811, 16716819, 16716809, 16716810, 16716810, 16716811, 16716812, 16716812, 16716813, 16716813, 16716814, 16716816, 16716819, 16716819, 16716820, 16716822, 16716823, 16716823, 16716810, 16716811, 16716811, 16716812, 16716812, 16716813, 16716814, 16716816, 16716819, 16716820, 16716820, 16716823, 16716824, 16716825, 16716811, 16716812, 16716812, 16716813, 16716815, 16716816, 16716818, 16716820, 16716820, 16716821, 16716824, 16716825, 16716812, 16716813, 16716814, 16716814, 16716815, 16716815, 16716817, 16716820, 16716821, 16716821, 16716824, 16716824, 16716813, 16716822, 16716825, 16716816, 16716817, 16716820, 16716822, 16716822, 16716826, 16716828, 16716816, 16716823, 16716826, 16716827, 16716817, 16716823, 16716823, 16716828, 16716817, 16716821, 16716824, 16716827, 16716829, 16716818, 16716819, 16716824, 16716827, 16716828, 16716828, 16716829, 16716829, 16716824, 16716825, 16716829, 16716830, 16716830, 16716830, 16716825, 16716826, 16716829, 16716826, 16716827, 16716832, 16716831, 16716828, 16716832, 16716829, 16716833, 16716833, 16716829, 16716830, 16716834, 16716835, 16716830, 16716833, 16716833, 16716835, 16716835, 16716836, 16716831, 16716832, 16716832, 16716833, 16716833, 16716834, 16716834, 16716835, 16716835, 16716836, 16716836, 16716837, 16716837, 16716834, 16716834, 16716835, 16716836, 16716833, 16716835, 16716835, 16716836, 16716836, 16716835, 16716836, 16716837, 16716835, 16716836, 16716837, 16716837, 16716838, 16716836, 16716837, 16716837, 16716838, 16716838, 16716837, 16716838, 16716838, 16716839, 16716839, 16716840, 16716840, 16716838, 16716839, 16716839, 16716840, 16716840, 16716841, 16716839, 16716840, 16716840, 16716841, 16716841, 16716851, 16716840, 16716841, 16716841, 16716842, 16716849, 16716841, 16716842, 16716842, 16716842, 16716843, 16716843, 16716852, 16716852, 16716857, 16716843, 16716844, 16716844, 16716845, 16716848, 16716855, 16716845, 16716846, 16716847, 16716847, 16716848, 16716849, 16716849, 16716854, 16716855, 16716856, 16716861, 16716861, 16716862, 16716864, 16716846, 16716847, 16716847, 16716848, 16716848, 16716849, 16716849, 16716850, 16716850, 16716851, 16716851, 16716852, 16716852, 16716853, 16716853, 16716857, 16716847, 16716848, 16716848, 16716849, 16716849, 16716850, 16716850, 16716851, 16716853, 16716848, 16716849, 16716849, 16716850, 16716850, 16716851, 16716852, 16716849, 16716850, 16716850, 16716851, 16716851, 16716852, 16716852, 16716853, 16716850, 16716851, 16716851, 16716852, 16716852, 16716853, 16716853, 16716851, 16716852, 16716852, 16716853, 16716853, 16716852, 16716853, 16716853, 16716854, 16716854, 16716855, 16716856, 16716853, 16716854, 16716854, 16716855, 16716855, 16716856, 16716857, 16716854, 16716855, 16716855, 16716856, 16716857, 16716858, 16716855, 16716856, 16716856, 16716857, 16716857, 16716856, 16716857, 16716857, 16716858, 16716857, 16716858, 16716858, 16716859, 16716858, 16716859, 16716860, 16716862, 16716859, 16716860, 16716861, 16716862, 16716862, 16716860, 16716861, 16716862, 16716862, 16716861, 16716862, 16716862, 16716863, 16716863, 16716864, 16716876, 16716862, 16716863, 16716863, 16716876, 17448696, 16716863, 16716864, 16716864, 16716865, 16716865, 22604772, 16716864, 16716865, 16716865, 16716868, 16716869, 16716870, 16716877, 16759494, 16716865, 16716866, 16716866, 16716867, 16716867, 16716866, 16716867, 16716867, 16716868, 16716868, 16716869, 16716878, 22604773, 16716867, 16716868, 16716868, 16716869, 16716869, 16716870, 16716871, 16716880, 16716868, 16716869, 16716869, 16716870, 16716870, 16716871, 16716872, 16716869, 16716870, 16716870, 16716871, 16716871, 16716870, 16716871, 16716871, 16716872, 16716872, 16716873, 16716871, 16716872, 16716872, 16716873, 16716873, 16716881, 16716872, 16716873, 16716873, 16716874, 16716875, 16716881, 16716873, 16716874, 16716874, 16716875, 16716882, 16929253, 16716874, 16716875, 16716875, 16716882, 16716875, 16716876, 16716876, 16716877, 16716877, 16716883, 16716876, 16716877, 16716877, 16716878, 16716878, 16716879, 16716879, 16716881, 16716883, 16716883, 22604778, 16716877, 16716878, 16716878, 16716879, 16716880, 16716881, 16716884, 17285482, 16716878, 16716879, 16716879, 16716880, 16716880, 16716881, 16716882, 16716882, 16716883, 16716883, 16716884, 17285482, 16716879, 16716880, 16716880, 16716881, 16716881, 16716882, 16716882, 16716883, 16716884, 16716884, 16716885, 16716880, 16716881, 16716881, 16716882, 16716882, 16716883, 16716883, 16716884, 16716885, 16716881, 16716882, 16716882, 16716883, 16716883, 16716884, 16716884, 16716886, 16716882, 16716883, 16716883, 16716884, 16716884, 16716885, 16716885, 16716886, 16716886, 16716883, 16716884, 16716884, 16716885, 16716885, 16716886, 16716886, 16716887, 22604782, 16716884, 16716885, 16716885, 16716886, 16716886, 16716887, 16716887, 16716885, 16716886, 16716886, 16716887, 16716887, 16716888, 16716886, 16716887, 16716887, 16716888, 16716888, 16716887, 16716888, 16716888, 16716889, 18491914, 16716888, 16716889, 16716889, 16716889, 16716890, 16716890, 16716891, 16716892, 16716892, 16716893, 16716894, 16716895, 16716896, 16759507, 16769950, 16826965, 16826965, 16827126, 16827126, 16827127, 16839574, 16849385, 16849386, 16876568, 16929258, 16929261, 16929262, 17135260, 17135262, 17135263, 17135264, 17135264, 17279437, 17279437, 17285489, 17285541, 17448674, 17448675, 17448676, 17448677, 17448710, 17604628, 22604786, 22607137, 22607239, 22608246, 16716892, 16716893, 16716893, 16716895, 16827127, 17092372, 17135262, 17135263, 17135265, 17279437, 17285489, 17285544, 17448710, 16716893, 16716894, 16716894, 16716895, 16835730, 16849386, 16929263, 17135262, 17135263, 17135264, 17135265, 17279438, 17279438, 17279440, 17285490, 17285526, 17432841, 17448675, 19066306, 16716894, 16716895, 16716895, 16716896, 16716922, 16759509, 16769940, 16769953, 16769953, 16793061, 16826966, 16826967, 16826967, 16826968, 16826968, 16827127, 16827128, 16827128, 16827129, 16849387, 16849387, 16849388, 16873388, 16876570, 16929263, 16929264, 16929265, 16929266, 17065804, 17135262, 17135263, 17135264, 17135264, 17135265, 17135265, 17135266, 17169388, 17169389, 17279438, 17279439, 17279439, 17285490, 17285490, 17285526, 17432843, 17432844, 17448675, 17448677, 17448680, 17448710, 17448710, 17448711, 17448749, 22604787, 16716895, 16716896, 16826967, 16826967, 16827129, 16929264, 16929266, 17135264, 17135264, 17135265, 17279440, 17285491, 17432843, 16716896, 16716897, 16759510, 16769951, 16769954, 16826967, 16929265, 16929266, 17135264, 17135264, 17285491, 17448673, 16716897, 16716898, 16716898, 16717030, 16717042, 16769942, 16769943, 16769952, 16769954, 16769955, 16826968, 16826968, 16826969, 16827129, 16827129, 16827130, 16849388, 16849389, 16862618, 16873391, 16873393, 16907063, 16929263, 16929265, 16929266, 16929267, 17135265, 17135265, 17135266, 17135266, 17135267, 17135268, 17279440, 17279440, 17279441, 17285492, 17285543, 17448678, 17448681, 16769952, 16769953, 16769953, 16929265, 17135265, 17285492, 16826969, 17432846, 16929267, 17135268, 16716959, 16929299, 16717177, 16717199, 16920661, 16827287, 16802134, 16802146, 16802146, 17177890, 16869765, 17177900, 17177900, 17328128, 16823000, 16823011, 16823012, 16823002, 16823013, 16823009, 16823010, 16823022, 16823023, 16823023, 16823024, 16823024, 16823025, 16823025, 16823027, 16823025, 16823028, 16823026, 16880187, 16880030, 17188336, 16823038, 16880200, 17188335, 17338562, 17188335, 17332510, 16880039, 16880201, 17188336, 17188337, 17338563, 17338613, 16982337, 17338564, 17338565, 16869247, 17005450, 16937039, 16937040, 16937049, 16937051, 16937051, 16937052, 16937052, 16937053, 16937053, 16937054, 16937054, 16937055, 16937055, 16937057, 16937040, 16937049, 16937049, 16937051, 16937055, 16937055, 16937056, 16937041, 16937052, 16937054, 16937055, 16937056, 16937056, 16937059, 16937055, 16937056, 16937057, 16937055, 16937056, 16937058, 16937061, 16937063, 16937212, 16937213, 16937064, 16937213, 16937215, 16937066, 17039349, 17245347, 17395575, 17542929, 16937214, 17039349, 17175887, 17245349, 17395576, 16937214, 17039350, 16937214, 17245350, 17395577, 16937069, 16937215, 16937216, 16937217, 17039351, 17245350, 16937215, 16937216, 17039351, 17245353, 17395578, 16959475, 17039352, 17245351, 17389526, 17395578, 16937071, 16937072, 16937216, 16937216, 16937217, 16959475, 17039352, 17245350, 17245352, 17245353, 17245354, 17389527, 17389527, 17389528, 17395579, 16959476, 17245352, 17245353, 17395579, 16959476, 17245354, 17039355, 16937362, 16937373, 16937373, 16937374, 16937362, 16937363, 16937364, 16937374, 16937374, 16937364, 16937374, 16937374, 16937375, 16937375, 16937375, 16937367, 16937376, 16937377, 16937377, 16937385, 16937386, 17039509, 16937386, 16959633, 17039510, 17039511, 16952042, 16959633, 16959634, 17039510, 17039511, 17039512, 17245510, 17245510, 17245511, 17245511, 17389685, 17389686, 17395737, 17395773, 17395777, 17543091, 17558924, 16954583, 17398290, 16962276, 17408190, 16966710, 17294302, 16981891, 16981892, 16981892, 16981893, 16981893, 16981892, 16981893, 16981893, 16981894, 17411943, 17061768, 17061769, 17417995, 17061769, 17267769, 17267771, 17417996, 17061770, 17267769, 17267770, 17267772, 17411945, 17417996, 17565351, 17417997, 17008354, 17431228, 17026640, 17587721, 17029897, 17029899, 17029902, 17085773, 17435947, 17085775, 17036260, 17036261, 17445181, 17097242, 17475671, 17124143, 17652306, 17141644, 17141645, 17141646, 17141647, 17141633, 17141648, 17141635, 17141635, 17141646, 17141647, 17141648, 17141649, 17141649, 17141649, 17141650, 17141650, 17141650, 17141650, 17141650, 17141661, 17497874, 17141663, 17347650, 17491823, 17141663, 17347646, 17347648, 17347648, 17347649, 17347652, 17491823, 17497875, 17497976, 17661059, 17268556, 17268641, 17347647, 17347648, 17347648, 17347649, 17347649, 17347650, 17347651, 17491823, 17491824, 17491824, 17497875, 17645230, 17661062, 17395457, 17395545, 17395631, 17395633, 17624865, 17414725, 17414727, 17634413, 17467864, 17848046, 17553633, 17553647, 17553649, 17553632, 17553647, 17553648, 17553632, 17553633, 17553648, 17553648, 17553650, 17553633, 17553634, 17553634, 17553635, 17553635, 17553636, 17553648, 17553649, 17553649, 17553650, 17553650, 17553651, 17553634, 17553635, 17553636, 17553651, 17553636, 17553636, 17553637, 17553637, 17553649, 17553651, 17553651, 17553652, 17553652, 17553650, 17553652, 17553654, 17553637, 17553650, 17553652, 17553653, 17553654, 17553651, 17553652, 17553653, 17553653, 17553653, 17553654, 17553654, 17553654, 17553654, 17553665, 17553666, 17697823, 17697824, 17703875, 17867043, 17595418, 17703876, 17867063, 17697824, 17703876, 17553667, 17553669, 17703877, 17553668, 17553669, 17553669, 17597520, 17697825, 17697825, 17697826, 17697826, 17697827, 17697827, 17703877, 17703877, 17703930, 17851226, 17867062, 17867063, 17867064, 17553669, 17697826, 17697826, 17703878, 17703914, 17587776, 17697827, 17703878, 17703928, 17703879, 17703879, 17867064, 17621896, 17621896, 17621898, 17885352, 17737998, 17737999, 17637182, 17873929, 17641423, 17641499, 17641568, 17747849, 17841997, 17841983, 17841984, 17841984, 17841997, 17841998, 17841998, 17841999, 17841984, 17841998, 17841998, 17841999, 17841999, 17842000, 17842001, 17841998, 17841999, 17841999, 17842000, 17842001, 17842002, 17841999, 17842000, 17842001, 17848049, 17848049, 17842013, 17848050, 17842014, 17848050, 17995405, 17848051, 17848091, 17848052, 17848053, 17854086, 17854087, 17854088, 17854088, 17854094, 17854095, 17854096, 17854097, 17854098, 17854099, 17854099, 17854112, 17854113, 17854117, 17854118, 17854118, 17854119, 17854121, 17854122, 17854122, 17854123, 17854141, 17854162, 17854118, 17854122, 17854123, 17854123, 17854119, 17854123, 17854124, 17854119, 17854124, 17854129, 17854130, 17854130, 17854132, 17854108, 17854133, 17854199, 18017283, 17854109, 17854110, 18017283, 17854134, 17854199, 17854135, 17854148, 17854149, 17854148, 17854153, 17854151, 17854153, 17854154, 17854193, 17854154, 17854152, 17854156, 17854154, 17854155, 17854156, 17854156, 17854157, 17854157, 17854157, 17854158, 17854158, 17854175, 17854198, 17854159, 17854160, 17854160, 17854161, 17854161, 17854162, 17854162, 17854163, 17854164, 17854164, 17854166, 17854166, 17854167, 17854168, 17854168, 17854169, 17854171, 17854172, 17854173, 17854173, 17854174, 17854174, 17854175, 17854175, 17854176, 17854177, 17854177, 17854178, 17854178, 17854179, 17854179, 17854180, 17854180, 17854181, 17854181, 17854182, 17854184, 17854187, 17854194, 17854194, 17854196, 17854196, 17854197, 17854197, 17854198, 17854160, 17854161, 17854161, 17854162, 17854162, 17854163, 17854174, 17854175, 17854176, 17854198, 17854199, 17854162, 17854163, 17854174, 17854174, 17854199, 17854163, 17854169, 17854200, 17854163, 17854164, 17854165, 17854169, 17854169, 17854175, 17854177, 17854181, 17854200, 17854164, 17854165, 17854165, 17854166, 17854168, 17854170, 17854175, 17854176, 17854184, 17854186, 17854188, 17854198, 17854201, 17854165, 17854166, 17854166, 17854169, 17854176, 17854182, 17854199, 17854201, 17854166, 17854167, 17854167, 17854169, 17854170, 17854171, 17854176, 17854177, 17854179, 17854179, 17854180, 17854182, 17854185, 17854188, 17854189, 17854194, 17854202, 17854167, 17854168, 17854168, 17854170, 17854176, 17854177, 17854177, 17854178, 17854179, 17854181, 17854182, 17854198, 17854198, 17854200, 17854202, 17854202, 17854171, 17854172, 17854178, 17854180, 17854169, 17854171, 17854175, 17854186, 17854200, 17854203, 17854178, 17854192, 17854201, 17854173, 17854180, 17854184, 17854186, 17854188, 17854201, 17854201, 17854205, 17854175, 17854177, 17854178, 17854188, 17854206, 17854184, 17854185, 17854179, 17854182, 17854182, 17854194, 17854207, 17854207, 17854208, 17854185, 17854183, 17854190, 17854201, 17854210, 17854192, 17854200, 17854188, 17854190, 17854212, 17854187, 17854189, 17854190, 17854191, 17854193, 17854197, 17854199, 17854200, 17854200, 17854212, 17854190, 17854190, 17854192, 17854192, 17854195, 17854196, 17854197, 17854198, 17854199, 17854200, 17854208, 17854210, 17854213, 17854190, 17854190, 17854194, 17854195, 17854195, 17854197, 17854198, 17854213, 17854214, 17854191, 17854193, 17854194, 17854196, 17854197, 17854198, 17854209, 17854212, 17854214, 17854193, 17854193, 17854195, 17854196, 17854196, 17854197, 17854198, 17854198, 17854199, 17854200, 17854208, 17854210, 17854212, 17854215, 17854203, 17854215, 17854195, 17854195, 17854196, 17854197, 17854198, 17854198, 17854214, 17854216, 17854198, 17854199, 17854211, 17854212, 17854214, 17854215, 17854217, 17854197, 17854199, 17854200, 17854216, 17854217, 17854200, 17854200, 17854201, 17854203, 17854218, 17854201, 17854205, 17854214, 17854218, 17854205, 17854219, 17854201, 17854202, 17854204, 17854215, 17854217, 17854219, 17854204, 17854205, 17854210, 17854220, 17854206, 17854215, 17854216, 17854217, 17854218, 17854219, 17854220, 17854208, 17854209, 17854221, 17854206, 17854218, 17854221, 17854207, 17854208, 17854216, 17854219, 17854222, 17854223, 17854223, 17854224, 17854224, 17854215, 17854225, 17854225, 17854226, 17854220, 17854226, 17854227, 17854223, 17854228, 17854229, 17854230, 17854231, 17854227, 17854229, 17854232, 17854232, 17854233, 17854231, 17854233, 17854231, 17854233, 17854234, 17854234, 18017345, 17854233, 17854235, 17854234, 17854234, 17854235, 17854235, 17854235, 17854236, 17854236, 17854236, 18001514, 17854237, 17854237, 17854238, 17854239, 17854240, 17854242, 17854243, 17854243, 17854246, 17854247, 17854248, 17854251, 17854256, 17854257, 17854258, 17854259, 17854262, 17854262, 17854264, 17854267, 17854268, 17854269, 17854271, 17854272, 17854272, 17854273, 17854273, 17854274, 18001513, 18001515, 18001517, 18001518, 18017347, 18017348, 18017349, 18017350, 18017370, 18114851, 19060590, 19060590, 17854239, 17854240, 17854248, 17854251, 17854263, 17854270, 17854271, 17854271, 17854272, 17854273, 17854273, 17854274, 17854274, 17854263, 17854274, 17854245, 17854275, 17854278, 17854257, 17854273, 17854279, 17854281, 17854282, 17854283, 17854261, 17854284, 17854275, 17854285, 17854286, 17854266, 17854273, 17854292, 17854293, 17854283, 17854292, 17854294, 17854297, 17854295, 17854295, 17854296, 17854296, 17854297, 17854298, 17854298, 18001538, 17854299, 17854299, 17854300, 17854302, 17854303, 17854301, 17854304, 17854305, 17854305, 17854304, 17854304, 17854305, 17854305, 17854306, 17854305, 17854307, 17854307, 17854306, 17854307, 17854307, 17854308, 17854307, 17854308, 17854308, 17854309, 17854309, 18001550, 18001552, 23173495, 17854310, 17854311, 17982484, 17982485, 17982486, 17982487, 18001543, 18001543, 18001544, 18001544, 18001546, 18001547, 18001547, 18001548, 18001548, 18001549, 18001549, 18001550, 18001550, 18001551, 18001551, 18001552, 18001552, 18001553, 18001553, 18001554, 18001555, 18017366, 18017381, 18017382, 18017383, 18017383, 18017384, 18017384, 18017385, 18017385, 18017386, 18017386, 18017393, 18017402, 18017406, 18017406, 18017408, 18017415, 18017417, 18017418, 18017419, 18017420, 18017421, 18017454, 18017454, 18017455, 18017456, 18017457, 18017457, 18041188, 18041264, 18041266, 18051206, 18051214, 19192158, 19635015, 19635033, 23173305, 23173495, 23176264, 18001552, 18001553, 18017383, 18017385, 18017419, 18001551, 18001552, 18001553, 18001554, 18017385, 18110673, 18110675, 18110674, 18110677, 18110677, 18145573, 18129738, 18129740, 18145573, 18145575, 18169451, 18148784, 18148779, 18148787, 18148801, 18148786, 18148787, 18148789, 18148789, 18148805, 18148785, 18148787, 18148789, 18148805, 18148806, 18148787, 18148789, 18148806, 18148790, 18148791, 18148806, 18148807, 18148789, 18148791, 18148791, 18148792, 18148793, 18148807, 18148807, 18148790, 18148791, 18148792, 18148792, 18148793, 18148808, 18148790, 18148791, 18148791, 18148792, 18148792, 18148808, 18148808, 18148809, 18148791, 18148792, 18148792, 18148793, 18148793, 18148795, 18148808, 18148809, 18148809, 18148792, 18148793, 18148793, 18148794, 18148795, 18148797, 18148809, 18148809, 18148810, 18148810, 18148793, 18148794, 18148794, 18148795, 18148796, 18148809, 18148810, 18148810, 18148811, 18148794, 18148795, 18148795, 18148810, 18148810, 18148811, 18148811, 18148795, 18148796, 18148800, 18148809, 18148810, 18148811, 18148811, 18148796, 18148797, 18148798, 18148804, 18148810, 18148811, 18148811, 18148812, 18148813, 18148797, 18148798, 18148811, 18148812, 18148812, 18148813, 18148813, 18148812, 18148812, 18148813, 18148813, 18148805, 18148812, 18148814, 18148813, 18148814, 18148814, 18148816, 18148819, 18148819, 18148825, 18164642, 18148826, 18148827, 18148827, 18148828, 18164625, 18164639, 18164640, 18164641, 18164641, 18164642, 18164642, 18164643, 18164643, 18164644, 18164645, 18164662, 18164708, 18164712, 18164713, 18164714, 18198470, 19207883, 18148827, 18148828, 18148828, 18148829, 18148830, 18164625, 18164626, 18164640, 18164640, 18164641, 18164641, 18164642, 18164642, 18164643, 18164643, 18164644, 18164645, 18164660, 18164661, 18164664, 18164666, 18164666, 18164671, 18164712, 18164715, 18164716, 18164717, 18164749, 18188521, 18198471, 18198476, 18320595, 19207884, 19896820, 18148828, 18164608, 18164624, 18164626, 18164629, 18164640, 18164641, 18164642, 18164642, 18164643, 18164643, 18164644, 18164644, 18164646, 18164646, 18164669, 18164679, 18164716, 18164627, 18164642, 18164642, 18164643, 18164643, 18164644, 18164644, 18164645, 23320755, 18164643, 18164643, 18164644, 18164645, 18164646, 18164646, 18180400, 18180435, 18180435, 18180432, 18180434, 18180435, 18180435, 18180436, 18180441, 18180450, 18180451, 18180451, 18180452, 18180453, 18180485, 18180487, 18180524, 18180453, 18180456, 18180454, 18180456, 18180454, 18180455, 18180457, 18180455, 18180456, 18180455, 18180456, 18180458, 18180456, 18180457, 18180457, 18180458, 18180458, 18180471, 18180471, 18180472, 18180473, 18180473, 18180457, 18180458, 18180458, 18180459, 18180459, 18180460, 18180460, 18180461, 18180461, 18180463, 18180470, 18180470, 18180471, 18180472, 18180472, 18180474, 18180458, 18180459, 18180459, 18180461, 18180466, 18180470, 18180472, 18180472, 18180473, 18180474, 18180479, 18180459, 18180460, 18180460, 18180461, 18180461, 18180462, 18180462, 18180471, 18180471, 18180472, 18180472, 18180473, 18180473, 18180474, 18180475, 18180460, 18180461, 18180461, 18180462, 18180462, 18180471, 18180472, 18180473, 18180473, 18180474, 18180475, 18180461, 18180462, 18180462, 18180463, 18180463, 18180464, 18180465, 18180467, 18180468, 18180469, 18180471, 18180472, 18180472, 18180473, 18180473, 18180474, 18180474, 18180475, 18180475, 18180476, 18180481, 18180463, 18180463, 18180468, 18180473, 18180474, 18180474, 18180475, 18180476, 18180477, 18180467, 18180474, 18180475, 18180477, 18180483, 18180464, 18180465, 18180472, 18180474, 18180475, 18180475, 18180476, 18180477, 18180479, 18180479, 18180480, 18180465, 18180466, 18180474, 18180475, 18180476, 18180476, 18180478, 18180480, 18180475, 18180476, 18180476, 18180477, 18180478, 18180478, 18180481, 18180476, 18180477, 18180479, 18180481, 18180477, 18180476, 18180478, 18180479, 18180478, 18180481, 18180483, 18180482, 18180506, 18180480, 18180484, 18180483, 18180484, 18180485, 18180486, 18180486, 18180484, 18180484, 18180485, 18180485, 18180486, 18180486, 18180487, 18180493, 18180485, 18180485, 18180486, 18180487, 18180487, 18180490, 18180495, 18204351, 18180485, 18180486, 18180487, 18180488, 18180499, 18180507, 18180486, 18180487, 18180487, 18180488, 18180488, 18180490, 18180498, 18180506, 18180545, 18204276, 23336583, 18180487, 18180488, 18180488, 18180489, 18180489, 18180491, 18180491, 18180493, 18180495, 18180501, 18180502, 18180508, 18180542, 18180544, 18180544, 18180545, 18204354, 18214219, 18180488, 18180489, 18180489, 18180490, 18180491, 18180491, 18180492, 18180492, 18180493, 18180494, 18180494, 18180495, 18180496, 18180497, 18180499, 18180501, 18180504, 18180505, 18180509, 18180509, 18180512, 18180515, 18180540, 18180544, 18180545, 18180545, 18180546, 18180546, 18204277, 18204351, 18204352, 18204356, 18214296, 18214298, 18214298, 18214300, 18214303, 18214303, 18214306, 18214310, 18336423, 18336426, 19355247, 19798098, 19798099, 21155545, 23161315, 23336584, 18180489, 18180490, 18180492, 18180495, 18180497, 18180490, 18180493, 18180495, 18180496, 18180504, 18180547, 18180549, 23336585, 18180491, 18180492, 18180492, 18180493, 18180493, 18180494, 18180494, 18180495, 18180495, 18180496, 18180496, 18180497, 18180497, 18180498, 18180498, 18180500, 18180500, 18180501, 18180501, 18180502, 18180502, 18180504, 18180504, 18180505, 18180505, 18180506, 18180506, 18180507, 18180507, 18180508, 18180508, 18180509, 18180509, 18180510, 18180510, 18180511, 18180511, 18180512, 18180512, 18180513, 18180516, 18180541, 18180542, 18180544, 18180545, 18180545, 18180546, 18180546, 18180547, 18180547, 18180548, 18180548, 18180549, 18204278, 18204279, 18204357, 18204358, 18204358, 18204359, 18210389, 18210390, 18214294, 18214297, 18214299, 18214301, 18214302, 18214303, 18214303, 18214304, 18214305, 18214309, 18214313, 18336427, 18336428, 18564095, 19098335, 19202553, 19223716, 19223716, 19223717, 19223721, 19798101, 19798105, 19798170, 21421826, 21587472, 23161315, 23161317, 23253551, 23336586, 23336632, 18180492, 18180493, 18180494, 18180494, 18180496, 18180496, 18180497, 18180497, 18180498, 18180498, 18180508, 18180509, 18180511, 18180511, 18180512, 18180512, 18180547, 18180548, 18204354, 18210392, 18214295, 18214306, 22207837, 23336586, 18180495, 18180501, 18180517, 18180552, 18180496, 18180497, 18180500, 18180508, 18180512, 18180516, 18214298, 18180495, 18180498, 18180499, 18180502, 18180504, 18180505, 18180510, 18180549, 18180550, 23336588, 18180496, 18180497, 18180497, 18180498, 18180498, 18180499, 18180499, 18180500, 18180501, 18180502, 18180503, 18180504, 18180505, 18180507, 18180508, 18180508, 18180509, 18180509, 18180510, 18180511, 18180511, 18180512, 18180513, 18180514, 18180549, 18180549, 18180550, 18204357, 18210393, 18214304, 18180498, 18180499, 18180508, 18180509, 18180515, 18180516, 18180520, 18180550, 18180500, 18180502, 18180505, 18180510, 18180512, 18180517, 18180501, 18180507, 18180512, 18180514, 18180515, 18180501, 18180502, 18180503, 18180504, 18180508, 18180509, 18180511, 18180513, 18180515, 18180515, 18180518, 18180501, 18180502, 18180502, 18180503, 18180504, 18180511, 18180514, 18180514, 18180516, 18180519, 18180521, 18180552, 23336591, 18180502, 18180503, 18180504, 18180505, 18180506, 18180507, 18180507, 18180510, 18180511, 18180512, 18180513, 18180513, 18180514, 18180515, 18180515, 18180516, 18180517, 18180517, 18180518, 18180519, 18180520, 18180522, 18180522, 18180503, 18180504, 18180506, 18180507, 18180508, 18180514, 18180514, 18180515, 18180516, 18180517, 18180518, 18180518, 18180519, 18180520, 18180521, 18180521, 18180504, 18180505, 18180506, 18180506, 18180507, 18180508, 18180508, 18180511, 18180511, 18180512, 18180513, 18180514, 18180516, 18180517, 18180518, 18180519, 18180519, 18180521, 18180522, 18180552, 18180507, 18180514, 18180515, 18180516, 18180517, 18180519, 18180520, 18180520, 18180521, 18180510, 18180512, 18180512, 18180513, 18180515, 18180516, 18180517, 18180519, 18180520, 18180520, 18180521, 18180522, 18180523, 18180539, 18180511, 18180521, 18180511, 18180515, 18180516, 18180518, 18180519, 18180519, 18180534, 18180536, 18180511, 18180513, 18180514, 18180514, 18180518, 18180519, 18180523, 18180535, 18180537, 18180521, 18180536, 18180515, 18180522, 18180524, 18180538, 18180539, 18180544, 18180519, 18180521, 18180523, 18180537, 18180538, 18180543, 18180520, 18180521, 18180525, 18180536, 18180543, 18180548, 18180548, 18180515, 18180523, 18180544, 18180549, 18180517, 18180526, 18180518, 18180518, 18180523, 18180540, 18180543, 18180518, 18180519, 18180520, 18180521, 18180522, 18180523, 18180525, 18180539, 18180540, 18180541, 18180544, 18180520, 18180521, 18180523, 18180525, 18180526, 18180527, 18180528, 18180541, 18180542, 18180522, 18180523, 18180523, 18180524, 18180526, 18180526, 18180542, 18180521, 18180522, 18180523, 18180523, 18180528, 18180528, 18180530, 18180541, 18180542, 18180522, 18180523, 18180523, 18180524, 18180524, 18180525, 18180525, 18180543, 18180523, 18180524, 18180524, 18180525, 18180526, 18180527, 18180528, 18180529, 18180530, 18180532, 18180542, 18180543, 18180524, 18180525, 18180525, 18180526, 18180526, 18180527, 18180527, 18180528, 18180529, 18180530, 18180531, 18180525, 18180526, 18180526, 18180527, 18180527, 18180528, 18180531, 18180544, 18180550, 18180552, 18180563, 18180526, 18180527, 18180527, 18180528, 18180528, 18180529, 18180529, 18180532, 18180538, 18180545, 18180545, 18180549, 18180527, 18180528, 18180528, 18180529, 18180534, 18180544, 18180545, 18180545, 18180546, 18180550, 18180528, 18180529, 18180529, 18180530, 18180530, 18180531, 18180532, 18180538, 18180543, 18180545, 18180546, 18180550, 18180529, 18180530, 18180530, 18180531, 18180532, 18180533, 18180545, 18180546, 18180546, 18180548, 18180530, 18180531, 18180531, 18180532, 18180532, 18180533, 18180533, 18180536, 18180545, 18180546, 18180546, 18180547, 18180548, 18214319, 18180531, 18180532, 18180532, 18180533, 18180533, 18180534, 18180535, 18180543, 18180547, 18180547, 18180551, 18180565, 18180567, 18336448, 19223736, 18180532, 18180533, 18180533, 18180535, 18180537, 18180547, 18180547, 18180548, 18180564, 18180568, 18214324, 18180533, 18180534, 18180534, 18180535, 18180536, 18180536, 18180546, 18180546, 18180548, 18180548, 18180549, 18180568, 18204300, 18210411, 18180534, 18180535, 18180535, 18180536, 18180537, 18180541, 18180546, 18180548, 18180548, 18180549, 18180569, 18204300, 18180535, 18180536, 18180537, 18180545, 18180548, 18180549, 18180549, 18180550, 18180554, 18180569, 18204376, 18214336, 18214347, 18180536, 18180537, 18180538, 18180539, 18180548, 18180548, 18180549, 18180550, 18180551, 18180554, 18180568, 18180569, 18180569, 18180570, 18204374, 18204375, 18214329, 19355271, 21047850, 23161339, 18180548, 18180550, 18180550, 18180570, 18214322, 18180538, 18180548, 18180549, 18180550, 18180550, 18180551, 18180571, 18204302, 19202573, 23253575, 18180539, 18180551, 18180551, 18180568, 18180570, 18214322, 18214326, 18180541, 18180551, 18180552, 18180572, 18180574, 18204379, 18966750, 18180552, 18180563, 18214327, 18214351, 18180553, 18180557, 18214328, 18180544, 18180553, 18180554, 18180572, 18180574, 23253577, 18180555, 18180561, 21421855, 18180557, 18180558, 18180577, 18180561, 18180581, 18180582, 18180585, 18180561, 18180562, 18180561, 18180562, 18180562, 18180565, 18180582, 18214338, 18180562, 18180563, 18204391, 18204401, 18214335, 19011211, 23336621, 18180563, 18180568, 18180570, 18180580, 18180581, 18180582, 18180583, 18180584, 18180584, 18204314, 18204315, 18214370, 19798139, 23336622, 18180564, 18180565, 18180566, 18180567, 18180567, 18180568, 18180568, 18180570, 18180571, 18180573, 18180576, 18180578, 18180581, 18180581, 18180582, 18180582, 18180583, 18180583, 18180584, 18180584, 18180585, 18180586, 18180587, 18180616, 18180617, 18180622, 18180622, 18180626, 18204315, 18204389, 18204390, 18204390, 18204391, 18204392, 18204394, 18204395, 18204395, 18204396, 18210428, 18210429, 18214257, 18214308, 18214317, 18214321, 18214329, 18214330, 18214332, 18214333, 18214333, 18214336, 18214338, 18214339, 18214339, 18214341, 18214344, 18214344, 18214346, 18214361, 18214363, 18214370, 18293737, 18293738, 18336464, 18336465, 19192572, 19202584, 19202585, 19223753, 19223753, 19223756, 19355285, 19606524, 19798140, 19798142, 19912686, 20500131, 21310992, 21421863, 22256660, 22269382, 22422460, 23161356, 23336622, 23336663, 23339196, 18180568, 18180569, 18180583, 18180584, 18180584, 18180585, 18214339, 19223753, 20449860, 23336623, 18180573, 18180582, 18214352, 18180569, 18180584, 18180585, 18180586, 18204391, 18214289, 18214318, 18929334, 18180584, 18204333, 18204395, 18214356, 18180575, 18204392, 18214341, 19798144, 18180572, 18214347, 18214351, 18214353, 18180588, 18214344, 18214349, 19223757, 18180574, 18180574, 18180580, 18180587, 18180587, 18180588, 18180588, 18180589, 18204346, 18204392, 18214341, 18214344, 18214352, 18336468, 19223755, 19798142, 22422464, 18180589, 18180590, 18214351, 18180589, 18204396, 23336628, 18180590, 18180605, 18214348, 18180588, 18180592, 18180594, 18180594, 18180594, 18214352, 18180595, 18180596, 18180595, 18180612, 18180612, 18180598, 18180613, 18180614, 18180600, 18180602, 18180615, 18180617, 18180599, 18180601, 18180616, 18180616, 18180617, 18180599, 18180600, 18180600, 18180601, 18180602, 18180604, 18180616, 18180601, 18180601, 18180602, 18180615, 18180617, 18180601, 18180602, 18180602, 18180603, 18180617, 18180617, 18180618, 18180602, 18180603, 18180603, 18180604, 18180605, 18180605, 18180616, 18180617, 18180617, 18180618, 18180619, 18180619, 18180603, 18180604, 18180604, 18180605, 18180607, 18180617, 18180617, 18180618, 18180618, 18180619, 18180619, 18180604, 18180605, 18180606, 18180611, 18180617, 18180618, 18180618, 18180619, 18180619, 18180605, 18180606, 18180606, 18180607, 18180608, 18180609, 18180616, 18180618, 18180618, 18180619, 18180619, 18180620, 18180621, 18180622, 18180606, 18180607, 18180608, 18180615, 18180616, 18180617, 18180619, 18180619, 18180620, 18180621, 18180618, 18180619, 18180620, 18180617, 18180618, 18180619, 18180619, 18180620, 18180620, 18180621, 18180623, 18180621, 18180618, 18180622, 18180622, 18180623, 18180623, 18180623, 18180624, 18214370, 18180629, 18180629, 18204426, 18180630, 18180631, 18180631, 18180631, 18180631, 18180632, 18180631, 18180632, 18180632, 18204419, 18180632, 18180633, 18180633, 18180634, 18204349, 18204426, 18210461, 18210462, 18214374, 18214376, 18214378, 18336498, 19223787, 19223787, 19223788, 20449893, 21426314, 23161387, 18180633, 18180634, 18180635, 18180636, 18180658, 18180669, 18204423, 18204426, 18204427, 18204428, 18204456, 18210460, 18210463, 18214352, 18214364, 18214367, 18214370, 18214376, 18214378, 18214396, 18336497, 18336498, 18464071, 19223788, 19325548, 19328643, 19798174, 23161387, 18180634, 18180635, 18180635, 18180636, 18180638, 18180650, 18180651, 18180655, 18180658, 18180659, 18180660, 18204350, 18204350, 18204422, 18204424, 18204425, 18204425, 18204427, 18204427, 18204428, 18204429, 18204430, 18204431, 18210461, 18210461, 18210462, 18210462, 18210463, 18210463, 18214292, 18214364, 18214367, 18214367, 18214368, 18214368, 18214370, 18214370, 18214371, 18214372, 18214372, 18214373, 18214373, 18214375, 18214377, 18214378, 18214379, 18214380, 18214381, 18214382, 18214390, 18214393, 18214397, 18214399, 18214400, 18293773, 18336498, 18336499, 18336500, 18924400, 18972087, 19011244, 19136476, 19202620, 19223787, 19223787, 19223788, 19223789, 19355320, 19798172, 19798176, 19798196, 19912722, 20782454, 21237333, 21311027, 21421898, 22207908, 23161391, 23161392, 23336657, 23336657, 18180635, 18180636, 18204350, 18204351, 18204426, 18204426, 18204427, 18204429, 18204432, 18204433, 18210462, 18210464, 18214293, 18214366, 18214367, 18214369, 18214370, 18214373, 18214373, 18214375, 18214379, 18214379, 18214380, 18214383, 18214386, 18214398, 18336500, 18481101, 18765392, 19011245, 19202624, 19223717, 19223789, 19223789, 19355320, 19821918, 20742818, 21421898, 23253623, 18180663, 18271530, 18336499, 19223789, 19223789, 19223790, 19606560, 18180640, 18204351, 18214378, 18214378, 18214382, 18336501, 19798177, 21421898, 18180639, 18180656, 18204431, 18336501, 18204436, 19223724, 18214374, 19223793, 18180708, 18180685, 18180686, 18180693, 18180692, 18180702, 18180697, 18180698, 18180691, 18180694, 18180700, 18180696, 18180702, 18180702, 18204458, 18210494, 18204459, 18214401, 23339044, 18180723, 18204466, 18214415, 18204465, 18204467, 18210501, 18210502, 18214438, 18214419, 18210509, 19223841, 18210520, 18228075, 18228076, 18228076, 18228085, 18228149, 18228149, 18228150, 18228151, 18228152, 18228152, 18228153, 18228154, 18228155, 18228155, 18228156, 18228157, 18228160, 18228162, 18228150, 18228151, 18228151, 18228152, 18228153, 18228164, 18228180, 18228185, 18228119, 18228135, 18234216, 18234220, 18228251, 18228214, 18228241, 18228213, 18228242, 18228220, 18228242, 18228215, 18228217, 18228243, 18228216, 18228217, 18228217, 18228220, 18228243, 18228216, 18228219, 18228244, 18228217, 18228218, 18228219, 18228220, 18228221, 18228244, 18228220, 18228221, 18228245, 18228219, 18228220, 18228221, 18228224, 18228245, 18228245, 18228222, 18228224, 18228225, 18228245, 18228246, 18228246, 18228224, 18228246, 18228247, 18228247, 18228247, 18228228, 18228248, 18228226, 18228248, 18228249, 18228249, 18228249, 18228249, 18228250, 18228250, 18228250, 18228251, 18228234, 18228252, 18228254, 18228254, 18228255, 18228256, 18228256, 18228271, 18234280, 18238196, 18360317, 19754937, 19821995, 23360476, 18228272, 18228273, 18234279, 18234280, 18234280, 18234281, 18234282, 18234284, 18238033, 18238164, 18238186, 18238187, 18238187, 18238188, 18238189, 18238190, 18238190, 18238191, 18238192, 18238192, 18238193, 18238194, 18238194, 18238195, 18238195, 18238197, 18238198, 18238198, 18238199, 18238199, 18238203, 18238208, 18238216, 18238217, 18238220, 18238220, 18238223, 18360317, 18360318, 19122226, 19226438, 19226439, 19247606, 19247607, 19379139, 19821989, 19821994, 19821994, 19821996, 20501337, 20766636, 23185210, 23185210, 23237289, 23360476, 18238198, 23185211, 18228291, 18228294, 18228295, 18228299, 19247619, 19247625, 18238214, 18234302, 18238207, 18240287, 18240288, 18240302, 18240289, 18240302, 18240304, 18240303, 18240304, 18240290, 18240291, 18240292, 18240293, 18240303, 18240305, 18240303, 18240305, 18240306, 18240304, 18240293, 18240294, 18240306, 18240307, 18240305, 18240307, 18240307, 18240307, 18240308, 18240318, 18244209, 18240318, 18240319, 18244210, 18244215, 18244217, 18244220, 18244224, 18737206, 19041088, 19232461, 19253630, 19355390, 20479190, 18244215, 18240320, 18244190, 18244192, 18244195, 18244210, 18244210, 18244211, 18244212, 18244213, 18244214, 18244215, 18244216, 18244216, 18244217, 18244217, 18244218, 18244219, 18244222, 18244227, 18244230, 18244239, 18244242, 18244242, 18244247, 18323616, 18366342, 18366343, 19232462, 19253630, 19253631, 19253631, 19385163, 19828020, 19828035, 18244055, 18244196, 18244216, 18244218, 18244220, 18244242, 18366342, 18366343, 19166319, 18247809, 18247811, 18247966, 18247968, 18248026, 18248086, 18248106, 18248083, 18248080, 18248079, 18248122, 18248098, 18248118, 18248090, 18248091, 18248105, 18248099, 18248107, 18248109, 18248130, 18248138, 18248103, 18248141, 18248107, 18248101, 18248104, 18248105, 18248112, 18248113, 18248116, 18248135, 18248137, 18248144, 18248146, 18248148, 18248104, 18248107, 18248112, 18248105, 18248106, 18248112, 18248115, 18248131, 18248146, 18248148, 18370233, 19257522, 18248104, 18248104, 18248109, 18248113, 18248116, 18248131, 18248132, 18248132, 18248137, 18248140, 18248148, 18248154, 18248104, 18248109, 18248132, 18248133, 18248152, 18248108, 18248110, 18248136, 18248107, 18248109, 18248116, 18248120, 18248133, 18248134, 18248138, 18248110, 18248134, 18248110, 18248111, 18248116, 18248116, 18248118, 18248118, 18248134, 18248135, 18248135, 18248139, 18248149, 18248150, 18248151, 18248114, 18248116, 18248123, 18248135, 18248154, 18248115, 18248121, 18248135, 18248140, 18248152, 18248112, 18248115, 18248115, 18248116, 18248136, 18248136, 18248122, 18248123, 18248136, 18248137, 18248137, 18248139, 18248152, 18248114, 18248117, 18248119, 18248130, 18248137, 18248137, 18248138, 18248153, 18248154, 18248155, 18248156, 18248114, 18248115, 18248116, 18248120, 18248137, 18248138, 18248139, 18248116, 18248117, 18248119, 18248120, 18248123, 18248124, 18248137, 18248138, 18248139, 18248141, 18248154, 18248118, 18248120, 18248138, 18248139, 18248139, 18248141, 18248142, 18248143, 18248120, 18248138, 18248139, 18248142, 18248125, 18248128, 18248131, 18248137, 18248140, 18248142, 18248153, 18248119, 18248121, 18248121, 18248123, 18248128, 18248141, 18248143, 18248143, 18248144, 18248155, 18248121, 18248122, 18248128, 18248140, 18248142, 18248142, 18248144, 18248154, 18248165, 18248151, 18248142, 18248142, 18248144, 18248159, 18248124, 18248131, 18248142, 18248143, 18248143, 18248145, 18248147, 18248125, 18248125, 18248128, 18248129, 18248131, 18248134, 18248142, 18248143, 18248143, 18248144, 18248144, 18248145, 18248146, 18248146, 18248147, 18248147, 18248148, 18248148, 18248158, 18248160, 18248166, 18248167, 18248132, 18248143, 18248145, 18248146, 18248147, 18248148, 18248144, 18248145, 18248146, 18248147, 18248147, 18248149, 18248131, 18248144, 18248144, 18248145, 18248147, 18248148, 18248150, 18248130, 18248138, 18248144, 18248131, 18248144, 18248145, 18248147, 18248152, 18248154, 18248146, 18248147, 18248147, 18248149, 18248150, 18248151, 18248152, 18248153, 18248158, 18248159, 18248148, 18248147, 18248148, 18248151, 18248158, 18248148, 18248150, 18248152, 18248154, 18248158, 18248155, 18248155, 18248158, 18248151, 18248155, 18248140, 18248147, 18248150, 18248154, 18248156, 18248164, 18248150, 18248145, 18248168, 18248158, 18248152, 18248169, 18248156, 18248171, 18248155, 18248150, 18248155, 18248156, 18248157, 18248157, 18248159, 18248161, 18248164, 18248178, 18248181, 18248160, 18248162, 18248176, 18248178, 18248183, 18248161, 18248162, 18248162, 18248163, 18248163, 18248164, 18248164, 18248165, 18248165, 18248166, 18248166, 18248169, 18248170, 18248171, 18248176, 18248177, 18248179, 18248180, 18248186, 18370262, 18370263, 18679211, 18799150, 19257551, 19257552, 19389083, 19832008, 21455661, 22150386, 23370420, 23370421, 18248162, 18248163, 18248163, 18248165, 18248166, 18248167, 18248168, 18248174, 18248176, 18248183, 18248186, 18327537, 18370262, 18370263, 18370264, 19170240, 19257551, 19725925, 20519202, 22150399, 23195155, 23370421, 18248163, 18248164, 18248165, 18248165, 18248166, 18248167, 18248169, 18248171, 18248178, 18248180, 18248184, 18248186, 18327537, 18370263, 19257551, 19257552, 19257553, 19831877, 19831941, 19831960, 23195156, 23287387, 18248165, 18248166, 18248166, 18248168, 18248169, 18248171, 18248175, 18248180, 18248181, 18248182, 18248187, 19257553, 19257554, 19831942, 18248166, 18248168, 18248168, 18248169, 18248169, 18248173, 18248186, 18370264, 18370264, 18370266, 19045009, 19236385, 19257553, 21455663, 18248168, 19257555, 19491775, 18248167, 18248168, 18248169, 18248174, 18248178, 18248182, 18248184, 18248184, 18248189, 18370265, 18851806, 18981325, 19236386, 19236390, 19257552, 19257553, 19257554, 20989516, 23287389, 18248174, 18248178, 18248179, 18248186, 18248189, 18305294, 18305296, 18327540, 18370265, 18370266, 19257555, 19257555, 19831962, 23195156, 23370424, 18248170, 18248171, 18248173, 18248174, 18248176, 18248185, 18305296, 18370266, 18370267, 18370268, 18542819, 19257555, 19946489, 23370425, 18248174, 18248185, 18370266, 19170244, 19257557, 19389088, 19831945, 23195156, 18248172, 18248172, 18248174, 18248175, 18248183, 18370267, 18370268, 18958168, 19236387, 19236389, 19257557, 19831881, 19832013, 23370426, 18248173, 18248175, 18248187, 18248189, 18248191, 18305297, 19257557, 19831940, 19831964, 23195156, 23370426, 18248174, 18248177, 18248180, 19170245, 19257558, 19491651, 19831945, 20816224, 22999039, 23195158, 23370427, 18248185, 18248191, 18248192, 18248192, 19257558, 18248187, 18248191, 18248193, 18679218, 19045014, 19831945, 21455666, 19257559, 18248181, 18248194, 18370270, 18248194, 18370271, 20816226, 23370429, 18248181, 18248190, 18248194, 18370272, 18248185, 18248192, 18370272, 19831950, 20438754, 18248184, 18248196, 19257562, 21455672, 23195161, 18248187, 19026572, 19389094, 18974838, 18248185, 18604674, 23370433, 18248188, 19946499, 18248187, 18248197, 19257565, 21189396, 18248190, 18248191, 18248193, 18370276, 18248196, 19257566, 19831951, 19831952, 18248192, 18370278, 18799167, 19045025, 19257566, 19946500, 18248191, 18370277, 19257567, 19725940, 18370279, 19132186, 19170255, 19257567, 18248194, 18248198, 18370278, 18958177, 19257568, 19640337, 18327553, 18370278, 18370279, 18370280, 18370280, 19170256, 19257567, 19831957, 21344807, 18327554, 18370275, 18370279, 18370279, 18370280, 19257569, 19432505, 23287404, 18248199, 19045028, 19257569, 19257570, 19831950, 18958182, 19257569, 19257570, 20483676, 20511097, 18248205, 19257571, 20483677, 22150417, 19831955, 18248205, 18327556, 19132190, 19236403, 21189403, 18370283, 18421956, 18370284, 19257573, 18617239, 19257572, 18248207, 19389105, 22400206, 23195174, 18305315, 18327559, 18370285, 18370286, 18574583, 23370444, 18370286, 19257575, 19257576, 18370286, 18370287, 18851827, 19257580, 19831965, 19831966, 19831984, 18327561, 18370287, 18469429, 18614589, 19236408, 19257576, 19257576, 21455686, 21460104, 23195177, 18362433, 18362434, 18362425, 18362436, 18362437, 19889079, 20003628, 18427406, 18427407, 20540255, 23344530, 18375476, 19895604, 18406922, 18406923, 18406924, 18406924, 19911263, 19336939, 19336939, 18449650, 18449651, 18931185, 19249627, 19315772, 19336940, 19468471, 21535049, 18492359, 18492376, 18492363, 18492377, 18492378, 18492363, 18492364, 18492378, 18492378, 18492365, 18492378, 18492379, 18492379, 18492367, 18492378, 18492378, 18492379, 18492379, 18492380, 18492381, 18492380, 18492380, 19379666, 18492392, 18492392, 19080278, 19254287, 19954055, 18492392, 19254287, 19292355, 19954053, 22272512, 22272514, 19358499, 19379667, 19379667, 19379668, 19511199, 19954052, 20898697, 20938334, 21564185, 21577778, 23409502, 18696676, 18739336, 18801327, 18921268, 18945309, 18990142, 19080279, 19080280, 19148679, 19153959, 19167123, 19167124, 19167125, 19241482, 19292356, 19358496, 19358499, 19358500, 19358501, 19379667, 19379667, 19379668, 19379668, 19379669, 19511200, 19517474, 19762439, 19954053, 19954055, 19954057, 19954123, 20068602, 20258489, 20423772, 20831476, 21311499, 21577778, 23314187, 23317268, 23317271, 23409503, 23492537, 23494929, 19953994, 18595720, 18595863, 18596006, 20005864, 18690665, 19478812, 18747570, 18747631, 19507288, 18781604, 19503124, 18837479, 18837495, 18837510, 21110897, 18900971, 18900972, 19496651, 20158352, 18947712, 19607333, 18961175, 19614064, 18980979, 19372265, 18986287, 18986291, 19626622, 19626623, 19110276, 19688616, 19688617, 19234104, 19234160, 19234215, 23688182, 19350155, 19350156, 19350157, 19350163, 19808556, 19940088, 21062084, 19398235, 19832593, 19455451, 19455459, 19455460, 19861206, 19999008, 19861141, 19487901, 23990296, 19668176, 19668181, 19668179, 19668181, 19668182, 19736575, 19755024, 19946401, 19958362, 20099101, 20541956, 24080439, 19678114, 19972534, 19701505, 19984230, 19714495, 19903412, 19752977, 20009968, 19763556, 19763556, 20015256, 24045092, 19804973, 19804975, 19804975, 20610349, 19910584, 20035964, 19815539, 20041247, 19841868, 19841869, 19841870, 19841867, 19841870, 19841870, 19841871, 19841872, 19841872, 20054410, 20628801, 20054413, 20054413, 22141652, 19872404, 20054414, 20628799, 21573444, 24084248, 24167283, 19902982, 20084992, 19990580, 20703174, 20016189, 20016190, 20016193, 20016192, 20016317, 20016318, 20016318, 20016319, 20141572, 20016446, 20016446, 20120531, 20120531, 20141698, 20273231, 20716088, 22344226, 20092319, 20092330, 20092330, 20092331, 20092331, 20092333, 20092334, 20092332, 20179642, 20179642, 20179643, 20754029, 20179642, 20179643, 24117241, 20092344, 20179643, 20179644, 20311304, 20179645, 20179645, 20709875, 20204595, 20810161, 20224619, 20224615, 20224606, 20224618, 20224618, 20224623, 20224619, 20224619, 20224624, 20224626, 20224627, 20224626, 20245785, 20224636, 20245784, 20245785, 20245786, 20245786, 20245787, 20377318, 20820173, 22333026, 24183386, 24358656, 23444428, 20245790, 20245791, 20245792, 24183394, 24358661, 24358714, 20248539, 20389278, 20266808, 20266817, 20266881, 20266885, 20266887, 20266939, 20266940, 20266956, 20266941, 20266954, 20266955, 20266955, 20266956, 20266957, 20266941, 20266942, 20266956, 20266956, 20266957, 20266957, 20266958, 20266942, 20266943, 20266946, 20266954, 20266956, 20266957, 20266957, 20266958, 20266958, 20266943, 20266944, 20266945, 20266946, 20266956, 20266956, 20266957, 20266958, 20266958, 20266959, 20266959, 20266961, 20266945, 20266946, 20266946, 20266957, 20266957, 20266958, 20266958, 20266959, 20266959, 20266960, 20266960, 20266958, 20266960, 20266961, 20266961, 20266961, 20266962, 20266964, 20266962, 20266966, 20266966, 20266968, 20266972, 24204556, 20266972, 20398488, 20841341, 23370630, 20266972, 20266973, 21815125, 22354196, 24204556, 24204558, 24204559, 20266973, 20266973, 20300263, 20797192, 20841344, 20841346, 22354196, 22465067, 23159802, 24204557, 24204558, 24379826, 20266973, 20266974, 20266974, 20398489, 20398490, 20501176, 20841341, 20841342, 20841343, 20841343, 20841415, 20955891, 21656817, 21678025, 21785987, 22354196, 22354197, 22451475, 24004664, 24201478, 24204557, 24296793, 24379827, 20266974, 20266976, 20371815, 20398486, 20398489, 20398490, 20398490, 20404760, 20501176, 20501177, 20501179, 20649729, 20710508, 20774303, 20792304, 20841283, 20841342, 20841344, 20841363, 20841417, 20841556, 22354196, 22354197, 22465068, 22469485, 23159805, 24204557, 24204559, 24296793, 20266975, 20266976, 20266976, 20266977, 20266978, 20321583, 20335855, 20371815, 20371898, 20398490, 20398491, 20404761, 20441895, 20501177, 20649729, 20792308, 20797190, 20797194, 20841283, 20841342, 20841343, 20841343, 20841344, 20841344, 20841345, 20841345, 20841346, 20841346, 20841347, 20841348, 20841349, 20841364, 20859452, 20955890, 20955892, 20955892, 20955893, 20955894, 21517697, 21520483, 21678025, 21843562, 22057139, 22198790, 22198791, 22354197, 22465068, 22465069, 22469486, 22469486, 22581775, 23159805, 23159806, 23370633, 23409591, 23409592, 23465595, 24204558, 24204559, 24256639, 24256640, 24296793, 24379828, 24379875, 24380523, 20398491, 20841345, 20841346, 20955892, 24204562, 22465069, 20841285, 20841345, 24204560, 24204564, 20841348, 24379889, 20774291, 20501184, 20333566, 20431792, 20376205, 20895906, 20404747, 20467382, 20470479, 20943104, 21057653, 20476662, 20476665, 20476749, 20476750, 20476751, 20476833, 20476836, 20476836, 23852616, 24484763, 20530003, 20530014, 20530006, 20530007, 20530015, 20530016, 20530017, 20530018, 20530021, 20530012, 20530016, 20530016, 20530017, 20530016, 20530022, 20530143, 20530025, 20530026, 20530027, 20530028, 20530140, 20530140, 20530141, 20530143, 20530143, 20530144, 20530141, 20530142, 20530144, 20530144, 20530144, 20530145, 20530145, 20530146, 20530144, 20530146, 20530147, 20530149, 20530265, 20530269, 20530266, 20530268, 20530267, 20530270, 20530271, 20530262, 20530271, 20530272, 20530272, 20530272, 20530273, 20530273, 20530274, 23578230, 24511478, 20972995, 20928845, 20928846, 24511480, 24511480, 20973000, 24336214, 24388293, 20530282, 20632830, 20748322, 20923962, 20972937, 20972994, 20972994, 20972995, 20972997, 20972998, 20972998, 20972999, 20973001, 20973214, 21087545, 21087547, 21611719, 21624718, 22596722, 22762368, 23382733, 23382733, 23597235, 23597251, 23777477, 24336215, 24472492, 24511481, 20573549, 20632830, 20972999, 20973000, 22762368, 23597319, 24511482, 24336214, 20632832, 20542561, 20542564, 20542566, 20542567, 20542568, 20754471, 22607289, 21600646, 21093698, 24517634, 20616828, 20616828, 21016279, 21394380, 21016217, 20735138, 20735268, 20735393, 20735394, 20735393, 20735395, 20735397, 20735397, 20735398, 20735398, 21026525, 21075500, 21075561, 22588414, 23604850, 24531010, 21075501, 21075564, 21075565, 22588414, 23643810, 20966400, 21495512, 22814800, 21032494, 21032496, 21032501, 21032501, 21179959, 24679560, 21224117, 22847843, 24587331, 24587331, 24762600, 21154052, 21284891, 21203704, 21203704, 21309719, 21309715, 21281622, 21281624, 21281650, 21348680, 22972403, 21348691, 21317650, 21317653, 21317654, 21366686, 21366692, 21659955, 24729905, 21327418, 21327421, 21327423, 21327424, 21327424, 21371513, 21371514, 21371574, 21371578, 21371597, 22729020, 22884427, 21415601, 21415602, 21415602, 21415661, 21415662, 21415662, 21415663, 21415665, 21415688, 21415735, 21415612, 21415662, 21415663, 21415663, 21415688, 21415663, 21415687, 21415708, 21415723, 21415724, 21415726, 21415726, 21415727, 21415713, 21415726, 21415727, 21415711, 21415711, 21415713, 21415713, 21415715, 21415728, 21415736, 21415712, 21415713, 21415714, 21415716, 21415728, 21415729, 21415730, 21415737, 21415713, 21415714, 21415714, 21415715, 21415716, 21415716, 21415717, 21415728, 21415729, 21415729, 21415714, 21415715, 21415716, 21415717, 21415717, 21415730, 21415731, 21415715, 21415716, 21415717, 21415718, 21415725, 21415730, 21415730, 21415717, 21415717, 21415718, 21415718, 21415729, 21415730, 21415730, 21415731, 21415717, 21415732, 21415719, 21415719, 21415727, 21415728, 21415731, 21415731, 21415732, 21415738, 21415719, 21415732, 21415732, 21415720, 21415721, 21415721, 21415722, 21415722, 21415725, 21415730, 21415731, 21415732, 21415732, 21415733, 21415733, 21415734, 21415735, 21415739, 21415740, 21415740, 21415741, 21415741, 21415732, 21415733, 21415734, 21415734, 21415736, 21415742, 21415723, 21415732, 21415733, 21415733, 21415734, 21415742, 21415728, 21415734, 21415743, 21415735, 21415738, 21415743, 21415738, 21415739, 21415797, 21415741, 21415798, 21415742, 21415744, 21530275, 21415744, 21415752, 21415753, 23051023, 24954212, 21415744, 21415745, 21415745, 21415746, 22066905, 24778944, 24954212, 21415745, 21415803, 22400010, 22928583, 23039454, 24778943, 24954213, 21415746, 21415747, 21415747, 21415748, 21415748, 21415750, 21415751, 21415751, 21415753, 21415754, 21415754, 21415755, 21415765, 21415801, 21415802, 21415803, 21415803, 21415939, 21530277, 21530278, 21530279, 21561995, 21838440, 21927926, 22037227, 22066904, 22066906, 22067450, 22092082, 22094869, 22117722, 22117724, 22221125, 22400010, 22400011, 22400012, 22523024, 22744339, 22859101, 22928582, 22928583, 22928583, 23039454, 23043871, 23062097, 23158769, 23205100, 23205100, 23422967, 23734189, 23945019, 24020964, 24322066, 24778943, 24778943, 24778944, 24778945, 24778945, 24778946, 24778947, 24871179, 24954213, 24954254, 21415751, 21415755, 21415803, 21557156, 22067451, 22099430, 23734191, 24039969, 24778944, 24954214, 21415753, 21415755, 23039454, 24220210, 21415749, 21415750, 21415754, 21415755, 21530279, 21530280, 24954215, 21415754, 21415755, 21415757, 22928584, 24778949, 21415752, 21415756, 21415767, 23025864, 24954216, 21415768, 21415755, 21415757, 21415769, 22400016, 21415758, 21415759, 23039457, 21415758, 21415760, 21415769, 21415770, 23985504, 21415759, 21415760, 21415770, 21415771, 21415771, 22928589, 24871185, 24954219, 21415772, 21530284, 22103003, 22389519, 24778952, 21415761, 21415762, 21415762, 21415770, 21415772, 23734196, 24778952, 24954221, 21415762, 21415763, 21415772, 21415772, 21415773, 21530286, 21530287, 22066916, 22400020, 22928591, 23039460, 23734198, 23825474, 21415764, 21415772, 21415810, 21415812, 21415813, 21415813, 21530286, 21689955, 22400020, 22928591, 23039461, 23039462, 24778952, 24778953, 24954222, 21415774, 23734198, 24778949, 22400022, 21415775, 21415815, 22854906, 23985516, 24778962, 24778966, 24871197, 24954190, 21415911, 21530296, 23039472, 23734211, 23945037, 24871197, 21415823, 21530296, 22928601, 24871198, 24954232, 24954242, 22117741, 22896289, 23039473, 23734210, 24954233, 21415865, 21415865, 21415867, 21415867, 21415867, 21415867, 21415870, 21415868, 21415869, 21415870, 21415869, 21415870, 21415870, 21415871, 21415871, 21415875, 21415872, 21415874, 21415878, 21415878, 21415873, 21415879, 21415879, 22928648, 21530343, 24954279, 21530346, 22928649, 24871245, 22117789, 24954280, 22400078, 23039521, 23039523, 23734249, 24021034, 24779012, 24954281, 22928651, 22928652, 24775932, 24954282, 22400080, 22928654, 22103068, 22026386, 22400085, 22773251, 24942203, 21530351, 21416056, 24954377, 21416156, 21416154, 21416162, 21530491, 23051242, 23205316, 21451951, 21548391, 21463224, 24802694, 21644821, 21644809, 21644811, 21644822, 21644822, 21644823, 21644824, 21644823, 21644824, 21644825, 21644825, 21644826, 21644826, 21644825, 21644827, 21644823, 21644825, 21644825, 21644826, 21644828, 21644835, 21644835, 22217540, 25068758, 22269553, 23043127, 23043128, 23153999, 23158416, 24893488, 21644838, 22042471, 22514557, 22646567, 22887722, 23153999, 23158417, 23319645, 23940011, 24985724, 25029768, 25068759, 23154000, 24439493, 24944545, 23848736, 25068760, 21644842, 22514559, 22858887, 23043129, 23153998, 23848736, 25068760, 22474921, 23154001, 23158419, 25068761, 23158419, 25068761, 22029834, 24893492, 21698624, 25095681, 21708259, 25100477, 21964160, 23202797, 22002256, 22410984, 22024600, 22024601, 25175614, 22399305, 22171934, 24112282, 22261176, 22261231, 22261307, 25377024, 22355168, 25423933, 22414837, 25370730, 22440118, 22440119, 24337658, 25466406, 22629340, 24340994, 22636889, 22713574, 22658722, 22658723, 23021505, 22693166, 22693240, 22693314, 24372980, 22718079, 22718080, 22718075, 22718081, 22718082, 23051182, 23051185, 25430117, 25605388, 25482201, 23011552, 22719175, 22719192, 22719247, 22769463, 23695613, 25182293, 25430685, 25482767, 25522920, 25605955, 22719315, 23695664, 22768433, 23715805, 24660327, 22774007, 22774008, 22774008, 22774009, 23607720, 24413329, 23705000, 23718594, 24957407, 22774412, 25633552, 22783141, 23723164, 22790257, 22790259, 22790259, 22790259, 23087273, 23615845, 25466206, 25641476, 25641477, 22819713, 22819715, 23062362, 23630574, 23741445, 23753017, 24436182, 25480938, 22894283, 23667857, 23026514, 23026615, 23026717, 23335976, 23046672, 24928229, 23089088, 23089089, 23765260, 25790702, 23170569, 25656361, 23305008, 23305011, 23305012, 23305012, 23305014, 23305015, 23305015, 23344646, 23305053, 23305082, 23305125, 23305130, 23305087, 25898854, 23305094, 24874158, 23305151, 23305159, 23984161, 23344722, 23305241, 23305246, 25223023, 25898968, 23363292, 23363292, 24178879, 23902363, 23384283, 23384275, 23384277, 23384290, 23384291, 23384291, 23384292, 23384293, 23384294, 23384295, 23384291, 23384292, 23384295, 23384296, 23384293, 23384295, 23384296, 23384294, 23384296, 23384297, 23514760, 23912862, 24718470, 23384310, 25763224, 23757456, 24023735, 24718472, 25763229, 25938494, 23384312, 24809746, 24189382, 24718462, 23757459, 24023737, 24929302, 25938497, 24023738, 24718476, 25763228, 25763230, 23912867, 24023737, 24718474, 25938498, 23420162, 23420164, 23525233, 24986192, 23630308, 23630315, 23630415, 24035875, 23630515, 23880565, 23645237, 23645238, 23795779, 25893696, 23648313, 25895235, 23730877, 25936519, 23847347, 24255275, 23915220, 23915371, 23915536, 23915607, 26204144, 23946320, 24161562, 24072948, 24072949, 25062798, 25368659, 24130618, 24130619, 24130620, 24130619, 24130618, 24130620, 24130622, 24562541, 26311656, 26311657, 26311657, 24253714, 24396898, 24562545, 25091625, 25397492, 26311658, 26311659, 24294045, 24294046, 24367739, 26310336, 24302467, 24487237, 24376802, 24376804, 24376954, 24376954, 24493258, 24377102, 24377105, 24685783, 26259628, 24441431, 24441419, 24441432, 24441432, 24441433, 24441432, 24441433, 24441433, 24441433, 24441433, 24441434, 24441434, 26291793, 24441445, 24552301, 24552302, 24552303, 24552304, 25022966, 25247041, 25454773, 26291791, 26291794, 26291794, 26291796, 26467063, 24485671, 24552302, 24552303, 24552304, 24667903, 24715362, 24717950, 24931808, 24941204, 24944593, 25247039, 25247040, 25552899, 26291794, 26291794, 26291797, 26467063, 25247030, 25247041, 26291795, 26467064, 24529907, 25166895, 24609713, 24636444, 24635987, 24636065, 24636068, 24636144, 24636149, 24649657, 26389148, 26481383, 25344397, 24663171, 24663174, 24663160, 24663174, 24663174, 24663175, 24663175, 24663175, 24663162, 24663164, 24663165, 24663176, 24663176, 24663177, 24663177, 24663178, 24663178, 24663177, 24663178, 24663178, 24663178, 24663179, 24663179, 24663179, 24663180, 24663180, 26577933, 26402668, 26577935, 24663191, 24719553, 25357913, 25663702, 26402666, 26577935, 24667594, 25357912, 26402666, 26402668, 24663192, 24663193, 24674749, 24674749, 24767717, 24828823, 24955887, 25215480, 25357912, 25357913, 25357914, 25607699, 26154274, 26402666, 26402667, 26402668, 26402668, 26454749, 26577936, 24965087, 25357913, 25663771, 25775411, 25973868, 26402667, 26402667, 26402671, 26454748, 26577937, 24674750, 24828824, 25357915, 26402668, 26402669, 26402671, 26402671, 26577937, 26402672, 26577938, 24672010, 24672010, 24672012, 24672009, 24672009, 24672010, 24672010, 24672012, 24672011, 26407082, 26582351, 24833238, 25362329, 26582352, 25231359, 25668188, 25978283, 26003533, 26407083, 26407084, 26582352, 25573158, 24786909, 25362332, 24686317, 24686318, 24686319, 24790345, 24794062, 25369484, 25675343, 26464963, 26589506, 24708517, 26600633, 24775932, 25414290, 24872258, 25151233, 24894372, 24894373, 25473511, 26518267, 24896591, 26611609, 24901804, 24901804, 24901805, 25477225, 25477227, 26697303, 24989291, 26006988, 24994465, 24994465, 24994466, 24994466, 24994467, 24994466, 24994467, 26009574, 26568307, 26660544, 26743578, 24994478, 25523557, 25734383, 26565228, 26568309, 26568310, 25773342, 26568310, 26743579, 26003918, 26159615, 26743580, 26568309, 26568312, 26660546, 25248594, 26870643, 25267046, 26879895, 25422182, 26765295, 25430201, 25430205, 26961447, 25741424, 25441000, 25441070, 25441141, 26791660, 25447756, 26970226, 25604550, 27048647, 25767780, 25910215, 25790731, 25921690, 25803883, 25928265, 26052638, 26052637, 26052639, 26052626, 26052637, 26052640, 26052635, 26052647, 26052647, 26052648, 26052633, 26052635, 26052648, 26052648, 26052649, 26052648, 26052649, 26052649, 26052636, 26052650, 26052649, 26052650, 26052651, 26052651, 26052648, 26052649, 26052650, 26052650, 26052651, 26052651, 26052652, 26052652, 26052653, 26052650, 26052651, 26052650, 26052651, 26052652, 26052662, 26358508, 27272671, 26302438, 26358510, 26668602, 27272671, 26052663, 26052664, 27097402, 27097403, 27272672, 26052665, 26052668, 26263477, 26302437, 26358508, 26538668, 27094323, 27097402, 27097403, 27189638, 27272672, 27272672, 26358440, 26538669, 26901385, 27097403, 27097403, 27097405, 27189638, 27272673, 26143924, 26143925, 27097404, 26303960, 26358511, 26358512, 27097404, 27272674, 27097405, 27097406, 27097407, 27272676, 26235196, 26235197, 26235198, 26235196, 26235197, 26235197, 26235198, 26235198, 26235199, 27188675, 27363945, 26393708, 27185597, 27188677, 26362424, 27188676, 27363805, 27363947, 26332767, 26332882, 26332995, 27412843, 26358216, 27425456, 26443224, 26553795, 26468117, 26510170, 26474305, 26474306, 26474306, 26474307, 27483500, 26513263, 26569338, 27308234, 27360312, 26569337, 27308230, 27400467, 27483501, 26489651, 27315904, 26552221, 26552220, 26552220, 26552221, 26552222, 26552222, 26552225, 26552225, 26552230, 27522457, 26890310, 26608298, 27347189, 27344110, 27347190, 27347190, 27347191, 27399270, 27439424, 27522459, 27522460, 27522460, 27347194, 26555263, 26555264, 27348708, 27348712, 27473962, 26626201, 26626200, 26626202, 27559448, 27436262, 26645287, 26664200, 26664201, 26664287, 26664289, 26664226, 26664229, 26664294, 26664298, 26664300, 26664301, 26664302, 26664367, 26664366, 26664367, 26664368, 26664369, 26664370, 26664370, 26664370, 26664371, 26664371, 26664373, 26664372, 26664372, 26664374, 26664374, 26664375, 26664374, 26664374, 26664375, 27578531, 27578532, 27207246, 27403263, 27403264, 27403264, 27403266, 27578533, 27578573, 27578574, 27581300, 27207247, 27403265, 27495499, 27578533, 27578534, 27403266, 26809792, 27475978, 26887681, 26887756, 26887830, 27690281, 27013429, 27013548, 27013667, 27577941, 27024686, 27024687, 27024688, 27024689, 27583421, 27583421, 27583422, 27583425, 27758692, 27583423, 27140801, 27140881, 27140882, 27140962, 27140962, 27641557, 27816826, 27228399, 27228399, 27860546, 27685277, 27860546, 27234225, 27688222, 27284555, 27713357, 27888624, 27324757, 27324833, 27324908, 27733527, 27335059, 27830843, 27645368, 27645370, 27645463, 27893762, 27645557, 27986090, 27742425, 27742500, 27742555, 28117642, 27749915, 27750019, 27750120, 27750119, 27750108, 27750120, 27750122, 27750132, 27946136, 28121406, 27832088, 28121408, 27914054, 28025024, 28108406, 28108479, 28108552, 28125352, 28135995, 28135996, 28135997, 28135997, 28139075, 28139077, 28139078, 28139082, 28231311, 28314346, 28142157, 28142158, 28142140, 28142141, 28142143, 28142156, 28142141, 28142142, 28142155, 28142157, 28142159, 28142159, 28142141, 28142142, 28142142, 28142143, 28142144, 28142157, 28142159, 28142160, 28142142, 28142143, 28142144, 28142144, 28142145, 28142145, 28142146, 28142157, 28142157, 28142158, 28142159, 28142159, 28142160, 28142160, 28142161, 28142143, 28142144, 28142144, 28142146, 28142147, 28142160, 28142161, 28142162, 28142145, 28142145, 28142146, 28142158, 28142160, 28142161, 28142161, 28142162, 28142146, 28142147, 28142159, 28142162, 28142162, 28142147, 28142159, 28142162, 28142162, 28142163, 28142163, 28142164, 28142147, 28142148, 28142160, 28142162, 28142163, 28142148, 28142160, 28142161, 28142163, 28142164, 28142161, 28142164, 28142164, 28142165, 28142164, 28142166, 28142166, 28234391, 28317426, 28142173, 28142174, 28142175, 28142176, 28142177, 28142178, 28194238, 28234392, 28317426, 28317427, 28142176, 28317427, 28142176, 28142177, 28142177, 28142178, 28234394, 28317428, 28317469, 28142177, 28142178, 28317429, 28142178, 28142179, 28142180, 28194240, 28317429, 28142179, 28142180, 28142180, 28193216, 28194241, 28194241, 28194242, 28195287, 28234395, 28278438, 28278439, 28278439, 28278445, 28286976, 28316617, 28317217, 28317411, 28317429, 28317430, 28317471, 28319781, 28142180, 28194243, 28317430, 28317471, 28317431, 28194244, 28317431, 28317472, 28317432, 28243611, 28368153, 28244264, 28245290, 28285443, 28246318, 28246319, 28246320, 28246320, 28246321, 28369316, 28369506, 28369507, 28369507, 28286474, 28330518, 28369508, 28248456, 28287564, 28326613, 28326614, 28326622, 28326623, 28326623, 28326624, 28326624, 28326625, 28326629, 28326625, 28326624, 28326624, 28326626, 28326633, 28326634, 28326634, 28326634, 28326635, 28409444, 28409657, 28409698, 28326635, 28326636, 28326636, 28326638, 28370666, 28409658, 28409699, 28326636, 28326637, 28409658, 28409699, 28409708, 28326637, 28326640, 28409658, 28409659, 28409700, 28409709, 28409659, 28409700, 28409702, 28409661, 28409662, 28409664, 28392648, 28392661, 28442677, 28414715, 28414716, 28414717, 28414701, 28414712, 28414717, 28414716, 28414718, 28414722, 28453703, 28414733, 28453707, 28453707, 28453708, 28431784, 28462238, 28468526, 28480104, 28491131, 28491437, 28491742, 28492249, 28492322, 28492330, 28492371, 28492373, 28492535, 28492421, 28492543, 28492561, 28492562, 28492640, 28492662, 28492680, 28492681, 28492682, 28492682, 28492683, 28492683, 28492684, 28492684, 28492685, 28492686, 28492689, 28492690, 28492691, 28492691, 28492694, 28492696, 28492697, 28492703, 28492706, 28492711, 28492712, 28492712, 28492715, 28492719, 28492720, 28492721, 28492721, 28492722, 28492682, 28492683, 28492684, 28492684, 28492685, 28492691, 28492712, 28492721, 28492722, 28492722, 28492683, 28492684, 28492684, 28492685, 28492699, 28492716, 28492721, 28492721, 28492722, 28492722, 28492723, 28492685, 28492686, 28492723, 28492686, 28492689, 28492723, 28492724, 28492691, 28492724, 28492724, 28492688, 28492723, 28492724, 28492725, 28492688, 28492725, 28492694, 28492697, 28492724, 28492725, 28492726, 28492726, 28492695, 28492729, 28492698, 28492730, 28492730, 28492703, 28492723, 28492731, 28492731, 28492701, 28492731, 28492732, 28492734, 28492732, 28492732, 28492741, 28492733, 28492717, 28492734, 28492737, 28492738, 28492739, 28492727, 28492744, 28492745, 28492745, 28492747, 28492751, 28492752, 28492752, 28492753, 28492753, 28492754, 28492756, 28492759, 28492760, 28492761, 28492761, 28492762, 28492762, 28492771, 28492763, 28492764, 28492764, 28492765, 28492765, 28492766, 28492766, 28492767, 28492767, 28492768, 28492768, 28492769, 28492769, 28492770, 28492770, 28492771, 28492772, 28492772, 28492773, 28492773, 28492774, 28492774, 28492775, 28492775, 28492776, 28492777, 28492778, 28492779, 28492780, 28492780, 28492781, 28492783, 28492783, 28492785, 28492786, 28492786, 28492787, 28492788, 28492789, 28492790, 28492797, 28492764, 28492765, 28492765, 28492766, 28492768, 28492768, 28492772, 28492773, 28492774, 28492775, 28492798, 28492765, 28492766, 28492767, 28492768, 28492770, 28492770, 28492771, 28492773, 28492766, 28492767, 28492767, 28492768, 28492769, 28492769, 28492773, 28492767, 28492768, 28492768, 28492769, 28492769, 28492770, 28492770, 28492771, 28492772, 28492772, 28492773, 28492773, 28492774, 28492774, 28492775, 28492775, 28492776, 28492776, 28492777, 28492777, 28492778, 28492780, 28492783, 28492786, 28492789, 28492798, 28492799, 28492768, 28492769, 28492769, 28492770, 28492770, 28492771, 28492771, 28492772, 28492772, 28492773, 28492773, 28492774, 28492774, 28492775, 28492775, 28492776, 28492776, 28492780, 28492786, 28492800, 28492769, 28492770, 28492770, 28492771, 28492772, 28492773, 28492775, 28492775, 28492776, 28492776, 28492770, 28492771, 28492771, 28492772, 28492775, 28492775, 28492776, 28492777, 28492780, 28492781, 28492790, 28492800, 28492771, 28492772, 28492773, 28492774, 28492775, 28492776, 28492778, 28492779, 28492785, 28492786, 28492772, 28492773, 28492774, 28492774, 28492775, 28492775, 28492776, 28492776, 28492777, 28492777, 28492778, 28492778, 28492779, 28492780, 28492781, 28492784, 28492786, 28492802, 28492774, 28492774, 28492775, 28492776, 28492776, 28492777, 28492777, 28492778, 28492778, 28492779, 28492780, 28492785, 28492785, 28492786, 28492776, 28492779, 28492785, 28492786, 28492776, 28492778, 28492778, 28492780, 28492803, 28492776, 28492777, 28492777, 28492778, 28492779, 28492779, 28492781, 28492783, 28492795, 28492804, 28492777, 28492778, 28492778, 28492779, 28492779, 28492780, 28492780, 28492781, 28492782, 28492779, 28492779, 28492780, 28492780, 28492781, 28492781, 28492783, 28492779, 28492780, 28492780, 28492781, 28492782, 28492782, 28492789, 28492780, 28492781, 28492781, 28492782, 28492782, 28492788, 28492790, 28492797, 28492800, 28492781, 28492782, 28492782, 28492783, 28492783, 28492784, 28492784, 28492785, 28492786, 28492787, 28492789, 28492793, 28492796, 28492798, 28492799, 28492805, 28492806, 28492782, 28492783, 28492783, 28492784, 28492784, 28492785, 28492785, 28492786, 28492786, 28492787, 28492788, 28492788, 28492789, 28492789, 28492790, 28492790, 28492791, 28492793, 28492793, 28492795, 28492796, 28492798, 28492798, 28492799, 28492800, 28492801, 28492806, 28492807, 28492783, 28492784, 28492784, 28492785, 28492785, 28492786, 28492787, 28492787, 28492788, 28492788, 28492789, 28492789, 28492790, 28492790, 28492791, 28492791, 28492807, 28492784, 28492785, 28492785, 28492786, 28492787, 28492787, 28492788, 28492789, 28492789, 28492790, 28492791, 28492792, 28492797, 28492797, 28492800, 28492808, 28492785, 28492786, 28492786, 28492787, 28492788, 28492789, 28492790, 28492791, 28492791, 28492798, 28492801, 28492808, 28492808, 28492786, 28492787, 28492787, 28492788, 28492788, 28492789, 28492790, 28492791, 28492791, 28492792, 28492793, 28492794, 28492795, 28492796, 28492799, 28492800, 28492808, 28492809, 28492787, 28492788, 28492788, 28492789, 28492789, 28492790, 28492790, 28492791, 28492791, 28492792, 28492792, 28492793, 28492795, 28492795, 28492796, 28492796, 28492798, 28492800, 28492801, 28492809, 28492788, 28492789, 28492789, 28492790, 28492790, 28492791, 28492791, 28492792, 28492792, 28492793, 28492793, 28492794, 28492795, 28492796, 28492796, 28492798, 28492798, 28492799, 28492799, 28492800, 28492801, 28492801, 28492803, 28492809, 28492810, 28492789, 28492790, 28492790, 28492791, 28492791, 28492793, 28492810, 28492790, 28492791, 28492791, 28492792, 28492792, 28492793, 28492793, 28492794, 28492794, 28492795, 28492797, 28492797, 28492798, 28492799, 28492800, 28492801, 28492802, 28492802, 28492803, 28492809, 28492810, 28492811, 28492791, 28492792, 28492792, 28492793, 28492793, 28492794, 28492794, 28492795, 28492796, 28492797, 28492800, 28492802, 28492802, 28492804, 28492811, 28492792, 28492793, 28492793, 28492794, 28492794, 28492795, 28492795, 28492796, 28492796, 28492798, 28492800, 28492801, 28492803, 28492810, 28492811, 28492812, 28492793, 28492794, 28492794, 28492795, 28492795, 28492796, 28492796, 28492797, 28492798, 28492798, 28492799, 28492799, 28492801, 28492803, 28492803, 28492804, 28492812, 28492794, 28492795, 28492795, 28492796, 28492796, 28492797, 28492797, 28492798, 28492799, 28492800, 28492801, 28492801, 28492802, 28492802, 28492803, 28492805, 28492806, 28492807, 28492811, 28492813, 28492795, 28492796, 28492796, 28492797, 28492798, 28492798, 28492799, 28492800, 28492800, 28492801, 28492802, 28492803, 28492803, 28492804, 28492806, 28492813, 28492796, 28492797, 28492797, 28492798, 28492799, 28492799, 28492800, 28492802, 28492802, 28492803, 28492805, 28492805, 28492806, 28492807, 28492809, 28492813, 28492814, 28492797, 28492798, 28492798, 28492800, 28492800, 28492801, 28492801, 28492802, 28492802, 28492803, 28492803, 28492804, 28492805, 28492805, 28492806, 28492806, 28492807, 28492814, 28492814, 28492798, 28492799, 28492799, 28492800, 28492801, 28492801, 28492802, 28492803, 28492804, 28492804, 28492805, 28492806, 28492807, 28492808, 28492810, 28492813, 28492815, 28492799, 28492800, 28492800, 28492801, 28492801, 28492802, 28492803, 28492804, 28492804, 28492805, 28492805, 28492806, 28492806, 28492815, 28492815, 28492800, 28492801, 28492801, 28492802, 28492802, 28492803, 28492804, 28492805, 28492805, 28492806, 28492807, 28492808, 28492808, 28492809, 28492811, 28492814, 28492815, 28492815, 28492816, 28492801, 28492802, 28492803, 28492804, 28492805, 28492806, 28492807, 28492808, 28492808, 28492816, 28492802, 28492803, 28492804, 28492805, 28492807, 28492808, 28492809, 28492815, 28492817, 28492803, 28492804, 28492804, 28492806, 28492808, 28492809, 28492817, 28492817, 28492804, 28492805, 28492805, 28492806, 28492806, 28492807, 28492807, 28492808, 28492809, 28492809, 28492810, 28492817, 28492818, 28492805, 28492806, 28492807, 28492807, 28492808, 28492808, 28492809, 28492809, 28492810, 28492811, 28492814, 28492814, 28492816, 28492816, 28492817, 28492818, 28492818, 28492807, 28492807, 28492808, 28492808, 28492809, 28492810, 28492810, 28492811, 28492814, 28492817, 28492818, 28492819, 28492810, 28492812, 28492813, 28492819, 28492808, 28492809, 28492809, 28492810, 28492811, 28492812, 28492820, 28492809, 28492810, 28492811, 28492811, 28492812, 28492813, 28492813, 28492814, 28492818, 28492819, 28492819, 28492820, 28492820, 28492810, 28492811, 28492811, 28492812, 28492812, 28492813, 28492814, 28492818, 28492818, 28492819, 28492820, 28492821, 28492811, 28492812, 28492812, 28492813, 28492813, 28492814, 28492814, 28492817, 28492819, 28492819, 28492820, 28492821, 28492821, 28492812, 28492813, 28492813, 28492814, 28492815, 28492817, 28492820, 28492821, 28492822, 28492813, 28492814, 28492814, 28492815, 28492815, 28492822, 28492814, 28492815, 28492815, 28492816, 28492816, 28492817, 28492818, 28492819, 28492820, 28492820, 28492821, 28492821, 28492822, 28492823, 28495099, 28492815, 28492821, 28492823, 28492816, 28492817, 28492817, 28492818, 28492818, 28492819, 28492819, 28492821, 28492821, 28492822, 28492822, 28492823, 28492824, 28492817, 28492818, 28492819, 28492820, 28492822, 28492823, 28492824, 28492824, 28492818, 28492820, 28492821, 28492822, 28492823, 28492824, 28492824, 28492825, 28492820, 28492823, 28492824, 28492825, 28492825, 28492824, 28492824, 28492826, 28492824, 28492825, 28492826, 28492827, 28492825, 28492825, 28492827, 28492827, 28492826, 28492828, 28495104, 28492827, 28492827, 28492828, 28492829, 28492828, 28492828, 28492829, 28492829, 28492828, 28492829, 28492830, 28492830, 28492830, 28492831, 28492831, 28492832, 28492833, 28492833, 28492834, 28492835, 28492836, 28492837, 28492837, 28492839, 28492840, 28492841, 28492841, 28492842, 28492843, 28492845, 28492845, 28492848, 28492852, 28492856, 28492857, 28492860, 28492861, 28492862, 28492863, 28492870, 28492870, 28492871, 28492871, 28492872, 28492873, 28493451, 28493493, 28493494, 28493508, 28495108, 28495210, 28492833, 28492834, 28492834, 28492835, 28492835, 28492836, 28492836, 28492837, 28492837, 28492838, 28492838, 28492839, 28492839, 28492840, 28492840, 28492841, 28492841, 28492842, 28492843, 28492843, 28492844, 28492844, 28492845, 28492846, 28492846, 28492847, 28492847, 28492848, 28492849, 28492851, 28492851, 28492852, 28492852, 28492854, 28492855, 28492856, 28492857, 28492857, 28492858, 28492858, 28492860, 28492861, 28492861, 28492862, 28492864, 28492865, 28492865, 28492866, 28492868, 28492869, 28492870, 28492870, 28492871, 28492871, 28492872, 28492872, 28492873, 28492873, 28495108, 28492834, 28492835, 28492835, 28492836, 28492838, 28492839, 28492839, 28492840, 28492846, 28492849, 28492849, 28492850, 28492853, 28492854, 28492855, 28492858, 28492859, 28492865, 28492868, 28492871, 28492872, 28492873, 28492874, 28492836, 28492845, 28492847, 28492859, 28492864, 28492870, 28492872, 28492872, 28492874, 28492840, 28492841, 28492842, 28492845, 28492873, 28492874, 28492875, 28492842, 28492844, 28492873, 28492874, 28492875, 28492840, 28492842, 28492849, 28492859, 28492862, 28492863, 28492874, 28492875, 28492876, 28492876, 28492843, 28492847, 28492843, 28492862, 28492877, 28492844, 28492845, 28492848, 28492848, 28492850, 28492852, 28492876, 28492876, 28492878, 28492845, 28492859, 28492860, 28492862, 28492878, 28495113, 28492845, 28492846, 28492848, 28492877, 28492879, 28492846, 28492848, 28492853, 28492864, 28492876, 28492847, 28492851, 28492852, 28492870, 28492879, 28492879, 28492880, 28492847, 28492848, 28492849, 28492849, 28492852, 28492857, 28492870, 28492873, 28492879, 28492879, 28492880, 28492848, 28492851, 28492853, 28492863, 28492878, 28492879, 28492881, 28493516, 28492850, 28492851, 28492855, 28492861, 28492879, 28492880, 28492881, 28492851, 28492852, 28492852, 28492860, 28492869, 28492881, 28492882, 28492852, 28492854, 28492856, 28492879, 28492880, 28492882, 28492852, 28492853, 28492883, 28492853, 28492854, 28492879, 28492882, 28492883, 28492854, 28492855, 28492856, 28492860, 28492863, 28492867, 28492870, 28492873, 28492881, 28492883, 28492883, 28492884, 28492857, 28492868, 28492880, 28492883, 28492884, 28492858, 28492869, 28492878, 28492885, 28492858, 28492871, 28492883, 28492884, 28492884, 28492886, 28492873, 28492877, 28492885, 28492886, 28492875, 28492882, 28492885, 28492887, 28492861, 28492887, 28492867, 28492877, 28492881, 28492884, 28492885, 28492886, 28492888, 28492886, 28492888, 28492865, 28492889, 28492889, 28492880, 28492888, 28492890, 28492870, 28492890, 28492876, 28492875, 28492890, 28492883, 28492892, 28492891, 28492892, 28492893, 28492876, 28492880, 28492884, 28492883, 28492893, 28492894, 28492882, 28492891, 28492894, 28492896, 28492893, 28492896, 28492885, 28492894, 28492895, 28492896, 28492897, 28492884, 28492895, 28492896, 28492898, 28492883, 28492895, 28492897, 28492898, 28492898, 28492897, 28492897, 28492899, 28492898, 28492893, 28492897, 28492897, 28492900, 28492888, 28492891, 28492894, 28492899, 28492900, 28492901, 28492893, 28492901, 28492893, 28492902, 28492902, 28492903, 28492903, 28492901, 28492903, 28492904, 28492896, 28492897, 28492900, 28492902, 28492904, 28492902, 28492903, 28492904, 28492904, 28492905, 28492905, 28492906, 28492906, 28492902, 28492904, 28492905, 28492905, 28492907, 28492908, 28492909, 28492906, 28492907, 28492907, 28492908, 28492909, 28495144, 28492908, 28492908, 28492907, 28492908, 28492910, 28492910, 28492908, 28492909, 28492909, 28492910, 28492910, 28492911, 28492909, 28492910, 28492910, 28492911, 28492911, 28495146, 28492910, 28492911, 28492911, 28492912, 28492911, 28492912, 28492912, 28492912, 28492913, 28492913, 28492914, 28493469, 28493492, 28493492, 28493534, 28493543, 28493545, 28495149, 28495251, 28495371, 28495393, 28495566, 45019009, 28493493, 28494048, 28494070, 28494071, 28494072, 28494072, 28494073, 28494073, 28494074, 28494075, 28494076, 28494077, 28494082, 28494091, 28494093, 28494094, 28494103, 28494107, 28494109, 28494111, 28494112, 28494112, 28494117, 28494146, 28494073, 28494113, 28494113, 28494114, 28494077, 28494092, 28494114, 28494114, 28494084, 28494115, 28494116, 28494116, 28494116, 28494117, 28494118, 28494123, 28494131, 28494132, 28494134, 28494130, 28494145, 28494148, 28494148, 28494151, 28494152, 28494153, 28494153, 28494187, 28494154, 28494155, 28494155, 28494156, 28494156, 28494157, 28494157, 28494158, 28494158, 28494159, 28494160, 28494160, 28494161, 28494161, 28494162, 28494162, 28494163, 28494163, 28494164, 28494165, 28494165, 28494166, 28494166, 28494168, 28494168, 28494169, 28494169, 28494170, 28494170, 28494171, 28494171, 28494173, 28494174, 28494175, 28494176, 28494177, 28494177, 28494179, 28494180, 28494181, 28494182, 28494184, 28494187, 28494188, 28494193, 28494156, 28494159, 28494160, 28494165, 28494166, 28494169, 28494182, 28494188, 28494163, 28494163, 28494164, 28494164, 28494167, 28494189, 28494178, 28494189, 28494159, 28494164, 28494164, 28494165, 28494165, 28494166, 28494190, 28494166, 28494165, 28494182, 28494164, 28494165, 28494167, 28494191, 28494191, 28494192, 28494167, 28494166, 28494167, 28494168, 28494179, 28494185, 28494193, 28494168, 28494168, 28494172, 28494189, 28494194, 28494168, 28494170, 28494171, 28494172, 28494173, 28494178, 28494179, 28494193, 28494171, 28494180, 28494195, 28494171, 28494171, 28494174, 28494182, 28494185, 28494186, 28494188, 28494189, 28494194, 28494196, 28494172, 28494173, 28494174, 28494178, 28494184, 28494185, 28494186, 28494188, 28494188, 28494189, 28494189, 28494190, 28494194, 28494196, 28494172, 28494174, 28494174, 28494175, 28494177, 28494179, 28494183, 28494184, 28494186, 28494188, 28494189, 28494190, 28494190, 28494193, 28494195, 28494197, 28494174, 28494175, 28494175, 28494176, 28494178, 28494178, 28494179, 28494179, 28494181, 28494183, 28494184, 28494186, 28494188, 28494189, 28494189, 28494190, 28494193, 28494197, 28494197, 28494187, 28494198, 28494176, 28494177, 28494178, 28494181, 28494188, 28494191, 28494195, 28494199, 28494177, 28494182, 28494182, 28494186, 28494187, 28494189, 28494190, 28494195, 28494195, 28494199, 28494178, 28494180, 28494185, 28494185, 28494186, 28494186, 28494187, 28494189, 28494189, 28494190, 28494192, 28494196, 28494198, 28494200, 28494186, 28494189, 28494190, 28494190, 28494193, 28494196, 28494199, 28494200, 28494181, 28494189, 28494202, 28494192, 28494192, 28494193, 28494185, 28494203, 28494186, 28494196, 28494199, 28494203, 28494187, 28494189, 28494200, 28494187, 28494188, 28494192, 28494198, 28494199, 28494204, 28494190, 28494191, 28494194, 28494197, 28494203, 28494205, 28494201, 28494205, 28494206, 28494193, 28494195, 28494207, 28494196, 28494203, 28494207, 28494207, 28494195, 28494199, 28494205, 28494208, 28494196, 28494197, 28494202, 28494203, 28494204, 28494208, 28495789, 28494199, 28494201, 28494202, 28494203, 28494205, 28494207, 28494208, 28494209, 28494208, 28494210, 28494201, 28494202, 28494202, 28494203, 28494204, 28494207, 28494209, 28494210, 28494211, 28495792, 28494202, 28494203, 28494209, 28494211, 28494203, 28494204, 28494209, 28494212, 28494210, 28494213, 28494206, 28494213, 28494206, 28494208, 28494210, 28494214, 28494210, 28494211, 28494212, 28494212, 28494214, 28494214, 28494210, 28494213, 28494215, 28494211, 28494215, 28494212, 28494216, 28494216, 28494216, 28494217, 28494215, 28494217, 28494217, 28494218, 28494219, 28495800, 28494217, 28494219, 28494219, 28494220, 28494220, 28494220, 28494221, 28494221, 28494222, 28494223, 28494223, 28494224, 28494225, 28494227, 28494229, 28494229, 28494230, 28494232, 28494232, 28494233, 28494235, 28494236, 28494244, 28494248, 28494254, 28494254, 28494257, 28494258, 28494259, 28494260, 28494261, 28494261, 28494262, 28494262, 28494263, 28494263, 28495803, 29131070, 28494226, 28494226, 28494234, 28494234, 28494240, 28494260, 28494261, 28494262, 28494262, 28494263, 28494263, 28494264, 28494225, 28494262, 28494263, 28494264, 28494264, 28494232, 28494265, 28494266, 28494267, 28494266, 28494267, 28495808, 28494269, 28494270, 28494270, 28494271, 28494272, 28494273, 28494271, 28494272, 28494274, 28494275, 28494275, 28494272, 28494271, 28494280, 28494285, 28494287, 28494295, 28494296, 28494297, 28494295, 28494299, 28494300, 28494299, 28494298, 28494300, 28494299, 28494301, 28494301, 28494301, 28494301, 28494302, 28494301, 28494302, 28494302, 28494303, 28494302, 28494303, 28494303, 28494303, 28494304, 28495843, 28494304, 28495844, 28494305, 28494306, 28494307, 28494311, 28494364, 28494747, 28495837, 28495844, 28495844, 28495882, 28495884, 28496919, 28495845, 28495845, 28494749, 28495846, 28494754, 28495851, 28494488, 28495968, 28495196, 28495197, 28495202, 28495219, 28495269, 28495270, 28495275, 28495292, 28495340, 28495345, 28495345, 28496364, 28496369, 28496369, 28497377, 28497383, 28497384, 28497385, 28497385, 28497386, 28497386, 28497387, 28497388, 28497388, 28497393, 28497394, 28497394, 28497395, 28497396, 28497396, 28497399, 28497400, 28497401, 28497405, 28497405, 28497407, 28497409, 28497410, 28497411, 28497411, 28497414, 28497415, 28497420, 28497420, 28497421, 28497421, 28497422, 28497385, 28497386, 28497387, 28497387, 28497388, 28497388, 28497392, 28497394, 28497396, 28497397, 28497404, 28497411, 28497412, 28497418, 28497421, 28497421, 28497422, 28497386, 28497387, 28497388, 28497397, 28497412, 28497418, 28497422, 28497422, 28497388, 28497389, 28497398, 28497413, 28497421, 28497422, 28497422, 28497423, 28497423, 28497412, 28497413, 28497423, 28497423, 28497391, 28497410, 28497414, 28497424, 28497424, 28497400, 28497400, 28497411, 28497425, 28497425, 28497425, 28497428, 28497429, 28497403, 28497405, 28497421, 28497430, 28497431, 28497431, 28497432, 28497434, 28497495, 28497496, 28497432, 28497432, 28497433, 28497433, 28497433, 28497434, 28497437, 28497437, 28497438, 28497436, 28497442, 28497442, 28497443, 28497443, 28497444, 28497445, 28497446, 28497447, 28497447, 28497448, 28497448, 28497448, 28497449, 28497449, 28497449, 28497451, 28497452, 28497453, 28497454, 28497457, 28497457, 28497458, 28497458, 28497459, 28497460, 28497460, 28497461, 28497461, 28497462, 28497462, 28497463, 28497463, 28497464, 28497466, 28497467, 28497467, 28497468, 28497469, 28497469, 28497470, 28497471, 28497471, 28497472, 28497472, 28497473, 28497473, 28497474, 28497475, 28497475, 28497476, 28497477, 28497478, 28497479, 28497480, 28497481, 28497482, 28497483, 28497484, 28497485, 28497485, 28497486, 28497489, 28497495, 28497497, 28497504, 28497523, 28497460, 28497461, 28497461, 28497462, 28497462, 28497463, 28497464, 28497464, 28497465, 28497466, 28497466, 28497467, 28497467, 28497468, 28497468, 28497469, 28497469, 28497470, 28497470, 28497471, 28497471, 28497472, 28497472, 28497473, 28497473, 28497474, 28497475, 28497476, 28497477, 28497477, 28497478, 28497480, 28497481, 28497482, 28497482, 28497484, 28497484, 28497485, 28497488, 28497489, 28497490, 28497494, 28497497, 28497461, 28497462, 28497462, 28497463, 28497463, 28497464, 28497464, 28497468, 28497470, 28497471, 28497472, 28497473, 28497462, 28497463, 28497464, 28497470, 28497471, 28497480, 28497463, 28497464, 28497464, 28497469, 28497470, 28497470, 28497471, 28497471, 28497472, 28497473, 28497474, 28497474, 28497476, 28497477, 28497478, 28497482, 28497464, 28497465, 28497469, 28497469, 28497472, 28497473, 28497475, 28497478, 28497465, 28497466, 28497467, 28497467, 28497469, 28497470, 28497470, 28497471, 28497472, 28497472, 28497473, 28497473, 28497474, 28497475, 28497475, 28497478, 28497487, 28497466, 28497467, 28497467, 28497468, 28497469, 28497470, 28497470, 28497471, 28497472, 28497472, 28497473, 28497473, 28497474, 28497475, 28497476, 28497470, 28497472, 28497474, 28497475, 28497471, 28497472, 28497473, 28497474, 28497470, 28497474, 28497475, 28497475, 28497473, 28497476, 28497476, 28497475, 28497477, 28497475, 28497476, 28497477, 28497480, 28497475, 28497477, 28497477, 28497478, 28497476, 28497477, 28497478, 28497479, 28497478, 28497479, 28497479, 28497479, 28497480, 28497480, 28497481, 28497479, 28497480, 28497481, 28497483, 28497491, 28497480, 28497481, 28497482, 28497483, 28497487, 28497481, 28497482, 28497482, 28497483, 28497483, 28497484, 28497487, 28497488, 28497492, 28497494, 28497482, 28497483, 28497484, 28497486, 28497488, 28497483, 28497484, 28497484, 28497486, 28497487, 28497487, 28497491, 28497484, 28497485, 28497490, 28497493, 28497485, 28497492, 28497494, 28497504, 28497510, 28497486, 28497487, 28497487, 28497488, 28497488, 28497489, 28497489, 28497490, 28497490, 28497491, 28497492, 28497492, 28497495, 28497495, 28497497, 28497502, 28497503, 28497504, 28497510, 28497487, 28497488, 28497488, 28497489, 28497489, 28497491, 28497491, 28497493, 28497496, 28497488, 28497489, 28497489, 28497490, 28497490, 28497491, 28497491, 28497492, 28497493, 28497495, 28497496, 28497498, 28497489, 28497490, 28497490, 28497491, 28497491, 28497492, 28497492, 28497494, 28497495, 28497496, 28497490, 28497491, 28497492, 28497491, 28497492, 28497492, 28497493, 28497493, 28497494, 28497494, 28497495, 28497496, 28497499, 28497500, 28497550, 28497492, 28497493, 28497493, 28497494, 28497494, 28497495, 28497505, 28497513, 28497493, 28497494, 28497494, 28497495, 28497496, 28497502, 28497506, 28497494, 28497495, 28497495, 28497496, 28497496, 28497500, 28497500, 28497501, 28497541, 28497495, 28497496, 28497496, 28497497, 28497501, 28497506, 28497515, 28497541, 28497496, 28497497, 28497497, 28497499, 28497500, 28497500, 28497501, 28497502, 28497504, 28497505, 28497508, 28497512, 28497553, 28497497, 28497498, 28497501, 28497502, 28497508, 28497512, 28497553, 28497498, 28497516, 28497499, 28497500, 28497500, 28497501, 28497501, 28497502, 28497502, 28497503, 28497503, 28497504, 28497504, 28497506, 28497506, 28497507, 28497507, 28497509, 28497509, 28497511, 28497500, 28497501, 28497501, 28497502, 28497502, 28497504, 28497501, 28497502, 28497502, 28497503, 28497503, 28497504, 28497518, 28497502, 28497503, 28497503, 28497504, 28497504, 28497505, 28497505, 28497506, 28497507, 28497508, 28497510, 28497512, 28497515, 28497518, 28497545, 28497858, 28497503, 28497504, 28497504, 28497505, 28497504, 28497505, 28497505, 28497506, 28497506, 28497507, 28497508, 28497511, 28497514, 28497519, 28497546, 28497505, 28497506, 28497506, 28497507, 28497507, 28497508, 28497509, 28497510, 28497516, 28497546, 28497506, 28497507, 28497507, 28497508, 28497507, 28497508, 28497508, 28497510, 28497511, 28497513, 28497513, 28497515, 28497516, 28497517, 28497520, 28497521, 28497508, 28497509, 28497509, 28497510, 28497510, 28497511, 28497513, 28497514, 28497521, 28497559, 28497509, 28497510, 28497510, 28497511, 28497511, 28497512, 28497512, 28497514, 28497514, 28497516, 28497518, 28497518, 28497522, 28497548, 28497668, 28497510, 28497511, 28497511, 28497512, 28497512, 28497513, 28497514, 28497515, 28497519, 28497549, 28497511, 28497512, 28497512, 28497513, 28497513, 28497515, 28497515, 28497517, 28497512, 28497513, 28497513, 28497517, 28497550, 28497513, 28497514, 28497514, 28497515, 28497515, 28497516, 28497516, 28497518, 28497520, 28497524, 28497550, 28497550, 28497514, 28497515, 28497516, 28497517, 28497518, 28497515, 28497516, 28497516, 28497517, 28497518, 28497519, 28497521, 28497525, 28497516, 28497517, 28497517, 28497518, 28497519, 28497522, 28497552, 28497517, 28497518, 28497518, 28497520, 28497526, 28497518, 28497519, 28497519, 28497520, 28497521, 28497521, 28497523, 28497523, 28497524, 28497526, 28497527, 28497553, 28497564, 28497564, 28497520, 28497521, 28497521, 28497522, 28497522, 28497524, 28497525, 28497527, 28497522, 28497524, 28497522, 28497523, 28497524, 28497524, 28497525, 28497525, 28497526, 28497527, 28497529, 28497524, 28497525, 28497525, 28497526, 28497556, 28497525, 28497526, 28497526, 28497556, 28497526, 28497527, 28497527, 28497528, 28497529, 28497529, 28497530, 28497530, 28497531, 28497531, 28497547, 28497558, 28497569, 28497529, 28497530, 28497530, 28497531, 28497531, 28497532, 28497530, 28497531, 28497531, 28497532, 28497532, 28497531, 28497532, 28497532, 28497533, 28497532, 28497533, 28497533, 28497543, 28497560, 28497533, 28497534, 28497534, 28497572, 28497535, 28497536, 28497536, 28497537, 28497537, 28497538, 28497538, 28497539, 28497540, 28497540, 28497541, 28497541, 28497542, 28497542, 28497543, 28497544, 28497544, 28497545, 28497548, 28497548, 28497549, 28497552, 28497553, 28497553, 28497554, 28497556, 28497556, 28497557, 28497558, 28497558, 28497559, 28497561, 28497562, 28497563, 28497564, 28497565, 28497566, 28497566, 28497567, 28497567, 28497568, 28497568, 28497569, 28497569, 28497570, 28497571, 28497571, 28497572, 28497572, 28497703, 28497536, 28497537, 28497537, 28497538, 28497539, 28497540, 28497540, 28497541, 28497541, 28497542, 28497542, 28497543, 28497543, 28497544, 28497544, 28497545, 28497545, 28497546, 28497547, 28497548, 28497548, 28497549, 28497549, 28497550, 28497552, 28497552, 28497553, 28497554, 28497556, 28497557, 28497557, 28497558, 28497559, 28497560, 28497561, 28497562, 28497563, 28497564, 28497564, 28497565, 28497566, 28497566, 28497567, 28497567, 28497569, 28497570, 28497570, 28497571, 28497571, 28497572, 28497572, 28497573, 28497541, 28497543, 28497548, 28497571, 28497572, 28497573, 28497541, 28497542, 28497542, 28497543, 28497555, 28497563, 28497574, 28497542, 28497546, 28497551, 28497563, 28497574, 28497540, 28497544, 28497564, 28497569, 28497575, 28497575, 28497545, 28497566, 28497573, 28497576, 28497545, 28497546, 28497547, 28497548, 28497548, 28497549, 28497566, 28497569, 28497575, 28497577, 28497545, 28497547, 28497570, 28497547, 28497548, 28497548, 28497549, 28497551, 28497554, 28497564, 28497567, 28497570, 28497571, 28497574, 28497577, 28497577, 28497578, 28497562, 28497567, 28497574, 28497575, 28497548, 28497549, 28497550, 28497556, 28497560, 28497561, 28497565, 28497568, 28497577, 28497578, 28497579, 28497549, 28497551, 28497555, 28497559, 28497565, 28497566, 28497568, 28497569, 28497572, 28497577, 28497578, 28497578, 28497579, 28497550, 28497551, 28497556, 28497559, 28497563, 28497569, 28497571, 28497572, 28497573, 28497573, 28497576, 28497577, 28497578, 28497580, 28497689, 45021327, 28497552, 28497563, 28497569, 28497580, 28497553, 28497557, 28497571, 28497581, 28497554, 28497557, 28497558, 28497568, 28497570, 28497573, 28497574, 28497575, 28497580, 28497581, 28497571, 28497580, 28497582, 28497691, 28497556, 28497562, 28497564, 28497576, 28497579, 28497563, 28497572, 28497575, 28497577, 28497581, 28497583, 28497576, 28497584, 28497568, 28497574, 28497563, 28497578, 28497581, 28497573, 28497575, 28497578, 28497580, 28497581, 28497584, 28497585, 28497586, 28497579, 28497583, 28497570, 28497572, 28497578, 28497584, 28497585, 28497586, 28497587, 28497577, 28497580, 28497582, 28497576, 28497589, 28497588, 28497589, 28497576, 28497579, 28497581, 28497584, 28497588, 28497590, 28497591, 28497585, 28497587, 28497591, 28497578, 28497581, 28497580, 28497584, 28497591, 28497582, 28497591, 28497593, 28497583, 28497584, 28497592, 28497583, 28497587, 28497588, 28497595, 28497587, 28497594, 28497596, 28497585, 28497587, 28497589, 28497590, 28497596, 28497588, 28497597, 28497595, 28497597, 28497591, 28497598, 28497587, 28497588, 28497589, 28497589, 28497590, 28497591, 28497592, 28497592, 28497593, 28497593, 28497594, 28497595, 28497596, 28497597, 28497597, 28497598, 28497598, 28497599, 28497589, 28497590, 28497592, 28497598, 28497598, 28497590, 28497591, 28497593, 28497597, 28497598, 28497598, 28497599, 28497599, 28497600, 28497597, 28497599, 28497599, 28497593, 28497595, 28497596, 28497597, 28497600, 28497594, 28497594, 28497600, 28497601, 28497594, 28497595, 28497596, 28497596, 28497597, 28497598, 28497599, 28497600, 28497600, 28497601, 28497601, 28497602, 28497602, 28497597, 28497601, 28497602, 28497603, 28497597, 28497598, 28497599, 28497600, 28497601, 28497602, 28497602, 28497603, 28497603, 28497598, 28497599, 28497600, 28497601, 28497601, 28497602, 28497602, 28497603, 28497604, 28497600, 28497601, 28497602, 28497604, 28497604, 28497604, 28497605, 28497603, 28497605, 28497603, 28497604, 28497604, 28497605, 28497606, 28497606, 28497606, 28497604, 28497605, 28497605, 28497606, 28497606, 28497607, 28497606, 28497606, 28497607, 28497607, 28497606, 28497607, 28497607, 28497608, 28497607, 28497608, 28497608, 28497608, 28497609, 28497609, 28497610, 28497630, 28497674, 28497718, 28497719, 28497741, 28497746, 28497768, 28497769, 28497770, 28497771, 28497772, 28497773, 28497774, 28497775, 28497805, 28497807, 28497912, 28497914, 28497963, 28497964, 28497964, 28498571, 28498606, 28499100, 28497719, 28497719, 28497741, 28497744, 28497924, 28497739, 28497783, 28497827, 28497828, 28497829, 28497830, 28497830, 28497831, 28497832, 28497837, 28497848, 28497848, 28497849, 28497849, 28497850, 28497853, 28497903, 28497849, 28497850, 28497850, 28497831, 28497832, 28497833, 28497845, 28497851, 28497851, 28497852, 28497852, 28497853, 28497853, 28497854, 28497859, 28497864, 28497869, 28497870, 28497870, 28497871, 28497871, 28497872, 28497873, 28497873, 28497874, 28497874, 28497875, 28497876, 28497876, 28497877, 28497878, 28497879, 28497880, 28497880, 28497881, 28497882, 28497882, 28497883, 28497883, 28497884, 28497884, 28497886, 28497886, 28497887, 28497887, 28497888, 28497889, 28497890, 28497891, 28497891, 28497892, 28497892, 28497893, 28497893, 28497894, 28497894, 28497895, 28497895, 28497896, 28497896, 28497897, 28497897, 28497898, 28497898, 28497899, 28497899, 28497900, 28497901, 28497901, 28497902, 28497903, 28497903, 28497904, 28497904, 28497905, 28497905, 28497906, 28497906, 28497908, 28497909, 28497911, 28497912, 28497923, 28497925, 28497925, 28497947, 28497873, 28497875, 28497875, 28497876, 28497877, 28497877, 28497879, 28497885, 28497889, 28497894, 28497895, 28497896, 28497896, 28497898, 28497900, 28497902, 28497904, 28497904, 28497905, 28497919, 28497926, 28497874, 28497875, 28497875, 28497877, 28497877, 28497882, 28497883, 28497887, 28497889, 28497893, 28497893, 28497894, 28497896, 28497898, 28497899, 28497899, 28497902, 28497905, 28497876, 28497877, 28497878, 28497881, 28497883, 28497883, 28497894, 28497895, 28497897, 28497901, 28497876, 28497877, 28497878, 28497878, 28497879, 28497896, 28497897, 28497905, 28497877, 28497878, 28497879, 28497879, 28497880, 28497880, 28497881, 28497882, 28497883, 28497885, 28497886, 28497886, 28497890, 28497891, 28497891, 28497892, 28497895, 28497895, 28497897, 28497897, 28497898, 28497901, 28497904, 28497906, 28497907, 28497909, 28497928, 28497879, 28497879, 28497882, 28497884, 28497901, 28497880, 28497891, 28497898, 28497898, 28497902, 28497903, 28497880, 28497881, 28497886, 28497895, 28497897, 28497898, 28497899, 28497929, 28497881, 28497882, 28497882, 28497883, 28497885, 28497886, 28497889, 28497891, 28497896, 28497896, 28497897, 28497899, 28497900, 28497901, 28497906, 28497907, 28497882, 28497883, 28497883, 28497884, 28497887, 28497891, 28497894, 28497895, 28497896, 28497897, 28497898, 28497899, 28497903, 28497905, 28497906, 28497914, 28497919, 28497930, 28497884, 28497885, 28497891, 28497893, 28497899, 28497884, 28497885, 28497886, 28497887, 28497891, 28497899, 28497906, 28497914, 28497907, 28497888, 28497889, 28497890, 28497897, 28497903, 28497909, 28497912, 28497908, 28497903, 28497919, 28497934, 28497890, 28497891, 28497892, 28497895, 28497900, 28497902, 28497903, 28497906, 28497909, 28497895, 28497902, 28497902, 28497904, 28497910, 28497898, 28497901, 28497902, 28497908, 28497910, 28497914, 28497919, 28497936, 28497936, 28497905, 28497907, 28497919, 28497937, 28497910, 28497912, 28497903, 28497916, 28497916, 28497901, 28497938, 28497907, 28497913, 28497905, 28497908, 28497913, 28497939, 28497914, 28497914, 28497917, 28497909, 28497922, 28497940, 28497915, 28497917, 28497919, 28497920, 28497905, 28497910, 28497941, 28497952, 28497910, 28497914, 28497916, 28497907, 28497909, 28497917, 28497909, 28497911, 28497921, 28497921, 28497916, 28497911, 28497912, 28497913, 28497918, 28497920, 28497922, 28497922, 28497910, 28497914, 28497917, 28497912, 28497917, 28497918, 28497919, 28497919, 28497924, 28497913, 28497914, 28497914, 28497915, 28497919, 28497920, 28497923, 28497923, 28497928, 28497932, 28497944, 28497945, 28497913, 28497915, 28497916, 28497917, 28497918, 28497920, 28497922, 28497923, 28497924, 28497924, 28497942, 28497946, 28497914, 28497918, 28497919, 28497920, 28497921, 28497946, 28497916, 28497916, 28497917, 28497920, 28497921, 28497947, 28497916, 28497917, 28497917, 28497918, 28497920, 28497921, 28497922, 28497923, 28497925, 28497926, 28497926, 28497947, 28497917, 28497918, 28497918, 28497919, 28497920, 28497921, 28497922, 28497922, 28497923, 28497924, 28497925, 28497926, 28497926, 28497927, 28497941, 28497919, 28497921, 28497922, 28497922, 28497923, 28497926, 28497927, 28497928, 28497933, 28497948, 28497919, 28497920, 28497920, 28497921, 28497922, 28497922, 28497923, 28497923, 28497924, 28497925, 28497927, 28497935, 28497942, 28497922, 28497922, 28497923, 28497924, 28497925, 28497926, 28497927, 28497922, 28497923, 28497924, 28497927, 28497950, 28497925, 28497926, 28497928, 28497929, 28497932, 28497923, 28497924, 28497925, 28497925, 28497927, 28497928, 28497929, 28497929, 28497951, 28497924, 28497925, 28497925, 28497926, 28497927, 28497928, 28497930, 28497931, 28497948, 28497951, 28497925, 28497926, 28497926, 28497928, 28497930, 28497930, 28497935, 28497952, 28497926, 28497927, 28497935, 28497952, 28497927, 28497928, 28497929, 28497932, 28497935, 28497953, 28497928, 28497929, 28497929, 28497930, 28497930, 28497931, 28497931, 28497932, 28497932, 28497933, 28497933, 28497934, 28497934, 28497935, 28497936, 28497937, 28497938, 28497938, 28497939, 28497940, 28497942, 28497945, 28497946, 28497948, 28497948, 28497950, 28497953, 28497930, 28497931, 28497932, 28497937, 28497954, 28497930, 28497948, 28497951, 28497931, 28497932, 28497933, 28497933, 28497934, 28497934, 28497935, 28497936, 28497937, 28497938, 28497940, 28497947, 28497948, 28497949, 28497952, 28497953, 28497954, 28497955, 28497932, 28497933, 28497934, 28497947, 28497955, 28497934, 28497935, 28497936, 28497939, 28497941, 28497952, 28497956, 28497934, 28497935, 28497936, 28497939, 28497939, 28497952, 28497956, 28497956, 28497935, 28497936, 28497937, 28497939, 28497939, 28497940, 28497946, 28497954, 28497955, 28497956, 28497957, 28497936, 28497937, 28497939, 28497939, 28497940, 28497941, 28497941, 28497942, 28497947, 28497952, 28497957, 28497957, 28497937, 28497940, 28497944, 28497945, 28497947, 28497952, 28497955, 28497956, 28497957, 28497958, 28497938, 28497939, 28497939, 28497940, 28497941, 28497942, 28497943, 28497950, 28497958, 28497958, 28497940, 28497958, 28497959, 28497943, 28497946, 28497959, 28497945, 28497960, 28497942, 28497960, 28497944, 28497961, 28497944, 28497945, 28497961, 28497961, 28497960, 28497961, 28497962, 28497951, 28497952, 28497954, 28497962, 28497948, 28497963, 28497953, 28497963, 28497953, 28497964, 28497964, 28497965, 28498742, 28497963, 28497965, 28497966, 28497957, 28497967, 28497968, 28497963, 28497964, 28497967, 28497968, 28497968, 28497965, 28497970, 28497971, 28497969, 28497971, 28497972, 28497971, 28497972, 28497972, 28497973, 28497971, 28497973, 28497973, 28497973, 28497974, 28497974, 28497975, 28497975, 28497975, 28497976, 28497976, 28497977, 28497977, 28497978, 28497978, 28497979, 28497980, 28497980, 28497981, 28497982, 28497983, 28497985, 28497986, 28497987, 28497988, 28497989, 28497989, 28497990, 28497991, 28497993, 28497994, 28497996, 28497996, 28497997, 28497997, 28497998, 28497998, 28497999, 28497999, 28498000, 28498000, 28498001, 28498099, 28498105, 28498170, 28498756, 28498790, 28499284, 28497980, 28497981, 28497982, 28497984, 28497985, 28497986, 28497989, 28497990, 28497994, 28497997, 28497998, 28497999, 28497999, 28498000, 28498001, 28498001, 28498000, 28498002, 28497986, 28497994, 28497997, 28498000, 28498000, 28498001, 28498001, 28498002, 28498003, 28498000, 28498002, 28498004, 28498000, 28498005, 28497996, 28498003, 28498007, 28497993, 28498002, 28498003, 28498007, 28498008, 28498002, 28498009, 28498010, 28498009, 28498007, 28498011, 28498002, 28498002, 28498010, 28498011, 28498012, 28498013, 28498013, 28498015, 28498011, 28498016, 28498011, 28498015, 28498014, 28498016, 28498018, 28498016, 28498018, 28498016, 28498017, 28498017, 28498019, 28498017, 28498017, 28498018, 28498018, 28498019, 28498020, 28498018, 28498019, 28498020, 28498019, 28498020, 28498020, 28498021, 28498020, 28498021, 28498021, 28498021, 28498022, 28498022, 28498127, 28498023, 28498024, 28498051, 28498096, 28498118, 28498119, 28498120, 28498121, 28498126, 28498127, 28498127, 28498139, 28498169, 28498171, 28498191, 28498778, 28498812, 28498878, 28499306, 28498097, 28498121, 28498097, 28498119, 28498147, 28498172, 28498191, 28498192, 28498193, 28498194, 28498200, 28498201, 28498194, 28498213, 28498214, 28498215, 28498215, 28498216, 28498216, 28498219, 28498223, 28498215, 28498217, 28498216, 28498217, 28498224, 28498218, 28498218, 28498219, 28498220, 28498220, 28498221, 28498221, 28498222, 28498222, 28498224, 28498225, 28498225, 28498292, 28498220, 28498221, 28498221, 28498225, 28498225, 28498226, 28498221, 28498222, 28498222, 28498223, 28498225, 28498226, 28498226, 28498222, 28498223, 28498226, 28498227, 28498223, 28498227, 28498227, 28498225, 28498226, 28498227, 28498227, 28498228, 28498228, 28498228, 28498228, 28498228, 28498229, 28498230, 28498230, 28498231, 28498231, 28498232, 28498233, 28498233, 28498234, 28498234, 28498235, 28498235, 28498236, 28498236, 28498237, 28498238, 28498238, 28498239, 28498239, 28498240, 28498241, 28498242, 28498243, 28498243, 28498244, 28498244, 28498246, 28498247, 28498247, 28498248, 28498249, 28498250, 28498251, 28498252, 28498252, 28498253, 28498253, 28498254, 28498254, 28498255, 28498255, 28498256, 28498256, 28498257, 28498258, 28498258, 28498259, 28498259, 28498260, 28498265, 28498266, 28498269, 28498273, 28498273, 28498274, 28498274, 28498275, 28498275, 28498276, 28498277, 28498278, 28498280, 28498297, 28498298, 28498299, 28498302, 28498303, 28498307, 28498233, 28498234, 28498234, 28498235, 28498235, 28498237, 28498237, 28498238, 28498238, 28498240, 28498243, 28498247, 28498250, 28498252, 28498255, 28498256, 28498259, 28498274, 28498275, 28498276, 28498299, 28498234, 28498235, 28498235, 28498237, 28498247, 28498277, 28498299, 28498235, 28498236, 28498236, 28498237, 28498241, 28498250, 28498251, 28498254, 28498255, 28498258, 28498276, 28498278, 28498236, 28498237, 28498237, 28498238, 28498238, 28498239, 28498239, 28498240, 28498240, 28498241, 28498242, 28498245, 28498246, 28498252, 28498255, 28498260, 28498268, 28498276, 28498278, 28498300, 28498237, 28498238, 28498238, 28498239, 28498239, 28498240, 28498240, 28498241, 28498241, 28498242, 28498242, 28498243, 28498245, 28498246, 28498247, 28498247, 28498249, 28498249, 28498251, 28498253, 28498254, 28498255, 28498256, 28498257, 28498258, 28498260, 28498261, 28498261, 28498264, 28498266, 28498269, 28498276, 28498277, 28498278, 28498279, 28498279, 28498300, 28498301, 28498310, 28498238, 28498239, 28498239, 28498240, 28498240, 28498241, 28498241, 28498243, 28498244, 28498246, 28498251, 28498253, 28498254, 28498257, 28498258, 28498259, 28498259, 28498261, 28498264, 28498266, 28498277, 28498279, 28498301, 28498310, 28498239, 28498240, 28498240, 28498241, 28498241, 28498242, 28498242, 28498245, 28498245, 28498246, 28498247, 28498247, 28498248, 28498250, 28498254, 28498254, 28498255, 28498255, 28498256, 28498257, 28498257, 28498258, 28498259, 28498260, 28498261, 28498262, 28498262, 28498267, 28498270, 28498277, 28498277, 28498280, 28498281, 28498302, 28498311, 28498240, 28498248, 28498256, 28498274, 28498280, 28498302, 28498241, 28498242, 28498242, 28498243, 28498244, 28498246, 28498247, 28498252, 28498253, 28498255, 28498256, 28498257, 28498259, 28498259, 28498261, 28498262, 28498265, 28498272, 28498278, 28498281, 28498284, 28498300, 28498303, 28498242, 28498243, 28498243, 28498245, 28498259, 28498262, 28498266, 28498284, 28498243, 28498244, 28498244, 28498245, 28498245, 28498247, 28498248, 28498250, 28498252, 28498253, 28498254, 28498256, 28498256, 28498261, 28498262, 28498263, 28498264, 28498265, 28498266, 28498267, 28498269, 28498271, 28498282, 28498304, 28498244, 28498245, 28498246, 28498248, 28498248, 28498250, 28498252, 28498253, 28498254, 28498255, 28498256, 28498257, 28498261, 28498263, 28498265, 28498266, 28498268, 28498270, 28498279, 28498282, 28498286, 28498304, 28498246, 28498247, 28498251, 28498253, 28498254, 28498255, 28498257, 28498258, 28498258, 28498259, 28498261, 28498262, 28498263, 28498263, 28498265, 28498272, 28498280, 28498283, 28498305, 28498248, 28498249, 28498263, 28498283, 28498287, 28498305, 28498247, 28498249, 28498252, 28498258, 28498259, 28498261, 28498262, 28498264, 28498284, 28498306, 28498249, 28498250, 28498255, 28498256, 28498257, 28498259, 28498260, 28498261, 28498263, 28498265, 28498265, 28498266, 28498268, 28498280, 28498284, 28498287, 28498264, 28498307, 28498252, 28498254, 28498258, 28498264, 28498273, 28498283, 28498317, 28498254, 28498255, 28498259, 28498262, 28498265, 28498268, 28498284, 28498286, 28498255, 28498266, 28498286, 28498260, 28498262, 28498264, 28498265, 28498267, 28498285, 28498287, 28498291, 28498267, 28498268, 28498290, 28498310, 28498269, 28498288, 28498310, 28498313, 28498258, 28498262, 28498263, 28498263, 28498264, 28498267, 28498268, 28498271, 28498272, 28498273, 28498307, 28498311, 28498264, 28498287, 28498271, 28498312, 28498278, 28498263, 28498265, 28498274, 28498282, 28498288, 28498313, 28498322, 28498270, 28498273, 28498281, 28498288, 28498313, 28498271, 28498273, 28498282, 28498319, 28498274, 28498282, 28498298, 28498314, 28498272, 28498274, 28498289, 28498315, 28498933, 28498272, 28498272, 28498274, 28498281, 28498292, 28498293, 28498315, 28498271, 28498274, 28498283, 28498291, 28498294, 28498309, 28498275, 28498293, 28498316, 28498269, 28498272, 28498276, 28498276, 28498279, 28498291, 28498317, 28498270, 28498271, 28498272, 28498272, 28498273, 28498274, 28498276, 28498277, 28498284, 28498292, 28498297, 28498274, 28498276, 28498279, 28498280, 28498280, 28498281, 28498283, 28498283, 28498318, 28498274, 28498274, 28498279, 28498281, 28498294, 28498295, 28498318, 28498318, 28498274, 28498275, 28498294, 28498296, 28498299, 28498319, 28498277, 28498278, 28498280, 28498296, 28498297, 28498326, 28498277, 28498278, 28498280, 28498287, 28498294, 28498295, 28498295, 28498296, 28498296, 28498297, 28498298, 28498320, 28498325, 28498329, 28498277, 28498277, 28498278, 28498297, 28498298, 28498320, 28498904, 28498277, 28498280, 28498281, 28498282, 28498296, 28498306, 28498321, 28498278, 28498280, 28498281, 28498282, 28498282, 28498283, 28498284, 28498297, 28498297, 28498298, 28498299, 28498312, 28498321, 28498279, 28498282, 28498283, 28498294, 28498298, 28498299, 28498300, 28498322, 28498281, 28498282, 28498282, 28498283, 28498283, 28498292, 28498295, 28498297, 28498298, 28498300, 28498322, 28498331, 28498281, 28498282, 28498292, 28498298, 28498299, 28498299, 28498300, 28498301, 28498323, 28498283, 28498284, 28498286, 28498290, 28498298, 28498299, 28498300, 28498300, 28498301, 28498304, 28498323, 28498283, 28498284, 28498284, 28498297, 28498298, 28498299, 28498302, 28498318, 28498324, 28498284, 28498289, 28498290, 28498292, 28498298, 28498300, 28498302, 28498324, 28498286, 28498286, 28498288, 28498290, 28498299, 28498300, 28498300, 28498301, 28498302, 28498303, 28498308, 28498325, 28498287, 28498290, 28498300, 28498300, 28498301, 28498303, 28498325, 28498288, 28498290, 28498300, 28498300, 28498301, 28498304, 28498326, 28498292, 28498302, 28498304, 28498309, 28498291, 28498302, 28498306, 28498326, 28498327, 28498292, 28498303, 28498305, 28498327, 28498327, 28498297, 28498306, 28498305, 28498306, 28498311, 28498298, 28498303, 28498304, 28498305, 28498307, 28498308, 28498305, 28498305, 28498306, 28498308, 28498313, 28498330, 28498330, 28498305, 28498331, 28498307, 28498309, 28498310, 28498332, 28498316, 28498332, 28498333, 28498309, 28498311, 28498312, 28498334, 28498312, 28498334, 28498337, 28498315, 28498337, 28498317, 28498314, 28498317, 28498338, 28498339, 28498314, 28498315, 28498316, 28498316, 28498317, 28498320, 28498320, 28498339, 28498315, 28498316, 28498316, 28498318, 28498319, 28498337, 28498340, 28498316, 28498317, 28498317, 28498318, 28498319, 28498320, 28498322, 28498335, 28498336, 28498337, 28498339, 28498340, 28498318, 28498319, 28498339, 28498341, 28498318, 28498319, 28498320, 28498321, 28498341, 28498342, 28498320, 28498322, 28498323, 28498323, 28498326, 28498332, 28498339, 28498340, 28498342, 28498321, 28498322, 28498322, 28498323, 28498323, 28498324, 28498324, 28498325, 28498325, 28498326, 28498326, 28498327, 28498331, 28498334, 28498335, 28498335, 28498337, 28498339, 28498340, 28498341, 28498341, 28498342, 28498342, 28498343, 28498348, 28498352, 28498343, 28498325, 28498330, 28498342, 28498344, 28498324, 28498325, 28498344, 28498344, 28498345, 28498328, 28498345, 28498329, 28498332, 28498340, 28498345, 28498346, 28498355, 28498329, 28498346, 28498343, 28498347, 28498347, 28498345, 28498347, 28498348, 28498348, 28498348, 28498347, 28498349, 28498350, 28498351, 28498351, 28498350, 28498354, 28498354, 28498356, 28498357, 28498357, 28498358, 28498359, 28498359, 28498360, 28498360, 28498360, 28498361, 28498362, 28498361, 28498362, 28498363, 28498363, 28498364, 28498371, 28498372, 28498364, 28498369, 28498364, 28498365, 28498366, 28498366, 28498367, 28498367, 28498368, 28498368, 28498369, 28498369, 28498370, 28498370, 28498371, 28498372, 28498372, 28498373, 28498373, 28498374, 28498949, 28498983, 28499477, 28499515, 28498366, 28498367, 28498367, 28498368, 28498369, 28498369, 28498370, 28498370, 28498371, 28498372, 28498372, 28498373, 28498373, 28498374, 28498374, 28498986, 28498367, 28498369, 28498370, 28498371, 28498372, 28498373, 28498374, 28498375, 28498369, 28498370, 28498374, 28498374, 28498375, 28498372, 28498376, 28498371, 28498372, 28498374, 28498375, 28498375, 28498376, 28498375, 28498377, 28498377, 28498373, 28498374, 28498376, 28498378, 28498374, 28498376, 28498377, 28498378, 28498378, 28498376, 28498376, 28498377, 28498377, 28498378, 28498378, 28498379, 28498988, 28498379, 28498380, 28498378, 28498379, 28498380, 28498380, 28498379, 28498380, 28498380, 28498381, 28498380, 28498381, 28498381, 28498381, 28498382, 28498382, 28498383, 28498384, 28498394, 28498395, 28498423, 28498957, 28498958, 28498992, 28498992, 28499008, 28499011, 28499393, 28499486, 28499846, 38968444, 45021744, 28498958, 28498958, 28498959, 28498969, 28498970, 28498802, 28499219, 28499415, 28499532, 28499533, 28499534, 28499534, 28499535, 28499535, 28499537, 28499537, 28499538, 28499542, 28499543, 28499543, 28499544, 28499556, 28499561, 28499565, 28499566, 28499566, 28499567, 28499567, 28499568, 28499608, 28499534, 28499535, 28499536, 28499538, 28499542, 28499567, 28499567, 28499568, 28499544, 28499567, 28499567, 28499568, 28499568, 28499537, 28499568, 28499537, 28499569, 28499538, 28499539, 28499547, 28499548, 28499569, 28499570, 28499570, 28499571, 28499571, 28499572, 28499576, 28499553, 28499553, 28499578, 28499644, 28500072, 28499556, 28499579, 28499579, 28499579, 28499590, 28499596, 28499599, 28499600, 28499600, 28499600, 28499600, 28499601, 28499601, 28499602, 28499603, 28499603, 28499604, 28499604, 28499605, 28499605, 28499606, 28499607, 28499607, 28499608, 28499609, 28499610, 28499610, 28499611, 28499612, 28499612, 28499614, 28499616, 28499616, 28499617, 28499617, 28499618, 28499618, 28499619, 28499619, 28499620, 28499620, 28499621, 28499621, 28499622, 28499622, 28499623, 28499623, 28499624, 28499624, 28499625, 28499625, 28499626, 28499627, 28499628, 28499628, 28499629, 28499629, 28499630, 28499630, 28499631, 28499632, 28499633, 28499634, 28499635, 28499636, 28499637, 28499638, 28499638, 28499639, 28499640, 28499640, 28499641, 28499642, 28499643, 28499648, 28499648, 28499603, 28499604, 28499605, 28499605, 28499606, 28499607, 28499610, 28499611, 28499611, 28499612, 28499615, 28499617, 28499617, 28499618, 28499618, 28499619, 28499620, 28499620, 28499621, 28499621, 28499622, 28499623, 28499623, 28499624, 28499624, 28499625, 28499625, 28499627, 28499629, 28499630, 28499630, 28499635, 28499636, 28499641, 28499643, 28499643, 28499604, 28499608, 28499610, 28499616, 28499618, 28499619, 28499619, 28499622, 28499624, 28499625, 28499629, 28499638, 28499639, 28499607, 28499608, 28499611, 28499613, 28499619, 28499619, 28499620, 28499620, 28499622, 28499624, 28499630, 28499606, 28499611, 28499615, 28499621, 28499626, 28499627, 28499628, 28499620, 28499623, 28499626, 28499610, 28499616, 28499624, 28499622, 28499625, 28499619, 28499622, 28499624, 28499626, 28499628, 28499629, 28499623, 28499634, 28499623, 28499618, 28499624, 28499625, 28499625, 28499627, 28499628, 28499629, 28499633, 28499643, 28499619, 28499626, 28499626, 28499626, 28499625, 28499626, 28499627, 28499630, 28499635, 28499627, 28499627, 28499628, 28499628, 28499637, 28499632, 28499639, 28499631, 28499639, 28499644, 28499655, 28499639, 28499655, 28499642, 28499657, 28499632, 28499632, 28499633, 28499637, 28499640, 28499643, 28499644, 28499632, 28499633, 28499634, 28499634, 28499639, 28499641, 28499643, 28499643, 28499645, 28499654, 28499658, 28499633, 28499634, 28499634, 28499635, 28499636, 28499636, 28499637, 28499637, 28499638, 28499638, 28499639, 28499639, 28499640, 28499642, 28499644, 28499644, 28499645, 28499646, 28499648, 28499649, 28499653, 28499658, 28499634, 28499635, 28499635, 28499636, 28499636, 28499637, 28499637, 28499638, 28499638, 28499639, 28499639, 28499640, 28499640, 28499642, 28499642, 28499643, 28499644, 28499645, 28499645, 28499647, 28499649, 28499652, 28499656, 28499658, 28499659, 28499635, 28499636, 28499637, 28499637, 28499638, 28499638, 28499639, 28499639, 28499640, 28499641, 28499641, 28499642, 28499643, 28499645, 28499645, 28499646, 28499647, 28499659, 28499636, 28499637, 28499637, 28499638, 28499638, 28499639, 28499640, 28499640, 28499641, 28499642, 28499643, 28499643, 28499644, 28499645, 28499646, 28499647, 28499660, 28499637, 28499638, 28499638, 28499639, 28499639, 28499640, 28499641, 28499644, 28499648, 28499650, 28499657, 28499660, 28499639, 28499639, 28499640, 28499640, 28499642, 28499642, 28499643, 28499645, 28499646, 28499647, 28499647, 28499648, 28499649, 28499653, 28499655, 28499661, 28499639, 28499640, 28499641, 28499641, 28499642, 28499643, 28499643, 28499644, 28499645, 28499645, 28499647, 28499648, 28499648, 28499651, 28499655, 28499661, 28499640, 28499641, 28499641, 28499642, 28499642, 28499643, 28499644, 28499644, 28499645, 28499647, 28499648, 28499650, 28499651, 28499654, 28499659, 28499662, 45022372, 28499641, 28499642, 28499643, 28499643, 28499644, 28499644, 28499646, 28499646, 28499647, 28499648, 28499650, 28499651, 28499652, 28499654, 28499658, 28499658, 28499660, 28499661, 28499662, 28499662, 28499642, 28499643, 28499644, 28499644, 28499645, 28499645, 28499646, 28499648, 28499649, 28499663, 28499643, 28499644, 28499644, 28499645, 28499645, 28499646, 28499646, 28499647, 28499647, 28499649, 28499649, 28499651, 28499651, 28499654, 28499655, 28499656, 28499657, 28499657, 28499659, 28499660, 28499663, 28499663, 28500071, 28500116, 28499644, 28499645, 28499646, 28499647, 28499647, 28499648, 28499649, 28499650, 28499659, 28499659, 28499661, 28499663, 28499664, 28499646, 28499646, 28499647, 28499650, 28499650, 28499651, 28499657, 28499664, 28499646, 28499647, 28499647, 28499648, 28499649, 28499650, 28499651, 28499652, 28499652, 28499657, 28499661, 28499665, 28500025, 28499647, 28499648, 28499649, 28499649, 28499650, 28499651, 28499651, 28499652, 28499653, 28499654, 28499656, 28499665, 28500118, 28499648, 28499649, 28499650, 28499650, 28499651, 28499652, 28499654, 28499662, 28499663, 28499665, 28499666, 28499650, 28499650, 28499652, 28499652, 28499653, 28499654, 28499655, 28499658, 28499659, 28499661, 28499666, 28499666, 28499651, 28499653, 28499665, 28499667, 28499651, 28499652, 28499653, 28499653, 28499654, 28499654, 28499656, 28499658, 28499658, 28499662, 28499667, 28499652, 28499653, 28499654, 28499654, 28499655, 28499655, 28499657, 28499659, 28499663, 28499663, 28499664, 28499665, 28499665, 28499668, 28500480, 28499654, 28499654, 28499656, 28499668, 28499661, 28499669, 28499655, 28499656, 28499656, 28499657, 28499658, 28499659, 28499660, 28499661, 28499663, 28499663, 28499665, 28499665, 28499666, 28499667, 28499668, 28499669, 28499669, 28499694, 28499656, 28499657, 28499657, 28499658, 28499658, 28499660, 28499661, 28499661, 28499662, 28499663, 28499665, 28499665, 28499666, 28499666, 28499667, 28499668, 28499669, 28499670, 28500123, 28499657, 28499658, 28499660, 28499662, 28499664, 28499666, 28499670, 28499670, 28499660, 28499661, 28499663, 28499664, 28499665, 28499667, 28499668, 28499668, 28499671, 28499659, 28499661, 28499663, 28499664, 28499664, 28499665, 28499666, 28499670, 28499671, 28499676, 28499661, 28499668, 28499670, 28499671, 28499672, 28499664, 28499672, 28499672, 28499666, 28499672, 28499665, 28499667, 28499667, 28499668, 28499670, 28499673, 28499673, 28499665, 28499667, 28499670, 28499674, 28499667, 28499671, 28499674, 28499667, 28499667, 28499668, 28499669, 28499675, 28499667, 28499668, 28499672, 28499675, 28500128, 28499669, 28499670, 28499671, 28499672, 28499673, 28499673, 28499675, 28499676, 28499676, 28499672, 28499672, 28499673, 28499674, 28499674, 28499677, 28499671, 28499672, 28499675, 28499677, 28499674, 28499675, 28499676, 28499677, 28499678, 28499676, 28499678, 28499675, 28499678, 28499678, 28499679, 28499675, 28499679, 28499679, 28499700, 28500132, 28499676, 28499677, 28499678, 28499680, 28499678, 28499679, 28499679, 28499680, 28499680, 28500040, 28500133, 28499679, 28499680, 28499681, 28499683, 28499715, 28500134, 28499681, 28499681, 28499680, 28499682, 28499682, 28499683, 28499683, 28499689, 28499684, 28499685, 28499685, 28499686, 28499686, 28499687, 28499687, 28499688, 28499688, 28499689, 28499689, 28499690, 28499690, 28499691, 28499691, 28499692, 28499693, 28499695, 28499696, 28499698, 28499700, 28499700, 28499701, 28499702, 28499702, 28499703, 28499703, 28499704, 28499704, 28499705, 28499706, 28499708, 28499709, 28499710, 28499711, 28499712, 28499713, 28499714, 28499715, 28499715, 28499716, 28499716, 28499717, 28499717, 28499718, 28499718, 28499900, 28500043, 28500095, 28500137, 28501180, 28874847, 35132081, 38969094, 28499685, 28499686, 28499686, 28499687, 28499687, 28499688, 28499689, 28499689, 28499690, 28499691, 28499691, 28499692, 28499699, 28499700, 28499700, 28499701, 28499703, 28499704, 28499712, 28499713, 28499715, 28499715, 28499716, 28499717, 28499717, 28499718, 28499718, 28499719, 28499692, 28499719, 28499687, 28499690, 28499691, 28499692, 28499705, 28499719, 28499720, 28499689, 28499689, 28499720, 28499691, 28499693, 28499712, 28499714, 28499719, 28499720, 28499721, 28499692, 28499693, 28499694, 28499702, 28499703, 28499721, 28500140, 28499695, 28499698, 28499713, 28499720, 28499722, 28499713, 28499693, 28499694, 28499695, 28499696, 28499702, 28499716, 28499716, 28499718, 28499720, 28499721, 28499722, 28499723, 28500141, 28499694, 28499695, 28499696, 28499696, 28499698, 28499701, 28499705, 28499706, 28499714, 28499716, 28499722, 28499722, 28499723, 28499723, 28500142, 28499695, 28499696, 28499696, 28499697, 28499702, 28499703, 28499706, 28499710, 28499723, 28499723, 28499724, 28500142, 28499697, 28499697, 28499724, 28499724, 28500143, 28499697, 28499703, 28499706, 28499707, 28499725, 28500143, 28499698, 28499699, 28499699, 28499704, 28499704, 28499706, 28499713, 28499716, 28499718, 28499719, 28499720, 28499722, 28499723, 28499723, 28499724, 28499725, 28499725, 28499709, 28499716, 28499717, 28499721, 28499722, 28499723, 28499723, 28499725, 28499725, 28499726, 28499712, 28499717, 28499727, 28499727, 28499721, 28499728, 28499730, 28499728, 28499731, 28499724, 28499731, 28499716, 28499732, 28499714, 28499732, 28499733, 28499733, 28499734, 28499719, 28499733, 28499734, 28499734, 28499734, 28499735, 28499722, 28499735, 28499736, 28499735, 28499736, 28499737, 28499726, 28499737, 28499736, 28499738, 28499738, 28499738, 28499739, 28499739, 28500158, 28499739, 28499741, 28499736, 28499733, 28499741, 28499742, 28499743, 28499743, 28499742, 28499743, 28499738, 28499739, 28499744, 28499740, 28499739, 28499743, 28499745, 28499745, 28499746, 28499741, 28499743, 28499744, 28499745, 28499746, 28499746, 28499746, 28499747, 28499745, 28499746, 28499747, 28499747, 28499748, 28499747, 28499748, 28499749, 28499746, 28499749, 28499747, 28499748, 28499749, 28499749, 28499750, 28499749, 28499750, 28499750, 28499750, 28499751, 28499750, 28499751, 28499751, 28499751, 28499752, 28499752, 28499753, 28499754, 28499754, 28499769, 28499819, 28499883, 28499887, 28500076, 28500077, 28500078, 28500079, 28500125, 28500126, 28500127, 28500128, 28500130, 28500134, 28500136, 28500171, 28500209, 28500230, 28500531, 28501215, 35132116, 38032002, 38969129, 28499887, 28500076, 28500077, 28500079, 28500172, 28500079, 28500078, 28500080, 28500173, 28500095, 28500143, 28500089, 28500092, 28500093, 28500140, 28500282, 28500284, 28500377, 28500283, 28500284, 28500400, 28500401, 28500402, 28500475, 28500475, 28500405, 28500405, 28500450, 28500452, 28500453, 28500453, 28500454, 28500456, 28500456, 28500457, 28500457, 28500469, 28500476, 28500477, 28500477, 28500477, 28500478, 28500459, 28500478, 28500523, 28500524, 28500505, 28500525, 28500511, 28500526, 28500526, 28500505, 28500507, 28500526, 28500527, 28500527, 28500528, 28500529, 28500529, 28500530, 28500530, 28500513, 28500532, 28500533, 28500535, 28500542, 28500549, 28500569, 28500550, 28500569, 28500570, 28500606, 28500570, 28500589, 28500590, 28500591, 28500591, 28500592, 28500592, 28500593, 28500593, 28500594, 28500594, 28500595, 28500595, 28500598, 28500599, 28500600, 28500601, 28500607, 28500611, 28500612, 28500618, 28500621, 28500622, 28500624, 28500625, 28500626, 28500626, 28500627, 28500627, 28500628, 28500632, 28500591, 28500593, 28500596, 28500600, 28500600, 28500628, 28500628, 28500593, 28500594, 28500594, 28500595, 28500627, 28500628, 28500629, 28500594, 28500600, 28500601, 28500628, 28500629, 28500629, 28500629, 28500629, 28500628, 28500630, 28500596, 28500614, 28500630, 28500631, 28500630, 28500631, 28500631, 28500629, 28500631, 28500632, 28500633, 28500633, 28500633, 28500633, 28500635, 28500636, 28500609, 28500610, 28500637, 28500638, 28500612, 28500638, 28500647, 28500653, 28500658, 28500703, 28500703, 28500960, 28500991, 28501010, 28501644, 28501677, 28501695, 28875311, 28988691, 29134264, 31383497, 28500638, 28500614, 28500639, 28500704, 28500641, 28500645, 28500642, 28500649, 28500649, 28500650, 28500656, 28500658, 28500659, 28500660, 28500662, 28500662, 28500663, 28500663, 28500664, 28500664, 28500678, 28500703, 28500664, 28500665, 28500665, 28500666, 28500667, 28500667, 28500668, 28500668, 28500669, 28500670, 28500671, 28500672, 28500673, 28500673, 28500674, 28500674, 28500675, 28500675, 28500676, 28500676, 28500677, 28500677, 28500678, 28500678, 28500679, 28500679, 28500680, 28500680, 28500681, 28500681, 28500682, 28500682, 28500683, 28500683, 28500684, 28500684, 28500685, 28500685, 28500686, 28500687, 28500689, 28500690, 28500690, 28500691, 28500692, 28500692, 28500693, 28500695, 28500697, 28500699, 28500700, 28500701, 28500701, 28500703, 28500703, 28500667, 28500668, 28500669, 28500669, 28500671, 28500672, 28500674, 28500675, 28500675, 28500677, 28500678, 28500678, 28500679, 28500679, 28500680, 28500680, 28500682, 28500682, 28500683, 28500685, 28500685, 28500690, 28500701, 28500703, 28500704, 28500669, 28500671, 28500674, 28500679, 28500680, 28500682, 28500687, 28500682, 28500672, 28500677, 28500681, 28500680, 28500682, 28500678, 28500681, 28500682, 28500682, 28500676, 28500679, 28500681, 28500682, 28500682, 28500683, 28500684, 28500684, 28500686, 28500688, 28500689, 28500703, 28500708, 28500683, 28500684, 28500686, 28500687, 28500685, 28500704, 28500684, 28500705, 28500681, 28500685, 28500687, 28500690, 28500685, 28500711, 28500683, 28500686, 28500688, 28500694, 28500711, 28500686, 28500688, 28500690, 28500693, 28500701, 28500712, 28500684, 28500686, 28500687, 28500687, 28500692, 28500712, 28500687, 28500688, 28500689, 28500691, 28500713, 28500688, 28500689, 28500690, 28500714, 28500689, 28500690, 28500714, 28500689, 28500691, 28500693, 28500694, 28500690, 28500691, 28500691, 28500692, 28500693, 28500693, 28500694, 28500696, 28500696, 28500697, 28500697, 28500699, 28500699, 28500702, 28500703, 28500704, 28500704, 28500705, 28500707, 28500712, 28500713, 28500714, 28500715, 28500691, 28500692, 28500692, 28500693, 28500694, 28500694, 28500695, 28500695, 28500696, 28500697, 28500697, 28500698, 28500699, 28500700, 28500701, 28500703, 28500707, 28500715, 28500716, 28500692, 28500693, 28500694, 28500695, 28500697, 28500698, 28500698, 28500699, 28500702, 28500702, 28500704, 28500705, 28500715, 28500716, 28500716, 28500693, 28500694, 28500694, 28500695, 28500695, 28500696, 28500696, 28500697, 28500697, 28500698, 28500699, 28500699, 28500700, 28500700, 28500701, 28500702, 28500703, 28500703, 28500704, 28500705, 28500705, 28500706, 28500707, 28500708, 28500710, 28500710, 28500712, 28500712, 28500715, 28500716, 28500716, 28500717, 28500694, 28500695, 28500695, 28500696, 28500696, 28500697, 28500699, 28500700, 28500705, 28500705, 28500706, 28500706, 28500708, 28500713, 28500716, 28500717, 28500717, 28500696, 28500699, 28500705, 28500707, 28500709, 28500696, 28500697, 28500697, 28500698, 28500698, 28500699, 28500700, 28500701, 28500701, 28500702, 28500702, 28500703, 28500704, 28500704, 28500705, 28500705, 28500706, 28500707, 28500707, 28500708, 28500716, 28500718, 28500698, 28500698, 28500699, 28500699, 28500700, 28500700, 28500701, 28500702, 28500702, 28500703, 28500704, 28500704, 28500705, 28500705, 28500706, 28500707, 28500707, 28500708, 28500709, 28500718, 28500719, 28500698, 28500699, 28500700, 28500700, 28500701, 28500701, 28500702, 28500703, 28500703, 28500705, 28500706, 28500707, 28500708, 28500713, 28500719, 28500719, 28500699, 28500700, 28500700, 28500701, 28500701, 28500702, 28500703, 28500703, 28500704, 28500706, 28500708, 28500710, 28500713, 28500719, 28500720, 28500700, 28500702, 28500702, 28500703, 28500703, 28500704, 28500706, 28500707, 28500710, 28500711, 28500720, 28500701, 28500703, 28500704, 28500704, 28500705, 28500706, 28500711, 28500714, 28500720, 28500720, 28500721, 28500703, 28500704, 28500704, 28500708, 28500710, 28500721, 28500703, 28500704, 28500704, 28500705, 28500705, 28500708, 28500709, 28500710, 28500710, 28500715, 28500721, 28500722, 28500704, 28500705, 28500705, 28500706, 28500708, 28500708, 28500709, 28500710, 28500711, 28500712, 28500713, 28500719, 28500720, 28500721, 28500722, 28500722, 28500706, 28500706, 28500707, 28500708, 28500709, 28500714, 28500716, 28500718, 28500719, 28500723, 28500706, 28500707, 28500707, 28500709, 28500709, 28500710, 28500710, 28500711, 28500712, 28500712, 28500713, 28500716, 28500718, 28500719, 28500720, 28500721, 28500722, 28500723, 28500723, 28500707, 28500708, 28500708, 28500710, 28500710, 28500711, 28500712, 28500714, 28500715, 28500719, 28500720, 28500721, 28500722, 28500723, 28500724, 28500708, 28500709, 28500710, 28500710, 28500711, 28500711, 28500712, 28500713, 28500716, 28500717, 28500720, 28500724, 28500724, 28500709, 28500711, 28500713, 28500723, 28500724, 28500725, 28500711, 28500711, 28500712, 28500716, 28500725, 28500712, 28500712, 28500713, 28500713, 28500714, 28500715, 28500716, 28500718, 28500722, 28500726, 28500726, 28500713, 28500714, 28500715, 28500715, 28500717, 28500718, 28500720, 28500720, 28500722, 28500724, 28500727, 28500714, 28500715, 28500716, 28500716, 28500717, 28500718, 28500720, 28500724, 28500725, 28500726, 28500727, 28500727, 28500716, 28500716, 28500717, 28500718, 28500719, 28500725, 28500725, 28500728, 28500717, 28500719, 28500724, 28500728, 28500717, 28500719, 28500720, 28500724, 28500727, 28500727, 28500728, 28500729, 28500719, 28500722, 28500726, 28500727, 28500728, 28500729, 28500729, 28500720, 28500721, 28500721, 28500725, 28500725, 28500727, 28500729, 28500730, 28501073, 28500722, 28500724, 28500726, 28500727, 28500728, 28500729, 28500730, 28500731, 28501728, 28500731, 28500725, 28500729, 28500731, 28500732, 28500727, 28500728, 28500729, 28500732, 28500732, 28500733, 28500730, 28500727, 28500728, 28500731, 28500733, 28500734, 28500728, 28500732, 28500734, 28500734, 28500729, 28500732, 28500734, 28500735, 28500731, 28500733, 28500736, 28500734, 28500735, 28500736, 28500736, 28500736, 28500737, 28500735, 28500736, 28500737, 28500736, 28500737, 28500738, 28500738, 28500738, 28500738, 28500739, 28500739, 28500739, 28500739, 28500740, 28500740, 28500741, 28500742, 28500742, 28500743, 28500743, 28500745, 28500745, 28500746, 28500747, 28500748, 28500748, 28500750, 28500751, 28500751, 28500753, 28500756, 28500763, 28500763, 28500767, 28500768, 28500769, 28500770, 28500772, 28500773, 28500773, 28500775, 28500775, 28500776, 28500776, 28500777, 28500777, 28500778, 28500778, 28500779, 28501025, 28501050, 28501050, 28501709, 28501738, 28501740, 29134329, 28500742, 28500743, 28500743, 28500744, 28500744, 28500746, 28500747, 28500747, 28500748, 28500748, 28500749, 28500749, 28500750, 28500752, 28500754, 28500755, 28500757, 28500758, 28500762, 28500763, 28500764, 28500768, 28500769, 28500770, 28500771, 28500771, 28500772, 28500773, 28500773, 28500774, 28500775, 28500775, 28500776, 28500776, 28500777, 28500777, 28500778, 28500778, 28500779, 28500779, 28500747, 28500749, 28500749, 28500750, 28500750, 28500752, 28500753, 28500776, 28500777, 28500779, 28500779, 28500780, 28500745, 28500749, 28500749, 28500776, 28500777, 28500778, 28500780, 28500780, 28500748, 28500759, 28500781, 28501052, 28500780, 28500781, 28500749, 28500781, 28500749, 28500783, 28500752, 28500754, 28500783, 28500783, 28500777, 28500754, 28500756, 28500759, 28500776, 28500782, 28500783, 28500784, 28500784, 28500784, 28500756, 28500758, 28500763, 28500783, 28500784, 28500785, 28500756, 28500757, 28500781, 28500785, 28500786, 28500757, 28500758, 28500761, 28500785, 28500758, 28500787, 28500780, 28500782, 28500785, 28500786, 28500760, 28500768, 28500783, 28500787, 28500787, 28500788, 28500779, 28500784, 28500787, 28500787, 28500788, 28500789, 28500779, 28500789, 28500788, 28500790, 28500788, 28500789, 28500790, 28500790, 28500791, 28500791, 28500792, 28500794, 28500787, 28500791, 28500793, 28500795, 28500792, 28500800, 28500795, 28500799, 28500800, 28500801, 28500793, 28500794, 28500805, 28500795, 28500806, 28500804, 28500806, 28500806, 28500806, 28500807, 28500807, 28500808, 28500805, 28500807, 28500802, 28500809, 28500809, 28500810, 28500808, 28500810, 28500807, 28500810, 28500809, 28500809, 28500810, 28500811, 28500811, 28500810, 28500811, 28500811, 28500812, 28500810, 28500812, 28500812, 28500811, 28500812, 28500812, 28500813, 28500813, 28500813, 28500813, 28500814, 28500812, 28500813, 28500813, 28500814, 28500814, 28500813, 28500814, 28500814, 28500815, 28500814, 28500815, 28500815, 28500815, 28500816, 28500816, 28500817, 28500818, 28501062, 28501063, 28501088, 28501089, 28501090, 28501113, 28501115, 28501116, 28501122, 28501747, 28501769, 28501776, 28501779, 28501785, 28501800, 28595045, 28875413, 28875414, 28988796, 38969661, 28501063, 28501088, 28501064, 28501308, 28501309, 28501310, 28501310, 28501311, 28501311, 28501315, 28501319, 28501320, 28501326, 28501330, 28501331, 28501333, 28501333, 28501334, 28501310, 28501312, 28501315, 28501334, 28501334, 28501316, 28501321, 28501334, 28501335, 28501316, 28501335, 28501336, 28501335, 28501336, 28501336, 28501339, 28501339, 28501340, 28501330, 28501332, 28501332, 28501335, 28501345, 28501370, 28502004, 28502033, 28502036, 28502059, 28775230, 28875669, 28875671, 29498404, 31584813, 31584813, 28501336, 28502034, 28501349, 29134628, 28501351, 28501355, 28501355, 28501356, 28501357, 28501357, 28501358, 28501358, 28501359, 28501360, 28501360, 28501361, 28501361, 28501362, 28501362, 28501363, 28501364, 28501364, 28501365, 28501367, 28501367, 28501368, 28501369, 28501369, 28501370, 28501370, 28501372, 28501374, 28501375, 28501375, 28501376, 28501376, 28501377, 28501377, 28501378, 28501378, 28501379, 28501379, 28501380, 28501380, 28501381, 28501381, 28501382, 28501382, 28501383, 28501383, 28501384, 28501384, 28501385, 28501385, 28501386, 28501386, 28501387, 28501388, 28501388, 28501389, 28501390, 28501391, 28501391, 28501392, 28501392, 28501393, 28501394, 28501395, 28501398, 28501399, 28501405, 28501407, 28501409, 28501409, 28501434, 28501362, 28501364, 28501364, 28501366, 28501368, 28501376, 28501376, 28501377, 28501380, 28501384, 28501389, 28501390, 28501392, 28501408, 28501409, 28501410, 28501363, 28501367, 28501373, 28501373, 28501380, 28501383, 28501385, 28501394, 28501410, 28501379, 28501381, 28501389, 28501363, 28501364, 28501378, 28501385, 28501411, 28501366, 28501367, 28501369, 28501372, 28501380, 28501380, 28501381, 28501381, 28501382, 28501384, 28501385, 28501386, 28501386, 28501388, 28501388, 28501389, 28501394, 28501395, 28501412, 28501367, 28501387, 28501387, 28501396, 28501382, 28501387, 28501387, 28501376, 28501382, 28501412, 28501374, 28501381, 28501389, 28501396, 28501414, 28501414, 28501388, 28501389, 28501415, 28501385, 28501390, 28501391, 28501394, 28501373, 28501391, 28501383, 28501387, 28501390, 28501388, 28501416, 28501418, 28501418, 28501394, 28501396, 28501419, 28501387, 28501394, 28501420, 28501395, 28501420, 28501395, 28501397, 28501420, 28501397, 28501424, 28501398, 28501399, 28501425, 28501399, 28501400, 28501394, 28501400, 28501406, 28501408, 28501410, 28501400, 28501401, 28501408, 28501427, 28501406, 28501396, 28501402, 28501409, 28501428, 28501403, 28501405, 28501408, 28501415, 28501428, 28501403, 28501408, 28501409, 28501400, 28501403, 28501404, 28501408, 28501409, 28501429, 28501404, 28501404, 28501406, 28501410, 28501428, 28501430, 28501404, 28501405, 28501406, 28501409, 28501412, 28501430, 28501405, 28502039, 28501407, 28501429, 28501405, 28501408, 28501432, 28501407, 28501407, 28501410, 28501411, 28501413, 28501433, 33437585, 28501408, 28501412, 28501415, 28501416, 28501419, 28501429, 28501433, 28501408, 28501410, 28501411, 28501415, 28501433, 28501434, 28501409, 28501410, 28501410, 28501411, 28501411, 28501412, 28501413, 28501413, 28501414, 28501415, 28501415, 28501416, 28501417, 28501418, 28501424, 28501424, 28501427, 28501429, 28501430, 28501430, 28501431, 28501432, 28501432, 28501434, 28501434, 28501410, 28501411, 28501411, 28501413, 28501416, 28501417, 28501417, 28501435, 28931396, 28501411, 28501412, 28501413, 28501418, 28501422, 28501427, 28501435, 28502044, 28501413, 28501414, 28501414, 28501418, 28501419, 28501421, 28501430, 28501432, 28501434, 28501436, 28501413, 28501415, 28501418, 28501431, 28501434, 28501436, 28501414, 28501415, 28501416, 28501417, 28501417, 28501420, 28501420, 28501429, 28501435, 28501436, 28501437, 28501437, 28501421, 28501428, 28501436, 28501438, 28501417, 28501418, 28501428, 28501438, 28501420, 28501423, 28501439, 28501439, 28501422, 28501427, 28501437, 28501440, 28501430, 28501432, 28501440, 28501423, 28501425, 28501426, 28501438, 28501439, 28501441, 28501425, 28501432, 28501442, 28501425, 28501426, 28501432, 28501440, 28501442, 28501442, 28501434, 28501441, 28501443, 28501433, 28501437, 28501441, 28501441, 28501442, 28501443, 28501444, 28501444, 28501445, 28501445, 28501436, 28501446, 28501446, 28501434, 28501447, 28501448, 28501447, 28501449, 28501449, 28501447, 28501448, 28501450, 28501450, 28501451, 28501452, 28501453, 28501452, 28502062, 28501451, 28501454, 28501453, 28501455, 28501455, 28501456, 28501456, 28501457, 28501457, 28501457, 28501458, 28502066, 28501458, 28501459, 28501460, 28501461, 28501461, 28501462, 28501465, 28501466, 28501468, 28501469, 28501471, 28501477, 28501480, 28501481, 28501482, 28501483, 28501483, 28501484, 28501484, 28501485, 28502068, 28502097, 28502105, 28502106, 28875734, 28875735, 28989110, 31584877, 28501461, 28501462, 28501468, 28501471, 28501482, 28501483, 28501483, 28501484, 28501484, 28501485, 28501485, 28501483, 28501485, 28501485, 28501486, 28501465, 28501486, 28501487, 28501486, 28501490, 28501491, 28501491, 28501492, 28501492, 28501492, 28501494, 28501493, 28501496, 28501499, 28501504, 28501504, 28501505, 28501506, 28501506, 28501504, 28501505, 28501506, 28501506, 28501507, 28501507, 28501507, 28501507, 28501508, 28501507, 28501508, 28501508, 28501509, 28502092, 28501509, 28501510, 28501511, 28501530, 28501554, 28501556, 28502093, 28502093, 28502122, 28502126, 28502148, 28875759, 28875760, 28989132, 28989141, 28989145, 28989146, 29134713, 34125159, 38970007, 38970041, 28502094, 28502094, 28502113, 28501600, 28502139, 28502676, 28502677, 28502678, 28502678, 28502679, 28502679, 28502681, 28502699, 28502704, 28502705, 28502705, 28502706, 28502733, 28502752, 28502706, 28502706, 28502706, 28502707, 28502707, 28502707, 28502707, 28502708, 28502708, 28502710, 28502727, 28502737, 28502733, 28502733, 28502734, 28502734, 28502781, 28502735, 28502736, 28502736, 28502737, 28502737, 28502738, 28502739, 28502739, 28502740, 28502740, 28502741, 28502741, 28502742, 28502742, 28502743, 28502743, 28502744, 28502744, 28502745, 28502746, 28502746, 28502748, 28502748, 28502750, 28502751, 28502752, 28502753, 28502754, 28502754, 28502755, 28502756, 28502756, 28502757, 28502757, 28502758, 28502758, 28502759, 28502759, 28502760, 28502761, 28502762, 28502762, 28502763, 28502763, 28502773, 28502778, 28502779, 28502779, 28502781, 28502781, 28502737, 28502737, 28502739, 28502739, 28502740, 28502741, 28502742, 28502744, 28502757, 28502759, 28502781, 28502782, 28502737, 28502739, 28502757, 28502760, 28502760, 28502761, 28502740, 28502759, 28502762, 28502740, 28502741, 28502743, 28502743, 28502744, 28502746, 28502755, 28502757, 28502758, 28502758, 28502759, 28502759, 28502760, 28502761, 28502765, 28502783, 28502743, 28502742, 28502743, 28502743, 28502744, 28502744, 28502745, 28502745, 28502746, 28502746, 28502747, 28502747, 28502750, 28502759, 28502759, 28502760, 28502761, 28502761, 28502762, 28502762, 28502763, 28502764, 28502765, 28502766, 28502766, 28502767, 28502768, 28502772, 28502785, 28502743, 28502744, 28502744, 28502745, 28502746, 28502746, 28502747, 28502747, 28502749, 28502759, 28502760, 28502761, 28502762, 28502763, 28502763, 28502764, 28502767, 28502785, 28502744, 28502745, 28502746, 28502746, 28502747, 28502748, 28502758, 28502760, 28502761, 28502763, 28502764, 28502765, 28502785, 28502786, 28502746, 28502747, 28502747, 28502748, 28502750, 28502756, 28502760, 28502761, 28502761, 28502763, 28502764, 28502767, 28502768, 28502786, 28502747, 28502762, 28502787, 28502747, 28502748, 28502762, 28502765, 28502769, 28502787, 28502748, 28502749, 28502749, 28502750, 28502753, 28502762, 28502763, 28502764, 28502765, 28502768, 28502768, 28502769, 28502788, 28502749, 28502750, 28502751, 28502753, 28502760, 28502761, 28502763, 28502763, 28502764, 28502765, 28502765, 28502766, 28502766, 28502767, 28502788, 28502750, 28502751, 28502752, 28502756, 28502761, 28502763, 28502764, 28502764, 28502765, 28502765, 28502766, 28502766, 28502767, 28502769, 28502770, 28502775, 28502783, 28502788, 28502789, 28502756, 28502762, 28502764, 28502765, 28502767, 28502789, 28502760, 28502761, 28502764, 28502765, 28502766, 28502766, 28502767, 28502767, 28502768, 28502790, 28502757, 28502764, 28502765, 28502765, 28502768, 28502771, 28502790, 28502754, 28502765, 28502765, 28502766, 28502768, 28502769, 28502772, 28502791, 28502765, 28502769, 28502773, 28502791, 28502768, 28502766, 28502767, 28502768, 28502770, 28502793, 28502769, 28502769, 28502769, 28502770, 28502794, 28502768, 28502770, 28502771, 28502795, 28502777, 28502795, 28502784, 28502798, 28502775, 28502799, 28502775, 28502777, 28502800, 28502775, 28502775, 28502777, 28502782, 28502800, 28502776, 28502776, 28502794, 28502801, 28502776, 28502778, 28502780, 28502784, 28502801, 28502802, 28502777, 28502778, 28502778, 28502779, 28502780, 28502780, 28502781, 28502781, 28502782, 28502783, 28502783, 28502784, 28502795, 28502800, 28502802, 28989778, 28502778, 28502779, 28502779, 28502780, 28502781, 28502782, 28502783, 28502783, 28502784, 28502784, 28502785, 28502802, 28502803, 28502779, 28502780, 28502780, 28502781, 28502781, 28502782, 28502782, 28502783, 28502784, 28502803, 28502780, 28502781, 28502781, 28502782, 28502783, 28502783, 28502784, 28502785, 28502795, 28502804, 28502782, 28502783, 28502783, 28502784, 28502785, 28502785, 28502786, 28502786, 28502791, 28502803, 28502804, 28502782, 28502783, 28502784, 28502784, 28502785, 28502785, 28502787, 28502805, 29135350, 28502783, 28502784, 28502784, 28502785, 28502786, 28502786, 28502787, 28502787, 28502805, 28502805, 28502784, 28502785, 28502785, 28502786, 28502786, 28502787, 28502787, 28502788, 28502789, 28502793, 28502793, 28502797, 28502798, 28502800, 28502802, 28502802, 28502804, 28502805, 28502806, 28502786, 28502788, 28502806, 28502786, 28502787, 28502787, 28502788, 28502788, 28502789, 28502796, 28502798, 28502807, 28502787, 28502788, 28502788, 28502789, 28502807, 28502807, 28876397, 28502788, 28502789, 28502789, 28502794, 28502800, 28502807, 28502808, 28502789, 28502790, 28502790, 28502794, 28502795, 28502801, 28502806, 28502808, 28502808, 28502790, 28502791, 28502793, 28502797, 28502802, 28502803, 28502805, 28502806, 28502808, 28502809, 28502791, 28502793, 28502796, 28502796, 28502797, 28502806, 28502807, 28502808, 28502809, 28502796, 28502801, 28502805, 28502808, 28502809, 28502810, 29135356, 28502811, 28502812, 28502808, 28502814, 28502808, 28502814, 28502814, 28502813, 28502815, 28502815, 28502816, 28502817, 28502816, 28502818, 28502819, 28502819, 28502820, 28502820, 28502814, 28502821, 28502821, 28502821, 28502822, 28502822, 28502823, 28502824, 28502824, 28502825, 28502824, 28502825, 28502826, 28502826, 28502826, 28502827, 28502828, 28502829, 28502829, 28502830, 28502831, 28502833, 28502837, 28502840, 28502840, 28502841, 28502842, 28502844, 28502845, 28502849, 28502850, 28502852, 28502853, 28502854, 28502855, 28502855, 28502856, 28502856, 28502857, 28620998, 28876418, 28876418, 28876419, 29135372, 29135373, 29231741, 30521724, 30898135, 30908718, 31515956, 31585561, 34125819, 34125820, 35133653, 28502829, 28502830, 28502831, 28502832, 28502834, 28502840, 28502841, 28502842, 28502847, 28502848, 28502849, 28502852, 28502853, 28502854, 28502855, 28502855, 28502856, 28502856, 28502857, 28502857, 28502856, 28502858, 28502857, 28502858, 28502859, 28502857, 28502860, 28502862, 28502863, 28502858, 28502869, 28502869, 28502870, 28502858, 28502868, 28502873, 28502873, 28502874, 28502876, 28502876, 28502878, 28502872, 28502878, 28502879, 28502877, 28502879, 28502880, 28502878, 28502881, 28502882, 28502882, 28502881, 28502882, 28502883, 28502883, 28502884, 28502884, 28502884, 28502884, 28502885, 28502885, 28502886, 28502887, 28596077, 28596078, 28596079, 28612674, 28621027, 28731632, 28771121, 28833590, 28849322, 28849322, 28876445, 28876445, 28876446, 28876446, 28876447, 28876447, 28876448, 28876448, 28891391, 28891392, 28932131, 28932133, 28932134, 28932135, 28989816, 28989817, 28989817, 28989820, 28989820, 28989823, 28989823, 28989824, 28989826, 28989827, 28989827, 28989828, 28989828, 28989829, 28989829, 28989830, 28989832, 28989833, 28989835, 29085815, 29085816, 29085817, 29099506, 29135397, 29135398, 29135399, 29135399, 29135400, 29135400, 29135401, 29135401, 29135402, 29135402, 29231773, 29358770, 29499180, 29499180, 29499181, 29499182, 29499183, 29950325, 30247153, 30518240, 30720845, 31585590, 31585591, 31862431, 32226215, 32367887, 33315522, 33438325, 33438325, 33438326, 33438327, 34125847, 34125847, 34125848, 34125849, 34125849, 34125850, 34125850, 34384890, 35133682, 35133682, 35133683, 35133691, 37733749, 38608689, 38744446, 38970695, 38970695, 39770980, 28876447, 28989817, 29135402, 28771121, 28876449, 29135403, 28689281, 28689281, 28689282, 28689284, 28689284, 28689285, 28689294, 28969651, 28969650, 28984596, 28969652, 28969653, 29228606, 33408726, 33531529, 28969653, 29228608, 28969652, 28722473, 28986246, 28739180, 28739181, 28739183, 28739183, 28994601, 28994602, 28994601, 28994602, 28833344, 28994603, 29107976, 28994605, 28927522, 29088782, 28960388, 29364158, 29039370, 29039370, 29144697, 29049142, 29262968, 29164306, 29207163, 29195771, 29195771, 29222896, 29222896, 29222897, 29250007, 29250008, 29250023, 29250023, 29250008, 29250008, 29250009, 29250022, 29250023, 29250024, 29250024, 29250008, 29250009, 29250009, 29250011, 29250022, 29250023, 29250023, 29250024, 29250025, 29250009, 29250010, 29250011, 29250024, 29250024, 29250025, 29250025, 29250010, 29250024, 29250025, 29250025, 29250026, 29250013, 29250022, 29250023, 29250024, 29250024, 29250025, 29250025, 29250026, 29250026, 29250027, 29250027, 29250028, 29250037, 29250037, 29250038, 29250038, 29250038, 29250039, 29250039, 29459392, 33143438, 34499425, 29250038, 29250039, 29250040, 29305710, 29508976, 29508978, 32765263, 29250039, 29250040, 29250040, 29250044, 29363393, 29363396, 29508977, 29508978, 29872758, 32528470, 33811901, 35507259, 29250040, 29250041, 29250041, 29305710, 29363397, 29363405, 29508975, 29508976, 29508977, 29508979, 30537552, 32407104, 29250041, 29305710, 29305711, 29305711, 29363394, 29363394, 29363395, 29363396, 29363397, 29363398, 29363399, 29363400, 29363401, 29363403, 29363404, 29363406, 29363407, 29363408, 29363408, 29363409, 29363409, 29363411, 29363411, 29363412, 29459394, 29508849, 29508973, 29508976, 29508977, 29508977, 29508978, 29508978, 29508979, 29508979, 29508980, 29605349, 29732329, 29732348, 29732348, 29732360, 29872757, 29872758, 29872759, 31174468, 31264645, 31282324, 31286391, 31824448, 31959168, 32326747, 32741465, 33689101, 33811902, 33852361, 34499425, 34499426, 34499426, 34499427, 35507259, 35507260, 29250043, 29250046, 29264969, 29305711, 29305712, 29338728, 29363394, 29363394, 29363395, 29363395, 29363397, 29363398, 29363398, 29363401, 29363402, 29363402, 29363403, 29363404, 29363405, 29363406, 29363406, 29363408, 29363409, 29363409, 29363410, 29363411, 29363411, 29363412, 29363412, 29459393, 29459394, 29459394, 29459395, 29459396, 29508974, 29508976, 29508977, 29508977, 29508978, 29508978, 29508979, 29508979, 29508980, 29508980, 29605345, 29732321, 29775912, 29872757, 29872758, 30537553, 31249821, 31959168, 32528470, 32741465, 32741465, 33143439, 33764258, 33811903, 34499426, 34499427, 34499427, 34499430, 35507260, 38107327, 29508980, 29363411, 29264974, 29305715, 29508984, 29279911, 29279913, 29279908, 29279909, 29280033, 29280036, 29523921, 33826846, 29378355, 29280161, 29280164, 29524042, 34514493, 29361378, 29361394, 29361391, 29361394, 29361396, 29361395, 29361395, 29361396, 29361397, 29361397, 29361396, 29361397, 29361405, 29419086, 29419090, 29413678, 29419082, 29419086, 29419089, 29564663, 29378743, 29419085, 29564662, 29564663, 29564664, 29564664, 31305505, 29564663, 29564665, 29396087, 32814494, 29427426, 29427427, 29597676, 29597677, 31338519, 29465959, 29471374, 29476761, 29476762, 29476747, 29476755, 29476756, 29476764, 29476750, 29476754, 29476759, 29476762, 29476763, 29476764, 29476764, 29476766, 29476770, 29476771, 29476773, 29476755, 29476764, 29476766, 29476757, 29476782, 29476752, 29476755, 29476756, 29476758, 29476765, 29476766, 29476758, 29476767, 29476784, 29476757, 29476767, 29476768, 29476769, 29476784, 29476784, 29476762, 29476764, 29476786, 29476769, 29476786, 29476763, 29476767, 29476786, 29476787, 29476768, 29476771, 29476773, 29476787, 29476766, 29476771, 29476787, 29476788, 29476766, 29476768, 29476769, 29476774, 29476788, 29476788, 29476772, 29476788, 29476766, 29476767, 29476789, 29476790, 29476790, 29476790, 29476769, 29476791, 29476769, 29476791, 29476791, 29476772, 29476772, 29476773, 29476775, 29476776, 29476791, 29476792, 29476771, 29476772, 29476774, 29476792, 29476792, 29476774, 29476776, 29476793, 29476773, 29476776, 29476793, 29476793, 29476776, 29476777, 29476793, 29476794, 29476775, 29476776, 29476777, 29476794, 29476794, 29476795, 29476778, 29476794, 29476795, 29622346, 29476777, 29476778, 29476779, 29476795, 29476796, 29476778, 29476779, 29476779, 29476780, 29476781, 29476795, 29476796, 29622343, 29476779, 29476780, 29476780, 29476796, 29476796, 29622346, 29476780, 29476781, 29476796, 29476797, 29622349, 34612795, 29476781, 29476783, 29476797, 29476797, 29622349, 29476782, 29476783, 29476797, 29476798, 29476798, 29622350, 29476783, 29476798, 29476798, 29476798, 29476799, 29622349, 29622351, 29476799, 29476800, 29622355, 29986134, 29622355, 29476813, 29476814, 29572780, 29572781, 29622361, 29622362, 29622363, 29622363, 29622364, 29622365, 29622365, 29622366, 29986142, 29986145, 32641856, 34612812, 35620645, 35620646, 29476814, 29543745, 29572780, 29572780, 29572781, 29572782, 29572782, 29573311, 29622235, 29622363, 29622363, 29622364, 29622364, 29622365, 29622365, 29622366, 29622370, 29718736, 29845681, 29845706, 29845718, 29927043, 29986144, 30734117, 31363206, 31395711, 32072554, 32854851, 32854851, 33534631, 33925289, 34612811, 34612812, 34612813, 35620646, 35620646, 29572782, 29622361, 29622364, 29622365, 29622365, 29622366, 29622366, 31399618, 31932918, 38095874, 39457660, 33925290, 29610693, 29689313, 29668760, 29668761, 29668761, 29668762, 29668760, 29668761, 29668761, 29668761, 29668762, 29668763, 29668762, 29668762, 29668763, 29668764, 29718345, 30830096, 35716626, 29718342, 29718345, 29718346, 29718344, 29718346, 29718346, 34708793, 34708794, 29718345, 29718346, 29718344, 29718346, 29718347, 29718347, 34021270, 29679308, 29669822, 29718876, 29689853, 29707729, 29696139, 29732035, 29725601, 29746761, 29767669, 29767668, 29767799, 29767796, 29767911, 29767912, 29767913, 29767929, 29767913, 29767914, 29767913, 29767914, 29767914, 29767915, 29767929, 29767929, 29767930, 29767913, 29767914, 29767915, 29767930, 29767931, 29767913, 29767914, 29767915, 29767915, 29767916, 29767928, 29767930, 29767931, 29767931, 29767914, 29767915, 29767915, 29767916, 29767928, 29767929, 29767929, 29767930, 29767930, 29767932, 29767915, 29767916, 29767918, 29767930, 29767930, 29767931, 29767931, 29767932, 29767932, 29767916, 29767917, 29767930, 29767931, 29767931, 29767932, 29767932, 29767933, 29767917, 29767918, 29767930, 29767931, 29767932, 29767932, 29767933, 29767918, 29767921, 29767929, 29767930, 29767930, 29767931, 29767931, 29767932, 29767932, 29767933, 29767933, 29767934, 29767934, 29767923, 29767931, 29767932, 29767932, 29767933, 29767933, 29767934, 29767934, 29767934, 29767936, 29767941, 29767938, 29767944, 29767945, 29767943, 29767945, 29767946, 34758377, 29767944, 29767946, 29767946, 29767947, 29864301, 29991346, 29767945, 29767946, 29767946, 29767947, 29864301, 34070854, 34758379, 29767946, 29767947, 29767947, 29767948, 30083957, 31616676, 33000417, 34070854, 34758379, 29767947, 29767948, 29767948, 30131712, 30260581, 31508773, 31616676, 32078483, 32218121, 34758379, 34758380, 39376983, 29767948, 29767949, 29767949, 29864303, 29864303, 29991282, 29991287, 29991289, 29991300, 29991307, 29991341, 30034865, 30131709, 30131711, 30131711, 30131712, 30131712, 30131713, 30131713, 30149352, 30495840, 30602650, 30796506, 30951974, 31090426, 31161893, 31203252, 31278226, 31508770, 31508773, 31744103, 31865956, 32666058, 32787424, 32905511, 33000418, 33402391, 33524353, 34070856, 34070856, 34070857, 34758378, 34758378, 34758379, 34758379, 34758380, 34758380, 34758381, 34758383, 35766213, 35766213, 36133400, 39603226, 29767949, 29767952, 29864304, 29991265, 29991275, 29991275, 29991281, 29991283, 29991286, 29991298, 29991308, 29991320, 29991321, 30034866, 30131711, 30131711, 30131712, 30131712, 30131713, 30131714, 30131714, 30582856, 30582857, 30796506, 31034565, 31090427, 31113671, 31154281, 31508774, 31545278, 31616677, 31860879, 32078484, 32083402, 32218122, 32666059, 32787424, 32787424, 33000419, 33174160, 33187652, 33402394, 33409999, 33608812, 33694442, 33948051, 33952244, 34070856, 34070857, 34070857, 34758378, 34758380, 34758380, 34758381, 34758381, 34758382, 34758384, 34758384, 35766213, 35766213, 35766214, 39603227, 39603273, 29841680, 29864304, 29896005, 29959242, 29991267, 29991268, 29991269, 29991280, 29991280, 29991281, 29991282, 29991283, 29991285, 29991288, 29991288, 29991289, 29991305, 29991305, 29991306, 29991310, 29991311, 29991313, 29991344, 30126494, 30131709, 30131710, 30131712, 30131712, 30131713, 30131714, 30131714, 30449235, 30495841, 30582857, 30861818, 31161894, 31433701, 31508771, 31508774, 31616678, 31616770, 31643364, 31768293, 32018361, 32078484, 32078485, 32083403, 32218122, 32218123, 32666054, 32666059, 32787424, 32787424, 32787425, 32792328, 32858746, 33000419, 33665129, 33948052, 34070855, 34070857, 34070857, 34070858, 34758379, 34758380, 34758380, 34758381, 34758381, 34758382, 35243421, 35766213, 35766214, 35766214, 39603227, 33948052, 34070857, 30131717, 29915424, 30065050, 29960666, 29960657, 29960670, 29960671, 29960671, 29960672, 30087649, 30228078, 30228081, 31258261, 30087681, 30087684, 30297377, 32314489, 34854748, 35862580, 35862582, 30024075, 30577305, 30150546, 30263915, 30214594, 30214636, 30214659, 30214642, 30214663, 30214607, 30214669, 30214647, 30214647, 30214640, 30214657, 30214687, 30214656, 30214660, 30214658, 30214627, 30214640, 30214654, 30214656, 30214658, 30214659, 30214662, 30214668, 30214664, 30214664, 30214671, 30214701, 30214680, 30214702, 30214673, 30214675, 30214671, 30214670, 30214678, 30214671, 30214674, 30214675, 30214676, 30214699, 30214666, 30214687, 30214679, 30214679, 30214675, 30214699, 30214684, 30214695, 30214690, 30214693, 30214698, 30214695, 30214713, 30214694, 30214718, 30355084, 35989584, 30214736, 34981752, 30355086, 35989586, 30214737, 30355086, 30214702, 30214702, 30355082, 30214699, 30355085, 34981755, 33128884, 33223794, 34981755, 30214723, 34981756, 31967482, 30214728, 30214709, 30214741, 31840082, 30355088, 35073409, 34294234, 34294237, 30214725, 31961142, 34981760, 31840067, 30355092, 31019887, 34171433, 31840060, 35989596, 30355097, 34981765, 30355097, 30355098, 34981766, 31839864, 30355104, 30214757, 31175369, 30355104, 30214744, 30214759, 31175372, 35989609, 32889453, 30214762, 30348313, 30214765, 30214765, 30355114, 30214767, 30355120, 34294270, 30214779, 30672649, 32441536, 35989628, 30355123, 30355126, 33223834, 34294272, 34981796, 30258282, 30237666, 31732185, 30260620, 30260691, 32912431, 30301796, 30301796, 30301796, 30398643, 30398643, 31775704, 34214983, 30377284, 30377285, 30436386, 36070888, 30399984, 33316443, 30481896, 30488693, 30485073, 35116959, 30495485, 30495484, 30495485, 30495485, 30495474, 30495486, 30495486, 30495473, 30495487, 30495487, 30495488, 30495475, 30495486, 30495487, 30495487, 30495489, 30495476, 30495487, 30495488, 30495489, 30495476, 30495488, 30495490, 30495478, 30495490, 30495492, 30495478, 30495490, 30495491, 30495479, 30495491, 30495490, 30495492, 33364194, 39740751, 30495501, 32287208, 33154150, 33364194, 34434632, 34434632, 35122155, 35122156, 35122156, 30495502, 31160283, 31872550, 31980463, 33848107, 35213807, 30495503, 34434633, 34494508, 35122156, 36129990, 30813012, 30931542, 31160284, 31243462, 31315752, 31356467, 31410051, 31454204, 31518593, 31839430, 31872549, 31980455, 32101545, 32107881, 32132071, 32287210, 32447180, 32554565, 32581899, 33151201, 33151202, 33151203, 33364196, 33364196, 33551429, 34434632, 34434634, 34434634, 34434636, 35122156, 35122156, 35122157, 35122157, 35122158, 35122158, 35122159, 36129990, 36129991, 36129991, 38730058, 39967004, 39967027, 31705475, 30530767, 31692144, 30634145, 35191515, 30753234, 36258866, 31130533, 31264156, 35066858, 35439677, 35439679, 31223747, 31223748, 32236682, 34798764, 31367596, 35558211, 31397780, 31397783, 31397781, 31397783, 32431611, 34885781, 31611433, 34885783, 31676744, 31437370, 32310372, 31825076, 31825077, 31825077, 31825078, 31825079, 31825079, 31825080, 31890390, 34028989, 36794784, 33764953, 35099428, 35682139, 33815997, 35099429, 32796867, 35099430, 35786954, 31955749, 31955749, 31955753, 31955812, 32602706, 34094351, 35164789, 31991432, 33329870, 33777807, 40714975, 32136015, 32136016, 32136018, 32136018, 33850100, 34184460, 35132093, 35254897, 32217442, 32726161, 32301228, 36025043, 32324623, 32895054, 32412980, 32413082, 32413089, 32413180, 32413187, 34323071, 35393508, 36081032, 32459441, 34346189, 32533631, 36141240, 32540623, 32540629, 32540649, 32540651, 32540674, 33604490, 36144748, 32541693, 32820580, 32555851, 32555854, 32813872, 34581609, 34758651, 32638616, 34222787, 32788516, 35458340, 32853522, 33051566, 32915469, 34239832, 32938816, 40761997, 33071898, 35722839, 33098908, 33883608, 33099469, 33099472, 37431981, 34453195, 33183373, 35778577, 33234882, 33400573, 33249595, 33249606, 33249606, 33249607, 33249599, 33249612, 33249612, 33249613, 33249614, 33249614, 33249617, 33249613, 33249613, 33249610, 33249616, 33249614, 34741253, 33249622, 35811692, 34740493, 36756043, 33249628, 33481715, 33958960, 34528262, 35688891, 35811694, 36499218, 33357516, 33758005, 36499219, 33357527, 36499220, 34182428, 35811697, 36499220, 35811698, 36499224, 33279262, 34779881, 33293453, 33980880, 33314620, 33314620, 33991463, 33991464, 35175737, 33322477, 35848148, 33322642, 34777782, 33322758, 36535793, 33465051, 33465278, 33465433, 33465443, 33465508, 33465510, 33465536, 33465584, 33465585, 33465601, 33465611, 33592939, 33617125, 33932234, 34066953, 34391297, 34707573, 34849250, 35251225, 35333166, 35848954, 35919688, 35919690, 36607211, 36607212, 33518794, 35946286, 33566264, 34117285, 33707589, 33707597, 36040683, 36728210, 33713814, 33713899, 33713983, 36731403, 33720274, 33720276, 33720277, 34834912, 34976589, 36734551, 37742384, 33768647, 33768649, 33768650, 36758736, 35000773, 36758735, 36071212, 33953821, 36851320, 33963979, 36856402, 34078927, 34078931, 34373617, 36913877, 34266409, 34266446, 34266485, 34467402, 34266556, 34467437, 34268835, 34268847, 34916534, 37008868, 34389036, 34389033, 34389034, 34389032, 34642527, 36381405, 37068928, 36381406, 34901777, 34398866, 34398867, 34398868, 34398873, 34398985, 34398986, 34398990, 36386322, 38081685, 34399104, 34399104, 34399111, 35316001, 36386439, 37073965, 34529096, 34598701, 34613638, 36493706, 34668295, 34668305, 34668305, 34755495, 35029622, 35041408, 35116242, 35237607, 35242511, 35355694, 35355694, 35450602, 35450602, 35852574, 36049867, 36521039, 36521040, 37208562, 37208563, 37208563, 37208564, 37208564, 37208565, 37300214, 37339742, 37693604, 38207929, 38216397, 38216397, 38713022, 39040026, 39320209, 42053410, 42053456, 42053456, 34842687, 36061391, 34896022, 35230101, 35115242, 36744510, 35222036, 35393131, 35317051, 35317166, 35317287, 37533087, 35390939, 35598925, 35403467, 37576146, 35414512, 35414513, 35682030, 38589501, 35564177, 35564179, 35564182, 35564181, 35564182, 35564182, 37656500, 37656502, 38664335, 35647850, 35685547, 35898541, 35898542, 36300515, 36308124, 36968979, 37656502, 37656503, 38664336, 38664337, 37656504, 35704830, 37039305, 35731543, 35731587, 37052679, 35806913, 35806913, 35806914, 35806912, 35806913, 35806914, 35806915, 35806914, 35806915, 35806915, 35806916, 36207139, 37090345, 37777869, 37777870, 36019908, 36421882, 35925000, 36019908, 36019909, 36421882, 36598322, 36967543, 37090346, 37777869, 37777870, 37777870, 38785704, 35812812, 35927947, 35816718, 37095245, 38790604, 35949553, 35949553, 35949557, 35949560, 37161667, 37161668, 37849191, 42467784, 38857028, 36043083, 36043083, 36043084, 36043073, 36043085, 36137229, 36137229, 36137993, 37895954, 37895954, 36231373, 36231373, 36231376, 37990096, 37990098, 36232139, 36232901, 36232901, 36232902, 36232903, 36232903, 36232900, 36232901, 36232901, 36232902, 36232902, 36232903, 36232903, 36232904, 36232904, 36232905, 36232904, 36232904, 36324491, 37303338, 36232916, 36634875, 37160602, 37303339, 37303339, 37303340, 37990862, 37990862, 37990863, 36634878, 36642484, 36897613, 37303340, 37990860, 37990862, 37990863, 37990864, 37990864, 38998698, 39230167, 37303341, 37990865, 36634876, 37008694, 37618042, 37990864, 37990865, 36579563, 36584153, 36634876, 36634877, 36634880, 37303341, 37990865, 37990865, 37990866, 38998698, 38998699, 38998699, 37374261, 38998699, 36280502, 36280504, 38014663, 37327141, 36416082, 37394929, 36580387, 37477083, 36607368, 36607370, 36607372, 36822107, 37490572, 37490574, 38178099, 36926279, 36926364, 36926446, 37650140, 36935402, 38342114, 36961461, 37667628, 37036848, 37036849, 37036850, 37036850, 37036849, 37036851, 37036853, 37036854, 37036854, 37036853, 37036854, 37036854, 37705313, 37299586, 38392837, 37299586, 37705315, 37705316, 38392839, 38392839, 38392840, 39400672, 37705316, 39400672, 37582510, 38392840, 38392840, 37052062, 37052064, 37052065, 37712920, 38400442, 38400443, 37200729, 37200732, 37787254, 38474778, 37280084, 37280094, 37684197, 37280774, 37356105, 37389761, 38569309, 37431430, 37431431, 38485314, 38590126, 37449690, 39607091, 37562318, 37562320, 37562321, 37968047, 38655572, 40030592, 38655572, 37592463, 39678478, 37620962, 37997376, 37784482, 38766652, 38088303, 38088307, 38231040, 38231044, 38128168, 38128169, 38128169, 38128155, 38128169, 38128170, 38128171, 38128170, 38128171, 38128172, 38128174, 38128185, 38250975, 38938497, 38938499, 39946332, 38250975, 38250975, 38938498, 38938499, 38938500, 39810601, 38136551, 38255164, 38232315, 38828914, 38278490, 39013659, 38373775, 38373762, 38373777, 38373780, 38373778, 38373764, 38373765, 38373766, 38373766, 38373777, 38373778, 38373778, 38373779, 38373779, 38373780, 38373780, 38373781, 38373781, 38373782, 38373784, 38373766, 38373778, 38373778, 38373779, 38373779, 38373780, 38373780, 38373781, 38373781, 38373779, 38373780, 38373781, 38373781, 38373782, 38373782, 38373768, 38373780, 38373780, 38373782, 38373779, 38373783, 38373783, 38373780, 38373783, 39061301, 38373791, 38373794, 38402548, 39061301, 39061301, 40069134, 38373793, 38373794, 39061300, 39061301, 39061302, 39061302, 38373794, 39061301, 39061303, 40069135, 41138742, 38373794, 38373795, 38373795, 38373796, 38373797, 38688481, 39061302, 39061302, 39061303, 39061303, 39061304, 39061304, 39152953, 40069135, 40069136, 38373795, 38373796, 38373797, 38579605, 39061301, 39061302, 39061302, 39061303, 39061304, 40069136, 40069136, 40069137, 40069143, 43906150, 38373796, 38373797, 38373798, 38444699, 38516470, 38688482, 38688483, 38814388, 39061302, 39061303, 39061303, 39061304, 39061304, 39061305, 39061306, 39845387, 40069135, 40069136, 40069137, 40069138, 43367363, 38373797, 38373798, 38373799, 38414239, 38688484, 38893157, 39061302, 39061303, 39061303, 39061304, 39061304, 39061305, 39061305, 39061306, 39258319, 40069137, 38373798, 38421544, 38688481, 38884109, 38893157, 39061303, 39061303, 39061304, 39061305, 39061305, 39061306, 39152955, 40069138, 40069138, 43679693, 43906151, 39061305, 40069138, 40069139, 40069146, 38433697, 38514799, 39061304, 39061306, 40069138, 40069138, 39061307, 38431315, 38431410, 38431505, 39090163, 38454694, 38454695, 39101757, 39101759, 38469341, 38469400, 38469482, 39109184, 38493589, 38493670, 38493791, 38493832, 38493972, 39121419, 40129253, 38515611, 38515612, 38515680, 38515681, 38515749, 38515749, 39132285, 38655862, 39145220, 38659157, 39203990, 38785430, 40274961, 39003179, 39003183, 39003183, 39003184, 39003185, 39003187, 39376003, 40383838, 39376004, 39376006, 39376006, 39376007, 39255045, 39255127, 39255220, 39502053, 39394434, 39571629, 39412530, 39412531, 39580677, 39580678, 39425555, 39425635, 39425724, 39587302, 39539197, 39539198, 39644010, 39644011, 39634540, 39634612, 39634681, 39691757, 39748806, 39748808, 39748808, 39748809, 39748809, 39748810, 39748811, 39748811, 39748823, 39748824, 39748824, 39748825, 39748827, 39748809, 39748810, 39748810, 39748811, 39748811, 39748821, 39748823, 39748824, 39748824, 39748828, 39748810, 39748811, 39748811, 39748812, 39748820, 39748825, 39748811, 39748812, 39748812, 39748813, 39748813, 39748814, 39748824, 39748825, 39748826, 39748826, 39748827, 39748827, 39748828, 39748812, 39748813, 39748813, 39748814, 39748814, 39748815, 39748815, 39748816, 39748825, 39748826, 39748826, 39748827, 39748827, 39748828, 39748828, 39748829, 39748830, 39748813, 39748814, 39748814, 39748815, 39748815, 39748816, 39748825, 39748826, 39748826, 39748827, 39748827, 39748828, 39748828, 39748829, 39748829, 39748814, 39748815, 39748815, 39748816, 39748816, 39748826, 39748827, 39748827, 39748828, 39748828, 39748829, 39748829, 39748830, 39748830, 39748831, 39748816, 39748817, 39748826, 39748827, 39748827, 39748828, 39748828, 39748829, 39748829, 39748830, 39748830, 39748831, 39748816, 39748817, 39748828, 39748829, 39748829, 39748830, 39748831, 39748817, 39748828, 39748828, 39748829, 39748829, 39748830, 39748831, 39748828, 39748829, 39748829, 39748830, 39748830, 39748831, 39748829, 39748831, 39748831, 39748837, 39748832, 39748833, 39748834, 39748837, 39748838, 39748839, 39748839, 39748841, 40756657, 39748839, 39748840, 39748841, 39748842, 40106187, 40756657, 39748840, 39748841, 39748841, 39748842, 39748843, 40233869, 40756659, 39748841, 39748842, 39748842, 39748843, 39748844, 39880005, 40756654, 40756658, 40756658, 40756659, 40756660, 44593673, 39748842, 39748843, 39748843, 39748844, 40756659, 40756660, 40756660, 40756661, 44367464, 44593673, 39748843, 39748844, 39748844, 39748845, 39748845, 39748846, 39840478, 39880006, 40086720, 40126579, 40126580, 40233868, 40366916, 40393407, 40393410, 40748191, 40756657, 40756658, 40756659, 40756659, 40756660, 40756660, 40756661, 40756661, 40756662, 40756664, 40756668, 40756670, 41123848, 41868576, 42194380, 42237367, 43356728, 43356729, 44069545, 44367426, 44367426, 44593674, 44593720, 39748844, 39748845, 39748845, 39748846, 39748846, 39752006, 39832864, 39880007, 39906106, 40083528, 40126580, 40756660, 40756661, 40756661, 40756662, 41025726, 43356728, 43656551, 44593674, 39748845, 39748846, 39748846, 39752007, 39906106, 40086719, 40233868, 40756660, 40756661, 40756661, 40756662, 40756662, 40756671, 41868577, 43356729, 44593675, 39748846, 39752007, 39773871, 39911279, 40126581, 40233868, 40358068, 40756660, 40756661, 40756661, 40756662, 40756662, 40756663, 40756664, 39748847, 39748848, 39840480, 39880008, 40007867, 40007870, 40157720, 40157801, 40393408, 40748193, 40756659, 40756662, 40756662, 40756663, 40756663, 40756664, 39752008, 40358069, 40756661, 40756662, 40756663, 40756663, 40756664, 44593676, 40756663, 40756664, 40756664, 40756667, 39755183, 39755184, 39883183, 40759837, 40759838, 39798911, 40781701, 39916897, 40840695, 39932125, 39932125, 40848307, 40848308, 41917914, 40848307, 40848308, 40011180, 40139042, 40887834, 41255021, 41999749, 40063379, 40550681, 40913933, 40073724, 43519175, 40142858, 40953676, 40262472, 41013480, 40266904, 40266908, 40266908, 41015700, 41015698, 41015699, 41015700, 41015700, 40418270, 41091402, 40424609, 40424609, 41094547, 41094551, 40463546, 40724272, 40504328, 40504328, 41134407, 41134408, 41134408, 41134409, 41134409, 44745172, 40566609, 40566672, 40566747, 40566765, 40566893, 40897749, 40567021, 41165754, 40718906, 40718907, 40718908, 40718908, 40718897, 40718910, 40718909, 40718920, 41241699, 41053319, 41241700, 41241701, 41241707, 41241701, 40967310, 41365904, 41365904, 40985000, 40985000, 41295071, 41374744, 41037985, 41037986, 41037987, 41037991, 41401239, 41401240, 41401241, 41401241, 41228740, 41496618, 41316993, 41540743, 41387733, 41576114, 41493032, 41628763, 41605142, 41676348, 41747553, 41747554, 41747554, 41756021, 41756022, 42859835, 41764473, 41764475, 41764474, 41764475, 41764475, 41764477, 41764475, 41764476, 41764477, 41764481, 41764497, 41764476, 41764477, 41764477, 41764492, 41764477, 41764478, 41764478, 41764482, 41764483, 41764485, 41764487, 41764492, 41764493, 41764493, 41764495, 41764495, 41764478, 41764479, 41764479, 41764482, 41764484, 41764486, 41764487, 41764488, 41764490, 41764491, 41764492, 41764493, 41764493, 41764494, 41764494, 41764495, 41764495, 41764496, 41764496, 41764497, 41764497, 41764479, 41764480, 41764480, 41764481, 41764483, 41764484, 41764485, 41764486, 41764486, 41764487, 41764488, 41764488, 41764490, 41764490, 41764491, 41764492, 41764492, 41764493, 41764493, 41764494, 41764494, 41764495, 41764495, 41764496, 41764496, 41764497, 41764497, 41764499, 41764480, 41764481, 41764481, 41764482, 41764482, 41764483, 41764484, 41764484, 41764485, 41764485, 41764486, 41764486, 41764487, 41764487, 41764488, 41764488, 41764489, 41764491, 41764492, 41764492, 41764493, 41764493, 41764494, 41764494, 41764495, 41764495, 41764496, 41764496, 41764497, 41764499, 41764499, 41764501, 41764502, 41764481, 41764484, 41764486, 41764488, 41764489, 41764491, 41764494, 41764495, 41764496, 41764496, 41764500, 41764484, 41764487, 41764489, 41764492, 41764496, 41764496, 41764504, 41764487, 41764487, 41764487, 41764497, 41764498, 41764498, 41764499, 41764498, 41764506, 41764488, 41764491, 41764496, 41764497, 41764498, 41764489, 41764499, 41764507, 41764498, 41764499, 41764490, 41764491, 41764492, 41764493, 41764499, 41764500, 41764491, 41764492, 41764492, 41764493, 41764494, 41764495, 41764500, 41764501, 41764501, 41764492, 41764493, 41764493, 41764495, 41764496, 41764500, 41764500, 41764501, 41764501, 41764502, 41764510, 41764493, 41764494, 41764495, 41764495, 41764501, 41764501, 41764502, 41764510, 41764494, 41764495, 41764496, 41764501, 41764502, 41764502, 41764511, 41764495, 41764496, 41764500, 41764501, 41764502, 41764503, 41764503, 41764496, 41764497, 41764497, 41764502, 41764502, 41764503, 41764506, 41764512, 41764497, 41764502, 41764502, 41764503, 41764503, 41764504, 41764505, 41764512, 41764512, 41764499, 41764503, 41764503, 41764504, 41764505, 41764513, 41764504, 41764501, 41764505, 41764505, 41764507, 45601503, 41764504, 41764506, 41764506, 41764511, 41764507, 41764507, 42489150, 41764505, 41764507, 41764507, 41764508, 41764509, 41764517, 42868304, 45601505, 41764507, 41764508, 41764508, 41764509, 41764510, 41764512, 41764507, 41764508, 41764508, 41764509, 41764517, 45375262, 45601506, 41764508, 41764509, 41764509, 41764510, 41764510, 41764511, 41764512, 41764517, 41764518, 41764518, 42131680, 44364560, 44364563, 45375260, 45601506, 45601506, 41764509, 41764510, 41764510, 41764511, 41764511, 41764512, 41764512, 41764516, 41764517, 41783270, 42131681, 42876409, 43202212, 43245202, 43627247, 44158455, 44364561, 45077378, 45601507, 41764510, 41764511, 41764511, 41764512, 41764512, 41764513, 41764513, 41764514, 41764515, 41764518, 41764519, 41764519, 41802679, 42131681, 42131683, 42698628, 42698629, 42823277, 42834100, 42868307, 42876409, 43202213, 43202215, 43675820, 43804686, 44364561, 44364562, 44364563, 45375168, 45375254, 45375257, 45375258, 45375298, 45601507, 41764511, 41764512, 41764512, 41764513, 41764513, 41764514, 41764514, 41764515, 41764515, 41764516, 41764518, 41764518, 41764519, 41764519, 41764520, 41764520, 41802641, 41875316, 42033558, 42131682, 42555531, 42834101, 42876410, 43336676, 43336676, 44158455, 44158455, 44239717, 44239722, 44239725, 44364562, 44364563, 44364564, 44985869, 45077377, 45239501, 45375260, 45375260, 45375261, 45375272, 45375274, 45375298, 45375299, 45601508, 41764512, 41764513, 41764513, 41764514, 41764514, 41764515, 41764515, 41764516, 41764518, 41764519, 41764520, 41897121, 41995966, 42131682, 42131684, 42135277, 42823278, 42868308, 43046350, 44158456, 44158457, 44180715, 44364562, 44364564, 45174839, 45239502, 45375050, 45375260, 45375261, 45601508, 45601508, 41764513, 41764514, 41764514, 41764515, 41764515, 41764516, 41764516, 41764519, 41764520, 41764520, 41764521, 42131683, 42698631, 42823278, 42834102, 43202214, 43777100, 44364563, 45004640, 45174840, 45375255, 45375259, 45375262, 45601509, 41764514, 41764515, 41764515, 41764516, 41764516, 41764517, 41764517, 41764520, 41764520, 41764521, 42834102, 44158458, 44239723, 44364563, 44664385, 45375262, 45375263, 45601509, 45601509, 41764515, 41764516, 41764516, 41764517, 41764517, 41764518, 41764518, 41764520, 41764520, 41764521, 41764521, 42131684, 42796636, 42834102, 42834103, 42868309, 42876412, 44364564, 44364565, 44664386, 45375262, 45375301, 45601510, 41764516, 41764517, 41764517, 41764518, 41764518, 41764519, 41764520, 41764520, 41764521, 41764521, 41764522, 41764522, 41764523, 42131684, 42876412, 43202220, 43513693, 44158458, 44158458, 44364564, 45375260, 45601510, 41764517, 41764518, 41764518, 41764520, 41764521, 41764521, 41764522, 41793496, 41995968, 42131685, 43437956, 43550008, 44364564, 45239504, 45375257, 45601511, 41764518, 41764519, 41764519, 41764520, 41764520, 41764521, 41764521, 41764522, 41764523, 41764523, 41997256, 42834104, 43202220, 44364565, 45601511, 41764519, 41764520, 41764520, 41764521, 41764521, 41764522, 41764522, 41764523, 41793497, 41875323, 42821307, 42868311, 43202217, 43202218, 43562066, 44364566, 45375260, 45601511, 45601512, 41764520, 41764521, 41764521, 41764522, 41764522, 41764523, 41764524, 41764525, 42698634, 42726407, 42868312, 44364566, 45375112, 45375262, 45601512, 41764521, 41764522, 41764523, 41764523, 44158460, 45375263, 45601513, 41764523, 41764524, 42131687, 44158461, 44364568, 45601513, 41764524, 41764524, 42131688, 43777105, 41764525, 41764526, 44364568, 45601514, 41764525, 41764526, 41764526, 44364569, 44664390, 44664390, 45601515, 41764526, 41764527, 41764527, 41875326, 42131687, 42131689, 42698637, 42823285, 43336685, 44004086, 44158463, 44364569, 44364571, 44364572, 45062729, 45174849, 45375262, 45375265, 45375265, 45601515, 41764527, 41764528, 41875327, 42131690, 44364570, 44364571, 45375266, 45375306, 45601516, 41764528, 41764529, 41793501, 41960052, 41995973, 42131690, 42131691, 42823286, 42834109, 42873513, 42876418, 43148729, 43190077, 43202222, 43562122, 43718899, 43777014, 43777107, 43785121, 44239730, 44364570, 44664391, 44985873, 45077386, 45375265, 45375267, 45375269, 45375270, 45375282, 45375283, 45601516, 45601516, 41764529, 42033569, 42131691, 42876419, 43312276, 43926637, 44158464, 44364571, 44364572, 45375265, 45375269, 45375313, 45377291, 45601517, 42131691, 44158465, 44364571, 44364572, 45601517, 41802041, 44383332, 41822505, 41835796, 43231229, 44393575, 41840848, 41840917, 41840954, 41841060, 41840993, 41841066, 45277812, 45213153, 41849072, 44406850, 41986137, 41986139, 43313037, 43380476, 44475383, 45486076, 45712328, 42029742, 44497183, 42155588, 42894174, 42227431, 42227432, 42227434, 42227429, 42227432, 42227520, 43380187, 44596028, 44596031, 45832975, 45606727, 42227610, 44596116, 42230010, 42958793, 42302620, 42302621, 43145471, 44046160, 44674484, 42498864, 42498865, 42498866, 42498866, 42498868, 42498868, 42498867, 42498868, 42498879, 43243593, 44293812, 44731745, 44144283, 44606906, 44690131, 44731746, 45742442, 45742480, 45968692, 42508144, 43201285, 43243594, 43569398, 43569405, 43612384, 43805142, 44144281, 44144283, 44731746, 44731748, 45742442, 45968692, 45968692, 43569399, 43805142, 44731748, 45742457, 45968694, 42506117, 45972349, 42517423, 43578677, 42757739, 43373029, 43213810, 46326164, 43346605, 43973393, 43411748, 43700034, 43632760, 43632761, 43632764, 43810541, 44210338, 45298693, 46535638, 46535639, 46535642, 43687616, 43687680, 45326151, 43688370, 46563475, 43828769, 44835512, 43878108, 45057561, 43882057, 43882057, 43882059, 45423341, 44260996, 45423342, 46434052, 43935191, 43903703, 43903703, 43903704, 43903704, 43903705, 43903705, 45434164, 43937910, 44271817, 45434165, 45434166, 46671111, 43937911, 46671111, 46671112, 43972113, 43980216, 44802203, 45468370, 46705314, 46705360, 46705360, 43982512, 45473569, 43988318, 43988319, 43988320, 43988328, 43988330, 43988331, 43988331, 43988328, 43988329, 43988330, 44673508, 44889008, 45351629, 45351631, 45476471, 45476473, 46487109, 46487166, 46487170, 46713416, 46713417, 46713463, 43988330, 43988331, 45292604, 45476474, 46713418, 46713464, 46713418, 46487176, 45476483, 44260641, 44260642, 44328234, 46657143, 44532941, 44696479, 45748783, 46759478, 44600151, 44890701, 44615638, 46196559, 44639934, 44639932, 44639933, 44639934, 44639937, 44639934, 44639935, 44639935, 44639937, 44639938, 44639937, 44639938, 44639939, 44639940, 44639942, 47039227, 46812980, 46500443, 45530392, 45802283, 46102106, 46677250, 46812977, 47039229, 45214821, 47039230, 45802284, 45596179, 44725907, 44725904, 44725910, 47082210, 45845271, 47082215, 44774812, 47106664, 44787914, 44977548, 44860007, 44860040, 44860023, 44860048, 45912342, 47149288, 44908856, 44908857, 44908858, 45936742, 45936743, 45111413, 45111416, 45111418, 46038022, 47274968, 45167184, 45478441, 45181256, 45605471, 45262887, 46113759, 45335528, 47387031, 45358696, 46202520, 45359643, 45359719, 45359741, 45359795, 46162189, 45724285, 45490017, 46227333, 45587173, 47286614, 45632297, 45860528, 45673303, 46318974, 45789509, 45789603, 45789698, 45789699, 45789699, 45789700, 45789703, 46180334, 46021692, 46377162, 46377163, 46377164, 47387856, 47387858, 47387861, 47614108, 47387868, 47614109, 47387903, 45805741, 46385190, 45842269, 46403454, 45844874, 46404749, 46029726, 46389145, 46088755, 46526689, 47763635, 47763681, 46237077, 46237198, 46237319, 47611699, 46243678, 46243710, 47614858, 46253684, 46609154, 46420842, 47703432, 46552414, 46552412, 46552413, 46552413, 46552414, 46552415, 46552412, 46552413, 46552413, 46552414, 46552414, 47769118, 46758519, 47769260, 46758519, 46758521, 47769007, 46758520, 46758522, 47798710, 47995465, 46758520, 47058343, 46758521, 46758521, 46570968, 46767796, 46596888, 46596909, 46596943, 46596943, 48017736, 46780790, 46714942, 46714946, 46714948, 46714948, 46714951, 47850490, 46839789, 47850484, 47850491, 48076734, 48076779, 47850523, 48076734, 46748533, 47199296, 46881387, 46881461, 46881536, 46923077, 46964613, 46964613, 46964614, 46964614, 46964615, 46964615, 46964616, 46964624, 46964625, 46964625, 46964626, 46964626, 46964627, 46964627, 46964628, 46964628, 46964629, 46964629, 46964631, 46964615, 46964625, 46964628, 46964615, 46964616, 46964616, 46964625, 46964626, 46964626, 46964627, 46964627, 46964629, 46964629, 46964630, 46964630, 46964631, 46964626, 46964628, 46964629, 46964630, 46964631, 46964628, 46964628, 46964630, 46964630, 46964631, 46964632, 46964628, 46964629, 46964630, 46964631, 46964628, 46964632, 46964639, 48201570, 46964638, 46964639, 46964640, 46964640, 46964641, 48201571, 46964640, 46964641, 48201571, 46964641, 46964642, 46964643, 47774906, 47975320, 48201571, 48201572, 46964641, 46964642, 47264449, 48201572, 46964641, 46964642, 47975323, 47975326, 48201573, 46964644, 48201573, 48201573, 46964643, 46964644, 46964644, 46964645, 47005489, 47084014, 47251121, 47264449, 47264451, 47774905, 47774906, 47975115, 47975321, 47975322, 47975323, 47975324, 47975324, 47975327, 47975362, 47975365, 48201573, 48201574, 48201620, 46964644, 46964645, 46964645, 46964648, 47047061, 47264447, 47585931, 47774906, 47774906, 47774908, 47839585, 47940564, 47975174, 47975322, 47975323, 47975324, 47975325, 47975325, 47975326, 47975326, 47975327, 47975327, 47975328, 47975338, 47975358, 47975361, 47975365, 47975365, 48110623, 48201574, 48201574, 48201621, 46964645, 46964646, 47264452, 47677446, 47975175, 47975238, 47975323, 47975324, 47975325, 47975325, 47975326, 47975327, 47975327, 47975328, 48033015, 48201575, 46964647, 47264452, 48201575, 48201575, 47511691, 47975329, 48201575, 48201576, 48201576, 47975365, 48201577, 48201579, 47046345, 47815765, 48242430, 48242477, 47129495, 47373726, 47203400, 48320960, 47537611, 47560801, 47564252, 47564268, 47564269, 47564270, 47564271, 47564276, 47564271, 47564271, 47564275, 47564271, 47564272, 48275145, 47564285, 48074729, 48275145, 48275146, 48275147, 48275185, 48501394, 48501395, 48501395, 48501396, 48501399, 48501400, 47583990, 47987123, 47617955, 48301984, 47650062, 48544304, 47777482, 48608000, 48058747, 48522380, 48207240, 48207245, 48207245, 48596635, 48822884, 48822888, 48244780, 48841648, 48360942, 48360943, 48360949, 48537723, 48899729, 48899734, 48390258, 48390259, 48390258, 48390260, 48487719, 48487720, 48688136, 48688138, 48914389, 48914389, 48585182, 48585183, 48585182, 48585183, 48585190, 48585183, 48585188, 48585188, 48585191, 48585186, 48638572, 48785599, 48785604, 48785642, 49011851, 49011851, 49011898, 48785605, 48785614, 49011854, 48785605, 49011858, 48691960, 49065238, 48714519, 48714520, 48714536, 48714568, 48714595, 48714612, 48714596, 48714591, 48714618, 48714669, 48714670, 48714671, 48850174, 48714687, 48714697, 48850351, 49076601, 49076601, 48850355, 48916496, 48951254, 48985613, 48985632, 48985633, 48985653, 49212072, 49212090, 49212091, 48985780, 49212112, 48985836, 48985843, 48985848, 48985934, 49212180, 49121230, 49212182, 48985932, 48985901, 49212255, 48986000, 48986004, 48986019, 48986024, 48986025, 48986001, 48986001, 48986021, 48986024, 48986027, 48986005, 48986005, 48986024, 48986025, 48986025, 48986030, 48986003, 48986005, 48986024, 48986025, 48986003, 48986006, 48986018, 48986023, 48986024, 48986006, 48986013, 48986019, 48986020, 48986022, 48986023, 48986026, 48986027, 48986032, 48986007, 48986012, 48986024, 48986024, 48986025, 48986026, 48986029, 48986029, 48986031, 48986032, 48986008, 48986008, 48986020, 48986023, 48986023, 48986026, 48986027, 48986028, 48986029, 48986030, 48986030, 48986031, 48986009, 48986030, 48986009, 48986009, 48986016, 48986027, 48986033, 48986009, 48986025, 48986026, 48986026, 48986027, 48986029, 48986030, 48986032, 48986034, 48986034, 48986010, 48986011, 48986023, 48986025, 48986025, 48986027, 48986028, 48986029, 48986029, 48986030, 48986030, 48986034, 48986035, 48986011, 48986026, 48986027, 48986028, 48986033, 48986033, 48986035, 48986026, 48986030, 48986030, 48986032, 48986033, 48986034, 48986034, 48986035, 48986035, 48986036, 48986035, 48986043, 48986028, 48986042, 48986044, 48986044, 48986032, 48986045, 48986039, 48986046, 48986049, 48986049, 48986049, 48986046, 48986050, 49212269, 49212269, 49212270, 48986043, 48986052, 48986054, 49212271, 48986053, 48986041, 48986048, 49212272, 48986045, 48986048, 49212273, 48986050, 48986044, 48986046, 49015420, 49212274, 48986045, 48986046, 49212274, 48986050, 48986051, 49212275, 48986048, 48986049, 49212275, 49212275, 48986065, 48986067, 49212276, 48986052, 49212276, 49212276, 48986053, 48986057, 49212020, 49212277, 48986057, 48986068, 49212277, 48986051, 49212278, 48986069, 49212278, 48986060, 49212279, 48986069, 49212279, 48986055, 48986071, 49212280, 48986057, 48986058, 49212280, 49212327, 48986058, 49212280, 49212281, 48986059, 48986072, 49212281, 49212281, 48986059, 48986063, 49212282, 48986068, 49121330, 49212282, 49212282, 49212329, 49212283, 49212329, 49212284, 49212285, 48986067, 48986076, 49212285, 49212285, 49212286, 49212286, 49212286, 49212287, 48986098, 49212288, 48986099, 48986097, 48986101, 48986102, 48986103, 48986103, 48986103, 48986104, 48986104, 48986105, 48986102, 48986102, 48986105, 48986105, 48986106, 48986112, 48986113, 49212311, 49212311, 49212313, 49212313, 49212314, 49212314, 49212314, 49212361, 49212314, 49212315, 49212316, 48990092, 49214318, 49044827, 49241681, 49045003, 49241759, 49101396, 49269955, 49256612, 49256614, 49347565, 49347565, 49438064, 49438321, 49438504, 49438505, 49438506, 49438506, 49438507, 49438507, 49438508, 49438509, 49438511, 49438512, 49438513, 49438513, 49438515, 49438516, 49438519, 49438520, 49438522, 49438524, 49438526, 49438526, 49438527, 49438528, 49438528, 49438530, 49438531, 49438532, 49438532, 49438534, 49438536, 49438537, 49438537, 49438540, 49438542, 49438542, 49438543, 49438544, 49438545, 49438545, 49438547, 49438548, 49438548, 49438549, 49438549, 49438550, 49438550, 49438551, 49438551, 49438506, 49438507, 49438507, 49438508, 49438509, 49438514, 49438515, 49438518, 49438524, 49438526, 49438527, 49438528, 49438532, 49438534, 49438536, 49438539, 49438541, 49438542, 49438542, 49438546, 49438548, 49438548, 49438549, 49438549, 49438550, 49438550, 49438551, 49438551, 49438552, 49438507, 49438508, 49438509, 49438509, 49438514, 49438518, 49438527, 49438527, 49438528, 49438528, 49438538, 49438543, 49438549, 49438550, 49438551, 49438552, 49438552, 49438534, 49438539, 49438542, 49438551, 49438552, 49438552, 49438509, 49438510, 49438511, 49438514, 49438520, 49438521, 49438528, 49438534, 49438544, 49438551, 49438552, 49438552, 49438553, 49438511, 49438516, 49438526, 49438553, 49438553, 49438516, 49438512, 49438517, 49438518, 49438519, 49438521, 49438521, 49438530, 49438531, 49438539, 49438545, 49438549, 49438552, 49438553, 49438554, 49438554, 49438554, 49438555, 49438542, 49438533, 49438548, 49438558, 49438559, 49438524, 49438528, 49438528, 49438534, 49438534, 49438535, 49438538, 49438540, 49438541, 49438546, 49438547, 49438548, 49438550, 49438551, 49438557, 49438558, 49438559, 49438559, 49438548, 49438560, 49438561, 49438561, 49438527, 49438549, 49438561, 49438561, 49438562, 49438563, 49438538, 49438549, 49438554, 49438559, 49438562, 49438539, 49438555, 49438564, 49438561, 49438565, 49438565, 49438565, 49438568, 49438545, 49438547, 49438569, 49438570, 49438568, 49438547, 49438549, 49438549, 49438553, 49438560, 49438563, 49438565, 49438568, 49438571, 49438571, 49438572, 49438572, 49438550, 49438553, 49438563, 49438571, 49438572, 49438572, 49438564, 49438559, 49438572, 49438573, 49438573, 49438574, 49438554, 49438573, 49438574, 49438562, 49438574, 49438574, 49438575, 49438574, 49438576, 49438559, 49438574, 49438575, 49438577, 49438563, 49438564, 49438567, 49438571, 49438577, 49438578, 49438578, 49438569, 49438579, 49438578, 49438579, 49438579, 49438580, 49438580, 49438571, 49438574, 49438575, 49438582, 49438572, 49438582, 49438583, 49438572, 49438576, 49438583, 49438584, 49438573, 49438583, 49438584, 49438582, 49438584, 49438584, 49438614, 49438580, 49438581, 49438583, 49438585, 49438585, 49438586, 49438576, 49438586, 49438586, 49438586, 49438587, 49438586, 49438587, 49438588, 49438584, 49438587, 49438589, 49438583, 49438586, 49438590, 49438589, 49438590, 49438590, 49438590, 49438591, 49438591, 49438591, 49438591, 49438592, 49438589, 49438592, 49438593, 49438593, 49438592, 49438593, 49438593, 49438591, 49438593, 49438593, 49438594, 49438593, 49438594, 49438594, 49438595, 49438594, 49438594, 49438595, 49438595, 49438595, 49438595, 49438595, 49438596, 49438596, 49438596, 49438597, 49438597, 49438598, 49438599, 49438599, 49438600, 49438600, 49438601, 49438601, 49438602, 49438603, 49438604, 49438610, 49438616, 49438624, 49438626, 49438627, 49438599, 49438600, 49438600, 49438601, 49438601, 49438602, 49438602, 49438603, 49438608, 49438600, 49438601, 49438601, 49438602, 49438602, 49438603, 49438601, 49438602, 49438602, 49438603, 49438603, 49438611, 49438626, 49438602, 49438603, 49438603, 49438604, 49438607, 49438603, 49438604, 49438604, 49438605, 49438604, 49438605, 49438606, 49438612, 49438605, 49438606, 49438606, 49438608, 49438609, 49438623, 49438630, 49438606, 49438607, 49438607, 49438608, 49438608, 49438609, 49438611, 49438612, 49438612, 49438613, 49438623, 49438607, 49438609, 49438613, 49438608, 49438609, 49438609, 49438610, 49438610, 49438612, 49438612, 49438620, 49438624, 49438627, 49438630, 49438631, 49438609, 49438610, 49438610, 49438611, 49438610, 49438611, 49438611, 49438612, 49438613, 49438614, 49438616, 49438616, 49438618, 49438626, 49438629, 49438631, 49438612, 49438613, 49438613, 49438614, 49438614, 49438615, 49438615, 49438616, 49438616, 49438617, 49438617, 49438618, 49438619, 49438620, 49438623, 49438623, 49438624, 49438625, 49438625, 49438626, 49438626, 49438627, 49438628, 49438630, 49438630, 49438614, 49438615, 49438615, 49438616, 49438616, 49438617, 49438626, 49438627, 49438615, 49438616, 49438616, 49438617, 49438617, 49438618, 49438618, 49438628, 49438616, 49438617, 49438617, 49438618, 49438618, 49438619, 49438619, 49438620, 49438620, 49438621, 49438623, 49438623, 49438624, 49438624, 49438626, 49438628, 49438628, 49438629, 49438630, 49438617, 49438618, 49438618, 49438619, 49438619, 49438620, 49438620, 49438622, 49438625, 49438626, 49438627, 49438627, 49438629, 49438618, 49438619, 49438619, 49438620, 49438620, 49438621, 49438622, 49438623, 49438624, 49438625, 49438626, 49438627, 49438629, 49438633, 49438636, 49438619, 49438620, 49438620, 49438621, 49438622, 49438623, 49438624, 49438624, 49438626, 49438627, 49438628, 49438629, 49438629, 49438630, 49438630, 49438620, 49438621, 49438624, 49438626, 49438629, 49438630, 49438621, 49438622, 49438622, 49438623, 49438623, 49438624, 49438625, 49438625, 49438626, 49438626, 49438627, 49438627, 49438628, 49438629, 49438629, 49438630, 49438630, 49438631, 49438631, 49438622, 49438623, 49438623, 49438624, 49438624, 49438625, 49438625, 49438626, 49438626, 49438627, 49438627, 49438628, 49438628, 49438629, 49438629, 49438630, 49438630, 49438631, 49438631, 49438632, 49438632, 49438635, 49438635, 49438636, 49438623, 49438624, 49438625, 49438625, 49438626, 49438626, 49438627, 49438627, 49438628, 49438629, 49438629, 49438630, 49438630, 49438631, 49438631, 49438632, 49438632, 49438633, 49438624, 49438626, 49438627, 49438629, 49438630, 49438631, 49438632, 49438625, 49438626, 49438626, 49438627, 49438627, 49438628, 49438628, 49438629, 49438629, 49438630, 49438631, 49438631, 49438632, 49438633, 49438638, 49438626, 49438627, 49438628, 49438628, 49438629, 49438630, 49438630, 49438631, 49438632, 49438627, 49438628, 49438628, 49438629, 49438630, 49438632, 49438628, 49438629, 49438629, 49438630, 49438630, 49438631, 49438631, 49438632, 49438632, 49438633, 49438634, 49438635, 49438635, 49438629, 49438630, 49438631, 49438631, 49438632, 49438633, 49438634, 49438635, 49438636, 49438630, 49438631, 49438631, 49438632, 49438632, 49438633, 49438633, 49438634, 49438635, 49438635, 49438637, 49438631, 49438632, 49438633, 49438634, 49438634, 49438636, 49438637, 49438632, 49438633, 49438633, 49438634, 49438634, 49438635, 49438636, 49438636, 49438633, 49438634, 49438634, 49438635, 49438635, 49438636, 49438636, 49438637, 49438637, 49438638, 49438640, 49438640, 49438634, 49438635, 49438635, 49438637, 49438635, 49438636, 49438636, 49438637, 49438637, 49438638, 49438638, 49438643, 49438636, 49438637, 49438637, 49438638, 49438638, 49438637, 49438638, 49438638, 49438639, 49438639, 49438644, 49438638, 49438639, 49438639, 49438640, 49438640, 49438641, 49438639, 49438640, 49438640, 49438640, 49438641, 49438642, 49438645, 49438641, 49438642, 49438642, 49438643, 49438643, 49438644, 49438644, 49438645, 49438646, 49438646, 49438647, 49438648, 49438648, 49438642, 49438643, 49438643, 49438644, 49438644, 49438645, 49438646, 49438646, 49438648, 49438649, 49438643, 49438644, 49438644, 49438645, 49438645, 49438646, 49438646, 49438647, 49438647, 49438649, 49438644, 49438645, 49438645, 49438646, 49438646, 49438647, 49438648, 49438645, 49438646, 49438646, 49438648, 49438646, 49438647, 49438647, 49438648, 49438647, 49438648, 49438649, 49438649, 49438650, 49438651, 49438648, 49438649, 49438649, 49438650, 49438650, 49438651, 49438652, 49438649, 49438650, 49438650, 49438652, 49438650, 49438651, 49438651, 49438652, 49438653, 49438653, 49438652, 49438653, 49438653, 49438654, 49438653, 49438654, 49438654, 49438654, 49438655, 49438655, 49438702, 49438656, 49438657, 49438657, 49438658, 49438658, 49438659, 49438660, 49438660, 49438661, 49438661, 49438662, 49438663, 49438663, 49438664, 49438664, 49438666, 49438666, 49438668, 49438668, 49438669, 49438669, 49438671, 49438672, 49438672, 49438674, 49438675, 49438677, 49438678, 49438684, 49438688, 49438689, 49438690, 49438691, 49438694, 49438701, 49438702, 50238864, 50785204, 50810227, 54415824, 55491880, 49438657, 49438658, 49438658, 49438659, 49438659, 49438660, 49438660, 49438661, 49438662, 49438663, 49438664, 49438665, 49438666, 49438666, 49438667, 49438669, 49438669, 49438670, 49438670, 49438672, 49438674, 49438674, 49438678, 49438678, 49438679, 49438680, 49438691, 49438699, 49438700, 49438701, 49438701, 49438702, 49438703, 49438658, 49438659, 49438659, 49438660, 49438661, 49438661, 49438664, 49438665, 49438666, 49438669, 49438669, 49438672, 49438680, 49438687, 49438703, 49438659, 49438660, 49438660, 49438661, 49438662, 49438663, 49438664, 49438664, 49438665, 49438665, 49438666, 49438667, 49438668, 49438669, 49438670, 49438673, 49438693, 49438702, 49438704, 49438660, 49438661, 49438662, 49438662, 49438663, 49438663, 49438664, 49438664, 49438665, 49438665, 49438666, 49438666, 49438668, 49438669, 49438670, 49438671, 49438671, 49438672, 49438673, 49438680, 49438680, 49438683, 49438684, 49438685, 49438702, 49438704, 49438661, 49438662, 49438662, 49438663, 49438663, 49438664, 49438664, 49438665, 49438665, 49438666, 49438666, 49438667, 49438668, 49438669, 49438669, 49438670, 49438670, 49438671, 49438671, 49438672, 49438674, 49438677, 49438677, 49438680, 49438681, 49438681, 49438691, 49438693, 49438697, 49438700, 49438705, 50019093, 49438663, 49438664, 49438665, 49438666, 49438667, 49438667, 49438670, 49438671, 49438689, 49438663, 49438664, 49438665, 49438666, 49438672, 49438675, 49438694, 49438706, 49438664, 49438665, 49438665, 49438666, 49438666, 49438667, 49438668, 49438668, 49438670, 49438672, 49438673, 49438674, 49438675, 49438677, 49438681, 49438706, 49438665, 49438666, 49438667, 49438667, 49438668, 49438669, 49438670, 49438672, 49438674, 49438675, 49438676, 49438679, 49438683, 49438689, 49438695, 49438707, 49438666, 49438668, 49438669, 49438671, 49438674, 49438707, 49438667, 49438668, 49438668, 49438669, 49438670, 49438673, 49438675, 49438691, 49438708, 49438668, 49438669, 49438670, 49438670, 49438672, 49438675, 49438676, 49438677, 49438669, 49438670, 49438671, 49438678, 49438685, 49438670, 49438671, 49438671, 49438672, 49438672, 49438673, 49438673, 49438674, 49438674, 49438675, 49438675, 49438676, 49438676, 49438677, 49438678, 49438679, 49438680, 49438681, 49438684, 49438685, 49438693, 49438698, 49438709, 49438709, 49438671, 49438672, 49438673, 49438673, 49438674, 49438675, 49438675, 49438676, 49438679, 49438672, 49438673, 49438674, 49438675, 49438675, 49438677, 49438677, 49438678, 49438679, 49438683, 49438698, 49438710, 49438674, 49438674, 49438675, 49438675, 49438676, 49438676, 49438677, 49438677, 49438678, 49438679, 49438679, 49438680, 49438680, 49438681, 49438681, 49438682, 49438684, 49438686, 49438687, 49438690, 49438694, 49438696, 49438698, 49438702, 49438706, 49438708, 49438711, 49438676, 49438675, 49438676, 49438677, 49438678, 49438678, 49438679, 49438681, 49438681, 49438696, 49438712, 49438676, 49438677, 49438677, 49438678, 49438678, 49438679, 49438679, 49438680, 49438681, 49438681, 49438688, 49438689, 49438693, 49438701, 49438710, 49438712, 49438678, 49438678, 49438679, 49438679, 49438680, 49438682, 49438688, 49438689, 49438696, 49438678, 49438680, 49438682, 49438682, 49438686, 49438696, 49438713, 49438713, 49438679, 49438680, 49438680, 49438681, 49438682, 49438683, 49438684, 49438685, 49438686, 49438689, 49438690, 49438702, 49438680, 49438681, 49438681, 49438682, 49438683, 49438687, 49438689, 49438695, 49438697, 49438703, 49438713, 49438714, 49438681, 49438682, 49438682, 49438683, 49438684, 49438687, 49438690, 49438711, 49438713, 49438715, 49438682, 49438683, 49438683, 49438684, 49438688, 49438691, 49438697, 49438700, 49438703, 49438713, 49438715, 49438683, 49438684, 49438684, 49438685, 49438686, 49438687, 49438687, 49438688, 49438690, 49438691, 49438692, 49438694, 49438699, 49438704, 49438716, 49438684, 49438685, 49438685, 49438686, 49438688, 49438698, 49438699, 49438705, 49438713, 49438685, 49438686, 49438686, 49438687, 49438687, 49438689, 49438690, 49438692, 49438692, 49438709, 49438717, 49438686, 49438687, 49438688, 49438689, 49438690, 49438692, 49438694, 49438687, 49438688, 49438688, 49438689, 49438689, 49438690, 49438690, 49438692, 49438692, 49438693, 49438693, 49438694, 49438694, 49438695, 49438695, 49438696, 49438699, 49438699, 49438700, 49438700, 49438701, 49438702, 49438703, 49438703, 49438704, 49438705, 49438705, 49438706, 49438707, 49438708, 49438709, 49438712, 49438714, 49438714, 49438715, 49438716, 49438716, 49438717, 49438718, 49438688, 49438689, 49438689, 49438690, 49438691, 49438694, 49438698, 49438707, 49438711, 49438718, 49438689, 49438690, 49438691, 49438695, 49438702, 49438719, 49438690, 49438691, 49438692, 49438694, 49438695, 49438696, 49438701, 49438702, 49438704, 49438719, 49438692, 49438692, 49438694, 49438695, 49438695, 49438696, 49438696, 49438697, 49438698, 49438700, 49438703, 49438708, 49438717, 49438692, 49438701, 49438704, 49438708, 49438717, 49438720, 49438693, 49438696, 49438697, 49438704, 49438707, 49438694, 49438695, 49438695, 49438696, 49438696, 49438697, 49438697, 49438698, 49438698, 49438700, 49438701, 49438703, 49438704, 49438705, 49438705, 49438706, 49438707, 49438708, 49438710, 49438712, 49438713, 49438716, 49438718, 49438718, 49438719, 49438721, 49438721, 49438697, 49438698, 49438698, 49438699, 49438702, 49438706, 49438698, 49438698, 49438698, 49438699, 49438701, 49438706, 49438699, 49438699, 49438700, 49438700, 49438702, 49438705, 49438709, 49438712, 49438721, 49438723, 49438699, 49438700, 49438700, 49438709, 49438712, 49438715, 49438700, 49438701, 49438701, 49438702, 49438702, 49438703, 49438704, 49438704, 49438705, 49438706, 49438707, 49438708, 49438709, 49438710, 49438711, 49438712, 49438713, 49438714, 49438715, 49438717, 49438721, 49438722, 49438723, 49438723, 49438724, 49438701, 49438702, 49438703, 49438704, 49438705, 49438705, 49438706, 49438706, 49438707, 49438708, 49438709, 49438709, 49438710, 49438711, 49438713, 49438714, 49438716, 49438720, 49438721, 49438722, 49438723, 49438702, 49438703, 49438703, 49438704, 49438705, 49438706, 49438707, 49438707, 49438708, 49438709, 49438710, 49438711, 49438712, 49438714, 49438715, 49438717, 49438719, 49438720, 49438720, 49438721, 49438722, 49438722, 49438724, 49438725, 49438705, 49438706, 49438707, 49438707, 49438708, 49438708, 49438709, 49438709, 49438710, 49438710, 49438711, 49438717, 49438718, 49438721, 49438724, 49438709, 49438711, 49438712, 49438715, 49438705, 49438712, 49438707, 49438709, 49438710, 49438710, 49438711, 49438713, 49438715, 49438716, 49438724, 49438711, 49438712, 49438725, 49438726, 49438711, 49438712, 49438713, 49438724, 49438710, 49438710, 49438712, 49438714, 49438717, 49438725, 49438710, 49438726, 49438728, 49438711, 49438713, 49438714, 49438715, 49438718, 49438719, 49438727, 49438730, 49438713, 49438713, 49438714, 49438715, 49438716, 49438720, 49438722, 49438726, 49438727, 49438729, 49438730, 49438714, 49438715, 49438715, 49438716, 49438730, 49438731, 49438715, 49438716, 49438720, 49438723, 49438726, 49438716, 49438716, 49438717, 49438718, 49438718, 49438719, 49438720, 49438720, 49438721, 49438721, 49438722, 49438723, 49438726, 49438727, 49438728, 49438729, 49438730, 49438731, 49438731, 49438732, 49438717, 49438718, 49438717, 49438718, 49438718, 49438719, 49438721, 49438721, 49438722, 49438723, 49438724, 49438728, 49438729, 49438730, 49438730, 49438731, 49438733, 49438719, 49438720, 49438721, 49438721, 49438722, 49438723, 49438724, 49438725, 49438725, 49438727, 49438728, 49438730, 49438730, 49438731, 49438731, 49438732, 49438733, 49438720, 49438723, 49438720, 49438721, 49438721, 49438722, 49438722, 49438723, 49438723, 49438724, 49438725, 49438725, 49438726, 49438726, 49438728, 49438728, 49438729, 49438729, 49438730, 49438731, 49438731, 49438732, 49438732, 49438733, 49438733, 49438734, 49438734, 49438721, 49438725, 49438730, 49438723, 49438724, 49438725, 49438726, 49438727, 49438730, 49438731, 49438732, 49438733, 49438734, 49438734, 49438735, 49438724, 49438725, 49438734, 49438735, 49438725, 49438727, 49438728, 49438729, 49438732, 49438733, 49438734, 49438735, 49438736, 49438725, 49438726, 49438727, 49438729, 49438730, 49438732, 49438733, 49438734, 49438734, 49438735, 49438735, 49438736, 49438737, 49438726, 49438727, 49438727, 49438728, 49438728, 49438729, 49438729, 49438730, 49438730, 49438732, 49438732, 49438733, 49438734, 49438734, 49438735, 49438735, 49438736, 49438736, 49438737, 49438737, 49438727, 49438728, 49438729, 49438731, 49438733, 49438733, 49438734, 49438736, 49438738, 49438728, 49438729, 49438730, 49438731, 49438735, 49438737, 49438738, 49438738, 49438729, 49438730, 49438733, 49438735, 49438737, 49438738, 49438739, 49438730, 49438731, 49438734, 49438735, 49438736, 49438738, 49438738, 49438739, 49438731, 49438732, 49438735, 49438737, 49438732, 49438733, 49438734, 49438734, 49438735, 49438736, 49438737, 49438737, 49438738, 49438738, 49438739, 49438740, 49438734, 49438735, 49438736, 49438737, 49438738, 49438738, 49438741, 49438735, 49438738, 49438738, 49438739, 49438740, 49438741, 49438736, 49438737, 49438737, 49438741, 49438737, 49438738, 49438738, 49438739, 49438740, 49438741, 49438741, 49438742, 49438743, 49438738, 49438740, 49438741, 49438741, 49438742, 49438739, 49438740, 49438740, 49438741, 49438741, 49438742, 49438742, 49438743, 49438744, 49438741, 49438741, 49438742, 49438743, 49438744, 49438741, 49438742, 49438742, 49438743, 49438743, 49438744, 49438745, 49438742, 49438743, 49438743, 49438744, 49438744, 49438745, 49438745, 49438743, 49438744, 49438744, 49438745, 49438745, 49438746, 49438744, 49438745, 49438745, 49438746, 49438746, 49438745, 49438746, 49438746, 49438747, 49438746, 49438747, 49438747, 55491925, 49438747, 49438748, 49438748, 49438749, 49438753, 49438754, 49438786, 49446300, 49610091, 49610096, 49610099, 49610100, 49610101, 49610103, 49662833, 49776770, 49798726, 49804469, 49804471, 49804473, 49804474, 49804478, 49819816, 49833619, 49833667, 49874225, 49886361, 50019134, 50019135, 50019136, 50019136, 50019137, 50019137, 50019138, 50019138, 50019139, 50019139, 50019140, 50019140, 50019141, 50019142, 50019144, 50238908, 50238908, 50238909, 50238909, 50238910, 50238910, 50238911, 50238911, 50238912, 50238912, 50238913, 50238913, 50331837, 50331837, 50331840, 50331840, 50761107, 50785247, 50785248, 50785249, 50785249, 50785250, 50785250, 50785251, 50785266, 50785268, 50810276, 50810280, 50810281, 50811343, 50811344, 50811345, 50811345, 51848522, 52186229, 52707957, 52772422, 53242584, 53303875, 53303876, 53483751, 53856310, 53889908, 54415869, 54539039, 54539040, 55491927, 49438754, 49610101, 49610102, 49833619, 50019137, 50019138, 50019139, 50019139, 50785252, 50019141, 49610104, 49610105, 50019142, 50019143, 50019143, 50019144, 50019144, 50238915, 50331844, 50785254, 50785255, 49610139, 49804509, 50019174, 50019175, 50019176, 50238947, 50238948, 50238949, 50785287, 49453863, 50026703, 49781454, 49781459, 49781467, 49781467, 49781469, 49781469, 49781469, 49781469, 49781471, 49781471, 49781472, 50190500, 50190501, 50190505, 50190506, 50190507, 50190506, 50190506, 50190507, 50190508, 50190508, 50190508, 49886933, 50243239, 50114804, 50114805, 50114806, 50114806, 50357172, 51123283, 50357174, 50357174, 51123286, 50357175, 50158723, 50379135, 50170209, 50170209, 50170211, 50170213, 50170213, 50170219, 50384876, 50384876, 50384877, 50384878, 51150990, 50384879, 50200908, 50620003, 50228564, 50228613, 50228647, 50228650, 50228696, 50228730, 50228733, 50414132, 50414166, 50414167, 51206374, 50309713, 50356041, 50334015, 50466792, 50402369, 50500954, 50599524, 50599538, 50599525, 50599524, 50599525, 50599525, 50599526, 50599540, 50599525, 50599526, 50599526, 50599540, 50599542, 50599543, 50599526, 50599527, 50599527, 50599528, 50599529, 50599541, 50599541, 50599543, 50599543, 50599527, 50599528, 50599528, 50599542, 50599542, 50599543, 50599543, 50599545, 50599528, 50599529, 50599529, 50599530, 50599530, 50599531, 50599541, 50599541, 50599542, 50599542, 50599543, 50599543, 50599544, 50599545, 50599545, 50599546, 50599546, 50599529, 50599530, 50599531, 50599531, 50599532, 50599538, 50599541, 50599542, 50599543, 50599543, 50599544, 50599544, 50599545, 50599530, 50599531, 50599531, 50599532, 50599532, 50599541, 50599541, 50599543, 50599543, 50599544, 50599544, 50599545, 50599545, 50599546, 50599546, 50599547, 50599547, 50599531, 50599532, 50599542, 50599543, 50599544, 50599545, 50599545, 50599546, 50599546, 50599547, 50599532, 50599533, 50599545, 50599546, 50599547, 50599548, 50599534, 50599534, 50599545, 50599545, 50599546, 50599546, 50599547, 50599548, 50599549, 50599534, 50599535, 50599543, 50599546, 50599546, 50599547, 50599548, 50599549, 50599549, 50599546, 50599547, 50599547, 50599548, 50599549, 50599550, 50599547, 50599549, 50599552, 50599551, 50599557, 50599556, 50599558, 50599555, 50599557, 50599558, 50601102, 50599556, 50599557, 50599556, 50599557, 50599557, 50819313, 50819313, 50819314, 50912238, 51365652, 51365653, 51365653, 50599557, 50599558, 50599558, 50599559, 50599559, 50599560, 50599560, 50819313, 50819313, 50819314, 50819315, 50819316, 50912241, 51365653, 51365653, 51365654, 51365654, 50599558, 50599559, 50599559, 50599560, 50599560, 50599561, 50599561, 50819312, 50819314, 50819315, 50819318, 50912242, 51107520, 51365653, 51365653, 51365654, 51365654, 51365655, 54470312, 50599559, 50599560, 50599560, 50599561, 50599561, 50599562, 50819314, 50819315, 50819315, 50819316, 50819317, 50819318, 50819318, 50912242, 51365653, 51365653, 51365654, 51365654, 51365655, 51365655, 51365656, 50599560, 50599561, 50599561, 50599562, 50599562, 50819314, 50819314, 50819315, 50819316, 50819316, 50819317, 50819317, 50819318, 50912245, 50912246, 51365654, 51365654, 51365655, 51365655, 51365656, 51365656, 51365671, 51365674, 50599561, 50599562, 50599562, 50819315, 50819316, 50819317, 50819317, 50819319, 51365654, 51365655, 51365656, 51365656, 51365673, 50599562, 50599563, 50599563, 50819312, 50819314, 50819315, 50819315, 50819316, 50819316, 50819317, 50819317, 50819318, 50819318, 50819319, 50819320, 50912243, 50912244, 50912244, 51365655, 51365655, 51365656, 51365656, 51365657, 51365657, 50599563, 50599564, 50599564, 50819316, 50819316, 50819317, 50819317, 50819318, 50819318, 50819319, 50819319, 50819321, 51365655, 51365656, 51365656, 51365657, 51365657, 50599564, 50599565, 50819315, 50819316, 50819317, 50819317, 50819318, 50819318, 50819319, 50912245, 50912247, 50912248, 51019282, 51365656, 51365657, 51365657, 51365674, 50599565, 50819315, 50819316, 50819317, 50819317, 50819318, 50819318, 50819319, 50819319, 50819320, 50912245, 50912248, 51107523, 51130494, 51365656, 51365657, 51365657, 51365658, 51365658, 50819317, 50819317, 50819320, 50819322, 51365657, 51365657, 50602662, 50913798, 51039079, 51039084, 51039069, 51039069, 51039070, 51039084, 51039085, 51039068, 51039069, 51039070, 51039071, 51039071, 51039085, 51039086, 51039086, 51039070, 51039071, 51039071, 51039072, 51039072, 51039084, 51039084, 51039086, 51039086, 51039070, 51039071, 51039071, 51039072, 51039072, 51039085, 51039085, 51039086, 51039086, 51039087, 51039087, 51039071, 51039072, 51039072, 51039073, 51039074, 51039086, 51039086, 51039087, 51039087, 51039088, 51039072, 51039073, 51039074, 51039075, 51039085, 51039086, 51039087, 51039087, 51039088, 51039088, 51039073, 51039074, 51039087, 51039088, 51039088, 51039089, 51039074, 51039075, 51039075, 51039076, 51039087, 51039088, 51039088, 51039089, 51039089, 51039075, 51039077, 51039087, 51039088, 51039088, 51039089, 51039089, 51039090, 51039088, 51039089, 51039090, 51039090, 51039077, 51039078, 51039089, 51039090, 51039079, 51039090, 51039090, 51039091, 51039091, 51039090, 51039092, 51039091, 51039092, 51585421, 51039100, 51585425, 51039102, 51039102, 51585424, 51585425, 51039101, 51039102, 51039102, 51585424, 51585426, 51585426, 51039102, 51039103, 51039103, 51132012, 51132015, 51132016, 51284384, 51585425, 51585425, 51585426, 51585427, 51610456, 51039103, 51039104, 51130871, 51132014, 51585425, 51585426, 51585426, 51585427, 51585427, 51039104, 51132014, 51132015, 51132015, 51132016, 51132018, 51171950, 51494565, 51585423, 51585425, 51585425, 51585426, 51585426, 51585427, 51585427, 51585428, 51585428, 51585443, 51585444, 51611522, 52648699, 54202492, 54656488, 56292104, 51039105, 51132015, 51132016, 51132018, 51132018, 51239037, 51350264, 51585425, 51585426, 51585426, 51585427, 51585427, 51585428, 51585428, 51585429, 56292105, 52648700, 51222705, 51677260, 51224938, 51224927, 51224938, 51224940, 51224940, 51224928, 51224937, 51224939, 51224941, 51224938, 51224939, 51224939, 51224941, 51224942, 51224942, 51224943, 51224943, 51224944, 51678350, 51678349, 51678350, 51678351, 51678350, 51678352, 54783010, 51593617, 51678349, 51678351, 51678352, 51678352, 51678353, 51678353, 51678354, 51678354, 54783011, 51304811, 51718287, 51438996, 51439011, 51439048, 51439052, 51439077, 51439119, 51785416, 51785448, 51529680, 51830723, 51615497, 51873631, 51873632, 51661433, 51896595, 51896596, 51950045, 52040906, 51962280, 51962351, 51962423, 52047086, 52083515, 52107658, 52131745, 52131747, 52131748, 52131747, 52131747, 52131748, 52131749, 52131747, 52131748, 52131749, 52131761, 52131748, 52131749, 52131749, 52131750, 52131750, 52131763, 52131764, 52131765, 52131779, 52131749, 52131750, 52131750, 52131751, 52131763, 52131768, 52131769, 52131750, 52131751, 52131751, 52131765, 52131766, 52131751, 52131752, 52131752, 52131763, 52131764, 52131764, 52131765, 52131766, 52131766, 52131767, 52131767, 52131768, 52131770, 52131752, 52131753, 52131753, 52131756, 52131757, 52131760, 52131761, 52131763, 52131764, 52131764, 52131765, 52131765, 52131766, 52131766, 52131767, 52131767, 52131768, 52131768, 52131769, 52131770, 52131771, 52131777, 52131753, 52131754, 52131754, 52131755, 52131755, 52131756, 52131756, 52131757, 52131758, 52131758, 52131759, 52131759, 52131760, 52131760, 52131761, 52131761, 52131762, 52131762, 52131763, 52131763, 52131764, 52131764, 52131765, 52131765, 52131766, 52131766, 52131767, 52131767, 52131768, 52131768, 52131769, 52131769, 52131770, 52131770, 52131771, 52131772, 52131772, 52131775, 52131780, 52131781, 52131785, 52131756, 52131760, 52131762, 52131763, 52131764, 52131766, 52131766, 52131767, 52131767, 52131768, 52131768, 52131770, 52131784, 52131764, 52131767, 52131768, 52131768, 52131757, 52131767, 52131768, 52131762, 52131764, 52131768, 52131764, 52131766, 52131768, 52131769, 52131770, 52131763, 52131764, 52131768, 52131764, 52131768, 52131771, 52131769, 52131771, 52131771, 52131771, 52131772, 52131766, 52131771, 52131769, 52131769, 52131771, 52131772, 52131774, 52131772, 52131774, 52131775, 52131768, 52131769, 52131771, 52131773, 52131774, 52131775, 52131775, 52131769, 52131771, 52131773, 52131774, 52131774, 52131771, 52131772, 52131773, 52131774, 52131775, 52131772, 52131775, 52131776, 52131776, 52131778, 52131776, 52131776, 52131777, 52131774, 52131776, 52131777, 52131775, 52131776, 52131776, 52131777, 52131778, 52131777, 52131777, 52131778, 52131778, 53195035, 52131777, 52131777, 52131778, 52131778, 52131779, 52131780, 52131777, 52131778, 52131778, 52131779, 52131779, 52131780, 52131778, 52131779, 52131779, 52131780, 52131780, 52131781, 52131781, 52131779, 52131780, 52131780, 52131781, 52131781, 52131782, 52131783, 52131780, 52131781, 52131781, 52131782, 52131783, 52131792, 52156793, 52157858, 54054473, 52131781, 52131782, 52131782, 52131783, 52131783, 52131784, 52131784, 52131785, 52131787, 52131800, 52156790, 52131782, 52131783, 52131783, 52131784, 52131784, 52131785, 52131785, 52131786, 52131788, 52131791, 52131792, 52131796, 52131801, 52156789, 52156795, 52157859, 54235024, 55762386, 55885556, 56838443, 52131783, 52131784, 52131784, 52131785, 52131785, 52131786, 52131786, 52131787, 52131787, 52131788, 52131789, 52131789, 52131790, 52131792, 52131793, 52131794, 52131795, 52131796, 52131797, 52131801, 52131803, 52156795, 52156796, 52156797, 52157860, 52157861, 52157862, 52157862, 53022398, 53083083, 53195039, 53670579, 54054473, 54054474, 54496124, 54748831, 55762386, 55762387, 55762387, 52131784, 52131785, 52131785, 52131786, 52131786, 52131787, 52131787, 52131788, 52131788, 52131789, 52131790, 52131790, 52131791, 52131792, 52131792, 52131793, 52131794, 52131794, 52131795, 52131796, 52131797, 52131798, 52131801, 52131803, 52156791, 52156791, 52156793, 52156795, 52156796, 52156796, 52156797, 52156797, 52156798, 52157862, 52157863, 53022401, 53195038, 53195038, 53195039, 53195040, 53195040, 53532746, 54054473, 54054475, 54830271, 55202829, 55236425, 55762387, 55762388, 55885556, 56838444, 52131785, 52131786, 52131786, 52131787, 52131787, 52131788, 52131788, 52131789, 52131789, 52131790, 52131792, 52131794, 52131796, 52131798, 52131798, 52131802, 52131804, 52156798, 52157862, 52157863, 53195039, 53195040, 55236426, 55762387, 55762388, 52131786, 52131787, 52131787, 52131788, 52131788, 52131789, 52131790, 52131790, 52131791, 52131791, 52131792, 52131793, 52131798, 52131799, 52131802, 52131803, 52131804, 52131804, 52156796, 52156796, 52156798, 52157862, 52157863, 52559475, 53195040, 53532747, 54054473, 54071903, 54650395, 54748833, 55762388, 55762389, 55885557, 55885559, 52131787, 52131788, 52131788, 52131789, 52131789, 52131790, 52131790, 52131791, 52131791, 52131793, 52131793, 52131795, 52131796, 52131797, 52131797, 52131799, 52131800, 52131801, 52131803, 52131803, 52131804, 52131804, 52131805, 52156792, 52156797, 52156799, 52156800, 52156800, 52157863, 52157864, 52387964, 52502281, 53083085, 53195041, 53195041, 53195042, 53195042, 54054473, 54650395, 54748833, 54830272, 55762389, 55762389, 55885559, 55885559, 56838446, 52131788, 52131789, 52131789, 52131790, 52131790, 52131791, 52131792, 52131793, 52131794, 52131798, 52131799, 52131800, 52131801, 52131802, 52131803, 52131805, 52156797, 52156799, 52156800, 52157862, 52157863, 52157865, 52387963, 53195040, 53195041, 53195042, 53763415, 54054476, 54235117, 55762389, 55762390, 52131789, 52131790, 52131790, 52131791, 52131791, 52131792, 52131792, 52131795, 52131796, 52131797, 52131798, 52131804, 52131804, 52131806, 52156799, 52156800, 52157864, 52157865, 52157865, 55236428, 52131790, 52131791, 52131791, 52131792, 52131792, 52131793, 52131794, 52131794, 52131795, 52131798, 52131799, 52131800, 52131802, 52131804, 52131805, 52131805, 52131806, 52156793, 52156795, 52156797, 52156800, 52156800, 52157863, 52157864, 52157864, 52157865, 53195042, 54650395, 55885559, 55885560, 52131791, 52131792, 52131792, 52131793, 52131793, 52131794, 52131795, 52131797, 52131798, 52131800, 52131801, 52131801, 52131802, 52131804, 52131805, 52131806, 52131806, 52156794, 52156802, 52157865, 52157866, 53195043, 55762390, 55762391, 55885561, 56838448, 52131792, 52131793, 52131793, 52131794, 52131796, 52131798, 52131800, 52131801, 52131802, 52131802, 52131803, 52131805, 52131806, 52131807, 52156795, 54496131, 55762392, 52131793, 52131794, 52131795, 52131796, 52131796, 52131797, 52131797, 52131798, 52131799, 52131800, 52131801, 52131802, 52131806, 52131806, 52131807, 52131808, 52156795, 52157864, 52157865, 53195044, 54830275, 55762392, 52131796, 52131796, 52131797, 52131798, 52131799, 52131802, 52131803, 52131806, 52131807, 52131797, 52131802, 52131802, 52131803, 52131807, 52157866, 53195044, 53195045, 53195046, 52131800, 52131801, 52131803, 52131805, 52131807, 52131808, 52131809, 52131809, 52156797, 53195045, 55762393, 55885562, 55885563, 52131804, 52131808, 52131809, 52131803, 52131804, 52131805, 52156802, 52157868, 53195045, 55762394, 52131803, 52131806, 52131809, 52131810, 52157868, 53195047, 55514192, 52131804, 52131809, 52131810, 52131812, 52156799, 52156803, 52156804, 53195046, 54054482, 52131807, 52131810, 52131811, 53195047, 52131804, 52131806, 52131810, 52131811, 52156800, 52156806, 52131804, 52157872, 55236435, 52131806, 52131807, 52131811, 52131813, 52156809, 52157873, 52157874, 55762398, 52131811, 52131812, 52156807, 52157873, 53195050, 55762398, 52131808, 55762397, 52131813, 52131813, 52156808, 52156809, 52157871, 52157872, 52157873, 52157874, 54054485, 56838456, 52131813, 52131815, 52156803, 52156807, 52156809, 52328216, 54748845, 55762399, 55885569, 52131810, 52131814, 52131815, 52156803, 53195052, 54054486, 54054487, 52131814, 52131815, 52156810, 53195052, 52131811, 52131812, 52131815, 52131816, 52156809, 52156810, 52156811, 52156812, 52157874, 52157876, 53195052, 53195053, 53195054, 54054487, 54650407, 56838458, 52131813, 52131815, 52131815, 52131817, 52156810, 52156812, 52157874, 52157875, 53195053, 52131815, 52131816, 52156806, 52156810, 52156812, 52157875, 52157877, 53195052, 53195054, 52131816, 52156812, 52633445, 55885572, 52131817, 52131817, 52156811, 52156812, 52131817, 52131818, 52156807, 52156812, 52156808, 52131819, 52131820, 52131820, 52131821, 52156807, 52156808, 52156808, 52156809, 52156809, 52156811, 52156813, 52156813, 52156814, 52156814, 52156815, 52156816, 52157875, 52157876, 52157876, 52157877, 52157879, 52157879, 53001744, 53083088, 53195056, 53195057, 54235107, 52131820, 52131821, 52131821, 52156808, 52156808, 52156809, 52156809, 52156810, 52156814, 52156814, 52156815, 52157876, 52157877, 52157880, 52157881, 52391778, 53001745, 53195056, 53195057, 55885574, 56838462, 52131821, 52131822, 52156809, 52156809, 52156810, 52156812, 52157878, 53195058, 53195059, 55762405, 55762405, 52131822, 52156809, 52156809, 52156810, 52156810, 52156811, 52156812, 52156815, 52156816, 52156817, 52157879, 52157880, 52157882, 53022420, 53195057, 53195057, 53195058, 53195059, 53532765, 54830290, 52131823, 52156809, 52156810, 52156810, 52156811, 52156811, 52156813, 52156814, 52156815, 52156816, 52156818, 52156820, 52157878, 52157878, 52157879, 52157880, 52157881, 52157882, 53195058, 53195058, 53195059, 53195060, 54054494, 54748852, 55762406, 55885576, 52156810, 52156811, 52181796, 52181797, 52181797, 52181811, 52181814, 52181816, 52181817, 52181797, 52181798, 52181798, 52181801, 52181803, 52181804, 52181812, 52181812, 52181814, 52181814, 52181815, 52181816, 52181817, 52181798, 52181799, 52181801, 52181802, 52181802, 52181803, 52181803, 52181804, 52181805, 52181806, 52181806, 52181813, 52181813, 52181814, 52181814, 52181815, 52181815, 52181816, 52181816, 52181818, 52181818, 52181821, 52181799, 52181800, 52181801, 52181802, 52181803, 52181803, 52181804, 52181804, 52181805, 52181805, 52181806, 52181807, 52181809, 52181813, 52181814, 52181814, 52181815, 52181815, 52181816, 52181817, 52181818, 52181818, 52181803, 52181804, 52181805, 52181805, 52181806, 52181813, 52181817, 52181818, 52181819, 52181819, 52181802, 52181804, 52181805, 52181822, 52181813, 52181805, 52181805, 52181807, 52181808, 52181823, 52181808, 52181815, 52181817, 52181818, 52181818, 52181819, 52181820, 52181824, 52181827, 52181807, 52181808, 52181809, 52181810, 52181820, 52181822, 52181822, 52181824, 52181825, 52181825, 52181827, 52181808, 52181809, 52181809, 52181810, 52181819, 52181819, 52181820, 52181820, 52181822, 52181824, 52181825, 52181826, 52181827, 52181827, 52181809, 52181810, 52181810, 52181819, 52181821, 52181823, 52181826, 52181826, 52181827, 52181828, 52181811, 52181811, 52181818, 52181820, 52181821, 52181821, 52181822, 52181823, 52181825, 52181826, 52181826, 52181827, 52181827, 52181812, 52181820, 52181822, 52181823, 52181825, 52181826, 52181826, 52181827, 52181827, 52181828, 52181829, 52181829, 52181820, 52181821, 52181822, 52181822, 52181824, 52181826, 52181827, 52181827, 52181828, 52181829, 52181813, 52181821, 52181822, 52181826, 52181827, 52181827, 52181828, 52181828, 52181829, 52181822, 52181822, 52181823, 52181827, 52181829, 52181825, 52181830, 52181826, 52181832, 52181827, 52181826, 52181829, 55787409, 52181830, 52181830, 54675415, 52181830, 52181830, 52181831, 52182880, 53220062, 55787410, 52181829, 52181830, 52181832, 52181832, 52181833, 52181837, 52181838, 52182881, 52182882, 53220062, 53220062, 52181830, 52181831, 52181833, 52181835, 52181836, 52181837, 52182882, 52182886, 53220060, 53220062, 52181831, 52181832, 52181832, 52181833, 52181833, 52181834, 52181835, 52181837, 52181837, 52181838, 52182883, 53220063, 55787411, 52181832, 52181833, 52181834, 52181835, 52181835, 52181836, 52181837, 52182882, 52182884, 52182884, 52182885, 52182886, 52182887, 53220063, 53220064, 55787411, 52181833, 52181834, 52181835, 52181835, 52181837, 52181838, 52181838, 52182882, 52182886, 52182886, 53220063, 52181834, 52181835, 52181836, 52181836, 52181838, 52181839, 52182883, 52182885, 52182888, 52391935, 55787412, 52181835, 52181837, 52181838, 52181838, 52181839, 52181839, 52181841, 55787413, 52181836, 52181837, 52181838, 52181839, 52181839, 52181840, 52182885, 52416786, 53220065, 54675420, 52181837, 52181839, 52181840, 52181840, 52182886, 52182888, 52182889, 55787414, 52181838, 52181839, 52181840, 52181841, 52181842, 52182885, 52182885, 52182886, 52182887, 52182888, 52182890, 52416787, 52584501, 53220065, 53220066, 54773859, 55787414, 52181840, 52181840, 52181841, 52181842, 52182884, 52182886, 52182887, 52584502, 53220066, 55910584, 52181841, 52182888, 52182889, 53047429, 52181841, 52181842, 52181842, 52181843, 52181844, 52181844, 52182886, 52182888, 52182888, 52182890, 52182891, 53220067, 53220068, 53323196, 54079500, 54079503, 54675422, 55151746, 55539212, 55787416, 55787416, 56863473, 52181842, 52181843, 52181843, 52182886, 52182889, 52182892, 52750982, 53220067, 53220067, 54079503, 55787417, 55910585, 52181843, 52181844, 52181845, 52181845, 52181905, 52182887, 52182889, 52182889, 52182891, 52182892, 52182892, 52412992, 52584505, 53108113, 53220067, 53220068, 53220068, 53220069, 54079503, 54079503, 54079504, 54521156, 55227858, 55787417, 55787417, 55910584, 55910587, 52181845, 52182888, 52182889, 52182889, 52182890, 52182890, 52182891, 52182891, 52182892, 52182892, 52182893, 52412991, 52584504, 53026757, 53108079, 53220068, 53220069, 53220070, 53220071, 53561874, 54079504, 54671144, 54773862, 55787417, 55910586, 55910587, 52182891, 52182892, 52182893, 52412993, 53220069, 53220070, 54521156, 54675424, 54773862, 55261456, 52182890, 53220069, 53220070, 54773864, 55787418, 52182889, 52182890, 52182893, 52182893, 53220070, 53220071, 53220071, 54079504, 54521158, 54675425, 55787419, 52182890, 52182890, 52182893, 53220071, 52181978, 53026830, 52183934, 52183935, 52183946, 52183933, 52183934, 52183934, 52183935, 52183936, 52183937, 52183947, 52183947, 52183948, 52183948, 52183949, 52183935, 52183936, 52183948, 52183948, 52183949, 52183934, 52183935, 52183935, 52183937, 52183948, 52183949, 52183937, 52183938, 52183949, 52183950, 52183950, 52183951, 52183951, 52183952, 52183937, 52183937, 52183938, 52183938, 52183950, 52183951, 52183952, 52183952, 52183938, 52183938, 52183939, 52183953, 52183954, 52183938, 52183939, 52183940, 52183950, 52183952, 52183952, 52183953, 52183954, 52183955, 52183955, 52183940, 52183940, 52183941, 52183952, 52183953, 52183954, 52183954, 52183955, 52183955, 52183940, 52183941, 52183951, 52183952, 52183952, 52183955, 52183955, 52183956, 52183957, 52183958, 52183941, 52183942, 52183950, 52183953, 52183953, 52183954, 52183956, 52183956, 52183957, 52183953, 52183953, 52183955, 52183956, 52183957, 52183957, 52183957, 52183958, 52183958, 52183966, 52183964, 53221128, 53221128, 53221129, 54672198, 52183965, 53221129, 54080564, 55788477, 52183964, 52183965, 52183968, 53221129, 52183965, 52183966, 52183968, 52183968, 53221129, 53221130, 53221130, 52183966, 52183967, 52183968, 52183969, 52414053, 53048492, 53221129, 53221130, 52183967, 52183968, 52183968, 52183969, 53221130, 53221131, 53221131, 54080566, 54676484, 55540274, 55788479, 55788479, 52183970, 53221131, 53221132, 54774924, 55788479, 52183970, 52183970, 52209699, 53027822, 53109114, 53221130, 53221131, 53221132, 53221132, 54080566, 54080566, 55262518, 55788480, 55911650, 52183971, 53221131, 53221132, 53221133, 53789508, 54080567, 52741013, 53221133, 53221133, 54080565, 54080566, 52183972, 52227437, 52414053, 52414054, 52520433, 52585569, 53221131, 53221132, 53221132, 53221133, 53221133, 53221134, 53221134, 53221135, 53317403, 53558840, 53789509, 54080568, 54080569, 54080570, 54097996, 54261212, 54522217, 54522219, 54676488, 54856365, 54874093, 55228922, 55228923, 55262519, 55530860, 55788479, 55788480, 55788481, 55788481, 55788482, 55911650, 56018891, 56018892, 56864538, 52862698, 53221132, 53221134, 53562939, 54261063, 53109178, 53221135, 52235441, 53246872, 52270918, 54818404, 52524647, 53198170, 52602047, 54983969, 52644150, 52644150, 52644152, 52644153, 53451229, 53451230, 53451229, 53451230, 53451231, 54491159, 52651748, 52651748, 52651749, 53455026, 53455026, 56022376, 52856969, 53557670, 52872789, 55119341, 52987178, 52987179, 52987175, 52987178, 52987178, 52987179, 52987267, 53622742, 53622743, 54127912, 54482178, 54482180, 52987357, 53622831, 53135098, 53696706, 53298107, 53298183, 53298256, 53298309, 54120108, 53320164, 53789250, 53541436, 54939908, 53871682, 53871682, 53871683, 53871686, 54064993, 54064994, 54064995, 55105007, 53913030, 53913033, 53913033, 56653019, 54085671, 54085671, 54085671, 54034332, 54034359, 54034381, 54034384, 54034394, 54034395, 54146348, 54146349, 54146350, 54484057, 55447437, 55601704, 56187736, 54258291, 54258304, 54258292, 54258304, 54258292, 54258293, 54258294, 54258305, 54258293, 54258294, 54258294, 54258295, 54258305, 54258294, 54258295, 54258306, 54258295, 54258296, 54258296, 54258297, 54258306, 54258306, 54258307, 54258296, 54258297, 54258297, 54258307, 54258297, 54258307, 54258308, 54258298, 54258308, 54258308, 54258317, 54258319, 54318590, 54318590, 54354576, 54354579, 54367266, 54389424, 54416528, 54481889, 54578935, 54596012, 54596012, 54596013, 54596013, 54596014, 54596014, 54600111, 54619359, 54655779, 54670248, 54688435, 54733847, 54826680, 54826682, 54973323, 54984166, 55005941, 55117737, 55117738, 55117739, 55117740, 55117741, 55117741, 55117742, 55117743, 55226252, 55298292, 55298293, 55298307, 55298316, 55298340, 55298354, 55298357, 55455823, 55539366, 55559390, 55559392, 55559392, 55559393, 55559395, 55559396, 55560618, 55709376, 55713659, 55713660, 55713660, 55713661, 55713662, 55786441, 55791643, 55812097, 55812097, 55812099, 55812099, 55812101, 55893537, 55893537, 55893538, 55941822, 56149015, 56179864, 56266093, 56266095, 56266095, 56266096, 56299692, 56609040, 56825653, 56825654, 56825654, 56825655, 56948823, 56948824, 56948825, 57201705, 57901711, 55893043, 55893539, 56266096, 56825655, 56825656, 56825656, 56948824, 54378874, 54378875, 55178025, 55619677, 54450849, 54450852, 54692287, 55655665, 55655667, 55069596, 54464567, 55816793, 54476285, 54709131, 54520552, 55690523, 54574806, 55276022, 54705471, 54705473, 54803556, 55341327, 54899608, 55438415, 54901647, 57147328, 54933718, 54933719, 54933720, 54933721, 54933721, 54933711, 54933722, 54933722, 54933723, 55897099, 55897100, 54933734, 55026143, 55164388, 55164390, 55455449, 55455449, 55455450, 55636018, 55897099, 55924209, 56149807, 56149807, 56231245, 56382435, 57163361, 57163362, 57163362, 57163363, 57286532, 57286533, 55455449, 54941962, 54941962, 54942019, 54942038, 54942056, 54942113, 54942114, 55341067, 55459667, 55459668, 55535566, 55640227, 55640281, 56055585, 56055586, 56055587, 57167580, 54980437, 55164977, 55053251, 57223127, 55082191, 55529683, 55118564, 55118565, 55150839, 56242228, 55183115, 55580146, 55209385, 55209388, 55209512, 56775234, 55209641, 57301322, 55268643, 56804860, 55349515, 55663356, 55395055, 55395058, 55395062, 55395061, 55395061, 55395062, 55686115, 55686116, 57394032, 55686121, 56834474, 57394034, 55686119, 57394036, 55688364, 55688439, 55688514, 55699277, 56527214, 57540770, 55710021, 55710027, 56439517, 57674684, 55739976, 56454496, 55753633, 55753765, 55753903, 57013925, 55977162, 55977161, 55977174, 55977175, 55977175, 55977161, 55977163, 55977177, 55977176, 55977163, 55977164, 55977176, 55977176, 55977178, 55977178, 55977164, 55977175, 55977176, 55977176, 55977177, 55977177, 55977178, 55977179, 55977179, 55977165, 55977177, 55977177, 55977179, 55977180, 55977180, 55977167, 55977178, 55977179, 55977180, 55977180, 55977181, 55977180, 55977183, 55977183, 55977181, 55977184, 55977183, 57685089, 55977188, 56139403, 56573096, 55977191, 56418827, 57159128, 57685090, 55977191, 56218447, 56573096, 56671535, 56671535, 57685090, 57685090, 55977192, 55977192, 55977193, 56157786, 56573097, 57685091, 57808260, 55977194, 55977194, 55977195, 56157672, 56157782, 56157787, 56418829, 56418830, 56418831, 56573097, 56573098, 57008452, 57125534, 57159130, 57477674, 57685091, 57685091, 57685092, 57685092, 57808260, 57808261, 57808261, 57808262, 55977195, 56573099, 57685092, 56053131, 56573099, 56752975, 56752976, 57125533, 57159131, 57436888, 57685092, 57685092, 57685093, 57685094, 57808262, 55977197, 56157677, 56157789, 56214817, 56418828, 56418831, 56418832, 56573098, 56573099, 56573099, 56573100, 56645879, 56671538, 56671538, 56671539, 56752977, 57125534, 57436888, 57436889, 57436891, 57685093, 57685093, 57685094, 57808262, 57808263, 57685094, 56418833, 56752977, 57685094, 57125536, 57685095, 57808264, 56012031, 56405572, 57176555, 56106106, 57223592, 56129036, 56129089, 56129113, 56597868, 56129192, 56494869, 56194196, 57793599, 56301636, 56735328, 56338167, 56338168, 56338175, 56338160, 56338175, 56599327, 57865588, 56338195, 56753600, 56599336, 56338282, 56338283, 56338283, 56338308, 56338317, 56626491, 57306085, 57865645, 56338317, 56338334, 56338333, 56852105, 56933545, 56753668, 56599406, 56748745, 56338378, 56338384, 56338389, 56338405, 56338405, 56338402, 56338464, 57865692, 56338438, 56338424, 57865696, 57865699, 57306147, 57617505, 57988880, 56338494, 57189082, 56338496, 57865736, 57865764, 57865765, 57865765, 57988936, 56452450, 57396764, 56459714, 57926358, 56653339, 57009616, 56799141, 57570124, 56820489, 58482828, 56860480, 56860479, 56860479, 56860480, 56860482, 56860466, 56860481, 56860482, 56860483, 56860483, 56860483, 56860484, 56860470, 56860483, 56860484, 56860484, 56860485, 56860484, 56860485, 56860485, 56860486, 56860487, 58126743, 57113189, 58126743, 58126744, 57567185, 57567186, 56860499, 57014749, 57014751, 57194628, 58126745, 58249915, 57010467, 57014749, 57014752, 57194628, 57567186, 57567186, 57600783, 57894030, 58126744, 58126745, 58126745, 58126746, 58249915, 56862956, 57054726, 56914699, 56914699, 57594293, 57221736, 57046432, 57693756, 57066641, 57117830, 57159190, 58399286, 57160450, 57160459, 57263172, 58276727, 58276728, 58276728, 58276733, 57169014, 57169014, 57169016, 57169015, 57169016, 57169017, 57169016, 57169017, 57169003, 57169015, 57169017, 57169017, 57169018, 57169019, 57169003, 57169017, 57169018, 57169018, 57169016, 57169017, 57169018, 57169019, 57169022, 58281008, 58281009, 57721450, 57267451, 57755048, 58281010, 57267456, 57169033, 57267456, 57348894, 57721452, 57721452, 58281012, 58404181, 57348895, 57721453, 57755050, 57267457, 57267457, 57348895, 57348896, 57348896, 57721451, 57721453, 57755050, 58032809, 58281011, 58281012, 58281012, 58281013, 58281014, 58404182, 58404183, 58617468, 59357069, 58281011, 58281014, 57246493, 57306202, 57314574, 57314575, 58353788, 57324994, 58359005, 57365890, 57365880, 57365894, 57365879, 57365892, 57365895, 57365894, 57365880, 57365881, 57365895, 57365895, 57365896, 57365896, 57365896, 57365895, 57365896, 57365897, 57365895, 57365899, 57365911, 57819889, 57365910, 58379449, 57365911, 57447333, 57819891, 58379449, 58379450, 58379450, 58379451, 58379452, 58502620, 59455507, 57365911, 57447334, 57819891, 58131246, 58379450, 58379451, 58379451, 57447334, 57853489, 58131251, 58379451, 58379451, 58379452, 58502620, 58502621, 58502621, 58379453, 57527782, 58460394, 57528767, 57528768, 57528768, 57528769, 57528769, 57528770, 57528770, 57528771, 57528770, 57883699, 57901326, 58212683, 58460885, 58460886, 57528782, 57901326, 58460885, 58460886, 59536943, 57679957, 57901327, 58460885, 58460886, 58460886, 58460887, 57556455, 57814377, 57901327, 57901328, 58460886, 58460887, 58460887, 58584055, 58584055, 58584056, 58691297, 57901328, 58584057, 57564224, 57564299, 57564374, 58601856, 57584182, 58280202, 57625337, 58509169, 57831147, 57831149, 58612076, 58052517, 58039724, 58039725, 58716363, 58716371, 58716364, 58100009, 58746518, 58101425, 58747215, 58121661, 58121724, 58121787, 58880563, 58238629, 58256257, 58273884, 58273873, 58273885, 58273886, 58273887, 58273887, 58273886, 58273886, 58273889, 58273885, 58273886, 58273887, 58273888, 58273888, 58273898, 58273900, 58273901, 58307483, 58833444, 58833444, 58833445, 58833445, 58956614, 58956614, 59209495, 58273901, 58307483, 58585240, 58781864, 58833445, 58833446, 58956615, 58273902, 58833445, 58833446, 58833446, 58833447, 58956616, 58833446, 58833447, 58833447, 58956616, 58833448, 58341076, 58341086, 58537047, 58618834, 58618835, 58867036, 58867037, 58867038, 58867038, 58867039, 58990207, 58990208, 58990209, 59029530, 59122887, 59943095, 58867039, 58733019, 59063010, 58877765, 59135387, 58896596, 58896597, 58896595, 58896597, 58896597, 58896598, 58896594, 58896596, 58896599, 58896610, 58896601, 58896601, 58896603, 58896602, 59144798, 59144800, 59144800, 59144801, 59144801, 59267970, 59144802, 59144802, 59267971, 59144802, 59144803, 59144803, 59267972, 59481259, 59144804, 59144813, 58927587, 59160302, 58959772, 58959887, 58960003, 59176502, 58976190, 59184602, 58978168, 59308755, 59289845, 59341427, 59392988, 59392988, 59392989, 59392989, 59392989, 59392990, 59392990, 59393005, 59392990, 59392991, 59393004, 59393005, 59393005, 59393006, 59393006, 59393007, 59393007, 59393008, 59392991, 59392992, 59392993, 59392993, 59392998, 59392999, 59393000, 59393003, 59393003, 59393004, 59393004, 59393005, 59393005, 59393006, 59393006, 59393007, 59393007, 59393008, 59393008, 59393009, 59393009, 59393010, 59393011, 59393012, 59393012, 59392992, 59392993, 59392993, 59392994, 59392995, 59392999, 59393001, 59393003, 59393004, 59393004, 59393005, 59393005, 59393006, 59393006, 59393007, 59393007, 59393008, 59393008, 59393009, 59393010, 59393010, 59393011, 59393011, 59392997, 59393007, 59393007, 59393008, 59393008, 59393009, 59393011, 59393005, 59393008, 59393009, 59393007, 59393008, 59393017, 59393008, 59393009, 59393009, 59393010, 59393012, 59393012, 59393013, 59393022, 59393014, 59393015, 59393014, 59393015, 59393016, 59393015, 59393019, 59393021, 59393016, 59393019, 59393020, 59393018, 59393020, 59393020, 59393021, 59393019, 59393020, 59393019, 59393020, 59393020, 59393021, 59393021, 59393023, 59393020, 59393021, 59393021, 59393022, 59516174, 59516175, 60469062, 59393021, 59393022, 59393022, 59393023, 59393023, 59393024, 59393031, 59516174, 59516175, 59516175, 59516176, 59516177, 59623416, 60469063, 59393022, 59393023, 59393023, 59393024, 59393024, 59393025, 59393025, 59393026, 59393026, 59393027, 59393027, 59393028, 59393029, 59393029, 59393031, 59516174, 59516175, 59516175, 59516176, 59516176, 59516177, 59729462, 60469063, 59393023, 59393024, 59393024, 59393025, 59393025, 59393026, 59393026, 59393027, 59393027, 59393031, 59393032, 59516174, 59516175, 59516176, 59516176, 59516177, 59516177, 59516178, 59729462, 59769057, 60094242, 60469064, 59393024, 59393025, 59393025, 59393026, 59393026, 59393027, 59393027, 59393028, 59393028, 59393029, 59393030, 59393030, 59393032, 59393033, 59432878, 59516176, 59516176, 59516177, 59516178, 60469064, 59393025, 59393026, 59393026, 59393027, 59393027, 59393028, 59393029, 59393029, 59393032, 59516176, 59516177, 59516177, 59516178, 59516178, 59516179, 60469065, 59393026, 59393027, 59393027, 59393028, 59393028, 59393029, 59393029, 59393030, 59397082, 59412061, 59516177, 59516177, 59516178, 59516179, 59769059, 60469065, 59393027, 59393028, 59393028, 59393029, 59393029, 59393030, 59393032, 59493757, 59516178, 59516178, 59393028, 59393029, 59393029, 59393030, 59393031, 59393032, 59393034, 59516178, 59516178, 59516179, 60094245, 60469066, 59393029, 59393030, 59393031, 59393031, 59393033, 59393034, 59393034, 59493768, 59516178, 59516179, 59516179, 59393030, 59393031, 59516179, 59516179, 59516180, 59516181, 60469067, 59393031, 59393032, 59393032, 59393033, 59516180, 59516180, 59516181, 59393033, 59516180, 59516180, 59516181, 59516181, 59516181, 59393037, 59516181, 59516181, 59516182, 59516183, 59516182, 59516183, 59516182, 59516183, 59516183, 59516184, 59516184, 59516184, 59516185, 59516184, 59516186, 59516186, 59401152, 59520247, 59431111, 59535227, 59472745, 59556044, 59594514, 59594520, 59594596, 59594590, 59594669, 59594679, 59617013, 59617015, 59639327, 59639328, 59639328, 59639329, 59639328, 59639329, 59639329, 59639330, 59639343, 59639329, 59639330, 59639330, 59639331, 59639342, 59639344, 59639345, 59639346, 59639346, 59639347, 59639348, 59639349, 59639330, 59639331, 59639331, 59639342, 59639342, 59639343, 59639344, 59639344, 59639345, 59639345, 59639346, 59639346, 59639347, 59639347, 59639348, 59639348, 59639349, 59639331, 59639332, 59639332, 59639333, 59639342, 59639343, 59639343, 59639344, 59639345, 59639345, 59639346, 59639346, 59639347, 59639347, 59639348, 59639348, 59639350, 59639355, 59639332, 59639333, 59639339, 59639341, 59639342, 59639343, 59639344, 59639344, 59639345, 59639345, 59639346, 59639346, 59639347, 59639347, 59639348, 59639348, 59639349, 59639349, 59639350, 59639351, 59639351, 59639352, 59639355, 59639357, 59639359, 59639343, 59639344, 59639345, 59639346, 59639346, 59639347, 59639347, 59639348, 59639348, 59639349, 59639349, 59639350, 59639350, 59639351, 59639353, 59639354, 59639354, 59639344, 59639347, 59639347, 59639348, 59639348, 59639352, 59639348, 59639353, 59639361, 59639356, 59639359, 59639354, 59639356, 59639359, 59639357, 59639357, 59639358, 59639359, 59639357, 59639358, 59639358, 59639359, 59639360, 60592230, 59639360, 59639358, 59639359, 59639359, 59639361, 59639361, 60592231, 59639359, 59639360, 59639360, 59639361, 59639361, 59639362, 59639362, 59639364, 59639368, 59892225, 60592232, 59639360, 59639361, 59639361, 59639362, 59639362, 59639363, 59639363, 59639364, 59639365, 59639367, 59639370, 59821788, 59852631, 59892226, 59977346, 60217411, 60592232, 59639361, 59639362, 59639362, 59639363, 59639363, 59639364, 59639364, 59639365, 59639366, 59639366, 59639367, 59639368, 59852631, 59892226, 60592233, 59639362, 59639363, 59639363, 59639364, 59639364, 59639365, 59639365, 59639366, 59639366, 59639367, 59639369, 59768842, 59852632, 59892227, 59977343, 60592233, 59639363, 59639364, 59639364, 59639365, 59639365, 59639366, 59639367, 59639370, 59639371, 59639375, 59852632, 59892227, 60217412, 60592234, 59639364, 59639365, 59639365, 59639366, 59639366, 59639367, 59639367, 59639368, 59639370, 59639373, 59678669, 59768841, 59852633, 59892228, 60217413, 60239039, 60580589, 60592234, 59639365, 59639366, 59639366, 59639367, 59639367, 59639368, 59639368, 59639369, 59639369, 59639370, 59639371, 59639372, 59639372, 59678669, 59772024, 59852633, 59892228, 59977348, 60217412, 60592235, 59639366, 59639367, 59639367, 59639368, 59639368, 59639369, 59639370, 59639370, 59639371, 59639373, 59639373, 59639374, 59639375, 59639376, 59772028, 59852634, 59892229, 60250584, 60592235, 59639367, 59639368, 59639368, 59639369, 59639369, 59639370, 59639370, 59639371, 59639373, 59678669, 59678670, 59746587, 59768845, 59852634, 59892229, 60250585, 60592236, 59639368, 59639369, 59639369, 59639370, 59639370, 59639371, 59639371, 59639372, 59639372, 59639374, 59639375, 59639375, 59639379, 59677642, 59746591, 59852635, 59892230, 59977350, 60592236, 59639369, 59639370, 59639370, 59639371, 59639371, 59639374, 59639375, 59678670, 59852635, 59892230, 59978373, 60592237, 59639370, 59639371, 59639371, 59639372, 59639372, 59639373, 59639374, 59639374, 59639375, 59639376, 59639377, 59639377, 59639378, 59639379, 59678672, 59746591, 59768844, 59776905, 59852636, 59892231, 60217415, 60217417, 60592237, 59639371, 59639372, 59639372, 59639373, 59639373, 59639374, 59639375, 59639375, 59678671, 59746591, 59770549, 59852636, 59892231, 59977263, 60217416, 60455063, 60592238, 59639372, 59639373, 59639373, 59639374, 59639375, 59639376, 59639376, 59730897, 59746593, 59772029, 59852637, 59892232, 60592238, 59639373, 59639375, 59639376, 59639376, 59639377, 59639380, 59746592, 59770553, 59852637, 60592239, 59639374, 59639375, 59639376, 59639378, 59639378, 59639379, 59639380, 59639380, 59639382, 59678674, 59772032, 59776907, 59852638, 59892233, 60217419, 60250588, 60592239, 59639375, 59639376, 59639377, 59639379, 59678675, 59746593, 59892233, 60592240, 59639376, 59639378, 59639379, 59639382, 59768849, 59849963, 59852639, 59892234, 60592240, 59639382, 59852639, 59892234, 60592241, 59639378, 59892235, 60217422, 60592241, 59639379, 59639383, 59639385, 59852640, 59892235, 60592242, 59639384, 59770560, 59772036, 59852641, 59892236, 60592242, 59852641, 59892236, 59772035, 59852642, 59892237, 59768853, 59852642, 59892237, 60592244, 59892238, 60592244, 59768852, 59977354, 59746599, 59852644, 60217424, 60592246, 59892240, 60592246, 59892241, 60592247, 59852646, 59715927, 59890920, 59717984, 59717985, 59717987, 59717987, 59717988, 59717989, 59717987, 59737395, 59891949, 60256730, 59931545, 59891951, 59808162, 60631553, 60631554, 60631554, 59756806, 59911360, 59822425, 59822428, 59822447, 59822471, 59822479, 59944191, 59853823, 59853824, 59853813, 59853814, 59853824, 59853825, 59853827, 59853826, 59853828, 59853827, 59853839, 59999464, 59876080, 59959870, 59999465, 60699471, 59999466, 59959872, 59898330, 59898333, 59898334, 59982122, 60021717, 60346900, 60721723, 59982123, 60021718, 60721724, 59982124, 60107863, 59901752, 59901749, 59901758, 60723434, 59983839, 59983839, 59904700, 59904701, 59904690, 59904704, 59904703, 59904707, 59904700, 59904710, 60724909, 59985309, 60024904, 60724910, 59985311, 59985312, 59914455, 59914459, 59914463, 60729788, 60729791, 59990194, 60004263, 60774707, 60060576, 60060631, 60060689, 60063309, 60065919, 60065920, 60065925, 60065926, 60065927, 60065927, 60805521, 60065944, 60065945, 60105515, 60668366, 60805521, 60065950, 60105520, 60065951, 60105521, 60105521, 60169960, 60190552, 60190637, 60190639, 60190640, 60190641, 60430706, 60463877, 60557059, 60805528, 60105522, 60463877, 60805528, 60145091, 60145111, 60145112, 60145112, 60145113, 60145132, 60470296, 60845118, 60145133, 60845118, 60845119, 60145134, 60146369, 60146371, 60146372, 60189331, 60189592, 60230232, 60230233, 60230236, 60258300, 60258350, 60258499, 60265009, 60470297, 60470298, 60470299, 60470301, 60503468, 60708002, 60708017, 60708284, 60845119, 60845120, 60147619, 60147621, 60147622, 60231482, 60846369, 60233541, 60514509, 60234073, 60889600, 60273982, 60909549, 60315155, 60315166, 60315167, 60315179, 60315235, 60315237, 60315311, 60315341, 60315343, 60315329, 60315332, 60930217, 60315347, 60315346, 60315347, 60930220, 60315350, 60343612, 60588582, 60930233, 60930235, 60317390, 60317391, 60931253, 60931254, 60371542, 60371640, 60958361, 60371788, 60371938, 60371939, 60371940, 60372012, 60372014, 60905173, 60958560, 60583739, 60384899, 60965009, 60795473, 60795476, 60795476, 60795476, 60795463, 60795477, 60795478, 60795479, 60795480, 60795481, 60795482, 60795484, 61170297, 61170298, 60795494, 61116912, 61170298, 60828649, 61170300, 61170301, 61170301, 61170302, 60838723, 60838849, 60838977, 61192046, 60861821, 60861849, 60861868, 60861878, 60861896, 61203500, 61203519, 60861972, 60862134, 61203547, 60862384, 61203779, 61048205, 61296674, 61270825, 61270847, 61270885, 61270897, 61270922, 61270923, 61270960, 61270972, 61270998, 61408025, 61271036, 61408074, 61408078, 61271506, 61408341, 61438371, 61438373, 61438410, 61438412, 61491759, 61521827, 61533472], "xaxis": "x", "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 0, 0, 0, 1, 3, 3, 1, 3, 6, 2, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 2, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 6, 2, 5, 2, 6, 5, 1, 2, 1, 3, 1, 1, 1, 1, 2, 2, 1, 3, 1, 1, 4, 4, 3, 2, 1, 1, 2, 3, 2, 1, 1, 1, 2, 1, 1, 1, 1, 3, 2, 3, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 6, 2, 2, 1, 1, 2, 5, 0, 0, 1, 1, 0, 1, 1, 0, 1, 4, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 3, 1, 1, 1, 0, 2, 1, 1, 2, 2, 1, 8, 0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 4, 0, 1, 1, 1, 1, 0, 2, 3, 2, 3, 4, 16, 2, 1, 1, 0, 1, 2, 2, 2, 2, 7, 3, 2, 1, 2, 3, 12, 2, 1, 1, 2, 2, 3, 1, 2, 4, 3, 16, 1, 4, 1, 2, 18, 2, 1, 0, 1, 1, 1, 1, 1, 2, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 0, 0, 1, 1, 0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 2, 0, 1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 3, 0, 0, 0, 1, 1, 0, 0, 0, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 5, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 5, 3, 1, 1, 1, 1, 2, 2, 1, 2, 1, 1, 2, 1, 18, 3, 3, 6, 4, 3, 5, 3, 3, 5, 6, 4, 5, 6, 8, 7, 3, 3, 1, 2, 4, 3, 8, 33, 18, 12, 5, 68, 30, 10, 8, 3, 7, 2, 1, 1, 1, 3, 3, 6, 4, 9, 3, 3, 2, 5, 8, 3, 5, 2, 3, 1, 1, 2, 3, 5, 3, 8, 6, 3, 1, 1, 1, 2, 4, 4, 3, 1, 1, 4, 3, 2, 1, 1, 1, 0, 3, 1, 2, 2, 1, 0, 0, 6, 1, 2, 2, 1, 4, 0, 0, 2, 5, 7, 2, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 5, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 1, 5, 1, 1, 1, 0, 0, 0, 0, 0, 4, 3, 2, 0, 0, 0, 0, 0, 0, 17, 6, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 6, 1, 7, 5, 4, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 2, 11, 5, 1, 1, 2, 4, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 6, 2, 1, 1, 1, 2, 2, 31, 4, 2, 1, 1, 1, 2, 1, 1, 1, 2, 3, 2, 2, 4, 4, 4, 4, 5, 11, 7, 9, 4, 3, 1, 9, 9, 3, 2, 3, 1, 2, 7, 1, 3, 3, 2, 4, 1, 5, 5, 8, 5, 3, 2, 4, 5, 6, 19, 17, 8, 11, 7, 10, 2, 1, 1, 3, 1, 4, 3, 3, 1, 1, 4, 3, 2, 2, 2, 3, 2, 3, 2, 2, 3, 1, 1, 1, 1, 3, 7, 2, 3, 3, 1, 2, 1, 1, 1, 1, 1, 2, 3, 3, 2, 3, 4, 4, 2, 1, 2, 2, 3, 1, 3, 2, 1, 2, 1, 1, 3, 1, 3, 1, 3, 1, 4, 4, 4, 2, 2, 2, 1, 1, 1, 2, 2, 2, 3, 2, 2, 4, 2, 2, 3, 5, 2, 2, 3, 1, 1, 1, 5, 1, 2, 2, 1, 3, 1, 2, 2, 2, 1, 2, 6, 2, 3, 2, 2, 1, 2, 7, 4, 3, 1, 3, 2, 5, 2, 4, 3, 2, 2, 4, 6, 3, 4, 6, 2, 3, 3, 5, 6, 1, 2, 3, 2, 2, 2, 2, 1, 5, 2, 1, 2, 4, 3, 6, 3, 4, 3, 1, 1, 5, 1, 0, 14, 1, 5, 3, 1, 2, 2, 2, 2, 0, 0, 3, 1, 2, 4, 5, 7, 3, 3, 6, 3, 1, 2, 1, 0, 3, 8, 13, 3, 6, 2, 3, 4, 3, 2, 2, 0, 0, 10, 16, 2, 4, 3, 3, 4, 1, 4, 5, 1, 3, 0, 0, 5, 8, 17, 3, 2, 3, 4, 1, 2, 2, 1, 6, 5, 6, 1, 0, 9, 24, 10, 5, 9, 3, 4, 2, 10, 3, 6, 2, 1, 0, 0, 0, 0, 0, 7, 9, 7, 12, 3, 1, 1, 6, 7, 5, 0, 0, 0, 0, 0, 0, 12, 2, 5, 16, 2, 2, 1, 2, 2, 12, 8, 3, 12, 1, 1, 0, 0, 0, 0, 0, 0, 10, 6, 2, 2, 2, 3, 3, 2, 3, 6, 2, 1, 0, 0, 0, 0, 0, 3, 2, 1, 1, 5, 5, 1, 1, 4, 1, 1, 6, 0, 0, 0, 0, 0, 0, 2, 2, 2, 6, 4, 9, 5, 10, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 4, 4, 4, 1, 0, 0, 3, 1, 3, 4, 1, 1, 3, 1, 0, 0, 0, 1, 1, 1, 2, 0, 0, 0, 3, 1, 11, 1, 0, 4, 1, 0, 1, 0, 0, 0, 2, 4, 5, 1, 0, 0, 1, 0, 0, 4, 2, 1, 1, 1, 0, 2, 1, 0, 1, 1, 3, 3, 1, 0, 3, 2, 6, 0, 0, 3, 1, 0, 0, 0, 2, 1, 0, 0, 0, 0, 17, 11, 3, 3, 4, 1, 0, 0, 0, 0, 0, 0, 0, 15, 9, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 3, 1, 1, 2, 3, 1, 3, 5, 1, 1, 1, 1, 4, 10, 13, 3, 1, 3, 7, 13, 2, 1, 2, 3, 1, 1, 94, 42, 10, 12, 1, 1, 1, 1, 1, 4, 198, 100, 78, 7, 3, 2, 7, 11, 11, 8, 10, 3, 3, 1, 5, 1, 2, 1, 2, 1, 225, 176, 1, 2, 3, 28, 14, 9, 19, 4, 3, 2, 1, 1, 1, 1, 1, 380, 8, 3, 3, 26, 15, 22, 34, 27, 20, 3, 9, 6, 4, 2, 1, 1, 139, 3, 3, 4, 26, 18, 49, 164, 153, 169, 265, 74, 38, 19, 5, 3, 1, 2, 1, 7, 7, 10, 16, 47, 25, 51, 13, 1, 1, 2, 4, 4, 9, 2, 6, 1, 10, 13, 2, 5, 0, 3, 2, 8, 11, 1, 16, 16, 29, 22, 5, 1, 1, 0, 0, 0, 0, 34, 36, 75, 11, 10, 3, 2, 0, 0, 55, 119, 33, 29, 4, 3, 1, 0, 0, 0, 0, 0, 0, 185, 46, 17, 12, 5, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 295, 68, 61, 25, 17, 8, 6, 3, 6, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 148, 99, 16, 9, 10, 6, 3, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 109, 33, 23, 8, 1, 7, 5, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 90, 48, 26, 9, 4, 5, 3, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 39, 5, 9, 11, 4, 1, 0, 0, 0, 0, 0, 0, 46, 13, 7, 6, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 27, 8, 19, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 8, 6, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 2, 3, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 8, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 1, 0, 0, 1, 2, 0, 0, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 4, 2, 1, 1, 7, 5, 1, 6, 1, 3, 2, 3, 8, 4, 1, 4, 3, 4, 9, 2, 4, 11, 1, 18, 6, 1, 10, 14, 42, 5, 1, 2, 2, 3, 56, 30, 2, 1, 2, 1, 1, 1, 1, 0, 1, 2, 1, 0, 29, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 0, 0, 2, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 2, 3, 2, 1, 3, 1, 1, 12, 2, 6, 5, 1, 3, 1, 1, 7, 7, 1, 1, 3, 1, 1, 1, 10, 3, 1, 1, 1, 1, 2, 1, 4, 3, 3, 2, 2, 7, 2, 2, 1, 2, 1, 2, 2, 2, 0, 2, 0, 0, 0, 0, 1, 2, 1, 0, 0, 0, 2, 1, 0, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 11, 1, 25, 7, 6, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 2, 0, 0, 2, 4, 2, 1, 0, 1, 3, 3, 1, 1, 6, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 1, 10, 3101, 501, 1141, 165, 15, 14, 4, 4, 45, 11, 1413, 6805, 4, 1356, 457, 59, 808, 437, 1552, 177, 132, 1358, 62, 882, 869, 178, 1359, 33, 139, 16, 179, 8, 2, 6, 2, 0, 61, 0, 0, 0, 46, 1360, 72, 4652, 5866, 526, 68, 790, 158, 1552, 46, 311, 521, 17, 188, 534, 182, 186, 51, 206, 472, 40, 374, 73, 85, 211, 933, 181, 64, 64, 128, 79, 47, 37, 163, 821, 18, 643, 468, 214, 274, 98, 125, 51, 132, 137, 159, 371, 67, 177, 99, 38, 28, 122, 165, 46, 9, 146, 50, 501, 7315, 2711, 621, 64, 911, 262, 171, 141, 33, 33, 190, 50, 8, 252, 450, 26, 113, 22, 375, 69, 357, 268, 16, 36, 24, 96, 2713, 41, 57, 52, 12, 622, 459, 991, 108, 45, 25, 288, 66, 12, 182, 330, 18, 189, 3626, 450, 86, 66, 111, 27, 8, 187, 52, 356, 208, 623, 474, 42, 460, 286, 90, 6, 34, 32, 188, 46, 37, 35, 357, 0, 173, 913, 287, 2715, 20, 38, 305, 28, 40, 392, 263, 46, 169, 1, 14, 26, 31, 274, 269, 65, 0, 194, 12, 40, 11, 914, 106, 461, 105, 58, 18, 38, 20, 46, 56, 15, 36, 68, 14, 34, 7, 47, 24, 50, 22, 915, 60, 31, 144, 103, 41, 18, 112, 9, 49, 156, 1, 21, 29, 134, 350, 0, 49, 33, 177, 307, 62, 39, 104, 43, 29, 64, 27, 57, 678, 101, 61, 42, 83, 184, 116, 9, 140, 63, 451, 789, 15, 73, 212, 95, 37, 102, 91, 132, 168, 8, 96, 992, 743, 358, 40, 50, 62, 3, 34, 261, 968, 196, 31, 2716, 51, 27, 272, 21, 34, 67, 19, 66, 16, 306, 188, 590, 43, 41, 121, 2, 30, 270, 723, 9, 176, 203, 32, 462, 30, 1, 185, 281, 279, 8, 44, 15, 10, 254, 0, 66, 82, 18, 391, 63, 149, 264, 2715, 49, 330, 26, 373, 183, 51, 365, 3166, 104, 0, 6089, 5614, 62, 37, 12, 21, 231, 14, 98, 42, 5, 11, 61, 71, 141, 16, 128, 192, 245, 6344, 0, 0, 0, 0, 0, 0, 0, 459, 19, 41, 225, 496, 132, 1384, 26, 475, 71, 152, 2032, 61, 458, 35, 13, 20, 1, 20, 40, 230, 224, 13, 495, 550, 40, 131, 4, 10, 59, 1357, 25, 70, 137, 534, 109, 488, 1356, 255, 2088, 8, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 1, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 2, 0, 1, 1, 0, 0, 1, 0, 2, 0, 0, 1, 0, 1, 0, 2, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 5, 2, 15, 10, 2, 1, 2, 7, 1, 1, 2, 1, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 5, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 6, 5, 1, 1, 4, 2, 1, 1, 2, 1, 23, 1, 4, 4, 4, 3, 24, 25, 6, 11, 6, 9, 10, 7, 1, 1, 3, 5, 17, 31, 30, 24, 13, 1, 4, 1, 2, 5, 7, 2, 1, 1, 3, 8, 5, 11, 2, 4, 1, 1, 1, 3, 3, 2, 2, 4, 3, 2, 6, 1, 4, 2, 4, 2, 1, 1, 2, 4, 1, 1, 2, 0, 0, 1, 1, 4, 1, 0, 0, 3, 7, 2, 1, 1, 0, 0, 0, 0, 13, 7, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 9, 10, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 0, 1, 1, 0, 0, 1, 2, 1, 0, 1, 0, 1, 1, 1, 2, 1, 1, 48, 6, 6, 5, 1, 4, 4, 4, 1, 1, 2, 2, 1, 1, 2, 3, 1, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 85, 9909, 56, 299, 3, 41, 27, 110, 2, 145, 109, 200, 887, 4969, 12088, 8, 1, 1, 2, 1, 1, 2, 1, 173, 158, 63, 530, 193, 5359, 3541, 174, 159, 57, 302, 64, 1, 40, 28, 98, 14, 3, 146, 1, 107, 94, 533, 201, 786, 482, 12216, 21956, 2886, 574, 3579, 842, 2391, 2216, 811, 494, 869, 479, 164, 114, 137, 4, 360, 219, 908, 417, 1015, 88, 6, 299, 2596, 804, 348, 448, 857, 829, 753, 305, 67, 247, 320, 83, 69, 336, 32, 170, 175, 260, 626, 104, 57, 241, 107, 36, 360, 403, 373, 7, 141, 163, 100, 104, 30, 5, 1714, 331, 20, 394, 2667, 1, 898, 866, 1666, 1176, 529, 868, 1672, 594, 734, 163, 256, 327, 135, 119, 459, 61, 148, 1486, 1076, 4, 699, 166, 614, 518, 357, 559, 56, 423, 336, 342, 275, 104, 99, 235, 292, 13, 314, 348, 212, 152, 194, 160, 16, 224, 97, 48, 1374, 64, 734, 154, 717, 228, 104, 403, 225, 200, 95, 197, 319, 153, 8, 243, 194, 106, 480, 192, 212, 633, 2, 25, 1, 172, 212, 382, 269, 442, 172, 109, 375, 219, 1203, 459, 157, 256, 164, 296, 33, 65, 1, 10, 155, 313, 345, 1058, 120, 324, 12, 33, 531, 406, 12, 62, 277, 48, 1166, 284, 4, 262, 61, 24, 134, 193, 401, 1, 453, 160, 841, 383, 487, 31, 1260, 206, 957, 193, 79, 646, 87, 153, 213, 718, 137, 59, 1, 23, 132, 22, 106, 313, 349, 270, 124, 12, 353, 158, 109, 98, 495, 278, 151, 562, 84, 76, 951, 89, 15, 51, 23, 21, 519, 196, 51, 292, 24, 152, 124, 30, 721, 93, 81, 526, 148, 745, 33, 165, 13, 66, 1, 13, 2, 115, 105, 70, 25, 94, 32, 329, 133, 5, 100, 260, 136, 218, 120, 1060, 34, 228, 277, 110, 195, 12, 425, 27, 259, 219, 29, 34, 207, 1130, 332, 87, 532, 958, 1061, 208, 17, 29, 5, 119, 254, 282, 188, 200, 192, 107, 633, 0, 374, 495, 138, 39, 317, 487, 56, 142, 32, 15, 957, 60, 5, 361, 402, 151, 38, 149, 146, 1545, 520, 584, 155, 737, 732, 262, 35, 243, 49, 131, 134, 220, 80, 165, 242, 204, 184, 214, 152, 1400, 410, 688, 1182, 182, 150, 12, 350, 5, 229, 601, 1115, 461, 285, 4, 20, 439, 12, 936, 1350, 161, 488, 24, 50, 53, 30, 272, 305, 2761, 86, 285, 58, 137, 319, 176, 22, 315, 353, 68, 12, 63, 392, 99, 24, 117, 88, 78, 97, 2, 256, 253, 512, 506, 334, 29, 287, 209, 2, 29, 66, 62, 80, 28, 569, 60, 196, 12, 1550, 615, 128, 229, 291, 554, 253, 515, 72, 564, 96, 519, 1223, 9, 337, 154, 6, 189, 269, 50, 263, 202, 212, 958, 584, 96, 184, 383, 187, 137, 529, 275, 490, 220, 75, 151, 150, 404, 213, 0, 319, 151, 75, 273, 197, 513, 674, 60, 64, 323, 129, 6, 283, 239, 297, 12, 80, 734, 508, 154, 383, 187, 341, 403, 2, 96, 32, 273, 245, 134, 243, 195, 717, 133, 190, 68, 152, 18, 201, 76, 258, 1703, 225, 181, 47, 284, 68, 107, 479, 121, 315, 4, 196, 532, 318, 257, 253, 157, 292, 271, 324, 171, 226, 33, 39, 14, 865, 445, 228, 240, 746, 603, 34, 679, 340, 185, 178, 95, 98, 341, 214, 98, 250, 828, 184, 349, 224, 594, 23, 514, 160, 173, 99, 375, 583, 71, 848, 192, 299, 214, 492, 538, 780, 256, 163, 208, 103, 33, 98, 1041, 530, 8, 410, 1, 95, 225, 396, 134, 1942, 191, 640, 195, 744, 716, 82, 120, 4, 79, 279, 188, 564, 282, 236, 487, 123, 229, 377, 1, 292, 185, 133, 3937, 292, 558, 126, 823, 9, 626, 49, 213, 462, 638, 211, 145, 448, 753, 103, 70, 1041, 424, 2212, 23, 349, 318, 349, 1080, 1176, 162, 29, 1050, 0, 336, 251, 459, 955, 219, 84, 210, 67, 709, 217, 243, 447, 760, 3, 194, 7, 106, 223, 237, 333, 253, 171, 141, 238, 59, 423, 743, 125, 347, 35, 715, 94, 464, 62, 170, 989, 1, 1121, 1207, 434, 34, 841, 0, 225, 151, 334, 177, 34, 1505, 290, 222, 634, 954, 49, 445, 714, 177, 1024, 252, 267, 97, 520, 15, 380, 178, 174, 680, 141, 219, 382, 41, 109, 730, 24, 380, 99, 331, 368, 1490, 223, 914, 348, 389, 200, 742, 224, 42, 16, 288, 166, 151, 768, 1895, 105, 599, 904, 0, 591, 396, 384, 317, 796, 344, 824, 1368, 307, 85, 239, 713, 1638, 98, 497, 0, 4226, 201, 868, 673, 9042, 1360, 7235, 10715, 1879, 4811, 5212, 2721, 3177, 20856, 18198, 303, 268, 74, 227, 417, 98, 275, 258, 83, 20, 28, 175, 1, 22, 5, 1, 2, 64, 14, 12, 48, 219, 346, 106, 266, 418, 150, 7070, 0, 0, 0, 0, 2671, 296, 43, 27, 63, 247, 266, 1140, 427, 110, 131, 17, 96, 69, 53, 109, 226, 754, 142, 244, 218, 201, 92, 200, 1231, 156, 536, 429, 704, 6999, 336, 648, 130, 405, 149, 1283, 46, 33, 6, 271, 5, 10, 41, 18, 40, 118, 48, 73, 0, 266, 28, 62, 60, 87, 186, 161, 217, 61, 39, 323, 276, 12, 92, 1, 371, 7, 122, 75, 65, 125, 338, 16, 75, 66, 446, 150, 890, 90, 13, 109, 75, 13, 56, 27, 13, 288, 2, 14, 18, 29, 15, 64, 174, 27, 17, 15, 97, 0, 44, 6, 10, 54, 0, 67, 117, 19, 372, 8, 121, 63, 174, 476, 54, 15, 42, 74, 28, 110, 43, 227, 529, 223, 74, 129, 549, 243, 74, 173, 216, 573, 372, 317, 65, 692, 226, 360, 192, 71, 2816, 105, 167, 1564, 1316, 1605, 192, 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 3, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 2, 1, 1, 1, 1, 3, 1, 1, 2, 1, 1, 1, 1, 4, 6, 10, 1, 6, 2, 8, 9, 4, 2, 2, 7, 12, 1, 1, 4, 1, 3, 19, 17, 2, 5, 1, 4, 2, 5, 2, 4, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 1, 2, 1, 2, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 2, 1, 1, 1, 5, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 6, 1, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 4, 0, 0, 0, 0, 5, 1, 0, 0, 1, 8, 0, 2, 0, 0, 1, 1, 1, 4, 7, 15, 2, 1, 2, 8, 66, 1, 1, 1, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 5, 4, 2, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 4, 3, 0, 1, 2, 6, 3, 13, 1, 6, 38, 3184, 61, 22, 5, 1, 5, 4997, 185, 28, 3, 10, 6, 20, 2, 3, 5985, 516, 100, 83, 31, 14, 53, 68, 26, 3, 5690, 433, 190, 103, 16, 18, 48, 157, 269, 281, 23, 3, 3102, 1021, 328, 23, 15, 32, 42, 56, 828, 854, 637, 55, 1, 1300, 442, 122, 80, 62, 95, 633, 441, 656, 9, 8, 1, 503, 132, 65, 28, 24, 83, 68, 955, 490, 376, 18, 55, 94, 706, 264, 354, 6, 263, 29, 70, 27, 55, 67, 29, 16, 23, 31, 28, 17, 122, 58, 190, 160, 69, 1984, 1585, 19, 0, 0, 4365, 35, 8, 6681, 168, 31, 1, 0, 0, 0, 4770, 135, 1, 2, 0, 0, 0, 0, 0, 0, 0, 3434, 15, 2, 3, 1, 1, 0, 0, 0, 0, 0, 0, 385, 341, 37, 30, 20, 29, 2, 6, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 202, 15, 9, 9, 6, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 49, 62, 37, 41, 3, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 13, 13, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 16, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 26, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 10, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 2, 1, 2, 2, 6, 6, 5, 4, 1, 2, 5, 1, 1, 1, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 2, 1, 2, 1, 2, 3, 0, 0, 1, 0, 0, 0, 0, 1, 0, 2, 0, 0, 6, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 2, 2, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 4, 0, 0, 0, 2, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 2, 0, 2, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 1, 1, 1, 3, 1, 2, 2, 4, 2, 4, 2, 2, 2, 2, 1, 5, 1, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 5, 4, 5, 1, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 2, 1, 1, 10, 5, 16, 12, 2, 3, 3, 1, 1, 1, 1, 2, 2, 1, 1, 2, 1, 0, 1, 3, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 2, 2, 1, 2, 36, 3, 11, 7, 2, 2, 2, 1, 1, 1, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 1, 2, 2, 1, 9, 1, 1, 1, 1, 2, 2, 1, 1, 2, 1, 1, 2, 3, 2, 1, 2, 2, 8, 1, 1, 1, 7, 2, 2, 2, 2, 4, 3, 1, 3, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 1, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 8, 5, 1, 3, 2, 2, 1, 6, 3, 1, 2, 1, 1, 1, 1, 33, 16, 14, 16, 1, 1, 2, 1, 10, 1, 6, 37, 62, 22, 6, 1, 2, 2, 4, 3, 8, 5, 4, 1, 68, 41, 10, 9, 2, 3, 3, 10, 16, 5, 9, 1, 1, 1, 1, 215, 44, 1, 2, 1, 2, 3, 16, 6, 55, 17, 20, 2, 1, 221, 50, 28, 7, 2, 1, 5, 5, 9, 22, 130, 51, 49, 3, 1, 1, 48, 18, 4, 8, 8, 21, 26, 3, 6, 175, 42, 74, 4, 1, 1, 9, 6, 8, 3, 77, 14, 27, 2, 11, 8, 42, 11, 2, 5, 16, 7, 9, 4, 1, 4, 2, 7, 4, 7, 1, 2, 0, 0, 3, 6, 15, 12, 5, 6, 24, 10, 8, 2, 0, 10, 6, 28, 3, 14, 0, 0, 0, 238, 149, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 240, 14, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 89, 4, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 2, 1, 2, 9, 1, 1, 3, 2, 2, 61, 1, 2, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 4, 1, 1, 1, 5, 6, 3, 20, 1, 1, 1, 1, 11, 6, 31, 2, 2, 1, 1, 1, 2, 17, 67, 3, 6, 3, 2, 2, 2, 1, 66, 11, 8, 1, 1, 2, 2, 5, 2, 3, 1, 2, 328, 97, 20, 10, 28, 51, 36, 37, 48, 81, 32, 22, 22, 9, 116, 14, 4, 12, 9, 25, 31, 41, 46, 50, 109, 30, 23, 12, 7, 9, 1, 7, 20, 29, 17, 14, 62, 76, 46, 26, 30, 11, 2, 5, 13, 2, 9, 20, 4, 6, 4, 1, 5, 2, 3, 0, 10, 0, 0, 4, 8, 5, 2, 3, 1, 11, 24, 18, 3, 1, 1, 0, 13, 16, 21, 28, 8, 4, 7, 3, 0, 14, 16, 25, 16, 5, 6, 6, 0, 0, 0, 0, 41, 49, 7, 7, 9, 4, 0, 0, 0, 0, 0, 72, 46, 28, 11, 6, 0, 0, 0, 0, 0, 0, 137, 109, 31, 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 110, 52, 37, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 54, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 117, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 2, 1, 0, 2, 0, 1, 1, 1, 8, 13, 2, 5, 2, 1, 2, 1, 4, 1, 2, 2, 1, 3, 1, 5, 0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 3, 1, 0, 0, 0, 0, 0, 2, 0, 1, 2, 3, 9, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 1, 1, 0, 0, 0, 0, 2, 1, 5, 1, 1, 9, 1, 2, 1, 6, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 1, 1, 2, 10, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 1, 2, 1, 1, 1, 2, 1, 4, 1, 2, 1, 2, 1, 4, 2, 8, 1, 2, 2, 3, 1, 15, 2, 2, 22, 7, 2, 3, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 1, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 2, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 5, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 2, 2, 1, 1, 1, 1, 1, 214, 37, 12, 1, 5, 4, 2, 1, 13, 10, 3, 25, 18, 17, 9, 8, 4, 10, 15, 10, 15, 22, 22, 21, 1, 147, 28, 16, 5, 22, 6, 6, 11, 3, 5, 12, 5, 10, 4, 6, 11, 1, 2, 50, 16, 25, 34, 33, 5, 15, 6, 9, 15, 28, 9, 14, 3, 3, 6, 1, 2, 2, 5, 5, 4, 48, 5, 16, 6, 2, 4, 3, 3, 2, 2, 15, 3, 2, 1, 24, 4, 6, 3, 2, 3, 3, 3, 2, 3, 3, 2, 1, 2, 6, 4, 2, 5, 6, 3, 13, 6, 5, 3, 2, 2, 1, 3, 1, 2, 2, 7, 5, 4, 1, 2, 1, 5, 2, 5, 2, 52, 43, 14, 17, 12, 2, 6, 3, 3, 0, 49, 29, 1, 2, 10, 3, 0, 0, 0, 0, 0, 80, 20, 9, 2, 3, 2, 2, 0, 103, 10, 12, 1, 2, 1, 1, 1, 0, 0, 75, 28, 1, 5, 2, 3, 1, 0, 0, 74, 27, 3, 9, 2, 0, 0, 0, 112, 5, 2, 10, 6, 1, 2, 0, 0, 0, 139, 7, 5, 4, 4, 0, 0, 0, 107, 26, 7, 6, 1, 1, 0, 0, 0, 0, 70, 14, 11, 2, 1, 1, 1, 0, 0, 0, 0, 0, 69, 19, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 25, 2, 2, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 2, 8, 4, 1, 1, 1, 1, 1, 3, 5, 4, 1, 3, 1, 12, 9, 18, 1, 4, 43, 41, 3, 10, 1, 157, 15, 1, 280, 3033, 35, 19, 34, 15, 7, 14, 9, 6, 55, 316, 2, 3, 5, 2, 1967, 485, 492, 373, 268, 116, 5, 32, 20, 8, 61, 49, 95, 1244, 36, 5, 877, 393, 142, 129, 223, 16, 12, 44, 12, 389, 20, 632, 286, 139, 101, 18, 19, 26, 46, 263, 17, 5, 541, 302, 268, 31, 21, 60, 67, 404, 5, 42, 313, 330, 25, 26, 43, 51, 39, 98, 454, 100, 11, 448, 27, 33, 57, 47, 113, 382, 14, 145, 76, 8, 13, 7, 76, 196, 39, 69, 134, 872, 8, 145, 7, 6, 25, 83, 9, 26, 17, 12, 25, 30, 95, 39, 46, 38, 38, 16, 40, 98, 260, 1, 23, 48, 185, 8, 44, 245, 3, 4, 656, 97, 5, 0, 773, 1598, 122, 7, 6, 0, 1, 1, 0, 1, 0, 0, 0, 0, 615, 45, 2, 3, 0, 0, 1728, 40, 6, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 549, 56, 28, 23, 2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 180, 20, 42, 1, 0, 0, 0, 0, 0, 0, 33, 37, 2, 0, 0, 0, 2, 0, 1, 0, 49, 0, 1, 0, 1547, 229, 68, 19, 2, 13, 11, 4, 4, 2, 5, 19, 2, 26, 10, 2, 2, 1, 2264, 113, 75, 7, 22, 3, 1, 18, 2, 4, 13, 3, 1, 3390, 136, 29, 71, 25, 19, 4, 4, 46, 10, 45, 5, 3741, 175, 273, 33, 132, 184, 4, 7, 13, 15, 19, 3, 154, 7, 16, 17, 1, 1476, 1224, 184, 263, 402, 54, 54, 55, 18, 56, 41, 417, 6, 46, 14, 697, 200, 192, 277, 103, 6, 275, 17, 4, 2, 377, 568, 662, 50, 96, 8, 569, 19, 76, 19, 3, 187, 442, 33, 1, 164, 3, 35, 10, 1, 781, 118, 122, 36, 99, 220, 3, 11, 8, 185, 208, 345, 183, 92, 288, 55, 13, 180, 63, 19, 12, 1063, 33, 185, 36, 12, 3, 2, 1, 54, 82, 165, 114, 143, 3, 12, 62, 97, 38, 53, 188, 5, 1, 0, 24, 77, 19, 20, 231, 7, 4, 126, 23, 35, 124, 0, 107, 120, 441, 2, 54, 1, 75, 162, 82, 462, 62, 118, 0, 34, 337, 114, 5, 1402, 481, 89, 17, 2, 1, 2, 1, 0, 790, 150, 6, 4, 2, 1114, 55, 16, 3, 3, 0, 2, 1, 1, 528, 44, 20, 27, 4, 18, 3, 1, 0, 380, 312, 137, 114, 157, 68, 24, 126, 86, 39, 47, 26, 21, 99, 114, 93, 41, 10, 87, 134, 39, 9, 348, 57, 8, 3453, 786, 4, 1, 1, 4303, 34, 15974, 9024, 946, 726, 257, 63, 50, 74, 26, 7, 61, 2, 3, 4, 2, 16463, 463, 132, 33838, 4332, 472, 535, 102, 6, 33, 46, 47, 8, 73, 2, 8, 1, 1, 35999, 1684, 611, 227, 122, 271, 58, 69, 3, 36, 66, 2, 6, 3, 1, 40287, 2652, 1002, 481, 130, 155, 80, 52, 194, 31, 20, 2, 39709, 2468, 942, 391, 282, 247, 368, 136, 404, 34, 39287, 3577, 982, 344, 172, 114, 359, 43, 54, 105, 967, 18, 16, 19, 38728, 3476, 498, 243, 217, 241, 309, 88, 79, 39, 184, 1095, 25, 10, 98, 4, 19, 2, 24828, 9934, 1812, 1107, 1749, 1280, 1198, 340, 465, 969, 1044, 653, 24, 50, 44, 10, 10, 13695, 4110, 2504, 2062, 1890, 1811, 459, 372, 755, 2067, 207, 410, 99, 8848, 5135, 2061, 2523, 1136, 302, 2792, 275, 1532, 145, 425, 25, 5475, 2605, 3171, 840, 446, 1058, 374, 1106, 35, 69, 94, 3761, 3161, 2063, 1440, 1591, 1674, 630, 208, 269, 161, 47, 18, 1, 6725, 828, 247, 1983, 819, 756, 657, 255, 72, 265, 9, 5447, 2644, 3859, 2961, 2869, 691, 412, 774, 3058, 4115, 1120, 2803, 1299, 264, 475, 225, 4207, 1618, 2580, 527, 114, 2, 5602, 8907, 2424, 2179, 758, 728, 8454, 2370, 2529, 1635, 941, 80, 77, 196, 26222, 4603, 2669, 669, 27899, 4636, 1242, 241, 92, 142, 33134, 2650, 1043, 809, 0, 33816, 4261, 2221, 2000, 0, 0, 29764, 4629, 3055, 1, 0, 29286, 3741, 33992, 12, 21090, 3, 0, 0, 0, 0, 4418, 463, 76, 18, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2720, 84, 19, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1758, 179, 9, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1046, 37, 17, 8, 2, 1, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 387, 69, 17, 7, 1, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 104, 19, 9, 8, 3, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 9, 7, 3, 6, 2, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 2, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 1, 1, 11, 0, 8, 1, 2, 2, 5, 2, 13, 5, 1, 2, 1, 18, 1, 1, 8, 1, 1, 1, 1, 1, 3, 2, 1, 1, 0, 0, 0, 0, 0, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 0, 1, 1, 2, 1, 1, 1, 2, 3, 2, 1, 2, 3, 0, 0, 0, 0, 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 4, 4, 2, 1, 2, 6, 1, 1, 2, 8, 30, 1, 3, 3, 6, 1, 7, 1, 1, 1, 1, 1, 2, 1, 1, 7, 1, 3, 1, 2, 4, 2, 2, 1, 4, 7, 10, 0, 3, 1, 0, 0, 0, 0, 1, 0, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 1, 3, 1, 2, 0, 1, 2, 3, 1, 0, 0, 5, 3, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 5, 2, 3, 1, 2, 92, 15, 18, 3, 6, 3, 3, 3, 2, 1, 2, 5, 51, 1, 11, 1, 103, 48, 2, 6, 4, 5, 23, 3, 8, 16, 100, 4, 1, 1, 75, 4, 7, 11, 3, 2, 2, 3, 26, 89, 2, 1, 13, 7, 36, 11, 4, 6, 8, 4, 23, 116, 1, 1, 5, 19, 4, 3, 6, 7, 7, 4, 3, 1, 15, 25, 1, 1, 6, 7, 43, 2, 10, 2, 6, 2, 2, 3, 3, 76, 6, 3, 4, 1, 1, 3, 17, 1, 1, 1, 2, 2, 13, 2, 7, 9, 1, 1, 7, 1, 8, 0, 1, 2, 8, 0, 0, 64, 0, 1, 1, 1, 0, 1, 10, 8, 2, 5, 64, 4, 10, 22, 12, 2, 1, 0, 2, 1, 1, 1, 3, 5, 1, 3, 1, 9, 2, 2, 1, 5, 1, 1, 2, 8, 2, 2, 5, 2, 6, 9, 15, 10, 5, 1, 0, 7, 16, 21, 13, 8, 2, 44, 45, 13, 8, 7, 1, 142, 31, 35, 10, 1, 408, 217, 36, 800, 56, 5, 1, 1, 1, 2339, 10, 6934, 1, 3, 2, 19456, 1, 7, 4, 15, 8, 13, 8, 1, 1, 1, 1, 2, 3, 7806, 2946, 3972, 2192, 2199, 1595, 1681, 957, 547, 175, 124, 63, 10, 16, 12, 9, 5805, 887, 582, 315, 384, 204, 174, 45, 23, 6335, 1077, 983, 419, 184, 266, 70, 8286, 1839, 627, 607, 430, 48, 21, 16, 9361, 1610, 1036, 607, 208, 93, 82, 12235, 2197, 837, 335, 125, 14591, 2544, 547, 157, 157, 47, 19, 19623, 1521, 374, 288, 73, 15, 4, 24358, 1788, 717, 186, 49, 4, 25587, 3019, 576, 149, 45, 28828, 1182, 62, 22, 34483, 1170, 136, 1, 38407, 1041, 18, 5, 42460, 639, 15, 5, 2, 47979, 172, 22, 20, 45409, 5122, 3284, 753, 49, 6, 1, 40544, 6465, 640, 3, 0, 44135, 3111, 224, 31, 61, 0, 51433, 2581, 374, 5, 2, 2, 5, 0, 53735, 1777, 651, 61, 55, 52662, 3157, 535, 117, 25, 9, 12, 0, 51417, 2932, 461, 187, 50, 24, 3, 1, 50693, 3890, 457, 34, 90, 6, 4, 47840, 5294, 828, 224, 51, 47083, 4263, 939, 241, 38, 17, 47470, 5148, 402, 87, 30, 2, 49591, 2767, 490, 29, 9, 18, 47845, 7544, 131, 9, 6, 0, 48634, 1421, 17, 4, 51679, 1243, 856, 22, 296, 37, 38539, 8276, 2420, 701, 162, 176, 35, 22, 20, 266, 0, 30083, 6698, 1106, 427, 23, 220, 416, 0, 29583, 5567, 1414, 593, 141, 35, 377, 50, 30, 8, 664, 0, 25245, 7684, 2206, 205, 181, 398, 359, 1, 64, 102, 1733, 19313, 5303, 2348, 1470, 142, 1037, 470, 116, 2259, 14948, 5864, 2628, 994, 288, 241, 884, 2856, 10383, 5419, 3481, 118, 559, 560, 381, 83, 2060, 7851, 4183, 848, 1329, 236, 206, 20, 4156, 0, 4073, 3760, 1846, 1459, 937, 283, 5113, 3823, 3041, 1954, 520, 825, 3277, 3449, 1172, 1021, 1867, 3062, 822, 1062, 2148, 6906, 0, 833, 1727, 4526, 1004, 4123, 8046, 19500, 108, 263, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11910, 89, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6483, 8, 5, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1205, 28, 12, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 646, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 281, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 4, 2, 2, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 2, 2, 1, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 4, 2, 1, 1, 6, 11, 2, 3, 3, 6, 5, 7, 1, 1, 2, 4, 3, 2, 1, 8, 2, 2, 2, 2, 1, 6, 1, 1, 1, 3, 1, 1, 1, 3, 1, 2, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 3, 1, 1, 1, 2, 4, 2, 6, 2, 18, 2, 5, 3, 1, 6, 4, 2, 1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 4, 4, 8, 1, 1, 3, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 3, 4, 2, 2, 1, 3, 61, 3, 7, 3, 7, 3, 1, 1, 1, 0, 2, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1, 0, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 2, 3, 9, 2, 3, 6, 1, 26, 1, 3, 3, 16, 1, 2, 1, 2, 19, 4, 1, 1, 1, 11, 2, 34, 2, 3, 2, 7, 1, 1, 5, 13, 1, 1, 5, 2, 26, 1, 2, 2, 1, 2, 1, 1, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 1, 1, 1, 1, 10, 16, 1, 2, 1, 3, 15, 3, 1, 1, 1, 3, 7, 11, 1, 1, 3, 1, 1, 0, 0, 4, 0, 3, 0, 0, 0, 0, 0, 0, 3, 1454, 268, 514, 72, 6, 6, 27, 4, 2, 57, 22, 109, 287, 1054, 81, 3, 182, 626, 4839, 2068, 1, 1, 823, 210, 423, 9, 72, 141, 58, 390, 128, 31, 43, 7, 7, 9, 0, 0, 0, 9, 5, 0, 3, 0, 56, 21, 110, 245, 44, 663, 1882, 70, 2, 80, 4, 5, 308, 107, 251, 309, 171, 14, 942, 13, 9647, 2, 8, 5107, 394, 51, 911, 3837, 84, 2460, 1230, 530, 73, 219, 333, 37, 30, 43, 55, 11, 16, 335, 514, 254, 31, 252, 286, 128, 309, 46, 76, 16, 40, 8, 167, 114, 49, 33, 65, 63, 13, 137, 224, 122, 60, 1, 188, 4104, 411, 254, 2373, 891, 141, 422, 54, 15, 36, 152, 384, 92, 412, 212, 52, 50, 255, 31, 22, 1086, 155, 594, 337, 600, 5, 12, 169, 434, 3133, 1394, 198, 622, 14, 211, 9, 79, 10, 7, 95, 13, 313, 1433, 974, 142, 401, 24, 41, 332, 22, 1988, 182, 312, 257, 394, 657, 487, 12, 193, 156, 279, 197, 3, 5, 13, 15, 736, 483, 975, 414, 441, 216, 151, 178, 91, 131, 157, 119, 26, 246, 779, 105, 925, 484, 183, 143, 1, 152, 1867, 251, 25, 22, 133, 153, 416, 74, 1003, 34, 402, 258, 977, 314, 54, 168, 485, 226, 425, 580, 111, 338, 395, 670, 601, 32, 659, 250, 32, 46, 56, 227, 185, 487, 252, 426, 12, 228, 17, 217, 47, 356, 416, 84, 6, 20, 24, 2, 16, 437, 67, 12, 648, 57, 58, 66, 20, 32, 11, 6, 25, 31, 557, 22, 16, 33, 17, 19, 6, 24, 399, 32, 3, 53, 11, 23, 16, 30, 229, 110, 68, 156, 23, 45, 39, 55, 49, 16, 169, 6, 2, 26, 31, 161, 406, 0, 296, 280, 339, 157, 417, 3, 18, 24, 453, 761, 37, 36, 403, 396, 281, 25, 14, 45, 338, 12, 80, 7, 26, 7, 13, 340, 34, 187, 259, 201, 40, 222, 22, 2, 604, 162, 418, 235, 49, 8, 34, 664, 27, 16, 581, 26, 978, 35, 439, 4, 1, 64, 7, 170, 161, 3, 19, 603, 1, 90, 15, 112, 48, 49, 660, 324, 4, 18, 415, 14, 11, 662, 33, 486, 14, 25, 414, 602, 35, 230, 15, 1074, 1350, 580, 245, 276, 48, 0, 169, 30, 976, 601, 1172, 2873, 280, 80, 975, 213, 0, 1191, 3237, 3760, 132, 17, 10, 298, 5, 127, 494, 3, 24, 42, 13, 244, 174, 98, 518, 3, 41, 3, 6, 155, 500, 84, 685, 2211, 2012, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 85, 330, 56, 1111, 13, 205, 164, 427, 169, 334, 464, 238, 176, 58, 86, 16, 9, 297, 87, 6, 128, 489, 7, 329, 4, 330, 57, 25, 298, 299, 43, 12, 541, 68, 106, 97, 524, 294, 102, 565, 914, 218, 23, 0, 2, 5, 4, 19, 18, 86, 2, 5, 12, 204, 522, 293, 75, 154, 303, 87, 63, 63, 606, 1879, 175, 303, 83, 2847, 294, 8136, 0, 0, 0, 7, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 2, 1, 1, 2, 1, 1, 2, 1, 2, 2, 1, 2, 5, 1, 1, 1, 2, 1, 2, 1, 3, 1, 1, 2, 2, 1, 4, 3, 3, 2, 7, 1, 6, 1, 2, 2, 1, 1, 1, 3, 1, 9, 18, 2, 4, 3, 2, 5, 11, 2, 2, 11, 8, 18, 5, 1, 9, 8, 6, 3, 23, 21, 7, 41, 34, 2, 1, 10, 4, 1, 2, 53, 36, 5, 10, 2, 2, 5, 2, 53, 53, 4, 1, 3, 3, 22, 23, 8, 1, 1, 5, 4, 3, 1, 3, 6, 2, 5, 1, 3, 2, 4, 2, 2, 0, 81, 9, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 25, 7, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 7, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 3, 1, 2, 1, 1, 3, 2, 1, 31, 10, 14, 6, 16, 3, 4, 5, 1, 1, 47, 28, 13, 51, 1, 3, 2, 1, 2, 1, 1, 2, 9, 9, 20, 1, 56, 25, 60, 1, 1, 2, 2, 2, 21, 1, 1, 54, 157, 2, 2, 8, 7, 6, 5, 2, 2, 6, 2, 2, 1, 1, 149, 3, 1, 8, 1, 2, 3, 4, 4, 11, 1, 97, 2, 43, 11, 16, 15, 15, 8, 3, 4, 33, 55, 30, 10, 102, 170, 219, 3, 31, 250, 3, 23, 4, 5, 9, 8, 25, 16, 42, 2, 3, 4, 3, 2, 1, 15, 10, 4, 18, 18, 30, 6, 17, 1, 4, 2, 8, 7, 3, 11, 9, 11, 2, 6, 5, 11, 18, 15, 6, 2, 2, 5, 8, 5, 1, 8, 7, 13, 4, 9, 2, 6, 4, 1, 5, 3, 4, 11, 4, 4, 4, 5, 10, 13, 16, 2, 4, 8, 0, 6, 4, 15, 6, 12, 1, 0, 0, 3, 7, 2, 23, 0, 0, 36, 76, 5, 5, 29, 5, 0, 0, 0, 0, 0, 153, 14, 7, 70, 2, 2, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 67, 251, 1, 1, 12, 18, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 13, 1, 2, 0, 99, 3, 0, 0, 0, 0, 0, 0, 42, 2, 3, 6, 11, 3, 2, 1, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 1, 0, 12, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 1, 0, 1, 1, 0, 2, 1, 0, 2, 0, 1, 1, 1, 0, 1, 1, 4, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 0, 1, 1, 0, 1, 1, 1, 1, 0, 0, 2, 1, 2, 1, 3, 1, 2, 1, 2, 1, 2, 2, 2, 2, 2, 2, 2, 5, 1, 1, 1, 1, 1, 3, 3, 0, 1, 2, 1, 1, 2, 1, 0, 7, 1, 1, 1, 1, 1, 2, 4, 1, 3, 2, 1, 0, 1, 2, 1, 1, 2, 2, 4, 1, 2, 1, 1, 1, 0, 1, 4, 1, 2, 3, 1, 1, 3, 1, 1, 1, 1, 2, 6, 1, 1, 2, 3, 2, 3, 2, 1, 1, 2, 2, 1, 1, 1, 3, 4, 2, 1, 1, 4, 1, 5, 1, 1, 1, 2, 1, 1, 4, 1, 5, 2, 2, 1, 1, 1, 3, 1, 3, 1, 1, 1, 3, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 3, 1, 4, 6, 2, 2, 2, 1, 1, 2, 1, 1, 2, 4, 1, 5, 3, 2, 2, 2, 3, 1, 1, 2, 1, 9, 1, 1, 3, 2, 6, 2, 2, 1, 1, 2, 1, 1, 2, 5, 1, 1, 2, 1, 4, 1, 5, 2, 2, 2, 9, 1, 1, 3, 2, 2, 1, 3, 17, 4, 4, 7, 2, 1, 5, 2, 2, 2, 1, 12, 16, 3, 3, 5, 1, 2, 1, 1, 1, 0, 18, 11, 9, 9, 1, 2, 1, 3, 3, 3, 1, 1, 43, 21, 3, 3, 2, 3, 1, 5, 3, 1, 76, 17, 9, 1, 1, 9, 3, 2, 1, 5, 9, 3, 98, 47, 30, 9, 3, 7, 1, 1, 3, 1, 106, 25, 21, 6, 9, 2, 2, 2, 7, 2, 2, 8, 2, 0, 116, 56, 8, 10, 8, 4, 9, 9, 14, 14, 1, 0, 0, 0, 0, 129, 52, 2, 7, 3, 4, 14, 20, 0, 0, 0, 179, 9, 1, 3, 16, 11, 2, 3, 28, 36, 1, 0, 0, 0, 58, 28, 27, 26, 7, 1, 2, 4, 82, 90, 0, 0, 51, 11, 7, 1, 2, 4, 8, 3, 3, 0, 0, 0, 0, 13, 50, 1, 1, 9, 2, 4, 17, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 29, 3, 0, 0, 7, 6, 2, 4, 23, 13, 0, 0, 0, 0, 49, 33, 1, 0, 0, 0, 0, 10, 47, 6, 0, 0, 0, 0, 1, 1, 0, 0, 9, 1, 0, 3, 4, 2, 0, 0, 0, 2, 1, 0, 2, 8, 0, 18, 0, 0, 0, 8, 2, 7, 4, 4, 1, 0, 0, 6, 8, 0, 0, 0, 0, 0, 216, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 10, 5, 2, 2, 4, 2, 10, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 3, 1, 7, 4, 4, 2, 1, 3, 1, 2, 13, 12, 5, 2, 2, 2, 2, 5, 6, 16, 1, 1, 8, 7, 2, 1, 1, 2, 14, 18, 23, 3, 1, 32, 4, 3, 4, 2, 2, 6, 46, 2, 2, 3, 5, 2, 8, 2, 4, 2, 15, 31, 35, 15, 3, 1, 1, 2, 2, 1, 1, 2, 9, 1, 7, 1, 2, 10, 5, 3, 3, 3, 2, 2, 10, 3, 1, 3, 3, 2, 13, 6, 1, 3, 5, 0, 2, 2, 0, 1, 2, 2, 2, 4, 1, 2, 1, 2, 0, 12, 12, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 3, 2, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21, 2, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 5, 1, 1, 9, 1, 4, 1, 1, 4, 10, 2, 1, 1, 5, 1, 1, 2, 2, 13, 2, 1, 2, 3, 10, 8, 2, 1, 8, 1, 7, 2, 5, 3, 15, 5, 3, 4, 2, 8, 1, 4, 4, 1, 3, 1, 2, 1, 1, 1, 5, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 5, 4, 3, 2, 1, 1, 3, 6, 1, 2, 10, 21, 3, 2, 2, 1, 1, 4, 24, 1, 1, 4, 6, 1, 4, 2, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 4, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 0, 1, 1, 1, 0, 0, 2, 1, 1, 4, 1, 1, 4, 3, 1, 1, 2, 1, 1, 1, 2, 1, 1, 2, 3, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 2, 1, 3, 3, 2, 1, 5, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 3, 1, 2, 9, 2, 1, 1, 1, 2, 3, 1, 1, 2, 1, 3, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 2, 3, 1, 1, 4, 1, 1, 1, 2, 3, 3, 1, 1, 2, 1, 6, 1, 4, 1, 1, 1, 2, 2, 1, 2, 1, 1, 1, 3, 3, 1, 2, 1, 1, 6, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 6, 1, 2, 1, 2, 1, 1, 1, 5, 2, 2, 1, 1, 5, 1, 1, 1, 1, 1, 3, 1, 1, 8, 2, 12, 8, 1, 1, 6, 4, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 3, 8, 2, 1, 1, 1, 3, 2, 2, 1, 1, 1, 4, 1, 3, 2, 1, 1, 1, 1, 3, 3, 1, 1, 3, 2, 1, 1, 2, 2, 2, 6, 2, 2, 1, 1, 1, 1, 2, 2, 2, 1, 1, 5, 2, 2, 1, 1, 2, 2, 1, 3, 1, 3, 6, 2, 2, 1, 2, 4, 4, 1, 1, 3, 1, 2, 1, 3, 4, 5, 1, 5, 7, 4, 3, 2, 1, 1, 9, 2, 1, 1, 1, 2, 4, 9, 9, 2, 5, 2, 2, 2, 1, 3, 3, 2, 1, 2, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 7, 8, 2, 2, 0, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 1, 5, 1, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 4, 2, 0, 1, 3, 1, 1, 1, 1, 0, 0, 0, 9, 2, 1, 2, 2, 3, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 3, 2, 2, 4, 4, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 2, 1, 1, 0, 0, 0, 0, 0, 2, 1, 0, 1, 0, 0, 0, 2, 2, 1, 0, 1, 2, 0, 0, 0, 3, 1, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 1, 0, 2, 1, 0, 0, 2, 1, 1, 0, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 3, 1, 3, 7, 3, 1, 60, 2, 2, 1, 7, 6, 5, 13, 1, 3, 3, 0, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 4, 2, 0, 1, 0, 1, 2, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 3, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 2, 3, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 4, 1, 1, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 1, 4, 3, 1, 1, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 9, 3, 2, 5, 5, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 1, 1, 3, 7, 3, 2, 4, 3, 3, 36, 2, 1, 3, 1, 10, 10, 5, 11, 12, 1, 4, 2, 2, 2, 13, 47, 50, 88, 2, 1, 1, 1, 1, 1, 3, 3, 3, 10, 17, 1, 2, 2, 1, 5, 2, 2, 3, 1, 2, 1, 1, 2, 1, 0, 2, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 5, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 13, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 2, 0, 0, 0, 1, 2, 1, 0, 0, 1, 1, 2, 1, 33, 6, 4, 4, 1, 2, 3, 1, 4, 2, 1, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 1, 4, 3, 21, 3, 22, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 0, 3, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 1, 1, 1, 4, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 1, 1, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 9, 8, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 3, 2, 5, 1, 4, 3, 2, 2, 4, 3, 1, 1, 7, 1, 3, 4, 1, 8, 2, 2, 1, 3, 7, 7, 3, 4, 1, 3, 1, 5, 2, 15, 1, 1, 5, 10, 4, 2, 9, 3, 3, 4, 3, 34, 1, 1, 21, 3, 3, 2, 2, 2, 7, 1, 2, 3, 1, 13, 10, 11, 5, 1, 1, 2, 2, 9, 7, 61, 2, 1, 3, 5, 1, 3, 4, 1, 6, 22, 2, 2, 1, 1, 2, 2, 3, 5, 7, 1, 8, 5, 2, 6, 2, 3, 2, 7, 0, 1, 0, 1, 1, 0, 2, 1, 1, 0, 0, 5, 12, 1, 2, 0, 0, 0, 24, 0, 0, 0, 0, 0, 0, 8, 5, 9, 7, 2, 5, 2, 5, 6, 2, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 2, 1, 1, 0, 0, 0, 0, 3, 2, 1, 0, 0, 1, 1, 1, 0, 0, 1, 1, 2, 1, 0, 2, 1, 0, 1, 1, 2, 1, 0, 0, 3, 3, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 2, 2, 1, 1, 1, 0, 0, 0, 4, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 2, 2, 1, 4, 3, 6, 1, 2, 1, 9, 2, 1, 2, 1, 1, 2, 5, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 18, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 5, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 3, 1, 2, 1, 2, 1, 2, 2, 2, 1, 2, 1, 3, 1, 2, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 5, 0, 5, 4, 0, 1, 0, 1, 1, 0, 0, 1, 1, 6, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 2, 0, 0, 0, 1, 1, 0, 0, 1, 2, 9, 7, 1, 11, 3, 1, 1, 15, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 4, 0, 0, 3, 1, 0, 0, 0, 0, 1, 2, 1, 2, 4, 2, 2, 2, 1, 1, 1, 2, 1, 34, 10, 4, 1, 2, 5, 2, 1, 1, 1, 2, 2, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 4, 1, 2, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 5, 8, 2, 2, 2, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 1, 0, 0, 1, 2, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 1, 1, 1, 1, 1, 3, 3, 1, 1, 3, 4, 1, 2, 2, 1, 1, 5, 1, 3, 2, 1, 2, 2, 1, 4, 2, 1, 7, 1, 2, 2, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 4, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 7, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 3, 2, 0, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 1, 5, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 1, 2, 0, 0, 0, 1, 0, 3, 0, 0, 1, 2, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 2, 1, 4, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 8, 1, 2, 1, 1, 1, 1, 2, 3, 13, 4, 4, 4, 8, 2, 2, 20, 2, 10, 6, 9, 11, 1, 2, 3, 1, 3, 1, 1, 9, 1, 4, 3, 1, 7, 10, 2, 39, 1, 1, 2, 6, 5, 1, 2, 7, 2, 4, 3, 1, 1, 1, 5, 4, 2, 7, 5, 2, 3, 20, 1, 7, 57, 1, 1, 5, 1, 1, 0, 0, 1, 3, 1, 17, 1, 1, 0, 0, 0, 0, 2, 0, 1, 1, 4, 1, 0, 0, 0, 2, 1, 0, 5, 1, 1, 0, 0, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 3, 1, 5, 1, 15, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 6, 2, 39, 44, 9, 20, 2, 1, 3, 3, 4, 4, 3, 2, 1, 11, 6, 0, 0, 0, 8, 3, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 1, 1, 1, 1, 1, 1, 2, 1, 1, 0, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 1, 2, 1, 0, 1, 0, 0, 0, 2, 1, 47, 9907, 8170, 2583, 1295, 1378, 1382, 237, 1436, 276, 202, 2654, 389, 438, 841, 315, 113, 208, 66, 839, 60, 588, 156, 236, 488, 2441, 28759, 11766, 1967, 1298, 130, 229, 571, 841, 348, 557, 3271, 776, 1432, 553, 194, 1342, 493, 193, 888, 380, 216, 4433, 76, 795, 1565, 1680, 1300, 554, 930, 372, 557, 743, 411, 1574, 440, 2289, 761, 193, 46, 778, 781, 268, 3195, 334, 277, 556, 558, 557, 204, 558, 511, 539, 3060, 177, 6, 193, 191, 0, 427, 5, 0, 780, 40, 1314, 314, 112, 494, 206, 2, 38, 207, 67, 425, 670, 93, 61, 587, 538, 349, 237, 1332, 1144, 4005, 953, 61551, 1, 25148, 9800, 16154, 58621, 9969, 1788, 1587, 1050, 1943, 1728, 703, 234, 1002, 1462, 1220, 1100, 6114, 2562, 1791, 1149, 1006, 713, 2665, 220, 59, 220, 550, 6, 55, 338, 46, 17, 117, 84, 288, 215, 261, 7, 21, 25, 1505, 2747, 5601, 12819, 1344, 813, 1078, 75, 437, 297, 21, 18, 1325, 9179, 642, 189, 223, 152, 867, 4, 17859, 2373, 288, 904, 338, 504, 847, 47715, 1937, 3467, 2322, 6440, 5789, 149, 2668, 1343, 1773, 2937, 100, 8213, 6023, 3125, 350, 654, 1633, 1026, 167, 94, 114, 275, 310, 13, 103, 56, 6196, 9894, 348, 20669, 1509, 1137, 551, 2691, 2881, 1072, 1108, 1350, 4752, 3222, 2314, 225, 678, 312, 333, 305, 2515, 317, 2107, 1310, 441, 610, 1383, 956, 289, 297, 1594, 4370, 6920, 507, 182, 1725, 2224, 770, 240, 180, 204, 132, 1905, 568, 213, 1136, 460, 635, 135, 349, 207, 38, 6125, 340, 2966, 2487, 1754, 1578, 2690, 13020, 3077, 190, 345, 570, 1993, 321, 105, 308, 696, 280, 2817, 1176, 1367, 913, 3429, 6422, 3584, 463, 1529, 794, 1602, 852, 1, 638, 758, 381, 704, 150, 508, 3086, 846, 224, 18, 154, 2525, 721, 5666, 105, 1255, 442, 189, 1, 270, 1112, 561, 3794, 2902, 817, 588, 448, 893, 854, 664, 4222, 2787, 211, 869, 477, 1113, 495, 3903, 1996, 541, 983, 759, 374, 7726, 2841, 676, 561, 207, 858, 696, 195, 79, 39074, 10343, 5620, 3400, 865, 2679, 4076, 1896, 220, 353, 328, 230, 72, 131, 2, 156, 849, 21840, 10613, 5736, 7265, 8283, 4826, 644, 4226, 338, 583, 1691, 542, 329, 161, 303, 772, 167, 636, 693, 135, 179, 135, 2, 345, 3, 618, 178, 160, 11763, 7871, 5985, 6934, 3831, 2425, 294, 147, 807, 1366, 475, 153, 806, 322, 77, 212, 270, 7101, 7597, 6182, 3326, 2703, 336, 298, 335, 3184, 1518, 411, 46, 240, 1271, 239, 155, 4731, 9965, 5277, 4677, 384, 1866, 396, 1670, 478, 79, 115, 392, 32, 12558, 10283, 34, 5698, 95, 223, 489, 1048, 1428, 3, 287, 103, 404, 166, 50, 10, 225, 89, 23892, 3220, 7964, 1697, 2291, 785, 4841, 1875, 595, 1127, 231, 252, 4, 1029, 576, 1008, 170, 166, 293, 923, 5160, 15258, 3073, 4663, 4219, 5396, 4322, 4004, 1453, 2524, 4, 977, 24, 565, 1005, 347, 109, 979, 450, 97, 344, 214, 393, 185, 2105, 4894, 903, 657, 1177, 414, 853, 174, 8674, 4390, 5183, 5110, 5681, 3307, 4494, 3928, 450, 2113, 2371, 1138, 629, 614, 705, 2, 300, 442, 237, 54, 16, 731, 3035, 842, 1636, 1055, 1448, 1704, 1402, 178, 1553, 533, 473, 386, 525, 647, 252, 2079, 1859, 1533, 1534, 1186, 2281, 200, 2694, 239, 466, 414, 819, 385, 17, 183, 1045, 3462, 2261, 1274, 1377, 1207, 1057, 708, 1864, 499, 443, 235, 852, 435, 99, 397, 1903, 439, 5584, 3443, 1778, 2658, 1944, 1521, 1608, 1179, 1254, 511, 545, 278, 461, 348, 1165, 640, 211, 902, 128, 2, 4501, 5051, 2429, 6360, 162, 802, 1214, 959, 1170, 874, 69, 1058, 512, 178, 329, 1769, 5697, 4138, 833, 3758, 1330, 1703, 2111, 305, 387, 63, 138, 80, 241, 248, 191, 302, 164, 5052, 5621, 6071, 329, 699, 2558, 1511, 612, 931, 961, 2206, 1350, 11, 898, 589, 1730, 163, 803, 1072, 3424, 9637, 1655, 2220, 476, 3434, 1020, 7, 1085, 652, 259, 587, 1836, 165, 323, 268, 1207, 6915, 322, 382, 596, 222, 1365, 1024, 350, 444, 1032, 399, 76, 304, 562, 708, 5222, 524, 986, 6533, 10276, 5418, 3261, 1396, 515, 775, 1691, 2505, 759, 659, 607, 414, 213, 1288, 1363, 686, 1865, 6775, 624, 573, 151, 1087, 727, 321, 47, 592, 419, 522, 803, 556, 206, 383, 105, 201, 1093, 2367, 1644, 326, 1180, 717, 566, 1546, 4944, 1692, 8, 1926, 737, 3014, 847, 432, 1197, 75, 3237, 546, 493, 7585, 1843, 4175, 3624, 2279, 2220, 2488, 815, 4360, 878, 711, 299, 148, 3, 541, 1707, 3956, 3714, 4674, 2726, 5519, 421, 2795, 251, 1558, 544, 448, 1171, 1622, 116, 494, 7, 85, 1112, 5598, 997, 304, 1142, 1676, 1443, 5040, 2921, 1043, 2095, 3232, 543, 188, 76, 572, 214, 121, 289, 3073, 8198, 2245, 4122, 2962, 1706, 3818, 474, 101, 337, 957, 1931, 1980, 3285, 1802, 5584, 1344, 2591, 1607, 1432, 1164, 322, 1115, 1755, 1230, 5625, 2391, 1207, 513, 2183, 1037, 400, 690, 150, 1440, 3076, 98, 6852, 1969, 1466, 3318, 1427, 7470, 3057, 1663, 1042, 925, 289, 384, 781, 485, 753, 1418, 2296, 6237, 0, 2313, 609, 4531, 2071, 435, 1904, 2729, 604, 107, 443, 1178, 1120, 3937, 5443, 10544, 20385, 570, 348, 252, 877, 739, 434, 4396, 4070, 660, 164, 1, 350, 2097, 210, 2375, 4023, 2, 559, 661, 477, 1910, 684, 903, 3474, 1224, 606, 190, 1624, 1163, 288, 876, 1319, 385, 298, 0, 349, 100, 780, 1177, 338, 558, 3009, 958, 1743, 2768, 8377, 2182, 14390, 1099, 41546, 71404, 1215, 195, 3, 368, 59, 175, 220, 57, 25, 38, 6, 158, 55, 2, 165, 364, 137, 24, 177, 52, 39, 4, 0, 51, 386, 86, 319, 363, 2989, 0, 0, 0, 0, 0, 0, 11281, 1711, 2616, 972, 781, 523, 673, 942, 2227, 772, 1355, 527, 620, 1723, 1279, 1081, 3333, 734, 551, 1892, 256, 152, 773, 71, 657, 83, 1443, 280, 281, 194, 188, 1211, 155, 42, 384, 110, 71, 976, 549, 157, 372, 344, 523, 188, 254, 748, 167, 679, 438, 649, 982, 436, 1528, 1219, 4414, 560, 1472, 11205, 0, 857, 387, 199, 480, 870, 138, 206, 194, 542, 224, 377, 841, 147, 318, 405, 306, 400, 440, 616, 782, 1491, 217, 1994, 573, 125, 599, 256, 271, 271, 215, 108, 330, 622, 366, 149, 659, 161, 280, 772, 268, 442, 196, 128, 131, 262, 572, 192, 100, 83, 92, 586, 98, 214, 524, 353, 318, 237, 486, 274, 678, 145, 128, 207, 605, 166, 518, 338, 478, 490, 261, 108, 173, 219, 0, 355, 205, 137, 589, 202, 461, 159, 123, 204, 402, 354, 354, 39, 67, 236, 193, 158, 236, 267, 571, 335, 601, 365, 249, 467, 352, 160, 859, 250, 889, 190, 235, 1, 341, 259, 0, 204, 249, 505, 252, 148, 557, 115, 399, 266, 362, 776, 491, 478, 858, 158, 572, 194, 72, 538, 375, 398, 334, 361, 210, 248, 397, 372, 102, 265, 161, 238, 335, 231, 282, 319, 142, 648, 157, 582, 879, 658, 264, 257, 567, 124, 247, 162, 153, 353, 571, 169, 370, 604, 964, 832, 570, 659, 164, 108, 558, 600, 246, 97, 84, 191, 124, 85, 124, 364, 747, 567, 346, 393, 50, 365, 223, 376, 364, 840, 283, 334, 364, 193, 778, 189, 588, 625, 154, 125, 284, 251, 333, 232, 260, 317, 41, 406, 107, 235, 149, 236, 359, 283, 779, 271, 265, 95, 163, 215, 427, 519, 211, 308, 199, 153, 885, 170, 766, 255, 318, 162, 260, 110, 487, 569, 332, 568, 51, 91, 834, 522, 282, 259, 557, 228, 84, 151, 66, 270, 252, 363, 489, 331, 658, 840, 102, 362, 835, 76, 521, 170, 166, 466, 257, 161, 152, 353, 1242, 614, 436, 256, 599, 329, 198, 1079, 0, 363, 394, 255, 578, 259, 401, 254, 344, 1313, 307, 71, 1100, 655, 1699, 98, 1148, 4824, 0, 2776, 188, 1094, 1363, 2367, 6493, 13415, 945, 4759, 15646, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 3, 249, 149, 114, 1202, 61, 110, 137, 85, 41, 9, 14, 5, 81, 17, 25, 49, 196, 1563, 7732, 1, 1, 134, 121, 151, 119, 18, 29, 190, 1130, 36, 27, 112, 24, 135, 88, 42, 36, 28, 15, 6, 82, 18, 109, 51, 52, 74, 128, 1928, 4, 1834, 603, 93, 730, 46, 203, 372, 126, 131, 495, 521, 793, 63, 280, 614, 662, 1760, 805, 63, 406, 670, 721, 575, 54, 65, 38, 273, 84, 81, 3, 100, 112, 296, 61, 63, 204, 15, 71, 109, 47, 111, 525, 666, 8191, 1, 395, 103, 93, 146, 139, 87, 133, 759, 91, 83, 36, 51, 126, 225, 51, 44, 54, 28, 65, 281, 396, 131, 184, 47, 160, 45, 115, 169, 66, 82, 81, 48, 132, 414, 104, 2, 3, 34, 48, 116, 160, 13, 176, 156, 479, 98, 79, 9, 61, 90, 101, 64, 126, 415, 328, 96, 399, 117, 2, 16, 49, 427, 84, 5, 153, 5, 125, 362, 67, 39, 105, 54, 203, 68, 9, 83, 38, 46, 183, 526, 411, 97, 319, 67, 55, 24, 38, 8, 54, 168, 44, 52, 69, 17, 255, 46, 140, 10, 6, 48, 281, 107, 397, 11, 67, 52, 107, 56, 193, 153, 410, 114, 93, 266, 64, 132, 126, 258, 164, 4, 102, 50, 145, 362, 169, 3, 7, 128, 2, 42, 14, 111, 296, 288, 50, 162, 2, 119, 127, 250, 202, 419, 74, 60, 38, 99, 23, 652, 52, 56, 62, 117, 7, 25, 163, 222, 163, 218, 68, 66, 162, 49, 282, 129, 108, 135, 110, 30, 2, 80, 462, 2, 2, 283, 3, 56, 80, 3, 2, 3, 109, 8, 3, 3, 113, 89, 416, 4, 185, 68, 62, 118, 48, 98, 13, 1, 66, 53, 127, 414, 123, 214, 229, 0, 54, 38, 162, 97, 60, 80, 282, 155, 52, 65, 57, 49, 143, 229, 44, 67, 139, 85, 387, 0, 41, 39, 53, 274, 56, 164, 161, 111, 40, 344, 192, 396, 47, 36, 296, 538, 642, 250, 49, 8, 87, 467, 136, 43, 176, 413, 267, 37, 131, 232, 190, 346, 803, 23, 463, 2224, 249, 0, 800, 299, 796, 326, 428, 162, 815, 1921, 2754, 165, 40, 35, 23, 31, 125, 83, 11, 66, 142, 5, 63, 80, 5, 31, 36, 17, 30, 111, 51, 180, 144, 648, 422, 3737, 108, 2763, 0, 0, 27, 58, 26, 16, 16, 45, 56, 515, 80, 1092, 28, 700, 45, 64, 21, 29, 39, 46, 36, 26, 22, 57, 32, 0, 126, 82, 45, 10, 42, 22, 60, 80, 25, 4, 15, 64, 81, 15, 4, 32, 39, 16, 80, 29, 102, 7, 49, 28, 107, 87, 89, 27, 85, 106, 60, 148, 612, 30, 601, 584, 13, 163, 328, 6379, 0, 490, 0, 8, 3, 10, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 16, 1, 1, 1, 32, 2, 2, 2, 1, 17, 1, 0, 0, 0, 16, 18, 31614, 3811, 3025, 225, 877, 581, 793, 377, 516, 1160, 76, 38, 161, 892, 127, 513, 112, 412, 576, 367, 128, 103, 704, 169, 141, 236, 112, 923, 17558, 12690, 81, 1292, 2315, 903, 3128, 302, 1092, 425, 614, 317, 835, 494, 767, 233, 497, 1017, 13313, 4372, 617, 452, 672, 563, 178, 264, 2246, 137, 426, 447, 517, 697, 281, 619, 1924, 1076, 680, 267, 273, 167, 1081, 1361, 230, 1233, 626, 1377, 303, 1109, 441, 1795, 361, 378, 97, 334, 273, 12, 336, 310, 1121, 20, 0, 0, 0, 0, 78, 47, 478, 662, 2701, 868, 126, 514, 114, 493, 413, 502, 73, 442, 366, 231, 129, 103, 266, 2, 2227, 1273, 170, 235, 698, 142, 233, 492, 759, 1149, 2560, 847, 53725, 67318, 6962, 3969, 16514, 2413, 10850, 4849, 652, 798, 723, 494, 628, 357, 1200, 2346, 1652, 12532, 2306, 602, 417, 2927, 92, 203, 6, 221, 12, 1, 55, 34, 270, 60, 68, 58, 18, 2, 30, 1, 4, 24, 3, 6, 2, 3, 11388, 545, 11913, 1385, 4879, 8955, 312, 793, 390, 650, 187, 139, 182, 988, 949, 363, 2799, 350, 18669, 498, 2129, 486, 1114, 1591, 89, 52, 67, 173, 18, 1, 197, 5, 39, 22, 18, 2, 39, 15, 10, 2, 8, 13, 14, 410, 3787, 536, 3791, 2017, 616, 651, 560, 1603, 3468, 460, 503, 783, 1160, 1022, 328, 1627, 15, 869, 6502, 4941, 734, 760, 938, 5509, 1026, 8717, 2154, 241, 628, 18, 1, 50, 2, 536, 337, 455, 1720, 1601, 443, 123, 1, 2913, 789, 637, 556, 922, 538, 693, 3707, 1624, 1341, 13328, 189, 171, 96, 142, 131, 1, 785, 304, 274, 646, 1843, 512, 969, 1232, 1319, 341, 765, 14409, 1497, 50, 146, 790, 786, 617, 654, 311, 797, 305, 652, 275, 324, 1833, 944, 276, 647, 649, 791, 2527, 511, 923, 456, 140, 152, 1657, 1184, 2201, 796, 1371, 2797, 505, 950, 2341, 255, 8152, 915, 51, 183, 1625, 14766, 1006, 139, 27, 8195, 831, 86, 826, 2, 5127, 75587, 12951, 11717, 14297, 114, 93, 121, 33, 19, 3739, 1501, 1430, 28, 17, 35700, 20426, 34207, 45, 49, 9, 200, 21893, 30061, 2, 4, 55767, 56, 49, 21, 5, 74735, 38958, 7784, 840, 10011, 1254, 397, 1423, 409, 1267, 55, 2942, 67, 83, 43, 15, 21, 5, 5, 58455, 6237, 272, 5939, 1945, 988, 219, 731, 25, 44022, 2953, 33476, 8544, 819, 4002, 1423, 281, 1763, 107, 73, 24, 6524, 37979, 7069, 790, 515, 1306, 1493, 2231, 44, 17, 9556, 740, 272, 55940, 6139, 13175, 12718, 1707, 1324, 381, 5453, 55, 66, 31, 1, 11519, 28084, 17791, 8857, 1045, 8147, 8, 17, 11423, 1112, 3747, 866, 2457, 2, 35, 32609, 11625, 2646, 9, 11895, 72, 7, 33, 0, 37069, 10038, 1013, 20106, 3, 33, 3, 0, 12521, 1572, 50879, 168, 363, 149, 309, 80, 163, 6, 7, 65, 1, 3243, 24926, 195, 13, 21, 15, 2, 6256, 9, 17097, 7901, 68861, 676, 19417, 10266, 1723, 470, 7830, 1125, 133, 199, 3, 132, 43, 14, 15, 7, 842, 11367, 1140, 1367, 1956, 400, 6070, 841, 389, 1029, 120, 280, 6, 6288, 46247, 14465, 3765, 1311, 13644, 533, 49, 1, 42, 68, 8, 7, 5, 0, 0, 6772, 1318, 329, 526, 48438, 8905, 1528, 14708, 886, 28, 109, 19, 2, 35, 1, 22557, 9163, 44708, 149, 373, 191, 303, 34, 9, 0, 6082, 30765, 412, 369, 16242, 1691, 49, 336, 130, 195, 28, 12, 41, 58, 2, 5, 119831, 5211, 860, 93, 1460, 398, 17, 85, 17, 1, 102522, 2333, 3654, 13201, 76, 846, 210, 467, 188, 69, 34, 6, 14, 0, 0, 22740, 18995, 64868, 168, 937, 285, 115, 25, 49, 0, 4090, 20769, 233, 863, 38, 67, 76, 1, 25686, 247, 793, 36, 0, 24361, 96143, 2831, 880, 189, 464, 86, 65, 61, 63, 0, 0, 23896, 756, 229, 104, 37, 113208, 4678, 462, 4229, 140, 10, 55, 13, 98048, 3393, 14464, 367, 68, 70, 1, 23866, 78911, 163, 84, 10, 27842, 32, 121365, 157, 1328, 93, 36, 706, 32, 7, 21, 1, 2, 2, 14669, 6146, 95846, 1046, 36, 2183, 12, 79, 14641, 293, 6131, 57735, 13587, 3947, 2918, 38298, 60, 6, 45, 17369, 4872, 1121, 35347, 0, 1326, 3996, 25633, 1, 653, 9468, 8735, 87515, 2109, 3478, 1271, 6258, 8014, 3523, 4, 1, 2, 18679, 26694, 4410, 18381, 17154, 1794, 7803, 1657, 9575, 1504, 195, 7349, 22923, 6742, 860, 9027, 5072, 555, 1, 0, 64195, 1737, 101526, 1, 43062, 606, 393, 363, 236, 122, 307, 793, 177, 756, 245, 769, 503, 1525, 42, 311, 23, 751, 112, 413, 805, 124, 412, 84, 283, 279, 213, 138, 145, 155, 101, 2385, 290, 249, 116, 2294, 194, 7, 466, 30, 278, 370, 47, 183, 256, 483, 526, 144, 5350, 0, 1982, 1396, 701, 600, 611, 2752, 149, 2442, 639, 1595, 2440, 1940, 839, 208, 1019, 120, 99, 583, 86, 158, 430, 711, 243, 420, 252, 317, 365, 256, 88, 366, 444, 165, 516, 219, 398, 4573, 192, 314, 225, 1522, 65, 1145, 219, 216, 86, 46, 199, 253, 411, 242, 1271, 6090, 1109, 124, 175, 176, 316, 681, 528, 231, 358, 88, 148, 270, 160, 291, 122, 412, 175, 65, 235, 507, 29, 196, 96, 120, 208, 401, 227, 78, 365, 125, 939, 132, 527, 673, 678, 414, 80, 117, 148, 176, 290, 847, 334, 289, 364, 347, 230, 82, 301, 372, 67, 483, 271, 318, 721, 258, 244, 381, 359, 148, 320, 124, 316, 187, 321, 185, 4, 347, 298, 817, 250, 215, 146, 352, 84, 341, 499, 123, 1022, 526, 174, 146, 545, 66, 480, 499, 232, 483, 86, 157, 722, 538, 762, 93, 226, 542, 403, 0, 0, 506, 171, 161, 353, 363, 131, 41, 207, 402, 491, 68, 279, 416, 505, 250, 214, 123, 542, 119, 8, 13, 0, 401, 566, 105, 364, 98, 346, 552, 372, 101, 209, 94, 400, 87, 174, 159, 439, 145, 100, 231, 792, 347, 132, 200, 173, 110, 500, 411, 242, 259, 243, 86, 221, 69, 498, 241, 3, 329, 112, 253, 233, 567, 442, 353, 256, 43, 227, 347, 254, 489, 186, 120, 161, 106, 322, 170, 89, 484, 142, 258, 308, 212, 259, 367, 580, 242, 164, 143, 83, 90, 63, 515, 105, 184, 630, 181, 218, 340, 232, 254, 397, 169, 2, 30319, 2746, 571, 297, 2051, 293, 184, 450, 167, 139, 209, 352, 1338, 1551, 2184, 1520, 4503, 25170, 1306, 103, 3116, 777, 16224, 360, 40, 461, 522, 8383, 2711, 191, 582, 257, 12227, 5643, 672, 235, 104, 259, 12, 482, 153, 312, 339, 504, 124, 1382, 1321, 370, 84, 289, 813, 1523, 349, 471, 1283, 4568, 410, 292, 152, 1120, 987, 588, 128, 351, 77, 226, 283, 752, 1796, 83, 234, 426, 131, 182, 255, 72, 661, 1781, 277, 587, 122, 1034, 472, 233, 167, 226, 595, 790, 75, 425, 85, 1070, 208, 334, 351, 332, 256, 707, 573, 1388, 571, 531, 920, 767, 1088, 959, 3011, 2319, 24910, 2154, 5014, 25826, 14948, 39679, 23, 5, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 426, 67, 4641, 252, 290, 32, 47, 53, 83, 1587, 8760, 8816, 1, 29, 93, 199, 143, 68, 123, 27, 105, 873, 2569, 1069, 380, 90, 232, 33, 48, 104, 54, 85, 1442, 1254, 13480, 5119, 4420, 763, 1598, 5031, 614, 747, 1689, 1790, 202, 436, 94, 88, 106, 850, 213, 138, 599, 654, 82, 454, 159, 257, 278, 102, 156, 309, 282, 236, 795, 559, 453, 645, 1032, 1182, 346, 1111, 239, 630, 46, 659, 1075, 1274, 55, 749, 4242, 256, 2195, 172, 56, 38, 1469, 203, 464, 255, 218, 54, 115, 33, 1, 76, 18, 472, 4165, 1, 265, 949, 239, 74, 534, 88, 113, 125, 209, 88, 352, 368, 177, 199, 217, 143, 57, 98, 72, 43, 758, 366, 831, 847, 301, 391, 232, 266, 90, 129, 261, 96, 151, 14, 283, 113, 143, 62, 138, 108, 236, 198, 133, 131, 84, 13, 61, 51, 126, 475, 350, 445, 301, 307, 232, 143, 190, 375, 418, 1757, 554, 329, 178, 306, 374, 129, 277, 151, 312, 1, 109, 104, 90, 214, 98, 406, 394, 10, 137, 144, 146, 46, 106, 290, 351, 182, 196, 240, 2, 352, 4, 65, 45, 39, 115, 388, 795, 352, 75, 420, 324, 66, 166, 1032, 392, 298, 469, 409, 114, 535, 6, 412, 252, 353, 186, 324, 353, 392, 94, 111, 87, 199, 184, 531, 254, 155, 171, 74, 4, 118, 355, 222, 1414, 89, 408, 116, 300, 99, 112, 36, 260, 330, 179, 387, 180, 100, 26, 307, 378, 470, 114, 300, 495, 89, 134, 181, 653, 160, 95, 101, 130, 89, 713, 413, 313, 241, 303, 294, 233, 114, 132, 414, 55, 33, 435, 417, 278, 110, 116, 267, 123, 92, 622, 443, 139, 114, 342, 248, 51, 142, 828, 536, 83, 126, 415, 27, 35, 242, 255, 453, 89, 9, 1, 157, 0, 5, 225, 30, 321, 279, 172, 44, 50, 50, 3, 0, 416, 128, 110, 156, 103, 210, 104, 49, 55, 85, 133, 180, 537, 109, 127, 155, 28, 141, 302, 254, 281, 301, 143, 76, 73, 237, 267, 28, 54, 102, 138, 14, 206, 193, 156, 0, 262, 95, 425, 170, 32, 392, 106, 144, 97, 136, 0, 2, 306, 186, 112, 97, 481, 34, 84, 654, 44, 287, 236, 417, 213, 520, 226, 101, 85, 52, 536, 347, 38, 1287, 388, 95, 24, 87, 84, 152, 1, 637, 100, 451, 97, 188, 902, 325, 402, 160, 235, 291, 4, 31, 124, 184, 143, 235, 187, 96, 6, 242, 46, 252, 151, 187, 0, 348, 11, 50, 633, 716, 48, 181, 354, 137, 50, 212, 9, 285, 1478, 165, 416, 109, 186, 105, 772, 133, 72, 45, 282, 115, 101, 1, 611, 450, 613, 493, 185, 0, 54, 182, 117, 373, 435, 429, 1518, 176, 114, 32, 39, 112, 169, 231, 451, 1330, 204, 118, 201, 180, 437, 229, 725, 190, 46, 2823, 360, 292, 201, 142, 127, 904, 91, 4687, 123, 815, 813, 1081, 2580, 261, 1821, 285, 144, 137, 155, 289, 78, 124, 204, 257, 278, 499, 146, 192, 133, 322, 243, 6785, 150, 312, 596, 54, 200, 257, 92, 326, 484, 237, 145, 2604, 153, 224, 462, 233, 133, 173, 255, 314, 14, 128, 161, 376, 268, 5343, 282, 1, 204, 111, 10, 283, 245, 539, 34, 417, 113, 174, 809, 654, 226, 1, 2, 54, 47, 649, 442, 71, 102, 119, 326, 56, 748, 236, 84, 189, 699, 923, 1365, 293, 293, 98, 130, 117, 91, 330, 205, 340, 7199, 117, 114, 36, 228, 137, 246, 103, 303, 64, 934, 285, 190, 379, 40, 330, 266, 60, 118, 234, 2894, 197, 944, 576, 219, 253, 547, 380, 194, 294, 964, 293, 994, 134, 249, 191, 882, 3, 181, 1089, 248, 265, 129, 1039, 409, 118, 123, 149, 418, 1424, 259, 35, 0, 183, 752, 302, 448, 249, 168, 266, 417, 136, 186, 1460, 128, 117, 255, 191, 313, 42, 30, 64, 91, 129, 245, 265, 259, 206, 320, 53, 416, 244, 299, 776, 404, 695, 462, 258, 4271, 5817, 471, 1092, 120, 184, 50, 465, 79, 155, 86, 290, 269, 82, 0, 50, 216, 571, 289, 113, 800, 75, 794, 947, 1599, 1108, 873, 11275, 0, 0, 0, 0, 0, 0, 72, 256, 153, 237, 292, 101, 169, 218, 50, 148, 28, 339, 409, 572, 61, 2627, 216, 321, 152, 67, 101, 111, 115, 40, 27, 716, 118, 154, 98, 84, 51, 236, 206, 87, 153, 137, 203, 100, 124, 78, 136, 154, 253, 289, 96, 170, 8, 10, 67, 422, 44, 9, 22, 115, 9, 252, 135, 202, 183, 193, 481, 150, 137, 133, 143, 152, 357, 226, 118, 221, 38, 275, 101, 137, 780, 1018, 307, 142, 126, 1461, 637, 71, 3017, 411, 2493, 1739, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 2, 184, 6, 79, 4, 13, 2, 3, 79, 102, 2, 6, 393, 1, 1, 51, 35, 29, 158, 1, 35, 8, 1742, 3069, 992, 263, 1005, 23, 100, 21, 3141, 2973, 1, 978, 269, 77, 25, 345, 66, 798, 483, 663, 65, 32, 1441, 624, 163, 295, 1037, 595, 197, 657, 144, 303, 27, 117, 1380, 362, 66, 26, 72, 31, 305, 28, 60, 215, 8758, 10394, 1187, 1682, 6062, 6360, 745, 1312, 71, 127, 871, 281, 215, 192, 114, 327, 87, 131, 25, 56, 132, 205, 49, 67, 19, 41, 33, 5, 125, 41, 8, 220, 92, 74, 277, 37, 14, 25, 132, 34, 4, 141, 126, 29, 52, 9, 114, 98, 52, 235, 23, 8, 16, 177, 556, 88, 4, 20, 15, 890, 3, 14, 9, 89, 1373, 1093, 4245, 1165, 278, 173, 300, 46, 623, 88, 52, 154, 194, 13, 20, 362, 43, 124, 43, 69, 16, 617, 1106, 321, 366, 28, 31, 117, 2524, 82, 253, 194, 65, 2, 103, 53, 13, 75, 32, 19, 8708, 1047, 1167, 77, 137, 35, 1002, 369, 246, 223, 153, 113, 34, 71, 49, 52, 230, 91, 58, 210, 3627, 1643, 115, 582, 237, 4083, 805, 1017, 66, 721, 206, 115, 294, 116, 96, 241, 34, 59, 201, 7, 313, 172, 61, 63, 177, 187, 292, 13, 109, 200, 30, 99, 90, 26, 256, 114, 65, 269, 26, 2625, 64, 531, 135, 212, 222, 239, 401, 41, 36, 62, 121, 309, 18, 62, 17, 290, 45, 22, 195, 59, 55, 227, 20, 278, 2010, 255, 184, 913, 467, 57, 79, 141, 183, 108, 77, 78, 131, 84, 60, 186, 33, 222, 141, 139, 84, 115, 112, 17, 78, 13, 17, 114, 203, 59, 179, 26, 176, 16, 78, 72, 110, 199, 81, 72, 188, 1246, 217, 150, 249, 79, 154, 113, 128, 130, 8, 138, 203, 67, 50, 174, 38, 122, 107, 126, 141, 33, 183, 301, 179, 36, 427, 101, 43, 36, 36, 1318, 182, 178, 1339, 825, 418, 326, 356, 254, 191, 246, 222, 130, 242, 92, 254, 48, 61, 33, 368, 72, 105, 652, 91, 166, 973, 436, 127, 535, 180, 499, 25, 161, 93, 124, 277, 28, 265, 105, 81, 120, 241, 160, 75, 88, 200, 215, 223, 56, 100, 35, 94, 78, 33, 97, 37, 45, 103, 42, 167, 146, 233, 126, 774, 138, 26, 58, 246, 82, 77, 11, 876, 751, 224, 224, 258, 229, 77, 191, 505, 137, 402, 216, 877, 190, 144, 316, 106, 12, 154, 122, 683, 239, 108, 306, 290, 35, 42, 340, 403, 80, 80, 752, 27, 73, 16, 217, 128, 41, 92, 59, 328, 102, 132, 362, 155, 175, 75, 404, 73, 114, 38, 327, 349, 26, 117, 1, 109, 94, 73, 125, 78, 9, 130, 363, 218, 181, 2, 35, 97, 271, 357, 81, 79, 31, 242, 57, 129, 129, 500, 29, 35, 101, 155, 255, 33, 18, 58, 35, 59, 98, 10, 190, 878, 20, 26, 114, 160, 34, 61, 39, 30, 284, 247, 0, 1, 127, 39, 145, 16, 155, 187, 18, 364, 195, 10, 83, 15, 72, 120, 233, 217, 25, 51, 221, 34, 83, 6, 133, 91, 126, 66, 65, 289, 335, 216, 220, 96, 59, 405, 212, 243, 100, 86, 278, 259, 237, 32, 1, 33, 96, 91, 34, 90, 12, 118, 44, 237, 35, 2, 185, 40, 137, 52, 127, 54, 227, 14, 37, 52, 64, 67, 0, 9, 72, 17, 7, 80, 242, 43, 10, 11, 19, 177, 26, 79, 48, 24, 0, 83, 64, 202, 204, 34, 73, 136, 21, 848, 174, 82, 20, 63, 753, 76, 66, 105, 58, 0, 38, 124, 2, 185, 96, 20, 30, 142, 95, 118, 302, 545, 134, 114, 189, 180, 54, 18, 98, 165, 6, 365, 155, 113, 137, 138, 133, 25, 317, 43, 403, 156, 227, 79, 166, 71, 53, 3, 501, 0, 303, 880, 684, 65, 217, 119, 40, 547, 53, 170, 157, 881, 428, 240, 18, 222, 205, 344, 218, 506, 288, 970, 442, 147, 401, 116, 156, 301, 203, 211, 157, 135, 64, 11, 83, 117, 167, 128, 184, 19, 58, 265, 380, 320, 240, 62, 546, 227, 158, 109, 82, 53, 101, 74, 129, 87, 754, 322, 92, 656, 121, 110, 279, 185, 53, 144, 1213, 40, 260, 254, 686, 327, 1161, 205, 146, 315, 221, 90, 309, 161, 827, 116, 115, 31, 19, 156, 235, 186, 93, 190, 99, 200, 181, 97, 216, 20, 527, 54, 19, 462, 162, 96, 255, 665, 84, 41, 319, 598, 148, 216, 995, 127, 21, 470, 189, 16, 1402, 1759, 137, 64, 199, 110, 45, 77, 37, 837, 348, 391, 223, 199, 202, 685, 80, 17, 386, 1, 1753, 1, 50, 18, 66, 125, 58, 1, 1283, 162, 694, 719, 217, 451, 745, 141, 329, 48, 300, 681, 282, 259, 129, 124, 867, 79, 105, 302, 104, 5, 494, 878, 10244, 33, 113, 276, 217, 83, 98, 938, 225, 150, 600, 110, 652, 326, 215, 188, 51, 259, 401, 506, 15, 27, 466, 328, 78, 443, 327, 93, 847, 18, 923, 283, 65, 74, 52, 82, 260, 1, 124, 128, 125, 866, 16, 52, 335, 109, 327, 107, 122, 411, 1, 659, 606, 266, 3, 2, 2, 1395, 36, 2199, 10499, 538, 43, 106, 219, 73, 30, 219, 120, 1814, 148, 566, 298, 675, 163, 427, 5927, 0, 0, 0, 0, 1584, 278, 94, 243, 20, 362, 182, 2714, 30, 422, 95, 569, 315, 527, 2888, 0, 352, 117, 103, 710, 102, 266, 46, 405, 34, 42, 116, 350, 124, 104, 93, 63, 70, 170, 83, 39, 64, 116, 80, 151, 81, 27, 236, 345, 144, 79, 46, 34, 73, 103, 1256, 133, 921, 238, 175, 2790, 0, 146, 231, 410, 742, 87, 1240, 16, 240, 61, 609, 173, 879, 2677, 81, 1421, 2291, 35, 4, 2, 18, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 5318, 410, 634, 545, 2983, 217, 293, 199, 2, 4, 53, 2, 5, 104, 113, 206, 371, 10252, 6591, 3, 4, 387, 103, 1992, 285, 283, 45, 1862, 416, 2, 133, 144, 440, 86, 104, 640, 509, 38, 126, 367, 342, 85, 3685, 926, 233, 586, 585, 201, 284, 1, 2, 4, 0, 0, 1, 343, 0, 84, 6, 105, 77, 38, 268, 71, 334, 231, 20354, 17558, 2380, 2438, 468, 75, 186, 27, 297, 1652, 316, 408, 1913, 251, 410, 478, 947, 263, 541, 49, 400, 2095, 4604, 2681, 2342, 600, 242, 608, 353, 401, 1064, 155, 1335, 250, 10, 328, 828, 95, 1002, 308, 212, 79, 141, 123, 200, 123, 136, 109, 135, 239, 1, 39, 254, 278, 25, 1, 182, 144, 292, 368, 1013, 2067, 1, 1, 914, 1461, 43, 453, 185, 251, 188, 165, 490, 42, 146, 73, 337, 3318, 2110, 1933, 470, 309, 16, 215, 343, 620, 71, 151, 270, 287, 109, 260, 65, 430, 156, 192, 274, 33, 5, 1786, 129, 684, 366, 223, 336, 620, 289, 82, 130, 129, 134, 61, 140, 303, 132, 658, 226, 1464, 536, 102, 253, 166, 31, 176, 199, 271, 44, 200, 11, 66, 1, 401, 161, 81, 186, 304, 28, 185, 298, 685, 747, 252, 9, 7, 1027, 259, 56, 410, 210, 596, 947, 270, 31, 367, 246, 82, 659, 148, 105, 412, 376, 222, 270, 179, 301, 147, 227, 669, 158, 130, 39, 305, 264, 45, 326, 164, 52, 686, 147, 224, 48, 208, 223, 74, 26, 92, 71, 8, 568, 1207, 537, 597, 297, 170, 149, 82, 8, 17, 52, 5229, 1009, 1561, 716, 830, 348, 419, 47, 661, 123, 74, 571, 101, 298, 219, 446, 145, 8, 208, 215, 375, 438, 2070, 276, 1221, 412, 931, 673, 1175, 162, 1180, 68, 8, 749, 26, 29, 260, 868, 1813, 609, 212, 14, 403, 152, 41, 61, 534, 1373, 424, 867, 553, 1220, 999, 146, 249, 114, 572, 30, 102, 300, 354, 463, 4, 2, 499, 187, 323, 201, 268, 300, 208, 1080, 161, 161, 1277, 79, 4, 285, 221, 278, 2, 51, 914, 129, 157, 601, 18, 359, 74, 237, 58, 367, 511, 22, 634, 82, 8, 172, 107, 4, 480, 6, 46, 424, 108, 326, 345, 176, 134, 33, 1266, 267, 574, 68, 140, 370, 68, 3, 155, 322, 86, 162, 299, 183, 17, 15, 624, 2, 624, 523, 449, 61, 452, 0, 746, 544, 289, 131, 170, 274, 4, 368, 0, 1265, 1676, 33, 249, 172, 0, 286, 342, 92, 941, 54, 9, 263, 213, 210, 145, 56, 143, 2, 221, 107, 305, 139, 46, 269, 901, 995, 19, 156, 8, 339, 145, 1180, 853, 638, 1257, 166, 1, 229, 227, 245, 26, 216, 161, 202, 336, 279, 175, 174, 2, 427, 429, 0, 0, 80, 1050, 111, 165, 197, 351, 209, 233, 70, 27, 218, 97, 60, 371, 526, 129, 193, 123, 27, 150, 88, 506, 325, 616, 1485, 281, 320, 862, 130, 269, 10, 194, 91, 0, 243, 621, 13, 864, 366, 48, 178, 463, 307, 227, 440, 1740, 0, 244, 149, 735, 65, 1014, 383, 1, 312, 106, 70, 304, 202, 1511, 881, 861, 358, 351, 119, 46, 245, 597, 80, 1185, 994, 192, 78, 165, 1691, 242, 449, 827, 325, 166, 150, 148, 685, 9, 102, 961, 2546, 2570, 105, 110, 49, 478, 877, 143, 325, 1, 482, 401, 1044, 0, 961, 66, 458, 242, 150, 80, 4399, 1032, 478, 275, 70, 46, 171, 209, 429, 174, 945, 173, 1, 117, 8, 1053, 2151, 0, 2754, 990, 797, 111, 233, 68, 657, 423, 515, 6, 1467, 2, 91, 253, 141, 130, 137, 4741, 0, 557, 1153, 451, 827, 1423, 27, 109, 2294, 536, 109, 129, 127, 412, 149, 6, 392, 1486, 184, 199, 323, 48, 410, 428, 538, 73, 1357, 1, 212, 13, 55, 215, 495, 354, 344, 460, 3, 114, 72, 491, 3, 207, 475, 230, 1562, 402, 366, 238, 175, 160, 170, 361, 876, 439, 127, 684, 529, 422, 401, 201, 322, 0, 546, 201, 181, 119, 1528, 252, 421, 1247, 487, 151, 1021, 244, 400, 273, 945, 229, 126, 321, 3545, 39, 571, 174, 228, 649, 683, 8, 991, 439, 863, 1528, 657, 943, 1272, 1, 0, 990, 802, 148, 524, 266, 171, 261, 1861, 1144, 0, 0, 1257, 1010, 1995, 2, 8, 0, 275, 2902, 872, 812, 1693, 1046, 9450, 1, 13758, 126, 929, 87, 296, 307, 311, 83, 1006, 969, 376, 234, 57, 677, 679, 35, 72, 3, 127, 160, 28, 42, 105, 58, 133, 69, 84, 24, 201, 28, 43, 107, 0, 79, 246, 178, 222, 303, 145, 118, 285, 198, 315, 233, 1271, 3678, 0, 0, 0, 0, 0, 0, 0, 0, 33, 1232, 151, 780, 504, 367, 1623, 1333, 902, 32, 743, 660, 133, 32, 103, 5, 33, 16, 88, 182, 67, 63, 572, 74, 557, 412, 937, 1934, 88, 70, 130, 82, 503, 802, 99, 232, 293, 129, 150, 85, 251, 137, 119, 21, 342, 140, 56, 290, 28, 342, 49, 148, 77, 0, 149, 137, 216, 149, 169, 82, 380, 301, 235, 425, 22, 26, 270, 435, 155, 198, 100, 62, 0, 103, 136, 71, 662, 82, 213, 31, 33, 0, 106, 809, 204, 128, 408, 0, 92, 160, 147, 107, 138, 265, 236, 57, 127, 640, 482, 0, 91, 87, 78, 61, 0, 321, 101, 57, 132, 31, 0, 236, 101, 90, 253, 29, 159, 226, 112, 108, 64, 160, 169, 394, 67, 373, 592, 164, 205, 104, 85, 210, 142, 213, 281, 64, 1130, 634, 100, 89, 34, 81, 73, 136, 2, 126, 212, 252, 237, 266, 30, 21, 159, 160, 134, 79, 27, 102, 106, 71, 41, 313, 4, 163, 106, 12, 250, 132, 265, 126, 98, 83, 38, 166, 187, 29, 0, 225, 41, 264, 1, 88, 106, 103, 22, 111, 298, 84, 118, 78, 105, 78, 107, 308, 178, 45, 118, 269, 77, 83, 197, 10, 181, 263, 159, 105, 220, 551, 324, 95, 141, 271, 268, 205, 57, 512, 267, 523, 283, 66, 605, 643, 292, 146, 94, 3162, 774, 1544, 1140, 13198, 46, 15, 6, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 8, 1, 1, 0, 0, 0, 0, 0, 1, 4, 46, 13, 1, 43, 14, 5, 24, 11, 7, 39, 2, 9, 5, 1, 6, 11, 884, 2, 1, 49, 9, 7, 6, 1, 3, 28, 5, 9, 9, 17, 8, 11, 8, 18, 1, 4, 10, 15, 6, 10, 9, 1, 7, 5, 34, 0, 16, 0, 0, 0, 0, 14, 4679, 1344, 1489, 958, 499, 79, 449, 386, 11, 91, 154, 155, 2078, 996, 116, 52, 69, 240, 51, 1, 16, 102, 212, 1296, 117, 989, 11856, 9767, 1, 303, 107, 85, 720, 482, 2217, 807, 217, 187, 111, 110, 187, 239, 610, 179, 296, 597, 76, 164, 191, 120, 1061, 379, 122, 180, 102, 167, 108, 181, 500, 67, 93, 409, 12, 92, 42, 114, 86, 156, 297, 2695, 2015, 723, 14, 12, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 115, 3, 1, 0, 1, 51, 103, 70, 68, 174, 52, 102, 2, 15, 104, 112, 196, 1685, 200, 130, 1, 2, 969, 566, 21302, 14186, 1887, 619, 735, 176, 2085, 3053, 412, 421, 489, 342, 1235, 321, 548, 527, 271, 339, 652, 1382, 9976, 5342, 1944, 5986, 554, 264, 1214, 1382, 1305, 1185, 595, 204, 97, 152, 99, 378, 820, 598, 139, 154, 7, 17, 198, 188, 136, 367, 187, 70, 24, 511, 230, 885, 4035, 1055, 1011, 160, 143, 983, 347, 225, 166, 1221, 835, 359, 2482, 1006, 225, 1041, 406, 419, 503, 88, 276, 434, 98, 86, 120, 597, 766, 862, 291, 11, 823, 114, 85, 621, 1618, 767, 132, 177, 161, 343, 1406, 299, 186, 358, 143, 5, 579, 2490, 1057, 715, 180, 84, 107, 647, 173, 2, 209, 5, 80, 122, 348, 359, 414, 9, 437, 14, 292, 41, 93, 252, 232, 701, 226, 193, 113, 144, 167, 438, 158, 1, 167, 530, 600, 344, 625, 233, 20, 531, 1125, 104, 67, 272, 399, 329, 203, 254, 950, 121, 184, 1080, 1080, 94, 161, 5352, 636, 4417, 721, 1226, 1439, 1050, 108, 317, 325, 402, 129, 599, 615, 380, 646, 309, 201, 569, 229, 103, 36, 1196, 2563, 3856, 1374, 314, 635, 1195, 1998, 93, 401, 143, 427, 88, 91, 227, 24, 18, 159, 530, 865, 1248, 557, 424, 452, 228, 129, 229, 330, 139, 10, 863, 178, 189, 487, 697, 2109, 187, 1421, 2298, 1191, 1008, 524, 646, 54, 661, 443, 1097, 743, 355, 344, 297, 331, 596, 210, 297, 370, 37, 335, 119, 287, 404, 208, 152, 499, 162, 436, 2760, 149, 573, 935, 1017, 348, 312, 262, 227, 354, 293, 311, 492, 6, 178, 778, 181, 30, 150, 125, 136, 188, 6, 384, 60, 484, 612, 149, 300, 355, 163, 304, 326, 191, 253, 366, 703, 94, 8, 16, 2, 127, 3, 4, 497, 1449, 478, 346, 107, 347, 273, 213, 168, 1105, 837, 5, 351, 455, 522, 204, 10, 279, 113, 468, 350, 783, 367, 677, 599, 1170, 785, 61, 152, 514, 233, 219, 658, 215, 156, 417, 152, 249, 2276, 849, 317, 485, 192, 1187, 650, 8, 120, 276, 220, 379, 96, 159, 265, 187, 1251, 301, 441, 254, 1041, 35, 474, 6, 42, 930, 52, 1307, 763, 313, 258, 2, 113, 337, 150, 255, 340, 318, 119, 53, 55, 535, 261, 773, 159, 1019, 197, 22, 180, 153, 161, 188, 648, 227, 512, 319, 483, 231, 145, 487, 608, 41, 354, 351, 82, 1198, 321, 306, 319, 563, 629, 62, 208, 160, 95, 253, 172, 194, 232, 193, 735, 2, 1907, 212, 501, 442, 4, 299, 89, 788, 171, 348, 263, 428, 734, 255, 32, 310, 215, 254, 581, 234, 331, 690, 18, 295, 455, 156, 324, 151, 308, 71, 169, 226, 126, 502, 1020, 732, 118, 1194, 307, 568, 816, 67, 267, 135, 604, 991, 12, 831, 625, 836, 443, 473, 343, 1019, 252, 228, 462, 6, 146, 410, 300, 258, 309, 321, 5, 326, 399, 1193, 580, 151, 404, 356, 701, 1018, 386, 370, 51, 434, 457, 703, 1030, 99, 240, 175, 657, 310, 4, 364, 93, 220, 2525, 292, 393, 152, 143, 62, 87, 536, 1576, 120, 724, 20, 355, 684, 652, 300, 285, 151, 15, 566, 2547, 636, 454, 93, 534, 237, 829, 4137, 126, 38, 172, 187, 316, 346, 223, 877, 0, 382, 611, 378, 135, 348, 782, 311, 2000, 0, 658, 723, 158, 1234, 952, 1135, 323, 332, 232, 841, 4, 266, 193, 935, 336, 1070, 1676, 403, 186, 416, 656, 285, 650, 402, 286, 1223, 730, 403, 1522, 613, 177, 2049, 325, 200, 307, 228, 465, 265, 476, 716, 2483, 4632, 150, 2275, 639, 2664, 226, 638, 16869, 20752, 774, 89, 160, 156, 100, 134, 59, 433, 2, 123, 223, 379, 123, 117, 68, 78, 79, 1, 0, 115, 38, 2, 94, 136, 578, 67, 156, 399, 805, 424, 490, 2083, 5727, 0, 0, 0, 0, 0, 0, 0, 2313, 1019, 219, 393, 206, 383, 735, 88, 461, 321, 217, 262, 337, 304, 751, 128, 71, 246, 172, 78, 122, 67, 90, 88, 90, 158, 30, 389, 128, 383, 221, 145, 98, 323, 1036, 927, 962, 979, 2074, 3446, 600, 152, 372, 153, 108, 75, 47, 3, 92, 287, 366, 815, 305, 191, 30, 132, 42, 216, 59, 113, 98, 218, 59, 0, 394, 157, 205, 304, 91, 9, 208, 173, 127, 94, 599, 204, 36, 159, 318, 218, 35, 97, 21, 87, 101, 90, 326, 190, 51, 320, 209, 258, 212, 29, 1, 122, 189, 216, 181, 355, 260, 208, 240, 95, 279, 256, 69, 202, 151, 87, 285, 149, 145, 74, 35, 188, 338, 89, 122, 176, 172, 508, 32, 217, 245, 87, 158, 129, 69, 327, 72, 247, 219, 70, 173, 79, 43, 37, 203, 2, 3, 66, 5, 4, 89, 2, 15, 204, 148, 87, 126, 157, 317, 326, 207, 325, 30, 598, 388, 93, 127, 69, 78, 238, 54, 80, 49, 117, 213, 211, 85, 132, 345, 222, 143, 246, 554, 507, 204, 213, 352, 199, 20, 87, 1050, 462, 390, 301, 1520, 1628, 27, 637, 1841, 1410, 2852, 13015, 61, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2074, 503, 212, 26, 272, 1154, 20, 151, 18, 37, 235, 887, 2294, 8276, 539, 301, 321, 212, 734, 140, 542, 250, 121, 29, 185, 27, 302, 225, 50, 308, 409, 962, 17, 11, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 1, 0, 19, 38, 127, 113, 303, 842, 505, 4325, 3412, 1378, 208, 771, 3009, 500, 290, 245, 347, 396, 279, 1, 163, 48, 298, 273, 199, 155, 50, 319, 477, 178, 481, 218, 5, 309, 189, 135, 390, 406, 16, 51, 124, 56, 144, 298, 683, 350, 2332, 156, 188, 443, 457, 387, 271, 107, 32, 92, 175, 205, 44, 142, 176, 817, 19, 85, 101, 118, 200, 485, 419, 7372, 4, 1180, 265, 301, 125, 123, 370, 1, 69, 34, 63, 54, 56, 103, 81, 95, 535, 134, 117, 60, 62, 427, 171, 72, 56, 292, 1, 92, 118, 220, 249, 126, 102, 80, 604, 381, 119, 280, 389, 320, 1, 3, 223, 2, 150, 200, 276, 109, 93, 519, 84, 36, 655, 339, 79, 85, 250, 132, 160, 135, 169, 78, 266, 302, 605, 138, 81, 131, 340, 29, 101, 271, 1, 205, 76, 382, 126, 118, 127, 120, 2, 136, 124, 30, 49, 209, 80, 12, 303, 223, 52, 361, 123, 156, 170, 61, 115, 318, 128, 317, 160, 133, 418, 339, 606, 0, 43, 96, 514, 125, 68, 8, 4, 340, 228, 190, 285, 425, 341, 0, 38, 129, 108, 0, 24, 64, 426, 452, 34, 36, 54, 35, 197, 41, 0, 41, 86, 255, 110, 1, 89, 93, 14, 49, 0, 7, 117, 1, 54, 145, 1, 586, 179, 0, 127, 358, 0, 1105, 32, 0, 223, 0, 71, 85, 881, 44, 172, 0, 605, 252, 1325, 331, 240, 378, 1098, 299, 356, 179, 46, 167, 306, 131, 249, 254, 122, 31, 123, 171, 80, 9, 45, 291, 132, 203, 2803, 748, 6, 171, 102, 41, 65, 163, 254, 0, 321, 75, 70, 89, 425, 161, 192, 0, 40, 66, 42, 86, 8, 4, 68, 174, 131, 619, 201, 74, 170, 103, 108, 556, 8, 13, 38, 61, 154, 291, 272, 110, 1, 153, 1927, 7, 96, 24, 261, 331, 51, 15, 168, 550, 39, 33, 814, 55, 38, 128, 47, 255, 132, 37, 327, 307, 42, 1, 38, 191, 278, 44, 80, 508, 308, 388, 85, 26, 85, 353, 309, 221, 511, 97, 1, 273, 771, 648, 580, 34, 20, 2, 3, 86, 1, 37, 555, 553, 102, 117, 96, 288, 84, 30, 239, 79, 344, 271, 122, 67, 0, 65, 206, 81, 72, 203, 180, 145, 83, 607, 380, 2824, 0, 713, 2528, 5856, 246, 187, 53, 100, 170, 120, 19, 97, 38, 246, 173, 780, 250, 286, 1335, 568, 5788, 0, 0, 0, 0, 0, 0, 0, 0, 204, 304, 63, 74, 213, 337, 207, 293, 887, 568, 2579, 79, 29, 51, 282, 186, 303, 52, 185, 99, 82, 90, 62, 48, 72, 18, 73, 99, 37, 83, 112, 46, 65, 105, 396, 72, 493, 428, 229, 457, 173, 205, 143, 370, 813, 753, 2578, 0, 2472, 18, 2, 1, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 947, 203, 396, 377, 276, 61, 22, 135, 747, 9324, 11765, 1, 2, 655, 312, 33, 173, 83, 319, 169, 212, 279, 62, 23, 1, 137, 428, 326, 11236, 4, 5383, 756, 87, 3493, 252, 16027, 1456, 1486, 1220, 121, 588, 1304, 239, 1166, 104, 770, 1250, 325, 47, 2, 122, 13, 123, 59, 33, 2, 102, 179, 221, 478, 167, 567, 366, 497, 322, 171, 689, 645, 142, 77, 132, 92, 177, 983, 79, 65, 114, 135, 177, 5108, 272, 611, 2386, 652, 90, 91, 260, 48, 73, 164, 102, 698, 130, 422, 7, 167, 30, 8, 404, 77, 12, 1312, 155, 47, 105, 240, 90, 102, 134, 448, 198, 323, 1, 131, 103, 145, 598, 254, 5150, 2079, 3631, 114, 459, 1785, 641, 1804, 88, 672, 52, 159, 357, 694, 1, 265, 349, 160, 334, 240, 243, 221, 16, 77, 326, 1, 221, 605, 1506, 712, 456, 1236, 1095, 781, 65, 209, 147, 31, 227, 3, 123, 146, 171, 240, 54, 259, 1202, 109, 457, 429, 928, 437, 91, 112, 182, 66, 274, 72, 252, 577, 1045, 1571, 879, 33, 598, 240, 394, 337, 282, 408, 235, 156, 167, 454, 443, 115, 229, 422, 255, 48, 121, 460, 158, 1558, 1117, 694, 49, 329, 17, 549, 721, 352, 202, 85, 495, 668, 2244, 160, 256, 305, 386, 140, 261, 126, 252, 342, 178, 54, 313, 264, 801, 336, 229, 1140, 172, 315, 625, 305, 215, 482, 708, 377, 362, 392, 202, 970, 355, 241, 319, 1465, 250, 226, 407, 105, 337, 164, 275, 274, 194, 210, 24, 230, 1, 303, 381, 438, 164, 255, 159, 75, 414, 206, 136, 23, 52, 66, 8, 92, 257, 102, 88, 273, 354, 599, 689, 48, 3, 87, 344, 237, 94, 57, 104, 115, 51, 14, 173, 90, 162, 124, 60, 241, 34, 276, 1, 273, 103, 103, 388, 90, 180, 141, 315, 227, 222, 172, 256, 395, 299, 342, 258, 135, 140, 230, 273, 195, 109, 347, 485, 390, 86, 160, 93, 162, 458, 200, 168, 231, 575, 0, 116, 195, 482, 211, 345, 28, 156, 154, 534, 498, 178, 313, 491, 441, 2, 214, 322, 138, 128, 91, 117, 441, 254, 81, 0, 457, 655, 548, 253, 23, 76, 102, 336, 1642, 6, 638, 326, 161, 204, 3, 579, 298, 278, 749, 179, 357, 215, 6, 163, 222, 124, 1, 0, 1966, 136, 320, 162, 419, 48, 130, 1345, 145, 500, 377, 724, 705, 551, 878, 723, 600, 801, 111, 335, 3, 7, 142, 48, 314, 258, 307, 314, 2267, 81, 103, 544, 212, 103, 397, 236, 664, 2, 111, 216, 1706, 90, 485, 118, 1, 296, 882, 0, 264, 122, 243, 157, 125, 104, 567, 496, 755, 81, 2, 336, 109, 105, 289, 2221, 315, 714, 77, 103, 409, 119, 222, 237, 182, 1048, 645, 165, 162, 1229, 316, 127, 622, 174, 3401, 342, 354, 50, 2, 735, 4626, 0, 110, 244, 3, 158, 341, 297, 885, 98, 1685, 317, 102, 110, 353, 101, 221, 78, 143, 379, 169, 108, 340, 576, 287, 118, 51, 315, 668, 352, 236, 446, 996, 95, 999, 4162, 12238, 394, 91, 213, 2, 40, 174, 51, 167, 20, 101, 88, 0, 125, 37, 63, 73, 592, 95, 590, 181, 349, 8818, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 224, 159, 67, 170, 141, 87, 109, 117, 53, 100, 20, 223, 221, 253, 922, 61, 567, 442, 639, 7413, 85, 528, 160, 90, 211, 66, 169, 39, 140, 173, 140, 278, 21, 118, 100, 89, 117, 2, 54, 99, 19, 172, 124, 36, 171, 173, 48, 62, 219, 71, 252, 211, 371, 218, 1033, 428, 271, 1290, 136, 963, 1742, 8, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 5, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 4, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 3, 0, 0, 0, 1, 1, 1, 2, 2, 4, 3, 1, 2, 1, 1, 4, 3, 22, 1, 2, 2, 2, 4, 2, 13, 25, 1, 2, 7, 1, 3, 44, 2, 9, 3, 3, 3, 4, 7, 14, 13, 68, 86, 261, 68, 2, 2, 4, 3, 2, 1, 1, 4, 3, 1, 0, 0, 0, 1, 5, 2, 0, 0, 0, 0, 18, 27, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 56, 13, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 94, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 2, 1, 8, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 3, 1, 1, 1, 1, 1, 4, 1, 1, 1, 1, 1, 2, 1, 2, 1, 4, 2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 2, 1, 2, 2, 1, 4, 1, 1, 2, 1, 1, 3, 1, 1, 3, 3, 2, 2, 3, 1, 3, 1, 1, 1, 5, 3, 2, 4, 1, 4, 9, 3, 1, 1, 1, 1, 2, 3, 1, 1, 1, 8, 1, 4, 1, 3, 1, 1, 1, 4, 4, 0, 3, 4, 1, 2, 1, 1, 2, 3, 2, 2, 2, 6, 0, 5, 2, 3, 2, 6, 0, 3, 6, 6, 10, 0, 0, 4, 1, 14, 7, 0, 3, 3, 13, 1, 2, 0, 4, 10, 7, 7, 1, 0, 0, 8, 1, 0, 0, 0, 17, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 3, 5, 2, 1, 1, 1, 3, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 3, 2, 1, 3, 1, 1, 1, 1, 1, 1, 3, 1, 1, 3, 1, 3, 5, 1, 2, 4, 3, 1, 3, 4, 7, 14, 2, 1, 1, 1, 1, 3, 6, 11, 1, 1, 2, 1, 2, 1, 1, 13, 30, 2, 1, 4, 4, 1, 1, 52, 3, 3, 4, 2, 14, 5, 64, 1, 6, 9, 2, 33, 23, 22, 33, 205, 65, 34, 1, 2, 14, 6, 6, 8, 52, 24, 3, 2, 2, 1, 3, 3, 1, 5, 2, 1, 0, 9, 25, 2, 1, 0, 0, 11, 6, 15, 1, 0, 0, 0, 6, 20, 3, 1, 0, 0, 0, 0, 0, 15, 11, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 45, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 3, 5, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 2, 1, 1, 1, 1, 1, 2, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 0, 0, 1, 0, 0, 0, 1, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 1, 0, 0, 0, 2, 0, 1, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 1, 2, 1, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 5, 1, 12, 2, 5, 1, 6, 1, 1, 1, 2, 25, 1, 1, 2, 3, 1, 10, 4, 5, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 4, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 2, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 3, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 1, 0, 0, 0, 4, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 4, 0, 0, 3, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 0, 0, 1, 0, 2, 1, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 1, 0, 0, 2, 0, 1, 0, 1, 1, 1, 1, 1, 1, 5, 1, 2, 2, 1, 3, 1, 2, 1, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 12, 5, 24, 10, 4, 12, 5, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 1, 1, 0, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 2, 2, 0, 1, 0, 2, 1, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 125, 4, 422, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 3, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 2, 0, 1, 1, 8, 1, 3, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 4, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 3, 4, 1, 1, 1, 1, 5, 1, 8, 3, 2, 13, 1, 1, 1, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 1, 2, 1, 1, 5, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 1, 2, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 2, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 2, 1, 1, 2, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 2, 0, 1, 1, 2, 1, 1, 13, 5, 2, 1, 4, 3, 2, 22, 14, 17, 20, 11, 3, 2, 1, 8, 4, 16, 3, 3, 9, 7, 7, 4, 4, 2, 3, 2, 2, 1, 3, 3, 5, 2, 2, 5, 2, 4, 2, 0, 1, 2, 0, 0, 0, 0, 4, 9, 0, 0, 0, 0, 3, 0, 0, 0, 0, 5, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 1, 0, 0, 3, 0, 0, 1, 1, 0, 0, 1, 1, 0, 2, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 2, 1, 0, 1, 1, 3, 2, 3, 4, 2, 2, 1, 1, 1, 1, 1, 5, 9, 7, 1, 1, 3, 2, 1, 1, 1, 17, 2, 11, 2, 3, 3, 55, 56, 22, 8, 3, 5, 2, 8, 24, 20, 18, 2, 1, 77, 9, 2, 4, 6, 6, 3, 1, 8, 2, 24, 7, 59, 4, 9, 3, 1, 77, 16, 11, 7, 23, 1, 4, 4, 24, 26, 19, 101, 6, 2, 2, 24, 6, 7, 7, 8, 9, 14, 53, 8, 35, 5, 5, 2, 2, 1, 3, 5, 4, 3, 3, 3, 14, 41, 3, 9, 1, 1, 6, 6, 13, 3, 5, 2, 3, 15, 3, 4, 3, 3, 12, 3, 5, 8, 17, 6, 54, 1, 8, 8, 7, 1, 1, 2, 2, 2, 1, 1, 4, 3, 0, 4, 9, 14, 2, 0, 0, 18, 3, 26, 1, 1, 0, 0, 22, 94, 2, 4, 1, 0, 0, 0, 0, 0, 0, 0, 56, 1, 4, 1, 0, 0, 0, 0, 0, 0, 69, 33, 14, 16, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 4, 7, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 12, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0, 1, 0, 1, 0, 5, 2, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 2, 0, 0, 1, 0, 1, 0, 1, 0, 1, 3, 1, 0, 0, 0, 0, 0, 2, 0, 1, 1, 0, 0, 1, 0, 7, 1, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 3, 2, 1, 1, 3, 10, 4, 1, 40, 17, 2, 1, 1, 1, 2, 3, 1, 1, 1, 1, 268, 28, 1, 1, 2, 1, 1, 4, 2, 1, 2, 15, 7, 5, 4, 4, 2, 1, 1, 1, 1, 592, 11, 4, 3, 4, 3, 4, 10, 5, 7, 13, 1, 3, 1, 2, 13, 17, 6, 53, 76, 64, 18, 13, 1, 5, 2, 3, 1, 48, 22, 5, 13, 30, 9, 3, 6, 22, 44, 49, 30, 12, 10, 21, 5, 17, 7, 17, 12, 22, 7, 86, 185, 220, 59, 46, 17, 2, 1, 1, 1, 1, 7, 6, 7, 6, 10, 7, 3, 14, 16, 2, 2, 5, 10, 4, 12, 4, 5, 2, 10, 14, 14, 6, 5, 7, 3, 2, 1, 10, 5, 2, 2, 6, 6, 4, 2, 2, 7, 23, 11, 3, 2, 6, 16, 20, 20, 4, 9, 15, 8, 27, 11, 7, 32, 3, 11, 1, 10, 10, 8, 13, 5, 5, 1, 26, 28, 6, 6, 18, 20, 18, 1, 5, 18, 7, 4, 31, 3, 2, 36, 5, 5, 10, 7, 10, 12, 21, 7, 5, 2, 31, 26, 3, 1, 1, 21, 8, 35, 26, 6, 2, 1, 2, 8, 9, 8, 21, 6, 4, 6, 9, 22, 11, 6, 0, 8, 6, 1, 1, 9, 7, 0, 7, 10, 3, 4, 3, 1, 0, 0, 13, 8, 8, 2, 1, 1, 6, 9, 6, 7, 1, 0, 0, 79, 64, 13, 4, 4, 2, 2, 1, 3, 1, 0, 0, 0, 0, 0, 0, 225, 62, 30, 20, 8, 3, 3, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 295, 138, 53, 38, 10, 1, 11, 2, 1, 2, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 185, 72, 17, 20, 13, 9, 8, 3, 5, 4, 2, 4, 3, 4, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 140, 115, 27, 13, 9, 3, 1, 1, 2, 5, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 56, 23, 7, 10, 1, 4, 18, 1, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 48, 12, 6, 12, 1, 1, 2, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 61, 17, 11, 12, 9, 3, 1, 3, 8, 1, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 38, 13, 9, 7, 3, 1, 1, 2, 19, 1, 13, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 21, 4, 13, 3, 4, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 14, 1, 2, 3, 1, 5, 2, 6, 1, 0, 0, 0, 0, 0, 11, 10, 1, 4, 2, 5, 5, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 1, 4, 3, 1, 3, 6, 1, 0, 0, 0, 0, 0, 0, 0, 3, 2, 5, 12, 0, 0, 0, 2, 1, 0, 0, 0, 0, 1, 5, 0, 0, 17, 1, 0, 0, 4, 2, 8, 0, 0, 0, 0, 4, 37, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, 0, 11, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3, 0, 0, 0, 1, 1, 0, 1, 2, 1, 0, 0, 1, 0, 1, 4, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 5, 7, 23, 3, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 4, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 3, 1, 0, 0, 0, 0, 0, 1, 1, 5, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 26, 0, 0, 0, 0, 0, 0, 1, 0, 262, 136, 4, 1, 1, 2, 2, 260, 5, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 5, 0, 0, 0, 2, 0, 1, 0, 1, 1, 1, 2, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 4, 6, 1, 2, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 2, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 1, 9, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 4, 0, 0, 0, 2, 0, 1, 0, 3, 1, 0, 1, 0, 1, 0, 1, 1, 1, 4, 2, 1, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 2, 1, 0, 1, 6, 29, 10, 5, 7, 3, 2, 5, 6, 6, 5, 6, 2, 64, 40, 3, 1, 1, 2, 3, 5, 2, 5, 2, 4, 12, 4, 2, 4, 8, 12, 8, 1, 3, 3, 3, 2, 17, 1, 2, 4, 8, 13, 1, 1, 3, 2, 7, 4, 4, 2, 3, 0, 3, 2, 4, 5, 3, 0, 2, 3, 0, 1, 1, 1, 0, 0, 0, 0, 5, 3, 0, 0, 2, 1, 0, 0, 0, 1, 0, 0, 29, 5, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 6, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 4, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 3, 0, 0, 0, 0, 0, 0, 5, 1, 1, 1, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 9, 1, 2, 1, 18, 4, 2, 0, 1, 3, 6, 1, 0, 2, 2, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 4, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 2, 1, 3, 2, 1, 1, 1, 1, 2, 3, 1, 3, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 2, 2, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 3, 2, 2, 1, 3, 1, 1, 1, 1, 1, 4, 1, 1, 1, 2, 1, 3, 2, 3, 1, 1, 2, 3, 5, 1, 2, 1, 1, 2, 1, 6, 2, 3, 1, 1, 8, 1, 3, 2, 3, 1, 1, 2, 1, 1, 1, 3, 1, 2, 1, 1, 1, 1, 2, 1, 0, 0, 0, 3, 1, 1, 0, 1, 5, 1, 0, 2, 1, 0, 1, 4, 1, 0, 0, 1, 1, 0, 3, 2, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 2, 2, 0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 2, 3, 0, 0, 2, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 4, 1, 1, 5, 8, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 2, 0, 1, 0, 1, 0, 2, 1, 0, 0, 1, 0, 139, 150845, 37572, 5906, 15238, 4699, 14669, 471, 1050, 3618, 600, 14113, 30, 1457, 2164, 557, 78, 64, 5431, 891, 688, 686, 1919, 90, 2785, 2635, 41, 83, 1284, 282, 55, 3348, 2232, 6, 39, 389, 2172, 1345, 5655, 855, 1495, 569, 282, 8110, 41620, 17262, 4071, 15637, 2756, 11447, 5457, 6207, 25666, 2795, 1009, 463, 140, 1218, 1374, 6269, 1227, 1021, 1578, 1473, 2168, 1254, 3205, 741, 850, 1554, 2727, 2046, 2259, 42134, 6214, 257, 748, 1953, 3502, 8728, 5017, 6493, 5428, 2937, 1409, 1189, 1778, 1722, 1204, 3263, 6139, 1713, 30, 947, 1882, 2058, 1023, 2759, 749, 1954, 1329, 2084, 2687, 1592, 1892, 2164, 2036, 910, 527, 1660, 8792, 1052, 3068, 722, 1333, 6081, 919, 3506, 373, 5407, 1572, 3201, 1291, 2090, 2982, 3108, 1101, 1808, 1251, 1583, 1114, 7141, 473, 374, 2085, 1051, 2693, 1177, 2443, 602, 2507, 3508, 957, 1582, 4607, 2028, 1470, 3217, 2164, 2165, 4808, 5633, 3461, 1770, 41, 3323, 6087, 5174, 1573, 2796, 1, 19, 1, 3200, 5, 3747, 215, 0, 2722, 1709, 1290, 2059, 1008, 2089, 1591, 1891, 1418, 4258, 556, 958, 79, 464, 62, 1334, 4, 1581, 2329, 207, 457, 3097, 2449, 2156, 2721, 72, 3630, 4483, 1163, 397, 59, 2090, 1161, 2330, 7857, 1451, 1410, 365, 2, 3109, 1486, 28, 1375, 56, 903, 1330, 549, 518, 42, 1469, 89, 1378, 1454, 1333, 3216, 4364, 2037, 1678, 3098, 2843, 2091, 23, 2165, 42, 948, 1379, 1148, 79, 84, 1285, 2196, 2166, 2119, 1050, 1708, 649, 1777, 2036, 1881, 56, 3199, 2164, 1572, 1723, 2448, 5989, 1, 2778, 2853, 1284, 1677, 4766, 3553, 2057, 1176, 2523, 2056, 2169, 2233, 15189, 1592, 2155, 1769, 7, 2195, 2034, 40, 2720, 5291, 2553, 1493, 679, 4789, 587, 2852, 3203, 2156, 1419, 2060, 73, 6209, 6023, 1391, 824, 23, 851, 16, 2110, 5117, 2442, 13, 804, 6710, 915, 42, 7370, 808, 33850, 12599, 128, 272982, 1209, 357833, 486613, 109195, 44483, 45622, 14488, 10982, 7193, 2515, 566, 105, 170, 661, 4, 14, 321, 325803, 66931, 57966, 22998, 10389, 2417, 195, 162, 259, 274047, 105452, 40228, 14233, 445, 930, 294257, 61406, 16495, 11074, 1816, 312, 360, 363809, 112428, 27317, 106, 7, 428568, 72503, 2281, 11, 586951, 6408, 43, 389, 697794, 1895, 9934, 189, 235, 38, 50, 102537, 595723, 2568, 2053, 8096, 2150, 422, 221, 142, 6, 51, 102371, 1656, 418, 92796, 135093, 448034, 592, 28383, 4855, 261, 28, 157, 12, 194, 4, 27945, 66785, 320, 359, 161177, 3976, 29496, 655249, 216, 705, 789, 85, 29, 664, 7, 86, 30098, 321, 75843, 83592, 352732, 50871, 87789, 21074, 7866, 11329, 12982, 4027, 266, 451, 624, 242, 562, 1009, 842, 606, 362, 5547, 2115, 23, 2116, 12002, 47508, 9501, 3544, 117, 2590, 386, 241, 54993, 6200, 8954, 11323, 8883, 1099, 4307, 190, 131428, 150774, 57901, 23059, 32438, 31885, 2848, 5489, 2411, 1501, 4097, 1407, 134, 4356, 2482, 667, 6477, 43, 1721, 107475, 33549, 14807, 30030, 9490, 752, 94, 598, 323, 257, 488, 58, 1173, 135548, 67202, 85634, 45586, 6394, 1407, 11, 5157, 2064, 2856, 2978, 3816, 30, 222, 260, 67059, 109876, 60245, 5823, 4140, 1296, 31, 2839, 1996, 3361, 419, 21, 42, 2763, 289, 111679, 65672, 118, 4737, 5772, 927, 272098, 34175, 6156, 14682, 2782, 4115, 5090, 3174, 4282, 592, 8647, 4731, 3697, 8140, 1790, 1440, 5530, 3655, 1347, 187455, 9195, 38311, 15635, 4207, 16759, 14375, 35164, 9970, 9741, 52590, 5804, 17140, 7356, 30075, 4849, 3702, 123, 39877, 481, 233, 24, 157, 15, 2194, 57893, 2756, 26289, 81, 26474, 6752, 6189, 46738, 14724, 4752, 13526, 4144, 2218, 170, 23538, 2146, 1017, 5780, 4136, 5449, 4384, 629, 95, 2661, 111, 54, 20868, 55, 19493, 8736, 10822, 23904, 4883, 8444, 3059, 5719, 5784, 13008, 30, 2783, 2839, 1500, 3830, 25, 35, 6457, 2513, 54, 3479, 123, 35, 2782, 2653, 736, 2130, 9496, 627, 3468, 25526, 3272, 5531, 1722, 17381, 1619, 15235, 70, 9, 5466, 362, 7436, 3205, 1885, 100, 2580, 665, 177, 1914, 6548, 9448, 8909, 24438, 4269, 25133, 9602, 4377, 18642, 1970, 11777, 12815, 562, 7241, 1562, 3516, 30, 4422, 16260, 7866, 586, 5443, 2557, 2687, 12601, 47239, 38336, 3458, 41166, 3504, 11324, 6885, 51852, 808, 160, 4218, 27, 32376, 3204, 36948, 22028, 23746, 39922, 6893, 2562, 6856, 87177, 5536, 660, 17381, 10229, 9796, 5634, 6918, 57508, 7322, 23423, 156497, 12047, 11, 12755, 23854, 76572, 1000, 340, 2535, 13164, 41199, 28, 98041, 795, 361, 313, 482291, 132210, 21397, 8395, 13278, 5622, 14782, 50, 11666, 524, 16, 69, 43, 418514, 21909, 5318, 10843, 34643, 11732, 416, 2729, 60, 36, 267963, 16276, 69595, 135292, 51754, 1645, 2143, 7279, 2188, 17, 34275, 63785, 129459, 83627, 1481, 1979, 446, 15469, 38913, 12369, 42, 81526, 85565, 3688, 2117, 416307, 6662, 5773, 117, 82, 398, 199130, 101697, 365836, 8688, 1192, 297, 23, 61936, 143908, 240, 156, 169565, 3273, 702671, 2976, 2928, 1048, 682295, 13444, 18952, 964, 211154, 437081, 36203, 213834, 10744, 650101, 6, 348503, 148, 1892, 541, 1870, 455, 46, 454, 60, 16, 152, 822, 113, 8, 1459, 37, 273, 1, 10, 220, 426, 478, 138, 7, 200, 129, 153, 154, 131, 49, 16, 90, 42, 89, 191, 2269, 0, 0, 0, 0, 0, 162272, 29820, 85770, 32708, 1490, 1761, 5446, 3741, 1188, 2763, 267, 1782, 414, 127, 1938, 68, 1014, 1173, 27, 4976, 1, 519, 0, 217, 1023, 77, 566, 150, 1115, 300, 247, 369, 2105, 46544, 84154, 11950, 711, 1419, 7669, 1877, 1839, 700, 1036, 2130, 950, 923, 203, 147, 48788, 13076, 456, 2404, 3163, 629, 917, 3107, 740, 142, 94, 94, 1461, 2, 355, 1752, 677, 105, 216, 140674, 3743, 17036, 7800, 2246, 3500, 5446, 1233, 4580, 2033, 2959, 7220, 2137, 506, 2646, 1488, 1322, 2190, 6623, 160, 109, 1234, 1031, 106, 258, 557, 6328, 19927, 46500, 16786, 3809, 7290, 7994, 4531, 26813, 2016, 1777, 7830, 6497, 1697, 89, 5702, 1544, 1647, 30, 1111, 18927, 2090, 1888, 793, 3269, 297, 789, 3, 1300, 316, 444, 0, 5022, 902, 753, 79, 1112, 457, 737, 2, 373, 18493, 1728, 2794, 1700, 190, 370, 0, 135, 23059, 2419, 17708, 10680, 14328, 19025, 3, 2861, 1532, 589, 1532, 5, 1366, 618, 388, 169, 3771, 7003, 5117, 25181, 2152, 10332, 1419, 1824, 1726, 2025, 2117, 113, 1240, 0, 1, 296, 2048, 4179, 2284, 2153, 1616, 19, 11351, 6151, 17335, 1398, 4736, 1170, 7, 250, 16, 4163, 21620, 465, 2322, 4075, 1446, 1828, 911, 30825, 682, 464, 4480, 116, 23450, 37905, 37685, 2505, 5078, 12914, 4644, 1086, 2049, 3191, 2732, 8442, 2955, 4112, 3656, 39, 1338, 2439, 44, 2192, 809, 7, 134, 257, 6865, 6423, 2437, 1207, 7259, 1280, 4729, 734, 945, 23513, 2105, 16287, 140, 535, 3991, 8, 1759, 3462, 266, 2, 69, 25167, 26473, 7241, 2417, 6100, 4461, 3729, 5503, 5086, 54, 1282, 13370, 558, 1219, 876, 291, 1119, 279, 3512, 449, 399, 310, 500, 82, 95, 206, 613, 2505, 13745, 3708, 3252, 1577, 1640, 5202, 6685, 1039, 38, 413, 11135, 4703, 8992, 17371, 7554, 23790, 4456, 1903, 3241, 1541, 1318, 821, 52, 2, 93, 243, 10856, 5008, 5277, 3629, 1571, 7740, 2750, 2268, 274, 4138, 1085, 139, 3348, 553, 1571, 8, 88, 5940, 2844, 9111, 3172, 5562, 10246, 2153, 808, 285, 534, 1416, 1, 6747, 18050, 6682, 7475, 5752, 2584, 1545, 110, 2029, 0, 581, 1, 12767, 1084, 7317, 948, 12200, 588, 191, 34, 19, 78, 54339, 7105, 7275, 22854, 181, 1505, 201, 13, 75, 28, 505, 24375, 10453, 9130, 32344, 4374, 3, 1080, 552, 5, 1646, 48, 7, 1725, 23, 120, 10280, 12010, 32812, 587, 1037, 832, 454, 1, 26, 3184, 22678, 2319, 3776, 897, 2461, 2881, 1465, 1795, 18, 34, 21552, 359, 138, 947, 3636, 2836, 450, 30022, 21584, 24925, 29112, 1175, 6059, 31275, 3865, 6121, 226, 33466, 4699, 11663, 3002, 626, 4956, 1278, 2154, 1092, 1085, 570, 335, 3169, 1154, 1980, 1036, 1389, 3803, 2022, 510, 1795, 1534, 1571, 1559, 951, 545, 1506, 51, 600, 3347, 9874, 1204, 1826, 12181, 3403, 1533, 0, 661, 71, 8260, 10558, 8303, 995, 4887, 6, 14114, 11068, 16239, 458, 2229, 4126, 1402, 418, 456, 3, 12851, 22525, 1646, 1181, 3485, 619, 9142, 962, 1202, 557, 1412, 2, 953, 1174, 1825, 1079, 2440, 199, 810, 27462, 3463, 1133, 1982, 1175, 7072, 2055, 5363, 12956, 2664, 35851, 16161, 15056, 2017, 1280, 741, 970, 3821, 1359, 645, 5651, 6274, 114, 1284, 2090, 1513, 908, 1963, 670, 1260, 267, 1140, 3221, 1875, 585, 1386, 1118, 2882, 677, 1375, 2910, 700, 3198, 2414, 6882, 9279, 3402, 1640, 932, 457, 3372, 154, 43, 4, 2681, 933, 515, 1405, 1, 533, 22580, 27235, 10762, 1386, 1565, 2497, 1888, 906, 1702, 3115, 13354, 3581, 2267, 7160, 1280, 1879, 745, 17, 161, 48, 165, 1538, 192, 1767, 57, 21337, 5368, 1040, 701, 3514, 718, 383, 2915, 2252, 2197, 3087, 3384, 5069, 2255, 1170, 3484, 2327, 1081, 1512, 1376, 1335, 16018, 4694, 2839, 4081, 1958, 1377, 4469, 8683, 19698, 6205, 6375, 12438, 1522, 349, 1107, 3062, 1807, 2043, 1273, 1762, 1053, 996, 1090, 313, 2205, 4463, 4496, 2907, 3245, 2752, 2625, 935, 2609, 5560, 3091, 2247, 1402, 1115, 78, 3307, 627, 3740, 1387, 2840, 1566, 1235, 789, 1616, 931, 4662, 728, 1039, 1209, 3199, 1618, 4395, 567, 1279, 4794, 448, 1532, 1234, 2143, 2322, 5446, 2191, 4, 509, 558, 717, 1230, 6638, 1703, 557, 3202, 1277, 382, 107, 53, 2143, 10990, 3859, 4583, 2206, 209, 983, 1318, 458, 1406, 202, 7067, 3571, 2106, 1091, 21, 132, 1615, 3335, 1, 2753, 2142, 34178, 16495, 20767, 639, 1378, 1456, 524, 1318, 2830, 621, 1381, 2030, 610, 2995, 1698, 1598, 1726, 493, 947, 2322, 1358, 934, 13601, 1506, 22843, 2951, 8857, 1898, 1414, 1080, 1485, 2326, 6374, 2191, 1368, 1343, 2119, 27258, 2690, 2265, 2909, 3031, 1016, 2105, 3957, 678, 1650, 7410, 6175, 4189, 2883, 2155, 615, 120, 3168, 1505, 6181, 7850, 6251, 3588, 6754, 12541, 2416, 750, 4691, 1641, 13297, 2856, 702, 4905, 3119, 18499, 1448, 7009, 3120, 8217, 1227, 1342, 805, 2765, 4045, 4544, 1646, 1357, 1837, 2137, 779, 5308, 3060, 728, 4312, 4675, 5144, 637, 1466, 1597, 1699, 1463, 3088, 1035, 2202, 2264, 418, 930, 3344, 1384, 1036, 1388, 499, 3744, 894, 1574, 1564, 1038, 3571, 72, 572, 274, 2017, 4416, 2053, 322, 76, 518, 12, 51, 2138, 9078, 1278, 2210, 2421, 1317, 5057, 1899, 2213, 1562, 1851, 1736, 1698, 584, 1947, 1424, 75, 895, 1763, 1798, 2132, 1032, 4578, 2022, 1332, 432, 61, 383, 778, 2963, 31, 1015, 1399, 424, 1573, 749, 1106, 16, 509, 1315, 2104, 2263, 6200, 2788, 1900, 1054, 2131, 545, 2137, 1640, 2103, 2089, 2665, 2143, 2326, 8699, 14355, 4214, 5733, 3337, 5223, 3527, 1634, 2491, 1703, 1639, 2138, 2078, 1563, 1676, 1694, 1760, 1310, 2056, 1902, 777, 271, 1037, 4122, 5733, 2498, 3234, 2743, 1036, 3187, 1421, 1805, 1745, 717, 2823, 5157, 2042, 1573, 1544, 1638, 2270, 17216, 27516, 14531, 13927, 1337, 5192, 5515, 1980, 3302, 6558, 1356, 1031, 315, 19421, 1037, 3330, 2931, 8736, 1898, 71, 10928, 32861, 16634, 33966, 2053, 5679, 10040, 15767, 10359, 19179, 506, 3647, 10235, 29840, 47872, 4236, 10894, 8203, 54493, 11300, 11267, 9722, 47213, 58409, 96340, 0, 32078, 42930, 140725, 34, 1, 16, 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 3, 1, 0, 0, 1, 2, 1, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 2, 2, 1, 2, 7, 14, 4, 5, 1, 10, 2, 1, 1, 64, 22, 10, 18, 3, 7, 8, 2, 122, 84, 7, 2, 7, 8, 2, 4, 3, 19, 27, 49, 36, 4, 6, 1, 1, 110, 3, 10, 10, 3, 4, 3, 8, 27, 24, 54, 20, 6, 48, 24, 18, 15, 27, 2, 4, 4, 19, 62, 52, 38, 2, 25, 1, 1, 3, 13, 5, 4, 4, 4, 25, 8, 6, 7, 3, 25, 14, 6, 3, 4, 1, 13, 4, 5, 2, 33, 19, 3, 3, 5, 14, 8, 2, 8, 6, 11, 8, 5, 2, 41, 11, 7, 6, 3, 4, 5, 9, 1, 3, 1, 3, 1, 1, 1, 3, 0, 1, 2, 5, 4, 8, 0, 0, 0, 0, 0, 0, 0, 9, 24, 13, 1, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 21, 1, 9, 15, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 108, 4, 52, 13, 2, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 78, 45, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 75, 19, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 55, 25, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 3, 3, 9, 2, 2, 3, 2, 1, 2, 1, 2, 1, 7, 4, 2, 2, 3, 1, 1, 2, 1, 3, 7, 5, 8, 1, 10, 1, 2, 4, 2, 2, 10, 3, 2, 10, 2, 1, 2, 1, 11, 11, 9, 2, 4, 2, 2, 6, 12, 5, 10, 5, 4, 11, 5, 10, 6, 43, 6, 1, 1, 2, 4, 6, 2, 19, 13, 3, 6, 7, 1, 5, 4, 1, 3, 1, 10, 7, 9, 2, 3, 3, 5, 2, 0, 1, 0, 3, 1, 0, 0, 2, 3, 2, 0, 0, 0, 5, 14, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 11, 0, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 1, 2, 1, 2, 1, 1, 1, 20, 1, 1, 1, 1, 4, 1, 2, 8, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 2, 1, 1, 0, 0, 1, 0, 2, 0, 0, 2, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 1, 14, 11, 30, 7, 3, 1, 1, 1, 1, 27, 54, 12, 6, 2, 1, 1, 89, 32, 7, 2, 2, 559, 84, 4, 6, 2, 3, 7, 10, 1, 6, 3, 4, 1, 1230, 11, 4, 4, 5, 11, 1, 4, 2, 2, 13, 17, 11, 43, 40, 8, 14, 4, 2, 1, 1, 1, 166, 21, 26, 22, 30, 21, 21, 12, 29, 21, 9, 33, 27, 57, 53, 30, 40, 9, 5, 19, 38, 39, 58, 119, 271, 94, 378, 264, 202, 51, 15, 13, 5, 4, 2, 1, 2, 1, 1, 1, 1, 7, 9, 3, 12, 13, 26, 26, 30, 34, 30, 18, 3, 1, 3, 5, 6, 16, 8, 13, 8, 12, 9, 5, 9, 10, 6, 13, 5, 9, 10, 13, 12, 6, 6, 13, 5, 6, 14, 17, 14, 9, 10, 10, 13, 16, 8, 15, 13, 14, 19, 20, 7, 13, 7, 16, 18, 11, 16, 15, 35, 28, 12, 26, 9, 6, 25, 7, 18, 18, 13, 2, 13, 10, 11, 13, 8, 6, 9, 9, 27, 29, 5, 31, 5, 25, 11, 0, 8, 9, 14, 28, 3, 1, 20, 34, 12, 35, 17, 1, 28, 26, 84, 72, 37, 9, 6, 227, 137, 84, 36, 13, 2, 1, 259, 151, 60, 14, 3, 1, 0, 0, 0, 527, 372, 58, 23, 11, 14, 1, 2, 3, 1, 0, 741, 183, 30, 24, 15, 5, 1, 2, 2, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 801, 128, 93, 17, 7, 6, 10, 3, 1, 4, 1, 2, 1, 2, 1, 3, 2, 1, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 349, 204, 94, 34, 7, 15, 7, 5, 4, 6, 4, 2, 3, 1, 3, 1, 2, 1, 2, 4, 5, 2, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 303, 83, 16, 29, 12, 10, 0, 1, 3, 1, 2, 2, 2, 1, 2, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 319, 66, 52, 12, 8, 3, 5, 4, 1, 0, 2, 6, 2, 2, 26, 3, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 163, 122, 18, 32, 3, 8, 8, 12, 6, 2, 3, 2, 1, 1, 1, 2, 2, 1, 33, 3, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 79, 30, 44, 16, 16, 4, 2, 3, 4, 1, 2, 2, 3, 15, 9, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 80, 40, 30, 27, 4, 5, 3, 6, 8, 1, 1, 45, 13, 2, 0, 0, 0, 0, 0, 0, 40, 19, 9, 6, 11, 1, 1, 4, 1, 2, 1, 7, 1, 38, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 27, 6, 6, 9, 6, 27, 14, 3, 2, 5, 2, 3, 9, 16, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 2, 6, 3, 1, 7, 1, 2, 4, 1, 3, 29, 4, 2, 0, 0, 0, 8, 2, 1, 9, 2, 5, 1, 2, 6, 5, 3, 6, 25, 5, 1, 1, 0, 0, 0, 0, 0, 0, 2, 1, 3, 4, 3, 3, 5, 12, 1, 5, 7, 7, 11, 7, 0, 0, 0, 0, 2, 1, 1, 1, 4, 2, 2, 1, 0, 0, 0, 0, 0, 1, 2, 1, 5, 1, 1, 0, 0, 0, 0, 1, 1, 12, 2, 0, 0, 0, 1, 34, 1, 1, 0, 0, 0, 0, 0, 1, 4, 1, 0, 3, 3, 2, 1, 0, 0, 1, 0, 0, 2, 4, 13, 1, 0, 0, 0, 0, 6, 9, 0, 0, 0, 0, 2, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 2, 7, 1, 0, 0, 0, 0, 11, 2, 0, 0, 2, 5, 12, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 12, 2, 0, 0, 0, 0, 0, 1, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 2, 0, 0, 14, 13, 0, 0, 0, 123, 31, 26, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 49, 18, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 2, 1, 1, 1, 1, 14, 5, 1, 2, 1, 1, 1, 5, 2, 3, 1, 1, 1, 25, 4, 1, 1, 1, 2, 1, 4, 1, 1, 1, 4, 3, 3, 5, 4, 2, 2, 2, 3, 1, 1, 13, 3, 1, 3, 3, 5, 3, 10, 2, 3, 4, 1, 1, 8, 24, 9, 5, 7, 3, 1, 2, 1, 4, 1, 5, 6, 4, 5, 5, 1, 3, 2, 2, 3, 1, 1, 3, 2, 1, 1, 1, 2, 2, 3, 4, 2, 5, 2, 3, 1, 1, 1, 2, 1, 1, 3, 2, 2, 2, 5, 1, 1, 1, 1, 1, 2, 6, 3, 2, 4, 2, 1, 5, 3, 1, 1, 3, 2, 1, 2, 2, 2, 2, 2, 1, 1, 4, 7, 3, 2, 13, 3, 2, 2, 12, 2, 8, 9, 2, 1, 3, 4, 4, 3, 12, 3, 1, 5, 2, 1, 1, 2, 3, 3, 2, 2, 2, 2, 2, 1, 2, 13, 2, 4, 2, 2, 4, 3, 4, 2, 9, 2, 5, 1, 3, 2, 1, 2, 1, 2, 2, 2, 0, 2, 4, 0, 6, 1, 2, 0, 0, 0, 13, 4, 1, 1, 2, 1, 1, 0, 0, 0, 0, 23, 1, 3, 1, 4, 1, 0, 0, 0, 0, 20, 2, 3, 2, 1, 1, 1, 2, 1, 1, 0, 0, 0, 6, 12, 8, 4, 7, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 5, 2, 1, 2, 2, 0, 0, 0, 0, 8, 1, 5, 1, 3, 1, 0, 0, 0, 0, 0, 5, 2, 2, 2, 1, 1, 1, 0, 3, 3, 1, 1, 1, 1, 0, 0, 0, 0, 5, 8, 1, 1, 0, 0, 0, 0, 3, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 2, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 1, 3, 4, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 3, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 2, 2, 1, 2, 2, 1, 1, 1, 1, 4, 4, 1, 2, 3, 1, 5, 1, 1, 3, 2, 2, 1, 2, 11, 2, 2, 4, 2, 3, 2, 5, 1, 2, 1, 3, 2, 2, 4, 1, 2, 3, 4, 5, 1, 9, 5, 7, 3, 1, 19, 3, 1, 3, 6, 2, 3, 1, 7, 1, 1, 5, 2, 3, 6, 2, 2, 3, 12, 2, 2, 3, 3, 6, 48, 1, 3, 2, 1, 2, 2, 0, 0, 0, 0, 2, 0, 0, 0, 3, 1, 2, 0, 1, 2, 1, 7, 0, 0, 0, 2, 2, 2, 2, 0, 0, 0, 0, 1, 4, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 4, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 4, 2, 1, 0, 1, 0, 1, 0, 1, 1, 4, 1, 0, 0, 0, 0, 1, 3, 1, 0, 0, 0, 0, 2, 2, 1, 1, 6, 2, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 4, 6, 1, 3, 11, 42, 10, 2, 16, 22, 1, 2, 115, 15, 6, 10, 5, 198, 1, 40, 18, 9, 189, 37, 40, 1, 37, 47, 66, 3, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 3, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 2, 21, 1, 3, 3, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 13, 4, 32, 4, 13, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 0, 2, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 4, 8, 4, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 1, 1, 2, 3, 3, 1, 1, 2, 12, 1, 5, 1, 4, 1, 4, 4, 12, 1, 2, 3, 5, 1, 2, 8, 1, 2, 2, 6, 2, 4, 40, 2, 2, 1, 3, 1, 1, 0, 1, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 2, 1, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 0, 0, 1, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 1, 3, 6, 1, 2, 1, 1, 2, 6, 3, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 4, 0, 4, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 2, 4, 37, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 13, 3, 5, 8, 4, 2, 2, 5, 2, 1, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 5, 5, 9, 3, 13, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 4, 0, 1, 0, 1, 1, 0, 0, 2, 1, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 18, 5, 25, 3, 7, 1, 1, 2, 5, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 654, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 4, 0, 1, 0, 1, 0, 1, 1, 1, 1, 6, 19, 7, 2, 42, 28, 2, 1, 4, 3, 3, 2, 3, 2, 261, 7, 2, 4, 3, 2, 2, 8, 3, 2, 2, 2, 3, 31, 48, 17, 7, 9, 3, 8, 1, 1, 1, 2, 1, 36, 13, 3, 6, 4, 3, 6, 2, 3, 11, 4, 23, 17, 160, 268, 133, 27, 20, 5, 6, 3, 2, 3, 8, 2, 35, 6, 4, 5, 1, 5, 9, 2, 4, 3, 2, 4, 2, 7, 5, 5, 5, 4, 1, 3, 2, 3, 3, 8, 4, 2, 1, 3, 2, 2, 1, 3, 8, 1, 3, 1, 3, 11, 4, 1, 2, 1, 5, 5, 4, 3, 0, 0, 0, 118, 15, 10, 8, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 143, 65, 14, 17, 10, 5, 3, 1, 3, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 63, 38, 10, 12, 9, 2, 5, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35, 12, 12, 5, 5, 4, 4, 2, 3, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 19, 12, 10, 6, 2, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 19, 6, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 17, 2, 3, 3, 1, 1, 1, 0, 0, 0, 10, 6, 5, 1, 1, 1, 1, 0, 0, 0, 0, 0, 4, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 5, 2, 0, 0, 0, 0, 0, 3, 2, 3, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 23, 22, 1, 1, 1, 247, 5, 3, 2, 1, 5, 4, 3, 2, 2, 1, 1, 770, 351, 37, 2, 15, 8, 9, 64, 101, 54, 38, 16, 6, 14, 3, 6, 4, 582, 87, 11, 3, 2, 12, 17, 8, 55, 123, 35, 33, 11, 11, 8, 2, 1, 1, 306, 34, 10, 2, 14, 23, 30, 4, 45, 151, 328, 141, 87, 41, 19, 12, 6, 2, 2, 3, 4, 1, 1, 1, 1, 25, 7, 10, 58, 205, 99, 52, 26, 6, 7, 1, 1, 1, 1, 2, 1, 1, 10, 12, 16, 7, 4, 3, 4, 11, 1, 14, 1, 9, 23, 1, 22, 15, 14, 5, 10, 25, 5, 4, 3, 0, 3, 21, 5, 27, 4, 3, 0, 184, 95, 39, 8, 6, 4, 2, 1, 1, 0, 0, 436, 210, 48, 28, 53, 1, 2, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 528, 42, 76, 36, 16, 4, 4, 2, 1, 1, 1, 1, 0, 0, 0, 317, 181, 143, 37, 19, 15, 2, 12, 2, 2, 1, 0, 0, 0, 0, 0, 176, 177, 11, 16, 2, 3, 1, 1, 4, 1, 0, 0, 0, 0, 244, 62, 16, 10, 15, 11, 3, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 246, 83, 42, 8, 20, 3, 7, 2, 3, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 127, 64, 15, 23, 6, 2, 2, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 89, 20, 34, 5, 4, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 27, 50, 27, 6, 9, 1, 2, 2, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 32, 8, 6, 3, 1, 1, 1, 0, 0, 0, 0, 0, 23, 34, 3, 16, 2, 4, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 9, 3, 1, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 12, 1, 6, 3, 2, 1, 0, 0, 0, 0, 0, 0, 4, 4, 2, 1, 2, 1, 0, 0, 0, 0, 2, 6, 1, 1, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 4, 0, 0, 0, 2, 1, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3, 4, 5, 4, 3, 0, 1, 1, 1, 1, 1, 6, 1, 3, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 4, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 18, 5, 117, 38, 1, 0, 6, 1, 0, 0, 0, 3, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 10, 17, 1, 443, 7, 0, 0, 13, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 1, 0, 0, 4, 1, 2, 1, 1, 0, 1, 6, 3, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 18, 1, 1, 17, 16, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 17, 2, 2, 1, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 12, 2, 1, 4, 0, 0, 2, 0, 0, 1, 0, 2, 0, 1, 1, 1, 0, 2, 1, 2, 1, 1, 0, 1, 0, 0, 3, 0, 24, 1, 23, 22, 0, 1, 0], "yaxis": "y"}], "layout": {"height": 300, "legend": {"tracegroupgap": 0}, "shapes": [{"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 3492073, "x1": 3492073, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 8368730, "x1": 8368730, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 17854286, "x1": 17854286, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28492878, "x1": 28492878, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28494246, "x1": 28494246, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28497562, "x1": 28497562, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28497966, "x1": 28497966, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28498191, "x1": 28498191, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28499660, "x1": 28499660, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28500642, "x1": 28500642, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28501398, "x1": 28501398, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28502735, "x1": 28502735, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28502849, "x1": 28502849, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 48714600, "x1": 48714600, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 48714550, "x1": 48714550, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 49438585, "x1": 49438585, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}], "template": {"data": {"bar": [{"error_x": {"color": "rgb(36,36,36)"}, "error_y": {"color": "rgb(36,36,36)"}, "marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "baxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmapgl"}], "histogram": [{"marker": {"line": {"color": "white", "width": 0.6}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "rgb(237,237,237)"}, "line": {"color": "white"}}, "header": {"fill": {"color": "rgb(217,217,217)"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "colorscale": {"diverging": [[0.0, "rgb(103,0,31)"], [0.1, "rgb(178,24,43)"], [0.2, "rgb(214,96,77)"], [0.3, "rgb(244,165,130)"], [0.4, "rgb(253,219,199)"], [0.5, "rgb(247,247,247)"], [0.6, "rgb(209,229,240)"], [0.7, "rgb(146,197,222)"], [0.8, "rgb(67,147,195)"], [0.9, "rgb(33,102,172)"], [1.0, "rgb(5,48,97)"]], "sequential": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "sequentialminus": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]]}, "colorway": ["#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF"], "font": {"color": "rgb(36,36,36)"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "white", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "white", "polar": {"angularaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "radialaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "scene": {"xaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "zaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}, "shapedefaults": {"fillcolor": "black", "line": {"width": 0}, "opacity": 0.3}, "ternary": {"aaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "baxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "caxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}}, "title": {"text": "2R"}, "width": 750, "xaxis": {"anchor": "y", "domain": [0.0, 1.0], "title": {"text": "midpoint"}}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0], "title": {"text": "depth"}}}}, "text/html": ["<div>                            <div id=\"c51c61b8-8b30-4ff6-b32f-2edf91c238a1\" class=\"plotly-graph-div\" style=\"height:300px; width:750px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"c51c61b8-8b30-4ff6-b32f-2edf91c238a1\")) {                    Plotly.newPlot(                        \"c51c61b8-8b30-4ff6-b32f-2edf91c238a1\",                        [{\"hovertemplate\":\"midpoint=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"\",\"marker\":{\"color\":\"lightsalmon\",\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"showlegend\":false,\"x\":[2227,12676,12734,12756,43285,43286,43286,43287,43287,43288,43289,43289,43290,43291,73041,86576,88045,106990,183239,183239,183240,183240,183241,183241,183242,183256,183258,183258,183260,183260,183261,183261,183262,183262,183263,183263,183264,183264,272319,306312,431212,431214,431216,431218,431219,454897,454898,454898,622836,622837,622837,622838,622838,622839,622840,622840,622841,622841,622842,622842,622843,787178,787179,787179,787180,791058,869090,869090,869091,869091,869092,869092,869093,869094,869099,869099,869101,869102,869103,869103,869104,869105,869105,869106,869106,869107,869199,869200,869201,869201,869202,869202,869203,869203,869204,869204,869205,1059579,1181823,1181824,1181827,1665943,1745998,2734160,4184272,5464868,5464868,5464869,8358264,8358319,8358320,8927043,14246340,14248692,14248729,14249109,14249766,30772552,4469,185482,25383,25459,25491,25534,25539,881959,196023,881874,86587,86587,86587,86587,86587,86588,86588,86590,86588,86589,86588,86591,86588,86589,86589,86589,86590,86593,86590,86593,86594,912392,912503,1102879,86602,86603,226541,226563,666139,666139,912392,912405,912406,226542,226542,226543,226564,226565,666140,912393,912504,1789299,226563,666140,912393,912406,226543,226563,226564,226567,666146,146094,942142,173163,269827,176102,271297,213992,530378,366479,366480,366486,366497,366499,366501,366480,366481,366482,366488,366494,366496,366496,366497,366499,366502,366512,366481,366482,366486,366496,366496,366497,366497,366498,366498,366499,366500,366501,366505,366510,366511,366512,366482,366496,366497,366498,366499,366499,366500,366501,366502,366503,366504,366504,366505,366507,366507,366508,366510,366513,366516,366517,366517,366518,366502,366503,366504,366505,366507,366509,366511,366511,366512,366514,366517,366504,366505,366516,366501,366502,366503,366512,366518,366523,366512,366517,366518,366512,366517,366519,366530,366534,806094,366514,366514,366515,366518,366534,806094,2900313,366520,806095,366520,366526,806098,1052349,366518,366525,366526,366536,1052351,366518,366521,366522,366525,366528,366535,366537,806099,1052350,806097,806102,366522,366523,806098,806099,366538,366540,366522,366523,366527,366539,366539,366540,366522,366523,366539,366540,366524,366524,366540,366540,366541,366541,614476,366525,366525,366530,366535,366540,366540,366541,366525,366526,366529,366534,366541,366541,366542,366526,366529,366530,366535,366536,366538,366540,366541,366541,366542,366533,366538,366540,366542,366542,366543,1052466,366542,366543,366543,366544,366529,366544,638163,806102,806103,806104,366545,614482,366545,614482,1242846,366546,806105,806106,366539,366548,614487,974326,366540,366548,614483,1052471,1052368,806108,806108,1052362,1052474,366550,806109,806110,366544,806110,366551,1052369,1052376,974331,366552,806112,1929272,366553,806113,806116,1052368,806115,366555,806114,1052480,366555,614492,638175,1052381,366556,366557,806115,806116,1929276,366557,366558,455600,593965,614494,614496,638176,806111,806114,806116,806116,806117,806120,806120,970457,974336,1052369,1052370,1052370,1052371,1052375,1052377,1052378,1052381,1052383,1052479,1052480,1052480,1052481,1052481,1052482,1052483,1929276,2917438,806116,806117,806117,806120,806120,970458,974337,974337,1052370,1052375,1052479,1052481,806118,1052370,1052381,1052484,806117,806118,1052371,1052484,544653,544656,695709,1141535,612635,929161,821384,834072,846763,846764,854606,878286,1046231,862443,862444,862444,862445,862445,862445,862446,862446,862449,862449,862451,862452,862449,862450,1300321,1300337,1054067,1054068,1054069,1300321,1300322,1054069,1218411,1054070,1054071,1054072,1300329,1054072,909807,909808,909808,909809,909810,909811,909808,1077748,1077748,1077750,1077747,1077749,1324015,1077749,1077750,1324018,1077751,1245674,1245688,1245691,1245674,1245675,1245675,1245678,1245679,1245686,1245690,1245675,1245676,1245679,1245690,1245691,1245691,1245692,1245693,1245676,1245677,1245678,1245679,1245679,1245691,1245691,1245692,1245692,1245693,1245693,1245677,1245678,1245679,1245679,1245680,1245680,1245681,1245681,1245688,1245690,1245691,1245691,1245692,1245692,1245693,1245693,1245694,1245694,1245695,1245695,1245693,1245693,1245694,1245681,1245696,1245681,1245682,1245695,1245696,1245693,1245696,1245696,1245697,1245698,1245694,1245694,1245695,1245696,1245697,1245697,1245698,1245683,1245693,1245694,1245694,1245695,1245697,1245698,1245698,1245699,1245699,1245701,1245694,1245696,1245698,1245698,1245699,1245700,1245698,1245700,1245699,1245701,1245700,1245703,1491942,1245705,1245708,1245706,1245707,1245710,1491943,1491954,1245706,1245707,1245707,1245708,1245709,1245709,1491944,1492054,1245707,1245708,1245709,1245709,1245710,1245711,1333716,1410033,1413911,1413912,1491944,1491945,1491954,1491958,1492056,1492056,1492057,1492058,1245708,1245709,1245710,1245710,1245711,1413912,1413912,1491945,1491945,1491946,1491960,1492057,1492058,1245709,1245710,1245710,1245711,1245711,1245712,1245712,1491946,1491956,1492056,1492057,1492058,1245710,1245711,1245711,1491946,1491946,1491950,1492056,1492058,1492059,1245711,1245712,1245712,1245713,1245713,1410032,1413913,1413914,1491944,1491946,1491946,1491947,1491948,1491950,1491956,1491959,1491960,1491961,1491963,1492056,1492058,1492058,1492059,1492060,1804679,2368853,1245712,1245713,1245715,1410034,1410035,1413914,1433403,1491946,1491947,1491947,1491948,1491948,1491950,1491952,1491957,1491959,1491960,1491963,1491963,1492057,1492058,1492059,1492060,2368854,1245713,1245714,1410035,1413914,1433403,1491946,1491947,1491947,1491948,1491948,1491949,1491949,1491951,1491953,1491962,1491963,1491963,1491964,1491964,1492056,1492057,1492059,1492059,1492060,1492060,1492061,1682436,3357016,3357017,6087724,1245714,1245715,1410036,1410037,1413915,1491947,1491948,1491948,1491957,1491959,1491960,1492060,1682435,2368855,1410036,1413915,1413916,1491948,1491949,1491950,1491954,1491959,1491962,1492061,1492062,1410037,1491949,1491950,1491950,1491954,1492061,1491955,1491951,1421739,1501934,1574355,1574369,1574370,1574358,1574371,1574371,1574372,1574372,1578250,1656283,1656283,1656284,1656287,1656293,1656294,1656295,1656297,1656393,1656394,1656395,1656396,2533190,1582116,1582128,1582128,1582129,1582129,1582130,1582131,1582129,1582129,1582130,1582141,1660171,1582141,1660162,1660164,1660161,1660162,1660162,1660176,1660177,1660274,1850650,1660162,1660163,1660175,2537069,1660163,1660164,1621118,1621119,1679676,1679684,1738195,1738181,1738182,1738196,1738181,1738182,1738186,1738187,1738196,1738197,1738198,1738182,1738183,1738183,1738184,1738184,1738186,1738187,1738189,1738190,1738192,1738192,1738193,1738194,1738195,1738195,1738196,1738196,1738197,1738197,1738198,1738198,1738199,1738199,1738200,1738202,1738183,1738184,1738184,1738185,1738185,1738186,1738187,1738187,1738188,1738188,1738191,1738192,1738192,1738193,1738193,1738194,1738194,1738195,1738195,1738196,1738196,1738197,1738197,1738198,1738198,1738199,1738199,1738200,1738200,1738201,1738201,1738202,1738203,1738204,1738184,1738185,1738188,1738195,1738195,1738196,1738196,1738197,1738198,1738198,1738199,1738199,1738200,1738185,1738188,1738189,1738191,1738194,1738195,1738196,1738197,1738198,1738198,1738199,1738200,1738200,1738201,1738203,1738205,1738208,1738210,1738212,1738199,1738200,1738200,1738201,1738213,1738194,1738200,1738202,1738213,1738190,1738200,1738209,1738215,1738216,1738190,1738217,1738206,1738217,1738199,1738199,1738201,1738211,1738216,1738199,1738201,1738202,1738202,1738203,1738204,1738204,1738209,1738218,1738196,1738197,1738201,1738204,1738205,1738205,1738218,1738219,1738194,1738201,1738203,1738204,1738204,1738196,1738199,1738200,1738204,1738221,1738207,1738201,1738203,1738205,1738221,1738221,1738203,1738204,1738208,1738202,1738203,1738204,1738204,1738207,1738210,1738210,1738215,1738223,1738223,1738204,1738205,1738206,1738211,1738223,1738204,1738205,1738208,1738209,1738210,1738211,1738223,1738223,1738205,1738206,1738207,1738208,1738208,1738211,1738207,1738208,1738208,1738209,1738210,1738210,1738212,1738213,1738213,1738215,1738223,1738227,1738208,1738209,1738209,1738210,1738210,1738212,1738213,1738213,1738216,1738224,1738224,1738225,1738225,1738226,2615101,1738209,1738209,1738210,1738211,1738211,1738212,1738212,1738223,1738225,1738307,1770490,1738209,1738210,1738210,1738211,1738211,1738212,1738213,1738215,1738225,1738226,1738226,1738227,1738228,1738307,1738210,1738211,1738211,1738212,1738213,1738215,1738226,1738226,1738227,1738227,1738229,1738308,1738308,1738211,1738212,1738212,1738213,1738214,1738215,1738216,1738225,1738226,1738227,1738227,1738228,1738309,1738309,1738212,1738213,1738213,1738214,1738214,1738215,1738217,1738218,1738222,1738225,1738226,1738227,1738227,1738228,1738229,1738310,1738213,1738214,1738214,1738215,1738215,1738216,1738217,1738220,1738227,1738228,1738228,1738229,1738230,1738309,1738309,1738310,1738310,2615104,1738214,1738215,1738215,1738216,1738217,1738218,1738219,1738228,1738228,1738229,1738308,1738309,1738310,1738310,1738311,2050933,1738215,1738216,1738216,1738217,1738218,1738219,1738220,1738221,1738223,1738228,1738229,1738229,1738230,1738231,1738231,1738309,1738310,1738310,1738312,2050931,2615105,1738216,1738217,1738217,1738218,1738218,1738220,1738229,1738229,1738230,1738230,1738231,1738231,1738308,1738309,1738311,1738312,1738312,1738217,1738218,1738218,1738219,1738219,1738222,1738222,1738229,1738229,1738230,1738230,1738231,1738310,1738311,1738311,1738312,1738312,1738313,1738219,1738219,1738220,1738221,1738228,1738230,1738230,1738231,1738311,1738311,1738312,1738312,1738313,1738313,2050932,6333977,1738219,1738220,1738226,1738231,1738232,1738233,1738312,1738312,1738221,1738223,1738223,1738228,1738231,1738231,1738232,1738233,1738311,1738312,1738313,1738230,1738231,1738232,1738233,1738313,1738314,1738315,1738222,1738231,1738232,1738235,1738313,1738227,1738235,1738314,1738233,1738312,1738315,1738315,1738230,1738233,1738234,1738236,1738314,1738315,1738235,1738316,2050936,1738233,1738234,1738236,1738235,1738236,1738316,1738234,1738238,1738318,1738237,1738238,1738238,1738236,1738240,1738320,1738239,1738240,1738242,1738322,1738324,1738241,1738242,1738322,1738323,1738323,1738241,1738243,1738320,1738322,1738323,1738323,1738242,1738243,1738243,1738244,1738245,1738245,1738322,1738323,1738324,1738324,1738325,2615119,2802082,1738243,1738244,1738245,1738245,1738321,1738323,1738323,1738324,1738324,1738325,1738325,1738326,1928698,2387377,2615119,3603282,1738244,1738246,1738322,1738323,1738323,1738324,1738325,1738325,1738326,1738326,1928701,1928701,2050946,2615120,1738245,1738246,1738246,1738322,1738323,1738323,1738324,1738324,1738325,1738325,1738326,1738326,1738327,1738327,1928702,2050946,2502839,2615120,1738325,1738326,2615121,1738247,1738323,1738326,1738326,1738327,1738327,1738328,1738324,1738325,1738325,1738326,1738327,1738328,1738328,2050949,2615122,6333993,1738327,1738418,1738422,1738402,1738402,1738403,1738403,1738402,1738403,1738403,1738402,1738403,1738404,1738404,1738405,1738418,1738419,1738403,1738404,1738404,1738405,1738406,1738418,1738404,1738405,1738405,1738406,1738419,1738421,1738424,1738428,1738405,1738406,1738406,1738407,1738420,1738422,1738423,1738424,1738424,1738425,1738406,1738407,1738407,1738408,1738419,1738420,1738420,1738421,1738421,1738422,1738422,1738423,1738423,1738424,1738424,1738425,1738425,1738426,1738427,1738428,1738407,1738408,1738408,1738419,1738420,1738421,1738422,1738422,1738423,1738423,1738424,1738424,1738425,1738426,1738427,1738427,1738429,1738408,1738416,1738419,1738421,1738421,1738422,1738422,1738423,1738423,1738424,1738424,1738425,1738425,1738426,1738426,1738427,1738428,1738409,1738410,1738410,1738420,1738421,1738421,1738422,1738422,1738423,1738423,1738424,1738424,1738425,1738425,1738426,1738426,1738427,1738427,1738431,1738421,1738422,1738422,1738423,1738423,1738424,1738424,1738425,1738426,1738428,1738429,1738423,1738421,1738431,1738433,1738435,1738435,1738435,1738435,1738436,1738436,2615214,1738434,1738435,1738436,1738436,1738437,1738435,1738436,1738436,1738437,1738437,1738438,1738439,1928794,1928797,2615215,5053532,1738436,1738437,1738437,1738438,1738438,1738439,1738440,2615216,4946355,1738437,1738438,1738438,1738439,1738439,1738440,1738444,1770605,1928797,1928798,2051042,2615216,6334085,1738438,1738439,1738439,1738440,1738440,1738443,1738444,1738446,1928798,1928803,1981545,2051046,2615217,3603378,3603379,4946357,6334087,1738439,1738440,1738440,1738441,1738441,1738442,1738442,1738443,1738443,1738444,1738444,1738446,1884142,1928797,1928798,1928798,1928799,1928800,1960714,2051043,2051043,2051044,2051045,2615217,2817589,3603379,5053526,6334088,1738440,1738441,1738441,1738442,1738442,1738443,1738443,1738444,1738446,1738447,1928798,1928799,1928799,2051043,2051046,2077037,2409458,2535163,2615218,4946357,5053492,6334088,1738441,1738442,1738442,1738443,1738443,1738444,1738444,1738445,1738445,1738446,1928797,1928798,1928799,1928800,1948868,2051044,2573596,2606258,2615218,2615218,2615306,3586277,3603380,4946358,5053531,1738442,1738443,1738443,1738444,1738444,1738445,1738445,1738446,1738447,1738447,1738448,1928795,1928798,1928798,1928799,1928800,1992498,2051044,2051046,2051046,2615219,3603381,6334089,1738443,1738444,1738444,1738445,1738445,1738446,1738447,1928798,1928799,1928799,1928800,1928801,2615219,1738444,1738445,1738445,1738446,1738447,1738448,1738448,1928799,1928800,1928801,1928801,2051045,2615220,3082886,3586278,3586280,3603382,1738445,1738446,1738446,1738447,1738447,1738448,1738449,1740248,1928797,1928799,1928799,1928800,1928801,1928801,1928802,2010616,2051046,2051047,2051048,2077039,2535166,2615220,3586278,3603382,5053494,5053529,1738446,1738447,1738447,1738448,1738449,1738450,1770608,1928799,1928800,1928800,1928801,1928801,1928802,1928804,2051046,2051050,2535167,2615221,1738447,1738448,1738448,1738449,1738450,1928800,1928801,1928801,1928802,1928802,1928803,2051048,2615221,3603383,5053495,1738448,1738449,1738450,1738450,1738454,1928797,1928798,1928801,1928802,1928803,1928803,2051047,2051048,2051048,2051051,2077041,2387479,2535167,2615222,2615245,2615276,2615279,1738449,1738450,1738451,1738451,1738452,1928801,1928802,1928803,1928804,1928804,2461230,2535168,2615222,3603384,1738450,1738451,1738452,1740250,1928802,1928803,1928804,1981551,2051050,2051051,2387479,2615223,1928802,1928804,1928804,1928805,2051050,2615223,1738452,1738454,1928803,1928804,1928805,1948874,2051053,2615224,1738453,1928802,1928803,1928804,2051050,2615224,1738454,1928801,1928806,2615225,1928805,1928805,1928806,2409466,2615225,1928805,2051054,1742054,1742061,1742109,1742116,1742192,1930660,2078928,1802786,1802788,1960974,2405995,6094964,2029861,2760936,2119152,2119168,2119153,2119166,2119168,2119153,2119169,2119153,2119154,2119154,2119155,2119156,2119156,2119171,2119172,2119172,2119155,2119156,2119156,2119157,2119171,2119172,2119172,2119173,2119174,2119156,2119157,2119157,2119173,2119173,2119157,2119158,2119159,2119173,2119173,2119174,2119158,2119173,2119174,2119174,2119175,2119171,2119172,2119173,2119174,2119174,2119175,2119175,2119175,2119176,2119177,2119180,2119187,2796629,2119188,2119188,2119189,2805592,2119189,2119190,2241416,2241417,2241418,2241419,2241420,2241420,2241421,2267411,2805592,2805615,2119190,2119191,2139243,2241416,2241417,2241418,2241419,2241419,2241421,2241421,2267412,2487193,2569171,2725538,2725539,2805592,2805593,2805644,6524463,2151090,2241419,2241419,2651260,2667171,2725536,2805593,2805593,3793755,6524463,2241419,2805594,2805594,2241424,2159306,2159307,2159308,2159436,2159439,2159439,2159566,2159568,2159568,2261614,2825787,2182999,2183080,2183080,2183161,2183161,2837583,5275857,2224663,2224665,2858335,2294162,2246566,2869287,2282931,2887535,2363657,2363645,2363660,2363647,2363648,2363649,2363649,2363651,2363661,2363662,2363662,2363663,2363663,2363664,2363664,2363667,2363662,2363663,2363663,2363664,2363664,2363665,2363665,2363666,2363650,2363664,2363664,2363665,2363668,2363670,2363651,2363665,2363663,2363666,2363662,2363664,2363664,2363665,2363665,2363666,2363667,2363668,2363666,2363669,2363670,2363666,2363670,2927834,2363675,2789413,2927835,2927836,2927892,2363677,2363679,2363681,2847781,2847782,2927836,2363679,2363679,2927837,2363679,2363680,2363683,2389656,2722078,2847783,2927837,3898895,2363680,2927838,3915999,3916000,5366135,2927838,2927887,2847784,2927838,2927839,4163829,2927839,2927840,2927840,2927841,2927834,2927842,6646712,2927844,2415695,2415700,2415761,2415770,2415844,2415846,2415917,2953956,2953957,2855272,3173672,3009262,3250666,3019163,3255585,3036521,3036522,3036523,3264264,3109931,3264265,3080491,3080491,3080492,6012391,3286251,3286252,3183340,3183342,3257622,3337675,3184023,3338016,3215162,3273530,3353585,3267439,3267505,3267579,3267593,3379795,3331894,3331900,3331901,3331901,3331903,3331900,3331901,3331900,3331901,3331902,3411951,3411954,3411954,4367851,3331914,3411955,3411955,3411955,3411956,5850230,3411956,3411958,3408760,3450383,3474087,3483047,4471213,3491988,3491995,3491996,3491997,3491998,3491998,3491999,3492006,3492007,3492007,3492017,3492018,3492018,3492019,3492071,3491998,3491998,3492018,3492019,3492019,3491999,3492000,3492020,3492000,3492009,3492020,3492021,3492003,3492020,3492021,3492021,3492022,3492023,3492016,3492029,3492017,3492018,3492030,3492030,3492067,5930281,5930316,3492040,3492040,3492041,3492041,3492042,3492043,3492043,3492044,3492044,3492045,3492046,3492046,3492047,3492047,3492048,3492049,3492049,3492050,3492051,3492052,3492054,3492054,3492058,3492060,3492061,3492061,3492062,3492063,3492063,3492064,3492064,3492065,3492065,3492066,3492067,3492068,3492068,3492069,3492069,3492070,3492070,3492071,3492071,3492072,3492072,3492073,3492073,3492074,3492075,3492076,3492077,3492077,3492078,3492079,3492081,3492083,3492085,3492092,3492092,3492094,3492094,3492045,3492045,3492047,3492049,3492063,3492063,3492065,3492067,3492069,3492069,3492076,3492077,3492094,3492095,3492050,3492070,3492078,3492095,3492068,3492054,3492065,3492068,3492070,3492071,3492096,3492051,3492065,3492068,3492095,3492097,3492057,3492061,3492074,3492098,3492073,3492072,3492074,3492099,3492069,3492074,3492099,3492073,3492079,3492069,3492076,3492101,3492070,3492075,3492076,3492102,3492069,3492103,3492071,3492104,3492083,3492106,3492107,3492080,3492078,3492110,3492085,3492089,3492112,3492083,3492096,3492113,3492088,3492091,3492099,3492114,3492084,3492088,3492092,3492088,3492089,3492090,3492094,3492096,3492108,3492110,3492112,3492115,3492089,3492092,3492093,3492099,3492115,3492097,3492116,3492092,3492094,3492095,3492096,3492097,3492090,3492092,3492100,3492116,3492117,3492092,3492094,3492096,3492090,3492091,3492090,3492094,3492092,3492094,3492093,3492096,3492097,3492093,3492094,3492095,3492097,3492103,3492120,3492094,3492095,3492096,3492096,3492097,3492097,3492102,3492105,3492112,3492113,3492118,3492118,3492120,3492096,3492098,3492100,3492120,3492121,3492096,3492098,3492098,3492101,3492103,3492116,3492118,3492121,3492121,3492098,3492099,3492102,3492103,3492107,3492108,3492109,3492113,3492115,3492121,3492122,3492098,3492122,3492122,3492099,3492100,3492106,3492117,3492123,3492101,3492103,3492121,3492123,3492123,3492105,3492115,3492120,3492121,3492122,3492123,3492124,3492124,3492104,3492119,3492121,3492121,3492123,3492125,3492105,3492117,3492118,3492119,3492105,3492116,3492126,3492126,3492126,3492118,3492127,3492128,3492111,3492123,3492127,3492128,3492128,3492129,3492130,3492130,3492130,3492131,3492131,3492131,3492132,3492133,3492134,3492135,3492137,3492138,3492138,4463121,3492139,3492140,3492137,3492140,3492140,3492141,3492139,3492142,3492143,3492143,3492144,3492144,3492145,3492145,3492145,3492145,3492146,5930444,3492146,3492147,3492148,3492148,3492153,3492156,3492161,3492163,3492163,3492164,3492165,3492165,3492166,3492167,3492167,3492168,3492168,3492169,3492169,3492170,3492170,3694442,4480233,4480234,5417685,5930345,7210941,3492149,3492160,3492161,3492163,3492164,3492165,3492167,3492168,3492169,3492169,3492170,3492170,3492171,3492165,3492171,3492176,3492179,3492172,3492183,3492184,3492184,3492185,3492186,3492184,3492186,3492187,3492187,3492188,3492188,3492189,3492189,3492189,3492190,3492190,3492191,3492191,3492191,3492191,3492192,3492192,3492193,3492194,3504012,3504013,3648547,3679057,3680754,3694464,3694465,3780411,3853590,3904491,3943087,3959763,4067883,4109027,4147363,4163450,4183436,4217090,4426353,4463150,4463151,4463152,4463152,4463153,4463153,4463154,4463154,4480253,4480255,4480255,4480256,4480256,4480257,4480257,4480258,4480258,4480259,4480261,4728084,4959365,4966839,5091344,5268949,5417708,5450932,5823233,5823234,5823234,5823235,5823237,5854631,5930368,5930368,5930403,7210964,10104386,10866241,15992437,32518649,3492263,4480257,4480257,4480259,5823234,5930369,3680755,4480258,5823235,5930369,3492334,5930439,3515844,3515844,4492088,4492088,3804919,3804920,3804921,3804925,4619525,4636629,4636630,4636631,6086747,3865937,3865937,4667135,6117248,3869330,4916660,6118944,3896747,3896748,3896749,3896750,4682539,6132651,4987051,6132653,4068641,4768487,4214999,4215000,4841667,6291778,4316824,4875485,4394017,4931186,4427344,4427350,4930736,4947843,4643632,5056005,4725873,5097103,6547215,4802544,5135438,4834723,6601641,4874731,6621664,4941998,4942004,6655276,5188066,5360525,5397324,5403802,5436067,5434123,5434124,5434125,5434111,5434121,5434112,5434124,5434126,5434127,5434127,5434128,5434128,5434127,5434128,5434128,5434129,5434126,5434127,5434128,5434126,5434129,5434129,5434217,5434140,5434219,5434220,5451229,5434222,5699058,5434142,6388682,5434142,5451231,5451231,5451232,6794208,6794209,6901342,6901343,7128554,8181939,5434222,5451231,5451231,5451232,5451232,5451233,6794209,6901343,6901343,7128554,8181937,8181938,5451232,6794209,6901344,5451233,5434312,5434312,5434313,5434315,5451321,5451321,5451322,6901433,8182029,5451322,5468316,5468319,5468335,5468319,5468336,5468319,5468320,5468321,5468334,5468334,5468335,5468335,5468336,5468336,5468338,5468320,5468321,5468322,5468333,5468334,5468334,5468335,5468335,5468336,5468336,5468337,5468321,5468322,5468322,5468323,5468324,5468333,5468335,5468335,5468336,5468336,5468337,5468337,5468338,5468322,5468323,5468336,5468337,5468337,5468338,5468338,5468339,5468324,5468337,5468337,5468338,5468338,5468339,5468339,5468340,5468341,5468324,5468327,5468336,5468337,5468337,5468338,5468338,5468339,5468339,5468338,5468340,5468339,5468340,5468341,5468342,5468339,5468341,5468345,5468348,5468349,5716161,6414836,5468349,5468351,5468350,5468351,6811312,6918446,5468350,5468351,5468351,5468352,5468352,6811312,6918446,6918447,8199043,5468351,5468352,5468352,5468354,5468356,5716163,5733288,6405788,6811313,6811313,6918447,6918447,6918484,8199043,5468352,5468353,5716164,5810342,6018615,6405788,6642843,6811313,6811314,6918447,6918448,8199044,5468353,5468354,5468355,5716164,6224282,6811312,6811314,6811314,6918448,6918448,6918483,6918484,8199044,5468355,5716165,6079425,6606642,6811314,6811315,6828951,6918448,6918449,6918503,8199044,5468356,5468357,5716165,6811315,6918449,6918449,6918450,5468359,5716166,6811316,6811316,6918450,7927741,8199046,5716167,6918451,6918452,6918452,6918452,6811318,5963988,5963989,5963990,5963991,5963991,5963992,7166272,6854468,7166273,5964005,6921251,7059139,7059140,7166274,6653615,6807487,7059140,7166275,7059141,7166275,5998236,6703958,6077353,7222954,6152347,7260453,6426548,7397551,6441497,7297892,6568888,7468721,6690508,6690511,6690580,7422400,6690652,7529604,6980226,7674393,7045715,7707135,7343239,7343239,7343240,7343240,7343240,7855899,7855937,7855899,7855900,7855900,7361336,7757812,7409686,7781988,7889122,7650989,8009777,7744945,7744947,8056752,8056752,7817340,7817416,7817488,7985884,7878521,8123543,8154287,8154289,8154289,8154275,8154276,8154289,8154290,8154290,8154291,8154291,8154277,8154290,8154291,8154291,8154293,8154291,8154291,8154292,8154293,8154294,8154280,8154293,8154294,8261423,8261424,8154305,8154306,8261424,8261424,8261459,8350737,9542019,9542020,8154306,8261424,8261425,8407399,9542021,8261425,8261425,8261425,8261426,8261427,8189563,8279061,8217081,8292818,8368543,8368544,8368545,8368546,8368556,8368557,8368558,8368560,8368563,8368565,8368569,8368575,8368577,8368578,8368578,8368579,8368580,8368586,8368594,8368609,8368611,8368617,8368619,8368545,8368546,8368548,8368573,8368578,8368578,8368579,8368578,8368579,8368580,8368581,8368582,8368590,8368592,8368593,8368586,8368595,8368597,8368599,8368615,8368603,8368604,8368606,8368610,8368611,8368612,8368612,8368613,8368614,8368614,8368615,8368616,8368616,8368617,8368618,8368618,8368619,8368619,8368621,8368621,8368622,8368622,8368623,8368624,8368624,8368625,8368626,8368627,8368627,8368628,8368628,8368629,8368629,8368630,8368630,8368631,8368631,8368632,8368632,8368633,8368633,8368634,8368634,8368635,8368635,8368636,8368637,8368637,8368638,8368639,8368639,8368640,8368640,8368642,8368643,8368644,8368645,8368645,8368646,8368646,8368647,8368648,8368649,8368651,8368652,8368652,8368653,8368653,8368654,8368656,8368614,8368615,8368615,8368616,8368616,8368617,8368617,8368618,8368620,8368620,8368621,8368622,8368624,8368624,8368627,8368628,8368628,8368629,8368629,8368630,8368630,8368631,8368631,8368632,8368632,8368633,8368633,8368634,8368635,8368635,8368636,8368636,8368637,8368638,8368638,8368639,8368640,8368642,8368643,8368644,8368645,8368646,8368647,8368648,8368649,8368650,8368652,8368654,8368654,8368616,8368618,8368619,8368623,8368629,8368629,8368630,8368632,8368632,8368633,8368635,8368637,8368648,8368648,8368653,8368655,8368618,8368618,8368626,8368630,8368632,8368633,8368636,8368639,8368619,8368620,8368621,8368622,8368626,8368628,8368630,8368631,8368631,8368632,8368633,8368634,8368634,8368635,8368635,8368639,8368640,8368645,8368647,8368652,8368619,8368653,8368620,8368624,8368627,8368628,8368633,8368636,8368646,8368622,8368632,8368632,8368633,8368634,8368635,8368635,8368636,8368637,8368639,8368640,8368643,8368655,8368655,8368623,8368624,8368625,8368626,8368628,8368629,8368629,8368630,8368632,8368633,8368634,8368635,8368637,8368637,8368638,8368641,8368647,8368648,8368656,8368624,8368631,8368633,8368634,8368635,8368635,8368636,8368639,8368639,8368645,8368659,8368630,8368630,8368634,8368636,8368641,8368660,8368627,8368628,8368631,8368635,8368636,8368636,8368638,8368640,8368642,8368642,8368646,8368655,8368658,8368660,8368635,8368630,8368632,8368635,8368637,8368638,8368641,8368642,8368642,8368643,8368645,8368652,8368662,8368648,8368635,8368638,8368639,8368639,8368643,8368661,8368663,8368663,8368644,8368659,8368664,8368635,8368637,8368637,8368640,8368640,8368642,8368643,8368644,8368648,8368651,8368658,8368663,8368663,8368665,8368665,8368638,8368638,8368640,8368642,8368648,8368640,8368651,8368643,8368641,8368641,8368642,8368644,8368645,8368646,8368646,8368647,8368647,8368649,8368650,8368651,8368653,8368657,8368662,8368642,8368642,8368643,8368648,8368655,8368666,8368643,8368643,8368655,8368668,8368643,8368646,8368648,8368649,8368651,8368662,8368644,8368645,8368646,8368646,8368647,8368648,8368649,8368650,8368651,8368653,8368654,8368655,8368655,8368658,8368661,8368666,8368668,8368668,8368669,8368669,8368645,8368646,8368646,8368647,8368647,8368648,8368648,8368649,8368650,8368650,8368651,8368653,8368654,8368656,8368656,8368665,8368668,8368669,8368670,8368646,8368647,8368647,8368649,8368654,8368656,8368657,8368662,8368670,8368648,8368648,8368649,8368650,8368651,8368651,8368652,8368652,8368653,8368654,8368655,8368657,8368660,8368662,8368662,8368664,8368664,8368666,8368669,8368671,8368705,8368648,8368649,8368650,8368651,8368652,8368653,8368653,8368654,8368654,8368655,8368656,8368657,8368658,8368665,8368666,8368667,8368670,8368671,8368649,8368650,8368650,8368651,8368652,8368652,8368653,8368653,8368654,8368654,8368655,8368655,8368656,8368657,8368658,8368662,8368665,8368669,8368670,8368672,8368650,8368651,8368652,8368652,8368653,8368653,8368654,8368654,8368655,8368656,8368657,8368658,8368661,8368664,8368665,8368667,8368670,8368652,8368654,8368656,8368656,8368657,8368658,8368669,8368669,8368670,8368671,8368673,8368653,8368654,8368654,8368655,8368657,8368660,8368669,8368673,8368653,8368654,8368654,8368655,8368656,8368657,8368658,8368659,8368663,8368666,8368667,8368672,8368674,8368654,8368655,8368656,8368658,8368659,8368660,8368660,8368663,8368666,8368668,8368674,8368655,8368656,8368656,8368657,8368658,8368658,8368659,8368660,8368665,8368668,8368673,8368674,8368674,8368675,8368657,8368658,8368658,8368659,8368660,8368661,8368661,8368664,8368665,8368665,8368668,8368670,8368673,8368674,8368674,8368675,8368657,8368658,8368658,8368659,8368660,8368665,8368667,8368668,8368673,8368674,8368676,8368658,8368659,8368660,8368660,8368662,8368663,8368665,8368669,8368671,8368674,8368676,8368660,8368660,8368661,8368662,8368662,8368675,8368676,8368676,8368677,8368660,8368661,8368662,8368663,8368674,8368675,8368676,8368677,8368662,8368663,8368664,8368668,8368673,8368676,8368677,8368678,8368662,8368663,8368664,8368664,8368665,8368666,8368667,8368667,8368670,8368670,8368671,8368673,8368674,8368675,8368675,8368676,8368677,8368677,8368678,8368678,8368691,8368676,8368677,8368678,8368665,8368665,8368666,8368667,8368670,8368672,8368673,8368676,8368676,8368677,8368677,8368678,8368678,8368679,8368679,8368675,8368680,8368666,8368668,8368669,8368673,8368674,8368676,8368677,8368678,8368678,8368679,8368679,8368680,9649201,8368667,8368670,8368671,8368672,8368673,8368676,8368677,8368678,8368679,8368680,8368680,8368681,8368668,8368672,8368673,8368675,8368676,8368679,8368681,8368671,8368673,8368675,8368677,8368678,8368681,8368674,8368676,8368680,8368682,8368672,8368674,8368674,8368677,8368677,8368679,8368679,8368681,8368681,8368682,8368682,8368683,8368684,9649204,8368679,8368682,8368676,8368676,8368678,8368683,8368684,8368685,8368679,8368679,8368680,8368681,8368683,8368683,8368684,8368685,8368686,8368679,8368680,8368681,8368684,8368686,8368686,8368685,8368687,8368680,8368685,8368682,8368684,8368685,8368685,8368686,8368687,8368687,8368688,8368683,8368684,8368686,8368687,8368688,8368687,8368688,8368685,8368687,8368687,8368689,8368689,8368686,8368686,8368688,8368688,8368689,8368690,9649208,8368688,8368688,8368690,8368687,8368689,8368690,8368691,8368689,8368690,8368691,8368691,8368689,8368690,8368690,8368692,9377907,8368690,8368691,8368692,8368692,8368691,8368692,8368692,8368693,8368692,8368693,8368693,8368693,8368694,8368694,8368695,8368696,8368696,8368697,8368698,8368700,8368701,8368701,8368702,8368702,8368703,8368704,8368705,8368706,8368706,8368707,8368707,8368708,8368711,8368712,8368713,8368724,8368726,8368727,8368727,8368728,8368728,8368729,8368729,9377910,9649214,9649215,9649218,8368696,8368697,8368698,8368699,8368700,8368701,8368701,8368702,8368702,8368703,8368704,8368705,8368706,8368708,8368713,8368714,8368717,8368718,8368720,8368723,8368724,8368726,8368726,8368727,8368727,8368728,8368728,8368729,8368729,8368730,8368703,8368713,8368719,8368720,8368728,8368730,8368699,8368702,8368703,8368703,8368704,8368705,8368707,8368709,8368730,8368731,8368703,8368731,8656488,8368732,8368704,8368734,8368707,8368707,8368709,8368733,8368734,8368735,8368734,8368735,8368708,8368709,8368710,8368710,8368715,8368716,8368717,8368730,8368733,8368735,8368736,8368710,8368725,8368733,8368734,8368736,8368736,8368737,8368712,8368737,8368713,8368716,8368717,8368722,8368736,8368738,8368738,8368715,8368716,8368718,8368718,8368723,8368739,8368718,8368720,8368724,8368740,9649226,8368741,8368741,8368721,8368742,11751791,8368742,8368743,8368727,8368743,8368744,8368745,8368744,8368741,8368744,8368745,8368747,8368731,8368747,8368745,8368746,8368748,8368748,8368747,8368750,8368752,8368753,8368754,8368757,8368758,8368754,8368758,8368758,8368760,8368758,8368759,8368758,8368761,8368760,8368760,8368761,8368761,8368761,8368762,8368762,8368763,8368763,8368764,8368765,8368797,8457966,8514626,8514629,8595860,8595861,8595862,8595862,8595863,8595864,8595864,8595865,8595865,8595866,8595866,8595867,8595868,8635371,8656520,8656521,8884941,8884944,8884944,8888070,8957354,9239795,9351419,9351420,9361214,9377943,9377944,9377944,9436361,9436363,9589037,9596352,9649247,9649248,9649248,9649249,9649249,9649250,9649250,9649251,9649252,11559236,11904431,12542673,12542687,12542701,12542702,13111425,18430722,8368765,8368797,8483991,8595860,8595861,8595862,8595864,8595865,8595865,8595866,8595866,8704197,8861893,9239797,9361168,9377944,9377945,9436361,9436361,9649246,9649248,9649249,9649250,9649250,9649253,12542703,12542704,8595862,8595864,8595866,8900304,9351421,9377945,9649251,8368905,9378053,9649358,8547180,9738464,8599232,9493185,8660503,8660504,8660506,9030821,9030821,9795127,8822971,8822973,8822973,8822974,8822974,8822975,8822975,8822976,8822964,8822979,8822965,8822979,8822980,8822965,8822966,8822980,8822966,8822967,8822967,8822981,8822981,8822982,8822967,8822968,8822981,8822981,8822982,8822982,8822983,8822983,8822968,8822970,8822982,8822982,8822983,8822982,8822983,8822984,8822970,8822983,8822983,8822984,8822985,9605054,9605057,9663469,9876362,9876363,9605058,9876363,8822996,8822997,9112060,9876365,9876365,8822996,8822997,8822997,8822998,9605060,9605061,9876366,8822997,9112059,9112061,9605060,9605061,9876366,9876366,8822998,8822999,9067162,9578536,9578537,9605061,9605061,9605062,9605063,9663477,9761333,9876365,9876366,9876367,9605062,9636382,9876365,9876366,9876367,9876366,9876367,9876368,8901992,9644565,8944289,8944290,8944291,8944289,9665712,9665713,9937020,9649096,9039642,9984695,9311337,10120542,9355045,9871097,9401131,9401133,9401135,9401136,9401134,9401136,9401137,9401137,9401138,9401138,9401215,9401216,9401216,9401217,9401217,9401219,9894137,10165442,10165443,9894138,10165443,9401298,9401298,9401299,9401299,9401300,9894217,10165522,9894217,9407422,10168601,9431855,9909495,9545970,9966560,10110840,10110840,10520294,10248989,10334090,10334092,10334093,10631921,10631922,10631923,10631923,10353629,10353677,10353720,10353721,10353792,10353831,10641783,10353898,10370516,10641822,10387137,10387138,10387138,10387124,10387139,10387139,10387137,10387138,10387139,10387139,10387140,10387141,10387142,10387143,10658442,10658443,10658443,10658444,10658444,10387154,10658444,10658445,10445556,10445556,10658444,10658444,10658445,10658445,10658446,10658446,13551898,10658446,10658446,10658445,10449781,10689766,10503956,10503971,10503972,10503972,10503973,10503974,10503986,10716861,10716861,10716861,10699677,10699729,10699781,10814763,10809325,10869538,10823990,10824044,10876893,10929732,10929733,10929734,10929734,10929734,10929749,10929735,10929735,10929736,10929737,10929737,10929738,10929739,10929753,10929737,10929738,10929738,10929739,10929751,10929751,10929752,10929752,10929753,10929738,10929739,10929739,10929740,10929740,10929751,10929752,10929752,10929753,10929753,10929739,10929740,10929740,10929741,10929741,10929751,10929751,10929752,10929752,10929753,10929753,10929754,10929740,10929741,10929741,10929742,10929743,10929751,10929751,10929752,10929752,10929753,10929753,10929754,10929756,10929741,10929742,10929742,10929743,10929752,10929752,10929753,10929753,10929754,10929754,10929755,10929756,10929742,10929743,10929743,10929744,10929752,10929752,10929753,10929753,10929754,10929754,10929755,10929743,10929753,10929754,10929754,10929755,10929755,10929754,10929755,10929755,10929754,10929755,10929756,10929754,10929756,10929763,10929763,10929763,10929764,10929764,10929765,10929764,10929765,10929765,10929765,10929766,10929766,11156722,13032314,10929766,10929767,10929767,10929767,10929768,10929768,10929769,11050594,13823187,30184136,10929768,10929769,10929770,10929772,11083983,12665251,12665257,12803305,13032315,13823148,13823173,10929769,10929770,10929771,10929771,10929772,10929773,11156724,12803304,12803305,13032316,13032317,13823204,10929770,10929771,10929771,10929772,10929772,10929773,10929773,10929774,10929774,11035608,11050595,11050595,11050596,11105220,11110639,11149841,11202958,11230839,11230840,11581615,11751562,11765860,11816183,11841502,12255826,12309191,12309191,12309192,12309192,12309193,12556148,12607400,12650975,12665252,12665253,12680966,12761017,12803303,12803304,12803304,12803305,12803305,12803306,12803306,12803307,12803307,12883768,13032252,13032314,13032315,13032315,13032316,13032317,13106435,13267640,13823149,13823174,13823175,13823190,10929771,10929772,10929772,10929773,10929773,10929774,10929774,11050596,11050597,11050598,11105217,12192809,12221537,12309191,12665253,12665259,12680967,12803305,12803305,12803306,12803306,12803307,13032317,13823149,13823205,10929772,10929773,10929773,10929774,10929774,10929775,10929775,11039313,11050595,11050596,11050596,11050597,11050597,11050598,11050599,11086433,11149844,11154265,11193877,11230840,11357795,11557923,11765861,11841502,11843376,11903793,12101108,12223570,12309192,12309192,12309193,12309193,12330443,12463364,12665253,12665253,12665254,12680967,12680968,12803304,12803305,12803305,12803306,12803306,12803307,12803307,12803308,12839739,12839740,13032316,13032316,13032317,13032317,13032318,13823150,13823174,13823175,13823177,13823207,10929773,10929774,10929774,10929775,10929775,11050596,11050597,11149845,11156726,11230841,11557918,11765862,12316169,12330443,12665254,12680967,12680968,12803305,12803306,12803306,12803307,12803307,12803308,12803310,12839740,13032317,13823150,10929774,10929775,10929775,10929776,11050598,11050600,11110639,11152511,11156727,11184695,11374434,12309192,12309193,12309194,12665254,12665254,12665255,12680968,12681085,12803306,12803307,12803307,12803308,12803308,12803309,12803310,13032317,13032317,13032318,13823151,10929775,10929776,10929776,10929777,11050597,11149846,11156727,11196070,11230843,11557924,12556152,12665254,12665255,12665255,12680969,12680970,12803306,12803306,12803307,12803307,12803308,12803308,12803309,12803309,12803311,12839741,13032317,13032317,13032318,13823151,10929776,10929777,10929777,10964927,11039312,11039314,11050598,11050599,11050599,11086153,11104915,11105222,11149846,11156728,11581618,11841506,12309194,12309194,12330445,12665255,12665256,12665256,12680969,12680969,12803306,12803307,12803308,12803308,12803309,12803309,12803310,12803310,12839742,13032316,13032318,13032319,13823152,13823153,13823177,10929778,11050600,11050601,11230843,12309195,12665256,12680969,12680970,12803307,12803308,12803309,12839742,11050599,11050600,11105221,11105222,11156729,11581618,11581901,12330446,12665256,12665262,12680970,12803307,12803308,12803310,12803310,12803311,12839743,13032319,13032320,13032320,13823153,11156729,11841508,12309195,12803309,12803310,13032321,13032322,11000094,12716136,11141459,13929001,11148863,11148865,11148865,12790520,12912859,12912860,11171420,11171434,11171436,11171436,11171436,11171422,11171435,11171436,11171436,11171437,11171437,11171437,11171439,11171437,11171438,11171440,11171439,11171441,11171442,11171450,13153154,11171452,12451282,12924146,12430032,12430033,12786093,12801807,12924145,12924146,12924148,12960580,13943990,11270684,11270685,11277566,12213811,12430034,12441354,12786094,12786096,12801805,12801808,12924145,12924146,12924146,12924147,13153157,13153158,11277567,12924146,12924148,12924148,12924149,11238210,12957531,11242542,12959698,11243169,11243334,11243496,12837981,11280108,12856162,11280679,11280680,11280680,11280681,11280682,11332187,11325305,12371252,12856429,12978766,12978768,11291517,11291518,11291664,11411720,11291809,12984330,11369926,11369916,11369928,11369928,11369918,11369928,11369929,11369930,12901051,13023391,11369942,12885338,13023389,13023390,11948161,11375260,12531942,11378767,12889756,13027808,11383692,11383692,11383693,11383694,11992827,12068469,12557409,12892219,12907933,13030271,12536158,13030272,13030273,13030272,13030273,12907935,11439634,13058246,11457984,11457994,11458004,13067422,11462385,12931570,11476157,14096403,11531922,11531923,11531922,11531923,11531923,12966335,12610273,12966335,13104387,13104388,13104390,13333399,12966336,13104389,11785834,13231344,11819109,13125642,12186087,12186092,12186093,13309136,13431475,13431476,12233473,12233476,12233476,13317113,13332827,14475051,13332827,12234055,13455460,12526390,13128758,12573366,13625109,12601965,12601966,13145296,13639410,13639411,12702655,13689777,12753248,12753245,12753247,12753248,12753248,13715049,13576997,13715049,13715049,13715051,12756989,12757051,12757115,13588407,12877860,13304508,13256185,13828467,13272462,13974661,13455861,14066357,13461863,13931325,13513334,13513393,13529613,13517383,14097118,13545825,14111343,13581893,14129372,13688626,13688627,13688612,13688613,13688613,13688624,13688627,13688627,13688628,13688628,13688628,13688628,13688629,13688628,13688629,13688629,13688626,13688629,13688630,13688631,13688641,14182740,14060402,14182739,14182741,14182741,14182742,13688644,13709878,13718276,14182741,14219174,13709879,13987973,14044689,14182743,14411753,13709879,13966530,14044690,14060404,14182741,14182742,14182742,14182743,14182744,14182744,14411754,13702578,14189716,13711271,13721200,13731122,13731123,13731124,13731125,13731125,14081647,14081648,14203986,14203987,14203987,13731134,14081648,13731137,13792953,13877210,14203988,14203989,14507118,14203990,13841250,13747920,14441397,13854808,13854883,13854954,14265912,13951373,14066956,13996969,14336911,14023295,14350074,14182539,14182539,14182541,14429695,14429698,14658709,14244426,14689650,14285042,14358608,14287314,14518518,14372193,14372195,14386470,14386472,14400734,14400750,14400750,14400736,14400748,14400749,14400749,14400750,14400750,14400751,14400752,14400752,14400750,14400751,14400752,14400753,14400750,14400752,14400753,14400753,14400759,14400760,14538801,14400764,14400766,14538801,14538802,14538802,14400764,14538801,15225639,14400767,14400767,14416464,14538801,14538802,14538802,14538803,14538803,14538804,15558703,14400766,14400767,14538801,14538802,14538802,14538803,14538803,14538804,15558647,14416465,14538803,14538804,14538804,14538805,14416465,14538804,14538805,14400770,14538803,14538805,14538805,14538806,14416466,14538804,14538807,14538807,14416463,14538804,14538806,14767815,14400878,14400992,14767931,14419699,14584709,14432159,14432167,14432171,14432171,14432172,14432172,14432163,14432164,14432168,14432172,14432173,14432173,14432174,14432173,14432174,14432173,14432174,14432176,14432179,14432286,14432289,14432183,14432183,14432287,14432288,14432288,14432289,14432289,14432290,14432290,14432292,14432293,14432290,14432291,14432291,14432293,14432184,14432187,14432289,14432289,14432290,14432290,14432291,14432291,14432290,14432291,14432291,14432292,14432292,14432292,14432291,14432403,14432405,14432395,14432396,14432404,14432404,14432405,14432405,14432406,14432398,14432406,14432407,14432396,14432398,14432406,14432407,14432407,14432408,14432398,14432406,14432406,14432407,14432407,14432408,14432408,14432409,14432400,14432406,14432408,14432408,14432409,14432400,14432408,14432408,14432409,14432403,14432409,14432410,14432412,14432412,14432410,14432413,14432414,14554625,14554628,14783638,14432416,14432418,14554627,14554627,14554627,14554628,14432418,14432419,14432420,14554628,14554629,14432420,14496671,14554625,14554628,14554629,14554629,14554630,14554630,14554631,14783639,14783640,14554628,14554629,14554629,14554630,14554630,14554631,14554631,14554630,14554631,14783641,14554629,14554630,14554632,14554630,14554630,14554631,14554632,14554633,14554633,14560940,14618897,14592278,14634565,14676835,14676837,14676837,14676838,14676838,14676839,14676839,14676840,14676852,14676854,14676838,14676839,14676839,14676840,14676840,14676841,14676854,14676856,14676839,14676840,14676840,14676841,14676841,14676843,14676853,14676854,14676855,14676856,14676856,14676840,14676841,14676841,14676842,14676842,14676844,14676853,14676854,14676855,14676856,14676856,14676857,14676857,14676841,14676842,14676842,14676843,14676843,14676844,14676855,14676856,14676856,14676857,14676857,14676858,14676858,14676859,14676859,14676842,14676843,14676843,14676844,14676844,14676854,14676855,14676855,14676856,14676857,14676857,14676858,14676858,14676859,14676843,14676844,14676844,14676845,14676845,14676846,14676854,14676856,14676856,14676857,14676857,14676858,14676858,14676859,14676859,14676862,14676844,14676845,14676845,14676855,14676855,14676856,14676856,14676857,14676857,14676858,14676858,14676859,14676859,14676860,14676861,14676845,14676856,14676857,14676857,14676858,14676859,14676859,14676860,14676846,14676858,14676859,14676859,14676860,14676858,14676859,14676860,14676860,14676859,14676860,14676861,14676861,14676867,14676869,14676867,14676869,14676870,14905863,14905865,14676868,14676869,14676870,14676870,14676871,14676870,14676870,14676871,14676871,14676872,15696724,14676871,14676871,14676871,14676872,14676872,14905865,14905866,14905867,14676872,14676873,14676873,14713288,14713290,14713291,14905865,14905866,14905866,14905867,14905867,14905868,14905869,14914449,15129746,15320725,15696700,15696725,15806956,14676873,14676874,14676874,14713289,14713290,14713290,14905865,14905865,14905866,14905867,14905868,14905868,14905869,15141192,15696700,15696727,14676874,14676875,14676875,14676876,14713289,14713290,14713290,14713291,14713291,14713292,14757320,14780496,14867977,14905865,14905866,14905866,14905867,14905867,14905868,14905868,14905869,14905869,14905870,14979987,14979988,15363691,15363695,15363697,15696701,15696721,15696725,15696726,14676876,14676878,14713291,14713291,14713292,14905867,14905867,14905868,14905868,14905869,14905869,14905870,14979988,15320727,15696701,15696702,15696702,14905867,14905869,14905869,15363691,14713292,14905869,14905869,14905870,14905870,15696704,14713294,15696705,14749720,14749721,14749721,14749707,14749722,14749722,14749708,14749720,14749721,14749721,14749722,14749723,14749721,14749722,14749723,14749722,14749723,14749723,14749724,14942298,14942296,14942297,14942298,14942298,14942299,15733157,14942298,14942299,14942299,15733157,14749737,14942298,14942298,14942299,14942300,14942297,14942298,14942298,14942299,14942299,14942300,14942300,14942301,14942301,15016419,15016420,15177624,15733133,15733158,15733159,15733161,14837778,14837779,14837780,14986324,15777160,14986329,14884147,15009518,15059090,15096980,15134743,15134809,15134859,15134858,15134859,15134859,15134860,15134874,15134875,15134859,15134859,15134860,15134860,15134861,15134874,15134878,15134859,15134860,15134860,15134861,15134861,15134874,15134878,15134879,15134860,15134861,15134861,15134862,15134862,15134863,15134876,15134876,15134877,15134861,15134862,15134862,15134863,15134876,15134876,15134877,15134878,15134879,15134862,15134863,15134863,15134864,15134873,15134874,15134876,15134877,15134877,15134878,15134879,15134880,15134863,15134864,15134864,15134875,15134876,15134876,15134877,15134877,15134878,15134878,15134879,15134879,15134880,15134880,15134864,15134865,15134865,15134875,15134876,15134876,15134877,15134877,15134878,15134878,15134879,15134879,15134880,15134880,15134881,15134865,15134867,15134876,15134877,15134877,15134878,15134878,15134879,15134879,15134880,15134880,15134881,15134881,15134869,15134878,15134878,15134879,15134880,15134880,15134881,15134881,15134882,15134883,15134877,15134883,15134883,15925707,15134890,15925707,15925733,15134889,15134890,15134890,15134891,15134892,15134893,15134889,15134890,15134891,15134892,15134893,15134893,15925734,15134890,15134891,15134891,15134892,15134892,15134893,15134893,15134894,15925709,15134891,15134892,15134892,15134893,15134893,15134894,15134894,15208996,15370200,15592704,15925710,15134892,15134893,15134893,15134894,15134894,15134895,15592694,15925710,15925710,15925735,15925736,15134893,15134894,15134894,15134895,15134895,15208998,15549736,15549736,15925710,15925736,15925737,15134894,15134895,15134895,15134896,15549736,15549737,15592705,15592707,15789958,15901569,15925711,15925711,15925712,15925718,15925736,15925736,15925737,15134895,15134896,15134896,15208998,15208999,15292332,15370203,15549737,15592697,15592704,15592706,15925711,15925712,15925714,15925735,15925736,15925736,15925737,15925767,15134896,15134897,15134897,15134898,15136273,15208998,15208999,15292332,15292332,15370203,15370203,15546497,15549737,15592701,15592703,15592706,15592707,15592707,15592708,15823165,15925711,15925712,15925712,15925713,15925716,15925736,15925737,15925737,15925738,15925769,15925770,15925867,15134897,15134898,15208999,15208999,15209000,15287498,15370205,15370205,15549738,15549738,15549739,15592698,15592700,15592701,15592701,15592702,15592707,15592707,15592708,15823165,15925712,15925713,15925713,15925714,15925720,15925736,15925736,15925737,15925738,15925738,15925739,15925752,16138267,15134898,15134899,15134899,15134900,15143461,15143463,15208999,15209000,15209000,15209001,15253644,15292333,15370203,15370204,15370204,15370206,15370206,15388050,15549738,15549739,15592702,15592702,15592703,15592704,15592705,15592706,15592706,15592707,15592708,15592708,15592709,15688815,15853361,15901571,15918570,15925712,15925713,15925713,15925714,15925714,15925721,15925733,15925736,15925737,15925737,15925738,15925738,15925739,15925767,15925768,15925770,15925772,16641845,15134899,15592703,15925713,15925739,15925740,15209001,15592706,15592709,15925714,15925740,15925714,15925741,15925715,15137663,15371594,15152042,15152043,15152044,15212352,15934294,15601289,15272717,15272790,15272824,15272931,15661756,15283101,15283113,15283114,15283116,15283116,15283116,15283117,15283103,15283114,15283115,15283115,15283116,15283117,15283117,15283118,15283118,15283119,15283119,15283119,15999827,15999852,15283130,15620613,15999828,15283131,15366449,15623854,15283131,15444321,15666825,15975688,15999829,15999830,15999830,15999850,15999854,15999855,15444322,15462167,15623855,15666819,15666822,15666823,15666826,15758127,15864075,15999830,15999855,15666823,15999830,15999831,15999832,15999857,15444323,15666820,15666827,15864078,15999831,15999858,15372407,15488967,15440111,16078388,16810291,15449779,15449780,15449781,15703944,15750154,16083159,16083183,15750156,15582630,16149584,15605525,15605523,15605525,15605526,15605525,15605526,15605524,15605526,15605526,15605527,15605529,15605529,15605530,15828026,16153891,16161032,16161059,16161033,15828030,16161058,16161059,15828025,15828027,15828028,16161034,16161042,16161059,16161060,16055451,15612745,15828024,15619954,15835235,15641217,15641217,15845875,16043126,15958110,15958110,15958113,15961350,16337381,16337325,16337352,15964579,15964591,15964592,15964592,15964593,15964594,15964594,15964595,15964592,15964592,15964593,15964593,16007554,16340573,15964608,16007554,16007562,16007564,16340566,16340567,16340587,16340590,16340592,16340592,16007562,16340593,16007564,16340568,16340592,16340593,16340594,16007562,16007564,16340569,16340595,16050501,16050518,16050509,16050520,16050522,16050520,16050524,16050509,16050512,16050521,16050524,16050526,16050521,16050525,16050525,16050527,16050528,16050514,16050513,16050530,16050515,16050527,16050530,16050530,16050531,16050515,16050516,16050525,16050529,16050531,16050515,16050532,16050516,16050517,16050517,16050532,16050517,16050533,16050518,16050527,16050530,16050531,16050533,16050533,16050521,16050530,16050534,16050534,16050535,16050533,16050538,16050542,16141829,16383532,16383532,16383533,16383539,16383557,16383558,16383534,16050544,16050545,16383543,16050545,16383535,16383560,16383536,16383562,16050547,16383537,16050547,16383537,16383538,16383563,16383563,16050550,16141836,16359397,16383538,16383538,16383539,16383539,16383541,16383546,16383546,16383561,16383563,16383563,16383564,16383564,16383565,16383539,16383539,16383539,16233137,16233138,16233138,16474840,16474840,16474841,16242744,16479642,16445034,16445035,16445036,16580789,16580814,16580814,16505369,16610954,16511444,16613991,16571850,16571880,16571963,16644285,16668257,16668257,16668381,16692398,16692399,16692424,16692400,16692424,16692424,16668504,16692547,16702254,16702261,16709417,16709402,16716527,16716527,16716528,16716531,16716533,16716536,16716542,16716543,16716528,16716529,16716529,16716530,16716530,16716531,16716531,16716532,16716535,16716536,16716536,16716537,16716538,16716538,16716539,16716539,16716540,16716540,16716541,16716541,16716542,16716542,16716543,16716543,16716544,16716529,16716530,16716536,16716537,16716538,16716538,16716539,16716539,16716540,16716541,16716541,16716542,16716542,16716543,16716543,16716544,16716544,16716545,16716530,16716531,16716531,16716538,16716539,16716539,16716540,16716541,16716541,16716542,16716542,16716543,16716543,16716544,16716544,16716545,16716531,16716532,16716533,16716534,16716537,16716537,16716539,16716539,16716540,16716541,16716542,16716543,16716543,16716544,16716544,16716533,16716539,16716542,16716545,16716533,16716540,16716542,16716544,16716536,16716542,16716543,16716544,16716545,16716546,16716544,16716545,16716546,16716550,16716545,16716545,16716545,16716547,16716546,16716546,16716547,16716547,16716549,16716549,16716550,16716550,16716551,16716552,16716553,16716553,16716546,16716547,16716549,16716550,16716550,16716553,16716554,16716554,16716546,16716547,16716548,16716551,16716547,16716548,16716548,16716550,16716550,16716551,16716551,16716552,16716553,16716563,16716548,16716549,16716550,16716551,16716552,16716553,16716562,16716562,16716563,16716563,16716564,16716549,16716550,16716551,16716551,16716553,16716553,16716556,16716564,16716550,16716551,16716551,16716552,16716553,16716553,16716556,16716557,16716559,16716564,16716551,16716552,16716552,16716553,16716553,16716554,16716557,16716563,16716565,16716552,16716553,16716554,16716554,16716555,16716564,16716565,16716566,16716553,16716554,16716554,16716555,16716555,16716556,16716556,16716564,16716566,16716567,16716554,16716555,16716555,16716556,16716556,16716565,16716566,16716566,16716555,16716556,16716556,16716557,16716558,16716559,16716566,16716566,16716567,16716568,16716556,16716557,16716557,16716558,16716558,16716559,16716561,16716562,16716566,16716567,16716567,16716568,16716557,16716558,16716558,16716561,16716563,16716566,16716566,16716567,16716567,16716568,16716568,16716569,16716558,16716559,16716560,16716560,16716562,16716563,16716566,16716567,16716567,16716568,16716568,16716569,17432676,16716559,16716561,16716561,16716562,16716563,16716564,16716566,16716567,16716567,16716568,16716568,16716569,16716569,16716570,16716570,16716583,16716600,16716627,17448508,16716564,16716567,16716568,16716569,16716569,16716570,16716570,16929099,16716568,16716571,16716569,16716570,16716571,16716566,16716568,16716570,16716570,16716571,16716572,16716569,16716569,16716570,16716570,16716571,16716571,16716571,16716572,16716571,16716568,16716572,16716573,16716574,16716571,16716572,16716573,16716573,16716574,16716575,16716575,16716576,16716573,16716575,16716575,16716576,16716576,16716576,16716576,16716577,16716578,16716576,16716577,16716577,16716578,16716578,16716577,16716578,16716578,16716579,16716588,16716578,16716579,16716589,16716579,16716580,16716580,16716581,16716581,16716582,16716582,16716583,16716588,16716589,16716590,16716580,16716581,16716582,16716583,16716590,16716581,16716582,16716582,16716583,16716583,16716584,16716584,16716588,16716588,16716589,16716589,16716590,16716590,16716591,16716592,16716592,16716582,16716583,16716583,16716584,16716584,16716588,16716589,16716589,16716590,16716591,16716592,16716583,16716584,16716584,16716585,16716588,16716590,16716590,16716591,16716592,16716593,16716593,16716584,16716585,16716585,16716589,16716590,16716590,16716592,16716592,16716593,16716593,16716585,16716586,16716586,16716589,16716590,16716591,16716592,16716592,16716593,16716594,16716594,16716586,16716589,16716590,16716592,16716592,16716593,16716593,16716594,16716594,16716587,16716588,16716590,16716591,16716591,16716592,16716592,16716593,16716593,16716594,16716594,16716595,16716595,16716593,16716594,16716594,16716596,16716595,16716597,16716594,16716595,16716597,16716598,16716596,16716597,16716598,16716598,16716597,16716598,16716598,16716599,16716600,16716598,16716599,16716599,16716600,16716599,16716600,16716601,16716601,16716600,16716601,16716602,16716604,16716601,16716602,16716602,16716603,16716603,16716604,16716604,16716605,16716606,16716606,16716609,16716617,16716620,16716621,16716602,16716603,16716603,16716604,16716606,16716607,16716603,16716604,16716604,16716605,16716605,16716606,16716606,16716608,16716609,16716618,16716621,16716622,16716625,16716604,16716605,16716605,16716606,16716606,16716607,16716607,16716608,16716609,16716612,16716619,16716621,16716622,16716623,16716605,16716606,16716606,16716607,16716607,16716608,16716608,16716619,16716621,16716622,16716606,16716607,16716607,16716608,16716608,16716609,16716610,16716611,16716614,16716622,16716607,16716608,16716609,16716623,16716608,16716609,16716609,16716610,16716610,16716611,16716611,16716612,16716612,16716614,16716614,16716619,16716619,16716620,16716620,16716621,16716621,16716626,16716609,16716610,16716610,16716611,16716611,16716612,16716612,16716613,16716616,16716619,16716620,16716621,16716625,16716610,16716611,16716611,16716612,16716612,16716613,16716614,16716615,16716620,16716620,16716621,16716621,16716611,16716612,16716612,16716613,16716613,16716614,16716614,16716615,16716615,16716616,16716618,16716619,16716620,16716621,16716621,16716622,16716624,16716612,16716613,16716613,16716614,16716614,16716616,16716616,16716617,16716618,16716619,16716620,16716621,16716621,16716622,16716622,16716613,16716614,16716614,16716615,16716617,16716621,16716621,16716622,16716623,16716623,16716614,16716615,16716615,16716616,16716620,16716621,16716622,16716622,16716623,16716623,16716624,16716615,16716616,16716619,16716621,16716622,16716623,16716623,16716624,16716625,16716616,16716617,16716618,16716619,16716619,16716623,16716623,16716624,16716624,16716617,16716618,16716618,16716619,16716619,16716620,16716620,16716621,16716621,16716622,16716622,16716623,16716623,16716624,16716624,16716625,16716625,16716626,16716627,16716628,16716619,16716620,16716624,16716622,16716624,16716625,16716620,16716621,16716623,16716623,16716624,16716625,16716626,16716626,16716629,16716621,16716623,16716624,16716625,16716625,16716626,16716626,16716622,16716623,16716625,16716626,16716630,16716624,16716625,16716626,16716628,16716627,16716628,16716626,16716627,16716626,16716628,16716627,16716628,16716633,16716628,16716629,16716629,16716630,16716630,16716631,16716631,16716632,16716632,16716633,16716634,16716635,16716635,16716631,16716632,16716632,16716633,16716635,16716632,16716633,16716633,16716634,16716634,16716635,16716635,16716636,16716636,16716633,16716634,16716634,16716635,16716635,16716636,16716636,16716637,16716638,16716634,16716635,16716635,16716636,16716636,16716637,16716637,16716635,16716636,16716636,16716637,16716637,16716638,16716636,16716637,16716637,16716638,16716638,16716637,16716638,16716638,16716639,16716638,16716639,16716639,16716639,16716640,16716640,16716641,16716650,16716640,16716641,16716641,16716642,16716642,16716643,16716643,16716644,16716644,16716645,16716645,16716646,16716650,16716652,16716653,16716654,16716654,16716642,16716643,16716643,16716643,16716644,16716644,16716645,16716645,16716646,16716646,16716647,16716648,16716648,16716651,16716653,16716655,16716655,16716658,16716644,16716645,16716645,16716646,16716646,16716647,16716647,16716649,16716650,16716651,16716652,16716654,16716655,16716658,16716658,16716645,16716646,16716646,16716647,16716647,16716648,16716649,16716651,16716652,16716653,16716654,16716657,16716646,16716647,16716647,16716648,16716648,16716649,16716650,16716652,16716653,16716654,16716647,16716648,16716648,16716649,16716649,16716650,16716651,16716651,16716652,16716652,16716653,16716654,16716655,16716656,16716648,16716649,16716649,16716650,16716650,16716651,16716651,16716652,16716652,16716653,16716653,16716654,16716654,16716655,16716655,16716656,16716657,16716660,16716649,16716650,16716650,16716651,16716651,16716652,16716652,16716653,16716653,16716654,16716654,16716655,16716655,16716656,16716656,16716657,16716657,16716650,16716651,16716651,16716652,16716652,16716653,16716653,16716654,16716654,16716655,16716655,16716656,16716656,16716651,16716652,16716652,16716653,16716653,16716654,16716654,16716655,16716655,16716656,16716657,16716659,16716652,16716653,16716653,16716654,16716654,16716655,16716655,16716656,16716656,16716657,16716657,16716653,16716654,16716654,16716655,16716655,16716656,16716656,16716657,16716657,16716658,16716658,16716659,16716663,16716654,16716655,16716655,16716656,16716656,16716657,16716657,16716658,16716658,16716659,16716660,16716655,16716656,16716656,16716657,16716657,16716658,16716658,16716659,16716656,16716657,16716657,16716658,16716658,16716659,16716659,16716661,16716657,16716658,16716658,16716659,16716660,16716662,16716658,16716659,16716659,16716660,16716660,16716661,16716659,16716660,16716660,16716661,16716661,16716662,16716662,16716663,16716660,16716661,16716661,16716662,16716661,16716662,16716662,16716663,16716663,16716664,16716662,16716663,16716663,16716664,16716753,16716663,16716664,16716664,16716665,16716754,16716762,16716664,16716665,16716665,16716668,16716754,16716665,16716666,16716666,16716667,16716667,16716669,16716679,16716755,16716756,16716762,16716668,16716669,16716669,16716670,16716670,16716671,16716680,16716681,16716708,16716740,16716754,16716754,16716756,16716756,16716669,16716670,16716670,16716671,16716671,16716681,16716682,16716739,16716739,16716754,16716755,16716756,16716670,16716671,16716671,16716672,16716673,16716674,16716680,16716682,16716723,16716724,16716728,16716729,16716738,16716739,16716739,16716740,16716742,16716755,16716755,16716756,16716756,16716757,16716761,16716671,16716672,16716672,16716673,16716673,16716674,16716674,16716675,16716676,16716681,16716682,16716683,16716684,16716685,16716723,16716724,16716724,16716733,16716739,16716740,16716741,16716741,16716745,16716751,16716755,16716756,16716756,16716757,16716672,16716673,16716673,16716674,16716674,16716675,16716676,16716677,16716681,16716682,16716682,16716683,16716683,16716684,16716684,16716685,16716686,16716687,16716700,16716706,16716707,16716708,16716709,16716710,16716710,16716723,16716724,16716724,16716725,16716725,16716728,16716728,16716729,16716730,16716739,16716739,16716740,16716740,16716741,16716741,16716742,16716742,16716743,16716744,16716745,16716745,16716755,16716755,16716756,16716756,16716757,16716757,16716758,16716758,16716673,16716674,16716674,16716675,16716675,16716676,16716676,16716679,16716679,16716682,16716683,16716683,16716684,16716684,16716685,16716685,16716688,16716699,16716701,16716705,16716705,16716706,16716706,16716709,16716710,16716711,16716723,16716724,16716725,16716725,16716726,16716728,16716728,16716729,16716730,16716730,16716736,16716739,16716740,16716741,16716741,16716742,16716742,16716744,16716744,16716745,16716752,16716754,16716755,16716755,16716756,16716757,16716757,16716758,16716758,16716759,17135154,17285416,16716674,16716675,16716675,16716676,16716676,16716677,16716677,16716678,16716679,16716680,16716684,16716686,16716687,16716688,16716688,16716707,16716708,16716711,16716711,16716724,16716724,16716725,16716725,16716726,16716727,16716728,16716730,16716731,16716736,16716741,16716741,16716742,16716742,16716743,16716745,16716751,16716756,16716757,16716757,16716758,16716758,16716759,16929155,16716675,16716676,16716678,16716680,16716683,16716684,16716684,16716685,16716686,16716707,16716712,16716725,16716725,16716726,16716727,16716730,16716731,16716742,16716742,16716753,16716757,16716758,16716758,16716759,16716759,16716676,16716677,16716677,16716681,16716684,16716686,16716688,16716689,16716709,16716728,16716730,16716742,16716742,16716747,16716748,16716759,16716759,16716677,16716679,16716679,16716681,16716687,16716713,16716741,16716743,16716743,16716744,16716745,16716747,16716759,16716679,16716681,16716685,16716708,16716711,16716727,16716728,16716729,16716739,16716742,16716743,16716744,16716759,16716760,16716679,16716686,16716728,16716733,16716744,16716744,16716745,16716748,16716760,16716713,16716729,16716744,16716745,16716759,16716715,16716734,16716745,16716745,16716761,16716692,16716746,16716761,16716763,16716716,16716710,16716747,16716717,16716731,16716734,16716747,16716748,16716703,16716692,16716696,16716703,16716704,16716694,16716704,16716695,16716705,16716696,16716705,16716695,16716698,16716705,16716706,16716696,16716706,16716697,16716699,16716706,16716700,16716707,16716708,16716711,16716709,16716710,16716711,16716712,16716711,16716712,16716712,16716710,16716713,16716716,16716745,16716764,16716767,16716778,16929175,16716717,16716720,16716733,16716745,16716747,16716750,16716762,16716763,16716763,16716764,16716770,16716771,16716778,16716778,16716779,16716779,16716780,16716780,16871673,17285438,16716761,16716780,16716765,16716735,16716782,16716749,16716751,16716762,16716765,16716766,16716766,16716779,16716782,16716783,16716737,16716738,16716769,16716751,16716752,16716753,16716753,16716754,16716754,16716754,16716755,16716756,16716757,16716757,16716758,16716763,16716765,16716766,16716778,16716758,16716772,16716773,16716775,16716778,16716787,16716788,16716788,16716789,16716789,16716790,16716790,16716793,16716794,16716803,16716804,16716804,16716805,16716789,16716781,16716785,16716785,16716781,16716784,16716785,16716786,16716776,16716777,16716779,16716786,16716786,16716787,16716782,16716782,16716786,16716787,16716792,16716787,16716787,16716788,16716783,16716788,16716793,16716793,16716793,16716793,16716794,16716790,16716792,16716793,16716795,16716796,16716795,16716795,16716796,16716796,16716791,16716792,16716796,16716797,16716792,16716797,16716802,16716796,16716801,16716802,16716802,16716803,16716803,16716811,16716820,16716797,16716802,16716802,16716803,16716803,16716804,16716804,16716807,16716808,16716818,16716819,16716820,16716820,16716801,16716802,16716803,16716804,16716804,16716806,16716819,16716820,16716804,16716802,16716804,16716806,16716816,16716805,16716806,16716807,16716808,16716808,16716806,16716807,16716813,16716823,16716807,16716808,16716808,16716809,16716810,16716812,16716815,16716819,16716819,16716821,16716821,16716822,16716822,16716823,16716824,16716824,16716825,16716808,16716809,16716809,16716810,16716811,16716819,16716809,16716810,16716810,16716811,16716812,16716812,16716813,16716813,16716814,16716816,16716819,16716819,16716820,16716822,16716823,16716823,16716810,16716811,16716811,16716812,16716812,16716813,16716814,16716816,16716819,16716820,16716820,16716823,16716824,16716825,16716811,16716812,16716812,16716813,16716815,16716816,16716818,16716820,16716820,16716821,16716824,16716825,16716812,16716813,16716814,16716814,16716815,16716815,16716817,16716820,16716821,16716821,16716824,16716824,16716813,16716822,16716825,16716816,16716817,16716820,16716822,16716822,16716826,16716828,16716816,16716823,16716826,16716827,16716817,16716823,16716823,16716828,16716817,16716821,16716824,16716827,16716829,16716818,16716819,16716824,16716827,16716828,16716828,16716829,16716829,16716824,16716825,16716829,16716830,16716830,16716830,16716825,16716826,16716829,16716826,16716827,16716832,16716831,16716828,16716832,16716829,16716833,16716833,16716829,16716830,16716834,16716835,16716830,16716833,16716833,16716835,16716835,16716836,16716831,16716832,16716832,16716833,16716833,16716834,16716834,16716835,16716835,16716836,16716836,16716837,16716837,16716834,16716834,16716835,16716836,16716833,16716835,16716835,16716836,16716836,16716835,16716836,16716837,16716835,16716836,16716837,16716837,16716838,16716836,16716837,16716837,16716838,16716838,16716837,16716838,16716838,16716839,16716839,16716840,16716840,16716838,16716839,16716839,16716840,16716840,16716841,16716839,16716840,16716840,16716841,16716841,16716851,16716840,16716841,16716841,16716842,16716849,16716841,16716842,16716842,16716842,16716843,16716843,16716852,16716852,16716857,16716843,16716844,16716844,16716845,16716848,16716855,16716845,16716846,16716847,16716847,16716848,16716849,16716849,16716854,16716855,16716856,16716861,16716861,16716862,16716864,16716846,16716847,16716847,16716848,16716848,16716849,16716849,16716850,16716850,16716851,16716851,16716852,16716852,16716853,16716853,16716857,16716847,16716848,16716848,16716849,16716849,16716850,16716850,16716851,16716853,16716848,16716849,16716849,16716850,16716850,16716851,16716852,16716849,16716850,16716850,16716851,16716851,16716852,16716852,16716853,16716850,16716851,16716851,16716852,16716852,16716853,16716853,16716851,16716852,16716852,16716853,16716853,16716852,16716853,16716853,16716854,16716854,16716855,16716856,16716853,16716854,16716854,16716855,16716855,16716856,16716857,16716854,16716855,16716855,16716856,16716857,16716858,16716855,16716856,16716856,16716857,16716857,16716856,16716857,16716857,16716858,16716857,16716858,16716858,16716859,16716858,16716859,16716860,16716862,16716859,16716860,16716861,16716862,16716862,16716860,16716861,16716862,16716862,16716861,16716862,16716862,16716863,16716863,16716864,16716876,16716862,16716863,16716863,16716876,17448696,16716863,16716864,16716864,16716865,16716865,22604772,16716864,16716865,16716865,16716868,16716869,16716870,16716877,16759494,16716865,16716866,16716866,16716867,16716867,16716866,16716867,16716867,16716868,16716868,16716869,16716878,22604773,16716867,16716868,16716868,16716869,16716869,16716870,16716871,16716880,16716868,16716869,16716869,16716870,16716870,16716871,16716872,16716869,16716870,16716870,16716871,16716871,16716870,16716871,16716871,16716872,16716872,16716873,16716871,16716872,16716872,16716873,16716873,16716881,16716872,16716873,16716873,16716874,16716875,16716881,16716873,16716874,16716874,16716875,16716882,16929253,16716874,16716875,16716875,16716882,16716875,16716876,16716876,16716877,16716877,16716883,16716876,16716877,16716877,16716878,16716878,16716879,16716879,16716881,16716883,16716883,22604778,16716877,16716878,16716878,16716879,16716880,16716881,16716884,17285482,16716878,16716879,16716879,16716880,16716880,16716881,16716882,16716882,16716883,16716883,16716884,17285482,16716879,16716880,16716880,16716881,16716881,16716882,16716882,16716883,16716884,16716884,16716885,16716880,16716881,16716881,16716882,16716882,16716883,16716883,16716884,16716885,16716881,16716882,16716882,16716883,16716883,16716884,16716884,16716886,16716882,16716883,16716883,16716884,16716884,16716885,16716885,16716886,16716886,16716883,16716884,16716884,16716885,16716885,16716886,16716886,16716887,22604782,16716884,16716885,16716885,16716886,16716886,16716887,16716887,16716885,16716886,16716886,16716887,16716887,16716888,16716886,16716887,16716887,16716888,16716888,16716887,16716888,16716888,16716889,18491914,16716888,16716889,16716889,16716889,16716890,16716890,16716891,16716892,16716892,16716893,16716894,16716895,16716896,16759507,16769950,16826965,16826965,16827126,16827126,16827127,16839574,16849385,16849386,16876568,16929258,16929261,16929262,17135260,17135262,17135263,17135264,17135264,17279437,17279437,17285489,17285541,17448674,17448675,17448676,17448677,17448710,17604628,22604786,22607137,22607239,22608246,16716892,16716893,16716893,16716895,16827127,17092372,17135262,17135263,17135265,17279437,17285489,17285544,17448710,16716893,16716894,16716894,16716895,16835730,16849386,16929263,17135262,17135263,17135264,17135265,17279438,17279438,17279440,17285490,17285526,17432841,17448675,19066306,16716894,16716895,16716895,16716896,16716922,16759509,16769940,16769953,16769953,16793061,16826966,16826967,16826967,16826968,16826968,16827127,16827128,16827128,16827129,16849387,16849387,16849388,16873388,16876570,16929263,16929264,16929265,16929266,17065804,17135262,17135263,17135264,17135264,17135265,17135265,17135266,17169388,17169389,17279438,17279439,17279439,17285490,17285490,17285526,17432843,17432844,17448675,17448677,17448680,17448710,17448710,17448711,17448749,22604787,16716895,16716896,16826967,16826967,16827129,16929264,16929266,17135264,17135264,17135265,17279440,17285491,17432843,16716896,16716897,16759510,16769951,16769954,16826967,16929265,16929266,17135264,17135264,17285491,17448673,16716897,16716898,16716898,16717030,16717042,16769942,16769943,16769952,16769954,16769955,16826968,16826968,16826969,16827129,16827129,16827130,16849388,16849389,16862618,16873391,16873393,16907063,16929263,16929265,16929266,16929267,17135265,17135265,17135266,17135266,17135267,17135268,17279440,17279440,17279441,17285492,17285543,17448678,17448681,16769952,16769953,16769953,16929265,17135265,17285492,16826969,17432846,16929267,17135268,16716959,16929299,16717177,16717199,16920661,16827287,16802134,16802146,16802146,17177890,16869765,17177900,17177900,17328128,16823000,16823011,16823012,16823002,16823013,16823009,16823010,16823022,16823023,16823023,16823024,16823024,16823025,16823025,16823027,16823025,16823028,16823026,16880187,16880030,17188336,16823038,16880200,17188335,17338562,17188335,17332510,16880039,16880201,17188336,17188337,17338563,17338613,16982337,17338564,17338565,16869247,17005450,16937039,16937040,16937049,16937051,16937051,16937052,16937052,16937053,16937053,16937054,16937054,16937055,16937055,16937057,16937040,16937049,16937049,16937051,16937055,16937055,16937056,16937041,16937052,16937054,16937055,16937056,16937056,16937059,16937055,16937056,16937057,16937055,16937056,16937058,16937061,16937063,16937212,16937213,16937064,16937213,16937215,16937066,17039349,17245347,17395575,17542929,16937214,17039349,17175887,17245349,17395576,16937214,17039350,16937214,17245350,17395577,16937069,16937215,16937216,16937217,17039351,17245350,16937215,16937216,17039351,17245353,17395578,16959475,17039352,17245351,17389526,17395578,16937071,16937072,16937216,16937216,16937217,16959475,17039352,17245350,17245352,17245353,17245354,17389527,17389527,17389528,17395579,16959476,17245352,17245353,17395579,16959476,17245354,17039355,16937362,16937373,16937373,16937374,16937362,16937363,16937364,16937374,16937374,16937364,16937374,16937374,16937375,16937375,16937375,16937367,16937376,16937377,16937377,16937385,16937386,17039509,16937386,16959633,17039510,17039511,16952042,16959633,16959634,17039510,17039511,17039512,17245510,17245510,17245511,17245511,17389685,17389686,17395737,17395773,17395777,17543091,17558924,16954583,17398290,16962276,17408190,16966710,17294302,16981891,16981892,16981892,16981893,16981893,16981892,16981893,16981893,16981894,17411943,17061768,17061769,17417995,17061769,17267769,17267771,17417996,17061770,17267769,17267770,17267772,17411945,17417996,17565351,17417997,17008354,17431228,17026640,17587721,17029897,17029899,17029902,17085773,17435947,17085775,17036260,17036261,17445181,17097242,17475671,17124143,17652306,17141644,17141645,17141646,17141647,17141633,17141648,17141635,17141635,17141646,17141647,17141648,17141649,17141649,17141649,17141650,17141650,17141650,17141650,17141650,17141661,17497874,17141663,17347650,17491823,17141663,17347646,17347648,17347648,17347649,17347652,17491823,17497875,17497976,17661059,17268556,17268641,17347647,17347648,17347648,17347649,17347649,17347650,17347651,17491823,17491824,17491824,17497875,17645230,17661062,17395457,17395545,17395631,17395633,17624865,17414725,17414727,17634413,17467864,17848046,17553633,17553647,17553649,17553632,17553647,17553648,17553632,17553633,17553648,17553648,17553650,17553633,17553634,17553634,17553635,17553635,17553636,17553648,17553649,17553649,17553650,17553650,17553651,17553634,17553635,17553636,17553651,17553636,17553636,17553637,17553637,17553649,17553651,17553651,17553652,17553652,17553650,17553652,17553654,17553637,17553650,17553652,17553653,17553654,17553651,17553652,17553653,17553653,17553653,17553654,17553654,17553654,17553654,17553665,17553666,17697823,17697824,17703875,17867043,17595418,17703876,17867063,17697824,17703876,17553667,17553669,17703877,17553668,17553669,17553669,17597520,17697825,17697825,17697826,17697826,17697827,17697827,17703877,17703877,17703930,17851226,17867062,17867063,17867064,17553669,17697826,17697826,17703878,17703914,17587776,17697827,17703878,17703928,17703879,17703879,17867064,17621896,17621896,17621898,17885352,17737998,17737999,17637182,17873929,17641423,17641499,17641568,17747849,17841997,17841983,17841984,17841984,17841997,17841998,17841998,17841999,17841984,17841998,17841998,17841999,17841999,17842000,17842001,17841998,17841999,17841999,17842000,17842001,17842002,17841999,17842000,17842001,17848049,17848049,17842013,17848050,17842014,17848050,17995405,17848051,17848091,17848052,17848053,17854086,17854087,17854088,17854088,17854094,17854095,17854096,17854097,17854098,17854099,17854099,17854112,17854113,17854117,17854118,17854118,17854119,17854121,17854122,17854122,17854123,17854141,17854162,17854118,17854122,17854123,17854123,17854119,17854123,17854124,17854119,17854124,17854129,17854130,17854130,17854132,17854108,17854133,17854199,18017283,17854109,17854110,18017283,17854134,17854199,17854135,17854148,17854149,17854148,17854153,17854151,17854153,17854154,17854193,17854154,17854152,17854156,17854154,17854155,17854156,17854156,17854157,17854157,17854157,17854158,17854158,17854175,17854198,17854159,17854160,17854160,17854161,17854161,17854162,17854162,17854163,17854164,17854164,17854166,17854166,17854167,17854168,17854168,17854169,17854171,17854172,17854173,17854173,17854174,17854174,17854175,17854175,17854176,17854177,17854177,17854178,17854178,17854179,17854179,17854180,17854180,17854181,17854181,17854182,17854184,17854187,17854194,17854194,17854196,17854196,17854197,17854197,17854198,17854160,17854161,17854161,17854162,17854162,17854163,17854174,17854175,17854176,17854198,17854199,17854162,17854163,17854174,17854174,17854199,17854163,17854169,17854200,17854163,17854164,17854165,17854169,17854169,17854175,17854177,17854181,17854200,17854164,17854165,17854165,17854166,17854168,17854170,17854175,17854176,17854184,17854186,17854188,17854198,17854201,17854165,17854166,17854166,17854169,17854176,17854182,17854199,17854201,17854166,17854167,17854167,17854169,17854170,17854171,17854176,17854177,17854179,17854179,17854180,17854182,17854185,17854188,17854189,17854194,17854202,17854167,17854168,17854168,17854170,17854176,17854177,17854177,17854178,17854179,17854181,17854182,17854198,17854198,17854200,17854202,17854202,17854171,17854172,17854178,17854180,17854169,17854171,17854175,17854186,17854200,17854203,17854178,17854192,17854201,17854173,17854180,17854184,17854186,17854188,17854201,17854201,17854205,17854175,17854177,17854178,17854188,17854206,17854184,17854185,17854179,17854182,17854182,17854194,17854207,17854207,17854208,17854185,17854183,17854190,17854201,17854210,17854192,17854200,17854188,17854190,17854212,17854187,17854189,17854190,17854191,17854193,17854197,17854199,17854200,17854200,17854212,17854190,17854190,17854192,17854192,17854195,17854196,17854197,17854198,17854199,17854200,17854208,17854210,17854213,17854190,17854190,17854194,17854195,17854195,17854197,17854198,17854213,17854214,17854191,17854193,17854194,17854196,17854197,17854198,17854209,17854212,17854214,17854193,17854193,17854195,17854196,17854196,17854197,17854198,17854198,17854199,17854200,17854208,17854210,17854212,17854215,17854203,17854215,17854195,17854195,17854196,17854197,17854198,17854198,17854214,17854216,17854198,17854199,17854211,17854212,17854214,17854215,17854217,17854197,17854199,17854200,17854216,17854217,17854200,17854200,17854201,17854203,17854218,17854201,17854205,17854214,17854218,17854205,17854219,17854201,17854202,17854204,17854215,17854217,17854219,17854204,17854205,17854210,17854220,17854206,17854215,17854216,17854217,17854218,17854219,17854220,17854208,17854209,17854221,17854206,17854218,17854221,17854207,17854208,17854216,17854219,17854222,17854223,17854223,17854224,17854224,17854215,17854225,17854225,17854226,17854220,17854226,17854227,17854223,17854228,17854229,17854230,17854231,17854227,17854229,17854232,17854232,17854233,17854231,17854233,17854231,17854233,17854234,17854234,18017345,17854233,17854235,17854234,17854234,17854235,17854235,17854235,17854236,17854236,17854236,18001514,17854237,17854237,17854238,17854239,17854240,17854242,17854243,17854243,17854246,17854247,17854248,17854251,17854256,17854257,17854258,17854259,17854262,17854262,17854264,17854267,17854268,17854269,17854271,17854272,17854272,17854273,17854273,17854274,18001513,18001515,18001517,18001518,18017347,18017348,18017349,18017350,18017370,18114851,19060590,19060590,17854239,17854240,17854248,17854251,17854263,17854270,17854271,17854271,17854272,17854273,17854273,17854274,17854274,17854263,17854274,17854245,17854275,17854278,17854257,17854273,17854279,17854281,17854282,17854283,17854261,17854284,17854275,17854285,17854286,17854266,17854273,17854292,17854293,17854283,17854292,17854294,17854297,17854295,17854295,17854296,17854296,17854297,17854298,17854298,18001538,17854299,17854299,17854300,17854302,17854303,17854301,17854304,17854305,17854305,17854304,17854304,17854305,17854305,17854306,17854305,17854307,17854307,17854306,17854307,17854307,17854308,17854307,17854308,17854308,17854309,17854309,18001550,18001552,23173495,17854310,17854311,17982484,17982485,17982486,17982487,18001543,18001543,18001544,18001544,18001546,18001547,18001547,18001548,18001548,18001549,18001549,18001550,18001550,18001551,18001551,18001552,18001552,18001553,18001553,18001554,18001555,18017366,18017381,18017382,18017383,18017383,18017384,18017384,18017385,18017385,18017386,18017386,18017393,18017402,18017406,18017406,18017408,18017415,18017417,18017418,18017419,18017420,18017421,18017454,18017454,18017455,18017456,18017457,18017457,18041188,18041264,18041266,18051206,18051214,19192158,19635015,19635033,23173305,23173495,23176264,18001552,18001553,18017383,18017385,18017419,18001551,18001552,18001553,18001554,18017385,18110673,18110675,18110674,18110677,18110677,18145573,18129738,18129740,18145573,18145575,18169451,18148784,18148779,18148787,18148801,18148786,18148787,18148789,18148789,18148805,18148785,18148787,18148789,18148805,18148806,18148787,18148789,18148806,18148790,18148791,18148806,18148807,18148789,18148791,18148791,18148792,18148793,18148807,18148807,18148790,18148791,18148792,18148792,18148793,18148808,18148790,18148791,18148791,18148792,18148792,18148808,18148808,18148809,18148791,18148792,18148792,18148793,18148793,18148795,18148808,18148809,18148809,18148792,18148793,18148793,18148794,18148795,18148797,18148809,18148809,18148810,18148810,18148793,18148794,18148794,18148795,18148796,18148809,18148810,18148810,18148811,18148794,18148795,18148795,18148810,18148810,18148811,18148811,18148795,18148796,18148800,18148809,18148810,18148811,18148811,18148796,18148797,18148798,18148804,18148810,18148811,18148811,18148812,18148813,18148797,18148798,18148811,18148812,18148812,18148813,18148813,18148812,18148812,18148813,18148813,18148805,18148812,18148814,18148813,18148814,18148814,18148816,18148819,18148819,18148825,18164642,18148826,18148827,18148827,18148828,18164625,18164639,18164640,18164641,18164641,18164642,18164642,18164643,18164643,18164644,18164645,18164662,18164708,18164712,18164713,18164714,18198470,19207883,18148827,18148828,18148828,18148829,18148830,18164625,18164626,18164640,18164640,18164641,18164641,18164642,18164642,18164643,18164643,18164644,18164645,18164660,18164661,18164664,18164666,18164666,18164671,18164712,18164715,18164716,18164717,18164749,18188521,18198471,18198476,18320595,19207884,19896820,18148828,18164608,18164624,18164626,18164629,18164640,18164641,18164642,18164642,18164643,18164643,18164644,18164644,18164646,18164646,18164669,18164679,18164716,18164627,18164642,18164642,18164643,18164643,18164644,18164644,18164645,23320755,18164643,18164643,18164644,18164645,18164646,18164646,18180400,18180435,18180435,18180432,18180434,18180435,18180435,18180436,18180441,18180450,18180451,18180451,18180452,18180453,18180485,18180487,18180524,18180453,18180456,18180454,18180456,18180454,18180455,18180457,18180455,18180456,18180455,18180456,18180458,18180456,18180457,18180457,18180458,18180458,18180471,18180471,18180472,18180473,18180473,18180457,18180458,18180458,18180459,18180459,18180460,18180460,18180461,18180461,18180463,18180470,18180470,18180471,18180472,18180472,18180474,18180458,18180459,18180459,18180461,18180466,18180470,18180472,18180472,18180473,18180474,18180479,18180459,18180460,18180460,18180461,18180461,18180462,18180462,18180471,18180471,18180472,18180472,18180473,18180473,18180474,18180475,18180460,18180461,18180461,18180462,18180462,18180471,18180472,18180473,18180473,18180474,18180475,18180461,18180462,18180462,18180463,18180463,18180464,18180465,18180467,18180468,18180469,18180471,18180472,18180472,18180473,18180473,18180474,18180474,18180475,18180475,18180476,18180481,18180463,18180463,18180468,18180473,18180474,18180474,18180475,18180476,18180477,18180467,18180474,18180475,18180477,18180483,18180464,18180465,18180472,18180474,18180475,18180475,18180476,18180477,18180479,18180479,18180480,18180465,18180466,18180474,18180475,18180476,18180476,18180478,18180480,18180475,18180476,18180476,18180477,18180478,18180478,18180481,18180476,18180477,18180479,18180481,18180477,18180476,18180478,18180479,18180478,18180481,18180483,18180482,18180506,18180480,18180484,18180483,18180484,18180485,18180486,18180486,18180484,18180484,18180485,18180485,18180486,18180486,18180487,18180493,18180485,18180485,18180486,18180487,18180487,18180490,18180495,18204351,18180485,18180486,18180487,18180488,18180499,18180507,18180486,18180487,18180487,18180488,18180488,18180490,18180498,18180506,18180545,18204276,23336583,18180487,18180488,18180488,18180489,18180489,18180491,18180491,18180493,18180495,18180501,18180502,18180508,18180542,18180544,18180544,18180545,18204354,18214219,18180488,18180489,18180489,18180490,18180491,18180491,18180492,18180492,18180493,18180494,18180494,18180495,18180496,18180497,18180499,18180501,18180504,18180505,18180509,18180509,18180512,18180515,18180540,18180544,18180545,18180545,18180546,18180546,18204277,18204351,18204352,18204356,18214296,18214298,18214298,18214300,18214303,18214303,18214306,18214310,18336423,18336426,19355247,19798098,19798099,21155545,23161315,23336584,18180489,18180490,18180492,18180495,18180497,18180490,18180493,18180495,18180496,18180504,18180547,18180549,23336585,18180491,18180492,18180492,18180493,18180493,18180494,18180494,18180495,18180495,18180496,18180496,18180497,18180497,18180498,18180498,18180500,18180500,18180501,18180501,18180502,18180502,18180504,18180504,18180505,18180505,18180506,18180506,18180507,18180507,18180508,18180508,18180509,18180509,18180510,18180510,18180511,18180511,18180512,18180512,18180513,18180516,18180541,18180542,18180544,18180545,18180545,18180546,18180546,18180547,18180547,18180548,18180548,18180549,18204278,18204279,18204357,18204358,18204358,18204359,18210389,18210390,18214294,18214297,18214299,18214301,18214302,18214303,18214303,18214304,18214305,18214309,18214313,18336427,18336428,18564095,19098335,19202553,19223716,19223716,19223717,19223721,19798101,19798105,19798170,21421826,21587472,23161315,23161317,23253551,23336586,23336632,18180492,18180493,18180494,18180494,18180496,18180496,18180497,18180497,18180498,18180498,18180508,18180509,18180511,18180511,18180512,18180512,18180547,18180548,18204354,18210392,18214295,18214306,22207837,23336586,18180495,18180501,18180517,18180552,18180496,18180497,18180500,18180508,18180512,18180516,18214298,18180495,18180498,18180499,18180502,18180504,18180505,18180510,18180549,18180550,23336588,18180496,18180497,18180497,18180498,18180498,18180499,18180499,18180500,18180501,18180502,18180503,18180504,18180505,18180507,18180508,18180508,18180509,18180509,18180510,18180511,18180511,18180512,18180513,18180514,18180549,18180549,18180550,18204357,18210393,18214304,18180498,18180499,18180508,18180509,18180515,18180516,18180520,18180550,18180500,18180502,18180505,18180510,18180512,18180517,18180501,18180507,18180512,18180514,18180515,18180501,18180502,18180503,18180504,18180508,18180509,18180511,18180513,18180515,18180515,18180518,18180501,18180502,18180502,18180503,18180504,18180511,18180514,18180514,18180516,18180519,18180521,18180552,23336591,18180502,18180503,18180504,18180505,18180506,18180507,18180507,18180510,18180511,18180512,18180513,18180513,18180514,18180515,18180515,18180516,18180517,18180517,18180518,18180519,18180520,18180522,18180522,18180503,18180504,18180506,18180507,18180508,18180514,18180514,18180515,18180516,18180517,18180518,18180518,18180519,18180520,18180521,18180521,18180504,18180505,18180506,18180506,18180507,18180508,18180508,18180511,18180511,18180512,18180513,18180514,18180516,18180517,18180518,18180519,18180519,18180521,18180522,18180552,18180507,18180514,18180515,18180516,18180517,18180519,18180520,18180520,18180521,18180510,18180512,18180512,18180513,18180515,18180516,18180517,18180519,18180520,18180520,18180521,18180522,18180523,18180539,18180511,18180521,18180511,18180515,18180516,18180518,18180519,18180519,18180534,18180536,18180511,18180513,18180514,18180514,18180518,18180519,18180523,18180535,18180537,18180521,18180536,18180515,18180522,18180524,18180538,18180539,18180544,18180519,18180521,18180523,18180537,18180538,18180543,18180520,18180521,18180525,18180536,18180543,18180548,18180548,18180515,18180523,18180544,18180549,18180517,18180526,18180518,18180518,18180523,18180540,18180543,18180518,18180519,18180520,18180521,18180522,18180523,18180525,18180539,18180540,18180541,18180544,18180520,18180521,18180523,18180525,18180526,18180527,18180528,18180541,18180542,18180522,18180523,18180523,18180524,18180526,18180526,18180542,18180521,18180522,18180523,18180523,18180528,18180528,18180530,18180541,18180542,18180522,18180523,18180523,18180524,18180524,18180525,18180525,18180543,18180523,18180524,18180524,18180525,18180526,18180527,18180528,18180529,18180530,18180532,18180542,18180543,18180524,18180525,18180525,18180526,18180526,18180527,18180527,18180528,18180529,18180530,18180531,18180525,18180526,18180526,18180527,18180527,18180528,18180531,18180544,18180550,18180552,18180563,18180526,18180527,18180527,18180528,18180528,18180529,18180529,18180532,18180538,18180545,18180545,18180549,18180527,18180528,18180528,18180529,18180534,18180544,18180545,18180545,18180546,18180550,18180528,18180529,18180529,18180530,18180530,18180531,18180532,18180538,18180543,18180545,18180546,18180550,18180529,18180530,18180530,18180531,18180532,18180533,18180545,18180546,18180546,18180548,18180530,18180531,18180531,18180532,18180532,18180533,18180533,18180536,18180545,18180546,18180546,18180547,18180548,18214319,18180531,18180532,18180532,18180533,18180533,18180534,18180535,18180543,18180547,18180547,18180551,18180565,18180567,18336448,19223736,18180532,18180533,18180533,18180535,18180537,18180547,18180547,18180548,18180564,18180568,18214324,18180533,18180534,18180534,18180535,18180536,18180536,18180546,18180546,18180548,18180548,18180549,18180568,18204300,18210411,18180534,18180535,18180535,18180536,18180537,18180541,18180546,18180548,18180548,18180549,18180569,18204300,18180535,18180536,18180537,18180545,18180548,18180549,18180549,18180550,18180554,18180569,18204376,18214336,18214347,18180536,18180537,18180538,18180539,18180548,18180548,18180549,18180550,18180551,18180554,18180568,18180569,18180569,18180570,18204374,18204375,18214329,19355271,21047850,23161339,18180548,18180550,18180550,18180570,18214322,18180538,18180548,18180549,18180550,18180550,18180551,18180571,18204302,19202573,23253575,18180539,18180551,18180551,18180568,18180570,18214322,18214326,18180541,18180551,18180552,18180572,18180574,18204379,18966750,18180552,18180563,18214327,18214351,18180553,18180557,18214328,18180544,18180553,18180554,18180572,18180574,23253577,18180555,18180561,21421855,18180557,18180558,18180577,18180561,18180581,18180582,18180585,18180561,18180562,18180561,18180562,18180562,18180565,18180582,18214338,18180562,18180563,18204391,18204401,18214335,19011211,23336621,18180563,18180568,18180570,18180580,18180581,18180582,18180583,18180584,18180584,18204314,18204315,18214370,19798139,23336622,18180564,18180565,18180566,18180567,18180567,18180568,18180568,18180570,18180571,18180573,18180576,18180578,18180581,18180581,18180582,18180582,18180583,18180583,18180584,18180584,18180585,18180586,18180587,18180616,18180617,18180622,18180622,18180626,18204315,18204389,18204390,18204390,18204391,18204392,18204394,18204395,18204395,18204396,18210428,18210429,18214257,18214308,18214317,18214321,18214329,18214330,18214332,18214333,18214333,18214336,18214338,18214339,18214339,18214341,18214344,18214344,18214346,18214361,18214363,18214370,18293737,18293738,18336464,18336465,19192572,19202584,19202585,19223753,19223753,19223756,19355285,19606524,19798140,19798142,19912686,20500131,21310992,21421863,22256660,22269382,22422460,23161356,23336622,23336663,23339196,18180568,18180569,18180583,18180584,18180584,18180585,18214339,19223753,20449860,23336623,18180573,18180582,18214352,18180569,18180584,18180585,18180586,18204391,18214289,18214318,18929334,18180584,18204333,18204395,18214356,18180575,18204392,18214341,19798144,18180572,18214347,18214351,18214353,18180588,18214344,18214349,19223757,18180574,18180574,18180580,18180587,18180587,18180588,18180588,18180589,18204346,18204392,18214341,18214344,18214352,18336468,19223755,19798142,22422464,18180589,18180590,18214351,18180589,18204396,23336628,18180590,18180605,18214348,18180588,18180592,18180594,18180594,18180594,18214352,18180595,18180596,18180595,18180612,18180612,18180598,18180613,18180614,18180600,18180602,18180615,18180617,18180599,18180601,18180616,18180616,18180617,18180599,18180600,18180600,18180601,18180602,18180604,18180616,18180601,18180601,18180602,18180615,18180617,18180601,18180602,18180602,18180603,18180617,18180617,18180618,18180602,18180603,18180603,18180604,18180605,18180605,18180616,18180617,18180617,18180618,18180619,18180619,18180603,18180604,18180604,18180605,18180607,18180617,18180617,18180618,18180618,18180619,18180619,18180604,18180605,18180606,18180611,18180617,18180618,18180618,18180619,18180619,18180605,18180606,18180606,18180607,18180608,18180609,18180616,18180618,18180618,18180619,18180619,18180620,18180621,18180622,18180606,18180607,18180608,18180615,18180616,18180617,18180619,18180619,18180620,18180621,18180618,18180619,18180620,18180617,18180618,18180619,18180619,18180620,18180620,18180621,18180623,18180621,18180618,18180622,18180622,18180623,18180623,18180623,18180624,18214370,18180629,18180629,18204426,18180630,18180631,18180631,18180631,18180631,18180632,18180631,18180632,18180632,18204419,18180632,18180633,18180633,18180634,18204349,18204426,18210461,18210462,18214374,18214376,18214378,18336498,19223787,19223787,19223788,20449893,21426314,23161387,18180633,18180634,18180635,18180636,18180658,18180669,18204423,18204426,18204427,18204428,18204456,18210460,18210463,18214352,18214364,18214367,18214370,18214376,18214378,18214396,18336497,18336498,18464071,19223788,19325548,19328643,19798174,23161387,18180634,18180635,18180635,18180636,18180638,18180650,18180651,18180655,18180658,18180659,18180660,18204350,18204350,18204422,18204424,18204425,18204425,18204427,18204427,18204428,18204429,18204430,18204431,18210461,18210461,18210462,18210462,18210463,18210463,18214292,18214364,18214367,18214367,18214368,18214368,18214370,18214370,18214371,18214372,18214372,18214373,18214373,18214375,18214377,18214378,18214379,18214380,18214381,18214382,18214390,18214393,18214397,18214399,18214400,18293773,18336498,18336499,18336500,18924400,18972087,19011244,19136476,19202620,19223787,19223787,19223788,19223789,19355320,19798172,19798176,19798196,19912722,20782454,21237333,21311027,21421898,22207908,23161391,23161392,23336657,23336657,18180635,18180636,18204350,18204351,18204426,18204426,18204427,18204429,18204432,18204433,18210462,18210464,18214293,18214366,18214367,18214369,18214370,18214373,18214373,18214375,18214379,18214379,18214380,18214383,18214386,18214398,18336500,18481101,18765392,19011245,19202624,19223717,19223789,19223789,19355320,19821918,20742818,21421898,23253623,18180663,18271530,18336499,19223789,19223789,19223790,19606560,18180640,18204351,18214378,18214378,18214382,18336501,19798177,21421898,18180639,18180656,18204431,18336501,18204436,19223724,18214374,19223793,18180708,18180685,18180686,18180693,18180692,18180702,18180697,18180698,18180691,18180694,18180700,18180696,18180702,18180702,18204458,18210494,18204459,18214401,23339044,18180723,18204466,18214415,18204465,18204467,18210501,18210502,18214438,18214419,18210509,19223841,18210520,18228075,18228076,18228076,18228085,18228149,18228149,18228150,18228151,18228152,18228152,18228153,18228154,18228155,18228155,18228156,18228157,18228160,18228162,18228150,18228151,18228151,18228152,18228153,18228164,18228180,18228185,18228119,18228135,18234216,18234220,18228251,18228214,18228241,18228213,18228242,18228220,18228242,18228215,18228217,18228243,18228216,18228217,18228217,18228220,18228243,18228216,18228219,18228244,18228217,18228218,18228219,18228220,18228221,18228244,18228220,18228221,18228245,18228219,18228220,18228221,18228224,18228245,18228245,18228222,18228224,18228225,18228245,18228246,18228246,18228224,18228246,18228247,18228247,18228247,18228228,18228248,18228226,18228248,18228249,18228249,18228249,18228249,18228250,18228250,18228250,18228251,18228234,18228252,18228254,18228254,18228255,18228256,18228256,18228271,18234280,18238196,18360317,19754937,19821995,23360476,18228272,18228273,18234279,18234280,18234280,18234281,18234282,18234284,18238033,18238164,18238186,18238187,18238187,18238188,18238189,18238190,18238190,18238191,18238192,18238192,18238193,18238194,18238194,18238195,18238195,18238197,18238198,18238198,18238199,18238199,18238203,18238208,18238216,18238217,18238220,18238220,18238223,18360317,18360318,19122226,19226438,19226439,19247606,19247607,19379139,19821989,19821994,19821994,19821996,20501337,20766636,23185210,23185210,23237289,23360476,18238198,23185211,18228291,18228294,18228295,18228299,19247619,19247625,18238214,18234302,18238207,18240287,18240288,18240302,18240289,18240302,18240304,18240303,18240304,18240290,18240291,18240292,18240293,18240303,18240305,18240303,18240305,18240306,18240304,18240293,18240294,18240306,18240307,18240305,18240307,18240307,18240307,18240308,18240318,18244209,18240318,18240319,18244210,18244215,18244217,18244220,18244224,18737206,19041088,19232461,19253630,19355390,20479190,18244215,18240320,18244190,18244192,18244195,18244210,18244210,18244211,18244212,18244213,18244214,18244215,18244216,18244216,18244217,18244217,18244218,18244219,18244222,18244227,18244230,18244239,18244242,18244242,18244247,18323616,18366342,18366343,19232462,19253630,19253631,19253631,19385163,19828020,19828035,18244055,18244196,18244216,18244218,18244220,18244242,18366342,18366343,19166319,18247809,18247811,18247966,18247968,18248026,18248086,18248106,18248083,18248080,18248079,18248122,18248098,18248118,18248090,18248091,18248105,18248099,18248107,18248109,18248130,18248138,18248103,18248141,18248107,18248101,18248104,18248105,18248112,18248113,18248116,18248135,18248137,18248144,18248146,18248148,18248104,18248107,18248112,18248105,18248106,18248112,18248115,18248131,18248146,18248148,18370233,19257522,18248104,18248104,18248109,18248113,18248116,18248131,18248132,18248132,18248137,18248140,18248148,18248154,18248104,18248109,18248132,18248133,18248152,18248108,18248110,18248136,18248107,18248109,18248116,18248120,18248133,18248134,18248138,18248110,18248134,18248110,18248111,18248116,18248116,18248118,18248118,18248134,18248135,18248135,18248139,18248149,18248150,18248151,18248114,18248116,18248123,18248135,18248154,18248115,18248121,18248135,18248140,18248152,18248112,18248115,18248115,18248116,18248136,18248136,18248122,18248123,18248136,18248137,18248137,18248139,18248152,18248114,18248117,18248119,18248130,18248137,18248137,18248138,18248153,18248154,18248155,18248156,18248114,18248115,18248116,18248120,18248137,18248138,18248139,18248116,18248117,18248119,18248120,18248123,18248124,18248137,18248138,18248139,18248141,18248154,18248118,18248120,18248138,18248139,18248139,18248141,18248142,18248143,18248120,18248138,18248139,18248142,18248125,18248128,18248131,18248137,18248140,18248142,18248153,18248119,18248121,18248121,18248123,18248128,18248141,18248143,18248143,18248144,18248155,18248121,18248122,18248128,18248140,18248142,18248142,18248144,18248154,18248165,18248151,18248142,18248142,18248144,18248159,18248124,18248131,18248142,18248143,18248143,18248145,18248147,18248125,18248125,18248128,18248129,18248131,18248134,18248142,18248143,18248143,18248144,18248144,18248145,18248146,18248146,18248147,18248147,18248148,18248148,18248158,18248160,18248166,18248167,18248132,18248143,18248145,18248146,18248147,18248148,18248144,18248145,18248146,18248147,18248147,18248149,18248131,18248144,18248144,18248145,18248147,18248148,18248150,18248130,18248138,18248144,18248131,18248144,18248145,18248147,18248152,18248154,18248146,18248147,18248147,18248149,18248150,18248151,18248152,18248153,18248158,18248159,18248148,18248147,18248148,18248151,18248158,18248148,18248150,18248152,18248154,18248158,18248155,18248155,18248158,18248151,18248155,18248140,18248147,18248150,18248154,18248156,18248164,18248150,18248145,18248168,18248158,18248152,18248169,18248156,18248171,18248155,18248150,18248155,18248156,18248157,18248157,18248159,18248161,18248164,18248178,18248181,18248160,18248162,18248176,18248178,18248183,18248161,18248162,18248162,18248163,18248163,18248164,18248164,18248165,18248165,18248166,18248166,18248169,18248170,18248171,18248176,18248177,18248179,18248180,18248186,18370262,18370263,18679211,18799150,19257551,19257552,19389083,19832008,21455661,22150386,23370420,23370421,18248162,18248163,18248163,18248165,18248166,18248167,18248168,18248174,18248176,18248183,18248186,18327537,18370262,18370263,18370264,19170240,19257551,19725925,20519202,22150399,23195155,23370421,18248163,18248164,18248165,18248165,18248166,18248167,18248169,18248171,18248178,18248180,18248184,18248186,18327537,18370263,19257551,19257552,19257553,19831877,19831941,19831960,23195156,23287387,18248165,18248166,18248166,18248168,18248169,18248171,18248175,18248180,18248181,18248182,18248187,19257553,19257554,19831942,18248166,18248168,18248168,18248169,18248169,18248173,18248186,18370264,18370264,18370266,19045009,19236385,19257553,21455663,18248168,19257555,19491775,18248167,18248168,18248169,18248174,18248178,18248182,18248184,18248184,18248189,18370265,18851806,18981325,19236386,19236390,19257552,19257553,19257554,20989516,23287389,18248174,18248178,18248179,18248186,18248189,18305294,18305296,18327540,18370265,18370266,19257555,19257555,19831962,23195156,23370424,18248170,18248171,18248173,18248174,18248176,18248185,18305296,18370266,18370267,18370268,18542819,19257555,19946489,23370425,18248174,18248185,18370266,19170244,19257557,19389088,19831945,23195156,18248172,18248172,18248174,18248175,18248183,18370267,18370268,18958168,19236387,19236389,19257557,19831881,19832013,23370426,18248173,18248175,18248187,18248189,18248191,18305297,19257557,19831940,19831964,23195156,23370426,18248174,18248177,18248180,19170245,19257558,19491651,19831945,20816224,22999039,23195158,23370427,18248185,18248191,18248192,18248192,19257558,18248187,18248191,18248193,18679218,19045014,19831945,21455666,19257559,18248181,18248194,18370270,18248194,18370271,20816226,23370429,18248181,18248190,18248194,18370272,18248185,18248192,18370272,19831950,20438754,18248184,18248196,19257562,21455672,23195161,18248187,19026572,19389094,18974838,18248185,18604674,23370433,18248188,19946499,18248187,18248197,19257565,21189396,18248190,18248191,18248193,18370276,18248196,19257566,19831951,19831952,18248192,18370278,18799167,19045025,19257566,19946500,18248191,18370277,19257567,19725940,18370279,19132186,19170255,19257567,18248194,18248198,18370278,18958177,19257568,19640337,18327553,18370278,18370279,18370280,18370280,19170256,19257567,19831957,21344807,18327554,18370275,18370279,18370279,18370280,19257569,19432505,23287404,18248199,19045028,19257569,19257570,19831950,18958182,19257569,19257570,20483676,20511097,18248205,19257571,20483677,22150417,19831955,18248205,18327556,19132190,19236403,21189403,18370283,18421956,18370284,19257573,18617239,19257572,18248207,19389105,22400206,23195174,18305315,18327559,18370285,18370286,18574583,23370444,18370286,19257575,19257576,18370286,18370287,18851827,19257580,19831965,19831966,19831984,18327561,18370287,18469429,18614589,19236408,19257576,19257576,21455686,21460104,23195177,18362433,18362434,18362425,18362436,18362437,19889079,20003628,18427406,18427407,20540255,23344530,18375476,19895604,18406922,18406923,18406924,18406924,19911263,19336939,19336939,18449650,18449651,18931185,19249627,19315772,19336940,19468471,21535049,18492359,18492376,18492363,18492377,18492378,18492363,18492364,18492378,18492378,18492365,18492378,18492379,18492379,18492367,18492378,18492378,18492379,18492379,18492380,18492381,18492380,18492380,19379666,18492392,18492392,19080278,19254287,19954055,18492392,19254287,19292355,19954053,22272512,22272514,19358499,19379667,19379667,19379668,19511199,19954052,20898697,20938334,21564185,21577778,23409502,18696676,18739336,18801327,18921268,18945309,18990142,19080279,19080280,19148679,19153959,19167123,19167124,19167125,19241482,19292356,19358496,19358499,19358500,19358501,19379667,19379667,19379668,19379668,19379669,19511200,19517474,19762439,19954053,19954055,19954057,19954123,20068602,20258489,20423772,20831476,21311499,21577778,23314187,23317268,23317271,23409503,23492537,23494929,19953994,18595720,18595863,18596006,20005864,18690665,19478812,18747570,18747631,19507288,18781604,19503124,18837479,18837495,18837510,21110897,18900971,18900972,19496651,20158352,18947712,19607333,18961175,19614064,18980979,19372265,18986287,18986291,19626622,19626623,19110276,19688616,19688617,19234104,19234160,19234215,23688182,19350155,19350156,19350157,19350163,19808556,19940088,21062084,19398235,19832593,19455451,19455459,19455460,19861206,19999008,19861141,19487901,23990296,19668176,19668181,19668179,19668181,19668182,19736575,19755024,19946401,19958362,20099101,20541956,24080439,19678114,19972534,19701505,19984230,19714495,19903412,19752977,20009968,19763556,19763556,20015256,24045092,19804973,19804975,19804975,20610349,19910584,20035964,19815539,20041247,19841868,19841869,19841870,19841867,19841870,19841870,19841871,19841872,19841872,20054410,20628801,20054413,20054413,22141652,19872404,20054414,20628799,21573444,24084248,24167283,19902982,20084992,19990580,20703174,20016189,20016190,20016193,20016192,20016317,20016318,20016318,20016319,20141572,20016446,20016446,20120531,20120531,20141698,20273231,20716088,22344226,20092319,20092330,20092330,20092331,20092331,20092333,20092334,20092332,20179642,20179642,20179643,20754029,20179642,20179643,24117241,20092344,20179643,20179644,20311304,20179645,20179645,20709875,20204595,20810161,20224619,20224615,20224606,20224618,20224618,20224623,20224619,20224619,20224624,20224626,20224627,20224626,20245785,20224636,20245784,20245785,20245786,20245786,20245787,20377318,20820173,22333026,24183386,24358656,23444428,20245790,20245791,20245792,24183394,24358661,24358714,20248539,20389278,20266808,20266817,20266881,20266885,20266887,20266939,20266940,20266956,20266941,20266954,20266955,20266955,20266956,20266957,20266941,20266942,20266956,20266956,20266957,20266957,20266958,20266942,20266943,20266946,20266954,20266956,20266957,20266957,20266958,20266958,20266943,20266944,20266945,20266946,20266956,20266956,20266957,20266958,20266958,20266959,20266959,20266961,20266945,20266946,20266946,20266957,20266957,20266958,20266958,20266959,20266959,20266960,20266960,20266958,20266960,20266961,20266961,20266961,20266962,20266964,20266962,20266966,20266966,20266968,20266972,24204556,20266972,20398488,20841341,23370630,20266972,20266973,21815125,22354196,24204556,24204558,24204559,20266973,20266973,20300263,20797192,20841344,20841346,22354196,22465067,23159802,24204557,24204558,24379826,20266973,20266974,20266974,20398489,20398490,20501176,20841341,20841342,20841343,20841343,20841415,20955891,21656817,21678025,21785987,22354196,22354197,22451475,24004664,24201478,24204557,24296793,24379827,20266974,20266976,20371815,20398486,20398489,20398490,20398490,20404760,20501176,20501177,20501179,20649729,20710508,20774303,20792304,20841283,20841342,20841344,20841363,20841417,20841556,22354196,22354197,22465068,22469485,23159805,24204557,24204559,24296793,20266975,20266976,20266976,20266977,20266978,20321583,20335855,20371815,20371898,20398490,20398491,20404761,20441895,20501177,20649729,20792308,20797190,20797194,20841283,20841342,20841343,20841343,20841344,20841344,20841345,20841345,20841346,20841346,20841347,20841348,20841349,20841364,20859452,20955890,20955892,20955892,20955893,20955894,21517697,21520483,21678025,21843562,22057139,22198790,22198791,22354197,22465068,22465069,22469486,22469486,22581775,23159805,23159806,23370633,23409591,23409592,23465595,24204558,24204559,24256639,24256640,24296793,24379828,24379875,24380523,20398491,20841345,20841346,20955892,24204562,22465069,20841285,20841345,24204560,24204564,20841348,24379889,20774291,20501184,20333566,20431792,20376205,20895906,20404747,20467382,20470479,20943104,21057653,20476662,20476665,20476749,20476750,20476751,20476833,20476836,20476836,23852616,24484763,20530003,20530014,20530006,20530007,20530015,20530016,20530017,20530018,20530021,20530012,20530016,20530016,20530017,20530016,20530022,20530143,20530025,20530026,20530027,20530028,20530140,20530140,20530141,20530143,20530143,20530144,20530141,20530142,20530144,20530144,20530144,20530145,20530145,20530146,20530144,20530146,20530147,20530149,20530265,20530269,20530266,20530268,20530267,20530270,20530271,20530262,20530271,20530272,20530272,20530272,20530273,20530273,20530274,23578230,24511478,20972995,20928845,20928846,24511480,24511480,20973000,24336214,24388293,20530282,20632830,20748322,20923962,20972937,20972994,20972994,20972995,20972997,20972998,20972998,20972999,20973001,20973214,21087545,21087547,21611719,21624718,22596722,22762368,23382733,23382733,23597235,23597251,23777477,24336215,24472492,24511481,20573549,20632830,20972999,20973000,22762368,23597319,24511482,24336214,20632832,20542561,20542564,20542566,20542567,20542568,20754471,22607289,21600646,21093698,24517634,20616828,20616828,21016279,21394380,21016217,20735138,20735268,20735393,20735394,20735393,20735395,20735397,20735397,20735398,20735398,21026525,21075500,21075561,22588414,23604850,24531010,21075501,21075564,21075565,22588414,23643810,20966400,21495512,22814800,21032494,21032496,21032501,21032501,21179959,24679560,21224117,22847843,24587331,24587331,24762600,21154052,21284891,21203704,21203704,21309719,21309715,21281622,21281624,21281650,21348680,22972403,21348691,21317650,21317653,21317654,21366686,21366692,21659955,24729905,21327418,21327421,21327423,21327424,21327424,21371513,21371514,21371574,21371578,21371597,22729020,22884427,21415601,21415602,21415602,21415661,21415662,21415662,21415663,21415665,21415688,21415735,21415612,21415662,21415663,21415663,21415688,21415663,21415687,21415708,21415723,21415724,21415726,21415726,21415727,21415713,21415726,21415727,21415711,21415711,21415713,21415713,21415715,21415728,21415736,21415712,21415713,21415714,21415716,21415728,21415729,21415730,21415737,21415713,21415714,21415714,21415715,21415716,21415716,21415717,21415728,21415729,21415729,21415714,21415715,21415716,21415717,21415717,21415730,21415731,21415715,21415716,21415717,21415718,21415725,21415730,21415730,21415717,21415717,21415718,21415718,21415729,21415730,21415730,21415731,21415717,21415732,21415719,21415719,21415727,21415728,21415731,21415731,21415732,21415738,21415719,21415732,21415732,21415720,21415721,21415721,21415722,21415722,21415725,21415730,21415731,21415732,21415732,21415733,21415733,21415734,21415735,21415739,21415740,21415740,21415741,21415741,21415732,21415733,21415734,21415734,21415736,21415742,21415723,21415732,21415733,21415733,21415734,21415742,21415728,21415734,21415743,21415735,21415738,21415743,21415738,21415739,21415797,21415741,21415798,21415742,21415744,21530275,21415744,21415752,21415753,23051023,24954212,21415744,21415745,21415745,21415746,22066905,24778944,24954212,21415745,21415803,22400010,22928583,23039454,24778943,24954213,21415746,21415747,21415747,21415748,21415748,21415750,21415751,21415751,21415753,21415754,21415754,21415755,21415765,21415801,21415802,21415803,21415803,21415939,21530277,21530278,21530279,21561995,21838440,21927926,22037227,22066904,22066906,22067450,22092082,22094869,22117722,22117724,22221125,22400010,22400011,22400012,22523024,22744339,22859101,22928582,22928583,22928583,23039454,23043871,23062097,23158769,23205100,23205100,23422967,23734189,23945019,24020964,24322066,24778943,24778943,24778944,24778945,24778945,24778946,24778947,24871179,24954213,24954254,21415751,21415755,21415803,21557156,22067451,22099430,23734191,24039969,24778944,24954214,21415753,21415755,23039454,24220210,21415749,21415750,21415754,21415755,21530279,21530280,24954215,21415754,21415755,21415757,22928584,24778949,21415752,21415756,21415767,23025864,24954216,21415768,21415755,21415757,21415769,22400016,21415758,21415759,23039457,21415758,21415760,21415769,21415770,23985504,21415759,21415760,21415770,21415771,21415771,22928589,24871185,24954219,21415772,21530284,22103003,22389519,24778952,21415761,21415762,21415762,21415770,21415772,23734196,24778952,24954221,21415762,21415763,21415772,21415772,21415773,21530286,21530287,22066916,22400020,22928591,23039460,23734198,23825474,21415764,21415772,21415810,21415812,21415813,21415813,21530286,21689955,22400020,22928591,23039461,23039462,24778952,24778953,24954222,21415774,23734198,24778949,22400022,21415775,21415815,22854906,23985516,24778962,24778966,24871197,24954190,21415911,21530296,23039472,23734211,23945037,24871197,21415823,21530296,22928601,24871198,24954232,24954242,22117741,22896289,23039473,23734210,24954233,21415865,21415865,21415867,21415867,21415867,21415867,21415870,21415868,21415869,21415870,21415869,21415870,21415870,21415871,21415871,21415875,21415872,21415874,21415878,21415878,21415873,21415879,21415879,22928648,21530343,24954279,21530346,22928649,24871245,22117789,24954280,22400078,23039521,23039523,23734249,24021034,24779012,24954281,22928651,22928652,24775932,24954282,22400080,22928654,22103068,22026386,22400085,22773251,24942203,21530351,21416056,24954377,21416156,21416154,21416162,21530491,23051242,23205316,21451951,21548391,21463224,24802694,21644821,21644809,21644811,21644822,21644822,21644823,21644824,21644823,21644824,21644825,21644825,21644826,21644826,21644825,21644827,21644823,21644825,21644825,21644826,21644828,21644835,21644835,22217540,25068758,22269553,23043127,23043128,23153999,23158416,24893488,21644838,22042471,22514557,22646567,22887722,23153999,23158417,23319645,23940011,24985724,25029768,25068759,23154000,24439493,24944545,23848736,25068760,21644842,22514559,22858887,23043129,23153998,23848736,25068760,22474921,23154001,23158419,25068761,23158419,25068761,22029834,24893492,21698624,25095681,21708259,25100477,21964160,23202797,22002256,22410984,22024600,22024601,25175614,22399305,22171934,24112282,22261176,22261231,22261307,25377024,22355168,25423933,22414837,25370730,22440118,22440119,24337658,25466406,22629340,24340994,22636889,22713574,22658722,22658723,23021505,22693166,22693240,22693314,24372980,22718079,22718080,22718075,22718081,22718082,23051182,23051185,25430117,25605388,25482201,23011552,22719175,22719192,22719247,22769463,23695613,25182293,25430685,25482767,25522920,25605955,22719315,23695664,22768433,23715805,24660327,22774007,22774008,22774008,22774009,23607720,24413329,23705000,23718594,24957407,22774412,25633552,22783141,23723164,22790257,22790259,22790259,22790259,23087273,23615845,25466206,25641476,25641477,22819713,22819715,23062362,23630574,23741445,23753017,24436182,25480938,22894283,23667857,23026514,23026615,23026717,23335976,23046672,24928229,23089088,23089089,23765260,25790702,23170569,25656361,23305008,23305011,23305012,23305012,23305014,23305015,23305015,23344646,23305053,23305082,23305125,23305130,23305087,25898854,23305094,24874158,23305151,23305159,23984161,23344722,23305241,23305246,25223023,25898968,23363292,23363292,24178879,23902363,23384283,23384275,23384277,23384290,23384291,23384291,23384292,23384293,23384294,23384295,23384291,23384292,23384295,23384296,23384293,23384295,23384296,23384294,23384296,23384297,23514760,23912862,24718470,23384310,25763224,23757456,24023735,24718472,25763229,25938494,23384312,24809746,24189382,24718462,23757459,24023737,24929302,25938497,24023738,24718476,25763228,25763230,23912867,24023737,24718474,25938498,23420162,23420164,23525233,24986192,23630308,23630315,23630415,24035875,23630515,23880565,23645237,23645238,23795779,25893696,23648313,25895235,23730877,25936519,23847347,24255275,23915220,23915371,23915536,23915607,26204144,23946320,24161562,24072948,24072949,25062798,25368659,24130618,24130619,24130620,24130619,24130618,24130620,24130622,24562541,26311656,26311657,26311657,24253714,24396898,24562545,25091625,25397492,26311658,26311659,24294045,24294046,24367739,26310336,24302467,24487237,24376802,24376804,24376954,24376954,24493258,24377102,24377105,24685783,26259628,24441431,24441419,24441432,24441432,24441433,24441432,24441433,24441433,24441433,24441433,24441434,24441434,26291793,24441445,24552301,24552302,24552303,24552304,25022966,25247041,25454773,26291791,26291794,26291794,26291796,26467063,24485671,24552302,24552303,24552304,24667903,24715362,24717950,24931808,24941204,24944593,25247039,25247040,25552899,26291794,26291794,26291797,26467063,25247030,25247041,26291795,26467064,24529907,25166895,24609713,24636444,24635987,24636065,24636068,24636144,24636149,24649657,26389148,26481383,25344397,24663171,24663174,24663160,24663174,24663174,24663175,24663175,24663175,24663162,24663164,24663165,24663176,24663176,24663177,24663177,24663178,24663178,24663177,24663178,24663178,24663178,24663179,24663179,24663179,24663180,24663180,26577933,26402668,26577935,24663191,24719553,25357913,25663702,26402666,26577935,24667594,25357912,26402666,26402668,24663192,24663193,24674749,24674749,24767717,24828823,24955887,25215480,25357912,25357913,25357914,25607699,26154274,26402666,26402667,26402668,26402668,26454749,26577936,24965087,25357913,25663771,25775411,25973868,26402667,26402667,26402671,26454748,26577937,24674750,24828824,25357915,26402668,26402669,26402671,26402671,26577937,26402672,26577938,24672010,24672010,24672012,24672009,24672009,24672010,24672010,24672012,24672011,26407082,26582351,24833238,25362329,26582352,25231359,25668188,25978283,26003533,26407083,26407084,26582352,25573158,24786909,25362332,24686317,24686318,24686319,24790345,24794062,25369484,25675343,26464963,26589506,24708517,26600633,24775932,25414290,24872258,25151233,24894372,24894373,25473511,26518267,24896591,26611609,24901804,24901804,24901805,25477225,25477227,26697303,24989291,26006988,24994465,24994465,24994466,24994466,24994467,24994466,24994467,26009574,26568307,26660544,26743578,24994478,25523557,25734383,26565228,26568309,26568310,25773342,26568310,26743579,26003918,26159615,26743580,26568309,26568312,26660546,25248594,26870643,25267046,26879895,25422182,26765295,25430201,25430205,26961447,25741424,25441000,25441070,25441141,26791660,25447756,26970226,25604550,27048647,25767780,25910215,25790731,25921690,25803883,25928265,26052638,26052637,26052639,26052626,26052637,26052640,26052635,26052647,26052647,26052648,26052633,26052635,26052648,26052648,26052649,26052648,26052649,26052649,26052636,26052650,26052649,26052650,26052651,26052651,26052648,26052649,26052650,26052650,26052651,26052651,26052652,26052652,26052653,26052650,26052651,26052650,26052651,26052652,26052662,26358508,27272671,26302438,26358510,26668602,27272671,26052663,26052664,27097402,27097403,27272672,26052665,26052668,26263477,26302437,26358508,26538668,27094323,27097402,27097403,27189638,27272672,27272672,26358440,26538669,26901385,27097403,27097403,27097405,27189638,27272673,26143924,26143925,27097404,26303960,26358511,26358512,27097404,27272674,27097405,27097406,27097407,27272676,26235196,26235197,26235198,26235196,26235197,26235197,26235198,26235198,26235199,27188675,27363945,26393708,27185597,27188677,26362424,27188676,27363805,27363947,26332767,26332882,26332995,27412843,26358216,27425456,26443224,26553795,26468117,26510170,26474305,26474306,26474306,26474307,27483500,26513263,26569338,27308234,27360312,26569337,27308230,27400467,27483501,26489651,27315904,26552221,26552220,26552220,26552221,26552222,26552222,26552225,26552225,26552230,27522457,26890310,26608298,27347189,27344110,27347190,27347190,27347191,27399270,27439424,27522459,27522460,27522460,27347194,26555263,26555264,27348708,27348712,27473962,26626201,26626200,26626202,27559448,27436262,26645287,26664200,26664201,26664287,26664289,26664226,26664229,26664294,26664298,26664300,26664301,26664302,26664367,26664366,26664367,26664368,26664369,26664370,26664370,26664370,26664371,26664371,26664373,26664372,26664372,26664374,26664374,26664375,26664374,26664374,26664375,27578531,27578532,27207246,27403263,27403264,27403264,27403266,27578533,27578573,27578574,27581300,27207247,27403265,27495499,27578533,27578534,27403266,26809792,27475978,26887681,26887756,26887830,27690281,27013429,27013548,27013667,27577941,27024686,27024687,27024688,27024689,27583421,27583421,27583422,27583425,27758692,27583423,27140801,27140881,27140882,27140962,27140962,27641557,27816826,27228399,27228399,27860546,27685277,27860546,27234225,27688222,27284555,27713357,27888624,27324757,27324833,27324908,27733527,27335059,27830843,27645368,27645370,27645463,27893762,27645557,27986090,27742425,27742500,27742555,28117642,27749915,27750019,27750120,27750119,27750108,27750120,27750122,27750132,27946136,28121406,27832088,28121408,27914054,28025024,28108406,28108479,28108552,28125352,28135995,28135996,28135997,28135997,28139075,28139077,28139078,28139082,28231311,28314346,28142157,28142158,28142140,28142141,28142143,28142156,28142141,28142142,28142155,28142157,28142159,28142159,28142141,28142142,28142142,28142143,28142144,28142157,28142159,28142160,28142142,28142143,28142144,28142144,28142145,28142145,28142146,28142157,28142157,28142158,28142159,28142159,28142160,28142160,28142161,28142143,28142144,28142144,28142146,28142147,28142160,28142161,28142162,28142145,28142145,28142146,28142158,28142160,28142161,28142161,28142162,28142146,28142147,28142159,28142162,28142162,28142147,28142159,28142162,28142162,28142163,28142163,28142164,28142147,28142148,28142160,28142162,28142163,28142148,28142160,28142161,28142163,28142164,28142161,28142164,28142164,28142165,28142164,28142166,28142166,28234391,28317426,28142173,28142174,28142175,28142176,28142177,28142178,28194238,28234392,28317426,28317427,28142176,28317427,28142176,28142177,28142177,28142178,28234394,28317428,28317469,28142177,28142178,28317429,28142178,28142179,28142180,28194240,28317429,28142179,28142180,28142180,28193216,28194241,28194241,28194242,28195287,28234395,28278438,28278439,28278439,28278445,28286976,28316617,28317217,28317411,28317429,28317430,28317471,28319781,28142180,28194243,28317430,28317471,28317431,28194244,28317431,28317472,28317432,28243611,28368153,28244264,28245290,28285443,28246318,28246319,28246320,28246320,28246321,28369316,28369506,28369507,28369507,28286474,28330518,28369508,28248456,28287564,28326613,28326614,28326622,28326623,28326623,28326624,28326624,28326625,28326629,28326625,28326624,28326624,28326626,28326633,28326634,28326634,28326634,28326635,28409444,28409657,28409698,28326635,28326636,28326636,28326638,28370666,28409658,28409699,28326636,28326637,28409658,28409699,28409708,28326637,28326640,28409658,28409659,28409700,28409709,28409659,28409700,28409702,28409661,28409662,28409664,28392648,28392661,28442677,28414715,28414716,28414717,28414701,28414712,28414717,28414716,28414718,28414722,28453703,28414733,28453707,28453707,28453708,28431784,28462238,28468526,28480104,28491131,28491437,28491742,28492249,28492322,28492330,28492371,28492373,28492535,28492421,28492543,28492561,28492562,28492640,28492662,28492680,28492681,28492682,28492682,28492683,28492683,28492684,28492684,28492685,28492686,28492689,28492690,28492691,28492691,28492694,28492696,28492697,28492703,28492706,28492711,28492712,28492712,28492715,28492719,28492720,28492721,28492721,28492722,28492682,28492683,28492684,28492684,28492685,28492691,28492712,28492721,28492722,28492722,28492683,28492684,28492684,28492685,28492699,28492716,28492721,28492721,28492722,28492722,28492723,28492685,28492686,28492723,28492686,28492689,28492723,28492724,28492691,28492724,28492724,28492688,28492723,28492724,28492725,28492688,28492725,28492694,28492697,28492724,28492725,28492726,28492726,28492695,28492729,28492698,28492730,28492730,28492703,28492723,28492731,28492731,28492701,28492731,28492732,28492734,28492732,28492732,28492741,28492733,28492717,28492734,28492737,28492738,28492739,28492727,28492744,28492745,28492745,28492747,28492751,28492752,28492752,28492753,28492753,28492754,28492756,28492759,28492760,28492761,28492761,28492762,28492762,28492771,28492763,28492764,28492764,28492765,28492765,28492766,28492766,28492767,28492767,28492768,28492768,28492769,28492769,28492770,28492770,28492771,28492772,28492772,28492773,28492773,28492774,28492774,28492775,28492775,28492776,28492777,28492778,28492779,28492780,28492780,28492781,28492783,28492783,28492785,28492786,28492786,28492787,28492788,28492789,28492790,28492797,28492764,28492765,28492765,28492766,28492768,28492768,28492772,28492773,28492774,28492775,28492798,28492765,28492766,28492767,28492768,28492770,28492770,28492771,28492773,28492766,28492767,28492767,28492768,28492769,28492769,28492773,28492767,28492768,28492768,28492769,28492769,28492770,28492770,28492771,28492772,28492772,28492773,28492773,28492774,28492774,28492775,28492775,28492776,28492776,28492777,28492777,28492778,28492780,28492783,28492786,28492789,28492798,28492799,28492768,28492769,28492769,28492770,28492770,28492771,28492771,28492772,28492772,28492773,28492773,28492774,28492774,28492775,28492775,28492776,28492776,28492780,28492786,28492800,28492769,28492770,28492770,28492771,28492772,28492773,28492775,28492775,28492776,28492776,28492770,28492771,28492771,28492772,28492775,28492775,28492776,28492777,28492780,28492781,28492790,28492800,28492771,28492772,28492773,28492774,28492775,28492776,28492778,28492779,28492785,28492786,28492772,28492773,28492774,28492774,28492775,28492775,28492776,28492776,28492777,28492777,28492778,28492778,28492779,28492780,28492781,28492784,28492786,28492802,28492774,28492774,28492775,28492776,28492776,28492777,28492777,28492778,28492778,28492779,28492780,28492785,28492785,28492786,28492776,28492779,28492785,28492786,28492776,28492778,28492778,28492780,28492803,28492776,28492777,28492777,28492778,28492779,28492779,28492781,28492783,28492795,28492804,28492777,28492778,28492778,28492779,28492779,28492780,28492780,28492781,28492782,28492779,28492779,28492780,28492780,28492781,28492781,28492783,28492779,28492780,28492780,28492781,28492782,28492782,28492789,28492780,28492781,28492781,28492782,28492782,28492788,28492790,28492797,28492800,28492781,28492782,28492782,28492783,28492783,28492784,28492784,28492785,28492786,28492787,28492789,28492793,28492796,28492798,28492799,28492805,28492806,28492782,28492783,28492783,28492784,28492784,28492785,28492785,28492786,28492786,28492787,28492788,28492788,28492789,28492789,28492790,28492790,28492791,28492793,28492793,28492795,28492796,28492798,28492798,28492799,28492800,28492801,28492806,28492807,28492783,28492784,28492784,28492785,28492785,28492786,28492787,28492787,28492788,28492788,28492789,28492789,28492790,28492790,28492791,28492791,28492807,28492784,28492785,28492785,28492786,28492787,28492787,28492788,28492789,28492789,28492790,28492791,28492792,28492797,28492797,28492800,28492808,28492785,28492786,28492786,28492787,28492788,28492789,28492790,28492791,28492791,28492798,28492801,28492808,28492808,28492786,28492787,28492787,28492788,28492788,28492789,28492790,28492791,28492791,28492792,28492793,28492794,28492795,28492796,28492799,28492800,28492808,28492809,28492787,28492788,28492788,28492789,28492789,28492790,28492790,28492791,28492791,28492792,28492792,28492793,28492795,28492795,28492796,28492796,28492798,28492800,28492801,28492809,28492788,28492789,28492789,28492790,28492790,28492791,28492791,28492792,28492792,28492793,28492793,28492794,28492795,28492796,28492796,28492798,28492798,28492799,28492799,28492800,28492801,28492801,28492803,28492809,28492810,28492789,28492790,28492790,28492791,28492791,28492793,28492810,28492790,28492791,28492791,28492792,28492792,28492793,28492793,28492794,28492794,28492795,28492797,28492797,28492798,28492799,28492800,28492801,28492802,28492802,28492803,28492809,28492810,28492811,28492791,28492792,28492792,28492793,28492793,28492794,28492794,28492795,28492796,28492797,28492800,28492802,28492802,28492804,28492811,28492792,28492793,28492793,28492794,28492794,28492795,28492795,28492796,28492796,28492798,28492800,28492801,28492803,28492810,28492811,28492812,28492793,28492794,28492794,28492795,28492795,28492796,28492796,28492797,28492798,28492798,28492799,28492799,28492801,28492803,28492803,28492804,28492812,28492794,28492795,28492795,28492796,28492796,28492797,28492797,28492798,28492799,28492800,28492801,28492801,28492802,28492802,28492803,28492805,28492806,28492807,28492811,28492813,28492795,28492796,28492796,28492797,28492798,28492798,28492799,28492800,28492800,28492801,28492802,28492803,28492803,28492804,28492806,28492813,28492796,28492797,28492797,28492798,28492799,28492799,28492800,28492802,28492802,28492803,28492805,28492805,28492806,28492807,28492809,28492813,28492814,28492797,28492798,28492798,28492800,28492800,28492801,28492801,28492802,28492802,28492803,28492803,28492804,28492805,28492805,28492806,28492806,28492807,28492814,28492814,28492798,28492799,28492799,28492800,28492801,28492801,28492802,28492803,28492804,28492804,28492805,28492806,28492807,28492808,28492810,28492813,28492815,28492799,28492800,28492800,28492801,28492801,28492802,28492803,28492804,28492804,28492805,28492805,28492806,28492806,28492815,28492815,28492800,28492801,28492801,28492802,28492802,28492803,28492804,28492805,28492805,28492806,28492807,28492808,28492808,28492809,28492811,28492814,28492815,28492815,28492816,28492801,28492802,28492803,28492804,28492805,28492806,28492807,28492808,28492808,28492816,28492802,28492803,28492804,28492805,28492807,28492808,28492809,28492815,28492817,28492803,28492804,28492804,28492806,28492808,28492809,28492817,28492817,28492804,28492805,28492805,28492806,28492806,28492807,28492807,28492808,28492809,28492809,28492810,28492817,28492818,28492805,28492806,28492807,28492807,28492808,28492808,28492809,28492809,28492810,28492811,28492814,28492814,28492816,28492816,28492817,28492818,28492818,28492807,28492807,28492808,28492808,28492809,28492810,28492810,28492811,28492814,28492817,28492818,28492819,28492810,28492812,28492813,28492819,28492808,28492809,28492809,28492810,28492811,28492812,28492820,28492809,28492810,28492811,28492811,28492812,28492813,28492813,28492814,28492818,28492819,28492819,28492820,28492820,28492810,28492811,28492811,28492812,28492812,28492813,28492814,28492818,28492818,28492819,28492820,28492821,28492811,28492812,28492812,28492813,28492813,28492814,28492814,28492817,28492819,28492819,28492820,28492821,28492821,28492812,28492813,28492813,28492814,28492815,28492817,28492820,28492821,28492822,28492813,28492814,28492814,28492815,28492815,28492822,28492814,28492815,28492815,28492816,28492816,28492817,28492818,28492819,28492820,28492820,28492821,28492821,28492822,28492823,28495099,28492815,28492821,28492823,28492816,28492817,28492817,28492818,28492818,28492819,28492819,28492821,28492821,28492822,28492822,28492823,28492824,28492817,28492818,28492819,28492820,28492822,28492823,28492824,28492824,28492818,28492820,28492821,28492822,28492823,28492824,28492824,28492825,28492820,28492823,28492824,28492825,28492825,28492824,28492824,28492826,28492824,28492825,28492826,28492827,28492825,28492825,28492827,28492827,28492826,28492828,28495104,28492827,28492827,28492828,28492829,28492828,28492828,28492829,28492829,28492828,28492829,28492830,28492830,28492830,28492831,28492831,28492832,28492833,28492833,28492834,28492835,28492836,28492837,28492837,28492839,28492840,28492841,28492841,28492842,28492843,28492845,28492845,28492848,28492852,28492856,28492857,28492860,28492861,28492862,28492863,28492870,28492870,28492871,28492871,28492872,28492873,28493451,28493493,28493494,28493508,28495108,28495210,28492833,28492834,28492834,28492835,28492835,28492836,28492836,28492837,28492837,28492838,28492838,28492839,28492839,28492840,28492840,28492841,28492841,28492842,28492843,28492843,28492844,28492844,28492845,28492846,28492846,28492847,28492847,28492848,28492849,28492851,28492851,28492852,28492852,28492854,28492855,28492856,28492857,28492857,28492858,28492858,28492860,28492861,28492861,28492862,28492864,28492865,28492865,28492866,28492868,28492869,28492870,28492870,28492871,28492871,28492872,28492872,28492873,28492873,28495108,28492834,28492835,28492835,28492836,28492838,28492839,28492839,28492840,28492846,28492849,28492849,28492850,28492853,28492854,28492855,28492858,28492859,28492865,28492868,28492871,28492872,28492873,28492874,28492836,28492845,28492847,28492859,28492864,28492870,28492872,28492872,28492874,28492840,28492841,28492842,28492845,28492873,28492874,28492875,28492842,28492844,28492873,28492874,28492875,28492840,28492842,28492849,28492859,28492862,28492863,28492874,28492875,28492876,28492876,28492843,28492847,28492843,28492862,28492877,28492844,28492845,28492848,28492848,28492850,28492852,28492876,28492876,28492878,28492845,28492859,28492860,28492862,28492878,28495113,28492845,28492846,28492848,28492877,28492879,28492846,28492848,28492853,28492864,28492876,28492847,28492851,28492852,28492870,28492879,28492879,28492880,28492847,28492848,28492849,28492849,28492852,28492857,28492870,28492873,28492879,28492879,28492880,28492848,28492851,28492853,28492863,28492878,28492879,28492881,28493516,28492850,28492851,28492855,28492861,28492879,28492880,28492881,28492851,28492852,28492852,28492860,28492869,28492881,28492882,28492852,28492854,28492856,28492879,28492880,28492882,28492852,28492853,28492883,28492853,28492854,28492879,28492882,28492883,28492854,28492855,28492856,28492860,28492863,28492867,28492870,28492873,28492881,28492883,28492883,28492884,28492857,28492868,28492880,28492883,28492884,28492858,28492869,28492878,28492885,28492858,28492871,28492883,28492884,28492884,28492886,28492873,28492877,28492885,28492886,28492875,28492882,28492885,28492887,28492861,28492887,28492867,28492877,28492881,28492884,28492885,28492886,28492888,28492886,28492888,28492865,28492889,28492889,28492880,28492888,28492890,28492870,28492890,28492876,28492875,28492890,28492883,28492892,28492891,28492892,28492893,28492876,28492880,28492884,28492883,28492893,28492894,28492882,28492891,28492894,28492896,28492893,28492896,28492885,28492894,28492895,28492896,28492897,28492884,28492895,28492896,28492898,28492883,28492895,28492897,28492898,28492898,28492897,28492897,28492899,28492898,28492893,28492897,28492897,28492900,28492888,28492891,28492894,28492899,28492900,28492901,28492893,28492901,28492893,28492902,28492902,28492903,28492903,28492901,28492903,28492904,28492896,28492897,28492900,28492902,28492904,28492902,28492903,28492904,28492904,28492905,28492905,28492906,28492906,28492902,28492904,28492905,28492905,28492907,28492908,28492909,28492906,28492907,28492907,28492908,28492909,28495144,28492908,28492908,28492907,28492908,28492910,28492910,28492908,28492909,28492909,28492910,28492910,28492911,28492909,28492910,28492910,28492911,28492911,28495146,28492910,28492911,28492911,28492912,28492911,28492912,28492912,28492912,28492913,28492913,28492914,28493469,28493492,28493492,28493534,28493543,28493545,28495149,28495251,28495371,28495393,28495566,45019009,28493493,28494048,28494070,28494071,28494072,28494072,28494073,28494073,28494074,28494075,28494076,28494077,28494082,28494091,28494093,28494094,28494103,28494107,28494109,28494111,28494112,28494112,28494117,28494146,28494073,28494113,28494113,28494114,28494077,28494092,28494114,28494114,28494084,28494115,28494116,28494116,28494116,28494117,28494118,28494123,28494131,28494132,28494134,28494130,28494145,28494148,28494148,28494151,28494152,28494153,28494153,28494187,28494154,28494155,28494155,28494156,28494156,28494157,28494157,28494158,28494158,28494159,28494160,28494160,28494161,28494161,28494162,28494162,28494163,28494163,28494164,28494165,28494165,28494166,28494166,28494168,28494168,28494169,28494169,28494170,28494170,28494171,28494171,28494173,28494174,28494175,28494176,28494177,28494177,28494179,28494180,28494181,28494182,28494184,28494187,28494188,28494193,28494156,28494159,28494160,28494165,28494166,28494169,28494182,28494188,28494163,28494163,28494164,28494164,28494167,28494189,28494178,28494189,28494159,28494164,28494164,28494165,28494165,28494166,28494190,28494166,28494165,28494182,28494164,28494165,28494167,28494191,28494191,28494192,28494167,28494166,28494167,28494168,28494179,28494185,28494193,28494168,28494168,28494172,28494189,28494194,28494168,28494170,28494171,28494172,28494173,28494178,28494179,28494193,28494171,28494180,28494195,28494171,28494171,28494174,28494182,28494185,28494186,28494188,28494189,28494194,28494196,28494172,28494173,28494174,28494178,28494184,28494185,28494186,28494188,28494188,28494189,28494189,28494190,28494194,28494196,28494172,28494174,28494174,28494175,28494177,28494179,28494183,28494184,28494186,28494188,28494189,28494190,28494190,28494193,28494195,28494197,28494174,28494175,28494175,28494176,28494178,28494178,28494179,28494179,28494181,28494183,28494184,28494186,28494188,28494189,28494189,28494190,28494193,28494197,28494197,28494187,28494198,28494176,28494177,28494178,28494181,28494188,28494191,28494195,28494199,28494177,28494182,28494182,28494186,28494187,28494189,28494190,28494195,28494195,28494199,28494178,28494180,28494185,28494185,28494186,28494186,28494187,28494189,28494189,28494190,28494192,28494196,28494198,28494200,28494186,28494189,28494190,28494190,28494193,28494196,28494199,28494200,28494181,28494189,28494202,28494192,28494192,28494193,28494185,28494203,28494186,28494196,28494199,28494203,28494187,28494189,28494200,28494187,28494188,28494192,28494198,28494199,28494204,28494190,28494191,28494194,28494197,28494203,28494205,28494201,28494205,28494206,28494193,28494195,28494207,28494196,28494203,28494207,28494207,28494195,28494199,28494205,28494208,28494196,28494197,28494202,28494203,28494204,28494208,28495789,28494199,28494201,28494202,28494203,28494205,28494207,28494208,28494209,28494208,28494210,28494201,28494202,28494202,28494203,28494204,28494207,28494209,28494210,28494211,28495792,28494202,28494203,28494209,28494211,28494203,28494204,28494209,28494212,28494210,28494213,28494206,28494213,28494206,28494208,28494210,28494214,28494210,28494211,28494212,28494212,28494214,28494214,28494210,28494213,28494215,28494211,28494215,28494212,28494216,28494216,28494216,28494217,28494215,28494217,28494217,28494218,28494219,28495800,28494217,28494219,28494219,28494220,28494220,28494220,28494221,28494221,28494222,28494223,28494223,28494224,28494225,28494227,28494229,28494229,28494230,28494232,28494232,28494233,28494235,28494236,28494244,28494248,28494254,28494254,28494257,28494258,28494259,28494260,28494261,28494261,28494262,28494262,28494263,28494263,28495803,29131070,28494226,28494226,28494234,28494234,28494240,28494260,28494261,28494262,28494262,28494263,28494263,28494264,28494225,28494262,28494263,28494264,28494264,28494232,28494265,28494266,28494267,28494266,28494267,28495808,28494269,28494270,28494270,28494271,28494272,28494273,28494271,28494272,28494274,28494275,28494275,28494272,28494271,28494280,28494285,28494287,28494295,28494296,28494297,28494295,28494299,28494300,28494299,28494298,28494300,28494299,28494301,28494301,28494301,28494301,28494302,28494301,28494302,28494302,28494303,28494302,28494303,28494303,28494303,28494304,28495843,28494304,28495844,28494305,28494306,28494307,28494311,28494364,28494747,28495837,28495844,28495844,28495882,28495884,28496919,28495845,28495845,28494749,28495846,28494754,28495851,28494488,28495968,28495196,28495197,28495202,28495219,28495269,28495270,28495275,28495292,28495340,28495345,28495345,28496364,28496369,28496369,28497377,28497383,28497384,28497385,28497385,28497386,28497386,28497387,28497388,28497388,28497393,28497394,28497394,28497395,28497396,28497396,28497399,28497400,28497401,28497405,28497405,28497407,28497409,28497410,28497411,28497411,28497414,28497415,28497420,28497420,28497421,28497421,28497422,28497385,28497386,28497387,28497387,28497388,28497388,28497392,28497394,28497396,28497397,28497404,28497411,28497412,28497418,28497421,28497421,28497422,28497386,28497387,28497388,28497397,28497412,28497418,28497422,28497422,28497388,28497389,28497398,28497413,28497421,28497422,28497422,28497423,28497423,28497412,28497413,28497423,28497423,28497391,28497410,28497414,28497424,28497424,28497400,28497400,28497411,28497425,28497425,28497425,28497428,28497429,28497403,28497405,28497421,28497430,28497431,28497431,28497432,28497434,28497495,28497496,28497432,28497432,28497433,28497433,28497433,28497434,28497437,28497437,28497438,28497436,28497442,28497442,28497443,28497443,28497444,28497445,28497446,28497447,28497447,28497448,28497448,28497448,28497449,28497449,28497449,28497451,28497452,28497453,28497454,28497457,28497457,28497458,28497458,28497459,28497460,28497460,28497461,28497461,28497462,28497462,28497463,28497463,28497464,28497466,28497467,28497467,28497468,28497469,28497469,28497470,28497471,28497471,28497472,28497472,28497473,28497473,28497474,28497475,28497475,28497476,28497477,28497478,28497479,28497480,28497481,28497482,28497483,28497484,28497485,28497485,28497486,28497489,28497495,28497497,28497504,28497523,28497460,28497461,28497461,28497462,28497462,28497463,28497464,28497464,28497465,28497466,28497466,28497467,28497467,28497468,28497468,28497469,28497469,28497470,28497470,28497471,28497471,28497472,28497472,28497473,28497473,28497474,28497475,28497476,28497477,28497477,28497478,28497480,28497481,28497482,28497482,28497484,28497484,28497485,28497488,28497489,28497490,28497494,28497497,28497461,28497462,28497462,28497463,28497463,28497464,28497464,28497468,28497470,28497471,28497472,28497473,28497462,28497463,28497464,28497470,28497471,28497480,28497463,28497464,28497464,28497469,28497470,28497470,28497471,28497471,28497472,28497473,28497474,28497474,28497476,28497477,28497478,28497482,28497464,28497465,28497469,28497469,28497472,28497473,28497475,28497478,28497465,28497466,28497467,28497467,28497469,28497470,28497470,28497471,28497472,28497472,28497473,28497473,28497474,28497475,28497475,28497478,28497487,28497466,28497467,28497467,28497468,28497469,28497470,28497470,28497471,28497472,28497472,28497473,28497473,28497474,28497475,28497476,28497470,28497472,28497474,28497475,28497471,28497472,28497473,28497474,28497470,28497474,28497475,28497475,28497473,28497476,28497476,28497475,28497477,28497475,28497476,28497477,28497480,28497475,28497477,28497477,28497478,28497476,28497477,28497478,28497479,28497478,28497479,28497479,28497479,28497480,28497480,28497481,28497479,28497480,28497481,28497483,28497491,28497480,28497481,28497482,28497483,28497487,28497481,28497482,28497482,28497483,28497483,28497484,28497487,28497488,28497492,28497494,28497482,28497483,28497484,28497486,28497488,28497483,28497484,28497484,28497486,28497487,28497487,28497491,28497484,28497485,28497490,28497493,28497485,28497492,28497494,28497504,28497510,28497486,28497487,28497487,28497488,28497488,28497489,28497489,28497490,28497490,28497491,28497492,28497492,28497495,28497495,28497497,28497502,28497503,28497504,28497510,28497487,28497488,28497488,28497489,28497489,28497491,28497491,28497493,28497496,28497488,28497489,28497489,28497490,28497490,28497491,28497491,28497492,28497493,28497495,28497496,28497498,28497489,28497490,28497490,28497491,28497491,28497492,28497492,28497494,28497495,28497496,28497490,28497491,28497492,28497491,28497492,28497492,28497493,28497493,28497494,28497494,28497495,28497496,28497499,28497500,28497550,28497492,28497493,28497493,28497494,28497494,28497495,28497505,28497513,28497493,28497494,28497494,28497495,28497496,28497502,28497506,28497494,28497495,28497495,28497496,28497496,28497500,28497500,28497501,28497541,28497495,28497496,28497496,28497497,28497501,28497506,28497515,28497541,28497496,28497497,28497497,28497499,28497500,28497500,28497501,28497502,28497504,28497505,28497508,28497512,28497553,28497497,28497498,28497501,28497502,28497508,28497512,28497553,28497498,28497516,28497499,28497500,28497500,28497501,28497501,28497502,28497502,28497503,28497503,28497504,28497504,28497506,28497506,28497507,28497507,28497509,28497509,28497511,28497500,28497501,28497501,28497502,28497502,28497504,28497501,28497502,28497502,28497503,28497503,28497504,28497518,28497502,28497503,28497503,28497504,28497504,28497505,28497505,28497506,28497507,28497508,28497510,28497512,28497515,28497518,28497545,28497858,28497503,28497504,28497504,28497505,28497504,28497505,28497505,28497506,28497506,28497507,28497508,28497511,28497514,28497519,28497546,28497505,28497506,28497506,28497507,28497507,28497508,28497509,28497510,28497516,28497546,28497506,28497507,28497507,28497508,28497507,28497508,28497508,28497510,28497511,28497513,28497513,28497515,28497516,28497517,28497520,28497521,28497508,28497509,28497509,28497510,28497510,28497511,28497513,28497514,28497521,28497559,28497509,28497510,28497510,28497511,28497511,28497512,28497512,28497514,28497514,28497516,28497518,28497518,28497522,28497548,28497668,28497510,28497511,28497511,28497512,28497512,28497513,28497514,28497515,28497519,28497549,28497511,28497512,28497512,28497513,28497513,28497515,28497515,28497517,28497512,28497513,28497513,28497517,28497550,28497513,28497514,28497514,28497515,28497515,28497516,28497516,28497518,28497520,28497524,28497550,28497550,28497514,28497515,28497516,28497517,28497518,28497515,28497516,28497516,28497517,28497518,28497519,28497521,28497525,28497516,28497517,28497517,28497518,28497519,28497522,28497552,28497517,28497518,28497518,28497520,28497526,28497518,28497519,28497519,28497520,28497521,28497521,28497523,28497523,28497524,28497526,28497527,28497553,28497564,28497564,28497520,28497521,28497521,28497522,28497522,28497524,28497525,28497527,28497522,28497524,28497522,28497523,28497524,28497524,28497525,28497525,28497526,28497527,28497529,28497524,28497525,28497525,28497526,28497556,28497525,28497526,28497526,28497556,28497526,28497527,28497527,28497528,28497529,28497529,28497530,28497530,28497531,28497531,28497547,28497558,28497569,28497529,28497530,28497530,28497531,28497531,28497532,28497530,28497531,28497531,28497532,28497532,28497531,28497532,28497532,28497533,28497532,28497533,28497533,28497543,28497560,28497533,28497534,28497534,28497572,28497535,28497536,28497536,28497537,28497537,28497538,28497538,28497539,28497540,28497540,28497541,28497541,28497542,28497542,28497543,28497544,28497544,28497545,28497548,28497548,28497549,28497552,28497553,28497553,28497554,28497556,28497556,28497557,28497558,28497558,28497559,28497561,28497562,28497563,28497564,28497565,28497566,28497566,28497567,28497567,28497568,28497568,28497569,28497569,28497570,28497571,28497571,28497572,28497572,28497703,28497536,28497537,28497537,28497538,28497539,28497540,28497540,28497541,28497541,28497542,28497542,28497543,28497543,28497544,28497544,28497545,28497545,28497546,28497547,28497548,28497548,28497549,28497549,28497550,28497552,28497552,28497553,28497554,28497556,28497557,28497557,28497558,28497559,28497560,28497561,28497562,28497563,28497564,28497564,28497565,28497566,28497566,28497567,28497567,28497569,28497570,28497570,28497571,28497571,28497572,28497572,28497573,28497541,28497543,28497548,28497571,28497572,28497573,28497541,28497542,28497542,28497543,28497555,28497563,28497574,28497542,28497546,28497551,28497563,28497574,28497540,28497544,28497564,28497569,28497575,28497575,28497545,28497566,28497573,28497576,28497545,28497546,28497547,28497548,28497548,28497549,28497566,28497569,28497575,28497577,28497545,28497547,28497570,28497547,28497548,28497548,28497549,28497551,28497554,28497564,28497567,28497570,28497571,28497574,28497577,28497577,28497578,28497562,28497567,28497574,28497575,28497548,28497549,28497550,28497556,28497560,28497561,28497565,28497568,28497577,28497578,28497579,28497549,28497551,28497555,28497559,28497565,28497566,28497568,28497569,28497572,28497577,28497578,28497578,28497579,28497550,28497551,28497556,28497559,28497563,28497569,28497571,28497572,28497573,28497573,28497576,28497577,28497578,28497580,28497689,45021327,28497552,28497563,28497569,28497580,28497553,28497557,28497571,28497581,28497554,28497557,28497558,28497568,28497570,28497573,28497574,28497575,28497580,28497581,28497571,28497580,28497582,28497691,28497556,28497562,28497564,28497576,28497579,28497563,28497572,28497575,28497577,28497581,28497583,28497576,28497584,28497568,28497574,28497563,28497578,28497581,28497573,28497575,28497578,28497580,28497581,28497584,28497585,28497586,28497579,28497583,28497570,28497572,28497578,28497584,28497585,28497586,28497587,28497577,28497580,28497582,28497576,28497589,28497588,28497589,28497576,28497579,28497581,28497584,28497588,28497590,28497591,28497585,28497587,28497591,28497578,28497581,28497580,28497584,28497591,28497582,28497591,28497593,28497583,28497584,28497592,28497583,28497587,28497588,28497595,28497587,28497594,28497596,28497585,28497587,28497589,28497590,28497596,28497588,28497597,28497595,28497597,28497591,28497598,28497587,28497588,28497589,28497589,28497590,28497591,28497592,28497592,28497593,28497593,28497594,28497595,28497596,28497597,28497597,28497598,28497598,28497599,28497589,28497590,28497592,28497598,28497598,28497590,28497591,28497593,28497597,28497598,28497598,28497599,28497599,28497600,28497597,28497599,28497599,28497593,28497595,28497596,28497597,28497600,28497594,28497594,28497600,28497601,28497594,28497595,28497596,28497596,28497597,28497598,28497599,28497600,28497600,28497601,28497601,28497602,28497602,28497597,28497601,28497602,28497603,28497597,28497598,28497599,28497600,28497601,28497602,28497602,28497603,28497603,28497598,28497599,28497600,28497601,28497601,28497602,28497602,28497603,28497604,28497600,28497601,28497602,28497604,28497604,28497604,28497605,28497603,28497605,28497603,28497604,28497604,28497605,28497606,28497606,28497606,28497604,28497605,28497605,28497606,28497606,28497607,28497606,28497606,28497607,28497607,28497606,28497607,28497607,28497608,28497607,28497608,28497608,28497608,28497609,28497609,28497610,28497630,28497674,28497718,28497719,28497741,28497746,28497768,28497769,28497770,28497771,28497772,28497773,28497774,28497775,28497805,28497807,28497912,28497914,28497963,28497964,28497964,28498571,28498606,28499100,28497719,28497719,28497741,28497744,28497924,28497739,28497783,28497827,28497828,28497829,28497830,28497830,28497831,28497832,28497837,28497848,28497848,28497849,28497849,28497850,28497853,28497903,28497849,28497850,28497850,28497831,28497832,28497833,28497845,28497851,28497851,28497852,28497852,28497853,28497853,28497854,28497859,28497864,28497869,28497870,28497870,28497871,28497871,28497872,28497873,28497873,28497874,28497874,28497875,28497876,28497876,28497877,28497878,28497879,28497880,28497880,28497881,28497882,28497882,28497883,28497883,28497884,28497884,28497886,28497886,28497887,28497887,28497888,28497889,28497890,28497891,28497891,28497892,28497892,28497893,28497893,28497894,28497894,28497895,28497895,28497896,28497896,28497897,28497897,28497898,28497898,28497899,28497899,28497900,28497901,28497901,28497902,28497903,28497903,28497904,28497904,28497905,28497905,28497906,28497906,28497908,28497909,28497911,28497912,28497923,28497925,28497925,28497947,28497873,28497875,28497875,28497876,28497877,28497877,28497879,28497885,28497889,28497894,28497895,28497896,28497896,28497898,28497900,28497902,28497904,28497904,28497905,28497919,28497926,28497874,28497875,28497875,28497877,28497877,28497882,28497883,28497887,28497889,28497893,28497893,28497894,28497896,28497898,28497899,28497899,28497902,28497905,28497876,28497877,28497878,28497881,28497883,28497883,28497894,28497895,28497897,28497901,28497876,28497877,28497878,28497878,28497879,28497896,28497897,28497905,28497877,28497878,28497879,28497879,28497880,28497880,28497881,28497882,28497883,28497885,28497886,28497886,28497890,28497891,28497891,28497892,28497895,28497895,28497897,28497897,28497898,28497901,28497904,28497906,28497907,28497909,28497928,28497879,28497879,28497882,28497884,28497901,28497880,28497891,28497898,28497898,28497902,28497903,28497880,28497881,28497886,28497895,28497897,28497898,28497899,28497929,28497881,28497882,28497882,28497883,28497885,28497886,28497889,28497891,28497896,28497896,28497897,28497899,28497900,28497901,28497906,28497907,28497882,28497883,28497883,28497884,28497887,28497891,28497894,28497895,28497896,28497897,28497898,28497899,28497903,28497905,28497906,28497914,28497919,28497930,28497884,28497885,28497891,28497893,28497899,28497884,28497885,28497886,28497887,28497891,28497899,28497906,28497914,28497907,28497888,28497889,28497890,28497897,28497903,28497909,28497912,28497908,28497903,28497919,28497934,28497890,28497891,28497892,28497895,28497900,28497902,28497903,28497906,28497909,28497895,28497902,28497902,28497904,28497910,28497898,28497901,28497902,28497908,28497910,28497914,28497919,28497936,28497936,28497905,28497907,28497919,28497937,28497910,28497912,28497903,28497916,28497916,28497901,28497938,28497907,28497913,28497905,28497908,28497913,28497939,28497914,28497914,28497917,28497909,28497922,28497940,28497915,28497917,28497919,28497920,28497905,28497910,28497941,28497952,28497910,28497914,28497916,28497907,28497909,28497917,28497909,28497911,28497921,28497921,28497916,28497911,28497912,28497913,28497918,28497920,28497922,28497922,28497910,28497914,28497917,28497912,28497917,28497918,28497919,28497919,28497924,28497913,28497914,28497914,28497915,28497919,28497920,28497923,28497923,28497928,28497932,28497944,28497945,28497913,28497915,28497916,28497917,28497918,28497920,28497922,28497923,28497924,28497924,28497942,28497946,28497914,28497918,28497919,28497920,28497921,28497946,28497916,28497916,28497917,28497920,28497921,28497947,28497916,28497917,28497917,28497918,28497920,28497921,28497922,28497923,28497925,28497926,28497926,28497947,28497917,28497918,28497918,28497919,28497920,28497921,28497922,28497922,28497923,28497924,28497925,28497926,28497926,28497927,28497941,28497919,28497921,28497922,28497922,28497923,28497926,28497927,28497928,28497933,28497948,28497919,28497920,28497920,28497921,28497922,28497922,28497923,28497923,28497924,28497925,28497927,28497935,28497942,28497922,28497922,28497923,28497924,28497925,28497926,28497927,28497922,28497923,28497924,28497927,28497950,28497925,28497926,28497928,28497929,28497932,28497923,28497924,28497925,28497925,28497927,28497928,28497929,28497929,28497951,28497924,28497925,28497925,28497926,28497927,28497928,28497930,28497931,28497948,28497951,28497925,28497926,28497926,28497928,28497930,28497930,28497935,28497952,28497926,28497927,28497935,28497952,28497927,28497928,28497929,28497932,28497935,28497953,28497928,28497929,28497929,28497930,28497930,28497931,28497931,28497932,28497932,28497933,28497933,28497934,28497934,28497935,28497936,28497937,28497938,28497938,28497939,28497940,28497942,28497945,28497946,28497948,28497948,28497950,28497953,28497930,28497931,28497932,28497937,28497954,28497930,28497948,28497951,28497931,28497932,28497933,28497933,28497934,28497934,28497935,28497936,28497937,28497938,28497940,28497947,28497948,28497949,28497952,28497953,28497954,28497955,28497932,28497933,28497934,28497947,28497955,28497934,28497935,28497936,28497939,28497941,28497952,28497956,28497934,28497935,28497936,28497939,28497939,28497952,28497956,28497956,28497935,28497936,28497937,28497939,28497939,28497940,28497946,28497954,28497955,28497956,28497957,28497936,28497937,28497939,28497939,28497940,28497941,28497941,28497942,28497947,28497952,28497957,28497957,28497937,28497940,28497944,28497945,28497947,28497952,28497955,28497956,28497957,28497958,28497938,28497939,28497939,28497940,28497941,28497942,28497943,28497950,28497958,28497958,28497940,28497958,28497959,28497943,28497946,28497959,28497945,28497960,28497942,28497960,28497944,28497961,28497944,28497945,28497961,28497961,28497960,28497961,28497962,28497951,28497952,28497954,28497962,28497948,28497963,28497953,28497963,28497953,28497964,28497964,28497965,28498742,28497963,28497965,28497966,28497957,28497967,28497968,28497963,28497964,28497967,28497968,28497968,28497965,28497970,28497971,28497969,28497971,28497972,28497971,28497972,28497972,28497973,28497971,28497973,28497973,28497973,28497974,28497974,28497975,28497975,28497975,28497976,28497976,28497977,28497977,28497978,28497978,28497979,28497980,28497980,28497981,28497982,28497983,28497985,28497986,28497987,28497988,28497989,28497989,28497990,28497991,28497993,28497994,28497996,28497996,28497997,28497997,28497998,28497998,28497999,28497999,28498000,28498000,28498001,28498099,28498105,28498170,28498756,28498790,28499284,28497980,28497981,28497982,28497984,28497985,28497986,28497989,28497990,28497994,28497997,28497998,28497999,28497999,28498000,28498001,28498001,28498000,28498002,28497986,28497994,28497997,28498000,28498000,28498001,28498001,28498002,28498003,28498000,28498002,28498004,28498000,28498005,28497996,28498003,28498007,28497993,28498002,28498003,28498007,28498008,28498002,28498009,28498010,28498009,28498007,28498011,28498002,28498002,28498010,28498011,28498012,28498013,28498013,28498015,28498011,28498016,28498011,28498015,28498014,28498016,28498018,28498016,28498018,28498016,28498017,28498017,28498019,28498017,28498017,28498018,28498018,28498019,28498020,28498018,28498019,28498020,28498019,28498020,28498020,28498021,28498020,28498021,28498021,28498021,28498022,28498022,28498127,28498023,28498024,28498051,28498096,28498118,28498119,28498120,28498121,28498126,28498127,28498127,28498139,28498169,28498171,28498191,28498778,28498812,28498878,28499306,28498097,28498121,28498097,28498119,28498147,28498172,28498191,28498192,28498193,28498194,28498200,28498201,28498194,28498213,28498214,28498215,28498215,28498216,28498216,28498219,28498223,28498215,28498217,28498216,28498217,28498224,28498218,28498218,28498219,28498220,28498220,28498221,28498221,28498222,28498222,28498224,28498225,28498225,28498292,28498220,28498221,28498221,28498225,28498225,28498226,28498221,28498222,28498222,28498223,28498225,28498226,28498226,28498222,28498223,28498226,28498227,28498223,28498227,28498227,28498225,28498226,28498227,28498227,28498228,28498228,28498228,28498228,28498228,28498229,28498230,28498230,28498231,28498231,28498232,28498233,28498233,28498234,28498234,28498235,28498235,28498236,28498236,28498237,28498238,28498238,28498239,28498239,28498240,28498241,28498242,28498243,28498243,28498244,28498244,28498246,28498247,28498247,28498248,28498249,28498250,28498251,28498252,28498252,28498253,28498253,28498254,28498254,28498255,28498255,28498256,28498256,28498257,28498258,28498258,28498259,28498259,28498260,28498265,28498266,28498269,28498273,28498273,28498274,28498274,28498275,28498275,28498276,28498277,28498278,28498280,28498297,28498298,28498299,28498302,28498303,28498307,28498233,28498234,28498234,28498235,28498235,28498237,28498237,28498238,28498238,28498240,28498243,28498247,28498250,28498252,28498255,28498256,28498259,28498274,28498275,28498276,28498299,28498234,28498235,28498235,28498237,28498247,28498277,28498299,28498235,28498236,28498236,28498237,28498241,28498250,28498251,28498254,28498255,28498258,28498276,28498278,28498236,28498237,28498237,28498238,28498238,28498239,28498239,28498240,28498240,28498241,28498242,28498245,28498246,28498252,28498255,28498260,28498268,28498276,28498278,28498300,28498237,28498238,28498238,28498239,28498239,28498240,28498240,28498241,28498241,28498242,28498242,28498243,28498245,28498246,28498247,28498247,28498249,28498249,28498251,28498253,28498254,28498255,28498256,28498257,28498258,28498260,28498261,28498261,28498264,28498266,28498269,28498276,28498277,28498278,28498279,28498279,28498300,28498301,28498310,28498238,28498239,28498239,28498240,28498240,28498241,28498241,28498243,28498244,28498246,28498251,28498253,28498254,28498257,28498258,28498259,28498259,28498261,28498264,28498266,28498277,28498279,28498301,28498310,28498239,28498240,28498240,28498241,28498241,28498242,28498242,28498245,28498245,28498246,28498247,28498247,28498248,28498250,28498254,28498254,28498255,28498255,28498256,28498257,28498257,28498258,28498259,28498260,28498261,28498262,28498262,28498267,28498270,28498277,28498277,28498280,28498281,28498302,28498311,28498240,28498248,28498256,28498274,28498280,28498302,28498241,28498242,28498242,28498243,28498244,28498246,28498247,28498252,28498253,28498255,28498256,28498257,28498259,28498259,28498261,28498262,28498265,28498272,28498278,28498281,28498284,28498300,28498303,28498242,28498243,28498243,28498245,28498259,28498262,28498266,28498284,28498243,28498244,28498244,28498245,28498245,28498247,28498248,28498250,28498252,28498253,28498254,28498256,28498256,28498261,28498262,28498263,28498264,28498265,28498266,28498267,28498269,28498271,28498282,28498304,28498244,28498245,28498246,28498248,28498248,28498250,28498252,28498253,28498254,28498255,28498256,28498257,28498261,28498263,28498265,28498266,28498268,28498270,28498279,28498282,28498286,28498304,28498246,28498247,28498251,28498253,28498254,28498255,28498257,28498258,28498258,28498259,28498261,28498262,28498263,28498263,28498265,28498272,28498280,28498283,28498305,28498248,28498249,28498263,28498283,28498287,28498305,28498247,28498249,28498252,28498258,28498259,28498261,28498262,28498264,28498284,28498306,28498249,28498250,28498255,28498256,28498257,28498259,28498260,28498261,28498263,28498265,28498265,28498266,28498268,28498280,28498284,28498287,28498264,28498307,28498252,28498254,28498258,28498264,28498273,28498283,28498317,28498254,28498255,28498259,28498262,28498265,28498268,28498284,28498286,28498255,28498266,28498286,28498260,28498262,28498264,28498265,28498267,28498285,28498287,28498291,28498267,28498268,28498290,28498310,28498269,28498288,28498310,28498313,28498258,28498262,28498263,28498263,28498264,28498267,28498268,28498271,28498272,28498273,28498307,28498311,28498264,28498287,28498271,28498312,28498278,28498263,28498265,28498274,28498282,28498288,28498313,28498322,28498270,28498273,28498281,28498288,28498313,28498271,28498273,28498282,28498319,28498274,28498282,28498298,28498314,28498272,28498274,28498289,28498315,28498933,28498272,28498272,28498274,28498281,28498292,28498293,28498315,28498271,28498274,28498283,28498291,28498294,28498309,28498275,28498293,28498316,28498269,28498272,28498276,28498276,28498279,28498291,28498317,28498270,28498271,28498272,28498272,28498273,28498274,28498276,28498277,28498284,28498292,28498297,28498274,28498276,28498279,28498280,28498280,28498281,28498283,28498283,28498318,28498274,28498274,28498279,28498281,28498294,28498295,28498318,28498318,28498274,28498275,28498294,28498296,28498299,28498319,28498277,28498278,28498280,28498296,28498297,28498326,28498277,28498278,28498280,28498287,28498294,28498295,28498295,28498296,28498296,28498297,28498298,28498320,28498325,28498329,28498277,28498277,28498278,28498297,28498298,28498320,28498904,28498277,28498280,28498281,28498282,28498296,28498306,28498321,28498278,28498280,28498281,28498282,28498282,28498283,28498284,28498297,28498297,28498298,28498299,28498312,28498321,28498279,28498282,28498283,28498294,28498298,28498299,28498300,28498322,28498281,28498282,28498282,28498283,28498283,28498292,28498295,28498297,28498298,28498300,28498322,28498331,28498281,28498282,28498292,28498298,28498299,28498299,28498300,28498301,28498323,28498283,28498284,28498286,28498290,28498298,28498299,28498300,28498300,28498301,28498304,28498323,28498283,28498284,28498284,28498297,28498298,28498299,28498302,28498318,28498324,28498284,28498289,28498290,28498292,28498298,28498300,28498302,28498324,28498286,28498286,28498288,28498290,28498299,28498300,28498300,28498301,28498302,28498303,28498308,28498325,28498287,28498290,28498300,28498300,28498301,28498303,28498325,28498288,28498290,28498300,28498300,28498301,28498304,28498326,28498292,28498302,28498304,28498309,28498291,28498302,28498306,28498326,28498327,28498292,28498303,28498305,28498327,28498327,28498297,28498306,28498305,28498306,28498311,28498298,28498303,28498304,28498305,28498307,28498308,28498305,28498305,28498306,28498308,28498313,28498330,28498330,28498305,28498331,28498307,28498309,28498310,28498332,28498316,28498332,28498333,28498309,28498311,28498312,28498334,28498312,28498334,28498337,28498315,28498337,28498317,28498314,28498317,28498338,28498339,28498314,28498315,28498316,28498316,28498317,28498320,28498320,28498339,28498315,28498316,28498316,28498318,28498319,28498337,28498340,28498316,28498317,28498317,28498318,28498319,28498320,28498322,28498335,28498336,28498337,28498339,28498340,28498318,28498319,28498339,28498341,28498318,28498319,28498320,28498321,28498341,28498342,28498320,28498322,28498323,28498323,28498326,28498332,28498339,28498340,28498342,28498321,28498322,28498322,28498323,28498323,28498324,28498324,28498325,28498325,28498326,28498326,28498327,28498331,28498334,28498335,28498335,28498337,28498339,28498340,28498341,28498341,28498342,28498342,28498343,28498348,28498352,28498343,28498325,28498330,28498342,28498344,28498324,28498325,28498344,28498344,28498345,28498328,28498345,28498329,28498332,28498340,28498345,28498346,28498355,28498329,28498346,28498343,28498347,28498347,28498345,28498347,28498348,28498348,28498348,28498347,28498349,28498350,28498351,28498351,28498350,28498354,28498354,28498356,28498357,28498357,28498358,28498359,28498359,28498360,28498360,28498360,28498361,28498362,28498361,28498362,28498363,28498363,28498364,28498371,28498372,28498364,28498369,28498364,28498365,28498366,28498366,28498367,28498367,28498368,28498368,28498369,28498369,28498370,28498370,28498371,28498372,28498372,28498373,28498373,28498374,28498949,28498983,28499477,28499515,28498366,28498367,28498367,28498368,28498369,28498369,28498370,28498370,28498371,28498372,28498372,28498373,28498373,28498374,28498374,28498986,28498367,28498369,28498370,28498371,28498372,28498373,28498374,28498375,28498369,28498370,28498374,28498374,28498375,28498372,28498376,28498371,28498372,28498374,28498375,28498375,28498376,28498375,28498377,28498377,28498373,28498374,28498376,28498378,28498374,28498376,28498377,28498378,28498378,28498376,28498376,28498377,28498377,28498378,28498378,28498379,28498988,28498379,28498380,28498378,28498379,28498380,28498380,28498379,28498380,28498380,28498381,28498380,28498381,28498381,28498381,28498382,28498382,28498383,28498384,28498394,28498395,28498423,28498957,28498958,28498992,28498992,28499008,28499011,28499393,28499486,28499846,38968444,45021744,28498958,28498958,28498959,28498969,28498970,28498802,28499219,28499415,28499532,28499533,28499534,28499534,28499535,28499535,28499537,28499537,28499538,28499542,28499543,28499543,28499544,28499556,28499561,28499565,28499566,28499566,28499567,28499567,28499568,28499608,28499534,28499535,28499536,28499538,28499542,28499567,28499567,28499568,28499544,28499567,28499567,28499568,28499568,28499537,28499568,28499537,28499569,28499538,28499539,28499547,28499548,28499569,28499570,28499570,28499571,28499571,28499572,28499576,28499553,28499553,28499578,28499644,28500072,28499556,28499579,28499579,28499579,28499590,28499596,28499599,28499600,28499600,28499600,28499600,28499601,28499601,28499602,28499603,28499603,28499604,28499604,28499605,28499605,28499606,28499607,28499607,28499608,28499609,28499610,28499610,28499611,28499612,28499612,28499614,28499616,28499616,28499617,28499617,28499618,28499618,28499619,28499619,28499620,28499620,28499621,28499621,28499622,28499622,28499623,28499623,28499624,28499624,28499625,28499625,28499626,28499627,28499628,28499628,28499629,28499629,28499630,28499630,28499631,28499632,28499633,28499634,28499635,28499636,28499637,28499638,28499638,28499639,28499640,28499640,28499641,28499642,28499643,28499648,28499648,28499603,28499604,28499605,28499605,28499606,28499607,28499610,28499611,28499611,28499612,28499615,28499617,28499617,28499618,28499618,28499619,28499620,28499620,28499621,28499621,28499622,28499623,28499623,28499624,28499624,28499625,28499625,28499627,28499629,28499630,28499630,28499635,28499636,28499641,28499643,28499643,28499604,28499608,28499610,28499616,28499618,28499619,28499619,28499622,28499624,28499625,28499629,28499638,28499639,28499607,28499608,28499611,28499613,28499619,28499619,28499620,28499620,28499622,28499624,28499630,28499606,28499611,28499615,28499621,28499626,28499627,28499628,28499620,28499623,28499626,28499610,28499616,28499624,28499622,28499625,28499619,28499622,28499624,28499626,28499628,28499629,28499623,28499634,28499623,28499618,28499624,28499625,28499625,28499627,28499628,28499629,28499633,28499643,28499619,28499626,28499626,28499626,28499625,28499626,28499627,28499630,28499635,28499627,28499627,28499628,28499628,28499637,28499632,28499639,28499631,28499639,28499644,28499655,28499639,28499655,28499642,28499657,28499632,28499632,28499633,28499637,28499640,28499643,28499644,28499632,28499633,28499634,28499634,28499639,28499641,28499643,28499643,28499645,28499654,28499658,28499633,28499634,28499634,28499635,28499636,28499636,28499637,28499637,28499638,28499638,28499639,28499639,28499640,28499642,28499644,28499644,28499645,28499646,28499648,28499649,28499653,28499658,28499634,28499635,28499635,28499636,28499636,28499637,28499637,28499638,28499638,28499639,28499639,28499640,28499640,28499642,28499642,28499643,28499644,28499645,28499645,28499647,28499649,28499652,28499656,28499658,28499659,28499635,28499636,28499637,28499637,28499638,28499638,28499639,28499639,28499640,28499641,28499641,28499642,28499643,28499645,28499645,28499646,28499647,28499659,28499636,28499637,28499637,28499638,28499638,28499639,28499640,28499640,28499641,28499642,28499643,28499643,28499644,28499645,28499646,28499647,28499660,28499637,28499638,28499638,28499639,28499639,28499640,28499641,28499644,28499648,28499650,28499657,28499660,28499639,28499639,28499640,28499640,28499642,28499642,28499643,28499645,28499646,28499647,28499647,28499648,28499649,28499653,28499655,28499661,28499639,28499640,28499641,28499641,28499642,28499643,28499643,28499644,28499645,28499645,28499647,28499648,28499648,28499651,28499655,28499661,28499640,28499641,28499641,28499642,28499642,28499643,28499644,28499644,28499645,28499647,28499648,28499650,28499651,28499654,28499659,28499662,45022372,28499641,28499642,28499643,28499643,28499644,28499644,28499646,28499646,28499647,28499648,28499650,28499651,28499652,28499654,28499658,28499658,28499660,28499661,28499662,28499662,28499642,28499643,28499644,28499644,28499645,28499645,28499646,28499648,28499649,28499663,28499643,28499644,28499644,28499645,28499645,28499646,28499646,28499647,28499647,28499649,28499649,28499651,28499651,28499654,28499655,28499656,28499657,28499657,28499659,28499660,28499663,28499663,28500071,28500116,28499644,28499645,28499646,28499647,28499647,28499648,28499649,28499650,28499659,28499659,28499661,28499663,28499664,28499646,28499646,28499647,28499650,28499650,28499651,28499657,28499664,28499646,28499647,28499647,28499648,28499649,28499650,28499651,28499652,28499652,28499657,28499661,28499665,28500025,28499647,28499648,28499649,28499649,28499650,28499651,28499651,28499652,28499653,28499654,28499656,28499665,28500118,28499648,28499649,28499650,28499650,28499651,28499652,28499654,28499662,28499663,28499665,28499666,28499650,28499650,28499652,28499652,28499653,28499654,28499655,28499658,28499659,28499661,28499666,28499666,28499651,28499653,28499665,28499667,28499651,28499652,28499653,28499653,28499654,28499654,28499656,28499658,28499658,28499662,28499667,28499652,28499653,28499654,28499654,28499655,28499655,28499657,28499659,28499663,28499663,28499664,28499665,28499665,28499668,28500480,28499654,28499654,28499656,28499668,28499661,28499669,28499655,28499656,28499656,28499657,28499658,28499659,28499660,28499661,28499663,28499663,28499665,28499665,28499666,28499667,28499668,28499669,28499669,28499694,28499656,28499657,28499657,28499658,28499658,28499660,28499661,28499661,28499662,28499663,28499665,28499665,28499666,28499666,28499667,28499668,28499669,28499670,28500123,28499657,28499658,28499660,28499662,28499664,28499666,28499670,28499670,28499660,28499661,28499663,28499664,28499665,28499667,28499668,28499668,28499671,28499659,28499661,28499663,28499664,28499664,28499665,28499666,28499670,28499671,28499676,28499661,28499668,28499670,28499671,28499672,28499664,28499672,28499672,28499666,28499672,28499665,28499667,28499667,28499668,28499670,28499673,28499673,28499665,28499667,28499670,28499674,28499667,28499671,28499674,28499667,28499667,28499668,28499669,28499675,28499667,28499668,28499672,28499675,28500128,28499669,28499670,28499671,28499672,28499673,28499673,28499675,28499676,28499676,28499672,28499672,28499673,28499674,28499674,28499677,28499671,28499672,28499675,28499677,28499674,28499675,28499676,28499677,28499678,28499676,28499678,28499675,28499678,28499678,28499679,28499675,28499679,28499679,28499700,28500132,28499676,28499677,28499678,28499680,28499678,28499679,28499679,28499680,28499680,28500040,28500133,28499679,28499680,28499681,28499683,28499715,28500134,28499681,28499681,28499680,28499682,28499682,28499683,28499683,28499689,28499684,28499685,28499685,28499686,28499686,28499687,28499687,28499688,28499688,28499689,28499689,28499690,28499690,28499691,28499691,28499692,28499693,28499695,28499696,28499698,28499700,28499700,28499701,28499702,28499702,28499703,28499703,28499704,28499704,28499705,28499706,28499708,28499709,28499710,28499711,28499712,28499713,28499714,28499715,28499715,28499716,28499716,28499717,28499717,28499718,28499718,28499900,28500043,28500095,28500137,28501180,28874847,35132081,38969094,28499685,28499686,28499686,28499687,28499687,28499688,28499689,28499689,28499690,28499691,28499691,28499692,28499699,28499700,28499700,28499701,28499703,28499704,28499712,28499713,28499715,28499715,28499716,28499717,28499717,28499718,28499718,28499719,28499692,28499719,28499687,28499690,28499691,28499692,28499705,28499719,28499720,28499689,28499689,28499720,28499691,28499693,28499712,28499714,28499719,28499720,28499721,28499692,28499693,28499694,28499702,28499703,28499721,28500140,28499695,28499698,28499713,28499720,28499722,28499713,28499693,28499694,28499695,28499696,28499702,28499716,28499716,28499718,28499720,28499721,28499722,28499723,28500141,28499694,28499695,28499696,28499696,28499698,28499701,28499705,28499706,28499714,28499716,28499722,28499722,28499723,28499723,28500142,28499695,28499696,28499696,28499697,28499702,28499703,28499706,28499710,28499723,28499723,28499724,28500142,28499697,28499697,28499724,28499724,28500143,28499697,28499703,28499706,28499707,28499725,28500143,28499698,28499699,28499699,28499704,28499704,28499706,28499713,28499716,28499718,28499719,28499720,28499722,28499723,28499723,28499724,28499725,28499725,28499709,28499716,28499717,28499721,28499722,28499723,28499723,28499725,28499725,28499726,28499712,28499717,28499727,28499727,28499721,28499728,28499730,28499728,28499731,28499724,28499731,28499716,28499732,28499714,28499732,28499733,28499733,28499734,28499719,28499733,28499734,28499734,28499734,28499735,28499722,28499735,28499736,28499735,28499736,28499737,28499726,28499737,28499736,28499738,28499738,28499738,28499739,28499739,28500158,28499739,28499741,28499736,28499733,28499741,28499742,28499743,28499743,28499742,28499743,28499738,28499739,28499744,28499740,28499739,28499743,28499745,28499745,28499746,28499741,28499743,28499744,28499745,28499746,28499746,28499746,28499747,28499745,28499746,28499747,28499747,28499748,28499747,28499748,28499749,28499746,28499749,28499747,28499748,28499749,28499749,28499750,28499749,28499750,28499750,28499750,28499751,28499750,28499751,28499751,28499751,28499752,28499752,28499753,28499754,28499754,28499769,28499819,28499883,28499887,28500076,28500077,28500078,28500079,28500125,28500126,28500127,28500128,28500130,28500134,28500136,28500171,28500209,28500230,28500531,28501215,35132116,38032002,38969129,28499887,28500076,28500077,28500079,28500172,28500079,28500078,28500080,28500173,28500095,28500143,28500089,28500092,28500093,28500140,28500282,28500284,28500377,28500283,28500284,28500400,28500401,28500402,28500475,28500475,28500405,28500405,28500450,28500452,28500453,28500453,28500454,28500456,28500456,28500457,28500457,28500469,28500476,28500477,28500477,28500477,28500478,28500459,28500478,28500523,28500524,28500505,28500525,28500511,28500526,28500526,28500505,28500507,28500526,28500527,28500527,28500528,28500529,28500529,28500530,28500530,28500513,28500532,28500533,28500535,28500542,28500549,28500569,28500550,28500569,28500570,28500606,28500570,28500589,28500590,28500591,28500591,28500592,28500592,28500593,28500593,28500594,28500594,28500595,28500595,28500598,28500599,28500600,28500601,28500607,28500611,28500612,28500618,28500621,28500622,28500624,28500625,28500626,28500626,28500627,28500627,28500628,28500632,28500591,28500593,28500596,28500600,28500600,28500628,28500628,28500593,28500594,28500594,28500595,28500627,28500628,28500629,28500594,28500600,28500601,28500628,28500629,28500629,28500629,28500629,28500628,28500630,28500596,28500614,28500630,28500631,28500630,28500631,28500631,28500629,28500631,28500632,28500633,28500633,28500633,28500633,28500635,28500636,28500609,28500610,28500637,28500638,28500612,28500638,28500647,28500653,28500658,28500703,28500703,28500960,28500991,28501010,28501644,28501677,28501695,28875311,28988691,29134264,31383497,28500638,28500614,28500639,28500704,28500641,28500645,28500642,28500649,28500649,28500650,28500656,28500658,28500659,28500660,28500662,28500662,28500663,28500663,28500664,28500664,28500678,28500703,28500664,28500665,28500665,28500666,28500667,28500667,28500668,28500668,28500669,28500670,28500671,28500672,28500673,28500673,28500674,28500674,28500675,28500675,28500676,28500676,28500677,28500677,28500678,28500678,28500679,28500679,28500680,28500680,28500681,28500681,28500682,28500682,28500683,28500683,28500684,28500684,28500685,28500685,28500686,28500687,28500689,28500690,28500690,28500691,28500692,28500692,28500693,28500695,28500697,28500699,28500700,28500701,28500701,28500703,28500703,28500667,28500668,28500669,28500669,28500671,28500672,28500674,28500675,28500675,28500677,28500678,28500678,28500679,28500679,28500680,28500680,28500682,28500682,28500683,28500685,28500685,28500690,28500701,28500703,28500704,28500669,28500671,28500674,28500679,28500680,28500682,28500687,28500682,28500672,28500677,28500681,28500680,28500682,28500678,28500681,28500682,28500682,28500676,28500679,28500681,28500682,28500682,28500683,28500684,28500684,28500686,28500688,28500689,28500703,28500708,28500683,28500684,28500686,28500687,28500685,28500704,28500684,28500705,28500681,28500685,28500687,28500690,28500685,28500711,28500683,28500686,28500688,28500694,28500711,28500686,28500688,28500690,28500693,28500701,28500712,28500684,28500686,28500687,28500687,28500692,28500712,28500687,28500688,28500689,28500691,28500713,28500688,28500689,28500690,28500714,28500689,28500690,28500714,28500689,28500691,28500693,28500694,28500690,28500691,28500691,28500692,28500693,28500693,28500694,28500696,28500696,28500697,28500697,28500699,28500699,28500702,28500703,28500704,28500704,28500705,28500707,28500712,28500713,28500714,28500715,28500691,28500692,28500692,28500693,28500694,28500694,28500695,28500695,28500696,28500697,28500697,28500698,28500699,28500700,28500701,28500703,28500707,28500715,28500716,28500692,28500693,28500694,28500695,28500697,28500698,28500698,28500699,28500702,28500702,28500704,28500705,28500715,28500716,28500716,28500693,28500694,28500694,28500695,28500695,28500696,28500696,28500697,28500697,28500698,28500699,28500699,28500700,28500700,28500701,28500702,28500703,28500703,28500704,28500705,28500705,28500706,28500707,28500708,28500710,28500710,28500712,28500712,28500715,28500716,28500716,28500717,28500694,28500695,28500695,28500696,28500696,28500697,28500699,28500700,28500705,28500705,28500706,28500706,28500708,28500713,28500716,28500717,28500717,28500696,28500699,28500705,28500707,28500709,28500696,28500697,28500697,28500698,28500698,28500699,28500700,28500701,28500701,28500702,28500702,28500703,28500704,28500704,28500705,28500705,28500706,28500707,28500707,28500708,28500716,28500718,28500698,28500698,28500699,28500699,28500700,28500700,28500701,28500702,28500702,28500703,28500704,28500704,28500705,28500705,28500706,28500707,28500707,28500708,28500709,28500718,28500719,28500698,28500699,28500700,28500700,28500701,28500701,28500702,28500703,28500703,28500705,28500706,28500707,28500708,28500713,28500719,28500719,28500699,28500700,28500700,28500701,28500701,28500702,28500703,28500703,28500704,28500706,28500708,28500710,28500713,28500719,28500720,28500700,28500702,28500702,28500703,28500703,28500704,28500706,28500707,28500710,28500711,28500720,28500701,28500703,28500704,28500704,28500705,28500706,28500711,28500714,28500720,28500720,28500721,28500703,28500704,28500704,28500708,28500710,28500721,28500703,28500704,28500704,28500705,28500705,28500708,28500709,28500710,28500710,28500715,28500721,28500722,28500704,28500705,28500705,28500706,28500708,28500708,28500709,28500710,28500711,28500712,28500713,28500719,28500720,28500721,28500722,28500722,28500706,28500706,28500707,28500708,28500709,28500714,28500716,28500718,28500719,28500723,28500706,28500707,28500707,28500709,28500709,28500710,28500710,28500711,28500712,28500712,28500713,28500716,28500718,28500719,28500720,28500721,28500722,28500723,28500723,28500707,28500708,28500708,28500710,28500710,28500711,28500712,28500714,28500715,28500719,28500720,28500721,28500722,28500723,28500724,28500708,28500709,28500710,28500710,28500711,28500711,28500712,28500713,28500716,28500717,28500720,28500724,28500724,28500709,28500711,28500713,28500723,28500724,28500725,28500711,28500711,28500712,28500716,28500725,28500712,28500712,28500713,28500713,28500714,28500715,28500716,28500718,28500722,28500726,28500726,28500713,28500714,28500715,28500715,28500717,28500718,28500720,28500720,28500722,28500724,28500727,28500714,28500715,28500716,28500716,28500717,28500718,28500720,28500724,28500725,28500726,28500727,28500727,28500716,28500716,28500717,28500718,28500719,28500725,28500725,28500728,28500717,28500719,28500724,28500728,28500717,28500719,28500720,28500724,28500727,28500727,28500728,28500729,28500719,28500722,28500726,28500727,28500728,28500729,28500729,28500720,28500721,28500721,28500725,28500725,28500727,28500729,28500730,28501073,28500722,28500724,28500726,28500727,28500728,28500729,28500730,28500731,28501728,28500731,28500725,28500729,28500731,28500732,28500727,28500728,28500729,28500732,28500732,28500733,28500730,28500727,28500728,28500731,28500733,28500734,28500728,28500732,28500734,28500734,28500729,28500732,28500734,28500735,28500731,28500733,28500736,28500734,28500735,28500736,28500736,28500736,28500737,28500735,28500736,28500737,28500736,28500737,28500738,28500738,28500738,28500738,28500739,28500739,28500739,28500739,28500740,28500740,28500741,28500742,28500742,28500743,28500743,28500745,28500745,28500746,28500747,28500748,28500748,28500750,28500751,28500751,28500753,28500756,28500763,28500763,28500767,28500768,28500769,28500770,28500772,28500773,28500773,28500775,28500775,28500776,28500776,28500777,28500777,28500778,28500778,28500779,28501025,28501050,28501050,28501709,28501738,28501740,29134329,28500742,28500743,28500743,28500744,28500744,28500746,28500747,28500747,28500748,28500748,28500749,28500749,28500750,28500752,28500754,28500755,28500757,28500758,28500762,28500763,28500764,28500768,28500769,28500770,28500771,28500771,28500772,28500773,28500773,28500774,28500775,28500775,28500776,28500776,28500777,28500777,28500778,28500778,28500779,28500779,28500747,28500749,28500749,28500750,28500750,28500752,28500753,28500776,28500777,28500779,28500779,28500780,28500745,28500749,28500749,28500776,28500777,28500778,28500780,28500780,28500748,28500759,28500781,28501052,28500780,28500781,28500749,28500781,28500749,28500783,28500752,28500754,28500783,28500783,28500777,28500754,28500756,28500759,28500776,28500782,28500783,28500784,28500784,28500784,28500756,28500758,28500763,28500783,28500784,28500785,28500756,28500757,28500781,28500785,28500786,28500757,28500758,28500761,28500785,28500758,28500787,28500780,28500782,28500785,28500786,28500760,28500768,28500783,28500787,28500787,28500788,28500779,28500784,28500787,28500787,28500788,28500789,28500779,28500789,28500788,28500790,28500788,28500789,28500790,28500790,28500791,28500791,28500792,28500794,28500787,28500791,28500793,28500795,28500792,28500800,28500795,28500799,28500800,28500801,28500793,28500794,28500805,28500795,28500806,28500804,28500806,28500806,28500806,28500807,28500807,28500808,28500805,28500807,28500802,28500809,28500809,28500810,28500808,28500810,28500807,28500810,28500809,28500809,28500810,28500811,28500811,28500810,28500811,28500811,28500812,28500810,28500812,28500812,28500811,28500812,28500812,28500813,28500813,28500813,28500813,28500814,28500812,28500813,28500813,28500814,28500814,28500813,28500814,28500814,28500815,28500814,28500815,28500815,28500815,28500816,28500816,28500817,28500818,28501062,28501063,28501088,28501089,28501090,28501113,28501115,28501116,28501122,28501747,28501769,28501776,28501779,28501785,28501800,28595045,28875413,28875414,28988796,38969661,28501063,28501088,28501064,28501308,28501309,28501310,28501310,28501311,28501311,28501315,28501319,28501320,28501326,28501330,28501331,28501333,28501333,28501334,28501310,28501312,28501315,28501334,28501334,28501316,28501321,28501334,28501335,28501316,28501335,28501336,28501335,28501336,28501336,28501339,28501339,28501340,28501330,28501332,28501332,28501335,28501345,28501370,28502004,28502033,28502036,28502059,28775230,28875669,28875671,29498404,31584813,31584813,28501336,28502034,28501349,29134628,28501351,28501355,28501355,28501356,28501357,28501357,28501358,28501358,28501359,28501360,28501360,28501361,28501361,28501362,28501362,28501363,28501364,28501364,28501365,28501367,28501367,28501368,28501369,28501369,28501370,28501370,28501372,28501374,28501375,28501375,28501376,28501376,28501377,28501377,28501378,28501378,28501379,28501379,28501380,28501380,28501381,28501381,28501382,28501382,28501383,28501383,28501384,28501384,28501385,28501385,28501386,28501386,28501387,28501388,28501388,28501389,28501390,28501391,28501391,28501392,28501392,28501393,28501394,28501395,28501398,28501399,28501405,28501407,28501409,28501409,28501434,28501362,28501364,28501364,28501366,28501368,28501376,28501376,28501377,28501380,28501384,28501389,28501390,28501392,28501408,28501409,28501410,28501363,28501367,28501373,28501373,28501380,28501383,28501385,28501394,28501410,28501379,28501381,28501389,28501363,28501364,28501378,28501385,28501411,28501366,28501367,28501369,28501372,28501380,28501380,28501381,28501381,28501382,28501384,28501385,28501386,28501386,28501388,28501388,28501389,28501394,28501395,28501412,28501367,28501387,28501387,28501396,28501382,28501387,28501387,28501376,28501382,28501412,28501374,28501381,28501389,28501396,28501414,28501414,28501388,28501389,28501415,28501385,28501390,28501391,28501394,28501373,28501391,28501383,28501387,28501390,28501388,28501416,28501418,28501418,28501394,28501396,28501419,28501387,28501394,28501420,28501395,28501420,28501395,28501397,28501420,28501397,28501424,28501398,28501399,28501425,28501399,28501400,28501394,28501400,28501406,28501408,28501410,28501400,28501401,28501408,28501427,28501406,28501396,28501402,28501409,28501428,28501403,28501405,28501408,28501415,28501428,28501403,28501408,28501409,28501400,28501403,28501404,28501408,28501409,28501429,28501404,28501404,28501406,28501410,28501428,28501430,28501404,28501405,28501406,28501409,28501412,28501430,28501405,28502039,28501407,28501429,28501405,28501408,28501432,28501407,28501407,28501410,28501411,28501413,28501433,33437585,28501408,28501412,28501415,28501416,28501419,28501429,28501433,28501408,28501410,28501411,28501415,28501433,28501434,28501409,28501410,28501410,28501411,28501411,28501412,28501413,28501413,28501414,28501415,28501415,28501416,28501417,28501418,28501424,28501424,28501427,28501429,28501430,28501430,28501431,28501432,28501432,28501434,28501434,28501410,28501411,28501411,28501413,28501416,28501417,28501417,28501435,28931396,28501411,28501412,28501413,28501418,28501422,28501427,28501435,28502044,28501413,28501414,28501414,28501418,28501419,28501421,28501430,28501432,28501434,28501436,28501413,28501415,28501418,28501431,28501434,28501436,28501414,28501415,28501416,28501417,28501417,28501420,28501420,28501429,28501435,28501436,28501437,28501437,28501421,28501428,28501436,28501438,28501417,28501418,28501428,28501438,28501420,28501423,28501439,28501439,28501422,28501427,28501437,28501440,28501430,28501432,28501440,28501423,28501425,28501426,28501438,28501439,28501441,28501425,28501432,28501442,28501425,28501426,28501432,28501440,28501442,28501442,28501434,28501441,28501443,28501433,28501437,28501441,28501441,28501442,28501443,28501444,28501444,28501445,28501445,28501436,28501446,28501446,28501434,28501447,28501448,28501447,28501449,28501449,28501447,28501448,28501450,28501450,28501451,28501452,28501453,28501452,28502062,28501451,28501454,28501453,28501455,28501455,28501456,28501456,28501457,28501457,28501457,28501458,28502066,28501458,28501459,28501460,28501461,28501461,28501462,28501465,28501466,28501468,28501469,28501471,28501477,28501480,28501481,28501482,28501483,28501483,28501484,28501484,28501485,28502068,28502097,28502105,28502106,28875734,28875735,28989110,31584877,28501461,28501462,28501468,28501471,28501482,28501483,28501483,28501484,28501484,28501485,28501485,28501483,28501485,28501485,28501486,28501465,28501486,28501487,28501486,28501490,28501491,28501491,28501492,28501492,28501492,28501494,28501493,28501496,28501499,28501504,28501504,28501505,28501506,28501506,28501504,28501505,28501506,28501506,28501507,28501507,28501507,28501507,28501508,28501507,28501508,28501508,28501509,28502092,28501509,28501510,28501511,28501530,28501554,28501556,28502093,28502093,28502122,28502126,28502148,28875759,28875760,28989132,28989141,28989145,28989146,29134713,34125159,38970007,38970041,28502094,28502094,28502113,28501600,28502139,28502676,28502677,28502678,28502678,28502679,28502679,28502681,28502699,28502704,28502705,28502705,28502706,28502733,28502752,28502706,28502706,28502706,28502707,28502707,28502707,28502707,28502708,28502708,28502710,28502727,28502737,28502733,28502733,28502734,28502734,28502781,28502735,28502736,28502736,28502737,28502737,28502738,28502739,28502739,28502740,28502740,28502741,28502741,28502742,28502742,28502743,28502743,28502744,28502744,28502745,28502746,28502746,28502748,28502748,28502750,28502751,28502752,28502753,28502754,28502754,28502755,28502756,28502756,28502757,28502757,28502758,28502758,28502759,28502759,28502760,28502761,28502762,28502762,28502763,28502763,28502773,28502778,28502779,28502779,28502781,28502781,28502737,28502737,28502739,28502739,28502740,28502741,28502742,28502744,28502757,28502759,28502781,28502782,28502737,28502739,28502757,28502760,28502760,28502761,28502740,28502759,28502762,28502740,28502741,28502743,28502743,28502744,28502746,28502755,28502757,28502758,28502758,28502759,28502759,28502760,28502761,28502765,28502783,28502743,28502742,28502743,28502743,28502744,28502744,28502745,28502745,28502746,28502746,28502747,28502747,28502750,28502759,28502759,28502760,28502761,28502761,28502762,28502762,28502763,28502764,28502765,28502766,28502766,28502767,28502768,28502772,28502785,28502743,28502744,28502744,28502745,28502746,28502746,28502747,28502747,28502749,28502759,28502760,28502761,28502762,28502763,28502763,28502764,28502767,28502785,28502744,28502745,28502746,28502746,28502747,28502748,28502758,28502760,28502761,28502763,28502764,28502765,28502785,28502786,28502746,28502747,28502747,28502748,28502750,28502756,28502760,28502761,28502761,28502763,28502764,28502767,28502768,28502786,28502747,28502762,28502787,28502747,28502748,28502762,28502765,28502769,28502787,28502748,28502749,28502749,28502750,28502753,28502762,28502763,28502764,28502765,28502768,28502768,28502769,28502788,28502749,28502750,28502751,28502753,28502760,28502761,28502763,28502763,28502764,28502765,28502765,28502766,28502766,28502767,28502788,28502750,28502751,28502752,28502756,28502761,28502763,28502764,28502764,28502765,28502765,28502766,28502766,28502767,28502769,28502770,28502775,28502783,28502788,28502789,28502756,28502762,28502764,28502765,28502767,28502789,28502760,28502761,28502764,28502765,28502766,28502766,28502767,28502767,28502768,28502790,28502757,28502764,28502765,28502765,28502768,28502771,28502790,28502754,28502765,28502765,28502766,28502768,28502769,28502772,28502791,28502765,28502769,28502773,28502791,28502768,28502766,28502767,28502768,28502770,28502793,28502769,28502769,28502769,28502770,28502794,28502768,28502770,28502771,28502795,28502777,28502795,28502784,28502798,28502775,28502799,28502775,28502777,28502800,28502775,28502775,28502777,28502782,28502800,28502776,28502776,28502794,28502801,28502776,28502778,28502780,28502784,28502801,28502802,28502777,28502778,28502778,28502779,28502780,28502780,28502781,28502781,28502782,28502783,28502783,28502784,28502795,28502800,28502802,28989778,28502778,28502779,28502779,28502780,28502781,28502782,28502783,28502783,28502784,28502784,28502785,28502802,28502803,28502779,28502780,28502780,28502781,28502781,28502782,28502782,28502783,28502784,28502803,28502780,28502781,28502781,28502782,28502783,28502783,28502784,28502785,28502795,28502804,28502782,28502783,28502783,28502784,28502785,28502785,28502786,28502786,28502791,28502803,28502804,28502782,28502783,28502784,28502784,28502785,28502785,28502787,28502805,29135350,28502783,28502784,28502784,28502785,28502786,28502786,28502787,28502787,28502805,28502805,28502784,28502785,28502785,28502786,28502786,28502787,28502787,28502788,28502789,28502793,28502793,28502797,28502798,28502800,28502802,28502802,28502804,28502805,28502806,28502786,28502788,28502806,28502786,28502787,28502787,28502788,28502788,28502789,28502796,28502798,28502807,28502787,28502788,28502788,28502789,28502807,28502807,28876397,28502788,28502789,28502789,28502794,28502800,28502807,28502808,28502789,28502790,28502790,28502794,28502795,28502801,28502806,28502808,28502808,28502790,28502791,28502793,28502797,28502802,28502803,28502805,28502806,28502808,28502809,28502791,28502793,28502796,28502796,28502797,28502806,28502807,28502808,28502809,28502796,28502801,28502805,28502808,28502809,28502810,29135356,28502811,28502812,28502808,28502814,28502808,28502814,28502814,28502813,28502815,28502815,28502816,28502817,28502816,28502818,28502819,28502819,28502820,28502820,28502814,28502821,28502821,28502821,28502822,28502822,28502823,28502824,28502824,28502825,28502824,28502825,28502826,28502826,28502826,28502827,28502828,28502829,28502829,28502830,28502831,28502833,28502837,28502840,28502840,28502841,28502842,28502844,28502845,28502849,28502850,28502852,28502853,28502854,28502855,28502855,28502856,28502856,28502857,28620998,28876418,28876418,28876419,29135372,29135373,29231741,30521724,30898135,30908718,31515956,31585561,34125819,34125820,35133653,28502829,28502830,28502831,28502832,28502834,28502840,28502841,28502842,28502847,28502848,28502849,28502852,28502853,28502854,28502855,28502855,28502856,28502856,28502857,28502857,28502856,28502858,28502857,28502858,28502859,28502857,28502860,28502862,28502863,28502858,28502869,28502869,28502870,28502858,28502868,28502873,28502873,28502874,28502876,28502876,28502878,28502872,28502878,28502879,28502877,28502879,28502880,28502878,28502881,28502882,28502882,28502881,28502882,28502883,28502883,28502884,28502884,28502884,28502884,28502885,28502885,28502886,28502887,28596077,28596078,28596079,28612674,28621027,28731632,28771121,28833590,28849322,28849322,28876445,28876445,28876446,28876446,28876447,28876447,28876448,28876448,28891391,28891392,28932131,28932133,28932134,28932135,28989816,28989817,28989817,28989820,28989820,28989823,28989823,28989824,28989826,28989827,28989827,28989828,28989828,28989829,28989829,28989830,28989832,28989833,28989835,29085815,29085816,29085817,29099506,29135397,29135398,29135399,29135399,29135400,29135400,29135401,29135401,29135402,29135402,29231773,29358770,29499180,29499180,29499181,29499182,29499183,29950325,30247153,30518240,30720845,31585590,31585591,31862431,32226215,32367887,33315522,33438325,33438325,33438326,33438327,34125847,34125847,34125848,34125849,34125849,34125850,34125850,34384890,35133682,35133682,35133683,35133691,37733749,38608689,38744446,38970695,38970695,39770980,28876447,28989817,29135402,28771121,28876449,29135403,28689281,28689281,28689282,28689284,28689284,28689285,28689294,28969651,28969650,28984596,28969652,28969653,29228606,33408726,33531529,28969653,29228608,28969652,28722473,28986246,28739180,28739181,28739183,28739183,28994601,28994602,28994601,28994602,28833344,28994603,29107976,28994605,28927522,29088782,28960388,29364158,29039370,29039370,29144697,29049142,29262968,29164306,29207163,29195771,29195771,29222896,29222896,29222897,29250007,29250008,29250023,29250023,29250008,29250008,29250009,29250022,29250023,29250024,29250024,29250008,29250009,29250009,29250011,29250022,29250023,29250023,29250024,29250025,29250009,29250010,29250011,29250024,29250024,29250025,29250025,29250010,29250024,29250025,29250025,29250026,29250013,29250022,29250023,29250024,29250024,29250025,29250025,29250026,29250026,29250027,29250027,29250028,29250037,29250037,29250038,29250038,29250038,29250039,29250039,29459392,33143438,34499425,29250038,29250039,29250040,29305710,29508976,29508978,32765263,29250039,29250040,29250040,29250044,29363393,29363396,29508977,29508978,29872758,32528470,33811901,35507259,29250040,29250041,29250041,29305710,29363397,29363405,29508975,29508976,29508977,29508979,30537552,32407104,29250041,29305710,29305711,29305711,29363394,29363394,29363395,29363396,29363397,29363398,29363399,29363400,29363401,29363403,29363404,29363406,29363407,29363408,29363408,29363409,29363409,29363411,29363411,29363412,29459394,29508849,29508973,29508976,29508977,29508977,29508978,29508978,29508979,29508979,29508980,29605349,29732329,29732348,29732348,29732360,29872757,29872758,29872759,31174468,31264645,31282324,31286391,31824448,31959168,32326747,32741465,33689101,33811902,33852361,34499425,34499426,34499426,34499427,35507259,35507260,29250043,29250046,29264969,29305711,29305712,29338728,29363394,29363394,29363395,29363395,29363397,29363398,29363398,29363401,29363402,29363402,29363403,29363404,29363405,29363406,29363406,29363408,29363409,29363409,29363410,29363411,29363411,29363412,29363412,29459393,29459394,29459394,29459395,29459396,29508974,29508976,29508977,29508977,29508978,29508978,29508979,29508979,29508980,29508980,29605345,29732321,29775912,29872757,29872758,30537553,31249821,31959168,32528470,32741465,32741465,33143439,33764258,33811903,34499426,34499427,34499427,34499430,35507260,38107327,29508980,29363411,29264974,29305715,29508984,29279911,29279913,29279908,29279909,29280033,29280036,29523921,33826846,29378355,29280161,29280164,29524042,34514493,29361378,29361394,29361391,29361394,29361396,29361395,29361395,29361396,29361397,29361397,29361396,29361397,29361405,29419086,29419090,29413678,29419082,29419086,29419089,29564663,29378743,29419085,29564662,29564663,29564664,29564664,31305505,29564663,29564665,29396087,32814494,29427426,29427427,29597676,29597677,31338519,29465959,29471374,29476761,29476762,29476747,29476755,29476756,29476764,29476750,29476754,29476759,29476762,29476763,29476764,29476764,29476766,29476770,29476771,29476773,29476755,29476764,29476766,29476757,29476782,29476752,29476755,29476756,29476758,29476765,29476766,29476758,29476767,29476784,29476757,29476767,29476768,29476769,29476784,29476784,29476762,29476764,29476786,29476769,29476786,29476763,29476767,29476786,29476787,29476768,29476771,29476773,29476787,29476766,29476771,29476787,29476788,29476766,29476768,29476769,29476774,29476788,29476788,29476772,29476788,29476766,29476767,29476789,29476790,29476790,29476790,29476769,29476791,29476769,29476791,29476791,29476772,29476772,29476773,29476775,29476776,29476791,29476792,29476771,29476772,29476774,29476792,29476792,29476774,29476776,29476793,29476773,29476776,29476793,29476793,29476776,29476777,29476793,29476794,29476775,29476776,29476777,29476794,29476794,29476795,29476778,29476794,29476795,29622346,29476777,29476778,29476779,29476795,29476796,29476778,29476779,29476779,29476780,29476781,29476795,29476796,29622343,29476779,29476780,29476780,29476796,29476796,29622346,29476780,29476781,29476796,29476797,29622349,34612795,29476781,29476783,29476797,29476797,29622349,29476782,29476783,29476797,29476798,29476798,29622350,29476783,29476798,29476798,29476798,29476799,29622349,29622351,29476799,29476800,29622355,29986134,29622355,29476813,29476814,29572780,29572781,29622361,29622362,29622363,29622363,29622364,29622365,29622365,29622366,29986142,29986145,32641856,34612812,35620645,35620646,29476814,29543745,29572780,29572780,29572781,29572782,29572782,29573311,29622235,29622363,29622363,29622364,29622364,29622365,29622365,29622366,29622370,29718736,29845681,29845706,29845718,29927043,29986144,30734117,31363206,31395711,32072554,32854851,32854851,33534631,33925289,34612811,34612812,34612813,35620646,35620646,29572782,29622361,29622364,29622365,29622365,29622366,29622366,31399618,31932918,38095874,39457660,33925290,29610693,29689313,29668760,29668761,29668761,29668762,29668760,29668761,29668761,29668761,29668762,29668763,29668762,29668762,29668763,29668764,29718345,30830096,35716626,29718342,29718345,29718346,29718344,29718346,29718346,34708793,34708794,29718345,29718346,29718344,29718346,29718347,29718347,34021270,29679308,29669822,29718876,29689853,29707729,29696139,29732035,29725601,29746761,29767669,29767668,29767799,29767796,29767911,29767912,29767913,29767929,29767913,29767914,29767913,29767914,29767914,29767915,29767929,29767929,29767930,29767913,29767914,29767915,29767930,29767931,29767913,29767914,29767915,29767915,29767916,29767928,29767930,29767931,29767931,29767914,29767915,29767915,29767916,29767928,29767929,29767929,29767930,29767930,29767932,29767915,29767916,29767918,29767930,29767930,29767931,29767931,29767932,29767932,29767916,29767917,29767930,29767931,29767931,29767932,29767932,29767933,29767917,29767918,29767930,29767931,29767932,29767932,29767933,29767918,29767921,29767929,29767930,29767930,29767931,29767931,29767932,29767932,29767933,29767933,29767934,29767934,29767923,29767931,29767932,29767932,29767933,29767933,29767934,29767934,29767934,29767936,29767941,29767938,29767944,29767945,29767943,29767945,29767946,34758377,29767944,29767946,29767946,29767947,29864301,29991346,29767945,29767946,29767946,29767947,29864301,34070854,34758379,29767946,29767947,29767947,29767948,30083957,31616676,33000417,34070854,34758379,29767947,29767948,29767948,30131712,30260581,31508773,31616676,32078483,32218121,34758379,34758380,39376983,29767948,29767949,29767949,29864303,29864303,29991282,29991287,29991289,29991300,29991307,29991341,30034865,30131709,30131711,30131711,30131712,30131712,30131713,30131713,30149352,30495840,30602650,30796506,30951974,31090426,31161893,31203252,31278226,31508770,31508773,31744103,31865956,32666058,32787424,32905511,33000418,33402391,33524353,34070856,34070856,34070857,34758378,34758378,34758379,34758379,34758380,34758380,34758381,34758383,35766213,35766213,36133400,39603226,29767949,29767952,29864304,29991265,29991275,29991275,29991281,29991283,29991286,29991298,29991308,29991320,29991321,30034866,30131711,30131711,30131712,30131712,30131713,30131714,30131714,30582856,30582857,30796506,31034565,31090427,31113671,31154281,31508774,31545278,31616677,31860879,32078484,32083402,32218122,32666059,32787424,32787424,33000419,33174160,33187652,33402394,33409999,33608812,33694442,33948051,33952244,34070856,34070857,34070857,34758378,34758380,34758380,34758381,34758381,34758382,34758384,34758384,35766213,35766213,35766214,39603227,39603273,29841680,29864304,29896005,29959242,29991267,29991268,29991269,29991280,29991280,29991281,29991282,29991283,29991285,29991288,29991288,29991289,29991305,29991305,29991306,29991310,29991311,29991313,29991344,30126494,30131709,30131710,30131712,30131712,30131713,30131714,30131714,30449235,30495841,30582857,30861818,31161894,31433701,31508771,31508774,31616678,31616770,31643364,31768293,32018361,32078484,32078485,32083403,32218122,32218123,32666054,32666059,32787424,32787424,32787425,32792328,32858746,33000419,33665129,33948052,34070855,34070857,34070857,34070858,34758379,34758380,34758380,34758381,34758381,34758382,35243421,35766213,35766214,35766214,39603227,33948052,34070857,30131717,29915424,30065050,29960666,29960657,29960670,29960671,29960671,29960672,30087649,30228078,30228081,31258261,30087681,30087684,30297377,32314489,34854748,35862580,35862582,30024075,30577305,30150546,30263915,30214594,30214636,30214659,30214642,30214663,30214607,30214669,30214647,30214647,30214640,30214657,30214687,30214656,30214660,30214658,30214627,30214640,30214654,30214656,30214658,30214659,30214662,30214668,30214664,30214664,30214671,30214701,30214680,30214702,30214673,30214675,30214671,30214670,30214678,30214671,30214674,30214675,30214676,30214699,30214666,30214687,30214679,30214679,30214675,30214699,30214684,30214695,30214690,30214693,30214698,30214695,30214713,30214694,30214718,30355084,35989584,30214736,34981752,30355086,35989586,30214737,30355086,30214702,30214702,30355082,30214699,30355085,34981755,33128884,33223794,34981755,30214723,34981756,31967482,30214728,30214709,30214741,31840082,30355088,35073409,34294234,34294237,30214725,31961142,34981760,31840067,30355092,31019887,34171433,31840060,35989596,30355097,34981765,30355097,30355098,34981766,31839864,30355104,30214757,31175369,30355104,30214744,30214759,31175372,35989609,32889453,30214762,30348313,30214765,30214765,30355114,30214767,30355120,34294270,30214779,30672649,32441536,35989628,30355123,30355126,33223834,34294272,34981796,30258282,30237666,31732185,30260620,30260691,32912431,30301796,30301796,30301796,30398643,30398643,31775704,34214983,30377284,30377285,30436386,36070888,30399984,33316443,30481896,30488693,30485073,35116959,30495485,30495484,30495485,30495485,30495474,30495486,30495486,30495473,30495487,30495487,30495488,30495475,30495486,30495487,30495487,30495489,30495476,30495487,30495488,30495489,30495476,30495488,30495490,30495478,30495490,30495492,30495478,30495490,30495491,30495479,30495491,30495490,30495492,33364194,39740751,30495501,32287208,33154150,33364194,34434632,34434632,35122155,35122156,35122156,30495502,31160283,31872550,31980463,33848107,35213807,30495503,34434633,34494508,35122156,36129990,30813012,30931542,31160284,31243462,31315752,31356467,31410051,31454204,31518593,31839430,31872549,31980455,32101545,32107881,32132071,32287210,32447180,32554565,32581899,33151201,33151202,33151203,33364196,33364196,33551429,34434632,34434634,34434634,34434636,35122156,35122156,35122157,35122157,35122158,35122158,35122159,36129990,36129991,36129991,38730058,39967004,39967027,31705475,30530767,31692144,30634145,35191515,30753234,36258866,31130533,31264156,35066858,35439677,35439679,31223747,31223748,32236682,34798764,31367596,35558211,31397780,31397783,31397781,31397783,32431611,34885781,31611433,34885783,31676744,31437370,32310372,31825076,31825077,31825077,31825078,31825079,31825079,31825080,31890390,34028989,36794784,33764953,35099428,35682139,33815997,35099429,32796867,35099430,35786954,31955749,31955749,31955753,31955812,32602706,34094351,35164789,31991432,33329870,33777807,40714975,32136015,32136016,32136018,32136018,33850100,34184460,35132093,35254897,32217442,32726161,32301228,36025043,32324623,32895054,32412980,32413082,32413089,32413180,32413187,34323071,35393508,36081032,32459441,34346189,32533631,36141240,32540623,32540629,32540649,32540651,32540674,33604490,36144748,32541693,32820580,32555851,32555854,32813872,34581609,34758651,32638616,34222787,32788516,35458340,32853522,33051566,32915469,34239832,32938816,40761997,33071898,35722839,33098908,33883608,33099469,33099472,37431981,34453195,33183373,35778577,33234882,33400573,33249595,33249606,33249606,33249607,33249599,33249612,33249612,33249613,33249614,33249614,33249617,33249613,33249613,33249610,33249616,33249614,34741253,33249622,35811692,34740493,36756043,33249628,33481715,33958960,34528262,35688891,35811694,36499218,33357516,33758005,36499219,33357527,36499220,34182428,35811697,36499220,35811698,36499224,33279262,34779881,33293453,33980880,33314620,33314620,33991463,33991464,35175737,33322477,35848148,33322642,34777782,33322758,36535793,33465051,33465278,33465433,33465443,33465508,33465510,33465536,33465584,33465585,33465601,33465611,33592939,33617125,33932234,34066953,34391297,34707573,34849250,35251225,35333166,35848954,35919688,35919690,36607211,36607212,33518794,35946286,33566264,34117285,33707589,33707597,36040683,36728210,33713814,33713899,33713983,36731403,33720274,33720276,33720277,34834912,34976589,36734551,37742384,33768647,33768649,33768650,36758736,35000773,36758735,36071212,33953821,36851320,33963979,36856402,34078927,34078931,34373617,36913877,34266409,34266446,34266485,34467402,34266556,34467437,34268835,34268847,34916534,37008868,34389036,34389033,34389034,34389032,34642527,36381405,37068928,36381406,34901777,34398866,34398867,34398868,34398873,34398985,34398986,34398990,36386322,38081685,34399104,34399104,34399111,35316001,36386439,37073965,34529096,34598701,34613638,36493706,34668295,34668305,34668305,34755495,35029622,35041408,35116242,35237607,35242511,35355694,35355694,35450602,35450602,35852574,36049867,36521039,36521040,37208562,37208563,37208563,37208564,37208564,37208565,37300214,37339742,37693604,38207929,38216397,38216397,38713022,39040026,39320209,42053410,42053456,42053456,34842687,36061391,34896022,35230101,35115242,36744510,35222036,35393131,35317051,35317166,35317287,37533087,35390939,35598925,35403467,37576146,35414512,35414513,35682030,38589501,35564177,35564179,35564182,35564181,35564182,35564182,37656500,37656502,38664335,35647850,35685547,35898541,35898542,36300515,36308124,36968979,37656502,37656503,38664336,38664337,37656504,35704830,37039305,35731543,35731587,37052679,35806913,35806913,35806914,35806912,35806913,35806914,35806915,35806914,35806915,35806915,35806916,36207139,37090345,37777869,37777870,36019908,36421882,35925000,36019908,36019909,36421882,36598322,36967543,37090346,37777869,37777870,37777870,38785704,35812812,35927947,35816718,37095245,38790604,35949553,35949553,35949557,35949560,37161667,37161668,37849191,42467784,38857028,36043083,36043083,36043084,36043073,36043085,36137229,36137229,36137993,37895954,37895954,36231373,36231373,36231376,37990096,37990098,36232139,36232901,36232901,36232902,36232903,36232903,36232900,36232901,36232901,36232902,36232902,36232903,36232903,36232904,36232904,36232905,36232904,36232904,36324491,37303338,36232916,36634875,37160602,37303339,37303339,37303340,37990862,37990862,37990863,36634878,36642484,36897613,37303340,37990860,37990862,37990863,37990864,37990864,38998698,39230167,37303341,37990865,36634876,37008694,37618042,37990864,37990865,36579563,36584153,36634876,36634877,36634880,37303341,37990865,37990865,37990866,38998698,38998699,38998699,37374261,38998699,36280502,36280504,38014663,37327141,36416082,37394929,36580387,37477083,36607368,36607370,36607372,36822107,37490572,37490574,38178099,36926279,36926364,36926446,37650140,36935402,38342114,36961461,37667628,37036848,37036849,37036850,37036850,37036849,37036851,37036853,37036854,37036854,37036853,37036854,37036854,37705313,37299586,38392837,37299586,37705315,37705316,38392839,38392839,38392840,39400672,37705316,39400672,37582510,38392840,38392840,37052062,37052064,37052065,37712920,38400442,38400443,37200729,37200732,37787254,38474778,37280084,37280094,37684197,37280774,37356105,37389761,38569309,37431430,37431431,38485314,38590126,37449690,39607091,37562318,37562320,37562321,37968047,38655572,40030592,38655572,37592463,39678478,37620962,37997376,37784482,38766652,38088303,38088307,38231040,38231044,38128168,38128169,38128169,38128155,38128169,38128170,38128171,38128170,38128171,38128172,38128174,38128185,38250975,38938497,38938499,39946332,38250975,38250975,38938498,38938499,38938500,39810601,38136551,38255164,38232315,38828914,38278490,39013659,38373775,38373762,38373777,38373780,38373778,38373764,38373765,38373766,38373766,38373777,38373778,38373778,38373779,38373779,38373780,38373780,38373781,38373781,38373782,38373784,38373766,38373778,38373778,38373779,38373779,38373780,38373780,38373781,38373781,38373779,38373780,38373781,38373781,38373782,38373782,38373768,38373780,38373780,38373782,38373779,38373783,38373783,38373780,38373783,39061301,38373791,38373794,38402548,39061301,39061301,40069134,38373793,38373794,39061300,39061301,39061302,39061302,38373794,39061301,39061303,40069135,41138742,38373794,38373795,38373795,38373796,38373797,38688481,39061302,39061302,39061303,39061303,39061304,39061304,39152953,40069135,40069136,38373795,38373796,38373797,38579605,39061301,39061302,39061302,39061303,39061304,40069136,40069136,40069137,40069143,43906150,38373796,38373797,38373798,38444699,38516470,38688482,38688483,38814388,39061302,39061303,39061303,39061304,39061304,39061305,39061306,39845387,40069135,40069136,40069137,40069138,43367363,38373797,38373798,38373799,38414239,38688484,38893157,39061302,39061303,39061303,39061304,39061304,39061305,39061305,39061306,39258319,40069137,38373798,38421544,38688481,38884109,38893157,39061303,39061303,39061304,39061305,39061305,39061306,39152955,40069138,40069138,43679693,43906151,39061305,40069138,40069139,40069146,38433697,38514799,39061304,39061306,40069138,40069138,39061307,38431315,38431410,38431505,39090163,38454694,38454695,39101757,39101759,38469341,38469400,38469482,39109184,38493589,38493670,38493791,38493832,38493972,39121419,40129253,38515611,38515612,38515680,38515681,38515749,38515749,39132285,38655862,39145220,38659157,39203990,38785430,40274961,39003179,39003183,39003183,39003184,39003185,39003187,39376003,40383838,39376004,39376006,39376006,39376007,39255045,39255127,39255220,39502053,39394434,39571629,39412530,39412531,39580677,39580678,39425555,39425635,39425724,39587302,39539197,39539198,39644010,39644011,39634540,39634612,39634681,39691757,39748806,39748808,39748808,39748809,39748809,39748810,39748811,39748811,39748823,39748824,39748824,39748825,39748827,39748809,39748810,39748810,39748811,39748811,39748821,39748823,39748824,39748824,39748828,39748810,39748811,39748811,39748812,39748820,39748825,39748811,39748812,39748812,39748813,39748813,39748814,39748824,39748825,39748826,39748826,39748827,39748827,39748828,39748812,39748813,39748813,39748814,39748814,39748815,39748815,39748816,39748825,39748826,39748826,39748827,39748827,39748828,39748828,39748829,39748830,39748813,39748814,39748814,39748815,39748815,39748816,39748825,39748826,39748826,39748827,39748827,39748828,39748828,39748829,39748829,39748814,39748815,39748815,39748816,39748816,39748826,39748827,39748827,39748828,39748828,39748829,39748829,39748830,39748830,39748831,39748816,39748817,39748826,39748827,39748827,39748828,39748828,39748829,39748829,39748830,39748830,39748831,39748816,39748817,39748828,39748829,39748829,39748830,39748831,39748817,39748828,39748828,39748829,39748829,39748830,39748831,39748828,39748829,39748829,39748830,39748830,39748831,39748829,39748831,39748831,39748837,39748832,39748833,39748834,39748837,39748838,39748839,39748839,39748841,40756657,39748839,39748840,39748841,39748842,40106187,40756657,39748840,39748841,39748841,39748842,39748843,40233869,40756659,39748841,39748842,39748842,39748843,39748844,39880005,40756654,40756658,40756658,40756659,40756660,44593673,39748842,39748843,39748843,39748844,40756659,40756660,40756660,40756661,44367464,44593673,39748843,39748844,39748844,39748845,39748845,39748846,39840478,39880006,40086720,40126579,40126580,40233868,40366916,40393407,40393410,40748191,40756657,40756658,40756659,40756659,40756660,40756660,40756661,40756661,40756662,40756664,40756668,40756670,41123848,41868576,42194380,42237367,43356728,43356729,44069545,44367426,44367426,44593674,44593720,39748844,39748845,39748845,39748846,39748846,39752006,39832864,39880007,39906106,40083528,40126580,40756660,40756661,40756661,40756662,41025726,43356728,43656551,44593674,39748845,39748846,39748846,39752007,39906106,40086719,40233868,40756660,40756661,40756661,40756662,40756662,40756671,41868577,43356729,44593675,39748846,39752007,39773871,39911279,40126581,40233868,40358068,40756660,40756661,40756661,40756662,40756662,40756663,40756664,39748847,39748848,39840480,39880008,40007867,40007870,40157720,40157801,40393408,40748193,40756659,40756662,40756662,40756663,40756663,40756664,39752008,40358069,40756661,40756662,40756663,40756663,40756664,44593676,40756663,40756664,40756664,40756667,39755183,39755184,39883183,40759837,40759838,39798911,40781701,39916897,40840695,39932125,39932125,40848307,40848308,41917914,40848307,40848308,40011180,40139042,40887834,41255021,41999749,40063379,40550681,40913933,40073724,43519175,40142858,40953676,40262472,41013480,40266904,40266908,40266908,41015700,41015698,41015699,41015700,41015700,40418270,41091402,40424609,40424609,41094547,41094551,40463546,40724272,40504328,40504328,41134407,41134408,41134408,41134409,41134409,44745172,40566609,40566672,40566747,40566765,40566893,40897749,40567021,41165754,40718906,40718907,40718908,40718908,40718897,40718910,40718909,40718920,41241699,41053319,41241700,41241701,41241707,41241701,40967310,41365904,41365904,40985000,40985000,41295071,41374744,41037985,41037986,41037987,41037991,41401239,41401240,41401241,41401241,41228740,41496618,41316993,41540743,41387733,41576114,41493032,41628763,41605142,41676348,41747553,41747554,41747554,41756021,41756022,42859835,41764473,41764475,41764474,41764475,41764475,41764477,41764475,41764476,41764477,41764481,41764497,41764476,41764477,41764477,41764492,41764477,41764478,41764478,41764482,41764483,41764485,41764487,41764492,41764493,41764493,41764495,41764495,41764478,41764479,41764479,41764482,41764484,41764486,41764487,41764488,41764490,41764491,41764492,41764493,41764493,41764494,41764494,41764495,41764495,41764496,41764496,41764497,41764497,41764479,41764480,41764480,41764481,41764483,41764484,41764485,41764486,41764486,41764487,41764488,41764488,41764490,41764490,41764491,41764492,41764492,41764493,41764493,41764494,41764494,41764495,41764495,41764496,41764496,41764497,41764497,41764499,41764480,41764481,41764481,41764482,41764482,41764483,41764484,41764484,41764485,41764485,41764486,41764486,41764487,41764487,41764488,41764488,41764489,41764491,41764492,41764492,41764493,41764493,41764494,41764494,41764495,41764495,41764496,41764496,41764497,41764499,41764499,41764501,41764502,41764481,41764484,41764486,41764488,41764489,41764491,41764494,41764495,41764496,41764496,41764500,41764484,41764487,41764489,41764492,41764496,41764496,41764504,41764487,41764487,41764487,41764497,41764498,41764498,41764499,41764498,41764506,41764488,41764491,41764496,41764497,41764498,41764489,41764499,41764507,41764498,41764499,41764490,41764491,41764492,41764493,41764499,41764500,41764491,41764492,41764492,41764493,41764494,41764495,41764500,41764501,41764501,41764492,41764493,41764493,41764495,41764496,41764500,41764500,41764501,41764501,41764502,41764510,41764493,41764494,41764495,41764495,41764501,41764501,41764502,41764510,41764494,41764495,41764496,41764501,41764502,41764502,41764511,41764495,41764496,41764500,41764501,41764502,41764503,41764503,41764496,41764497,41764497,41764502,41764502,41764503,41764506,41764512,41764497,41764502,41764502,41764503,41764503,41764504,41764505,41764512,41764512,41764499,41764503,41764503,41764504,41764505,41764513,41764504,41764501,41764505,41764505,41764507,45601503,41764504,41764506,41764506,41764511,41764507,41764507,42489150,41764505,41764507,41764507,41764508,41764509,41764517,42868304,45601505,41764507,41764508,41764508,41764509,41764510,41764512,41764507,41764508,41764508,41764509,41764517,45375262,45601506,41764508,41764509,41764509,41764510,41764510,41764511,41764512,41764517,41764518,41764518,42131680,44364560,44364563,45375260,45601506,45601506,41764509,41764510,41764510,41764511,41764511,41764512,41764512,41764516,41764517,41783270,42131681,42876409,43202212,43245202,43627247,44158455,44364561,45077378,45601507,41764510,41764511,41764511,41764512,41764512,41764513,41764513,41764514,41764515,41764518,41764519,41764519,41802679,42131681,42131683,42698628,42698629,42823277,42834100,42868307,42876409,43202213,43202215,43675820,43804686,44364561,44364562,44364563,45375168,45375254,45375257,45375258,45375298,45601507,41764511,41764512,41764512,41764513,41764513,41764514,41764514,41764515,41764515,41764516,41764518,41764518,41764519,41764519,41764520,41764520,41802641,41875316,42033558,42131682,42555531,42834101,42876410,43336676,43336676,44158455,44158455,44239717,44239722,44239725,44364562,44364563,44364564,44985869,45077377,45239501,45375260,45375260,45375261,45375272,45375274,45375298,45375299,45601508,41764512,41764513,41764513,41764514,41764514,41764515,41764515,41764516,41764518,41764519,41764520,41897121,41995966,42131682,42131684,42135277,42823278,42868308,43046350,44158456,44158457,44180715,44364562,44364564,45174839,45239502,45375050,45375260,45375261,45601508,45601508,41764513,41764514,41764514,41764515,41764515,41764516,41764516,41764519,41764520,41764520,41764521,42131683,42698631,42823278,42834102,43202214,43777100,44364563,45004640,45174840,45375255,45375259,45375262,45601509,41764514,41764515,41764515,41764516,41764516,41764517,41764517,41764520,41764520,41764521,42834102,44158458,44239723,44364563,44664385,45375262,45375263,45601509,45601509,41764515,41764516,41764516,41764517,41764517,41764518,41764518,41764520,41764520,41764521,41764521,42131684,42796636,42834102,42834103,42868309,42876412,44364564,44364565,44664386,45375262,45375301,45601510,41764516,41764517,41764517,41764518,41764518,41764519,41764520,41764520,41764521,41764521,41764522,41764522,41764523,42131684,42876412,43202220,43513693,44158458,44158458,44364564,45375260,45601510,41764517,41764518,41764518,41764520,41764521,41764521,41764522,41793496,41995968,42131685,43437956,43550008,44364564,45239504,45375257,45601511,41764518,41764519,41764519,41764520,41764520,41764521,41764521,41764522,41764523,41764523,41997256,42834104,43202220,44364565,45601511,41764519,41764520,41764520,41764521,41764521,41764522,41764522,41764523,41793497,41875323,42821307,42868311,43202217,43202218,43562066,44364566,45375260,45601511,45601512,41764520,41764521,41764521,41764522,41764522,41764523,41764524,41764525,42698634,42726407,42868312,44364566,45375112,45375262,45601512,41764521,41764522,41764523,41764523,44158460,45375263,45601513,41764523,41764524,42131687,44158461,44364568,45601513,41764524,41764524,42131688,43777105,41764525,41764526,44364568,45601514,41764525,41764526,41764526,44364569,44664390,44664390,45601515,41764526,41764527,41764527,41875326,42131687,42131689,42698637,42823285,43336685,44004086,44158463,44364569,44364571,44364572,45062729,45174849,45375262,45375265,45375265,45601515,41764527,41764528,41875327,42131690,44364570,44364571,45375266,45375306,45601516,41764528,41764529,41793501,41960052,41995973,42131690,42131691,42823286,42834109,42873513,42876418,43148729,43190077,43202222,43562122,43718899,43777014,43777107,43785121,44239730,44364570,44664391,44985873,45077386,45375265,45375267,45375269,45375270,45375282,45375283,45601516,45601516,41764529,42033569,42131691,42876419,43312276,43926637,44158464,44364571,44364572,45375265,45375269,45375313,45377291,45601517,42131691,44158465,44364571,44364572,45601517,41802041,44383332,41822505,41835796,43231229,44393575,41840848,41840917,41840954,41841060,41840993,41841066,45277812,45213153,41849072,44406850,41986137,41986139,43313037,43380476,44475383,45486076,45712328,42029742,44497183,42155588,42894174,42227431,42227432,42227434,42227429,42227432,42227520,43380187,44596028,44596031,45832975,45606727,42227610,44596116,42230010,42958793,42302620,42302621,43145471,44046160,44674484,42498864,42498865,42498866,42498866,42498868,42498868,42498867,42498868,42498879,43243593,44293812,44731745,44144283,44606906,44690131,44731746,45742442,45742480,45968692,42508144,43201285,43243594,43569398,43569405,43612384,43805142,44144281,44144283,44731746,44731748,45742442,45968692,45968692,43569399,43805142,44731748,45742457,45968694,42506117,45972349,42517423,43578677,42757739,43373029,43213810,46326164,43346605,43973393,43411748,43700034,43632760,43632761,43632764,43810541,44210338,45298693,46535638,46535639,46535642,43687616,43687680,45326151,43688370,46563475,43828769,44835512,43878108,45057561,43882057,43882057,43882059,45423341,44260996,45423342,46434052,43935191,43903703,43903703,43903704,43903704,43903705,43903705,45434164,43937910,44271817,45434165,45434166,46671111,43937911,46671111,46671112,43972113,43980216,44802203,45468370,46705314,46705360,46705360,43982512,45473569,43988318,43988319,43988320,43988328,43988330,43988331,43988331,43988328,43988329,43988330,44673508,44889008,45351629,45351631,45476471,45476473,46487109,46487166,46487170,46713416,46713417,46713463,43988330,43988331,45292604,45476474,46713418,46713464,46713418,46487176,45476483,44260641,44260642,44328234,46657143,44532941,44696479,45748783,46759478,44600151,44890701,44615638,46196559,44639934,44639932,44639933,44639934,44639937,44639934,44639935,44639935,44639937,44639938,44639937,44639938,44639939,44639940,44639942,47039227,46812980,46500443,45530392,45802283,46102106,46677250,46812977,47039229,45214821,47039230,45802284,45596179,44725907,44725904,44725910,47082210,45845271,47082215,44774812,47106664,44787914,44977548,44860007,44860040,44860023,44860048,45912342,47149288,44908856,44908857,44908858,45936742,45936743,45111413,45111416,45111418,46038022,47274968,45167184,45478441,45181256,45605471,45262887,46113759,45335528,47387031,45358696,46202520,45359643,45359719,45359741,45359795,46162189,45724285,45490017,46227333,45587173,47286614,45632297,45860528,45673303,46318974,45789509,45789603,45789698,45789699,45789699,45789700,45789703,46180334,46021692,46377162,46377163,46377164,47387856,47387858,47387861,47614108,47387868,47614109,47387903,45805741,46385190,45842269,46403454,45844874,46404749,46029726,46389145,46088755,46526689,47763635,47763681,46237077,46237198,46237319,47611699,46243678,46243710,47614858,46253684,46609154,46420842,47703432,46552414,46552412,46552413,46552413,46552414,46552415,46552412,46552413,46552413,46552414,46552414,47769118,46758519,47769260,46758519,46758521,47769007,46758520,46758522,47798710,47995465,46758520,47058343,46758521,46758521,46570968,46767796,46596888,46596909,46596943,46596943,48017736,46780790,46714942,46714946,46714948,46714948,46714951,47850490,46839789,47850484,47850491,48076734,48076779,47850523,48076734,46748533,47199296,46881387,46881461,46881536,46923077,46964613,46964613,46964614,46964614,46964615,46964615,46964616,46964624,46964625,46964625,46964626,46964626,46964627,46964627,46964628,46964628,46964629,46964629,46964631,46964615,46964625,46964628,46964615,46964616,46964616,46964625,46964626,46964626,46964627,46964627,46964629,46964629,46964630,46964630,46964631,46964626,46964628,46964629,46964630,46964631,46964628,46964628,46964630,46964630,46964631,46964632,46964628,46964629,46964630,46964631,46964628,46964632,46964639,48201570,46964638,46964639,46964640,46964640,46964641,48201571,46964640,46964641,48201571,46964641,46964642,46964643,47774906,47975320,48201571,48201572,46964641,46964642,47264449,48201572,46964641,46964642,47975323,47975326,48201573,46964644,48201573,48201573,46964643,46964644,46964644,46964645,47005489,47084014,47251121,47264449,47264451,47774905,47774906,47975115,47975321,47975322,47975323,47975324,47975324,47975327,47975362,47975365,48201573,48201574,48201620,46964644,46964645,46964645,46964648,47047061,47264447,47585931,47774906,47774906,47774908,47839585,47940564,47975174,47975322,47975323,47975324,47975325,47975325,47975326,47975326,47975327,47975327,47975328,47975338,47975358,47975361,47975365,47975365,48110623,48201574,48201574,48201621,46964645,46964646,47264452,47677446,47975175,47975238,47975323,47975324,47975325,47975325,47975326,47975327,47975327,47975328,48033015,48201575,46964647,47264452,48201575,48201575,47511691,47975329,48201575,48201576,48201576,47975365,48201577,48201579,47046345,47815765,48242430,48242477,47129495,47373726,47203400,48320960,47537611,47560801,47564252,47564268,47564269,47564270,47564271,47564276,47564271,47564271,47564275,47564271,47564272,48275145,47564285,48074729,48275145,48275146,48275147,48275185,48501394,48501395,48501395,48501396,48501399,48501400,47583990,47987123,47617955,48301984,47650062,48544304,47777482,48608000,48058747,48522380,48207240,48207245,48207245,48596635,48822884,48822888,48244780,48841648,48360942,48360943,48360949,48537723,48899729,48899734,48390258,48390259,48390258,48390260,48487719,48487720,48688136,48688138,48914389,48914389,48585182,48585183,48585182,48585183,48585190,48585183,48585188,48585188,48585191,48585186,48638572,48785599,48785604,48785642,49011851,49011851,49011898,48785605,48785614,49011854,48785605,49011858,48691960,49065238,48714519,48714520,48714536,48714568,48714595,48714612,48714596,48714591,48714618,48714669,48714670,48714671,48850174,48714687,48714697,48850351,49076601,49076601,48850355,48916496,48951254,48985613,48985632,48985633,48985653,49212072,49212090,49212091,48985780,49212112,48985836,48985843,48985848,48985934,49212180,49121230,49212182,48985932,48985901,49212255,48986000,48986004,48986019,48986024,48986025,48986001,48986001,48986021,48986024,48986027,48986005,48986005,48986024,48986025,48986025,48986030,48986003,48986005,48986024,48986025,48986003,48986006,48986018,48986023,48986024,48986006,48986013,48986019,48986020,48986022,48986023,48986026,48986027,48986032,48986007,48986012,48986024,48986024,48986025,48986026,48986029,48986029,48986031,48986032,48986008,48986008,48986020,48986023,48986023,48986026,48986027,48986028,48986029,48986030,48986030,48986031,48986009,48986030,48986009,48986009,48986016,48986027,48986033,48986009,48986025,48986026,48986026,48986027,48986029,48986030,48986032,48986034,48986034,48986010,48986011,48986023,48986025,48986025,48986027,48986028,48986029,48986029,48986030,48986030,48986034,48986035,48986011,48986026,48986027,48986028,48986033,48986033,48986035,48986026,48986030,48986030,48986032,48986033,48986034,48986034,48986035,48986035,48986036,48986035,48986043,48986028,48986042,48986044,48986044,48986032,48986045,48986039,48986046,48986049,48986049,48986049,48986046,48986050,49212269,49212269,49212270,48986043,48986052,48986054,49212271,48986053,48986041,48986048,49212272,48986045,48986048,49212273,48986050,48986044,48986046,49015420,49212274,48986045,48986046,49212274,48986050,48986051,49212275,48986048,48986049,49212275,49212275,48986065,48986067,49212276,48986052,49212276,49212276,48986053,48986057,49212020,49212277,48986057,48986068,49212277,48986051,49212278,48986069,49212278,48986060,49212279,48986069,49212279,48986055,48986071,49212280,48986057,48986058,49212280,49212327,48986058,49212280,49212281,48986059,48986072,49212281,49212281,48986059,48986063,49212282,48986068,49121330,49212282,49212282,49212329,49212283,49212329,49212284,49212285,48986067,48986076,49212285,49212285,49212286,49212286,49212286,49212287,48986098,49212288,48986099,48986097,48986101,48986102,48986103,48986103,48986103,48986104,48986104,48986105,48986102,48986102,48986105,48986105,48986106,48986112,48986113,49212311,49212311,49212313,49212313,49212314,49212314,49212314,49212361,49212314,49212315,49212316,48990092,49214318,49044827,49241681,49045003,49241759,49101396,49269955,49256612,49256614,49347565,49347565,49438064,49438321,49438504,49438505,49438506,49438506,49438507,49438507,49438508,49438509,49438511,49438512,49438513,49438513,49438515,49438516,49438519,49438520,49438522,49438524,49438526,49438526,49438527,49438528,49438528,49438530,49438531,49438532,49438532,49438534,49438536,49438537,49438537,49438540,49438542,49438542,49438543,49438544,49438545,49438545,49438547,49438548,49438548,49438549,49438549,49438550,49438550,49438551,49438551,49438506,49438507,49438507,49438508,49438509,49438514,49438515,49438518,49438524,49438526,49438527,49438528,49438532,49438534,49438536,49438539,49438541,49438542,49438542,49438546,49438548,49438548,49438549,49438549,49438550,49438550,49438551,49438551,49438552,49438507,49438508,49438509,49438509,49438514,49438518,49438527,49438527,49438528,49438528,49438538,49438543,49438549,49438550,49438551,49438552,49438552,49438534,49438539,49438542,49438551,49438552,49438552,49438509,49438510,49438511,49438514,49438520,49438521,49438528,49438534,49438544,49438551,49438552,49438552,49438553,49438511,49438516,49438526,49438553,49438553,49438516,49438512,49438517,49438518,49438519,49438521,49438521,49438530,49438531,49438539,49438545,49438549,49438552,49438553,49438554,49438554,49438554,49438555,49438542,49438533,49438548,49438558,49438559,49438524,49438528,49438528,49438534,49438534,49438535,49438538,49438540,49438541,49438546,49438547,49438548,49438550,49438551,49438557,49438558,49438559,49438559,49438548,49438560,49438561,49438561,49438527,49438549,49438561,49438561,49438562,49438563,49438538,49438549,49438554,49438559,49438562,49438539,49438555,49438564,49438561,49438565,49438565,49438565,49438568,49438545,49438547,49438569,49438570,49438568,49438547,49438549,49438549,49438553,49438560,49438563,49438565,49438568,49438571,49438571,49438572,49438572,49438550,49438553,49438563,49438571,49438572,49438572,49438564,49438559,49438572,49438573,49438573,49438574,49438554,49438573,49438574,49438562,49438574,49438574,49438575,49438574,49438576,49438559,49438574,49438575,49438577,49438563,49438564,49438567,49438571,49438577,49438578,49438578,49438569,49438579,49438578,49438579,49438579,49438580,49438580,49438571,49438574,49438575,49438582,49438572,49438582,49438583,49438572,49438576,49438583,49438584,49438573,49438583,49438584,49438582,49438584,49438584,49438614,49438580,49438581,49438583,49438585,49438585,49438586,49438576,49438586,49438586,49438586,49438587,49438586,49438587,49438588,49438584,49438587,49438589,49438583,49438586,49438590,49438589,49438590,49438590,49438590,49438591,49438591,49438591,49438591,49438592,49438589,49438592,49438593,49438593,49438592,49438593,49438593,49438591,49438593,49438593,49438594,49438593,49438594,49438594,49438595,49438594,49438594,49438595,49438595,49438595,49438595,49438595,49438596,49438596,49438596,49438597,49438597,49438598,49438599,49438599,49438600,49438600,49438601,49438601,49438602,49438603,49438604,49438610,49438616,49438624,49438626,49438627,49438599,49438600,49438600,49438601,49438601,49438602,49438602,49438603,49438608,49438600,49438601,49438601,49438602,49438602,49438603,49438601,49438602,49438602,49438603,49438603,49438611,49438626,49438602,49438603,49438603,49438604,49438607,49438603,49438604,49438604,49438605,49438604,49438605,49438606,49438612,49438605,49438606,49438606,49438608,49438609,49438623,49438630,49438606,49438607,49438607,49438608,49438608,49438609,49438611,49438612,49438612,49438613,49438623,49438607,49438609,49438613,49438608,49438609,49438609,49438610,49438610,49438612,49438612,49438620,49438624,49438627,49438630,49438631,49438609,49438610,49438610,49438611,49438610,49438611,49438611,49438612,49438613,49438614,49438616,49438616,49438618,49438626,49438629,49438631,49438612,49438613,49438613,49438614,49438614,49438615,49438615,49438616,49438616,49438617,49438617,49438618,49438619,49438620,49438623,49438623,49438624,49438625,49438625,49438626,49438626,49438627,49438628,49438630,49438630,49438614,49438615,49438615,49438616,49438616,49438617,49438626,49438627,49438615,49438616,49438616,49438617,49438617,49438618,49438618,49438628,49438616,49438617,49438617,49438618,49438618,49438619,49438619,49438620,49438620,49438621,49438623,49438623,49438624,49438624,49438626,49438628,49438628,49438629,49438630,49438617,49438618,49438618,49438619,49438619,49438620,49438620,49438622,49438625,49438626,49438627,49438627,49438629,49438618,49438619,49438619,49438620,49438620,49438621,49438622,49438623,49438624,49438625,49438626,49438627,49438629,49438633,49438636,49438619,49438620,49438620,49438621,49438622,49438623,49438624,49438624,49438626,49438627,49438628,49438629,49438629,49438630,49438630,49438620,49438621,49438624,49438626,49438629,49438630,49438621,49438622,49438622,49438623,49438623,49438624,49438625,49438625,49438626,49438626,49438627,49438627,49438628,49438629,49438629,49438630,49438630,49438631,49438631,49438622,49438623,49438623,49438624,49438624,49438625,49438625,49438626,49438626,49438627,49438627,49438628,49438628,49438629,49438629,49438630,49438630,49438631,49438631,49438632,49438632,49438635,49438635,49438636,49438623,49438624,49438625,49438625,49438626,49438626,49438627,49438627,49438628,49438629,49438629,49438630,49438630,49438631,49438631,49438632,49438632,49438633,49438624,49438626,49438627,49438629,49438630,49438631,49438632,49438625,49438626,49438626,49438627,49438627,49438628,49438628,49438629,49438629,49438630,49438631,49438631,49438632,49438633,49438638,49438626,49438627,49438628,49438628,49438629,49438630,49438630,49438631,49438632,49438627,49438628,49438628,49438629,49438630,49438632,49438628,49438629,49438629,49438630,49438630,49438631,49438631,49438632,49438632,49438633,49438634,49438635,49438635,49438629,49438630,49438631,49438631,49438632,49438633,49438634,49438635,49438636,49438630,49438631,49438631,49438632,49438632,49438633,49438633,49438634,49438635,49438635,49438637,49438631,49438632,49438633,49438634,49438634,49438636,49438637,49438632,49438633,49438633,49438634,49438634,49438635,49438636,49438636,49438633,49438634,49438634,49438635,49438635,49438636,49438636,49438637,49438637,49438638,49438640,49438640,49438634,49438635,49438635,49438637,49438635,49438636,49438636,49438637,49438637,49438638,49438638,49438643,49438636,49438637,49438637,49438638,49438638,49438637,49438638,49438638,49438639,49438639,49438644,49438638,49438639,49438639,49438640,49438640,49438641,49438639,49438640,49438640,49438640,49438641,49438642,49438645,49438641,49438642,49438642,49438643,49438643,49438644,49438644,49438645,49438646,49438646,49438647,49438648,49438648,49438642,49438643,49438643,49438644,49438644,49438645,49438646,49438646,49438648,49438649,49438643,49438644,49438644,49438645,49438645,49438646,49438646,49438647,49438647,49438649,49438644,49438645,49438645,49438646,49438646,49438647,49438648,49438645,49438646,49438646,49438648,49438646,49438647,49438647,49438648,49438647,49438648,49438649,49438649,49438650,49438651,49438648,49438649,49438649,49438650,49438650,49438651,49438652,49438649,49438650,49438650,49438652,49438650,49438651,49438651,49438652,49438653,49438653,49438652,49438653,49438653,49438654,49438653,49438654,49438654,49438654,49438655,49438655,49438702,49438656,49438657,49438657,49438658,49438658,49438659,49438660,49438660,49438661,49438661,49438662,49438663,49438663,49438664,49438664,49438666,49438666,49438668,49438668,49438669,49438669,49438671,49438672,49438672,49438674,49438675,49438677,49438678,49438684,49438688,49438689,49438690,49438691,49438694,49438701,49438702,50238864,50785204,50810227,54415824,55491880,49438657,49438658,49438658,49438659,49438659,49438660,49438660,49438661,49438662,49438663,49438664,49438665,49438666,49438666,49438667,49438669,49438669,49438670,49438670,49438672,49438674,49438674,49438678,49438678,49438679,49438680,49438691,49438699,49438700,49438701,49438701,49438702,49438703,49438658,49438659,49438659,49438660,49438661,49438661,49438664,49438665,49438666,49438669,49438669,49438672,49438680,49438687,49438703,49438659,49438660,49438660,49438661,49438662,49438663,49438664,49438664,49438665,49438665,49438666,49438667,49438668,49438669,49438670,49438673,49438693,49438702,49438704,49438660,49438661,49438662,49438662,49438663,49438663,49438664,49438664,49438665,49438665,49438666,49438666,49438668,49438669,49438670,49438671,49438671,49438672,49438673,49438680,49438680,49438683,49438684,49438685,49438702,49438704,49438661,49438662,49438662,49438663,49438663,49438664,49438664,49438665,49438665,49438666,49438666,49438667,49438668,49438669,49438669,49438670,49438670,49438671,49438671,49438672,49438674,49438677,49438677,49438680,49438681,49438681,49438691,49438693,49438697,49438700,49438705,50019093,49438663,49438664,49438665,49438666,49438667,49438667,49438670,49438671,49438689,49438663,49438664,49438665,49438666,49438672,49438675,49438694,49438706,49438664,49438665,49438665,49438666,49438666,49438667,49438668,49438668,49438670,49438672,49438673,49438674,49438675,49438677,49438681,49438706,49438665,49438666,49438667,49438667,49438668,49438669,49438670,49438672,49438674,49438675,49438676,49438679,49438683,49438689,49438695,49438707,49438666,49438668,49438669,49438671,49438674,49438707,49438667,49438668,49438668,49438669,49438670,49438673,49438675,49438691,49438708,49438668,49438669,49438670,49438670,49438672,49438675,49438676,49438677,49438669,49438670,49438671,49438678,49438685,49438670,49438671,49438671,49438672,49438672,49438673,49438673,49438674,49438674,49438675,49438675,49438676,49438676,49438677,49438678,49438679,49438680,49438681,49438684,49438685,49438693,49438698,49438709,49438709,49438671,49438672,49438673,49438673,49438674,49438675,49438675,49438676,49438679,49438672,49438673,49438674,49438675,49438675,49438677,49438677,49438678,49438679,49438683,49438698,49438710,49438674,49438674,49438675,49438675,49438676,49438676,49438677,49438677,49438678,49438679,49438679,49438680,49438680,49438681,49438681,49438682,49438684,49438686,49438687,49438690,49438694,49438696,49438698,49438702,49438706,49438708,49438711,49438676,49438675,49438676,49438677,49438678,49438678,49438679,49438681,49438681,49438696,49438712,49438676,49438677,49438677,49438678,49438678,49438679,49438679,49438680,49438681,49438681,49438688,49438689,49438693,49438701,49438710,49438712,49438678,49438678,49438679,49438679,49438680,49438682,49438688,49438689,49438696,49438678,49438680,49438682,49438682,49438686,49438696,49438713,49438713,49438679,49438680,49438680,49438681,49438682,49438683,49438684,49438685,49438686,49438689,49438690,49438702,49438680,49438681,49438681,49438682,49438683,49438687,49438689,49438695,49438697,49438703,49438713,49438714,49438681,49438682,49438682,49438683,49438684,49438687,49438690,49438711,49438713,49438715,49438682,49438683,49438683,49438684,49438688,49438691,49438697,49438700,49438703,49438713,49438715,49438683,49438684,49438684,49438685,49438686,49438687,49438687,49438688,49438690,49438691,49438692,49438694,49438699,49438704,49438716,49438684,49438685,49438685,49438686,49438688,49438698,49438699,49438705,49438713,49438685,49438686,49438686,49438687,49438687,49438689,49438690,49438692,49438692,49438709,49438717,49438686,49438687,49438688,49438689,49438690,49438692,49438694,49438687,49438688,49438688,49438689,49438689,49438690,49438690,49438692,49438692,49438693,49438693,49438694,49438694,49438695,49438695,49438696,49438699,49438699,49438700,49438700,49438701,49438702,49438703,49438703,49438704,49438705,49438705,49438706,49438707,49438708,49438709,49438712,49438714,49438714,49438715,49438716,49438716,49438717,49438718,49438688,49438689,49438689,49438690,49438691,49438694,49438698,49438707,49438711,49438718,49438689,49438690,49438691,49438695,49438702,49438719,49438690,49438691,49438692,49438694,49438695,49438696,49438701,49438702,49438704,49438719,49438692,49438692,49438694,49438695,49438695,49438696,49438696,49438697,49438698,49438700,49438703,49438708,49438717,49438692,49438701,49438704,49438708,49438717,49438720,49438693,49438696,49438697,49438704,49438707,49438694,49438695,49438695,49438696,49438696,49438697,49438697,49438698,49438698,49438700,49438701,49438703,49438704,49438705,49438705,49438706,49438707,49438708,49438710,49438712,49438713,49438716,49438718,49438718,49438719,49438721,49438721,49438697,49438698,49438698,49438699,49438702,49438706,49438698,49438698,49438698,49438699,49438701,49438706,49438699,49438699,49438700,49438700,49438702,49438705,49438709,49438712,49438721,49438723,49438699,49438700,49438700,49438709,49438712,49438715,49438700,49438701,49438701,49438702,49438702,49438703,49438704,49438704,49438705,49438706,49438707,49438708,49438709,49438710,49438711,49438712,49438713,49438714,49438715,49438717,49438721,49438722,49438723,49438723,49438724,49438701,49438702,49438703,49438704,49438705,49438705,49438706,49438706,49438707,49438708,49438709,49438709,49438710,49438711,49438713,49438714,49438716,49438720,49438721,49438722,49438723,49438702,49438703,49438703,49438704,49438705,49438706,49438707,49438707,49438708,49438709,49438710,49438711,49438712,49438714,49438715,49438717,49438719,49438720,49438720,49438721,49438722,49438722,49438724,49438725,49438705,49438706,49438707,49438707,49438708,49438708,49438709,49438709,49438710,49438710,49438711,49438717,49438718,49438721,49438724,49438709,49438711,49438712,49438715,49438705,49438712,49438707,49438709,49438710,49438710,49438711,49438713,49438715,49438716,49438724,49438711,49438712,49438725,49438726,49438711,49438712,49438713,49438724,49438710,49438710,49438712,49438714,49438717,49438725,49438710,49438726,49438728,49438711,49438713,49438714,49438715,49438718,49438719,49438727,49438730,49438713,49438713,49438714,49438715,49438716,49438720,49438722,49438726,49438727,49438729,49438730,49438714,49438715,49438715,49438716,49438730,49438731,49438715,49438716,49438720,49438723,49438726,49438716,49438716,49438717,49438718,49438718,49438719,49438720,49438720,49438721,49438721,49438722,49438723,49438726,49438727,49438728,49438729,49438730,49438731,49438731,49438732,49438717,49438718,49438717,49438718,49438718,49438719,49438721,49438721,49438722,49438723,49438724,49438728,49438729,49438730,49438730,49438731,49438733,49438719,49438720,49438721,49438721,49438722,49438723,49438724,49438725,49438725,49438727,49438728,49438730,49438730,49438731,49438731,49438732,49438733,49438720,49438723,49438720,49438721,49438721,49438722,49438722,49438723,49438723,49438724,49438725,49438725,49438726,49438726,49438728,49438728,49438729,49438729,49438730,49438731,49438731,49438732,49438732,49438733,49438733,49438734,49438734,49438721,49438725,49438730,49438723,49438724,49438725,49438726,49438727,49438730,49438731,49438732,49438733,49438734,49438734,49438735,49438724,49438725,49438734,49438735,49438725,49438727,49438728,49438729,49438732,49438733,49438734,49438735,49438736,49438725,49438726,49438727,49438729,49438730,49438732,49438733,49438734,49438734,49438735,49438735,49438736,49438737,49438726,49438727,49438727,49438728,49438728,49438729,49438729,49438730,49438730,49438732,49438732,49438733,49438734,49438734,49438735,49438735,49438736,49438736,49438737,49438737,49438727,49438728,49438729,49438731,49438733,49438733,49438734,49438736,49438738,49438728,49438729,49438730,49438731,49438735,49438737,49438738,49438738,49438729,49438730,49438733,49438735,49438737,49438738,49438739,49438730,49438731,49438734,49438735,49438736,49438738,49438738,49438739,49438731,49438732,49438735,49438737,49438732,49438733,49438734,49438734,49438735,49438736,49438737,49438737,49438738,49438738,49438739,49438740,49438734,49438735,49438736,49438737,49438738,49438738,49438741,49438735,49438738,49438738,49438739,49438740,49438741,49438736,49438737,49438737,49438741,49438737,49438738,49438738,49438739,49438740,49438741,49438741,49438742,49438743,49438738,49438740,49438741,49438741,49438742,49438739,49438740,49438740,49438741,49438741,49438742,49438742,49438743,49438744,49438741,49438741,49438742,49438743,49438744,49438741,49438742,49438742,49438743,49438743,49438744,49438745,49438742,49438743,49438743,49438744,49438744,49438745,49438745,49438743,49438744,49438744,49438745,49438745,49438746,49438744,49438745,49438745,49438746,49438746,49438745,49438746,49438746,49438747,49438746,49438747,49438747,55491925,49438747,49438748,49438748,49438749,49438753,49438754,49438786,49446300,49610091,49610096,49610099,49610100,49610101,49610103,49662833,49776770,49798726,49804469,49804471,49804473,49804474,49804478,49819816,49833619,49833667,49874225,49886361,50019134,50019135,50019136,50019136,50019137,50019137,50019138,50019138,50019139,50019139,50019140,50019140,50019141,50019142,50019144,50238908,50238908,50238909,50238909,50238910,50238910,50238911,50238911,50238912,50238912,50238913,50238913,50331837,50331837,50331840,50331840,50761107,50785247,50785248,50785249,50785249,50785250,50785250,50785251,50785266,50785268,50810276,50810280,50810281,50811343,50811344,50811345,50811345,51848522,52186229,52707957,52772422,53242584,53303875,53303876,53483751,53856310,53889908,54415869,54539039,54539040,55491927,49438754,49610101,49610102,49833619,50019137,50019138,50019139,50019139,50785252,50019141,49610104,49610105,50019142,50019143,50019143,50019144,50019144,50238915,50331844,50785254,50785255,49610139,49804509,50019174,50019175,50019176,50238947,50238948,50238949,50785287,49453863,50026703,49781454,49781459,49781467,49781467,49781469,49781469,49781469,49781469,49781471,49781471,49781472,50190500,50190501,50190505,50190506,50190507,50190506,50190506,50190507,50190508,50190508,50190508,49886933,50243239,50114804,50114805,50114806,50114806,50357172,51123283,50357174,50357174,51123286,50357175,50158723,50379135,50170209,50170209,50170211,50170213,50170213,50170219,50384876,50384876,50384877,50384878,51150990,50384879,50200908,50620003,50228564,50228613,50228647,50228650,50228696,50228730,50228733,50414132,50414166,50414167,51206374,50309713,50356041,50334015,50466792,50402369,50500954,50599524,50599538,50599525,50599524,50599525,50599525,50599526,50599540,50599525,50599526,50599526,50599540,50599542,50599543,50599526,50599527,50599527,50599528,50599529,50599541,50599541,50599543,50599543,50599527,50599528,50599528,50599542,50599542,50599543,50599543,50599545,50599528,50599529,50599529,50599530,50599530,50599531,50599541,50599541,50599542,50599542,50599543,50599543,50599544,50599545,50599545,50599546,50599546,50599529,50599530,50599531,50599531,50599532,50599538,50599541,50599542,50599543,50599543,50599544,50599544,50599545,50599530,50599531,50599531,50599532,50599532,50599541,50599541,50599543,50599543,50599544,50599544,50599545,50599545,50599546,50599546,50599547,50599547,50599531,50599532,50599542,50599543,50599544,50599545,50599545,50599546,50599546,50599547,50599532,50599533,50599545,50599546,50599547,50599548,50599534,50599534,50599545,50599545,50599546,50599546,50599547,50599548,50599549,50599534,50599535,50599543,50599546,50599546,50599547,50599548,50599549,50599549,50599546,50599547,50599547,50599548,50599549,50599550,50599547,50599549,50599552,50599551,50599557,50599556,50599558,50599555,50599557,50599558,50601102,50599556,50599557,50599556,50599557,50599557,50819313,50819313,50819314,50912238,51365652,51365653,51365653,50599557,50599558,50599558,50599559,50599559,50599560,50599560,50819313,50819313,50819314,50819315,50819316,50912241,51365653,51365653,51365654,51365654,50599558,50599559,50599559,50599560,50599560,50599561,50599561,50819312,50819314,50819315,50819318,50912242,51107520,51365653,51365653,51365654,51365654,51365655,54470312,50599559,50599560,50599560,50599561,50599561,50599562,50819314,50819315,50819315,50819316,50819317,50819318,50819318,50912242,51365653,51365653,51365654,51365654,51365655,51365655,51365656,50599560,50599561,50599561,50599562,50599562,50819314,50819314,50819315,50819316,50819316,50819317,50819317,50819318,50912245,50912246,51365654,51365654,51365655,51365655,51365656,51365656,51365671,51365674,50599561,50599562,50599562,50819315,50819316,50819317,50819317,50819319,51365654,51365655,51365656,51365656,51365673,50599562,50599563,50599563,50819312,50819314,50819315,50819315,50819316,50819316,50819317,50819317,50819318,50819318,50819319,50819320,50912243,50912244,50912244,51365655,51365655,51365656,51365656,51365657,51365657,50599563,50599564,50599564,50819316,50819316,50819317,50819317,50819318,50819318,50819319,50819319,50819321,51365655,51365656,51365656,51365657,51365657,50599564,50599565,50819315,50819316,50819317,50819317,50819318,50819318,50819319,50912245,50912247,50912248,51019282,51365656,51365657,51365657,51365674,50599565,50819315,50819316,50819317,50819317,50819318,50819318,50819319,50819319,50819320,50912245,50912248,51107523,51130494,51365656,51365657,51365657,51365658,51365658,50819317,50819317,50819320,50819322,51365657,51365657,50602662,50913798,51039079,51039084,51039069,51039069,51039070,51039084,51039085,51039068,51039069,51039070,51039071,51039071,51039085,51039086,51039086,51039070,51039071,51039071,51039072,51039072,51039084,51039084,51039086,51039086,51039070,51039071,51039071,51039072,51039072,51039085,51039085,51039086,51039086,51039087,51039087,51039071,51039072,51039072,51039073,51039074,51039086,51039086,51039087,51039087,51039088,51039072,51039073,51039074,51039075,51039085,51039086,51039087,51039087,51039088,51039088,51039073,51039074,51039087,51039088,51039088,51039089,51039074,51039075,51039075,51039076,51039087,51039088,51039088,51039089,51039089,51039075,51039077,51039087,51039088,51039088,51039089,51039089,51039090,51039088,51039089,51039090,51039090,51039077,51039078,51039089,51039090,51039079,51039090,51039090,51039091,51039091,51039090,51039092,51039091,51039092,51585421,51039100,51585425,51039102,51039102,51585424,51585425,51039101,51039102,51039102,51585424,51585426,51585426,51039102,51039103,51039103,51132012,51132015,51132016,51284384,51585425,51585425,51585426,51585427,51610456,51039103,51039104,51130871,51132014,51585425,51585426,51585426,51585427,51585427,51039104,51132014,51132015,51132015,51132016,51132018,51171950,51494565,51585423,51585425,51585425,51585426,51585426,51585427,51585427,51585428,51585428,51585443,51585444,51611522,52648699,54202492,54656488,56292104,51039105,51132015,51132016,51132018,51132018,51239037,51350264,51585425,51585426,51585426,51585427,51585427,51585428,51585428,51585429,56292105,52648700,51222705,51677260,51224938,51224927,51224938,51224940,51224940,51224928,51224937,51224939,51224941,51224938,51224939,51224939,51224941,51224942,51224942,51224943,51224943,51224944,51678350,51678349,51678350,51678351,51678350,51678352,54783010,51593617,51678349,51678351,51678352,51678352,51678353,51678353,51678354,51678354,54783011,51304811,51718287,51438996,51439011,51439048,51439052,51439077,51439119,51785416,51785448,51529680,51830723,51615497,51873631,51873632,51661433,51896595,51896596,51950045,52040906,51962280,51962351,51962423,52047086,52083515,52107658,52131745,52131747,52131748,52131747,52131747,52131748,52131749,52131747,52131748,52131749,52131761,52131748,52131749,52131749,52131750,52131750,52131763,52131764,52131765,52131779,52131749,52131750,52131750,52131751,52131763,52131768,52131769,52131750,52131751,52131751,52131765,52131766,52131751,52131752,52131752,52131763,52131764,52131764,52131765,52131766,52131766,52131767,52131767,52131768,52131770,52131752,52131753,52131753,52131756,52131757,52131760,52131761,52131763,52131764,52131764,52131765,52131765,52131766,52131766,52131767,52131767,52131768,52131768,52131769,52131770,52131771,52131777,52131753,52131754,52131754,52131755,52131755,52131756,52131756,52131757,52131758,52131758,52131759,52131759,52131760,52131760,52131761,52131761,52131762,52131762,52131763,52131763,52131764,52131764,52131765,52131765,52131766,52131766,52131767,52131767,52131768,52131768,52131769,52131769,52131770,52131770,52131771,52131772,52131772,52131775,52131780,52131781,52131785,52131756,52131760,52131762,52131763,52131764,52131766,52131766,52131767,52131767,52131768,52131768,52131770,52131784,52131764,52131767,52131768,52131768,52131757,52131767,52131768,52131762,52131764,52131768,52131764,52131766,52131768,52131769,52131770,52131763,52131764,52131768,52131764,52131768,52131771,52131769,52131771,52131771,52131771,52131772,52131766,52131771,52131769,52131769,52131771,52131772,52131774,52131772,52131774,52131775,52131768,52131769,52131771,52131773,52131774,52131775,52131775,52131769,52131771,52131773,52131774,52131774,52131771,52131772,52131773,52131774,52131775,52131772,52131775,52131776,52131776,52131778,52131776,52131776,52131777,52131774,52131776,52131777,52131775,52131776,52131776,52131777,52131778,52131777,52131777,52131778,52131778,53195035,52131777,52131777,52131778,52131778,52131779,52131780,52131777,52131778,52131778,52131779,52131779,52131780,52131778,52131779,52131779,52131780,52131780,52131781,52131781,52131779,52131780,52131780,52131781,52131781,52131782,52131783,52131780,52131781,52131781,52131782,52131783,52131792,52156793,52157858,54054473,52131781,52131782,52131782,52131783,52131783,52131784,52131784,52131785,52131787,52131800,52156790,52131782,52131783,52131783,52131784,52131784,52131785,52131785,52131786,52131788,52131791,52131792,52131796,52131801,52156789,52156795,52157859,54235024,55762386,55885556,56838443,52131783,52131784,52131784,52131785,52131785,52131786,52131786,52131787,52131787,52131788,52131789,52131789,52131790,52131792,52131793,52131794,52131795,52131796,52131797,52131801,52131803,52156795,52156796,52156797,52157860,52157861,52157862,52157862,53022398,53083083,53195039,53670579,54054473,54054474,54496124,54748831,55762386,55762387,55762387,52131784,52131785,52131785,52131786,52131786,52131787,52131787,52131788,52131788,52131789,52131790,52131790,52131791,52131792,52131792,52131793,52131794,52131794,52131795,52131796,52131797,52131798,52131801,52131803,52156791,52156791,52156793,52156795,52156796,52156796,52156797,52156797,52156798,52157862,52157863,53022401,53195038,53195038,53195039,53195040,53195040,53532746,54054473,54054475,54830271,55202829,55236425,55762387,55762388,55885556,56838444,52131785,52131786,52131786,52131787,52131787,52131788,52131788,52131789,52131789,52131790,52131792,52131794,52131796,52131798,52131798,52131802,52131804,52156798,52157862,52157863,53195039,53195040,55236426,55762387,55762388,52131786,52131787,52131787,52131788,52131788,52131789,52131790,52131790,52131791,52131791,52131792,52131793,52131798,52131799,52131802,52131803,52131804,52131804,52156796,52156796,52156798,52157862,52157863,52559475,53195040,53532747,54054473,54071903,54650395,54748833,55762388,55762389,55885557,55885559,52131787,52131788,52131788,52131789,52131789,52131790,52131790,52131791,52131791,52131793,52131793,52131795,52131796,52131797,52131797,52131799,52131800,52131801,52131803,52131803,52131804,52131804,52131805,52156792,52156797,52156799,52156800,52156800,52157863,52157864,52387964,52502281,53083085,53195041,53195041,53195042,53195042,54054473,54650395,54748833,54830272,55762389,55762389,55885559,55885559,56838446,52131788,52131789,52131789,52131790,52131790,52131791,52131792,52131793,52131794,52131798,52131799,52131800,52131801,52131802,52131803,52131805,52156797,52156799,52156800,52157862,52157863,52157865,52387963,53195040,53195041,53195042,53763415,54054476,54235117,55762389,55762390,52131789,52131790,52131790,52131791,52131791,52131792,52131792,52131795,52131796,52131797,52131798,52131804,52131804,52131806,52156799,52156800,52157864,52157865,52157865,55236428,52131790,52131791,52131791,52131792,52131792,52131793,52131794,52131794,52131795,52131798,52131799,52131800,52131802,52131804,52131805,52131805,52131806,52156793,52156795,52156797,52156800,52156800,52157863,52157864,52157864,52157865,53195042,54650395,55885559,55885560,52131791,52131792,52131792,52131793,52131793,52131794,52131795,52131797,52131798,52131800,52131801,52131801,52131802,52131804,52131805,52131806,52131806,52156794,52156802,52157865,52157866,53195043,55762390,55762391,55885561,56838448,52131792,52131793,52131793,52131794,52131796,52131798,52131800,52131801,52131802,52131802,52131803,52131805,52131806,52131807,52156795,54496131,55762392,52131793,52131794,52131795,52131796,52131796,52131797,52131797,52131798,52131799,52131800,52131801,52131802,52131806,52131806,52131807,52131808,52156795,52157864,52157865,53195044,54830275,55762392,52131796,52131796,52131797,52131798,52131799,52131802,52131803,52131806,52131807,52131797,52131802,52131802,52131803,52131807,52157866,53195044,53195045,53195046,52131800,52131801,52131803,52131805,52131807,52131808,52131809,52131809,52156797,53195045,55762393,55885562,55885563,52131804,52131808,52131809,52131803,52131804,52131805,52156802,52157868,53195045,55762394,52131803,52131806,52131809,52131810,52157868,53195047,55514192,52131804,52131809,52131810,52131812,52156799,52156803,52156804,53195046,54054482,52131807,52131810,52131811,53195047,52131804,52131806,52131810,52131811,52156800,52156806,52131804,52157872,55236435,52131806,52131807,52131811,52131813,52156809,52157873,52157874,55762398,52131811,52131812,52156807,52157873,53195050,55762398,52131808,55762397,52131813,52131813,52156808,52156809,52157871,52157872,52157873,52157874,54054485,56838456,52131813,52131815,52156803,52156807,52156809,52328216,54748845,55762399,55885569,52131810,52131814,52131815,52156803,53195052,54054486,54054487,52131814,52131815,52156810,53195052,52131811,52131812,52131815,52131816,52156809,52156810,52156811,52156812,52157874,52157876,53195052,53195053,53195054,54054487,54650407,56838458,52131813,52131815,52131815,52131817,52156810,52156812,52157874,52157875,53195053,52131815,52131816,52156806,52156810,52156812,52157875,52157877,53195052,53195054,52131816,52156812,52633445,55885572,52131817,52131817,52156811,52156812,52131817,52131818,52156807,52156812,52156808,52131819,52131820,52131820,52131821,52156807,52156808,52156808,52156809,52156809,52156811,52156813,52156813,52156814,52156814,52156815,52156816,52157875,52157876,52157876,52157877,52157879,52157879,53001744,53083088,53195056,53195057,54235107,52131820,52131821,52131821,52156808,52156808,52156809,52156809,52156810,52156814,52156814,52156815,52157876,52157877,52157880,52157881,52391778,53001745,53195056,53195057,55885574,56838462,52131821,52131822,52156809,52156809,52156810,52156812,52157878,53195058,53195059,55762405,55762405,52131822,52156809,52156809,52156810,52156810,52156811,52156812,52156815,52156816,52156817,52157879,52157880,52157882,53022420,53195057,53195057,53195058,53195059,53532765,54830290,52131823,52156809,52156810,52156810,52156811,52156811,52156813,52156814,52156815,52156816,52156818,52156820,52157878,52157878,52157879,52157880,52157881,52157882,53195058,53195058,53195059,53195060,54054494,54748852,55762406,55885576,52156810,52156811,52181796,52181797,52181797,52181811,52181814,52181816,52181817,52181797,52181798,52181798,52181801,52181803,52181804,52181812,52181812,52181814,52181814,52181815,52181816,52181817,52181798,52181799,52181801,52181802,52181802,52181803,52181803,52181804,52181805,52181806,52181806,52181813,52181813,52181814,52181814,52181815,52181815,52181816,52181816,52181818,52181818,52181821,52181799,52181800,52181801,52181802,52181803,52181803,52181804,52181804,52181805,52181805,52181806,52181807,52181809,52181813,52181814,52181814,52181815,52181815,52181816,52181817,52181818,52181818,52181803,52181804,52181805,52181805,52181806,52181813,52181817,52181818,52181819,52181819,52181802,52181804,52181805,52181822,52181813,52181805,52181805,52181807,52181808,52181823,52181808,52181815,52181817,52181818,52181818,52181819,52181820,52181824,52181827,52181807,52181808,52181809,52181810,52181820,52181822,52181822,52181824,52181825,52181825,52181827,52181808,52181809,52181809,52181810,52181819,52181819,52181820,52181820,52181822,52181824,52181825,52181826,52181827,52181827,52181809,52181810,52181810,52181819,52181821,52181823,52181826,52181826,52181827,52181828,52181811,52181811,52181818,52181820,52181821,52181821,52181822,52181823,52181825,52181826,52181826,52181827,52181827,52181812,52181820,52181822,52181823,52181825,52181826,52181826,52181827,52181827,52181828,52181829,52181829,52181820,52181821,52181822,52181822,52181824,52181826,52181827,52181827,52181828,52181829,52181813,52181821,52181822,52181826,52181827,52181827,52181828,52181828,52181829,52181822,52181822,52181823,52181827,52181829,52181825,52181830,52181826,52181832,52181827,52181826,52181829,55787409,52181830,52181830,54675415,52181830,52181830,52181831,52182880,53220062,55787410,52181829,52181830,52181832,52181832,52181833,52181837,52181838,52182881,52182882,53220062,53220062,52181830,52181831,52181833,52181835,52181836,52181837,52182882,52182886,53220060,53220062,52181831,52181832,52181832,52181833,52181833,52181834,52181835,52181837,52181837,52181838,52182883,53220063,55787411,52181832,52181833,52181834,52181835,52181835,52181836,52181837,52182882,52182884,52182884,52182885,52182886,52182887,53220063,53220064,55787411,52181833,52181834,52181835,52181835,52181837,52181838,52181838,52182882,52182886,52182886,53220063,52181834,52181835,52181836,52181836,52181838,52181839,52182883,52182885,52182888,52391935,55787412,52181835,52181837,52181838,52181838,52181839,52181839,52181841,55787413,52181836,52181837,52181838,52181839,52181839,52181840,52182885,52416786,53220065,54675420,52181837,52181839,52181840,52181840,52182886,52182888,52182889,55787414,52181838,52181839,52181840,52181841,52181842,52182885,52182885,52182886,52182887,52182888,52182890,52416787,52584501,53220065,53220066,54773859,55787414,52181840,52181840,52181841,52181842,52182884,52182886,52182887,52584502,53220066,55910584,52181841,52182888,52182889,53047429,52181841,52181842,52181842,52181843,52181844,52181844,52182886,52182888,52182888,52182890,52182891,53220067,53220068,53323196,54079500,54079503,54675422,55151746,55539212,55787416,55787416,56863473,52181842,52181843,52181843,52182886,52182889,52182892,52750982,53220067,53220067,54079503,55787417,55910585,52181843,52181844,52181845,52181845,52181905,52182887,52182889,52182889,52182891,52182892,52182892,52412992,52584505,53108113,53220067,53220068,53220068,53220069,54079503,54079503,54079504,54521156,55227858,55787417,55787417,55910584,55910587,52181845,52182888,52182889,52182889,52182890,52182890,52182891,52182891,52182892,52182892,52182893,52412991,52584504,53026757,53108079,53220068,53220069,53220070,53220071,53561874,54079504,54671144,54773862,55787417,55910586,55910587,52182891,52182892,52182893,52412993,53220069,53220070,54521156,54675424,54773862,55261456,52182890,53220069,53220070,54773864,55787418,52182889,52182890,52182893,52182893,53220070,53220071,53220071,54079504,54521158,54675425,55787419,52182890,52182890,52182893,53220071,52181978,53026830,52183934,52183935,52183946,52183933,52183934,52183934,52183935,52183936,52183937,52183947,52183947,52183948,52183948,52183949,52183935,52183936,52183948,52183948,52183949,52183934,52183935,52183935,52183937,52183948,52183949,52183937,52183938,52183949,52183950,52183950,52183951,52183951,52183952,52183937,52183937,52183938,52183938,52183950,52183951,52183952,52183952,52183938,52183938,52183939,52183953,52183954,52183938,52183939,52183940,52183950,52183952,52183952,52183953,52183954,52183955,52183955,52183940,52183940,52183941,52183952,52183953,52183954,52183954,52183955,52183955,52183940,52183941,52183951,52183952,52183952,52183955,52183955,52183956,52183957,52183958,52183941,52183942,52183950,52183953,52183953,52183954,52183956,52183956,52183957,52183953,52183953,52183955,52183956,52183957,52183957,52183957,52183958,52183958,52183966,52183964,53221128,53221128,53221129,54672198,52183965,53221129,54080564,55788477,52183964,52183965,52183968,53221129,52183965,52183966,52183968,52183968,53221129,53221130,53221130,52183966,52183967,52183968,52183969,52414053,53048492,53221129,53221130,52183967,52183968,52183968,52183969,53221130,53221131,53221131,54080566,54676484,55540274,55788479,55788479,52183970,53221131,53221132,54774924,55788479,52183970,52183970,52209699,53027822,53109114,53221130,53221131,53221132,53221132,54080566,54080566,55262518,55788480,55911650,52183971,53221131,53221132,53221133,53789508,54080567,52741013,53221133,53221133,54080565,54080566,52183972,52227437,52414053,52414054,52520433,52585569,53221131,53221132,53221132,53221133,53221133,53221134,53221134,53221135,53317403,53558840,53789509,54080568,54080569,54080570,54097996,54261212,54522217,54522219,54676488,54856365,54874093,55228922,55228923,55262519,55530860,55788479,55788480,55788481,55788481,55788482,55911650,56018891,56018892,56864538,52862698,53221132,53221134,53562939,54261063,53109178,53221135,52235441,53246872,52270918,54818404,52524647,53198170,52602047,54983969,52644150,52644150,52644152,52644153,53451229,53451230,53451229,53451230,53451231,54491159,52651748,52651748,52651749,53455026,53455026,56022376,52856969,53557670,52872789,55119341,52987178,52987179,52987175,52987178,52987178,52987179,52987267,53622742,53622743,54127912,54482178,54482180,52987357,53622831,53135098,53696706,53298107,53298183,53298256,53298309,54120108,53320164,53789250,53541436,54939908,53871682,53871682,53871683,53871686,54064993,54064994,54064995,55105007,53913030,53913033,53913033,56653019,54085671,54085671,54085671,54034332,54034359,54034381,54034384,54034394,54034395,54146348,54146349,54146350,54484057,55447437,55601704,56187736,54258291,54258304,54258292,54258304,54258292,54258293,54258294,54258305,54258293,54258294,54258294,54258295,54258305,54258294,54258295,54258306,54258295,54258296,54258296,54258297,54258306,54258306,54258307,54258296,54258297,54258297,54258307,54258297,54258307,54258308,54258298,54258308,54258308,54258317,54258319,54318590,54318590,54354576,54354579,54367266,54389424,54416528,54481889,54578935,54596012,54596012,54596013,54596013,54596014,54596014,54600111,54619359,54655779,54670248,54688435,54733847,54826680,54826682,54973323,54984166,55005941,55117737,55117738,55117739,55117740,55117741,55117741,55117742,55117743,55226252,55298292,55298293,55298307,55298316,55298340,55298354,55298357,55455823,55539366,55559390,55559392,55559392,55559393,55559395,55559396,55560618,55709376,55713659,55713660,55713660,55713661,55713662,55786441,55791643,55812097,55812097,55812099,55812099,55812101,55893537,55893537,55893538,55941822,56149015,56179864,56266093,56266095,56266095,56266096,56299692,56609040,56825653,56825654,56825654,56825655,56948823,56948824,56948825,57201705,57901711,55893043,55893539,56266096,56825655,56825656,56825656,56948824,54378874,54378875,55178025,55619677,54450849,54450852,54692287,55655665,55655667,55069596,54464567,55816793,54476285,54709131,54520552,55690523,54574806,55276022,54705471,54705473,54803556,55341327,54899608,55438415,54901647,57147328,54933718,54933719,54933720,54933721,54933721,54933711,54933722,54933722,54933723,55897099,55897100,54933734,55026143,55164388,55164390,55455449,55455449,55455450,55636018,55897099,55924209,56149807,56149807,56231245,56382435,57163361,57163362,57163362,57163363,57286532,57286533,55455449,54941962,54941962,54942019,54942038,54942056,54942113,54942114,55341067,55459667,55459668,55535566,55640227,55640281,56055585,56055586,56055587,57167580,54980437,55164977,55053251,57223127,55082191,55529683,55118564,55118565,55150839,56242228,55183115,55580146,55209385,55209388,55209512,56775234,55209641,57301322,55268643,56804860,55349515,55663356,55395055,55395058,55395062,55395061,55395061,55395062,55686115,55686116,57394032,55686121,56834474,57394034,55686119,57394036,55688364,55688439,55688514,55699277,56527214,57540770,55710021,55710027,56439517,57674684,55739976,56454496,55753633,55753765,55753903,57013925,55977162,55977161,55977174,55977175,55977175,55977161,55977163,55977177,55977176,55977163,55977164,55977176,55977176,55977178,55977178,55977164,55977175,55977176,55977176,55977177,55977177,55977178,55977179,55977179,55977165,55977177,55977177,55977179,55977180,55977180,55977167,55977178,55977179,55977180,55977180,55977181,55977180,55977183,55977183,55977181,55977184,55977183,57685089,55977188,56139403,56573096,55977191,56418827,57159128,57685090,55977191,56218447,56573096,56671535,56671535,57685090,57685090,55977192,55977192,55977193,56157786,56573097,57685091,57808260,55977194,55977194,55977195,56157672,56157782,56157787,56418829,56418830,56418831,56573097,56573098,57008452,57125534,57159130,57477674,57685091,57685091,57685092,57685092,57808260,57808261,57808261,57808262,55977195,56573099,57685092,56053131,56573099,56752975,56752976,57125533,57159131,57436888,57685092,57685092,57685093,57685094,57808262,55977197,56157677,56157789,56214817,56418828,56418831,56418832,56573098,56573099,56573099,56573100,56645879,56671538,56671538,56671539,56752977,57125534,57436888,57436889,57436891,57685093,57685093,57685094,57808262,57808263,57685094,56418833,56752977,57685094,57125536,57685095,57808264,56012031,56405572,57176555,56106106,57223592,56129036,56129089,56129113,56597868,56129192,56494869,56194196,57793599,56301636,56735328,56338167,56338168,56338175,56338160,56338175,56599327,57865588,56338195,56753600,56599336,56338282,56338283,56338283,56338308,56338317,56626491,57306085,57865645,56338317,56338334,56338333,56852105,56933545,56753668,56599406,56748745,56338378,56338384,56338389,56338405,56338405,56338402,56338464,57865692,56338438,56338424,57865696,57865699,57306147,57617505,57988880,56338494,57189082,56338496,57865736,57865764,57865765,57865765,57988936,56452450,57396764,56459714,57926358,56653339,57009616,56799141,57570124,56820489,58482828,56860480,56860479,56860479,56860480,56860482,56860466,56860481,56860482,56860483,56860483,56860483,56860484,56860470,56860483,56860484,56860484,56860485,56860484,56860485,56860485,56860486,56860487,58126743,57113189,58126743,58126744,57567185,57567186,56860499,57014749,57014751,57194628,58126745,58249915,57010467,57014749,57014752,57194628,57567186,57567186,57600783,57894030,58126744,58126745,58126745,58126746,58249915,56862956,57054726,56914699,56914699,57594293,57221736,57046432,57693756,57066641,57117830,57159190,58399286,57160450,57160459,57263172,58276727,58276728,58276728,58276733,57169014,57169014,57169016,57169015,57169016,57169017,57169016,57169017,57169003,57169015,57169017,57169017,57169018,57169019,57169003,57169017,57169018,57169018,57169016,57169017,57169018,57169019,57169022,58281008,58281009,57721450,57267451,57755048,58281010,57267456,57169033,57267456,57348894,57721452,57721452,58281012,58404181,57348895,57721453,57755050,57267457,57267457,57348895,57348896,57348896,57721451,57721453,57755050,58032809,58281011,58281012,58281012,58281013,58281014,58404182,58404183,58617468,59357069,58281011,58281014,57246493,57306202,57314574,57314575,58353788,57324994,58359005,57365890,57365880,57365894,57365879,57365892,57365895,57365894,57365880,57365881,57365895,57365895,57365896,57365896,57365896,57365895,57365896,57365897,57365895,57365899,57365911,57819889,57365910,58379449,57365911,57447333,57819891,58379449,58379450,58379450,58379451,58379452,58502620,59455507,57365911,57447334,57819891,58131246,58379450,58379451,58379451,57447334,57853489,58131251,58379451,58379451,58379452,58502620,58502621,58502621,58379453,57527782,58460394,57528767,57528768,57528768,57528769,57528769,57528770,57528770,57528771,57528770,57883699,57901326,58212683,58460885,58460886,57528782,57901326,58460885,58460886,59536943,57679957,57901327,58460885,58460886,58460886,58460887,57556455,57814377,57901327,57901328,58460886,58460887,58460887,58584055,58584055,58584056,58691297,57901328,58584057,57564224,57564299,57564374,58601856,57584182,58280202,57625337,58509169,57831147,57831149,58612076,58052517,58039724,58039725,58716363,58716371,58716364,58100009,58746518,58101425,58747215,58121661,58121724,58121787,58880563,58238629,58256257,58273884,58273873,58273885,58273886,58273887,58273887,58273886,58273886,58273889,58273885,58273886,58273887,58273888,58273888,58273898,58273900,58273901,58307483,58833444,58833444,58833445,58833445,58956614,58956614,59209495,58273901,58307483,58585240,58781864,58833445,58833446,58956615,58273902,58833445,58833446,58833446,58833447,58956616,58833446,58833447,58833447,58956616,58833448,58341076,58341086,58537047,58618834,58618835,58867036,58867037,58867038,58867038,58867039,58990207,58990208,58990209,59029530,59122887,59943095,58867039,58733019,59063010,58877765,59135387,58896596,58896597,58896595,58896597,58896597,58896598,58896594,58896596,58896599,58896610,58896601,58896601,58896603,58896602,59144798,59144800,59144800,59144801,59144801,59267970,59144802,59144802,59267971,59144802,59144803,59144803,59267972,59481259,59144804,59144813,58927587,59160302,58959772,58959887,58960003,59176502,58976190,59184602,58978168,59308755,59289845,59341427,59392988,59392988,59392989,59392989,59392989,59392990,59392990,59393005,59392990,59392991,59393004,59393005,59393005,59393006,59393006,59393007,59393007,59393008,59392991,59392992,59392993,59392993,59392998,59392999,59393000,59393003,59393003,59393004,59393004,59393005,59393005,59393006,59393006,59393007,59393007,59393008,59393008,59393009,59393009,59393010,59393011,59393012,59393012,59392992,59392993,59392993,59392994,59392995,59392999,59393001,59393003,59393004,59393004,59393005,59393005,59393006,59393006,59393007,59393007,59393008,59393008,59393009,59393010,59393010,59393011,59393011,59392997,59393007,59393007,59393008,59393008,59393009,59393011,59393005,59393008,59393009,59393007,59393008,59393017,59393008,59393009,59393009,59393010,59393012,59393012,59393013,59393022,59393014,59393015,59393014,59393015,59393016,59393015,59393019,59393021,59393016,59393019,59393020,59393018,59393020,59393020,59393021,59393019,59393020,59393019,59393020,59393020,59393021,59393021,59393023,59393020,59393021,59393021,59393022,59516174,59516175,60469062,59393021,59393022,59393022,59393023,59393023,59393024,59393031,59516174,59516175,59516175,59516176,59516177,59623416,60469063,59393022,59393023,59393023,59393024,59393024,59393025,59393025,59393026,59393026,59393027,59393027,59393028,59393029,59393029,59393031,59516174,59516175,59516175,59516176,59516176,59516177,59729462,60469063,59393023,59393024,59393024,59393025,59393025,59393026,59393026,59393027,59393027,59393031,59393032,59516174,59516175,59516176,59516176,59516177,59516177,59516178,59729462,59769057,60094242,60469064,59393024,59393025,59393025,59393026,59393026,59393027,59393027,59393028,59393028,59393029,59393030,59393030,59393032,59393033,59432878,59516176,59516176,59516177,59516178,60469064,59393025,59393026,59393026,59393027,59393027,59393028,59393029,59393029,59393032,59516176,59516177,59516177,59516178,59516178,59516179,60469065,59393026,59393027,59393027,59393028,59393028,59393029,59393029,59393030,59397082,59412061,59516177,59516177,59516178,59516179,59769059,60469065,59393027,59393028,59393028,59393029,59393029,59393030,59393032,59493757,59516178,59516178,59393028,59393029,59393029,59393030,59393031,59393032,59393034,59516178,59516178,59516179,60094245,60469066,59393029,59393030,59393031,59393031,59393033,59393034,59393034,59493768,59516178,59516179,59516179,59393030,59393031,59516179,59516179,59516180,59516181,60469067,59393031,59393032,59393032,59393033,59516180,59516180,59516181,59393033,59516180,59516180,59516181,59516181,59516181,59393037,59516181,59516181,59516182,59516183,59516182,59516183,59516182,59516183,59516183,59516184,59516184,59516184,59516185,59516184,59516186,59516186,59401152,59520247,59431111,59535227,59472745,59556044,59594514,59594520,59594596,59594590,59594669,59594679,59617013,59617015,59639327,59639328,59639328,59639329,59639328,59639329,59639329,59639330,59639343,59639329,59639330,59639330,59639331,59639342,59639344,59639345,59639346,59639346,59639347,59639348,59639349,59639330,59639331,59639331,59639342,59639342,59639343,59639344,59639344,59639345,59639345,59639346,59639346,59639347,59639347,59639348,59639348,59639349,59639331,59639332,59639332,59639333,59639342,59639343,59639343,59639344,59639345,59639345,59639346,59639346,59639347,59639347,59639348,59639348,59639350,59639355,59639332,59639333,59639339,59639341,59639342,59639343,59639344,59639344,59639345,59639345,59639346,59639346,59639347,59639347,59639348,59639348,59639349,59639349,59639350,59639351,59639351,59639352,59639355,59639357,59639359,59639343,59639344,59639345,59639346,59639346,59639347,59639347,59639348,59639348,59639349,59639349,59639350,59639350,59639351,59639353,59639354,59639354,59639344,59639347,59639347,59639348,59639348,59639352,59639348,59639353,59639361,59639356,59639359,59639354,59639356,59639359,59639357,59639357,59639358,59639359,59639357,59639358,59639358,59639359,59639360,60592230,59639360,59639358,59639359,59639359,59639361,59639361,60592231,59639359,59639360,59639360,59639361,59639361,59639362,59639362,59639364,59639368,59892225,60592232,59639360,59639361,59639361,59639362,59639362,59639363,59639363,59639364,59639365,59639367,59639370,59821788,59852631,59892226,59977346,60217411,60592232,59639361,59639362,59639362,59639363,59639363,59639364,59639364,59639365,59639366,59639366,59639367,59639368,59852631,59892226,60592233,59639362,59639363,59639363,59639364,59639364,59639365,59639365,59639366,59639366,59639367,59639369,59768842,59852632,59892227,59977343,60592233,59639363,59639364,59639364,59639365,59639365,59639366,59639367,59639370,59639371,59639375,59852632,59892227,60217412,60592234,59639364,59639365,59639365,59639366,59639366,59639367,59639367,59639368,59639370,59639373,59678669,59768841,59852633,59892228,60217413,60239039,60580589,60592234,59639365,59639366,59639366,59639367,59639367,59639368,59639368,59639369,59639369,59639370,59639371,59639372,59639372,59678669,59772024,59852633,59892228,59977348,60217412,60592235,59639366,59639367,59639367,59639368,59639368,59639369,59639370,59639370,59639371,59639373,59639373,59639374,59639375,59639376,59772028,59852634,59892229,60250584,60592235,59639367,59639368,59639368,59639369,59639369,59639370,59639370,59639371,59639373,59678669,59678670,59746587,59768845,59852634,59892229,60250585,60592236,59639368,59639369,59639369,59639370,59639370,59639371,59639371,59639372,59639372,59639374,59639375,59639375,59639379,59677642,59746591,59852635,59892230,59977350,60592236,59639369,59639370,59639370,59639371,59639371,59639374,59639375,59678670,59852635,59892230,59978373,60592237,59639370,59639371,59639371,59639372,59639372,59639373,59639374,59639374,59639375,59639376,59639377,59639377,59639378,59639379,59678672,59746591,59768844,59776905,59852636,59892231,60217415,60217417,60592237,59639371,59639372,59639372,59639373,59639373,59639374,59639375,59639375,59678671,59746591,59770549,59852636,59892231,59977263,60217416,60455063,60592238,59639372,59639373,59639373,59639374,59639375,59639376,59639376,59730897,59746593,59772029,59852637,59892232,60592238,59639373,59639375,59639376,59639376,59639377,59639380,59746592,59770553,59852637,60592239,59639374,59639375,59639376,59639378,59639378,59639379,59639380,59639380,59639382,59678674,59772032,59776907,59852638,59892233,60217419,60250588,60592239,59639375,59639376,59639377,59639379,59678675,59746593,59892233,60592240,59639376,59639378,59639379,59639382,59768849,59849963,59852639,59892234,60592240,59639382,59852639,59892234,60592241,59639378,59892235,60217422,60592241,59639379,59639383,59639385,59852640,59892235,60592242,59639384,59770560,59772036,59852641,59892236,60592242,59852641,59892236,59772035,59852642,59892237,59768853,59852642,59892237,60592244,59892238,60592244,59768852,59977354,59746599,59852644,60217424,60592246,59892240,60592246,59892241,60592247,59852646,59715927,59890920,59717984,59717985,59717987,59717987,59717988,59717989,59717987,59737395,59891949,60256730,59931545,59891951,59808162,60631553,60631554,60631554,59756806,59911360,59822425,59822428,59822447,59822471,59822479,59944191,59853823,59853824,59853813,59853814,59853824,59853825,59853827,59853826,59853828,59853827,59853839,59999464,59876080,59959870,59999465,60699471,59999466,59959872,59898330,59898333,59898334,59982122,60021717,60346900,60721723,59982123,60021718,60721724,59982124,60107863,59901752,59901749,59901758,60723434,59983839,59983839,59904700,59904701,59904690,59904704,59904703,59904707,59904700,59904710,60724909,59985309,60024904,60724910,59985311,59985312,59914455,59914459,59914463,60729788,60729791,59990194,60004263,60774707,60060576,60060631,60060689,60063309,60065919,60065920,60065925,60065926,60065927,60065927,60805521,60065944,60065945,60105515,60668366,60805521,60065950,60105520,60065951,60105521,60105521,60169960,60190552,60190637,60190639,60190640,60190641,60430706,60463877,60557059,60805528,60105522,60463877,60805528,60145091,60145111,60145112,60145112,60145113,60145132,60470296,60845118,60145133,60845118,60845119,60145134,60146369,60146371,60146372,60189331,60189592,60230232,60230233,60230236,60258300,60258350,60258499,60265009,60470297,60470298,60470299,60470301,60503468,60708002,60708017,60708284,60845119,60845120,60147619,60147621,60147622,60231482,60846369,60233541,60514509,60234073,60889600,60273982,60909549,60315155,60315166,60315167,60315179,60315235,60315237,60315311,60315341,60315343,60315329,60315332,60930217,60315347,60315346,60315347,60930220,60315350,60343612,60588582,60930233,60930235,60317390,60317391,60931253,60931254,60371542,60371640,60958361,60371788,60371938,60371939,60371940,60372012,60372014,60905173,60958560,60583739,60384899,60965009,60795473,60795476,60795476,60795476,60795463,60795477,60795478,60795479,60795480,60795481,60795482,60795484,61170297,61170298,60795494,61116912,61170298,60828649,61170300,61170301,61170301,61170302,60838723,60838849,60838977,61192046,60861821,60861849,60861868,60861878,60861896,61203500,61203519,60861972,60862134,61203547,60862384,61203779,61048205,61296674,61270825,61270847,61270885,61270897,61270922,61270923,61270960,61270972,61270998,61408025,61271036,61408074,61408078,61271506,61408341,61438371,61438373,61438410,61438412,61491759,61521827,61533472],\"xaxis\":\"x\",\"y\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,1,0,0,0,1,3,3,1,3,6,2,1,1,1,1,1,1,3,1,1,1,1,2,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,2,0,1,1,1,1,1,1,2,1,1,1,2,2,1,1,1,1,1,6,2,5,2,6,5,1,2,1,3,1,1,1,1,2,2,1,3,1,1,4,4,3,2,1,1,2,3,2,1,1,1,2,1,1,1,1,3,2,3,2,1,1,1,1,1,1,1,1,1,2,1,6,2,2,1,1,2,5,0,0,1,1,0,1,1,0,1,4,1,0,1,0,0,0,0,0,1,0,0,3,1,1,1,0,2,1,1,2,2,1,8,0,0,0,0,1,0,0,0,2,1,4,0,1,1,1,1,0,2,3,2,3,4,16,2,1,1,0,1,2,2,2,2,7,3,2,1,2,3,12,2,1,1,2,2,3,1,2,4,3,16,1,4,1,2,18,2,1,0,1,1,1,1,1,2,0,0,0,0,1,0,2,0,0,1,0,0,1,1,0,0,1,3,0,0,0,0,0,0,0,2,0,0,2,0,1,0,0,0,1,0,0,1,0,0,0,0,1,0,0,3,0,0,0,1,1,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,2,0,0,0,1,1,1,1,1,2,1,1,2,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,5,2,1,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,5,3,1,1,1,1,2,2,1,2,1,1,2,1,18,3,3,6,4,3,5,3,3,5,6,4,5,6,8,7,3,3,1,2,4,3,8,33,18,12,5,68,30,10,8,3,7,2,1,1,1,3,3,6,4,9,3,3,2,5,8,3,5,2,3,1,1,2,3,5,3,8,6,3,1,1,1,2,4,4,3,1,1,4,3,2,1,1,1,0,3,1,2,2,1,0,0,6,1,2,2,1,4,0,0,2,5,7,2,3,2,0,0,0,0,0,0,0,0,0,0,0,0,2,5,5,1,1,0,0,0,0,0,0,0,0,2,3,1,5,1,1,1,0,0,0,0,0,4,3,2,0,0,0,0,0,0,17,6,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,6,1,7,5,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,2,11,5,1,1,2,4,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,6,2,1,1,1,2,2,31,4,2,1,1,1,2,1,1,1,2,3,2,2,4,4,4,4,5,11,7,9,4,3,1,9,9,3,2,3,1,2,7,1,3,3,2,4,1,5,5,8,5,3,2,4,5,6,19,17,8,11,7,10,2,1,1,3,1,4,3,3,1,1,4,3,2,2,2,3,2,3,2,2,3,1,1,1,1,3,7,2,3,3,1,2,1,1,1,1,1,2,3,3,2,3,4,4,2,1,2,2,3,1,3,2,1,2,1,1,3,1,3,1,3,1,4,4,4,2,2,2,1,1,1,2,2,2,3,2,2,4,2,2,3,5,2,2,3,1,1,1,5,1,2,2,1,3,1,2,2,2,1,2,6,2,3,2,2,1,2,7,4,3,1,3,2,5,2,4,3,2,2,4,6,3,4,6,2,3,3,5,6,1,2,3,2,2,2,2,1,5,2,1,2,4,3,6,3,4,3,1,1,5,1,0,14,1,5,3,1,2,2,2,2,0,0,3,1,2,4,5,7,3,3,6,3,1,2,1,0,3,8,13,3,6,2,3,4,3,2,2,0,0,10,16,2,4,3,3,4,1,4,5,1,3,0,0,5,8,17,3,2,3,4,1,2,2,1,6,5,6,1,0,9,24,10,5,9,3,4,2,10,3,6,2,1,0,0,0,0,0,7,9,7,12,3,1,1,6,7,5,0,0,0,0,0,0,12,2,5,16,2,2,1,2,2,12,8,3,12,1,1,0,0,0,0,0,0,10,6,2,2,2,3,3,2,3,6,2,1,0,0,0,0,0,3,2,1,1,5,5,1,1,4,1,1,6,0,0,0,0,0,0,2,2,2,6,4,9,5,10,0,0,0,0,0,0,0,0,1,2,4,4,4,1,0,0,3,1,3,4,1,1,3,1,0,0,0,1,1,1,2,0,0,0,3,1,11,1,0,4,1,0,1,0,0,0,2,4,5,1,0,0,1,0,0,4,2,1,1,1,0,2,1,0,1,1,3,3,1,0,3,2,6,0,0,3,1,0,0,0,2,1,0,0,0,0,17,11,3,3,4,1,0,0,0,0,0,0,0,15,9,2,1,0,0,0,0,0,0,0,0,0,0,0,0,13,3,0,0,0,0,0,0,0,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,3,1,1,2,3,1,3,5,1,1,1,1,4,10,13,3,1,3,7,13,2,1,2,3,1,1,94,42,10,12,1,1,1,1,1,4,198,100,78,7,3,2,7,11,11,8,10,3,3,1,5,1,2,1,2,1,225,176,1,2,3,28,14,9,19,4,3,2,1,1,1,1,1,380,8,3,3,26,15,22,34,27,20,3,9,6,4,2,1,1,139,3,3,4,26,18,49,164,153,169,265,74,38,19,5,3,1,2,1,7,7,10,16,47,25,51,13,1,1,2,4,4,9,2,6,1,10,13,2,5,0,3,2,8,11,1,16,16,29,22,5,1,1,0,0,0,0,34,36,75,11,10,3,2,0,0,55,119,33,29,4,3,1,0,0,0,0,0,0,185,46,17,12,5,4,1,1,0,0,0,0,0,0,0,0,0,295,68,61,25,17,8,6,3,6,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,148,99,16,9,10,6,3,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,109,33,23,8,1,7,5,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,48,26,9,4,5,3,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,39,39,5,9,11,4,1,0,0,0,0,0,0,46,13,7,6,3,2,1,0,0,0,0,0,0,0,0,0,0,27,8,19,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,8,6,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,8,2,3,2,2,0,0,0,0,0,0,0,0,0,0,12,8,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,1,1,1,0,0,0,0,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,1,2,2,1,0,0,1,2,0,0,0,1,0,1,1,1,2,1,1,1,1,1,2,4,2,1,1,7,5,1,6,1,3,2,3,8,4,1,4,3,4,9,2,4,11,1,18,6,1,10,14,42,5,1,2,2,3,56,30,2,1,2,1,1,1,1,0,1,2,1,0,29,4,0,0,0,0,0,0,0,0,0,0,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,1,0,0,2,0,0,1,1,0,0,1,1,0,0,1,0,1,0,1,1,2,3,2,1,3,1,1,12,2,6,5,1,3,1,1,7,7,1,1,3,1,1,1,10,3,1,1,1,1,2,1,4,3,3,2,2,7,2,2,1,2,1,2,2,2,0,2,0,0,0,0,1,2,1,0,0,0,2,1,0,2,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,11,1,25,7,6,1,0,0,1,0,1,0,1,0,1,1,1,0,0,0,1,1,1,0,0,0,1,1,0,0,1,0,2,0,0,2,4,2,1,0,1,3,3,1,1,6,1,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,2,0,2,0,0,1,10,3101,501,1141,165,15,14,4,4,45,11,1413,6805,4,1356,457,59,808,437,1552,177,132,1358,62,882,869,178,1359,33,139,16,179,8,2,6,2,0,61,0,0,0,46,1360,72,4652,5866,526,68,790,158,1552,46,311,521,17,188,534,182,186,51,206,472,40,374,73,85,211,933,181,64,64,128,79,47,37,163,821,18,643,468,214,274,98,125,51,132,137,159,371,67,177,99,38,28,122,165,46,9,146,50,501,7315,2711,621,64,911,262,171,141,33,33,190,50,8,252,450,26,113,22,375,69,357,268,16,36,24,96,2713,41,57,52,12,622,459,991,108,45,25,288,66,12,182,330,18,189,3626,450,86,66,111,27,8,187,52,356,208,623,474,42,460,286,90,6,34,32,188,46,37,35,357,0,173,913,287,2715,20,38,305,28,40,392,263,46,169,1,14,26,31,274,269,65,0,194,12,40,11,914,106,461,105,58,18,38,20,46,56,15,36,68,14,34,7,47,24,50,22,915,60,31,144,103,41,18,112,9,49,156,1,21,29,134,350,0,49,33,177,307,62,39,104,43,29,64,27,57,678,101,61,42,83,184,116,9,140,63,451,789,15,73,212,95,37,102,91,132,168,8,96,992,743,358,40,50,62,3,34,261,968,196,31,2716,51,27,272,21,34,67,19,66,16,306,188,590,43,41,121,2,30,270,723,9,176,203,32,462,30,1,185,281,279,8,44,15,10,254,0,66,82,18,391,63,149,264,2715,49,330,26,373,183,51,365,3166,104,0,6089,5614,62,37,12,21,231,14,98,42,5,11,61,71,141,16,128,192,245,6344,0,0,0,0,0,0,0,459,19,41,225,496,132,1384,26,475,71,152,2032,61,458,35,13,20,1,20,40,230,224,13,495,550,40,131,4,10,59,1357,25,70,137,534,109,488,1356,255,2088,8,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,3,0,1,1,0,0,1,2,1,1,0,0,0,0,0,1,1,0,0,2,0,0,1,1,1,1,0,0,0,0,1,0,1,1,0,0,1,0,2,0,1,1,0,0,1,0,2,0,0,1,0,1,0,2,0,1,1,0,0,1,0,1,0,1,1,1,1,1,1,5,2,15,10,2,1,2,7,1,1,2,1,1,1,1,1,0,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,2,1,0,0,0,0,0,0,1,1,2,1,1,6,5,1,1,4,2,1,1,2,1,23,1,4,4,4,3,24,25,6,11,6,9,10,7,1,1,3,5,17,31,30,24,13,1,4,1,2,5,7,2,1,1,3,8,5,11,2,4,1,1,1,3,3,2,2,4,3,2,6,1,4,2,4,2,1,1,2,4,1,1,2,0,0,1,1,4,1,0,0,3,7,2,1,1,0,0,0,0,13,7,5,1,1,0,0,0,0,0,0,0,0,0,22,6,0,0,0,0,0,0,0,0,0,0,14,3,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,2,9,10,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,1,0,2,1,1,1,1,0,0,0,0,0,1,0,2,0,0,1,0,1,1,0,0,1,2,1,0,1,0,1,1,1,2,1,1,48,6,6,5,1,4,4,4,1,1,2,2,1,1,2,3,1,0,0,3,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0,85,9909,56,299,3,41,27,110,2,145,109,200,887,4969,12088,8,1,1,2,1,1,2,1,173,158,63,530,193,5359,3541,174,159,57,302,64,1,40,28,98,14,3,146,1,107,94,533,201,786,482,12216,21956,2886,574,3579,842,2391,2216,811,494,869,479,164,114,137,4,360,219,908,417,1015,88,6,299,2596,804,348,448,857,829,753,305,67,247,320,83,69,336,32,170,175,260,626,104,57,241,107,36,360,403,373,7,141,163,100,104,30,5,1714,331,20,394,2667,1,898,866,1666,1176,529,868,1672,594,734,163,256,327,135,119,459,61,148,1486,1076,4,699,166,614,518,357,559,56,423,336,342,275,104,99,235,292,13,314,348,212,152,194,160,16,224,97,48,1374,64,734,154,717,228,104,403,225,200,95,197,319,153,8,243,194,106,480,192,212,633,2,25,1,172,212,382,269,442,172,109,375,219,1203,459,157,256,164,296,33,65,1,10,155,313,345,1058,120,324,12,33,531,406,12,62,277,48,1166,284,4,262,61,24,134,193,401,1,453,160,841,383,487,31,1260,206,957,193,79,646,87,153,213,718,137,59,1,23,132,22,106,313,349,270,124,12,353,158,109,98,495,278,151,562,84,76,951,89,15,51,23,21,519,196,51,292,24,152,124,30,721,93,81,526,148,745,33,165,13,66,1,13,2,115,105,70,25,94,32,329,133,5,100,260,136,218,120,1060,34,228,277,110,195,12,425,27,259,219,29,34,207,1130,332,87,532,958,1061,208,17,29,5,119,254,282,188,200,192,107,633,0,374,495,138,39,317,487,56,142,32,15,957,60,5,361,402,151,38,149,146,1545,520,584,155,737,732,262,35,243,49,131,134,220,80,165,242,204,184,214,152,1400,410,688,1182,182,150,12,350,5,229,601,1115,461,285,4,20,439,12,936,1350,161,488,24,50,53,30,272,305,2761,86,285,58,137,319,176,22,315,353,68,12,63,392,99,24,117,88,78,97,2,256,253,512,506,334,29,287,209,2,29,66,62,80,28,569,60,196,12,1550,615,128,229,291,554,253,515,72,564,96,519,1223,9,337,154,6,189,269,50,263,202,212,958,584,96,184,383,187,137,529,275,490,220,75,151,150,404,213,0,319,151,75,273,197,513,674,60,64,323,129,6,283,239,297,12,80,734,508,154,383,187,341,403,2,96,32,273,245,134,243,195,717,133,190,68,152,18,201,76,258,1703,225,181,47,284,68,107,479,121,315,4,196,532,318,257,253,157,292,271,324,171,226,33,39,14,865,445,228,240,746,603,34,679,340,185,178,95,98,341,214,98,250,828,184,349,224,594,23,514,160,173,99,375,583,71,848,192,299,214,492,538,780,256,163,208,103,33,98,1041,530,8,410,1,95,225,396,134,1942,191,640,195,744,716,82,120,4,79,279,188,564,282,236,487,123,229,377,1,292,185,133,3937,292,558,126,823,9,626,49,213,462,638,211,145,448,753,103,70,1041,424,2212,23,349,318,349,1080,1176,162,29,1050,0,336,251,459,955,219,84,210,67,709,217,243,447,760,3,194,7,106,223,237,333,253,171,141,238,59,423,743,125,347,35,715,94,464,62,170,989,1,1121,1207,434,34,841,0,225,151,334,177,34,1505,290,222,634,954,49,445,714,177,1024,252,267,97,520,15,380,178,174,680,141,219,382,41,109,730,24,380,99,331,368,1490,223,914,348,389,200,742,224,42,16,288,166,151,768,1895,105,599,904,0,591,396,384,317,796,344,824,1368,307,85,239,713,1638,98,497,0,4226,201,868,673,9042,1360,7235,10715,1879,4811,5212,2721,3177,20856,18198,303,268,74,227,417,98,275,258,83,20,28,175,1,22,5,1,2,64,14,12,48,219,346,106,266,418,150,7070,0,0,0,0,2671,296,43,27,63,247,266,1140,427,110,131,17,96,69,53,109,226,754,142,244,218,201,92,200,1231,156,536,429,704,6999,336,648,130,405,149,1283,46,33,6,271,5,10,41,18,40,118,48,73,0,266,28,62,60,87,186,161,217,61,39,323,276,12,92,1,371,7,122,75,65,125,338,16,75,66,446,150,890,90,13,109,75,13,56,27,13,288,2,14,18,29,15,64,174,27,17,15,97,0,44,6,10,54,0,67,117,19,372,8,121,63,174,476,54,15,42,74,28,110,43,227,529,223,74,129,549,243,74,173,216,573,372,317,65,692,226,360,192,71,2816,105,167,1564,1316,1605,192,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,3,0,1,0,1,1,1,0,0,0,1,1,2,1,1,1,1,3,1,1,2,1,1,1,1,4,6,10,1,6,2,8,9,4,2,2,7,12,1,1,4,1,3,19,17,2,5,1,4,2,5,2,4,0,0,0,0,0,0,0,4,1,0,0,0,1,2,1,2,0,0,0,16,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,0,0,0,0,1,0,1,0,2,0,2,1,1,1,5,1,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,2,1,1,6,1,0,0,0,2,0,1,0,1,0,1,1,0,0,1,1,4,0,0,0,0,5,1,0,0,1,8,0,2,0,0,1,1,1,4,7,15,2,1,2,8,66,1,1,1,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,5,4,2,1,1,0,0,0,1,0,1,0,1,0,4,3,0,1,2,6,3,13,1,6,38,3184,61,22,5,1,5,4997,185,28,3,10,6,20,2,3,5985,516,100,83,31,14,53,68,26,3,5690,433,190,103,16,18,48,157,269,281,23,3,3102,1021,328,23,15,32,42,56,828,854,637,55,1,1300,442,122,80,62,95,633,441,656,9,8,1,503,132,65,28,24,83,68,955,490,376,18,55,94,706,264,354,6,263,29,70,27,55,67,29,16,23,31,28,17,122,58,190,160,69,1984,1585,19,0,0,4365,35,8,6681,168,31,1,0,0,0,4770,135,1,2,0,0,0,0,0,0,0,3434,15,2,3,1,1,0,0,0,0,0,0,385,341,37,30,20,29,2,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,15,9,9,6,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,62,37,41,3,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,13,13,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,16,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,2,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,0,0,0,1,1,1,1,2,1,2,2,6,6,5,4,1,2,5,1,1,1,2,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,2,1,0,0,0,0,0,0,1,1,0,0,1,0,1,1,2,1,2,1,2,3,0,0,1,0,0,0,0,1,0,2,0,0,6,4,2,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,0,1,2,2,1,3,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,0,0,0,1,2,1,0,0,0,0,2,0,1,0,1,0,1,4,0,0,0,2,0,1,1,1,1,1,0,0,0,0,0,1,0,1,0,2,0,1,0,1,0,1,0,2,0,2,1,0,1,0,1,0,1,0,2,1,1,1,1,1,3,1,2,2,4,2,4,2,2,2,2,1,5,1,1,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,5,4,5,1,0,0,0,0,0,2,0,1,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,0,1,0,1,1,1,0,0,0,1,0,1,0,1,0,1,1,0,0,1,1,2,1,1,10,5,16,12,2,3,3,1,1,1,1,2,2,1,1,2,1,0,1,3,0,0,0,2,0,0,1,1,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,2,1,2,2,1,2,36,3,11,7,2,2,2,1,1,1,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,1,1,2,2,1,9,1,1,1,1,2,2,1,1,2,1,1,2,3,2,1,2,2,8,1,1,1,7,2,2,2,2,4,3,1,3,1,1,0,0,0,1,1,0,0,0,0,1,1,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,2,8,5,1,3,2,2,1,6,3,1,2,1,1,1,1,33,16,14,16,1,1,2,1,10,1,6,37,62,22,6,1,2,2,4,3,8,5,4,1,68,41,10,9,2,3,3,10,16,5,9,1,1,1,1,215,44,1,2,1,2,3,16,6,55,17,20,2,1,221,50,28,7,2,1,5,5,9,22,130,51,49,3,1,1,48,18,4,8,8,21,26,3,6,175,42,74,4,1,1,9,6,8,3,77,14,27,2,11,8,42,11,2,5,16,7,9,4,1,4,2,7,4,7,1,2,0,0,3,6,15,12,5,6,24,10,8,2,0,10,6,28,3,14,0,0,0,238,149,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,89,4,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,2,1,2,9,1,1,3,2,2,61,1,2,3,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,1,0,1,1,1,2,1,1,1,1,2,1,4,1,1,1,5,6,3,20,1,1,1,1,11,6,31,2,2,1,1,1,2,17,67,3,6,3,2,2,2,1,66,11,8,1,1,2,2,5,2,3,1,2,328,97,20,10,28,51,36,37,48,81,32,22,22,9,116,14,4,12,9,25,31,41,46,50,109,30,23,12,7,9,1,7,20,29,17,14,62,76,46,26,30,11,2,5,13,2,9,20,4,6,4,1,5,2,3,0,10,0,0,4,8,5,2,3,1,11,24,18,3,1,1,0,13,16,21,28,8,4,7,3,0,14,16,25,16,5,6,6,0,0,0,0,41,49,7,7,9,4,0,0,0,0,0,72,46,28,11,6,0,0,0,0,0,0,137,109,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,110,52,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,54,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,2,1,0,2,0,1,1,1,8,13,2,5,2,1,2,1,4,1,2,2,1,3,1,5,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,1,3,1,0,0,0,0,0,2,0,1,2,3,9,1,1,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,2,1,1,0,0,0,0,2,1,5,1,1,9,1,2,1,6,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,1,1,1,1,2,10,1,2,1,1,1,1,1,1,1,1,2,3,1,2,1,1,1,2,1,4,1,2,1,2,1,4,2,8,1,2,2,3,1,15,2,2,22,7,2,3,1,2,0,0,0,0,0,0,0,0,1,3,0,1,0,0,0,0,2,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,1,2,0,0,0,1,0,2,0,1,0,1,0,5,3,0,0,0,0,0,0,0,1,0,1,1,0,0,1,2,2,1,1,1,1,1,214,37,12,1,5,4,2,1,13,10,3,25,18,17,9,8,4,10,15,10,15,22,22,21,1,147,28,16,5,22,6,6,11,3,5,12,5,10,4,6,11,1,2,50,16,25,34,33,5,15,6,9,15,28,9,14,3,3,6,1,2,2,5,5,4,48,5,16,6,2,4,3,3,2,2,15,3,2,1,24,4,6,3,2,3,3,3,2,3,3,2,1,2,6,4,2,5,6,3,13,6,5,3,2,2,1,3,1,2,2,7,5,4,1,2,1,5,2,5,2,52,43,14,17,12,2,6,3,3,0,49,29,1,2,10,3,0,0,0,0,0,80,20,9,2,3,2,2,0,103,10,12,1,2,1,1,1,0,0,75,28,1,5,2,3,1,0,0,74,27,3,9,2,0,0,0,112,5,2,10,6,1,2,0,0,0,139,7,5,4,4,0,0,0,107,26,7,6,1,1,0,0,0,0,70,14,11,2,1,1,1,0,0,0,0,0,69,19,1,1,0,0,0,0,0,0,0,0,25,2,2,2,2,0,0,0,0,0,0,0,0,4,1,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,2,8,4,1,1,1,1,1,3,5,4,1,3,1,12,9,18,1,4,43,41,3,10,1,157,15,1,280,3033,35,19,34,15,7,14,9,6,55,316,2,3,5,2,1967,485,492,373,268,116,5,32,20,8,61,49,95,1244,36,5,877,393,142,129,223,16,12,44,12,389,20,632,286,139,101,18,19,26,46,263,17,5,541,302,268,31,21,60,67,404,5,42,313,330,25,26,43,51,39,98,454,100,11,448,27,33,57,47,113,382,14,145,76,8,13,7,76,196,39,69,134,872,8,145,7,6,25,83,9,26,17,12,25,30,95,39,46,38,38,16,40,98,260,1,23,48,185,8,44,245,3,4,656,97,5,0,773,1598,122,7,6,0,1,1,0,1,0,0,0,0,615,45,2,3,0,0,1728,40,6,1,0,1,0,0,0,0,0,0,0,549,56,28,23,2,0,0,0,0,1,0,0,0,0,180,20,42,1,0,0,0,0,0,0,33,37,2,0,0,0,2,0,1,0,49,0,1,0,1547,229,68,19,2,13,11,4,4,2,5,19,2,26,10,2,2,1,2264,113,75,7,22,3,1,18,2,4,13,3,1,3390,136,29,71,25,19,4,4,46,10,45,5,3741,175,273,33,132,184,4,7,13,15,19,3,154,7,16,17,1,1476,1224,184,263,402,54,54,55,18,56,41,417,6,46,14,697,200,192,277,103,6,275,17,4,2,377,568,662,50,96,8,569,19,76,19,3,187,442,33,1,164,3,35,10,1,781,118,122,36,99,220,3,11,8,185,208,345,183,92,288,55,13,180,63,19,12,1063,33,185,36,12,3,2,1,54,82,165,114,143,3,12,62,97,38,53,188,5,1,0,24,77,19,20,231,7,4,126,23,35,124,0,107,120,441,2,54,1,75,162,82,462,62,118,0,34,337,114,5,1402,481,89,17,2,1,2,1,0,790,150,6,4,2,1114,55,16,3,3,0,2,1,1,528,44,20,27,4,18,3,1,0,380,312,137,114,157,68,24,126,86,39,47,26,21,99,114,93,41,10,87,134,39,9,348,57,8,3453,786,4,1,1,4303,34,15974,9024,946,726,257,63,50,74,26,7,61,2,3,4,2,16463,463,132,33838,4332,472,535,102,6,33,46,47,8,73,2,8,1,1,35999,1684,611,227,122,271,58,69,3,36,66,2,6,3,1,40287,2652,1002,481,130,155,80,52,194,31,20,2,39709,2468,942,391,282,247,368,136,404,34,39287,3577,982,344,172,114,359,43,54,105,967,18,16,19,38728,3476,498,243,217,241,309,88,79,39,184,1095,25,10,98,4,19,2,24828,9934,1812,1107,1749,1280,1198,340,465,969,1044,653,24,50,44,10,10,13695,4110,2504,2062,1890,1811,459,372,755,2067,207,410,99,8848,5135,2061,2523,1136,302,2792,275,1532,145,425,25,5475,2605,3171,840,446,1058,374,1106,35,69,94,3761,3161,2063,1440,1591,1674,630,208,269,161,47,18,1,6725,828,247,1983,819,756,657,255,72,265,9,5447,2644,3859,2961,2869,691,412,774,3058,4115,1120,2803,1299,264,475,225,4207,1618,2580,527,114,2,5602,8907,2424,2179,758,728,8454,2370,2529,1635,941,80,77,196,26222,4603,2669,669,27899,4636,1242,241,92,142,33134,2650,1043,809,0,33816,4261,2221,2000,0,0,29764,4629,3055,1,0,29286,3741,33992,12,21090,3,0,0,0,0,4418,463,76,18,5,1,0,0,0,0,0,0,0,0,2720,84,19,1,1,0,0,0,0,0,0,0,1758,179,9,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1046,37,17,8,2,1,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,387,69,17,7,1,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,19,9,8,3,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,9,7,3,6,2,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,2,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,1,1,1,11,0,8,1,2,2,5,2,13,5,1,2,1,18,1,1,8,1,1,1,1,1,3,2,1,1,0,0,0,0,0,1,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,1,1,2,1,1,1,2,3,2,1,2,3,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,4,4,2,1,2,6,1,1,2,8,30,1,3,3,6,1,7,1,1,1,1,1,2,1,1,7,1,3,1,2,4,2,2,1,4,7,10,0,3,1,0,0,0,0,1,0,1,4,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,1,0,1,3,1,2,0,1,2,3,1,0,0,5,3,1,0,0,0,1,0,0,0,0,0,0,0,0,0,11,5,2,3,1,2,92,15,18,3,6,3,3,3,2,1,2,5,51,1,11,1,103,48,2,6,4,5,23,3,8,16,100,4,1,1,75,4,7,11,3,2,2,3,26,89,2,1,13,7,36,11,4,6,8,4,23,116,1,1,5,19,4,3,6,7,7,4,3,1,15,25,1,1,6,7,43,2,10,2,6,2,2,3,3,76,6,3,4,1,1,3,17,1,1,1,2,2,13,2,7,9,1,1,7,1,8,0,1,2,8,0,0,64,0,1,1,1,0,1,10,8,2,5,64,4,10,22,12,2,1,0,2,1,1,1,3,5,1,3,1,9,2,2,1,5,1,1,2,8,2,2,5,2,6,9,15,10,5,1,0,7,16,21,13,8,2,44,45,13,8,7,1,142,31,35,10,1,408,217,36,800,56,5,1,1,1,2339,10,6934,1,3,2,19456,1,7,4,15,8,13,8,1,1,1,1,2,3,7806,2946,3972,2192,2199,1595,1681,957,547,175,124,63,10,16,12,9,5805,887,582,315,384,204,174,45,23,6335,1077,983,419,184,266,70,8286,1839,627,607,430,48,21,16,9361,1610,1036,607,208,93,82,12235,2197,837,335,125,14591,2544,547,157,157,47,19,19623,1521,374,288,73,15,4,24358,1788,717,186,49,4,25587,3019,576,149,45,28828,1182,62,22,34483,1170,136,1,38407,1041,18,5,42460,639,15,5,2,47979,172,22,20,45409,5122,3284,753,49,6,1,40544,6465,640,3,0,44135,3111,224,31,61,0,51433,2581,374,5,2,2,5,0,53735,1777,651,61,55,52662,3157,535,117,25,9,12,0,51417,2932,461,187,50,24,3,1,50693,3890,457,34,90,6,4,47840,5294,828,224,51,47083,4263,939,241,38,17,47470,5148,402,87,30,2,49591,2767,490,29,9,18,47845,7544,131,9,6,0,48634,1421,17,4,51679,1243,856,22,296,37,38539,8276,2420,701,162,176,35,22,20,266,0,30083,6698,1106,427,23,220,416,0,29583,5567,1414,593,141,35,377,50,30,8,664,0,25245,7684,2206,205,181,398,359,1,64,102,1733,19313,5303,2348,1470,142,1037,470,116,2259,14948,5864,2628,994,288,241,884,2856,10383,5419,3481,118,559,560,381,83,2060,7851,4183,848,1329,236,206,20,4156,0,4073,3760,1846,1459,937,283,5113,3823,3041,1954,520,825,3277,3449,1172,1021,1867,3062,822,1062,2148,6906,0,833,1727,4526,1004,4123,8046,19500,108,263,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11910,89,3,1,0,0,0,0,0,0,0,0,0,6483,8,5,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1205,28,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,646,10,0,0,0,0,0,0,0,0,0,0,0,281,3,0,0,0,0,0,0,0,0,0,0,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,4,2,2,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,2,1,2,2,2,1,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,2,1,1,6,11,2,3,3,6,5,7,1,1,2,4,3,2,1,8,2,2,2,2,1,6,1,1,1,3,1,1,1,3,1,2,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,3,1,1,1,2,4,2,6,2,18,2,5,3,1,6,4,2,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,4,4,8,1,1,3,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,0,0,0,1,1,0,1,0,1,0,1,1,1,1,2,3,4,2,2,1,3,61,3,7,3,7,3,1,1,1,0,2,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,1,0,1,0,1,2,1,1,1,1,1,2,1,1,2,3,9,2,3,6,1,26,1,3,3,16,1,2,1,2,19,4,1,1,1,11,2,34,2,3,2,7,1,1,5,13,1,1,5,2,26,1,2,2,1,2,1,1,14,0,0,0,0,0,0,0,0,0,2,1,0,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,1,1,0,0,0,1,0,1,2,1,0,1,1,1,1,1,10,16,1,2,1,3,15,3,1,1,1,3,7,11,1,1,3,1,1,0,0,4,0,3,0,0,0,0,0,0,3,1454,268,514,72,6,6,27,4,2,57,22,109,287,1054,81,3,182,626,4839,2068,1,1,823,210,423,9,72,141,58,390,128,31,43,7,7,9,0,0,0,9,5,0,3,0,56,21,110,245,44,663,1882,70,2,80,4,5,308,107,251,309,171,14,942,13,9647,2,8,5107,394,51,911,3837,84,2460,1230,530,73,219,333,37,30,43,55,11,16,335,514,254,31,252,286,128,309,46,76,16,40,8,167,114,49,33,65,63,13,137,224,122,60,1,188,4104,411,254,2373,891,141,422,54,15,36,152,384,92,412,212,52,50,255,31,22,1086,155,594,337,600,5,12,169,434,3133,1394,198,622,14,211,9,79,10,7,95,13,313,1433,974,142,401,24,41,332,22,1988,182,312,257,394,657,487,12,193,156,279,197,3,5,13,15,736,483,975,414,441,216,151,178,91,131,157,119,26,246,779,105,925,484,183,143,1,152,1867,251,25,22,133,153,416,74,1003,34,402,258,977,314,54,168,485,226,425,580,111,338,395,670,601,32,659,250,32,46,56,227,185,487,252,426,12,228,17,217,47,356,416,84,6,20,24,2,16,437,67,12,648,57,58,66,20,32,11,6,25,31,557,22,16,33,17,19,6,24,399,32,3,53,11,23,16,30,229,110,68,156,23,45,39,55,49,16,169,6,2,26,31,161,406,0,296,280,339,157,417,3,18,24,453,761,37,36,403,396,281,25,14,45,338,12,80,7,26,7,13,340,34,187,259,201,40,222,22,2,604,162,418,235,49,8,34,664,27,16,581,26,978,35,439,4,1,64,7,170,161,3,19,603,1,90,15,112,48,49,660,324,4,18,415,14,11,662,33,486,14,25,414,602,35,230,15,1074,1350,580,245,276,48,0,169,30,976,601,1172,2873,280,80,975,213,0,1191,3237,3760,132,17,10,298,5,127,494,3,24,42,13,244,174,98,518,3,41,3,6,155,500,84,685,2211,2012,0,0,0,0,0,0,0,0,0,0,0,0,105,85,330,56,1111,13,205,164,427,169,334,464,238,176,58,86,16,9,297,87,6,128,489,7,329,4,330,57,25,298,299,43,12,541,68,106,97,524,294,102,565,914,218,23,0,2,5,4,19,18,86,2,5,12,204,522,293,75,154,303,87,63,63,606,1879,175,303,83,2847,294,8136,0,0,0,7,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,1,0,0,0,0,0,0,1,1,1,1,2,1,2,1,1,1,2,1,1,2,1,1,2,1,2,2,1,2,5,1,1,1,2,1,2,1,3,1,1,2,2,1,4,3,3,2,7,1,6,1,2,2,1,1,1,3,1,9,18,2,4,3,2,5,11,2,2,11,8,18,5,1,9,8,6,3,23,21,7,41,34,2,1,10,4,1,2,53,36,5,10,2,2,5,2,53,53,4,1,3,3,22,23,8,1,1,5,4,3,1,3,6,2,5,1,3,2,4,2,2,0,81,9,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,7,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,7,3,1,1,0,0,0,0,0,0,0,0,0,1,0,2,3,1,2,1,1,3,2,1,31,10,14,6,16,3,4,5,1,1,47,28,13,51,1,3,2,1,2,1,1,2,9,9,20,1,56,25,60,1,1,2,2,2,21,1,1,54,157,2,2,8,7,6,5,2,2,6,2,2,1,1,149,3,1,8,1,2,3,4,4,11,1,97,2,43,11,16,15,15,8,3,4,33,55,30,10,102,170,219,3,31,250,3,23,4,5,9,8,25,16,42,2,3,4,3,2,1,15,10,4,18,18,30,6,17,1,4,2,8,7,3,11,9,11,2,6,5,11,18,15,6,2,2,5,8,5,1,8,7,13,4,9,2,6,4,1,5,3,4,11,4,4,4,5,10,13,16,2,4,8,0,6,4,15,6,12,1,0,0,3,7,2,23,0,0,36,76,5,5,29,5,0,0,0,0,0,153,14,7,70,2,2,4,0,0,0,0,0,0,0,0,0,0,0,17,67,251,1,1,12,18,0,0,0,1,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,13,1,2,0,99,3,0,0,0,0,0,0,42,2,3,6,11,3,2,1,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,0,0,1,0,12,0,1,0,0,0,0,0,0,0,2,0,2,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,1,0,1,0,1,1,0,2,1,0,2,0,1,1,1,0,1,1,4,3,1,1,1,1,1,1,1,1,1,1,1,2,0,1,1,0,1,1,1,1,0,0,2,1,2,1,3,1,2,1,2,1,2,2,2,2,2,2,2,5,1,1,1,1,1,3,3,0,1,2,1,1,2,1,0,7,1,1,1,1,1,2,4,1,3,2,1,0,1,2,1,1,2,2,4,1,2,1,1,1,0,1,4,1,2,3,1,1,3,1,1,1,1,2,6,1,1,2,3,2,3,2,1,1,2,2,1,1,1,3,4,2,1,1,4,1,5,1,1,1,2,1,1,4,1,5,2,2,1,1,1,3,1,3,1,1,1,3,2,3,1,1,1,1,1,1,1,1,2,2,2,1,1,3,1,4,6,2,2,2,1,1,2,1,1,2,4,1,5,3,2,2,2,3,1,1,2,1,9,1,1,3,2,6,2,2,1,1,2,1,1,2,5,1,1,2,1,4,1,5,2,2,2,9,1,1,3,2,2,1,3,17,4,4,7,2,1,5,2,2,2,1,12,16,3,3,5,1,2,1,1,1,0,18,11,9,9,1,2,1,3,3,3,1,1,43,21,3,3,2,3,1,5,3,1,76,17,9,1,1,9,3,2,1,5,9,3,98,47,30,9,3,7,1,1,3,1,106,25,21,6,9,2,2,2,7,2,2,8,2,0,116,56,8,10,8,4,9,9,14,14,1,0,0,0,0,129,52,2,7,3,4,14,20,0,0,0,179,9,1,3,16,11,2,3,28,36,1,0,0,0,58,28,27,26,7,1,2,4,82,90,0,0,51,11,7,1,2,4,8,3,3,0,0,0,0,13,50,1,1,9,2,4,17,1,1,0,0,0,0,0,0,0,0,0,0,12,29,3,0,0,7,6,2,4,23,13,0,0,0,0,49,33,1,0,0,0,0,10,47,6,0,0,0,0,1,1,0,0,9,1,0,3,4,2,0,0,0,2,1,0,2,8,0,18,0,0,0,8,2,7,4,4,1,0,0,6,8,0,0,0,0,0,216,1,1,0,0,0,0,1,0,0,0,0,0,0,10,5,2,2,4,2,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,2,2,2,3,1,7,4,4,2,1,3,1,2,13,12,5,2,2,2,2,5,6,16,1,1,8,7,2,1,1,2,14,18,23,3,1,32,4,3,4,2,2,6,46,2,2,3,5,2,8,2,4,2,15,31,35,15,3,1,1,2,2,1,1,2,9,1,7,1,2,10,5,3,3,3,2,2,10,3,1,3,3,2,13,6,1,3,5,0,2,2,0,1,2,2,2,4,1,2,1,2,0,12,12,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,3,2,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,2,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,21,2,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,1,1,1,1,1,2,1,1,5,1,1,9,1,4,1,1,4,10,2,1,1,5,1,1,2,2,13,2,1,2,3,10,8,2,1,8,1,7,2,5,3,15,5,3,4,2,8,1,4,4,1,3,1,2,1,1,1,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,1,1,5,4,3,2,1,1,3,6,1,2,10,21,3,2,2,1,1,4,24,1,1,4,6,1,4,2,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,4,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,2,1,2,1,1,1,1,1,1,1,1,1,1,1,0,1,1,0,1,1,1,0,0,2,1,1,4,1,1,4,3,1,1,2,1,1,1,2,1,1,2,3,1,1,1,2,1,1,2,1,1,1,2,1,3,3,2,1,5,2,1,1,1,1,1,1,1,2,1,1,1,1,2,1,1,1,3,1,2,9,2,1,1,1,2,3,1,1,2,1,3,2,3,1,1,1,1,1,1,1,1,2,2,1,2,3,1,1,4,1,1,1,2,3,3,1,1,2,1,6,1,4,1,1,1,2,2,1,2,1,1,1,3,3,1,2,1,1,6,2,1,1,1,1,1,1,1,2,1,6,1,2,1,2,1,1,1,5,2,2,1,1,5,1,1,1,1,1,3,1,1,8,2,12,8,1,1,6,4,2,2,2,2,2,2,1,1,1,1,3,8,2,1,1,1,3,2,2,1,1,1,4,1,3,2,1,1,1,1,3,3,1,1,3,2,1,1,2,2,2,6,2,2,1,1,1,1,2,2,2,1,1,5,2,2,1,1,2,2,1,3,1,3,6,2,2,1,2,4,4,1,1,3,1,2,1,3,4,5,1,5,7,4,3,2,1,1,9,2,1,1,1,2,4,9,9,2,5,2,2,2,1,3,3,2,1,2,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,3,7,8,2,2,0,1,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,1,5,1,3,1,1,1,1,0,0,0,0,0,0,0,0,0,0,2,2,4,2,0,1,3,1,1,1,1,0,0,0,9,2,1,2,2,3,2,0,0,0,0,0,0,0,1,0,0,3,2,2,4,4,2,1,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,3,1,1,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,2,2,1,1,1,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,1,1,1,1,0,2,1,1,0,0,0,0,0,2,1,0,1,0,0,0,2,2,1,0,1,2,0,0,0,3,1,0,0,0,2,0,0,0,1,0,0,1,0,2,1,0,0,2,1,1,0,2,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,2,0,0,0,0,0,0,1,0,1,1,9,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,3,1,3,7,3,1,60,2,2,1,7,6,5,13,1,3,3,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,4,2,0,1,0,1,2,1,0,1,1,0,0,1,0,1,0,1,0,1,1,0,0,3,0,0,1,0,1,0,1,1,1,1,0,0,0,1,0,1,1,1,0,0,0,1,0,1,2,1,2,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,0,0,0,1,0,1,2,3,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,4,1,1,0,0,0,0,0,3,3,0,0,0,0,0,0,1,4,3,1,1,2,1,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,1,1,1,9,3,2,5,5,1,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,0,0,0,1,1,1,1,1,1,2,1,1,3,7,3,2,4,3,3,36,2,1,3,1,10,10,5,11,12,1,4,2,2,2,13,47,50,88,2,1,1,1,1,1,3,3,3,10,17,1,2,2,1,5,2,2,3,1,2,1,1,2,1,0,2,0,0,0,1,2,0,0,0,0,0,5,6,0,0,0,0,0,0,0,0,0,0,6,13,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,2,0,0,1,2,0,0,0,1,2,1,0,0,1,1,2,1,33,6,4,4,1,2,3,1,4,2,1,0,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,1,1,1,4,3,21,3,22,2,1,1,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,2,1,0,0,0,1,0,3,1,1,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,10,0,0,1,1,1,4,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,1,0,0,0,1,1,2,0,0,0,0,1,1,2,1,2,0,0,0,0,0,0,0,9,8,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,1,3,2,5,1,4,3,2,2,4,3,1,1,7,1,3,4,1,8,2,2,1,3,7,7,3,4,1,3,1,5,2,15,1,1,5,10,4,2,9,3,3,4,3,34,1,1,21,3,3,2,2,2,7,1,2,3,1,13,10,11,5,1,1,2,2,9,7,61,2,1,3,5,1,3,4,1,6,22,2,2,1,1,2,2,3,5,7,1,8,5,2,6,2,3,2,7,0,1,0,1,1,0,2,1,1,0,0,5,12,1,2,0,0,0,24,0,0,0,0,0,0,8,5,9,7,2,5,2,5,6,2,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,3,1,0,0,2,1,1,0,0,0,0,3,2,1,0,0,1,1,1,0,0,1,1,2,1,0,2,1,0,1,1,2,1,0,0,3,3,1,1,0,0,0,1,0,0,0,0,2,2,1,1,1,0,0,0,4,0,3,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,1,1,1,1,2,1,1,1,1,1,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,0,1,0,2,2,1,4,3,6,1,2,1,9,2,1,2,1,1,2,5,1,1,1,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,0,1,0,1,1,0,0,1,0,1,2,1,0,1,0,1,0,1,1,0,0,2,0,1,0,1,1,0,1,0,1,0,1,1,1,2,1,0,0,0,0,0,0,1,18,2,0,0,0,0,0,0,0,1,0,2,0,0,1,2,1,1,0,0,0,0,0,1,0,2,0,1,2,1,1,0,0,0,0,0,5,2,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,1,2,1,1,1,1,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,1,3,1,2,1,2,1,2,2,2,1,2,1,3,1,2,1,1,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,0,0,1,0,1,1,0,0,1,0,1,0,1,0,5,0,5,4,0,1,0,1,1,0,0,1,1,6,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,2,0,0,0,1,1,0,0,1,2,9,7,1,11,3,1,1,15,2,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,4,0,0,3,1,0,0,0,0,1,2,1,2,4,2,2,2,1,1,1,2,1,34,10,4,1,2,5,2,1,1,1,2,2,1,0,0,0,1,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,4,1,2,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,1,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,0,1,1,1,0,0,0,1,0,5,8,2,2,2,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,0,1,1,0,0,1,2,1,0,1,0,2,0,1,0,1,0,1,0,2,1,1,1,1,1,1,1,3,3,1,1,3,4,1,2,2,1,1,5,1,3,2,1,2,2,1,4,2,1,7,1,2,2,1,1,1,1,1,0,0,0,0,0,0,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,4,1,3,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,7,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,1,1,1,0,0,0,1,1,0,0,3,2,0,0,0,0,0,1,1,1,3,1,1,1,5,2,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,0,1,1,3,1,0,0,0,0,0,0,2,0,0,1,1,0,0,1,2,0,0,0,1,0,3,0,0,1,2,1,0,1,0,1,1,0,0,1,0,1,2,1,0,1,0,1,1,1,2,1,1,0,0,0,0,1,0,1,0,1,0,2,2,1,4,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,1,1,2,8,1,2,1,1,1,1,2,3,13,4,4,4,8,2,2,20,2,10,6,9,11,1,2,3,1,3,1,1,9,1,4,3,1,7,10,2,39,1,1,2,6,5,1,2,7,2,4,3,1,1,1,5,4,2,7,5,2,3,20,1,7,57,1,1,5,1,1,0,0,1,3,1,17,1,1,0,0,0,0,2,0,1,1,4,1,0,0,0,2,1,0,5,1,1,0,0,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,2,0,0,3,1,5,1,15,0,0,0,0,0,0,0,1,0,2,6,2,39,44,9,20,2,1,3,3,4,4,3,2,1,11,6,0,0,0,8,3,1,1,0,0,0,1,1,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,2,4,0,1,1,1,1,1,1,2,1,1,0,1,0,0,0,1,0,1,0,1,0,2,0,1,1,2,1,0,1,0,0,0,2,1,47,9907,8170,2583,1295,1378,1382,237,1436,276,202,2654,389,438,841,315,113,208,66,839,60,588,156,236,488,2441,28759,11766,1967,1298,130,229,571,841,348,557,3271,776,1432,553,194,1342,493,193,888,380,216,4433,76,795,1565,1680,1300,554,930,372,557,743,411,1574,440,2289,761,193,46,778,781,268,3195,334,277,556,558,557,204,558,511,539,3060,177,6,193,191,0,427,5,0,780,40,1314,314,112,494,206,2,38,207,67,425,670,93,61,587,538,349,237,1332,1144,4005,953,61551,1,25148,9800,16154,58621,9969,1788,1587,1050,1943,1728,703,234,1002,1462,1220,1100,6114,2562,1791,1149,1006,713,2665,220,59,220,550,6,55,338,46,17,117,84,288,215,261,7,21,25,1505,2747,5601,12819,1344,813,1078,75,437,297,21,18,1325,9179,642,189,223,152,867,4,17859,2373,288,904,338,504,847,47715,1937,3467,2322,6440,5789,149,2668,1343,1773,2937,100,8213,6023,3125,350,654,1633,1026,167,94,114,275,310,13,103,56,6196,9894,348,20669,1509,1137,551,2691,2881,1072,1108,1350,4752,3222,2314,225,678,312,333,305,2515,317,2107,1310,441,610,1383,956,289,297,1594,4370,6920,507,182,1725,2224,770,240,180,204,132,1905,568,213,1136,460,635,135,349,207,38,6125,340,2966,2487,1754,1578,2690,13020,3077,190,345,570,1993,321,105,308,696,280,2817,1176,1367,913,3429,6422,3584,463,1529,794,1602,852,1,638,758,381,704,150,508,3086,846,224,18,154,2525,721,5666,105,1255,442,189,1,270,1112,561,3794,2902,817,588,448,893,854,664,4222,2787,211,869,477,1113,495,3903,1996,541,983,759,374,7726,2841,676,561,207,858,696,195,79,39074,10343,5620,3400,865,2679,4076,1896,220,353,328,230,72,131,2,156,849,21840,10613,5736,7265,8283,4826,644,4226,338,583,1691,542,329,161,303,772,167,636,693,135,179,135,2,345,3,618,178,160,11763,7871,5985,6934,3831,2425,294,147,807,1366,475,153,806,322,77,212,270,7101,7597,6182,3326,2703,336,298,335,3184,1518,411,46,240,1271,239,155,4731,9965,5277,4677,384,1866,396,1670,478,79,115,392,32,12558,10283,34,5698,95,223,489,1048,1428,3,287,103,404,166,50,10,225,89,23892,3220,7964,1697,2291,785,4841,1875,595,1127,231,252,4,1029,576,1008,170,166,293,923,5160,15258,3073,4663,4219,5396,4322,4004,1453,2524,4,977,24,565,1005,347,109,979,450,97,344,214,393,185,2105,4894,903,657,1177,414,853,174,8674,4390,5183,5110,5681,3307,4494,3928,450,2113,2371,1138,629,614,705,2,300,442,237,54,16,731,3035,842,1636,1055,1448,1704,1402,178,1553,533,473,386,525,647,252,2079,1859,1533,1534,1186,2281,200,2694,239,466,414,819,385,17,183,1045,3462,2261,1274,1377,1207,1057,708,1864,499,443,235,852,435,99,397,1903,439,5584,3443,1778,2658,1944,1521,1608,1179,1254,511,545,278,461,348,1165,640,211,902,128,2,4501,5051,2429,6360,162,802,1214,959,1170,874,69,1058,512,178,329,1769,5697,4138,833,3758,1330,1703,2111,305,387,63,138,80,241,248,191,302,164,5052,5621,6071,329,699,2558,1511,612,931,961,2206,1350,11,898,589,1730,163,803,1072,3424,9637,1655,2220,476,3434,1020,7,1085,652,259,587,1836,165,323,268,1207,6915,322,382,596,222,1365,1024,350,444,1032,399,76,304,562,708,5222,524,986,6533,10276,5418,3261,1396,515,775,1691,2505,759,659,607,414,213,1288,1363,686,1865,6775,624,573,151,1087,727,321,47,592,419,522,803,556,206,383,105,201,1093,2367,1644,326,1180,717,566,1546,4944,1692,8,1926,737,3014,847,432,1197,75,3237,546,493,7585,1843,4175,3624,2279,2220,2488,815,4360,878,711,299,148,3,541,1707,3956,3714,4674,2726,5519,421,2795,251,1558,544,448,1171,1622,116,494,7,85,1112,5598,997,304,1142,1676,1443,5040,2921,1043,2095,3232,543,188,76,572,214,121,289,3073,8198,2245,4122,2962,1706,3818,474,101,337,957,1931,1980,3285,1802,5584,1344,2591,1607,1432,1164,322,1115,1755,1230,5625,2391,1207,513,2183,1037,400,690,150,1440,3076,98,6852,1969,1466,3318,1427,7470,3057,1663,1042,925,289,384,781,485,753,1418,2296,6237,0,2313,609,4531,2071,435,1904,2729,604,107,443,1178,1120,3937,5443,10544,20385,570,348,252,877,739,434,4396,4070,660,164,1,350,2097,210,2375,4023,2,559,661,477,1910,684,903,3474,1224,606,190,1624,1163,288,876,1319,385,298,0,349,100,780,1177,338,558,3009,958,1743,2768,8377,2182,14390,1099,41546,71404,1215,195,3,368,59,175,220,57,25,38,6,158,55,2,165,364,137,24,177,52,39,4,0,51,386,86,319,363,2989,0,0,0,0,0,0,11281,1711,2616,972,781,523,673,942,2227,772,1355,527,620,1723,1279,1081,3333,734,551,1892,256,152,773,71,657,83,1443,280,281,194,188,1211,155,42,384,110,71,976,549,157,372,344,523,188,254,748,167,679,438,649,982,436,1528,1219,4414,560,1472,11205,0,857,387,199,480,870,138,206,194,542,224,377,841,147,318,405,306,400,440,616,782,1491,217,1994,573,125,599,256,271,271,215,108,330,622,366,149,659,161,280,772,268,442,196,128,131,262,572,192,100,83,92,586,98,214,524,353,318,237,486,274,678,145,128,207,605,166,518,338,478,490,261,108,173,219,0,355,205,137,589,202,461,159,123,204,402,354,354,39,67,236,193,158,236,267,571,335,601,365,249,467,352,160,859,250,889,190,235,1,341,259,0,204,249,505,252,148,557,115,399,266,362,776,491,478,858,158,572,194,72,538,375,398,334,361,210,248,397,372,102,265,161,238,335,231,282,319,142,648,157,582,879,658,264,257,567,124,247,162,153,353,571,169,370,604,964,832,570,659,164,108,558,600,246,97,84,191,124,85,124,364,747,567,346,393,50,365,223,376,364,840,283,334,364,193,778,189,588,625,154,125,284,251,333,232,260,317,41,406,107,235,149,236,359,283,779,271,265,95,163,215,427,519,211,308,199,153,885,170,766,255,318,162,260,110,487,569,332,568,51,91,834,522,282,259,557,228,84,151,66,270,252,363,489,331,658,840,102,362,835,76,521,170,166,466,257,161,152,353,1242,614,436,256,599,329,198,1079,0,363,394,255,578,259,401,254,344,1313,307,71,1100,655,1699,98,1148,4824,0,2776,188,1094,1363,2367,6493,13415,945,4759,15646,5,0,0,0,0,0,0,0,0,0,0,0,0,0,8,3,249,149,114,1202,61,110,137,85,41,9,14,5,81,17,25,49,196,1563,7732,1,1,134,121,151,119,18,29,190,1130,36,27,112,24,135,88,42,36,28,15,6,82,18,109,51,52,74,128,1928,4,1834,603,93,730,46,203,372,126,131,495,521,793,63,280,614,662,1760,805,63,406,670,721,575,54,65,38,273,84,81,3,100,112,296,61,63,204,15,71,109,47,111,525,666,8191,1,395,103,93,146,139,87,133,759,91,83,36,51,126,225,51,44,54,28,65,281,396,131,184,47,160,45,115,169,66,82,81,48,132,414,104,2,3,34,48,116,160,13,176,156,479,98,79,9,61,90,101,64,126,415,328,96,399,117,2,16,49,427,84,5,153,5,125,362,67,39,105,54,203,68,9,83,38,46,183,526,411,97,319,67,55,24,38,8,54,168,44,52,69,17,255,46,140,10,6,48,281,107,397,11,67,52,107,56,193,153,410,114,93,266,64,132,126,258,164,4,102,50,145,362,169,3,7,128,2,42,14,111,296,288,50,162,2,119,127,250,202,419,74,60,38,99,23,652,52,56,62,117,7,25,163,222,163,218,68,66,162,49,282,129,108,135,110,30,2,80,462,2,2,283,3,56,80,3,2,3,109,8,3,3,113,89,416,4,185,68,62,118,48,98,13,1,66,53,127,414,123,214,229,0,54,38,162,97,60,80,282,155,52,65,57,49,143,229,44,67,139,85,387,0,41,39,53,274,56,164,161,111,40,344,192,396,47,36,296,538,642,250,49,8,87,467,136,43,176,413,267,37,131,232,190,346,803,23,463,2224,249,0,800,299,796,326,428,162,815,1921,2754,165,40,35,23,31,125,83,11,66,142,5,63,80,5,31,36,17,30,111,51,180,144,648,422,3737,108,2763,0,0,27,58,26,16,16,45,56,515,80,1092,28,700,45,64,21,29,39,46,36,26,22,57,32,0,126,82,45,10,42,22,60,80,25,4,15,64,81,15,4,32,39,16,80,29,102,7,49,28,107,87,89,27,85,106,60,148,612,30,601,584,13,163,328,6379,0,490,0,8,3,10,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,1,1,1,32,2,2,2,1,17,1,0,0,0,16,18,31614,3811,3025,225,877,581,793,377,516,1160,76,38,161,892,127,513,112,412,576,367,128,103,704,169,141,236,112,923,17558,12690,81,1292,2315,903,3128,302,1092,425,614,317,835,494,767,233,497,1017,13313,4372,617,452,672,563,178,264,2246,137,426,447,517,697,281,619,1924,1076,680,267,273,167,1081,1361,230,1233,626,1377,303,1109,441,1795,361,378,97,334,273,12,336,310,1121,20,0,0,0,0,78,47,478,662,2701,868,126,514,114,493,413,502,73,442,366,231,129,103,266,2,2227,1273,170,235,698,142,233,492,759,1149,2560,847,53725,67318,6962,3969,16514,2413,10850,4849,652,798,723,494,628,357,1200,2346,1652,12532,2306,602,417,2927,92,203,6,221,12,1,55,34,270,60,68,58,18,2,30,1,4,24,3,6,2,3,11388,545,11913,1385,4879,8955,312,793,390,650,187,139,182,988,949,363,2799,350,18669,498,2129,486,1114,1591,89,52,67,173,18,1,197,5,39,22,18,2,39,15,10,2,8,13,14,410,3787,536,3791,2017,616,651,560,1603,3468,460,503,783,1160,1022,328,1627,15,869,6502,4941,734,760,938,5509,1026,8717,2154,241,628,18,1,50,2,536,337,455,1720,1601,443,123,1,2913,789,637,556,922,538,693,3707,1624,1341,13328,189,171,96,142,131,1,785,304,274,646,1843,512,969,1232,1319,341,765,14409,1497,50,146,790,786,617,654,311,797,305,652,275,324,1833,944,276,647,649,791,2527,511,923,456,140,152,1657,1184,2201,796,1371,2797,505,950,2341,255,8152,915,51,183,1625,14766,1006,139,27,8195,831,86,826,2,5127,75587,12951,11717,14297,114,93,121,33,19,3739,1501,1430,28,17,35700,20426,34207,45,49,9,200,21893,30061,2,4,55767,56,49,21,5,74735,38958,7784,840,10011,1254,397,1423,409,1267,55,2942,67,83,43,15,21,5,5,58455,6237,272,5939,1945,988,219,731,25,44022,2953,33476,8544,819,4002,1423,281,1763,107,73,24,6524,37979,7069,790,515,1306,1493,2231,44,17,9556,740,272,55940,6139,13175,12718,1707,1324,381,5453,55,66,31,1,11519,28084,17791,8857,1045,8147,8,17,11423,1112,3747,866,2457,2,35,32609,11625,2646,9,11895,72,7,33,0,37069,10038,1013,20106,3,33,3,0,12521,1572,50879,168,363,149,309,80,163,6,7,65,1,3243,24926,195,13,21,15,2,6256,9,17097,7901,68861,676,19417,10266,1723,470,7830,1125,133,199,3,132,43,14,15,7,842,11367,1140,1367,1956,400,6070,841,389,1029,120,280,6,6288,46247,14465,3765,1311,13644,533,49,1,42,68,8,7,5,0,0,6772,1318,329,526,48438,8905,1528,14708,886,28,109,19,2,35,1,22557,9163,44708,149,373,191,303,34,9,0,6082,30765,412,369,16242,1691,49,336,130,195,28,12,41,58,2,5,119831,5211,860,93,1460,398,17,85,17,1,102522,2333,3654,13201,76,846,210,467,188,69,34,6,14,0,0,22740,18995,64868,168,937,285,115,25,49,0,4090,20769,233,863,38,67,76,1,25686,247,793,36,0,24361,96143,2831,880,189,464,86,65,61,63,0,0,23896,756,229,104,37,113208,4678,462,4229,140,10,55,13,98048,3393,14464,367,68,70,1,23866,78911,163,84,10,27842,32,121365,157,1328,93,36,706,32,7,21,1,2,2,14669,6146,95846,1046,36,2183,12,79,14641,293,6131,57735,13587,3947,2918,38298,60,6,45,17369,4872,1121,35347,0,1326,3996,25633,1,653,9468,8735,87515,2109,3478,1271,6258,8014,3523,4,1,2,18679,26694,4410,18381,17154,1794,7803,1657,9575,1504,195,7349,22923,6742,860,9027,5072,555,1,0,64195,1737,101526,1,43062,606,393,363,236,122,307,793,177,756,245,769,503,1525,42,311,23,751,112,413,805,124,412,84,283,279,213,138,145,155,101,2385,290,249,116,2294,194,7,466,30,278,370,47,183,256,483,526,144,5350,0,1982,1396,701,600,611,2752,149,2442,639,1595,2440,1940,839,208,1019,120,99,583,86,158,430,711,243,420,252,317,365,256,88,366,444,165,516,219,398,4573,192,314,225,1522,65,1145,219,216,86,46,199,253,411,242,1271,6090,1109,124,175,176,316,681,528,231,358,88,148,270,160,291,122,412,175,65,235,507,29,196,96,120,208,401,227,78,365,125,939,132,527,673,678,414,80,117,148,176,290,847,334,289,364,347,230,82,301,372,67,483,271,318,721,258,244,381,359,148,320,124,316,187,321,185,4,347,298,817,250,215,146,352,84,341,499,123,1022,526,174,146,545,66,480,499,232,483,86,157,722,538,762,93,226,542,403,0,0,506,171,161,353,363,131,41,207,402,491,68,279,416,505,250,214,123,542,119,8,13,0,401,566,105,364,98,346,552,372,101,209,94,400,87,174,159,439,145,100,231,792,347,132,200,173,110,500,411,242,259,243,86,221,69,498,241,3,329,112,253,233,567,442,353,256,43,227,347,254,489,186,120,161,106,322,170,89,484,142,258,308,212,259,367,580,242,164,143,83,90,63,515,105,184,630,181,218,340,232,254,397,169,2,30319,2746,571,297,2051,293,184,450,167,139,209,352,1338,1551,2184,1520,4503,25170,1306,103,3116,777,16224,360,40,461,522,8383,2711,191,582,257,12227,5643,672,235,104,259,12,482,153,312,339,504,124,1382,1321,370,84,289,813,1523,349,471,1283,4568,410,292,152,1120,987,588,128,351,77,226,283,752,1796,83,234,426,131,182,255,72,661,1781,277,587,122,1034,472,233,167,226,595,790,75,425,85,1070,208,334,351,332,256,707,573,1388,571,531,920,767,1088,959,3011,2319,24910,2154,5014,25826,14948,39679,23,5,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,426,67,4641,252,290,32,47,53,83,1587,8760,8816,1,29,93,199,143,68,123,27,105,873,2569,1069,380,90,232,33,48,104,54,85,1442,1254,13480,5119,4420,763,1598,5031,614,747,1689,1790,202,436,94,88,106,850,213,138,599,654,82,454,159,257,278,102,156,309,282,236,795,559,453,645,1032,1182,346,1111,239,630,46,659,1075,1274,55,749,4242,256,2195,172,56,38,1469,203,464,255,218,54,115,33,1,76,18,472,4165,1,265,949,239,74,534,88,113,125,209,88,352,368,177,199,217,143,57,98,72,43,758,366,831,847,301,391,232,266,90,129,261,96,151,14,283,113,143,62,138,108,236,198,133,131,84,13,61,51,126,475,350,445,301,307,232,143,190,375,418,1757,554,329,178,306,374,129,277,151,312,1,109,104,90,214,98,406,394,10,137,144,146,46,106,290,351,182,196,240,2,352,4,65,45,39,115,388,795,352,75,420,324,66,166,1032,392,298,469,409,114,535,6,412,252,353,186,324,353,392,94,111,87,199,184,531,254,155,171,74,4,118,355,222,1414,89,408,116,300,99,112,36,260,330,179,387,180,100,26,307,378,470,114,300,495,89,134,181,653,160,95,101,130,89,713,413,313,241,303,294,233,114,132,414,55,33,435,417,278,110,116,267,123,92,622,443,139,114,342,248,51,142,828,536,83,126,415,27,35,242,255,453,89,9,1,157,0,5,225,30,321,279,172,44,50,50,3,0,416,128,110,156,103,210,104,49,55,85,133,180,537,109,127,155,28,141,302,254,281,301,143,76,73,237,267,28,54,102,138,14,206,193,156,0,262,95,425,170,32,392,106,144,97,136,0,2,306,186,112,97,481,34,84,654,44,287,236,417,213,520,226,101,85,52,536,347,38,1287,388,95,24,87,84,152,1,637,100,451,97,188,902,325,402,160,235,291,4,31,124,184,143,235,187,96,6,242,46,252,151,187,0,348,11,50,633,716,48,181,354,137,50,212,9,285,1478,165,416,109,186,105,772,133,72,45,282,115,101,1,611,450,613,493,185,0,54,182,117,373,435,429,1518,176,114,32,39,112,169,231,451,1330,204,118,201,180,437,229,725,190,46,2823,360,292,201,142,127,904,91,4687,123,815,813,1081,2580,261,1821,285,144,137,155,289,78,124,204,257,278,499,146,192,133,322,243,6785,150,312,596,54,200,257,92,326,484,237,145,2604,153,224,462,233,133,173,255,314,14,128,161,376,268,5343,282,1,204,111,10,283,245,539,34,417,113,174,809,654,226,1,2,54,47,649,442,71,102,119,326,56,748,236,84,189,699,923,1365,293,293,98,130,117,91,330,205,340,7199,117,114,36,228,137,246,103,303,64,934,285,190,379,40,330,266,60,118,234,2894,197,944,576,219,253,547,380,194,294,964,293,994,134,249,191,882,3,181,1089,248,265,129,1039,409,118,123,149,418,1424,259,35,0,183,752,302,448,249,168,266,417,136,186,1460,128,117,255,191,313,42,30,64,91,129,245,265,259,206,320,53,416,244,299,776,404,695,462,258,4271,5817,471,1092,120,184,50,465,79,155,86,290,269,82,0,50,216,571,289,113,800,75,794,947,1599,1108,873,11275,0,0,0,0,0,0,72,256,153,237,292,101,169,218,50,148,28,339,409,572,61,2627,216,321,152,67,101,111,115,40,27,716,118,154,98,84,51,236,206,87,153,137,203,100,124,78,136,154,253,289,96,170,8,10,67,422,44,9,22,115,9,252,135,202,183,193,481,150,137,133,143,152,357,226,118,221,38,275,101,137,780,1018,307,142,126,1461,637,71,3017,411,2493,1739,0,4,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,2,184,6,79,4,13,2,3,79,102,2,6,393,1,1,51,35,29,158,1,35,8,1742,3069,992,263,1005,23,100,21,3141,2973,1,978,269,77,25,345,66,798,483,663,65,32,1441,624,163,295,1037,595,197,657,144,303,27,117,1380,362,66,26,72,31,305,28,60,215,8758,10394,1187,1682,6062,6360,745,1312,71,127,871,281,215,192,114,327,87,131,25,56,132,205,49,67,19,41,33,5,125,41,8,220,92,74,277,37,14,25,132,34,4,141,126,29,52,9,114,98,52,235,23,8,16,177,556,88,4,20,15,890,3,14,9,89,1373,1093,4245,1165,278,173,300,46,623,88,52,154,194,13,20,362,43,124,43,69,16,617,1106,321,366,28,31,117,2524,82,253,194,65,2,103,53,13,75,32,19,8708,1047,1167,77,137,35,1002,369,246,223,153,113,34,71,49,52,230,91,58,210,3627,1643,115,582,237,4083,805,1017,66,721,206,115,294,116,96,241,34,59,201,7,313,172,61,63,177,187,292,13,109,200,30,99,90,26,256,114,65,269,26,2625,64,531,135,212,222,239,401,41,36,62,121,309,18,62,17,290,45,22,195,59,55,227,20,278,2010,255,184,913,467,57,79,141,183,108,77,78,131,84,60,186,33,222,141,139,84,115,112,17,78,13,17,114,203,59,179,26,176,16,78,72,110,199,81,72,188,1246,217,150,249,79,154,113,128,130,8,138,203,67,50,174,38,122,107,126,141,33,183,301,179,36,427,101,43,36,36,1318,182,178,1339,825,418,326,356,254,191,246,222,130,242,92,254,48,61,33,368,72,105,652,91,166,973,436,127,535,180,499,25,161,93,124,277,28,265,105,81,120,241,160,75,88,200,215,223,56,100,35,94,78,33,97,37,45,103,42,167,146,233,126,774,138,26,58,246,82,77,11,876,751,224,224,258,229,77,191,505,137,402,216,877,190,144,316,106,12,154,122,683,239,108,306,290,35,42,340,403,80,80,752,27,73,16,217,128,41,92,59,328,102,132,362,155,175,75,404,73,114,38,327,349,26,117,1,109,94,73,125,78,9,130,363,218,181,2,35,97,271,357,81,79,31,242,57,129,129,500,29,35,101,155,255,33,18,58,35,59,98,10,190,878,20,26,114,160,34,61,39,30,284,247,0,1,127,39,145,16,155,187,18,364,195,10,83,15,72,120,233,217,25,51,221,34,83,6,133,91,126,66,65,289,335,216,220,96,59,405,212,243,100,86,278,259,237,32,1,33,96,91,34,90,12,118,44,237,35,2,185,40,137,52,127,54,227,14,37,52,64,67,0,9,72,17,7,80,242,43,10,11,19,177,26,79,48,24,0,83,64,202,204,34,73,136,21,848,174,82,20,63,753,76,66,105,58,0,38,124,2,185,96,20,30,142,95,118,302,545,134,114,189,180,54,18,98,165,6,365,155,113,137,138,133,25,317,43,403,156,227,79,166,71,53,3,501,0,303,880,684,65,217,119,40,547,53,170,157,881,428,240,18,222,205,344,218,506,288,970,442,147,401,116,156,301,203,211,157,135,64,11,83,117,167,128,184,19,58,265,380,320,240,62,546,227,158,109,82,53,101,74,129,87,754,322,92,656,121,110,279,185,53,144,1213,40,260,254,686,327,1161,205,146,315,221,90,309,161,827,116,115,31,19,156,235,186,93,190,99,200,181,97,216,20,527,54,19,462,162,96,255,665,84,41,319,598,148,216,995,127,21,470,189,16,1402,1759,137,64,199,110,45,77,37,837,348,391,223,199,202,685,80,17,386,1,1753,1,50,18,66,125,58,1,1283,162,694,719,217,451,745,141,329,48,300,681,282,259,129,124,867,79,105,302,104,5,494,878,10244,33,113,276,217,83,98,938,225,150,600,110,652,326,215,188,51,259,401,506,15,27,466,328,78,443,327,93,847,18,923,283,65,74,52,82,260,1,124,128,125,866,16,52,335,109,327,107,122,411,1,659,606,266,3,2,2,1395,36,2199,10499,538,43,106,219,73,30,219,120,1814,148,566,298,675,163,427,5927,0,0,0,0,1584,278,94,243,20,362,182,2714,30,422,95,569,315,527,2888,0,352,117,103,710,102,266,46,405,34,42,116,350,124,104,93,63,70,170,83,39,64,116,80,151,81,27,236,345,144,79,46,34,73,103,1256,133,921,238,175,2790,0,146,231,410,742,87,1240,16,240,61,609,173,879,2677,81,1421,2291,35,4,2,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,5318,410,634,545,2983,217,293,199,2,4,53,2,5,104,113,206,371,10252,6591,3,4,387,103,1992,285,283,45,1862,416,2,133,144,440,86,104,640,509,38,126,367,342,85,3685,926,233,586,585,201,284,1,2,4,0,0,1,343,0,84,6,105,77,38,268,71,334,231,20354,17558,2380,2438,468,75,186,27,297,1652,316,408,1913,251,410,478,947,263,541,49,400,2095,4604,2681,2342,600,242,608,353,401,1064,155,1335,250,10,328,828,95,1002,308,212,79,141,123,200,123,136,109,135,239,1,39,254,278,25,1,182,144,292,368,1013,2067,1,1,914,1461,43,453,185,251,188,165,490,42,146,73,337,3318,2110,1933,470,309,16,215,343,620,71,151,270,287,109,260,65,430,156,192,274,33,5,1786,129,684,366,223,336,620,289,82,130,129,134,61,140,303,132,658,226,1464,536,102,253,166,31,176,199,271,44,200,11,66,1,401,161,81,186,304,28,185,298,685,747,252,9,7,1027,259,56,410,210,596,947,270,31,367,246,82,659,148,105,412,376,222,270,179,301,147,227,669,158,130,39,305,264,45,326,164,52,686,147,224,48,208,223,74,26,92,71,8,568,1207,537,597,297,170,149,82,8,17,52,5229,1009,1561,716,830,348,419,47,661,123,74,571,101,298,219,446,145,8,208,215,375,438,2070,276,1221,412,931,673,1175,162,1180,68,8,749,26,29,260,868,1813,609,212,14,403,152,41,61,534,1373,424,867,553,1220,999,146,249,114,572,30,102,300,354,463,4,2,499,187,323,201,268,300,208,1080,161,161,1277,79,4,285,221,278,2,51,914,129,157,601,18,359,74,237,58,367,511,22,634,82,8,172,107,4,480,6,46,424,108,326,345,176,134,33,1266,267,574,68,140,370,68,3,155,322,86,162,299,183,17,15,624,2,624,523,449,61,452,0,746,544,289,131,170,274,4,368,0,1265,1676,33,249,172,0,286,342,92,941,54,9,263,213,210,145,56,143,2,221,107,305,139,46,269,901,995,19,156,8,339,145,1180,853,638,1257,166,1,229,227,245,26,216,161,202,336,279,175,174,2,427,429,0,0,80,1050,111,165,197,351,209,233,70,27,218,97,60,371,526,129,193,123,27,150,88,506,325,616,1485,281,320,862,130,269,10,194,91,0,243,621,13,864,366,48,178,463,307,227,440,1740,0,244,149,735,65,1014,383,1,312,106,70,304,202,1511,881,861,358,351,119,46,245,597,80,1185,994,192,78,165,1691,242,449,827,325,166,150,148,685,9,102,961,2546,2570,105,110,49,478,877,143,325,1,482,401,1044,0,961,66,458,242,150,80,4399,1032,478,275,70,46,171,209,429,174,945,173,1,117,8,1053,2151,0,2754,990,797,111,233,68,657,423,515,6,1467,2,91,253,141,130,137,4741,0,557,1153,451,827,1423,27,109,2294,536,109,129,127,412,149,6,392,1486,184,199,323,48,410,428,538,73,1357,1,212,13,55,215,495,354,344,460,3,114,72,491,3,207,475,230,1562,402,366,238,175,160,170,361,876,439,127,684,529,422,401,201,322,0,546,201,181,119,1528,252,421,1247,487,151,1021,244,400,273,945,229,126,321,3545,39,571,174,228,649,683,8,991,439,863,1528,657,943,1272,1,0,990,802,148,524,266,171,261,1861,1144,0,0,1257,1010,1995,2,8,0,275,2902,872,812,1693,1046,9450,1,13758,126,929,87,296,307,311,83,1006,969,376,234,57,677,679,35,72,3,127,160,28,42,105,58,133,69,84,24,201,28,43,107,0,79,246,178,222,303,145,118,285,198,315,233,1271,3678,0,0,0,0,0,0,0,0,33,1232,151,780,504,367,1623,1333,902,32,743,660,133,32,103,5,33,16,88,182,67,63,572,74,557,412,937,1934,88,70,130,82,503,802,99,232,293,129,150,85,251,137,119,21,342,140,56,290,28,342,49,148,77,0,149,137,216,149,169,82,380,301,235,425,22,26,270,435,155,198,100,62,0,103,136,71,662,82,213,31,33,0,106,809,204,128,408,0,92,160,147,107,138,265,236,57,127,640,482,0,91,87,78,61,0,321,101,57,132,31,0,236,101,90,253,29,159,226,112,108,64,160,169,394,67,373,592,164,205,104,85,210,142,213,281,64,1130,634,100,89,34,81,73,136,2,126,212,252,237,266,30,21,159,160,134,79,27,102,106,71,41,313,4,163,106,12,250,132,265,126,98,83,38,166,187,29,0,225,41,264,1,88,106,103,22,111,298,84,118,78,105,78,107,308,178,45,118,269,77,83,197,10,181,263,159,105,220,551,324,95,141,271,268,205,57,512,267,523,283,66,605,643,292,146,94,3162,774,1544,1140,13198,46,15,6,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,1,1,0,0,0,0,0,1,4,46,13,1,43,14,5,24,11,7,39,2,9,5,1,6,11,884,2,1,49,9,7,6,1,3,28,5,9,9,17,8,11,8,18,1,4,10,15,6,10,9,1,7,5,34,0,16,0,0,0,0,14,4679,1344,1489,958,499,79,449,386,11,91,154,155,2078,996,116,52,69,240,51,1,16,102,212,1296,117,989,11856,9767,1,303,107,85,720,482,2217,807,217,187,111,110,187,239,610,179,296,597,76,164,191,120,1061,379,122,180,102,167,108,181,500,67,93,409,12,92,42,114,86,156,297,2695,2015,723,14,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,3,1,0,1,51,103,70,68,174,52,102,2,15,104,112,196,1685,200,130,1,2,969,566,21302,14186,1887,619,735,176,2085,3053,412,421,489,342,1235,321,548,527,271,339,652,1382,9976,5342,1944,5986,554,264,1214,1382,1305,1185,595,204,97,152,99,378,820,598,139,154,7,17,198,188,136,367,187,70,24,511,230,885,4035,1055,1011,160,143,983,347,225,166,1221,835,359,2482,1006,225,1041,406,419,503,88,276,434,98,86,120,597,766,862,291,11,823,114,85,621,1618,767,132,177,161,343,1406,299,186,358,143,5,579,2490,1057,715,180,84,107,647,173,2,209,5,80,122,348,359,414,9,437,14,292,41,93,252,232,701,226,193,113,144,167,438,158,1,167,530,600,344,625,233,20,531,1125,104,67,272,399,329,203,254,950,121,184,1080,1080,94,161,5352,636,4417,721,1226,1439,1050,108,317,325,402,129,599,615,380,646,309,201,569,229,103,36,1196,2563,3856,1374,314,635,1195,1998,93,401,143,427,88,91,227,24,18,159,530,865,1248,557,424,452,228,129,229,330,139,10,863,178,189,487,697,2109,187,1421,2298,1191,1008,524,646,54,661,443,1097,743,355,344,297,331,596,210,297,370,37,335,119,287,404,208,152,499,162,436,2760,149,573,935,1017,348,312,262,227,354,293,311,492,6,178,778,181,30,150,125,136,188,6,384,60,484,612,149,300,355,163,304,326,191,253,366,703,94,8,16,2,127,3,4,497,1449,478,346,107,347,273,213,168,1105,837,5,351,455,522,204,10,279,113,468,350,783,367,677,599,1170,785,61,152,514,233,219,658,215,156,417,152,249,2276,849,317,485,192,1187,650,8,120,276,220,379,96,159,265,187,1251,301,441,254,1041,35,474,6,42,930,52,1307,763,313,258,2,113,337,150,255,340,318,119,53,55,535,261,773,159,1019,197,22,180,153,161,188,648,227,512,319,483,231,145,487,608,41,354,351,82,1198,321,306,319,563,629,62,208,160,95,253,172,194,232,193,735,2,1907,212,501,442,4,299,89,788,171,348,263,428,734,255,32,310,215,254,581,234,331,690,18,295,455,156,324,151,308,71,169,226,126,502,1020,732,118,1194,307,568,816,67,267,135,604,991,12,831,625,836,443,473,343,1019,252,228,462,6,146,410,300,258,309,321,5,326,399,1193,580,151,404,356,701,1018,386,370,51,434,457,703,1030,99,240,175,657,310,4,364,93,220,2525,292,393,152,143,62,87,536,1576,120,724,20,355,684,652,300,285,151,15,566,2547,636,454,93,534,237,829,4137,126,38,172,187,316,346,223,877,0,382,611,378,135,348,782,311,2000,0,658,723,158,1234,952,1135,323,332,232,841,4,266,193,935,336,1070,1676,403,186,416,656,285,650,402,286,1223,730,403,1522,613,177,2049,325,200,307,228,465,265,476,716,2483,4632,150,2275,639,2664,226,638,16869,20752,774,89,160,156,100,134,59,433,2,123,223,379,123,117,68,78,79,1,0,115,38,2,94,136,578,67,156,399,805,424,490,2083,5727,0,0,0,0,0,0,0,2313,1019,219,393,206,383,735,88,461,321,217,262,337,304,751,128,71,246,172,78,122,67,90,88,90,158,30,389,128,383,221,145,98,323,1036,927,962,979,2074,3446,600,152,372,153,108,75,47,3,92,287,366,815,305,191,30,132,42,216,59,113,98,218,59,0,394,157,205,304,91,9,208,173,127,94,599,204,36,159,318,218,35,97,21,87,101,90,326,190,51,320,209,258,212,29,1,122,189,216,181,355,260,208,240,95,279,256,69,202,151,87,285,149,145,74,35,188,338,89,122,176,172,508,32,217,245,87,158,129,69,327,72,247,219,70,173,79,43,37,203,2,3,66,5,4,89,2,15,204,148,87,126,157,317,326,207,325,30,598,388,93,127,69,78,238,54,80,49,117,213,211,85,132,345,222,143,246,554,507,204,213,352,199,20,87,1050,462,390,301,1520,1628,27,637,1841,1410,2852,13015,61,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2074,503,212,26,272,1154,20,151,18,37,235,887,2294,8276,539,301,321,212,734,140,542,250,121,29,185,27,302,225,50,308,409,962,17,11,2,3,0,0,0,0,0,0,0,0,0,0,0,0,10,0,1,0,19,38,127,113,303,842,505,4325,3412,1378,208,771,3009,500,290,245,347,396,279,1,163,48,298,273,199,155,50,319,477,178,481,218,5,309,189,135,390,406,16,51,124,56,144,298,683,350,2332,156,188,443,457,387,271,107,32,92,175,205,44,142,176,817,19,85,101,118,200,485,419,7372,4,1180,265,301,125,123,370,1,69,34,63,54,56,103,81,95,535,134,117,60,62,427,171,72,56,292,1,92,118,220,249,126,102,80,604,381,119,280,389,320,1,3,223,2,150,200,276,109,93,519,84,36,655,339,79,85,250,132,160,135,169,78,266,302,605,138,81,131,340,29,101,271,1,205,76,382,126,118,127,120,2,136,124,30,49,209,80,12,303,223,52,361,123,156,170,61,115,318,128,317,160,133,418,339,606,0,43,96,514,125,68,8,4,340,228,190,285,425,341,0,38,129,108,0,24,64,426,452,34,36,54,35,197,41,0,41,86,255,110,1,89,93,14,49,0,7,117,1,54,145,1,586,179,0,127,358,0,1105,32,0,223,0,71,85,881,44,172,0,605,252,1325,331,240,378,1098,299,356,179,46,167,306,131,249,254,122,31,123,171,80,9,45,291,132,203,2803,748,6,171,102,41,65,163,254,0,321,75,70,89,425,161,192,0,40,66,42,86,8,4,68,174,131,619,201,74,170,103,108,556,8,13,38,61,154,291,272,110,1,153,1927,7,96,24,261,331,51,15,168,550,39,33,814,55,38,128,47,255,132,37,327,307,42,1,38,191,278,44,80,508,308,388,85,26,85,353,309,221,511,97,1,273,771,648,580,34,20,2,3,86,1,37,555,553,102,117,96,288,84,30,239,79,344,271,122,67,0,65,206,81,72,203,180,145,83,607,380,2824,0,713,2528,5856,246,187,53,100,170,120,19,97,38,246,173,780,250,286,1335,568,5788,0,0,0,0,0,0,0,0,204,304,63,74,213,337,207,293,887,568,2579,79,29,51,282,186,303,52,185,99,82,90,62,48,72,18,73,99,37,83,112,46,65,105,396,72,493,428,229,457,173,205,143,370,813,753,2578,0,2472,18,2,1,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,947,203,396,377,276,61,22,135,747,9324,11765,1,2,655,312,33,173,83,319,169,212,279,62,23,1,137,428,326,11236,4,5383,756,87,3493,252,16027,1456,1486,1220,121,588,1304,239,1166,104,770,1250,325,47,2,122,13,123,59,33,2,102,179,221,478,167,567,366,497,322,171,689,645,142,77,132,92,177,983,79,65,114,135,177,5108,272,611,2386,652,90,91,260,48,73,164,102,698,130,422,7,167,30,8,404,77,12,1312,155,47,105,240,90,102,134,448,198,323,1,131,103,145,598,254,5150,2079,3631,114,459,1785,641,1804,88,672,52,159,357,694,1,265,349,160,334,240,243,221,16,77,326,1,221,605,1506,712,456,1236,1095,781,65,209,147,31,227,3,123,146,171,240,54,259,1202,109,457,429,928,437,91,112,182,66,274,72,252,577,1045,1571,879,33,598,240,394,337,282,408,235,156,167,454,443,115,229,422,255,48,121,460,158,1558,1117,694,49,329,17,549,721,352,202,85,495,668,2244,160,256,305,386,140,261,126,252,342,178,54,313,264,801,336,229,1140,172,315,625,305,215,482,708,377,362,392,202,970,355,241,319,1465,250,226,407,105,337,164,275,274,194,210,24,230,1,303,381,438,164,255,159,75,414,206,136,23,52,66,8,92,257,102,88,273,354,599,689,48,3,87,344,237,94,57,104,115,51,14,173,90,162,124,60,241,34,276,1,273,103,103,388,90,180,141,315,227,222,172,256,395,299,342,258,135,140,230,273,195,109,347,485,390,86,160,93,162,458,200,168,231,575,0,116,195,482,211,345,28,156,154,534,498,178,313,491,441,2,214,322,138,128,91,117,441,254,81,0,457,655,548,253,23,76,102,336,1642,6,638,326,161,204,3,579,298,278,749,179,357,215,6,163,222,124,1,0,1966,136,320,162,419,48,130,1345,145,500,377,724,705,551,878,723,600,801,111,335,3,7,142,48,314,258,307,314,2267,81,103,544,212,103,397,236,664,2,111,216,1706,90,485,118,1,296,882,0,264,122,243,157,125,104,567,496,755,81,2,336,109,105,289,2221,315,714,77,103,409,119,222,237,182,1048,645,165,162,1229,316,127,622,174,3401,342,354,50,2,735,4626,0,110,244,3,158,341,297,885,98,1685,317,102,110,353,101,221,78,143,379,169,108,340,576,287,118,51,315,668,352,236,446,996,95,999,4162,12238,394,91,213,2,40,174,51,167,20,101,88,0,125,37,63,73,592,95,590,181,349,8818,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,159,67,170,141,87,109,117,53,100,20,223,221,253,922,61,567,442,639,7413,85,528,160,90,211,66,169,39,140,173,140,278,21,118,100,89,117,2,54,99,19,172,124,36,171,173,48,62,219,71,252,211,371,218,1033,428,271,1290,136,963,1742,8,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,5,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,2,0,4,2,3,1,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,1,0,1,0,1,3,0,0,0,1,1,1,2,2,4,3,1,2,1,1,4,3,22,1,2,2,2,4,2,13,25,1,2,7,1,3,44,2,9,3,3,3,4,7,14,13,68,86,261,68,2,2,4,3,2,1,1,4,3,1,0,0,0,1,5,2,0,0,0,0,18,27,4,1,0,0,0,0,0,0,0,0,56,13,1,0,0,0,0,0,0,0,0,0,94,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,1,0,0,0,0,0,1,1,0,0,1,1,2,1,8,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,0,0,0,1,0,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,2,1,1,1,2,1,3,1,1,1,1,1,4,1,1,1,1,1,2,1,2,1,4,2,1,1,1,1,1,1,2,1,1,2,1,1,2,1,2,2,1,4,1,1,2,1,1,3,1,1,3,3,2,2,3,1,3,1,1,1,5,3,2,4,1,4,9,3,1,1,1,1,2,3,1,1,1,8,1,4,1,3,1,1,1,4,4,0,3,4,1,2,1,1,2,3,2,2,2,6,0,5,2,3,2,6,0,3,6,6,10,0,0,4,1,14,7,0,3,3,13,1,2,0,4,10,7,7,1,0,0,8,1,0,0,0,17,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,3,5,2,1,1,1,3,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,1,1,3,2,1,3,1,1,1,1,1,1,3,1,1,3,1,3,5,1,2,4,3,1,3,4,7,14,2,1,1,1,1,3,6,11,1,1,2,1,2,1,1,13,30,2,1,4,4,1,1,52,3,3,4,2,14,5,64,1,6,9,2,33,23,22,33,205,65,34,1,2,14,6,6,8,52,24,3,2,2,1,3,3,1,5,2,1,0,9,25,2,1,0,0,11,6,15,1,0,0,0,6,20,3,1,0,0,0,0,0,15,11,5,0,0,0,0,0,0,0,0,0,97,45,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,3,5,1,5,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,2,2,1,1,1,1,1,2,1,1,2,2,1,1,1,1,1,1,1,1,1,2,1,1,2,1,2,1,1,1,1,2,1,0,0,1,0,0,0,1,0,1,1,0,1,0,0,0,0,0,1,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,1,0,0,0,2,0,1,1,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,1,0,1,2,1,0,0,0,0,1,1,0,0,1,0,1,0,2,0,1,1,1,1,1,1,1,1,1,1,2,1,2,5,1,12,2,5,1,6,1,1,1,2,25,1,1,2,3,1,10,4,5,0,0,1,0,0,0,0,0,0,0,0,3,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,4,0,0,0,0,1,1,0,0,1,0,1,1,1,2,0,0,0,0,0,1,0,1,1,1,3,2,2,1,0,0,0,0,0,0,0,0,0,0,0,2,2,1,1,0,0,0,4,0,0,0,1,1,1,1,0,0,0,0,1,0,1,0,1,0,4,0,0,3,1,0,0,0,1,0,1,0,1,1,0,0,2,0,0,1,0,2,1,0,0,0,2,0,1,0,1,0,1,0,1,0,1,0,2,0,1,1,0,0,2,0,1,0,1,1,1,1,1,1,5,1,2,2,1,3,1,2,1,1,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,0,0,0,1,0,1,0,1,0,2,0,12,5,24,10,4,12,5,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,2,1,1,0,0,0,0,1,2,1,0,0,0,0,1,0,1,0,1,1,0,0,1,2,2,0,1,0,2,1,0,0,1,2,1,1,0,0,0,0,0,2,1,1,1,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,125,4,422,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,3,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,2,0,1,1,8,1,3,3,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,1,2,1,1,0,0,0,0,0,1,1,1,1,4,0,0,0,0,0,1,1,1,0,0,0,1,3,4,1,1,1,1,5,1,8,3,2,13,1,1,1,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,2,1,1,0,0,0,0,1,0,1,0,1,0,2,0,1,1,2,1,1,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,0,0,1,2,0,1,0,1,0,1,1,0,0,1,0,1,2,1,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,1,1,1,2,1,1,2,1,3,1,1,0,0,0,0,0,0,0,0,0,0,1,0,2,0,2,0,1,1,2,1,1,13,5,2,1,4,3,2,22,14,17,20,11,3,2,1,8,4,16,3,3,9,7,7,4,4,2,3,2,2,1,3,3,5,2,2,5,2,4,2,0,1,2,0,0,0,0,4,9,0,0,0,0,3,0,0,0,0,5,2,1,1,1,0,0,0,0,0,0,0,0,0,0,5,1,1,0,0,0,0,0,0,0,0,0,0,0,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,2,1,0,0,3,0,0,1,1,0,0,1,1,0,2,0,1,0,1,0,1,1,1,1,2,1,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,0,0,1,2,1,0,1,1,3,2,3,4,2,2,1,1,1,1,1,5,9,7,1,1,3,2,1,1,1,17,2,11,2,3,3,55,56,22,8,3,5,2,8,24,20,18,2,1,77,9,2,4,6,6,3,1,8,2,24,7,59,4,9,3,1,77,16,11,7,23,1,4,4,24,26,19,101,6,2,2,24,6,7,7,8,9,14,53,8,35,5,5,2,2,1,3,5,4,3,3,3,14,41,3,9,1,1,6,6,13,3,5,2,3,15,3,4,3,3,12,3,5,8,17,6,54,1,8,8,7,1,1,2,2,2,1,1,4,3,0,4,9,14,2,0,0,18,3,26,1,1,0,0,22,94,2,4,1,0,0,0,0,0,0,0,56,1,4,1,0,0,0,0,0,0,69,33,14,16,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,4,7,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,12,5,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,1,0,1,0,5,2,0,0,0,0,0,38,0,0,0,0,2,0,0,1,0,1,0,1,0,1,3,1,0,0,0,0,0,2,0,1,1,0,0,1,0,7,1,0,0,0,0,0,0,1,2,1,1,0,0,1,0,1,1,1,1,1,1,2,1,0,0,0,0,0,0,6,0,0,1,1,0,0,1,1,1,1,0,0,0,0,1,0,1,0,1,0,1,0,1,0,2,1,1,0,0,0,1,1,1,1,1,1,1,3,2,1,1,3,10,4,1,40,17,2,1,1,1,2,3,1,1,1,1,268,28,1,1,2,1,1,4,2,1,2,15,7,5,4,4,2,1,1,1,1,592,11,4,3,4,3,4,10,5,7,13,1,3,1,2,13,17,6,53,76,64,18,13,1,5,2,3,1,48,22,5,13,30,9,3,6,22,44,49,30,12,10,21,5,17,7,17,12,22,7,86,185,220,59,46,17,2,1,1,1,1,7,6,7,6,10,7,3,14,16,2,2,5,10,4,12,4,5,2,10,14,14,6,5,7,3,2,1,10,5,2,2,6,6,4,2,2,7,23,11,3,2,6,16,20,20,4,9,15,8,27,11,7,32,3,11,1,10,10,8,13,5,5,1,26,28,6,6,18,20,18,1,5,18,7,4,31,3,2,36,5,5,10,7,10,12,21,7,5,2,31,26,3,1,1,21,8,35,26,6,2,1,2,8,9,8,21,6,4,6,9,22,11,6,0,8,6,1,1,9,7,0,7,10,3,4,3,1,0,0,13,8,8,2,1,1,6,9,6,7,1,0,0,79,64,13,4,4,2,2,1,3,1,0,0,0,0,0,0,225,62,30,20,8,3,3,3,1,0,0,0,0,0,0,0,0,0,0,295,138,53,38,10,1,11,2,1,2,7,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,185,72,17,20,13,9,8,3,5,4,2,4,3,4,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,140,115,27,13,9,3,1,1,2,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,56,23,7,10,1,4,18,1,7,1,0,0,0,0,0,0,0,0,0,0,0,0,0,97,48,12,6,12,1,1,2,3,2,0,0,0,0,0,0,0,0,0,61,17,11,12,9,3,1,3,8,1,10,0,0,0,0,0,0,0,0,0,0,0,0,38,13,9,7,3,1,1,2,19,1,13,2,1,0,0,0,0,0,0,0,0,0,18,21,4,13,3,4,5,0,0,0,0,0,0,0,0,0,9,14,1,2,3,1,5,2,6,1,0,0,0,0,0,11,10,1,4,2,5,5,2,0,0,0,0,0,0,0,0,0,0,0,15,1,4,3,1,3,6,1,0,0,0,0,0,0,0,3,2,5,12,0,0,0,2,1,0,0,0,0,1,5,0,0,17,1,0,0,4,2,8,0,0,0,0,4,37,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,0,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,0,0,0,1,1,0,1,2,1,0,0,1,0,1,4,0,0,0,0,0,1,0,1,0,1,2,1,1,1,0,0,0,0,0,0,1,0,1,0,1,2,0,0,0,1,5,7,23,3,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,0,1,0,1,0,1,0,1,4,1,0,0,0,0,0,0,2,1,0,1,0,1,0,1,0,1,3,1,0,0,0,0,0,1,1,5,2,2,1,0,0,0,0,0,0,0,0,0,26,0,0,0,0,0,0,1,0,262,136,4,1,1,2,2,260,5,6,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,2,0,5,0,0,0,2,0,1,0,1,1,1,2,1,1,3,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,4,6,1,2,0,0,1,1,1,0,0,1,1,1,0,0,1,0,1,0,1,0,1,0,2,0,1,2,1,1,0,0,1,0,1,0,1,0,2,0,1,0,1,1,9,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,4,0,0,0,2,0,1,0,3,1,0,1,0,1,0,1,1,1,4,2,1,1,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,5,1,1,0,0,0,0,0,0,0,0,2,0,1,2,1,0,1,6,29,10,5,7,3,2,5,6,6,5,6,2,64,40,3,1,1,2,3,5,2,5,2,4,12,4,2,4,8,12,8,1,3,3,3,2,17,1,2,4,8,13,1,1,3,2,7,4,4,2,3,0,3,2,4,5,3,0,2,3,0,1,1,1,0,0,0,0,5,3,0,0,2,1,0,0,0,1,0,0,29,5,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,1,0,1,0,1,0,1,1,3,1,1,1,1,1,1,1,6,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,4,0,1,0,1,0,1,1,1,0,0,0,1,0,1,1,1,0,0,0,1,1,1,3,0,0,0,0,0,0,5,1,1,1,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,1,2,1,18,4,2,0,1,3,6,1,0,2,2,0,0,0,0,1,0,1,1,1,1,0,0,0,4,0,1,1,1,0,0,0,0,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,1,1,1,1,1,1,2,1,1,2,1,2,1,1,2,1,3,2,1,1,1,1,2,3,1,3,2,1,1,1,1,1,1,2,1,2,2,2,1,2,1,1,1,2,1,1,1,1,3,2,2,1,3,1,1,1,1,1,4,1,1,1,2,1,3,2,3,1,1,2,3,5,1,2,1,1,2,1,6,2,3,1,1,8,1,3,2,3,1,1,2,1,1,1,3,1,2,1,1,1,1,2,1,0,0,0,3,1,1,0,1,5,1,0,2,1,0,1,4,1,0,0,1,1,0,3,2,0,1,1,0,0,0,0,0,1,0,0,2,2,0,0,1,0,0,1,0,0,0,1,0,0,0,2,0,0,2,3,0,0,2,0,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,1,1,1,1,1,1,1,1,1,4,1,1,5,8,1,1,1,0,0,0,0,0,0,0,0,0,0,0,4,0,2,0,1,0,1,0,2,1,0,0,1,0,139,150845,37572,5906,15238,4699,14669,471,1050,3618,600,14113,30,1457,2164,557,78,64,5431,891,688,686,1919,90,2785,2635,41,83,1284,282,55,3348,2232,6,39,389,2172,1345,5655,855,1495,569,282,8110,41620,17262,4071,15637,2756,11447,5457,6207,25666,2795,1009,463,140,1218,1374,6269,1227,1021,1578,1473,2168,1254,3205,741,850,1554,2727,2046,2259,42134,6214,257,748,1953,3502,8728,5017,6493,5428,2937,1409,1189,1778,1722,1204,3263,6139,1713,30,947,1882,2058,1023,2759,749,1954,1329,2084,2687,1592,1892,2164,2036,910,527,1660,8792,1052,3068,722,1333,6081,919,3506,373,5407,1572,3201,1291,2090,2982,3108,1101,1808,1251,1583,1114,7141,473,374,2085,1051,2693,1177,2443,602,2507,3508,957,1582,4607,2028,1470,3217,2164,2165,4808,5633,3461,1770,41,3323,6087,5174,1573,2796,1,19,1,3200,5,3747,215,0,2722,1709,1290,2059,1008,2089,1591,1891,1418,4258,556,958,79,464,62,1334,4,1581,2329,207,457,3097,2449,2156,2721,72,3630,4483,1163,397,59,2090,1161,2330,7857,1451,1410,365,2,3109,1486,28,1375,56,903,1330,549,518,42,1469,89,1378,1454,1333,3216,4364,2037,1678,3098,2843,2091,23,2165,42,948,1379,1148,79,84,1285,2196,2166,2119,1050,1708,649,1777,2036,1881,56,3199,2164,1572,1723,2448,5989,1,2778,2853,1284,1677,4766,3553,2057,1176,2523,2056,2169,2233,15189,1592,2155,1769,7,2195,2034,40,2720,5291,2553,1493,679,4789,587,2852,3203,2156,1419,2060,73,6209,6023,1391,824,23,851,16,2110,5117,2442,13,804,6710,915,42,7370,808,33850,12599,128,272982,1209,357833,486613,109195,44483,45622,14488,10982,7193,2515,566,105,170,661,4,14,321,325803,66931,57966,22998,10389,2417,195,162,259,274047,105452,40228,14233,445,930,294257,61406,16495,11074,1816,312,360,363809,112428,27317,106,7,428568,72503,2281,11,586951,6408,43,389,697794,1895,9934,189,235,38,50,102537,595723,2568,2053,8096,2150,422,221,142,6,51,102371,1656,418,92796,135093,448034,592,28383,4855,261,28,157,12,194,4,27945,66785,320,359,161177,3976,29496,655249,216,705,789,85,29,664,7,86,30098,321,75843,83592,352732,50871,87789,21074,7866,11329,12982,4027,266,451,624,242,562,1009,842,606,362,5547,2115,23,2116,12002,47508,9501,3544,117,2590,386,241,54993,6200,8954,11323,8883,1099,4307,190,131428,150774,57901,23059,32438,31885,2848,5489,2411,1501,4097,1407,134,4356,2482,667,6477,43,1721,107475,33549,14807,30030,9490,752,94,598,323,257,488,58,1173,135548,67202,85634,45586,6394,1407,11,5157,2064,2856,2978,3816,30,222,260,67059,109876,60245,5823,4140,1296,31,2839,1996,3361,419,21,42,2763,289,111679,65672,118,4737,5772,927,272098,34175,6156,14682,2782,4115,5090,3174,4282,592,8647,4731,3697,8140,1790,1440,5530,3655,1347,187455,9195,38311,15635,4207,16759,14375,35164,9970,9741,52590,5804,17140,7356,30075,4849,3702,123,39877,481,233,24,157,15,2194,57893,2756,26289,81,26474,6752,6189,46738,14724,4752,13526,4144,2218,170,23538,2146,1017,5780,4136,5449,4384,629,95,2661,111,54,20868,55,19493,8736,10822,23904,4883,8444,3059,5719,5784,13008,30,2783,2839,1500,3830,25,35,6457,2513,54,3479,123,35,2782,2653,736,2130,9496,627,3468,25526,3272,5531,1722,17381,1619,15235,70,9,5466,362,7436,3205,1885,100,2580,665,177,1914,6548,9448,8909,24438,4269,25133,9602,4377,18642,1970,11777,12815,562,7241,1562,3516,30,4422,16260,7866,586,5443,2557,2687,12601,47239,38336,3458,41166,3504,11324,6885,51852,808,160,4218,27,32376,3204,36948,22028,23746,39922,6893,2562,6856,87177,5536,660,17381,10229,9796,5634,6918,57508,7322,23423,156497,12047,11,12755,23854,76572,1000,340,2535,13164,41199,28,98041,795,361,313,482291,132210,21397,8395,13278,5622,14782,50,11666,524,16,69,43,418514,21909,5318,10843,34643,11732,416,2729,60,36,267963,16276,69595,135292,51754,1645,2143,7279,2188,17,34275,63785,129459,83627,1481,1979,446,15469,38913,12369,42,81526,85565,3688,2117,416307,6662,5773,117,82,398,199130,101697,365836,8688,1192,297,23,61936,143908,240,156,169565,3273,702671,2976,2928,1048,682295,13444,18952,964,211154,437081,36203,213834,10744,650101,6,348503,148,1892,541,1870,455,46,454,60,16,152,822,113,8,1459,37,273,1,10,220,426,478,138,7,200,129,153,154,131,49,16,90,42,89,191,2269,0,0,0,0,0,162272,29820,85770,32708,1490,1761,5446,3741,1188,2763,267,1782,414,127,1938,68,1014,1173,27,4976,1,519,0,217,1023,77,566,150,1115,300,247,369,2105,46544,84154,11950,711,1419,7669,1877,1839,700,1036,2130,950,923,203,147,48788,13076,456,2404,3163,629,917,3107,740,142,94,94,1461,2,355,1752,677,105,216,140674,3743,17036,7800,2246,3500,5446,1233,4580,2033,2959,7220,2137,506,2646,1488,1322,2190,6623,160,109,1234,1031,106,258,557,6328,19927,46500,16786,3809,7290,7994,4531,26813,2016,1777,7830,6497,1697,89,5702,1544,1647,30,1111,18927,2090,1888,793,3269,297,789,3,1300,316,444,0,5022,902,753,79,1112,457,737,2,373,18493,1728,2794,1700,190,370,0,135,23059,2419,17708,10680,14328,19025,3,2861,1532,589,1532,5,1366,618,388,169,3771,7003,5117,25181,2152,10332,1419,1824,1726,2025,2117,113,1240,0,1,296,2048,4179,2284,2153,1616,19,11351,6151,17335,1398,4736,1170,7,250,16,4163,21620,465,2322,4075,1446,1828,911,30825,682,464,4480,116,23450,37905,37685,2505,5078,12914,4644,1086,2049,3191,2732,8442,2955,4112,3656,39,1338,2439,44,2192,809,7,134,257,6865,6423,2437,1207,7259,1280,4729,734,945,23513,2105,16287,140,535,3991,8,1759,3462,266,2,69,25167,26473,7241,2417,6100,4461,3729,5503,5086,54,1282,13370,558,1219,876,291,1119,279,3512,449,399,310,500,82,95,206,613,2505,13745,3708,3252,1577,1640,5202,6685,1039,38,413,11135,4703,8992,17371,7554,23790,4456,1903,3241,1541,1318,821,52,2,93,243,10856,5008,5277,3629,1571,7740,2750,2268,274,4138,1085,139,3348,553,1571,8,88,5940,2844,9111,3172,5562,10246,2153,808,285,534,1416,1,6747,18050,6682,7475,5752,2584,1545,110,2029,0,581,1,12767,1084,7317,948,12200,588,191,34,19,78,54339,7105,7275,22854,181,1505,201,13,75,28,505,24375,10453,9130,32344,4374,3,1080,552,5,1646,48,7,1725,23,120,10280,12010,32812,587,1037,832,454,1,26,3184,22678,2319,3776,897,2461,2881,1465,1795,18,34,21552,359,138,947,3636,2836,450,30022,21584,24925,29112,1175,6059,31275,3865,6121,226,33466,4699,11663,3002,626,4956,1278,2154,1092,1085,570,335,3169,1154,1980,1036,1389,3803,2022,510,1795,1534,1571,1559,951,545,1506,51,600,3347,9874,1204,1826,12181,3403,1533,0,661,71,8260,10558,8303,995,4887,6,14114,11068,16239,458,2229,4126,1402,418,456,3,12851,22525,1646,1181,3485,619,9142,962,1202,557,1412,2,953,1174,1825,1079,2440,199,810,27462,3463,1133,1982,1175,7072,2055,5363,12956,2664,35851,16161,15056,2017,1280,741,970,3821,1359,645,5651,6274,114,1284,2090,1513,908,1963,670,1260,267,1140,3221,1875,585,1386,1118,2882,677,1375,2910,700,3198,2414,6882,9279,3402,1640,932,457,3372,154,43,4,2681,933,515,1405,1,533,22580,27235,10762,1386,1565,2497,1888,906,1702,3115,13354,3581,2267,7160,1280,1879,745,17,161,48,165,1538,192,1767,57,21337,5368,1040,701,3514,718,383,2915,2252,2197,3087,3384,5069,2255,1170,3484,2327,1081,1512,1376,1335,16018,4694,2839,4081,1958,1377,4469,8683,19698,6205,6375,12438,1522,349,1107,3062,1807,2043,1273,1762,1053,996,1090,313,2205,4463,4496,2907,3245,2752,2625,935,2609,5560,3091,2247,1402,1115,78,3307,627,3740,1387,2840,1566,1235,789,1616,931,4662,728,1039,1209,3199,1618,4395,567,1279,4794,448,1532,1234,2143,2322,5446,2191,4,509,558,717,1230,6638,1703,557,3202,1277,382,107,53,2143,10990,3859,4583,2206,209,983,1318,458,1406,202,7067,3571,2106,1091,21,132,1615,3335,1,2753,2142,34178,16495,20767,639,1378,1456,524,1318,2830,621,1381,2030,610,2995,1698,1598,1726,493,947,2322,1358,934,13601,1506,22843,2951,8857,1898,1414,1080,1485,2326,6374,2191,1368,1343,2119,27258,2690,2265,2909,3031,1016,2105,3957,678,1650,7410,6175,4189,2883,2155,615,120,3168,1505,6181,7850,6251,3588,6754,12541,2416,750,4691,1641,13297,2856,702,4905,3119,18499,1448,7009,3120,8217,1227,1342,805,2765,4045,4544,1646,1357,1837,2137,779,5308,3060,728,4312,4675,5144,637,1466,1597,1699,1463,3088,1035,2202,2264,418,930,3344,1384,1036,1388,499,3744,894,1574,1564,1038,3571,72,572,274,2017,4416,2053,322,76,518,12,51,2138,9078,1278,2210,2421,1317,5057,1899,2213,1562,1851,1736,1698,584,1947,1424,75,895,1763,1798,2132,1032,4578,2022,1332,432,61,383,778,2963,31,1015,1399,424,1573,749,1106,16,509,1315,2104,2263,6200,2788,1900,1054,2131,545,2137,1640,2103,2089,2665,2143,2326,8699,14355,4214,5733,3337,5223,3527,1634,2491,1703,1639,2138,2078,1563,1676,1694,1760,1310,2056,1902,777,271,1037,4122,5733,2498,3234,2743,1036,3187,1421,1805,1745,717,2823,5157,2042,1573,1544,1638,2270,17216,27516,14531,13927,1337,5192,5515,1980,3302,6558,1356,1031,315,19421,1037,3330,2931,8736,1898,71,10928,32861,16634,33966,2053,5679,10040,15767,10359,19179,506,3647,10235,29840,47872,4236,10894,8203,54493,11300,11267,9722,47213,58409,96340,0,32078,42930,140725,34,1,16,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,3,1,0,0,0,0,0,0,1,0,1,2,1,1,1,1,0,0,0,0,0,0,1,0,3,1,0,0,1,2,1,0,0,0,0,1,0,2,0,1,0,1,1,1,1,2,1,1,1,1,3,2,2,1,2,7,14,4,5,1,10,2,1,1,64,22,10,18,3,7,8,2,122,84,7,2,7,8,2,4,3,19,27,49,36,4,6,1,1,110,3,10,10,3,4,3,8,27,24,54,20,6,48,24,18,15,27,2,4,4,19,62,52,38,2,25,1,1,3,13,5,4,4,4,25,8,6,7,3,25,14,6,3,4,1,13,4,5,2,33,19,3,3,5,14,8,2,8,6,11,8,5,2,41,11,7,6,3,4,5,9,1,3,1,3,1,1,1,3,0,1,2,5,4,8,0,0,0,0,0,0,0,9,24,13,1,5,1,1,0,0,0,0,0,0,0,0,0,0,71,21,1,9,15,1,1,0,0,0,0,0,0,0,0,0,0,0,0,108,4,52,13,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,78,45,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,4,1,0,0,0,0,0,0,0,0,0,0,75,19,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,25,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,1,1,2,1,2,1,3,3,9,2,2,3,2,1,2,1,2,1,7,4,2,2,3,1,1,2,1,3,7,5,8,1,10,1,2,4,2,2,10,3,2,10,2,1,2,1,11,11,9,2,4,2,2,6,12,5,10,5,4,11,5,10,6,43,6,1,1,2,4,6,2,19,13,3,6,7,1,5,4,1,3,1,10,7,9,2,3,3,5,2,0,1,0,3,1,0,0,2,3,2,0,0,0,5,14,3,0,0,0,0,0,0,0,0,0,16,11,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,1,2,1,2,1,1,1,20,1,1,1,1,4,1,2,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,2,2,1,1,0,0,1,0,2,0,0,2,0,0,1,0,1,2,1,0,1,0,1,1,1,1,1,1,1,1,2,3,1,14,11,30,7,3,1,1,1,1,27,54,12,6,2,1,1,89,32,7,2,2,559,84,4,6,2,3,7,10,1,6,3,4,1,1230,11,4,4,5,11,1,4,2,2,13,17,11,43,40,8,14,4,2,1,1,1,166,21,26,22,30,21,21,12,29,21,9,33,27,57,53,30,40,9,5,19,38,39,58,119,271,94,378,264,202,51,15,13,5,4,2,1,2,1,1,1,1,7,9,3,12,13,26,26,30,34,30,18,3,1,3,5,6,16,8,13,8,12,9,5,9,10,6,13,5,9,10,13,12,6,6,13,5,6,14,17,14,9,10,10,13,16,8,15,13,14,19,20,7,13,7,16,18,11,16,15,35,28,12,26,9,6,25,7,18,18,13,2,13,10,11,13,8,6,9,9,27,29,5,31,5,25,11,0,8,9,14,28,3,1,20,34,12,35,17,1,28,26,84,72,37,9,6,227,137,84,36,13,2,1,259,151,60,14,3,1,0,0,0,527,372,58,23,11,14,1,2,3,1,0,741,183,30,24,15,5,1,2,2,0,3,1,1,0,0,0,0,0,0,0,801,128,93,17,7,6,10,3,1,4,1,2,1,2,1,3,2,1,2,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,349,204,94,34,7,15,7,5,4,6,4,2,3,1,3,1,2,1,2,4,5,2,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,303,83,16,29,12,10,0,1,3,1,2,2,2,1,2,7,1,0,0,0,0,0,0,0,0,319,66,52,12,8,3,5,4,1,0,2,6,2,2,26,3,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,122,18,32,3,8,8,12,6,2,3,2,1,1,1,2,2,1,33,3,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,30,44,16,16,4,2,3,4,1,2,2,3,15,9,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,40,30,27,4,5,3,6,8,1,1,45,13,2,0,0,0,0,0,0,40,19,9,6,11,1,1,4,1,2,1,7,1,38,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,24,27,6,6,9,6,27,14,3,2,5,2,3,9,16,1,4,0,0,0,0,0,0,0,0,0,14,2,6,3,1,7,1,2,4,1,3,29,4,2,0,0,0,8,2,1,9,2,5,1,2,6,5,3,6,25,5,1,1,0,0,0,0,0,0,2,1,3,4,3,3,5,12,1,5,7,7,11,7,0,0,0,0,2,1,1,1,4,2,2,1,0,0,0,0,0,1,2,1,5,1,1,0,0,0,0,1,1,12,2,0,0,0,1,34,1,1,0,0,0,0,0,1,4,1,0,3,3,2,1,0,0,1,0,0,2,4,13,1,0,0,0,0,6,9,0,0,0,0,2,0,2,1,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,2,7,1,0,0,0,0,11,2,0,0,2,5,12,1,0,0,0,0,0,0,0,0,0,0,0,0,2,1,12,2,0,0,0,0,0,1,5,0,0,0,0,0,0,0,1,0,0,0,2,2,0,0,14,13,0,0,0,123,31,26,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,18,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,7,0,0,0,0,0,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,1,1,1,1,14,5,1,2,1,1,1,5,2,3,1,1,1,25,4,1,1,1,2,1,4,1,1,1,4,3,3,5,4,2,2,2,3,1,1,13,3,1,3,3,5,3,10,2,3,4,1,1,8,24,9,5,7,3,1,2,1,4,1,5,6,4,5,5,1,3,2,2,3,1,1,3,2,1,1,1,2,2,3,4,2,5,2,3,1,1,1,2,1,1,3,2,2,2,5,1,1,1,1,1,2,6,3,2,4,2,1,5,3,1,1,3,2,1,2,2,2,2,2,1,1,4,7,3,2,13,3,2,2,12,2,8,9,2,1,3,4,4,3,12,3,1,5,2,1,1,2,3,3,2,2,2,2,2,1,2,13,2,4,2,2,4,3,4,2,9,2,5,1,3,2,1,2,1,2,2,2,0,2,4,0,6,1,2,0,0,0,13,4,1,1,2,1,1,0,0,0,0,23,1,3,1,4,1,0,0,0,0,20,2,3,2,1,1,1,2,1,1,0,0,0,6,12,8,4,7,1,2,0,0,0,0,0,0,0,0,0,2,3,5,2,1,2,2,0,0,0,0,8,1,5,1,3,1,0,0,0,0,0,5,2,2,2,1,1,1,0,3,3,1,1,1,1,0,0,0,0,5,8,1,1,0,0,0,0,3,1,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,3,1,2,1,0,0,0,0,0,0,2,0,0,0,1,3,4,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,0,0,0,0,0,0,0,0,0,6,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,3,1,1,1,1,2,1,1,2,1,1,2,2,1,2,2,1,1,1,1,4,4,1,2,3,1,5,1,1,3,2,2,1,2,11,2,2,4,2,3,2,5,1,2,1,3,2,2,4,1,2,3,4,5,1,9,5,7,3,1,19,3,1,3,6,2,3,1,7,1,1,5,2,3,6,2,2,3,12,2,2,3,3,6,48,1,3,2,1,2,2,0,0,0,0,2,0,0,0,3,1,2,0,1,2,1,7,0,0,0,2,2,2,2,0,0,0,0,1,4,1,3,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,2,4,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,0,1,0,1,0,2,4,2,1,0,1,0,1,0,1,1,4,1,0,0,0,0,1,3,1,0,0,0,0,2,2,1,1,6,2,0,0,0,0,0,0,0,1,1,1,1,4,6,1,3,11,42,10,2,16,22,1,2,115,15,6,10,5,198,1,40,18,9,189,37,40,1,37,47,66,3,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,3,1,0,0,0,0,1,0,1,0,1,0,2,0,1,1,0,0,1,0,1,0,1,1,1,2,21,1,3,3,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,13,4,32,4,13,3,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,0,1,1,0,0,1,0,1,1,0,0,1,0,1,0,2,0,2,1,1,1,2,1,0,0,0,0,0,0,0,0,4,8,4,0,0,0,1,1,0,0,1,0,1,0,1,0,1,1,2,1,1,1,1,2,3,3,1,1,2,12,1,5,1,4,1,4,4,12,1,2,3,5,1,2,8,1,2,2,6,2,4,40,2,2,1,3,1,1,0,1,0,0,3,0,0,0,1,0,0,0,0,0,0,1,1,1,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,0,2,1,0,0,2,0,1,0,1,0,1,1,1,1,2,0,0,1,0,0,1,1,1,1,1,0,0,0,1,1,1,0,0,0,0,0,1,1,1,1,1,1,2,0,1,1,0,0,0,0,0,1,0,1,0,0,0,0,0,2,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,2,1,3,6,1,2,1,1,2,6,3,1,3,1,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,4,0,4,1,0,0,0,0,0,1,1,1,1,1,1,1,2,1,1,2,1,2,1,1,1,1,2,1,2,4,37,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,0,1,1,1,1,1,1,1,1,1,13,3,5,8,4,2,2,5,2,1,1,0,1,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,5,5,9,3,13,2,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,0,4,0,1,0,1,1,0,0,2,1,0,0,0,2,0,1,0,1,0,1,0,1,0,2,1,18,5,25,3,7,1,1,2,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,654,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,3,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,4,0,1,0,1,0,1,1,1,1,6,19,7,2,42,28,2,1,4,3,3,2,3,2,261,7,2,4,3,2,2,8,3,2,2,2,3,31,48,17,7,9,3,8,1,1,1,2,1,36,13,3,6,4,3,6,2,3,11,4,23,17,160,268,133,27,20,5,6,3,2,3,8,2,35,6,4,5,1,5,9,2,4,3,2,4,2,7,5,5,5,4,1,3,2,3,3,8,4,2,1,3,2,2,1,3,8,1,3,1,3,11,4,1,2,1,5,5,4,3,0,0,0,118,15,10,8,4,1,1,0,0,0,0,0,0,0,143,65,14,17,10,5,3,1,3,1,1,1,1,1,1,0,0,0,0,0,0,0,0,63,38,10,12,9,2,5,2,2,2,1,0,0,0,0,0,0,0,0,0,0,0,35,12,12,5,5,4,4,2,3,1,1,1,2,1,0,0,0,0,0,0,19,12,10,6,2,3,1,1,1,0,0,0,0,0,0,0,19,6,1,1,2,1,1,1,0,0,0,0,0,0,0,0,17,2,3,3,1,1,1,0,0,0,10,6,5,1,1,1,1,0,0,0,0,0,4,1,1,1,1,1,1,0,0,0,0,5,2,0,0,0,0,0,3,2,3,1,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,1,0,0,1,1,1,1,23,22,1,1,1,247,5,3,2,1,5,4,3,2,2,1,1,770,351,37,2,15,8,9,64,101,54,38,16,6,14,3,6,4,582,87,11,3,2,12,17,8,55,123,35,33,11,11,8,2,1,1,306,34,10,2,14,23,30,4,45,151,328,141,87,41,19,12,6,2,2,3,4,1,1,1,1,25,7,10,58,205,99,52,26,6,7,1,1,1,1,2,1,1,10,12,16,7,4,3,4,11,1,14,1,9,23,1,22,15,14,5,10,25,5,4,3,0,3,21,5,27,4,3,0,184,95,39,8,6,4,2,1,1,0,0,436,210,48,28,53,1,2,1,2,1,1,0,0,0,0,0,0,528,42,76,36,16,4,4,2,1,1,1,1,0,0,0,317,181,143,37,19,15,2,12,2,2,1,0,0,0,0,0,176,177,11,16,2,3,1,1,4,1,0,0,0,0,244,62,16,10,15,11,3,1,2,1,0,0,0,0,0,0,0,0,246,83,42,8,20,3,7,2,3,1,1,1,2,0,0,0,0,0,0,0,127,64,15,23,6,2,2,2,1,1,1,1,1,1,0,0,0,0,0,89,20,34,5,4,2,1,1,1,0,0,0,0,0,0,0,0,27,50,27,6,9,1,2,2,1,1,1,1,1,0,0,0,0,0,0,32,8,6,3,1,1,1,0,0,0,0,0,23,34,3,16,2,4,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,9,6,9,3,1,3,2,1,0,0,0,0,0,0,0,0,0,6,12,1,6,3,2,1,0,0,0,0,0,0,4,4,2,1,2,1,0,0,0,0,2,6,1,1,1,2,1,2,1,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,2,2,1,1,0,0,0,0,0,1,0,0,0,4,0,0,0,2,1,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,1,2,1,2,1,0,0,0,0,0,0,0,0,0,1,0,3,4,5,4,3,0,1,1,1,1,1,6,1,3,1,2,1,0,0,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,1,1,2,1,2,1,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,1,0,1,18,5,117,38,1,0,6,1,0,0,0,3,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,10,17,1,443,7,0,0,13,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,1,0,1,0,1,0,1,1,2,1,0,0,4,1,2,1,1,0,1,6,3,0,1,0,0,0,0,1,1,0,0,1,1,0,0,18,1,1,17,16,0,0,0,1,0,1,1,1,1,1,17,2,2,1,1,1,1,0,0,1,0,0,0,0,0,0,0,1,0,1,0,2,12,2,1,4,0,0,2,0,0,1,0,2,0,1,1,1,0,2,1,2,1,1,0,1,0,0,3,0,24,1,23,22,0,1,0],\"yaxis\":\"y\",\"type\":\"scattergl\"}],                        {\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"midpoint\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"depth\"}},\"legend\":{\"tracegroupgap\":0},\"title\":{\"text\":\"2R\"},\"height\":300,\"width\":750,\"shapes\":[{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":3492073,\"x1\":3492073,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":8368730,\"x1\":8368730,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":17854286,\"x1\":17854286,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28492878,\"x1\":28492878,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28494246,\"x1\":28494246,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28497562,\"x1\":28497562,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28497966,\"x1\":28497966,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28498191,\"x1\":28498191,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28499660,\"x1\":28499660,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28500642,\"x1\":28500642,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28501398,\"x1\":28501398,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28502735,\"x1\":28502735,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28502849,\"x1\":28502849,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":48714600,\"x1\":48714600,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":48714550,\"x1\":48714550,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":49438585,\"x1\":49438585,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"}]},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('c51c61b8-8b30-4ff6-b32f-2edf91c238a1');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}, {"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"hovertemplate": "midpoint=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "", "marker": {"color": "lightsalmon", "symbol": "circle"}, "mode": "markers", "name": "", "showlegend": false, "type": "scattergl", "x": [32518, 32549, 32549, 32570, 32572, 32580, 32580, 32584, 32639, 49475, 64432, 64477, 64478, 64478, 64482, 64483, 96573, 183555, 190392, 190491, 20981717, 65068, 65098, 65099, 65100, 65100, 65101, 65102, 65102, 65103, 65104, 65105, 65107, 65108, 65109, 65109, 65114, 65120, 65123, 65125, 65128, 65129, 65129, 65130, 65100, 65101, 65101, 65102, 65103, 65105, 65106, 65106, 65109, 65120, 65121, 65121, 65122, 65125, 65126, 65129, 65129, 65130, 65130, 65102, 65104, 65113, 65130, 65130, 65131, 65102, 65130, 65130, 65131, 65131, 65104, 65107, 65131, 65131, 65132, 65132, 65131, 65132, 65133, 65109, 65132, 65133, 65133, 65134, 65133, 65135, 65115, 65135, 65135, 65136, 65136, 65136, 65116, 65138, 65139, 65139, 65140, 65148, 97036, 97037, 96992, 65142, 65145, 65150, 65151, 65151, 65151, 65150, 65152, 65153, 65154, 65155, 65156, 65156, 65158, 65159, 65159, 65159, 65160, 65160, 65161, 65162, 65162, 65163, 65163, 65164, 65164, 65165, 65165, 65166, 65166, 65167, 65168, 65170, 65170, 65171, 65172, 65173, 65173, 65174, 65175, 65176, 65176, 65177, 65178, 65178, 65179, 65179, 65180, 65181, 65181, 65182, 65182, 65183, 65183, 65184, 65184, 65185, 65185, 65186, 65186, 65187, 65187, 65188, 65162, 65163, 65163, 65164, 65165, 65166, 65166, 65167, 65168, 65171, 65175, 65177, 65178, 65179, 65180, 65181, 65182, 65183, 65184, 65185, 65185, 65186, 65186, 65187, 65187, 65188, 65188, 65163, 65164, 65165, 65179, 65181, 65184, 65185, 65187, 65187, 65164, 65165, 65165, 65166, 65166, 65167, 65167, 65168, 65170, 65171, 65172, 65174, 65174, 65176, 65178, 65178, 65180, 65181, 65182, 65182, 65183, 65184, 65186, 65186, 65187, 65187, 65188, 65188, 65189, 65166, 65167, 65170, 65172, 65174, 65178, 65180, 65181, 65182, 65186, 65187, 65188, 65188, 65190, 65169, 65181, 65183, 65184, 65184, 65187, 65188, 65189, 65189, 65190, 65168, 65170, 65183, 65188, 65169, 65169, 65174, 65176, 65181, 65182, 65182, 65185, 65185, 65186, 65189, 65189, 65190, 65191, 65179, 65181, 65182, 65184, 65185, 65186, 65186, 65190, 65174, 65175, 65177, 65183, 65184, 65185, 65190, 65191, 65192, 65172, 65176, 65177, 65179, 65183, 65186, 65187, 65189, 65190, 65190, 65191, 65178, 65191, 65191, 65182, 65191, 65174, 65193, 65176, 65179, 65194, 65194, 65190, 65196, 65189, 65194, 65184, 65187, 65193, 65195, 65195, 65196, 65183, 65191, 65192, 65194, 65197, 65190, 65193, 65196, 65196, 65197, 65199, 65186, 65187, 65188, 65190, 65192, 65193, 65194, 65198, 65198, 65195, 65192, 65194, 65200, 65201, 65192, 65195, 65195, 65196, 65198, 65198, 65199, 65199, 65200, 65200, 65201, 65195, 65200, 65201, 65196, 65197, 65202, 97028, 97074, 65194, 65196, 65198, 65201, 65202, 65203, 97074, 65201, 65196, 65199, 65199, 65200, 65201, 65204, 97029, 65196, 65198, 65199, 65199, 65200, 65201, 65202, 65202, 65203, 65203, 65204, 65205, 97030, 97072, 97076, 65197, 65199, 65202, 65203, 65204, 97030, 65202, 65203, 65204, 65204, 65205, 65206, 65206, 97077, 65200, 65201, 65204, 65201, 65201, 65202, 65203, 65204, 65204, 65205, 65205, 65206, 65207, 65207, 97078, 65205, 65207, 65202, 65203, 65203, 65204, 65205, 65205, 65206, 65206, 65207, 97078, 65203, 65204, 65204, 65205, 65205, 65206, 65206, 65207, 65207, 65208, 65208, 65209, 97033, 97079, 65205, 65205, 65206, 65206, 65207, 65207, 65208, 65208, 65209, 65209, 66653, 97034, 65205, 65206, 65207, 65207, 65208, 65210, 97034, 65207, 65207, 65208, 65208, 65207, 65208, 65208, 65209, 65210, 65210, 65211, 65208, 65209, 65209, 65210, 65210, 65211, 65211, 97036, 97082, 65209, 65210, 65210, 65211, 65211, 65212, 97036, 65210, 65211, 65211, 65212, 65212, 65244, 97037, 65211, 65212, 65212, 65213, 97037, 97083, 65212, 65213, 65213, 65245, 97038, 97084, 97091, 65213, 65214, 97038, 97084, 65214, 65256, 65215, 65218, 65220, 65225, 65226, 65227, 65227, 65228, 65228, 65229, 65230, 65230, 65231, 65232, 65232, 65233, 65234, 65235, 65236, 65238, 65239, 65239, 65240, 65241, 65244, 65247, 65250, 65251, 65251, 65253, 65254, 65255, 65255, 65256, 65256, 65257, 97039, 97085, 97090, 65228, 65229, 65229, 65230, 65230, 65231, 65232, 65234, 65237, 65257, 65257, 65258, 65258, 65261, 65236, 65239, 65238, 65238, 65239, 65240, 65240, 65266, 65239, 65240, 65241, 65241, 65242, 65244, 65246, 65257, 65265, 65267, 65267, 65268, 65269, 65240, 65241, 65241, 65242, 65243, 65243, 65244, 65245, 65246, 65251, 65264, 65266, 65267, 65267, 65268, 65241, 65264, 65267, 65242, 65243, 65243, 65244, 65244, 65245, 65246, 65247, 65248, 65249, 65251, 65252, 65252, 65254, 65255, 65257, 65258, 65258, 65261, 65262, 65264, 65265, 65265, 65266, 65266, 65267, 65267, 65268, 65269, 65270, 65270, 65246, 65246, 65248, 65258, 65269, 65244, 65245, 65254, 65263, 65269, 65270, 65245, 65248, 65249, 65262, 65266, 65270, 65270, 65246, 65247, 65248, 65249, 65254, 65266, 65267, 65268, 65269, 65270, 65271, 65249, 65267, 65271, 65271, 65272, 65268, 65249, 65251, 65261, 65267, 65268, 65269, 65269, 65270, 65270, 65271, 65272, 65251, 65252, 65253, 65256, 65259, 65264, 65269, 65270, 65272, 65272, 65273, 65274, 65273, 65253, 65272, 65255, 65257, 65257, 65263, 65264, 65267, 65269, 65270, 65270, 65272, 65273, 65274, 65274, 65272, 65271, 65273, 65274, 65275, 65260, 65265, 65274, 65276, 65263, 65261, 65262, 65265, 65268, 65272, 65274, 65275, 65276, 65277, 65278, 65278, 65279, 65280, 65275, 65277, 65279, 65280, 65280, 65281, 65276, 65280, 65281, 65281, 65282, 65278, 65282, 65284, 65284, 65275, 65282, 65285, 65277, 65285, 65286, 65283, 65286, 65278, 65287, 65289, 65288, 65289, 65284, 65285, 65286, 65286, 65290, 65290, 65290, 65291, 65289, 65291, 65291, 65292, 65289, 65289, 65290, 65290, 65291, 65291, 65292, 65293, 65290, 65292, 65292, 65291, 65292, 65292, 65293, 65291, 65292, 65292, 65293, 65293, 65294, 65294, 65292, 65293, 65294, 65293, 65294, 65294, 65294, 65295, 65296, 65295, 65296, 65297, 65296, 65297, 65297, 97080, 65297, 65298, 65298, 97081, 65299, 65300, 65331, 97081, 97081, 97104, 97126, 97127, 97127, 97131, 129222, 197666, 65300, 97082, 97128, 97082, 97113, 68143, 98570, 98962, 113964, 128863, 128864, 128865, 128865, 128866, 128866, 128867, 128868, 128869, 128871, 128872, 128873, 128875, 128879, 128883, 128887, 128889, 128894, 128899, 128903, 128904, 128907, 128908, 128909, 128909, 128910, 128939, 128865, 128866, 128866, 128867, 128867, 128872, 128873, 128877, 128883, 128887, 128890, 128894, 128896, 128897, 128900, 128901, 128907, 128909, 128909, 128910, 128910, 128867, 128868, 128909, 128910, 128867, 128873, 128874, 128911, 128868, 128870, 128871, 128873, 128887, 128891, 128891, 128901, 128903, 128910, 128911, 128911, 128912, 128870, 128870, 128871, 128874, 128875, 128881, 128888, 128891, 128897, 128902, 128903, 128910, 128911, 128912, 128912, 128870, 128912, 128912, 128913, 128913, 128914, 128913, 128914, 128880, 128886, 128896, 128916, 128917, 128918, 128917, 128918, 128918, 128921, 128918, 128914, 128922, 128924, 128924, 128928, 128928, 128921, 128922, 128932, 128933, 128934, 128934, 128935, 128939, 128939, 128940, 128941, 128942, 128940, 128943, 128944, 128945, 128944, 128946, 128947, 128948, 128950, 128950, 128951, 128952, 128952, 128952, 128953, 128952, 128953, 128954, 128954, 128954, 128955, 128955, 128959, 128962, 128956, 128957, 128957, 128958, 128958, 128959, 128959, 128960, 128960, 128961, 128961, 128962, 128962, 128963, 128964, 128965, 128967, 128968, 128985, 128985, 128957, 128958, 128958, 128959, 128959, 128960, 128960, 128961, 128961, 128963, 128985, 128958, 128959, 128960, 128960, 128961, 128963, 128964, 128959, 128960, 128960, 128961, 128961, 128962, 128964, 128964, 128960, 128961, 128961, 128962, 128962, 128963, 128961, 128962, 128962, 128963, 128963, 128965, 128962, 128963, 128963, 128964, 128965, 128966, 128963, 128964, 128964, 128965, 128966, 128966, 128967, 128971, 128972, 128964, 128965, 128965, 128966, 128966, 128967, 128968, 128982, 128985, 128989, 128965, 128966, 128966, 128967, 128967, 128968, 128969, 128969, 128972, 128972, 128979, 128987, 128990, 128966, 128967, 128967, 128968, 128969, 128969, 128970, 128972, 128972, 128973, 128980, 128982, 128984, 128986, 128987, 128990, 128967, 128968, 128968, 128971, 128968, 128969, 128973, 128984, 128987, 128969, 128970, 128970, 128971, 128971, 128972, 128972, 128973, 128973, 128974, 128975, 128976, 128977, 128980, 128981, 128981, 128982, 128983, 128984, 128984, 128985, 128986, 128988, 128989, 128989, 128990, 128990, 128992, 128970, 128971, 128971, 128972, 128972, 128973, 128973, 128974, 128974, 128975, 128975, 128976, 128977, 128978, 128979, 128980, 128981, 128981, 128982, 128982, 128984, 128985, 128986, 128986, 128987, 128987, 128988, 128988, 128989, 128990, 128992, 128971, 128972, 128972, 128974, 128974, 128975, 128976, 128978, 128982, 128985, 128985, 128993, 128972, 128973, 128974, 128974, 128975, 128975, 128976, 128976, 128977, 128979, 128983, 128991, 128993, 128973, 128974, 128974, 128975, 128975, 128976, 128976, 128977, 128977, 128982, 128983, 128983, 128985, 128986, 128986, 128987, 128989, 128990, 128991, 128994, 128974, 128975, 128975, 128976, 128976, 128977, 128977, 128978, 128978, 128981, 128981, 128983, 128984, 128984, 128985, 128986, 128987, 128988, 128989, 128991, 128993, 128975, 128976, 128976, 128977, 128977, 128978, 128986, 128987, 128987, 128989, 128991, 128992, 128993, 128976, 128977, 128978, 128978, 128979, 128983, 128983, 128984, 128984, 128985, 128986, 128987, 128988, 128989, 128992, 128995, 128977, 128978, 128978, 128979, 128979, 128985, 128988, 128990, 128991, 128978, 128979, 128979, 128980, 128981, 128983, 128984, 128985, 128986, 128986, 128987, 128988, 128988, 128989, 128990, 128990, 128991, 128992, 128992, 128993, 128993, 128996, 128979, 128980, 128980, 128982, 128982, 128984, 128985, 128986, 128988, 128989, 128980, 128981, 128981, 128983, 128984, 128985, 128986, 128986, 128987, 128987, 128988, 128989, 128990, 128991, 128991, 128992, 128992, 128993, 128993, 128994, 128997, 128981, 128982, 128984, 128985, 128986, 128987, 128987, 128989, 128990, 128990, 128991, 128993, 128993, 128994, 128996, 128997, 128998, 128982, 128983, 128984, 128985, 128986, 128987, 128987, 128988, 128988, 128989, 128990, 128990, 128992, 128992, 128994, 128995, 128997, 128998, 128984, 128988, 128990, 128991, 128993, 128990, 128991, 128985, 128992, 128994, 128989, 128990, 128991, 128992, 128993, 128997, 128990, 128993, 128988, 128989, 128990, 128991, 128992, 128993, 128990, 128994, 128995, 128994, 128991, 128992, 128993, 128995, 128995, 128997, 128993, 128995, 128996, 128997, 129003, 128993, 128994, 128996, 128996, 128997, 129004, 128995, 128995, 128996, 128996, 128997, 128997, 128998, 128998, 128999, 129001, 129001, 129004, 128995, 128997, 128997, 128998, 129000, 129004, 128996, 128997, 128997, 128998, 128999, 129000, 129001, 128998, 128998, 129004, 129006, 128998, 128999, 129004, 128999, 129000, 129000, 129001, 129001, 129002, 129002, 129003, 129003, 129004, 129004, 129005, 129005, 129006, 129006, 129007, 161072, 129000, 129001, 129001, 129002, 129002, 129003, 129003, 129004, 129004, 129005, 129005, 129006, 129007, 129007, 129016, 129001, 129002, 129002, 129003, 129005, 129008, 129002, 129003, 129003, 129004, 129004, 129005, 129005, 129006, 129006, 129007, 129007, 129008, 129008, 129003, 129004, 129004, 129005, 129005, 129006, 129007, 129007, 129008, 129009, 129004, 129005, 129005, 129006, 129007, 129007, 129008, 129009, 129009, 129005, 129006, 129007, 129007, 129008, 129008, 129009, 129010, 129006, 129007, 129007, 129008, 129008, 129009, 129010, 129010, 129007, 129008, 129008, 129009, 129009, 129010, 129010, 129011, 129008, 129009, 129011, 129011, 129009, 129010, 129010, 129011, 129011, 129012, 129020, 129010, 129011, 129011, 129012, 129012, 129011, 129012, 129012, 129013, 129012, 129013, 129013, 129013, 129014, 129014, 161080, 129015, 129016, 129016, 129017, 129018, 129018, 129019, 129020, 129020, 129021, 129022, 129022, 129023, 129026, 129027, 129028, 129028, 129029, 129031, 129032, 129033, 129037, 129037, 129044, 129045, 129051, 129054, 129056, 129057, 129058, 129059, 129060, 129060, 129061, 132614, 161080, 161113, 229524, 229524, 248082, 271219, 129016, 129017, 129017, 129018, 129018, 129019, 129019, 129020, 129020, 129021, 129021, 129022, 129022, 129023, 129023, 129024, 129024, 129025, 129026, 129027, 129027, 129028, 129028, 129029, 129029, 129031, 129031, 129032, 129033, 129035, 129037, 129038, 129038, 129039, 129039, 129044, 129045, 129046, 129047, 129048, 129048, 129049, 129049, 129051, 129052, 129052, 129053, 129054, 129056, 129058, 129059, 129059, 129060, 129060, 129061, 129061, 161081, 129017, 129018, 129018, 129019, 129019, 129021, 129021, 129022, 129022, 129023, 129023, 129024, 129027, 129028, 129033, 129041, 129044, 129046, 129047, 129059, 129060, 129061, 129062, 161114, 129018, 129019, 129020, 129021, 129021, 129022, 129022, 129023, 129024, 129024, 129025, 129026, 129028, 129028, 129043, 129047, 129054, 129059, 129061, 129062, 129062, 161082, 129020, 129022, 129023, 129024, 129025, 129029, 129060, 129020, 129022, 129023, 129024, 129030, 129030, 129033, 129050, 129058, 129061, 129061, 129062, 129063, 129021, 129022, 129022, 129023, 129023, 129024, 129024, 129025, 129025, 129026, 129027, 129028, 129029, 129030, 129030, 129032, 129033, 129034, 129037, 129048, 129049, 129051, 129053, 129055, 129061, 129061, 129062, 129063, 129063, 129064, 161083, 129024, 129025, 129026, 129031, 129032, 129034, 129056, 129061, 129062, 129063, 129064, 161084, 129025, 129026, 129028, 129050, 129065, 129025, 129026, 129026, 129033, 161085, 129025, 129026, 129027, 129028, 129028, 129030, 129031, 129033, 129066, 161085, 129026, 129027, 129028, 129028, 129029, 129029, 129031, 129032, 129033, 129033, 129034, 129036, 129039, 129066, 161086, 229529, 129028, 129028, 129029, 129030, 129031, 129032, 129033, 129034, 129035, 129037, 129038, 129039, 129049, 129051, 129052, 129054, 129064, 129065, 129065, 129066, 129066, 129067, 161117, 129029, 129029, 129051, 129054, 129060, 129065, 129066, 129066, 129067, 129029, 129030, 129033, 129034, 129035, 129035, 129037, 129038, 129038, 129039, 129040, 129044, 129045, 129046, 129047, 129051, 129054, 129054, 129055, 129057, 129059, 129061, 129064, 129065, 129067, 129068, 161087, 129030, 129031, 129033, 129034, 129035, 129036, 129039, 129040, 129050, 129065, 129067, 129068, 129031, 129032, 129032, 129033, 129034, 129035, 129036, 129036, 129037, 129037, 129038, 129039, 129046, 129049, 129052, 129055, 129056, 129060, 129064, 129065, 129066, 129067, 129068, 129068, 129069, 161088, 161121, 129032, 129035, 129035, 129037, 129038, 129039, 129046, 129056, 129056, 129060, 129068, 129069, 248071, 129035, 129035, 129036, 129036, 129037, 129038, 129039, 129041, 129054, 129055, 129062, 129070, 129036, 129036, 129037, 129040, 129070, 129071, 129037, 129037, 129039, 129071, 129072, 129038, 129039, 129039, 129040, 129040, 129041, 129041, 129042, 129042, 129043, 129043, 129044, 129044, 129049, 129056, 129069, 129069, 129070, 129070, 129071, 129072, 161092, 129039, 129040, 129040, 129042, 129044, 129044, 129045, 129053, 129070, 129070, 129072, 129072, 129073, 129041, 129041, 129042, 129042, 129043, 129044, 129044, 129045, 129049, 129058, 129065, 129070, 129071, 129072, 129072, 129073, 161093, 129041, 129042, 129043, 129046, 129048, 129061, 129071, 129072, 129074, 129042, 129043, 129043, 129044, 129044, 129045, 129045, 129046, 129047, 129051, 129057, 129058, 129061, 129061, 129069, 129072, 129072, 129073, 129073, 129074, 129074, 161094, 161127, 248076, 129043, 129044, 129046, 129049, 129055, 129057, 129071, 129072, 129075, 129045, 129045, 129046, 129047, 129068, 129073, 129045, 129046, 129047, 129063, 129073, 129074, 129046, 129047, 129047, 129048, 129059, 129061, 129063, 129067, 129072, 129073, 129074, 129075, 129076, 161096, 129047, 129049, 129063, 129074, 129076, 129048, 129049, 129050, 129052, 129053, 129056, 129060, 129063, 129064, 129066, 129069, 129070, 129071, 129073, 129075, 129076, 129077, 129077, 129049, 129051, 129054, 129060, 129065, 129075, 129077, 129078, 161097, 129050, 129051, 129052, 129055, 129055, 129060, 129062, 129063, 129065, 129065, 129071, 129073, 129075, 129075, 129076, 129076, 129077, 129077, 129078, 129052, 129057, 129075, 129078, 161098, 129062, 129063, 129074, 129077, 129079, 129127, 129077, 129079, 129078, 129078, 129079, 129080, 129068, 129078, 129081, 129069, 129070, 129080, 129081, 129081, 129082, 129083, 161135, 129069, 129082, 129083, 161134, 129071, 129083, 129084, 129084, 129070, 129072, 129071, 129072, 129070, 129086, 129074, 129084, 129086, 129074, 129076, 129078, 129072, 129074, 129076, 129080, 129081, 129082, 129082, 129085, 129087, 129088, 129077, 129075, 129076, 129077, 129087, 129087, 129088, 129090, 129090, 129076, 129076, 129077, 129077, 129078, 129090, 129091, 129089, 129077, 129078, 129079, 129083, 129085, 129086, 129090, 129090, 129091, 129092, 129079, 129080, 129089, 129091, 129092, 129080, 129088, 129089, 129090, 129093, 129080, 129091, 129092, 129092, 129081, 129085, 129087, 129087, 129089, 129090, 129090, 129091, 129092, 129092, 129093, 129094, 129090, 129091, 129091, 129092, 129094, 129094, 129095, 129089, 129091, 129094, 129095, 129095, 129097, 129088, 129094, 129095, 129095, 129097, 129097, 129098, 129091, 129092, 129095, 129095, 129096, 129097, 129097, 129098, 129098, 129098, 129099, 129096, 129097, 129097, 129099, 129100, 129095, 129098, 129099, 129099, 129100, 129100, 129101, 129099, 129100, 129101, 129101, 129102, 129099, 129101, 129102, 129100, 129102, 129100, 129101, 129101, 129102, 129103, 129103, 129101, 129102, 129102, 129103, 129104, 248106, 129102, 129103, 129103, 129104, 129104, 129103, 129104, 129104, 129105, 129104, 129105, 129105, 129105, 129106, 129106, 129107, 129108, 129149, 129155, 132571, 132583, 132589, 132591, 132595, 132660, 135404, 135802, 161092, 161126, 161126, 161157, 161159, 161176, 161222, 229569, 229570, 248109, 248128, 254946, 21046271, 161127, 161093, 161127, 132618, 132643, 132643, 136075, 136065, 136075, 136093, 136095, 136083, 136110, 136159, 164615, 164618, 164630, 164641, 136224, 164690, 164723, 251673, 141724, 167446, 142515, 167839, 193111, 193145, 193146, 193147, 193147, 193148, 193149, 193149, 193150, 193156, 193175, 193176, 193176, 193177, 193177, 193178, 193178, 193179, 193147, 193149, 193149, 193176, 193177, 193178, 193179, 193179, 193149, 193178, 193179, 193179, 193180, 193150, 193180, 193151, 193152, 193163, 193169, 193171, 193178, 193179, 193180, 193181, 193181, 193181, 193181, 193182, 193153, 193179, 193180, 193182, 193182, 193182, 193166, 193186, 193189, 193191, 193252, 261599, 193189, 193193, 193200, 193201, 193205, 193205, 193206, 193209, 193209, 193209, 193213, 193217, 193223, 193226, 193252, 193252, 193209, 193209, 193210, 193210, 193210, 193211, 193211, 193212, 193213, 193213, 193214, 193214, 193215, 193215, 193216, 193217, 193218, 193219, 193220, 193222, 193223, 193223, 193225, 193225, 193226, 193227, 193228, 193228, 193229, 193229, 193230, 193230, 193231, 193231, 193232, 193232, 193233, 193233, 193234, 193234, 193235, 193236, 193237, 193237, 193238, 193239, 193242, 193244, 193244, 193245, 193245, 193246, 193251, 193252, 193252, 193213, 193214, 193214, 193216, 193217, 193220, 193223, 193227, 193229, 193229, 193231, 193235, 193239, 193239, 193244, 193246, 193253, 193215, 193228, 193229, 193239, 193240, 193247, 193230, 193245, 193217, 193218, 193225, 193227, 193229, 193230, 193231, 193233, 193236, 193242, 193255, 193219, 193231, 193235, 193238, 193240, 193238, 193227, 193231, 193232, 193241, 193242, 193233, 193257, 193235, 193237, 193238, 193238, 193235, 193260, 193263, 193237, 193239, 193241, 193236, 193239, 193244, 193263, 193240, 193249, 193250, 193250, 193241, 193249, 193250, 193241, 193248, 193243, 193243, 193245, 193246, 193247, 193248, 193249, 193249, 193250, 193250, 193251, 193252, 193253, 193254, 193254, 193255, 193258, 193261, 193267, 193244, 193268, 193244, 193253, 193245, 193246, 193246, 193247, 193247, 193248, 193248, 193249, 193249, 193250, 193250, 193251, 193251, 193252, 193252, 193253, 193253, 193254, 193255, 193255, 193256, 193256, 193257, 193258, 193258, 193259, 193260, 193260, 193262, 193263, 193263, 193268, 193269, 193271, 193248, 193255, 193269, 193248, 193252, 193254, 193255, 193270, 193292, 193249, 193251, 193270, 193249, 193253, 193255, 193257, 193271, 193250, 193251, 193252, 193253, 193253, 193254, 193255, 193256, 193256, 193258, 193260, 193261, 193263, 193271, 193253, 193254, 193263, 193271, 193272, 261476, 193254, 193256, 193257, 193258, 193259, 193266, 193272, 193275, 193265, 193273, 193255, 193256, 193273, 193255, 193256, 193256, 193257, 193258, 193259, 193260, 193265, 193267, 193274, 193276, 193277, 193256, 193257, 193258, 193259, 193259, 193260, 193265, 193266, 193267, 193268, 193274, 193277, 193296, 193257, 193258, 193259, 193260, 193261, 193261, 193266, 193268, 193268, 193274, 193275, 193277, 193259, 193260, 193260, 193261, 193262, 193262, 193265, 193268, 193269, 193273, 193274, 193275, 193275, 193278, 261646, 280184, 193260, 193262, 193269, 193276, 193261, 193262, 193263, 193263, 193267, 193270, 193273, 193276, 193276, 193279, 193261, 193262, 193267, 193262, 193263, 193264, 193264, 193267, 193268, 193268, 193269, 193269, 193271, 193274, 193277, 193277, 193280, 193300, 261646, 193264, 193265, 193265, 193267, 193269, 193271, 193271, 193277, 193277, 193278, 193300, 261647, 193265, 193266, 193266, 193268, 193270, 193271, 193272, 193278, 193278, 193279, 193281, 261649, 193266, 193267, 193268, 193269, 193270, 193271, 193272, 193273, 193276, 193279, 193279, 193282, 193270, 193271, 193272, 193273, 193273, 193279, 193280, 193270, 193272, 193274, 193279, 193280, 193271, 193281, 193281, 193275, 193282, 193273, 193282, 193285, 193274, 193276, 193274, 193275, 193275, 193276, 193283, 261652, 193276, 193277, 193283, 193284, 193286, 233749, 193276, 193278, 193281, 193284, 193286, 193277, 193278, 193278, 193284, 193285, 193279, 193285, 193285, 193279, 193286, 193280, 193282, 193282, 193286, 193286, 193308, 287131, 193284, 193286, 193287, 193287, 193288, 193289, 193289, 193290, 193291, 193291, 193292, 193294, 193292, 193293, 193294, 193295, 193295, 193296, 193297, 193298, 193298, 193299, 193301, 193301, 193302, 193303, 193303, 193304, 193309, 193310, 193310, 193312, 193313, 193314, 193314, 193315, 193315, 193321, 193321, 193322, 193322, 193323, 193323, 193324, 193324, 193325, 193325, 193326, 261661, 261662, 261662, 261663, 280202, 193294, 193296, 193296, 193297, 193298, 193299, 193300, 193302, 193304, 193307, 193309, 193311, 193312, 193316, 193317, 193319, 193321, 193322, 193323, 193324, 193324, 193325, 193325, 193326, 193326, 193296, 193298, 193313, 193324, 193324, 193325, 193297, 193298, 193299, 193300, 193301, 193304, 193305, 193318, 193324, 193324, 193325, 193326, 193327, 193327, 193328, 193328, 261666, 193299, 193324, 193326, 193327, 193328, 193328, 193329, 193321, 193325, 193326, 193328, 193329, 193328, 261667, 193311, 193331, 193324, 193331, 193332, 193313, 193316, 193332, 193331, 193328, 193331, 193333, 193325, 193328, 193330, 193334, 193335, 193337, 193339, 193338, 193340, 193339, 193342, 193340, 193341, 193343, 193334, 193344, 193343, 193344, 193345, 193335, 193336, 193344, 193347, 193337, 193346, 193348, 193339, 193347, 193348, 193348, 193343, 193346, 193349, 193349, 193348, 193349, 193348, 193348, 193350, 193352, 193353, 193351, 193354, 193351, 193352, 193354, 193352, 193353, 193354, 193354, 193355, 193352, 193354, 193355, 193353, 193354, 193354, 193355, 193355, 193356, 193354, 193355, 193356, 193356, 193355, 193356, 193356, 193357, 193356, 193357, 193357, 193357, 193358, 193358, 193359, 233794, 241861, 261534, 261692, 261693, 261694, 261694, 261695, 261695, 261696, 261696, 280235, 280254, 287072, 261693, 261695, 261695, 261696, 261696, 261697, 280235, 274234, 274241, 274399, 302142, 274564, 302303, 290381, 310216, 329712, 329721, 329877, 329882, 329883, 330044, 330028, 330029, 330030, 330029, 330031, 330030, 330031, 330031, 330032, 330046, 330047, 330047, 330048, 330049, 330049, 330050, 330051, 330031, 330032, 330032, 330043, 330043, 330044, 330044, 330045, 330046, 330046, 330047, 330047, 330048, 330048, 330049, 330049, 330050, 330050, 330051, 330051, 330053, 330032, 330033, 330041, 330045, 330046, 330047, 330047, 330048, 330048, 330049, 330049, 330050, 330050, 330051, 330051, 330052, 330054, 330033, 330034, 330034, 330035, 330036, 330036, 330037, 330038, 330039, 330039, 330040, 330040, 330041, 330041, 330043, 330045, 330045, 330046, 330046, 330047, 330047, 330048, 330048, 330049, 330049, 330050, 330050, 330051, 330051, 330052, 330052, 330053, 330054, 330034, 330035, 330037, 330038, 330038, 330039, 330039, 330041, 330042, 330042, 330043, 330046, 330047, 330048, 330048, 330049, 330049, 330050, 330050, 330051, 330051, 330052, 330052, 330053, 330043, 330044, 330049, 330055, 330059, 330051, 330050, 330042, 330052, 330042, 330050, 330046, 330051, 330052, 330053, 330044, 330046, 330053, 330047, 330048, 330048, 330054, 330057, 330055, 330053, 330054, 330055, 330058, 330048, 330054, 330055, 330055, 330056, 330056, 330055, 330055, 330051, 330056, 330057, 330059, 330057, 330058, 330057, 330058, 330059, 330058, 330058, 330060, 330062, 330059, 348583, 330057, 330057, 330061, 330063, 330060, 330061, 330062, 330064, 348584, 330060, 330061, 330060, 330063, 330061, 330062, 330062, 330063, 330063, 330064, 330064, 330066, 348586, 330062, 330063, 330063, 330064, 330065, 330066, 348586, 330063, 330064, 330064, 330065, 330065, 330066, 330066, 330067, 330071, 348586, 348587, 348606, 330064, 330065, 330065, 330066, 330066, 330067, 330067, 330068, 330068, 330070, 330073, 330074, 348587, 348587, 355424, 355458, 330065, 330066, 330066, 330067, 330067, 330068, 330068, 330069, 330070, 348587, 348588, 355459, 330066, 330067, 330067, 330068, 330068, 330069, 330069, 330070, 330072, 330074, 330074, 348588, 348608, 355463, 330067, 330068, 330068, 330069, 330070, 330070, 330071, 330073, 330073, 330074, 330074, 330075, 348589, 330068, 330069, 330069, 330070, 330071, 330071, 330073, 348589, 348648, 355426, 330069, 330070, 330070, 330071, 330071, 330072, 330072, 330073, 330074, 330075, 330076, 348590, 348609, 355427, 371781, 330070, 330071, 330071, 330072, 330073, 330073, 330075, 330076, 330076, 330077, 348590, 348610, 355427, 355526, 330071, 330072, 330072, 330076, 330076, 330077, 330077, 348591, 348610, 348610, 355428, 330072, 330073, 330073, 330076, 330077, 330077, 348591, 355428, 330073, 330074, 330074, 330076, 330077, 330078, 330078, 348592, 348611, 348613, 348641, 355429, 330074, 330075, 330075, 330076, 330077, 330078, 348592, 348612, 330075, 330077, 330078, 330079, 348592, 348593, 330076, 330079, 330079, 330080, 348593, 348643, 348645, 355430, 330078, 330079, 330080, 348594, 355431, 348621, 330080, 330080, 348595, 330081, 348595, 330082, 330082, 348596, 348650, 330082, 330084, 348596, 355433, 330084, 348596, 348597, 348616, 348597, 348598, 348598, 367110, 367111, 367112, 367112, 367113, 367113, 367114, 367119, 367120, 367121, 367122, 367125, 367129, 367130, 367130, 367133, 367143, 367186, 367130, 367130, 367131, 367121, 367131, 367131, 367115, 367131, 367132, 367132, 367132, 367126, 367131, 367132, 367133, 367133, 367138, 367139, 367130, 367131, 367132, 367132, 367140, 367140, 367144, 367173, 373992, 374056, 367132, 367141, 367141, 373993, 367142, 367143, 367145, 367148, 367148, 367149, 367149, 367150, 367173, 367150, 367151, 367151, 367152, 367152, 367153, 367153, 367154, 367154, 367155, 367155, 367156, 367156, 367157, 367157, 367158, 367158, 367159, 367159, 367160, 367161, 367161, 367162, 367162, 367164, 367165, 367166, 367166, 367167, 367167, 367168, 367168, 367169, 367169, 367170, 367170, 367171, 367171, 367172, 367172, 367173, 367173, 367174, 367174, 367175, 367175, 367176, 367177, 367177, 367179, 367179, 367180, 367180, 367181, 367181, 367182, 367182, 367183, 367183, 367184, 367184, 367186, 367186, 367187, 367187, 367188, 367193, 367194, 367198, 367203, 367204, 367204, 367206, 367151, 367152, 367152, 367153, 367153, 367154, 367155, 367155, 367156, 367157, 367158, 367159, 367160, 367162, 367163, 367163, 367168, 367171, 367171, 367172, 367173, 367176, 367177, 367180, 367181, 367181, 367184, 367187, 367206, 367153, 367153, 367156, 367158, 367160, 367173, 367177, 367153, 367169, 367177, 367154, 367156, 367157, 367159, 367161, 367164, 367168, 367171, 367171, 367173, 367175, 367177, 367179, 367179, 367181, 367184, 367185, 367200, 367205, 367155, 367156, 367156, 367157, 367157, 367158, 367159, 367159, 367161, 367162, 367169, 367170, 367171, 367172, 367172, 367174, 367174, 367175, 367178, 367178, 367179, 367180, 367183, 367184, 367184, 367206, 367206, 367208, 13787706, 367162, 367164, 367178, 367158, 367177, 367179, 367159, 367163, 367169, 367171, 367175, 367175, 367181, 367181, 367159, 367163, 367164, 367167, 367176, 367179, 367180, 367182, 367162, 367163, 367165, 367167, 367174, 367174, 367175, 367178, 367182, 367183, 367184, 367186, 367187, 367189, 367192, 367162, 367167, 367168, 367174, 367174, 367176, 367181, 367178, 367183, 367185, 367163, 367166, 367172, 367178, 367183, 367184, 367164, 367165, 367166, 367168, 367169, 367175, 367176, 367179, 367179, 367180, 367182, 367183, 367184, 367184, 367186, 367188, 367167, 367172, 367174, 367175, 367183, 367185, 367177, 367187, 367191, 367177, 367179, 367180, 367181, 367189, 367171, 367175, 367176, 367179, 367181, 367186, 367189, 367174, 367177, 367179, 367179, 367181, 367185, 367187, 367191, 367172, 367177, 367179, 367181, 367183, 367189, 367192, 367177, 367191, 367174, 367179, 367190, 367191, 367193, 367197, 367181, 367182, 367185, 367188, 367189, 367192, 367179, 367179, 367181, 367184, 367185, 367185, 367186, 367188, 367190, 367196, 367218, 367178, 367184, 367180, 367183, 367184, 367187, 367190, 367199, 367191, 367195, 367184, 367189, 367191, 367196, 367184, 367185, 367186, 367188, 367189, 367193, 367220, 373984, 367190, 367192, 367193, 367194, 367195, 367185, 367186, 367188, 367190, 367191, 367193, 367193, 367198, 367200, 367187, 367187, 367188, 367191, 367195, 367195, 367187, 367190, 367192, 367194, 367194, 367195, 367195, 367196, 367198, 367199, 367200, 367201, 367224, 367189, 367190, 367190, 367191, 367192, 367194, 367195, 367198, 367198, 367200, 367200, 367201, 367201, 367204, 367205, 367225, 367189, 367190, 367192, 367192, 367193, 367193, 367195, 367196, 367197, 367199, 367200, 367202, 367205, 367225, 367190, 367193, 367195, 367197, 367197, 367202, 367203, 367218, 367226, 367192, 367193, 367196, 367196, 367197, 367201, 367201, 367206, 367226, 367195, 367196, 367198, 367198, 367200, 367201, 367194, 367194, 367195, 367196, 367197, 367198, 367199, 367201, 367202, 367203, 367204, 367205, 367227, 367195, 367195, 367196, 367197, 367199, 367201, 367201, 367228, 367195, 367196, 367196, 367198, 367199, 367201, 367202, 367203, 367209, 367219, 367196, 367197, 367197, 367198, 367199, 367200, 367200, 367202, 367204, 367204, 367205, 367205, 367206, 367207, 367210, 367229, 367198, 367199, 367200, 367201, 367203, 367207, 367208, 367209, 367211, 373991, 367198, 367199, 367200, 367201, 367202, 367206, 367209, 367211, 367222, 367227, 367200, 367203, 367206, 367207, 367208, 367204, 367207, 367201, 367202, 367203, 367203, 367204, 367204, 367205, 367205, 367206, 367206, 367207, 367208, 367208, 367209, 367209, 367210, 367212, 367212, 367213, 367229, 367231, 367231, 367203, 367203, 367205, 367205, 367206, 367206, 367207, 367207, 367208, 367208, 367209, 367211, 367203, 367232, 367204, 367205, 367206, 367206, 367207, 367207, 367208, 367208, 367209, 367209, 367210, 367210, 367211, 367213, 367230, 367233, 373994, 367205, 367206, 367207, 367207, 367208, 367208, 367209, 367209, 367210, 367212, 367216, 367219, 367229, 367231, 367233, 367207, 367207, 367208, 367208, 367209, 367210, 367210, 367207, 367208, 367209, 367209, 367210, 367211, 367211, 367213, 367214, 367215, 367226, 367232, 367235, 367209, 367210, 367210, 367211, 367211, 367212, 367212, 367213, 367214, 367215, 367217, 367217, 367219, 367223, 367228, 367230, 367232, 367233, 367235, 367210, 367211, 367211, 367212, 367213, 367214, 367215, 367216, 367216, 367226, 367234, 367236, 367211, 367212, 367212, 367213, 367213, 367214, 367214, 367215, 367215, 367216, 367216, 367217, 367217, 367218, 367218, 367219, 367223, 367227, 367229, 367232, 367234, 367234, 367236, 367236, 367237, 367212, 367213, 367213, 367214, 367214, 367215, 367216, 367216, 367217, 367217, 367219, 367220, 367223, 367224, 367227, 367229, 367233, 367233, 367235, 367237, 367213, 367214, 367214, 367215, 367215, 367216, 367217, 367217, 367218, 367219, 367221, 367225, 367230, 367235, 367237, 367214, 367215, 367215, 367216, 367217, 367217, 367218, 367218, 367219, 367220, 367221, 367221, 367223, 367225, 367228, 367230, 367234, 367234, 367235, 367236, 367238, 367215, 367216, 367216, 367217, 367217, 367218, 367218, 367219, 367219, 367220, 367221, 367221, 367224, 367225, 367226, 367227, 367228, 367228, 367229, 367229, 367231, 367231, 367234, 367234, 367235, 367236, 367236, 367238, 367216, 367217, 367217, 367218, 367218, 367219, 367220, 367221, 367221, 367222, 367224, 367227, 367227, 367231, 367235, 367236, 367238, 367239, 367217, 367218, 367218, 367219, 367220, 367221, 367221, 367222, 367222, 367223, 367226, 367229, 367232, 367232, 367234, 367235, 367237, 367237, 367239, 367219, 367220, 367222, 367223, 367226, 367228, 367231, 367232, 367238, 367240, 367219, 367220, 367220, 367221, 367222, 367225, 367227, 367229, 367233, 367237, 367238, 367240, 367220, 367221, 367221, 367222, 367223, 367224, 367228, 367229, 367230, 367231, 367232, 367235, 367236, 367237, 367237, 367238, 367239, 367240, 367241, 367222, 367223, 367223, 367224, 367224, 367227, 367228, 367232, 367234, 367237, 367238, 367239, 367239, 367241, 367223, 367224, 367225, 367227, 367229, 367230, 367231, 367233, 367234, 367239, 367240, 367241, 367242, 367224, 367224, 367225, 367226, 367228, 367230, 367231, 367232, 367235, 367238, 367238, 367240, 367240, 367242, 367242, 367230, 367241, 367243, 367227, 367229, 367230, 367231, 367232, 367233, 367234, 367236, 367239, 367239, 367240, 367241, 367243, 367243, 367226, 367227, 367235, 367239, 367240, 367242, 367243, 367244, 367230, 367231, 367234, 367235, 367236, 367240, 367242, 367244, 367228, 367231, 367240, 367243, 367244, 367245, 367229, 367230, 367232, 367232, 367233, 367236, 367242, 367243, 367243, 367243, 367246, 367244, 367237, 367244, 367247, 367236, 367245, 367235, 367235, 367236, 367240, 367241, 367245, 367248, 367235, 367236, 367237, 367239, 367241, 367248, 367238, 367239, 367240, 367241, 367248, 367249, 367238, 367238, 367239, 367240, 367242, 367244, 367246, 367247, 367247, 367249, 374045, 367241, 367242, 367250, 367243, 367246, 367248, 367250, 367242, 367249, 367251, 367242, 367249, 367249, 367251, 367242, 367243, 367244, 367247, 367249, 367252, 367243, 367252, 367245, 367246, 367247, 367249, 367249, 367250, 367251, 367252, 367253, 367251, 367247, 367248, 367250, 367250, 367251, 367252, 367252, 367253, 367254, 367254, 367252, 367254, 367255, 367253, 367255, 367252, 367254, 367256, 367257, 367253, 367254, 367255, 367255, 367257, 367254, 367255, 367256, 367258, 367255, 367256, 367256, 367258, 367258, 367256, 367257, 367257, 367259, 367257, 367258, 367259, 367259, 367259, 367260, 374055, 374076, 374120, 367260, 367261, 367261, 367262, 367263, 367263, 367264, 367264, 367265, 367265, 367266, 367266, 367267, 367268, 367269, 367270, 367270, 367271, 367271, 367273, 367273, 367274, 367274, 367275, 367276, 367278, 367278, 367279, 367279, 367280, 367280, 367281, 367281, 374023, 374057, 374069, 374122, 367263, 367264, 367265, 367265, 367266, 367266, 367267, 367267, 367268, 367269, 367270, 367270, 367271, 367273, 367275, 367276, 367277, 367278, 367279, 367279, 367280, 367280, 367281, 367281, 367282, 374024, 374058, 367272, 367276, 367281, 367282, 367282, 367265, 367266, 367267, 367269, 367268, 367283, 367274, 367282, 367283, 367284, 367274, 367278, 367279, 367282, 367284, 367284, 367283, 367284, 367285, 367278, 367283, 367283, 367284, 367285, 367276, 367284, 367286, 367285, 367287, 367276, 367281, 367286, 367287, 367288, 367288, 367288, 367289, 367285, 367286, 367290, 367283, 367289, 367290, 367285, 367288, 367289, 367291, 367290, 367292, 367289, 367292, 367288, 367291, 367293, 367294, 367291, 367294, 367295, 367295, 367296, 367292, 367296, 367294, 367297, 367294, 367295, 367296, 367297, 367297, 367296, 367297, 367297, 367298, 367297, 367298, 367298, 367297, 367298, 367299, 367298, 367299, 367299, 367299, 367300, 367300, 374042, 367301, 374042, 374043, 374077, 374083, 374084, 374141, 390362, 1474058, 2457029, 3282791, 5790560, 374043, 380784, 380785, 380786, 380787, 380787, 380788, 380790, 380806, 380811, 380812, 380816, 380817, 380817, 380818, 380818, 380819, 380822, 380842, 380786, 380787, 380788, 380790, 380819, 380819, 380788, 380789, 380791, 380819, 380820, 380791, 380820, 380821, 380790, 380792, 380821, 380821, 380795, 380808, 380793, 380822, 380795, 380797, 380809, 380811, 380816, 380821, 380822, 380823, 380823, 380824, 380824, 380824, 380825, 380826, 380837, 380839, 380840, 380840, 380845, 380846, 380849, 380850, 380850, 380850, 380851, 380851, 380851, 380852, 380852, 380894, 380853, 380854, 380854, 380855, 380855, 380856, 380856, 380857, 380857, 380858, 380858, 380859, 380859, 380861, 380862, 380863, 380864, 380864, 380866, 380868, 380868, 380869, 380869, 380870, 380870, 380871, 380872, 380872, 380873, 380873, 380874, 380874, 380875, 380875, 380876, 380876, 380877, 380881, 380887, 380892, 380894, 380894, 380854, 380855, 380855, 380856, 380856, 380857, 380858, 380859, 380860, 380863, 380864, 380865, 380867, 380869, 380869, 380870, 380870, 380871, 380873, 380873, 380874, 380875, 380877, 380877, 380895, 380856, 380856, 380860, 380866, 380867, 380870, 380870, 380871, 380871, 380873, 380857, 380864, 380870, 380871, 380871, 380872, 380873, 380874, 380876, 380857, 380859, 380859, 380862, 380868, 380870, 380870, 380871, 380871, 380878, 380883, 380889, 380896, 380858, 380859, 380860, 380860, 380861, 380861, 380864, 380866, 380867, 380869, 380870, 380871, 380871, 380872, 380872, 380873, 380874, 380876, 380877, 380879, 380879, 380883, 380864, 380867, 380868, 380871, 380872, 380872, 380873, 380873, 380875, 380876, 380879, 380884, 380872, 380873, 380874, 380876, 380862, 380863, 380864, 380867, 380868, 380868, 380870, 380872, 380872, 380873, 380873, 380874, 380874, 380878, 380878, 380885, 380863, 380865, 380869, 380874, 380874, 380875, 380874, 380874, 380875, 380878, 380886, 380874, 380874, 380876, 380897, 380868, 380869, 380871, 380874, 380875, 380876, 380877, 380880, 380882, 380873, 380875, 380876, 380877, 380883, 380898, 380876, 380888, 380876, 380872, 380876, 380877, 380878, 380878, 380879, 380873, 380878, 380879, 380874, 380878, 380879, 380880, 380886, 380879, 380879, 380887, 380876, 380879, 380880, 380880, 380881, 380883, 380884, 380885, 380878, 380879, 380880, 380881, 380881, 380882, 380883, 380886, 380901, 380903, 380906, 380882, 380893, 380882, 380881, 380882, 380882, 380883, 380888, 380883, 380884, 380884, 380885, 380886, 380888, 380889, 380889, 380891, 380905, 380907, 380909, 380884, 380885, 380885, 380886, 380886, 380887, 380888, 380890, 380891, 380892, 380896, 380897, 380898, 380908, 380885, 380886, 380886, 380887, 380887, 380888, 380888, 380889, 380889, 380890, 380892, 380893, 380897, 380897, 380898, 380900, 380906, 380910, 380910, 380886, 380887, 380887, 380888, 380888, 380889, 380889, 380890, 380890, 380891, 380891, 380892, 380893, 380893, 380896, 380897, 380898, 380899, 380900, 380902, 380903, 380904, 380910, 380911, 380887, 380889, 380889, 380890, 380890, 380891, 380891, 380892, 380893, 380894, 380894, 380895, 380898, 380904, 380909, 380911, 380888, 380889, 380889, 380890, 380890, 380891, 380891, 380892, 380893, 380893, 380894, 380894, 380895, 380897, 380898, 380898, 380899, 380900, 380900, 380901, 380903, 380904, 380909, 380912, 380889, 380890, 380891, 380892, 380892, 380890, 380891, 380891, 380892, 380895, 380895, 380899, 380906, 380913, 380891, 380892, 380893, 380893, 380894, 380894, 380896, 380896, 380897, 380899, 380900, 380900, 380903, 380904, 380911, 380913, 380892, 380893, 380893, 380894, 380894, 380895, 380896, 380896, 380897, 380900, 380901, 380903, 380904, 380907, 380911, 380912, 380913, 380914, 380893, 380894, 380894, 380895, 380895, 380896, 380896, 380897, 380897, 380898, 380901, 380905, 380906, 380906, 380907, 380908, 380912, 380913, 380914, 380894, 380895, 380895, 380896, 380897, 380897, 380912, 380915, 380895, 380896, 380896, 380897, 380898, 380898, 380899, 380902, 380902, 380903, 380904, 380906, 380907, 380908, 380913, 380915, 380896, 380897, 380897, 380898, 380898, 380899, 380900, 380902, 380903, 380904, 380905, 380906, 380907, 380907, 380910, 380913, 380914, 380915, 380916, 380897, 380898, 380899, 380899, 380903, 380916, 380916, 380898, 380899, 380899, 380900, 380903, 380917, 380899, 380900, 380902, 380902, 380904, 380904, 380908, 380917, 380900, 380901, 380902, 380903, 380904, 380905, 380905, 380906, 380908, 380909, 380909, 380910, 380910, 380911, 380912, 380915, 380917, 380917, 380918, 380901, 380902, 380902, 380903, 380903, 380905, 380905, 380906, 380906, 380907, 380908, 380908, 380909, 380914, 380916, 380918, 380902, 380905, 380906, 380907, 380908, 380911, 380913, 380916, 380919, 380906, 380906, 380912, 380919, 380919, 380906, 380907, 380916, 380907, 380912, 380921, 380908, 380915, 380909, 380910, 380910, 380911, 380911, 380912, 380913, 380914, 380915, 380915, 380916, 380916, 380917, 380917, 380919, 380920, 380920, 380921, 380921, 380922, 380922, 380910, 380911, 380912, 380912, 380913, 380915, 380915, 380916, 380917, 380917, 380918, 380918, 380919, 380920, 380921, 380921, 380922, 380923, 380946, 380911, 380913, 380914, 380916, 380917, 380918, 380920, 380921, 380921, 380923, 380923, 380946, 380916, 380919, 380920, 380921, 380923, 380924, 380915, 380922, 380924, 380917, 380922, 380925, 380915, 380916, 380918, 380918, 380920, 380921, 380921, 380925, 380925, 380917, 380918, 380923, 380926, 380924, 380919, 380920, 380921, 380922, 380923, 380924, 380926, 380927, 380920, 380920, 380921, 380922, 380927, 380927, 380920, 380925, 380928, 380921, 380922, 380923, 380926, 380928, 380928, 380922, 380923, 380923, 380926, 380928, 380929, 380923, 380927, 380929, 380929, 380927, 380930, 380926, 380928, 380929, 380930, 380930, 380928, 380931, 380928, 380929, 380930, 380931, 380929, 380932, 380930, 380931, 380932, 380931, 380932, 380932, 380933, 380933, 380932, 380933, 380933, 380934, 380934, 380934, 397213, 380934, 380935, 380958, 380935, 380936, 380937, 380937, 380938, 380938, 380939, 380940, 380940, 380941, 380943, 380943, 380944, 380948, 380950, 380955, 380957, 380959, 380966, 380968, 380969, 380969, 380970, 397179, 397215, 397217, 397229, 1701596, 380937, 380938, 380939, 380939, 380940, 380941, 380941, 380942, 380942, 380943, 380947, 380947, 380951, 380952, 380952, 380953, 380955, 380955, 380959, 380963, 380963, 380964, 380965, 380965, 380966, 380966, 380967, 380967, 380968, 380968, 380969, 380969, 380970, 380970, 380941, 380942, 380943, 380948, 380966, 380970, 380971, 380940, 380971, 380971, 380972, 380944, 380972, 380973, 380946, 380971, 380972, 380973, 380974, 380946, 380958, 380974, 380974, 380974, 380975, 380950, 380973, 380975, 380976, 380954, 380976, 380977, 380977, 380978, 380978, 380975, 380981, 380973, 380982, 380983, 380985, 380981, 380982, 380986, 380987, 380988, 380988, 380984, 380988, 380989, 380991, 380982, 380983, 380993, 380992, 380993, 380994, 380996, 380996, 380997, 380997, 380998, 380995, 380997, 380999, 380999, 381000, 381000, 381000, 381000, 381001, 380999, 381001, 381001, 381002, 381002, 381003, 381003, 381004, 381005, 397202, 397213, 397213, 397248, 397249, 397251, 397254, 397262, 397264, 397266, 397269, 397313, 397313, 655838, 655839, 655854, 655855, 985356, 1480912, 1480913, 1701628, 1701629, 1701629, 1701630, 2114959, 2578292, 2578302, 2756889, 3289643, 3887177, 5679409, 5679410, 5794652, 5797411, 21172219, 381005, 397214, 397249, 397214, 397250, 413412, 413422, 413423, 413424, 413424, 413425, 413427, 413428, 413430, 413433, 413434, 413436, 413444, 413445, 413446, 413454, 413455, 413456, 413457, 413457, 413458, 413458, 413425, 413425, 413429, 413434, 413458, 413458, 413459, 413449, 413459, 413460, 413460, 413460, 413459, 413462, 413462, 413452, 413462, 413463, 413464, 413465, 413468, 413469, 413470, 413471, 413479, 413480, 413481, 413482, 413483, 413489, 413491, 413492, 413492, 413492, 413493, 413493, 413494, 413495, 413495, 413496, 413496, 413497, 413497, 413498, 413498, 413499, 413499, 413500, 413500, 413501, 413501, 413502, 413503, 413503, 413504, 413504, 413505, 413505, 413506, 413506, 413507, 413508, 413508, 413509, 413509, 413510, 413510, 413511, 413511, 413513, 413515, 413515, 413516, 413517, 413517, 413520, 413521, 413523, 413524, 413527, 413528, 413532, 413532, 413534, 413561, 413495, 413496, 413496, 413497, 413497, 413499, 413499, 413500, 413500, 413501, 413501, 413502, 413502, 413504, 413506, 413507, 413507, 413508, 413509, 413509, 413510, 413510, 413511, 413534, 413534, 413498, 413502, 413508, 413509, 413509, 413510, 413510, 413511, 413500, 413501, 413510, 413511, 413535, 413498, 413506, 413509, 413512, 413499, 413502, 413503, 413504, 413505, 413510, 413511, 413511, 413512, 413512, 413513, 413516, 413527, 413502, 413502, 413504, 413506, 413507, 413510, 413511, 413511, 413512, 413512, 413514, 413515, 413518, 413512, 413538, 413507, 413507, 413511, 413512, 413513, 413515, 413504, 413508, 413513, 413514, 413505, 413508, 413509, 413510, 413512, 413513, 413514, 413514, 413516, 413523, 413507, 413508, 413514, 413512, 413514, 413515, 413540, 413508, 413511, 413515, 413515, 413517, 413518, 413519, 413510, 413512, 413514, 413514, 413515, 413516, 413516, 413517, 413517, 413518, 413518, 413541, 413514, 413515, 413512, 413512, 413514, 413514, 413515, 413517, 413518, 413520, 413531, 413541, 413543, 413518, 413518, 413520, 413543, 413518, 413518, 413519, 413520, 413520, 413527, 413542, 413515, 413519, 413539, 413519, 413520, 413528, 413519, 413520, 413520, 413521, 413522, 413531, 413520, 413521, 413546, 413519, 413520, 413521, 413521, 413522, 413523, 413539, 413521, 413521, 413522, 413522, 413523, 413524, 413525, 413530, 413533, 413534, 413534, 413547, 413522, 413523, 413523, 413524, 413524, 413525, 413527, 413531, 413531, 413534, 413534, 413535, 413535, 413537, 413548, 413523, 413524, 413524, 413525, 413529, 413531, 413532, 413533, 413533, 413534, 413535, 413535, 413536, 413541, 413546, 413548, 413548, 413524, 413525, 413525, 413526, 413527, 413527, 413528, 413530, 413530, 413531, 413531, 413532, 413532, 413533, 413534, 413535, 413535, 413536, 413536, 413538, 413538, 413539, 413545, 413546, 413547, 413549, 413525, 413526, 413527, 413527, 413529, 413530, 413531, 413531, 413532, 413533, 413534, 413535, 413536, 413538, 413542, 413548, 413549, 413526, 413527, 413527, 413529, 413529, 413530, 413531, 413531, 413532, 413533, 413533, 413534, 413535, 413536, 413536, 413537, 413537, 413538, 413544, 413546, 413546, 413548, 413550, 413527, 413528, 413531, 413536, 413537, 413538, 413550, 413528, 413529, 413529, 413530, 413530, 413531, 413531, 413532, 413532, 413533, 413533, 413534, 413534, 413535, 413535, 413536, 413537, 413537, 413538, 413538, 413539, 413540, 413540, 413541, 413542, 413542, 413543, 413543, 413544, 413545, 413547, 413547, 413548, 413549, 413551, 413551, 413529, 413533, 413533, 413535, 413535, 413536, 413537, 413533, 413535, 413552, 413534, 413535, 413539, 413546, 413546, 413552, 413535, 413536, 413536, 413540, 413543, 413533, 413534, 413535, 413536, 413537, 413539, 413541, 413553, 413535, 413537, 413537, 413539, 413540, 413540, 413554, 413537, 413540, 413542, 413555, 413536, 413537, 413538, 413538, 413539, 413539, 413540, 413541, 413542, 413544, 413555, 413538, 413539, 413539, 413541, 413541, 413542, 413546, 413553, 413554, 413555, 413555, 672105, 413539, 413539, 413540, 413540, 413542, 413543, 413545, 413556, 413539, 413540, 413542, 413540, 413541, 413541, 413543, 413543, 413544, 413544, 413545, 413546, 413546, 413547, 413548, 413552, 413554, 413555, 413557, 672106, 413541, 413542, 413542, 413543, 413544, 413544, 413545, 413546, 413547, 413550, 413551, 413557, 413559, 672124, 1571635, 413542, 413544, 413545, 413552, 413553, 413555, 413557, 413558, 413544, 413545, 413547, 413550, 413556, 413558, 413545, 413546, 413559, 413545, 413550, 413546, 413547, 413547, 413548, 413549, 413549, 413550, 413551, 413552, 413553, 413553, 413555, 413555, 413556, 413556, 413557, 413558, 413558, 413559, 413560, 413585, 413547, 413548, 413549, 413550, 413557, 413558, 413559, 413560, 413560, 413548, 413549, 413550, 413550, 413551, 413554, 413555, 413556, 413556, 413557, 413558, 413558, 413559, 413559, 413560, 413561, 413550, 413550, 413551, 413551, 413552, 413553, 413554, 413555, 413556, 413556, 413557, 413559, 413559, 413560, 413560, 413561, 413561, 413553, 413555, 413558, 413560, 413560, 413561, 413562, 413562, 413597, 413553, 413558, 413559, 413561, 413561, 413563, 413554, 413561, 413562, 413563, 413563, 413557, 413558, 413560, 413561, 413562, 413563, 413564, 413558, 413558, 413558, 413560, 413562, 413564, 413565, 413561, 413563, 413565, 413566, 413562, 413563, 413561, 413562, 413563, 413563, 413564, 413565, 413566, 413567, 413562, 413567, 413564, 413564, 413566, 413567, 413567, 413568, 413568, 413567, 413568, 413569, 672135, 413565, 413567, 413569, 413567, 413567, 413568, 413568, 413569, 413570, 413569, 413570, 413569, 413571, 413569, 413570, 413570, 413571, 413571, 672138, 413570, 413571, 413571, 413572, 672121, 413571, 413572, 413572, 413572, 413573, 413573, 413574, 413575, 413575, 413576, 413576, 413577, 413578, 413578, 413579, 413579, 413580, 413582, 413582, 413584, 413585, 413590, 413594, 413596, 413598, 413599, 413600, 413603, 413607, 413608, 413609, 413609, 619904, 672123, 672124, 672130, 672135, 672137, 672139, 672140, 672140, 672141, 672141, 999376, 1121154, 1497197, 1497199, 2079250, 2131244, 2856680, 3903454, 413575, 413576, 413576, 413577, 413577, 413578, 413578, 413579, 413579, 413580, 413580, 413581, 413581, 413582, 413582, 413583, 413587, 413588, 413588, 413589, 413589, 413590, 413591, 413591, 413592, 413592, 413593, 413594, 413594, 413595, 413596, 413596, 413597, 413598, 413598, 413599, 413600, 413600, 413601, 413602, 413602, 413603, 413603, 413604, 413604, 413605, 413605, 413606, 413606, 413607, 413607, 413608, 413608, 413609, 413609, 413610, 1245706, 2131244, 413577, 413579, 413581, 413588, 413589, 413600, 413608, 413609, 413609, 413610, 413579, 672140, 1497196, 413579, 413580, 413582, 413583, 413586, 413607, 413608, 413609, 413610, 413611, 413582, 413583, 413584, 413584, 413612, 413585, 413604, 413611, 413583, 413593, 413612, 413584, 413591, 413601, 413603, 413603, 413605, 413609, 413611, 413612, 413613, 572214, 413598, 413610, 413611, 413611, 413613, 413585, 413587, 413588, 413614, 413586, 413587, 413588, 413593, 413596, 413603, 413609, 413610, 413611, 413612, 413613, 413613, 413614, 413614, 413615, 672148, 413607, 413612, 413613, 413613, 413592, 413615, 413598, 413601, 413603, 413605, 413614, 413616, 413596, 413597, 413600, 413604, 413614, 413615, 413616, 413616, 907321, 413618, 413617, 2131266, 413609, 672151, 413616, 413620, 413621, 413622, 413603, 413602, 413614, 413622, 413623, 413620, 413621, 413623, 413618, 413621, 413624, 413612, 413618, 413619, 413622, 413623, 413624, 413625, 413612, 413616, 413625, 413626, 413621, 413627, 413625, 413627, 413627, 413628, 413626, 413628, 413628, 672143, 413628, 413629, 1001661, 413631, 413629, 413630, 413631, 413623, 413626, 413631, 413632, 413629, 413623, 413623, 413629, 413631, 413632, 413633, 413633, 413633, 413634, 413627, 413631, 413632, 413633, 413634, 413635, 413634, 413634, 413635, 413634, 413635, 413633, 413634, 413635, 672165, 413633, 413636, 413636, 413637, 413637, 413635, 413637, 413637, 413638, 672169, 413636, 413638, 413639, 413639, 413638, 413639, 413640, 413639, 413639, 413640, 413640, 413641, 413639, 413640, 413640, 413641, 413642, 413640, 413641, 413641, 413642, 413641, 413642, 413643, 413642, 413643, 413643, 413644, 672158, 413644, 413645, 413646, 426590, 426591, 426594, 450455, 514618, 545882, 559147, 566329, 566632, 566680, 569468, 572246, 572247, 572251, 602556, 605257, 612259, 619940, 642848, 672158, 672158, 672159, 672159, 672160, 672160, 672163, 672165, 672171, 672173, 672174, 672174, 672175, 672175, 672176, 672176, 672177, 672177, 672178, 673414, 829366, 830860, 873161, 873162, 873163, 899024, 899026, 907348, 919740, 988482, 988484, 988485, 999949, 1001557, 1001676, 1025633, 1025646, 1104983, 1104987, 1118600, 1118603, 1118604, 1118606, 1121189, 1121190, 1121191, 1132693, 1148043, 1148044, 1241454, 1497231, 1497231, 1497232, 1497232, 1497233, 1497233, 1497234, 1535777, 1571687, 1571689, 1571691, 1717949, 1717949, 1717950, 1717951, 1717953, 1717954, 1844780, 2036076, 2131278, 2131279, 2131279, 2131280, 2131287, 2131288, 2131289, 2131290, 2131290, 2131291, 2131291, 2131292, 2131292, 2480197, 2480198, 2480200, 2594615, 2594617, 2594619, 2594620, 2773209, 2773210, 2856727, 3266963, 3266964, 3289746, 3305963, 3305964, 3903497, 5455893, 5810973, 5813732, 413646, 514619, 569384, 572246, 672159, 672175, 672176, 672176, 1118604, 1148044, 1497233, 1717952, 3266964, 612268, 672160, 672173, 1717953, 2131291, 2773211, 439551, 439552, 439558, 1001443, 1038594, 1510197, 2493161, 487278, 487281, 708992, 1158015, 615618, 615624, 773159, 673252, 773165, 678143, 804438, 963072, 704693, 817705, 817721, 719056, 719131, 719203, 824957, 719649, 983828, 719743, 982428, 725161, 827937, 725316, 725412, 725504, 828099, 730851, 730862, 730862, 730863, 730865, 730867, 730868, 730864, 730870, 730866, 730874, 730883, 830791, 830792, 830775, 830776, 770877, 830795, 830797, 830800, 1277225, 830782, 2289915, 791484, 861103, 796904, 796979, 797055, 863881, 810914, 810917, 810912, 1317248, 1795854, 870817, 826247, 878466, 878474, 872062, 901373, 930672, 930672, 930697, 930673, 930685, 930687, 930687, 930688, 930688, 930689, 930689, 930690, 930690, 930691, 930692, 930694, 930696, 930701, 930703, 930683, 930685, 930686, 930687, 930687, 930688, 930688, 930689, 930689, 930690, 930690, 930691, 930692, 930692, 930693, 930695, 930697, 930697, 930699, 930699, 930701, 930702, 930703, 930704, 930705, 930693, 930706, 930709, 930711, 930712, 930713, 930699, 930700, 930701, 930700, 930702, 930702, 930708, 930703, 930720, 930703, 930703, 930707, 930719, 930703, 930704, 930704, 930705, 930712, 930720, 930720, 930703, 930704, 930704, 930705, 930705, 930706, 930707, 930721, 930721, 930723, 1165877, 1377132, 1379719, 1391223, 2738724, 930704, 930705, 930705, 930706, 930707, 930709, 930711, 930718, 930721, 930721, 930722, 1377133, 1379720, 2389807, 2389809, 930705, 930706, 930706, 930707, 930707, 930710, 930715, 930721, 930722, 930722, 930723, 1830221, 1976478, 2389820, 2389820, 930706, 930707, 930707, 930708, 930708, 930710, 930711, 930712, 930713, 930722, 930722, 930723, 930723, 930724, 1165878, 1377134, 1755763, 1830217, 1976481, 930707, 930708, 930708, 930709, 930710, 930712, 930712, 930720, 930722, 930723, 930723, 930724, 1157557, 1165878, 1377134, 1379718, 1976480, 2389816, 3031741, 930708, 930709, 930710, 930710, 930711, 930714, 930718, 930719, 930723, 930723, 930724, 1087904, 1165879, 1165880, 1379721, 1976481, 2389823, 930709, 930710, 930713, 930721, 930723, 930724, 930724, 930725, 930726, 1165882, 930713, 930715, 930716, 930717, 930718, 930721, 930723, 930724, 930724, 930725, 930725, 1377136, 2389812, 2389818, 930712, 930712, 930714, 930715, 930724, 930725, 930725, 930726, 1549601, 930714, 930715, 930725, 1165884, 1377137, 2389813, 930713, 930714, 930723, 930726, 1165881, 930715, 930716, 930718, 930726, 930726, 930721, 930728, 2389813, 930727, 930718, 930720, 930727, 930728, 1165884, 1755769, 1976486, 930719, 930722, 930724, 930726, 1406580, 930728, 930729, 930729, 930720, 930723, 930729, 930730, 1087903, 1379727, 1755771, 1830228, 930729, 1500080, 1976489, 930731, 930732, 2389832, 930732, 1247024, 1087906, 930732, 1131704, 930734, 1379731, 930733, 930734, 1157566, 1499996, 930735, 930731, 1379733, 930735, 930736, 930736, 930737, 1129631, 2389823, 930736, 930737, 1379331, 1755777, 930738, 1247030, 1377149, 1755779, 1377149, 930738, 930739, 930739, 930740, 1087912, 1165894, 1257958, 1284178, 1377147, 1377150, 1406589, 1500132, 1755778, 1755779, 1830237, 1976495, 1976496, 1976497, 2103452, 2389826, 2389837, 2738749, 930739, 930740, 930740, 1087913, 1125545, 1131709, 1131710, 1157569, 1157571, 1157573, 1165894, 1165895, 1257887, 1363534, 1377150, 1377151, 1379737, 1755779, 1755780, 1755780, 1755781, 1755784, 1794324, 1830237, 1976495, 1976496, 1976496, 1976498, 1976499, 2389826, 2389837, 2389838, 2389840, 2738743, 2853162, 3031757, 3525510, 930740, 1036025, 1087913, 1157573, 1157573, 1165894, 1165895, 1165898, 1306921, 1377148, 1377151, 1379734, 1379737, 1391241, 1391243, 1755780, 1755780, 1755781, 1830234, 1855746, 1855829, 1976496, 1976497, 1976499, 2389826, 2389827, 2389837, 2389838, 2389838, 2389839, 2389840, 2738746, 3031756, 1125549, 1129636, 1165896, 1165898, 1284180, 1377151, 1455795, 1755777, 1755780, 1755781, 1755782, 1830235, 1830240, 1855746, 1936455, 1976497, 1976497, 1976498, 1976499, 2389827, 2389828, 2389836, 2389837, 2389840, 2738745, 930742, 1344643, 1379738, 1125546, 1377152, 1379739, 1755782, 1976498, 3564512, 933209, 1378398, 1141328, 1961049, 1245107, 1245112, 1245114, 1245114, 1245118, 1245120, 2133696, 1323093, 1323094, 1534350, 1288909, 1288911, 1520734, 1534351, 1548442, 1288912, 1534352, 1912981, 1534356, 1247991, 1248067, 1248102, 1248142, 1914472, 1316281, 3190466, 1320365, 1320363, 1320369, 2171315, 1571968, 1571971, 1328548, 1328546, 1364808, 1578651, 1332705, 1332706, 1332707, 1366891, 1578144, 1578147, 1701128, 1956776, 2177492, 2590824, 2590830, 3054160, 1384415, 1384417, 1384417, 1384418, 1384418, 1384418, 1384419, 1603996, 1603998, 1392741, 1603996, 1604007, 1606580, 1982626, 2021169, 2203343, 2616671, 1401050, 1401051, 1401064, 1401064, 1401065, 1401065, 1401053, 1401062, 1401063, 1401065, 1401065, 1401066, 1401066, 1401068, 1401069, 1401067, 1401067, 1401064, 1401068, 1401071, 1401076, 1612318, 1482204, 1401080, 1614907, 1401080, 1413457, 1614907, 1990951, 1401082, 1519349, 1519351, 1519352, 1612321, 1614908, 1626412, 1626413, 1641762, 1990947, 1990948, 1990950, 1990951, 1990951, 2029494, 2211667, 1612322, 2211668, 1612319, 1612322, 2005536, 1612324, 1614911, 1425845, 1425846, 1425898, 2637394, 1425952, 1624762, 1563333, 1563334, 1563336, 1563337, 1563340, 1563343, 1693454, 1693457, 2072085, 2292805, 1696045, 2706134, 1585043, 1585065, 1585088, 1991186, 1585190, 1827362, 2083011, 2717071, 1586264, 2717605, 1589524, 1589594, 1589670, 1589719, 1709232, 2085275, 2085276, 2719336, 1637651, 1637649, 1637652, 1637650, 1637653, 1637653, 1637654, 1637666, 1730621, 2743296, 1730620, 1730623, 1733210, 1760064, 1683165, 1782836, 1758557, 1758646, 1758735, 1793741, 1796337, 1796340, 1796341, 1796342, 1809957, 1812544, 2822644, 1824048, 1823559, 1823584, 1823585, 1823603, 1823563, 1823564, 1823568, 1823580, 1823581, 1823586, 1823587, 1823588, 1823606, 1823588, 1823606, 1823589, 1823589, 1823608, 1823590, 1823596, 1823601, 1823594, 1823615, 2836255, 1823606, 1826167, 2302175, 2836267, 2836268, 1823612, 2836262, 1823613, 1823630, 1823631, 1826171, 1826174, 1826175, 1837672, 2202214, 2202217, 2202217, 2202219, 2240761, 2276671, 2276673, 2422933, 2422935, 2422936, 2563649, 2836262, 2836263, 2836263, 2836264, 2836272, 2836273, 2836274, 2836275, 2836275, 2836276, 3185182, 3185182, 3185183, 1823632, 1826171, 1826174, 1826176, 1826177, 1833568, 1837673, 1837680, 1902232, 1946439, 2202217, 2202217, 2276672, 2422934, 2422935, 2422937, 2836275, 1826180, 1826185, 1826190, 2200368, 1826192, 1837696, 2202235, 1827978, 2425142, 1828732, 1828753, 1828757, 1828758, 1828734, 1828735, 1828737, 1828741, 1828753, 1828754, 1828759, 1828760, 1828760, 1828761, 1828761, 1828779, 1828737, 1828780, 1828762, 1828762, 1828756, 1828763, 1828781, 1828767, 2838853, 1828779, 1828780, 1828798, 1840259, 2204797, 2279251, 2425517, 5037406, 2204800, 2204802, 1828785, 2838849, 1828786, 1828804, 1855614, 1903803, 1904815, 1949025, 1998638, 2098238, 2204801, 2204803, 2204803, 2204804, 2204805, 2243345, 2279259, 2279261, 2279261, 2304769, 2425519, 2425520, 2425521, 2425522, 2425524, 2733067, 2786856, 2838848, 2838849, 2838849, 2838850, 2838850, 2838858, 2838860, 2838860, 2838861, 2838862, 2838863, 3077921, 3480780, 1828796, 1828805, 1840266, 1855615, 1949025, 1998639, 2013447, 2204802, 2204803, 2204803, 2204804, 2204804, 2279258, 2304768, 2425520, 2425521, 2475744, 2733068, 2838850, 2838850, 2838851, 2838859, 2838862, 3302191, 2838849, 2838860, 1904836, 2204822, 2204822, 2467478, 2838867, 2838869, 3187788, 3480799, 1843534, 2212183, 1851764, 1851769, 1851744, 1851770, 1851771, 1867120, 2216307, 2216309, 2216310, 2216310, 2254852, 2290764, 2437025, 2850355, 2850356, 2850365, 2850366, 1882454, 1882457, 1882458, 1882458, 1882459, 1882459, 2452362, 1975998, 2231647, 1931662, 2452365, 2865694, 2865706, 1975869, 2231648, 2865704, 2231648, 1978840, 2913887, 1980909, 1980911, 1980984, 1981060, 2280972, 2280972, 2280973, 2380938, 2915032, 2069329, 2069402, 2069402, 2069477, 2069478, 2069492, 2069532, 2069533, 2069534, 2069535, 2069543, 2069544, 2325183, 2325183, 2399640, 2545899, 2959229, 2959229, 2959240, 3308149, 3422565, 3422566, 3601160, 2077854, 2963392, 2168501, 2168502, 2374668, 3008726, 2595385, 2198121, 2389474, 2367702, 3108314, 2397306, 2489079, 2577101, 3213013, 2580830, 2580817, 2580833, 2580818, 2580834, 2580819, 2580834, 2580834, 2580819, 2580834, 2580834, 2580820, 2580834, 2580820, 2580821, 2580822, 2580835, 2580835, 2580836, 2580821, 2580822, 2580822, 2580835, 2580835, 2580836, 2580836, 2580823, 2580823, 2580835, 2580835, 2580836, 2580836, 2580837, 2580836, 2580837, 2580836, 2580836, 2580837, 2580837, 2580838, 2580837, 2580837, 2580838, 2580843, 2580849, 3214880, 3214894, 2580849, 2580850, 2580850, 2619382, 3214881, 3214893, 2580850, 2580851, 2655009, 2655293, 2689518, 2801552, 2801553, 2801555, 3109099, 3214882, 3214887, 3214892, 3214893, 2580851, 2595418, 2619380, 2619380, 2619383, 2655290, 2655292, 2680886, 2801552, 2801553, 2801554, 2801555, 2801558, 2801559, 2999522, 3023325, 3109100, 3214881, 3214882, 3214883, 3214888, 3214889, 3214891, 3214892, 3214893, 3214893, 3214894, 3214894, 3214895, 3214895, 3214896, 3524153, 3563800, 3563803, 3678218, 3678222, 3678224, 3856813, 3940318, 4389567, 2619376, 2619380, 2619381, 2619381, 2655010, 2655290, 2655291, 2655291, 2680802, 2680886, 2790837, 2801553, 2801553, 2801554, 2801554, 2801556, 2801558, 2843320, 2843539, 3109100, 3109100, 3214881, 3214882, 3214882, 3214883, 3214883, 3214884, 3214887, 3214891, 3214892, 3214893, 3214893, 3214894, 3214894, 3214895, 3214895, 3214896, 3214896, 3214897, 3214898, 3563800, 3563800, 3563801, 3563801, 3563802, 3678219, 3678221, 3678223, 3678225, 3856813, 3856813, 3940318, 6894576, 2801554, 2609997, 2609998, 3229463, 2695381, 2657918, 2657922, 2657923, 2657923, 2657924, 2657924, 2657924, 2657911, 2657925, 2657925, 2657926, 2657927, 2657928, 2840095, 3253439, 2881737, 2882037, 3253425, 2693836, 2693838, 2719345, 2800050, 2840098, 2840098, 2840100, 2840100, 3147645, 3253426, 3253426, 3253437, 3253438, 3253438, 3253439, 3716765, 2729178, 2729179, 2729464, 2729462, 2729743, 2729744, 2729744, 2729745, 2729745, 2729743, 2729746, 2729746, 2729748, 2729748, 2729749, 2729747, 2729751, 2729751, 2729752, 2729753, 2729753, 2729751, 2876004, 2755341, 2876005, 3289348, 2876007, 3289337, 2876007, 2876008, 2876010, 3289336, 3289337, 3289337, 3289347, 5061553, 2755257, 3289337, 3289338, 2876010, 3289338, 2729830, 2876010, 3289339, 3289348, 2876009, 2876010, 2876012, 3289339, 3289340, 3289340, 2876011, 2729915, 3183643, 2780759, 2780759, 2780760, 2780761, 2780762, 2780762, 2780763, 2780847, 2780848, 2780848, 2780848, 2780849, 2780849, 2780849, 2780850, 2780851, 2780934, 2780935, 2780936, 2780938, 2780935, 2780936, 2780937, 2780938, 2780937, 2780937, 2780938, 2780939, 3314929, 3314931, 3314929, 3956861, 3314930, 2901602, 3663851, 2901602, 2901603, 3314932, 3314932, 3314943, 3314944, 3106407, 2798198, 2910232, 2942173, 2942181, 3395562, 3395552, 3000834, 3011550, 3022253, 3022253, 3022254, 3022254, 3022267, 3022268, 3022270, 3022253, 3022254, 3022254, 3022255, 3022255, 3022268, 3022268, 3022269, 3022270, 3022254, 3022255, 3022255, 3022256, 3022257, 3022258, 3022268, 3022269, 3022270, 3022271, 3022272, 3022272, 3022273, 3022255, 3022256, 3022257, 3022269, 3022270, 3022270, 3022256, 3022258, 3022258, 3022271, 3022271, 3022272, 3022272, 3022273, 3022258, 3022258, 3022259, 3022259, 3022270, 3022271, 3022271, 3022272, 3022272, 3022273, 3022273, 3022274, 3022275, 3022273, 3022273, 3022272, 3022272, 3022274, 3022274, 3022275, 3022275, 3022273, 3022275, 3022275, 3022276, 3022273, 3022274, 3022275, 3022276, 3022276, 3022275, 3022277, 3022276, 3022277, 3022278, 3022278, 3022279, 3022280, 3022283, 3022284, 3435598, 3435610, 3022285, 3022285, 3022286, 3435599, 3435610, 3022286, 3022287, 3022290, 3435599, 3435599, 3435600, 3435611, 3022287, 3022287, 3022288, 3435598, 3435599, 3435600, 3022287, 3022288, 3435599, 3435600, 3435612, 3435612, 3022288, 3022289, 3022289, 3435600, 3435601, 3435611, 3435612, 3435613, 3022289, 3022290, 3022290, 3359413, 3435600, 3435601, 3435601, 3435602, 3435603, 3435610, 3435611, 3435611, 3435612, 3435612, 3435613, 3435613, 3435614, 3581578, 3784519, 3784520, 3784520, 3784521, 3898939, 3022290, 3022291, 3227074, 3435601, 3435601, 3435602, 3435602, 3435609, 3435612, 3435612, 3435614, 3784518, 3784519, 3784520, 3898935, 3898937, 4077532, 3435601, 3435602, 3435602, 3435603, 3435605, 3435608, 3435612, 3435613, 3435613, 3435614, 3435615, 3898942, 3072497, 3383609, 3435602, 3435603, 3435604, 3435611, 3435613, 3435616, 3784519, 3784522, 4161038, 3435610, 3435617, 4077534, 3435605, 3105604, 3105909, 3105864, 3106042, 3106139, 3106140, 3106214, 3106221, 3106255, 3106290, 3477613, 3477606, 3940942, 4003069, 4119536, 3122769, 3122770, 3122845, 3122846, 3122919, 3485949, 3485950, 3275957, 3276017, 3276093, 3276167, 3276216, 3276224, 3911507, 4025931, 3303696, 3576309, 3418204, 3633576, 3431870, 3431871, 3989315, 4282329, 3465811, 3657375, 3637360, 3637361, 3637361, 3743143, 3743144, 3743154, 3743156, 4385074, 3658521, 4395654, 3696549, 4121657, 3744939, 3744940, 3744942, 4260273, 3796934, 3796935, 3848912, 3848912, 3848912, 3848913, 3848921, 3848923, 3848932, 3848933, 3848913, 3848923, 3848925, 3848929, 3848914, 3848915, 3848920, 3848924, 3848924, 3848925, 3848926, 3848926, 3848927, 3848927, 3848929, 3848929, 3848930, 3848931, 3848931, 3848932, 3848915, 3848916, 3848917, 3848918, 3848918, 3848920, 3848920, 3848921, 3848921, 3848922, 3848922, 3848923, 3848923, 3848924, 3848924, 3848925, 3848925, 3848926, 3848926, 3848927, 3848927, 3848928, 3848929, 3848929, 3848930, 3848930, 3848931, 3848931, 3848932, 3848934, 3848934, 3848935, 3848936, 3848940, 3848916, 3848921, 3848925, 3848926, 3848927, 3848917, 3848918, 3848919, 3848920, 3848921, 3848922, 3848923, 3848923, 3848924, 3848925, 3848925, 3848926, 3848926, 3848927, 3848927, 3848928, 3848928, 3848929, 3848930, 3848930, 3848931, 3848931, 3848932, 3848936, 3848924, 3848924, 3848927, 3848930, 3848929, 3848927, 3848932, 3848945, 3848931, 3848929, 3848931, 3848946, 3848947, 3848927, 3848930, 3848931, 3848938, 3848927, 3848930, 3848932, 3848933, 3848944, 3848948, 3848930, 3848932, 3848935, 3848936, 3848947, 3848948, 3848929, 3848933, 3848936, 3848930, 3848931, 3848932, 3848932, 3848933, 3848934, 3848934, 3848935, 3848936, 3848939, 3848933, 3848933, 3848934, 3848935, 3848935, 3848950, 3848950, 3848951, 3848932, 3848933, 3848933, 3848934, 3848935, 3848939, 3848951, 3848933, 3848934, 3848934, 3848935, 3848935, 3848936, 3848937, 3848938, 3848938, 3848952, 3848934, 3848935, 3848935, 3848936, 3848936, 3848937, 3848939, 3848939, 3848950, 3848951, 3848952, 3848952, 3848935, 3848936, 3848936, 3848937, 3848937, 3848939, 3848939, 3848940, 3848940, 3848942, 3848943, 3848952, 3848952, 3848953, 3848953, 3848936, 3848937, 3848937, 3848938, 3848938, 3848939, 3848940, 3848941, 3848942, 3848944, 3848952, 3848953, 3848953, 3848955, 3848937, 3848938, 3848938, 3848939, 3848940, 3848941, 3848941, 3848942, 3848943, 3848944, 3848950, 3848952, 3848953, 3848953, 3848954, 3848954, 3848938, 3848939, 3848939, 3848940, 3848940, 3848941, 3848941, 3848942, 3848942, 3848943, 3848943, 3848951, 3848952, 3848953, 3848953, 3848954, 3848954, 3848956, 3848939, 3848940, 3848940, 3848941, 3848941, 3848942, 3848942, 3848943, 3848945, 3848947, 3848949, 3848953, 3848954, 3848954, 3848955, 3848955, 3848940, 3848941, 3848941, 3848942, 3848942, 3848943, 3848943, 3848944, 3848944, 3848945, 3848946, 3848947, 3848953, 3848954, 3848955, 3848955, 3848942, 3848942, 3848943, 3848943, 3848944, 3848944, 3848945, 3848946, 3848947, 3848954, 3848955, 3848955, 3848956, 3848957, 3848943, 3848945, 3848947, 3848955, 3848955, 3848956, 3848956, 3848957, 3848957, 3848958, 3848943, 3848944, 3848944, 3848945, 3848945, 3848955, 3848956, 3848956, 3848959, 3848944, 3848945, 3848945, 3848946, 3848946, 3848947, 3848956, 3848957, 4197847, 3848945, 3848946, 3848946, 3848947, 3848947, 3848948, 3848949, 3848953, 3848956, 3848957, 4197847, 4197847, 4197848, 4312263, 4351372, 5621139, 3848946, 3848947, 3848947, 3848948, 3848948, 3848949, 3848950, 3848957, 3848958, 3848960, 4197847, 3848947, 3848948, 3848948, 3848949, 3848950, 3848950, 3848951, 3848957, 3848960, 4197847, 4197848, 4197852, 3848948, 3848949, 3848949, 3848950, 3848951, 3848951, 3848952, 3848954, 3848959, 3848959, 4197849, 3848949, 3848950, 3848950, 3848951, 3848951, 3848952, 3848953, 3848954, 3848959, 4197849, 4197850, 4312265, 3848950, 3848951, 3848951, 3848952, 3848952, 3848953, 3848959, 3848960, 3848960, 3848951, 3848952, 3848952, 3848953, 3848953, 3848954, 3848954, 3848960, 3848960, 3848961, 4197852, 4574366, 4574370, 3848952, 3848953, 3848953, 3848954, 3848954, 3848955, 3848955, 3848956, 3848957, 3848960, 3848961, 3848961, 4197852, 4312271, 3848953, 3848954, 3848954, 3848955, 3848957, 3848961, 4197851, 4197854, 4312273, 3848954, 3848955, 3848955, 3848956, 3848956, 3848957, 3848957, 3848961, 3848962, 3848963, 4197853, 4197854, 4574387, 3848955, 3848956, 3848956, 3848957, 3848957, 3848958, 3848958, 3848961, 3848962, 3848962, 3890638, 4197852, 4312270, 3848956, 3848957, 3848957, 3848958, 3848959, 3848959, 3848960, 3848962, 3848963, 4059403, 4312277, 4574370, 3848957, 3848958, 3848958, 3848959, 3848959, 3848962, 3848963, 3848963, 4197855, 3848958, 3848959, 3848959, 3848960, 3848960, 3848961, 3848961, 3848962, 3848963, 3848963, 3848964, 3848964, 4197857, 3848959, 3848960, 3848960, 3848961, 3848962, 3848964, 3848964, 3848965, 4490867, 3848960, 3848961, 3848961, 3848962, 3848962, 3848964, 3848964, 4040822, 4490867, 3848961, 3848962, 3848962, 3848963, 3848964, 3848965, 3848965, 3848966, 4197857, 4312271, 4312271, 3848962, 3848963, 3848963, 3848964, 3848965, 3848965, 3848966, 3848966, 4312279, 3848963, 3848964, 3848964, 3848966, 3848966, 4312279, 4490869, 3848964, 3848965, 3848965, 3848966, 3848966, 3848967, 3848967, 3848968, 4312276, 4574382, 3848965, 3848966, 3848967, 3848967, 3848968, 3848968, 4197858, 4312273, 4312277, 4351383, 4490869, 3848967, 3848968, 3848968, 3848968, 3848968, 4087959, 6810309, 3848968, 3848969, 4197859, 4197863, 4312274, 4312280, 3848969, 3848970, 3848970, 4197857, 4197858, 4197859, 4197859, 4197860, 4197861, 4312277, 4312278, 4312280, 4312281, 4312282, 4312286, 4312286, 4490871, 4490872, 4574377, 3848970, 3848971, 3848971, 3848972, 3911480, 3937154, 3943857, 4022235, 4061914, 4061916, 4087961, 4088006, 4088013, 4138058, 4197854, 4197855, 4197857, 4197857, 4197858, 4197859, 4197859, 4197860, 4197860, 4197861, 4197861, 4197862, 4197862, 4197863, 4197863, 4197864, 4240776, 4272276, 4312274, 4312275, 4312275, 4312276, 4312276, 4312278, 4312278, 4312279, 4312280, 4312281, 4312281, 4312282, 4312282, 4312283, 4312285, 4490870, 4490870, 4490872, 4490872, 4574376, 4574377, 4574377, 4574379, 4574385, 4574387, 7173556, 3848971, 3848972, 3848972, 3890642, 4087961, 4087992, 4088013, 4131378, 4197855, 4197856, 4197857, 4197857, 4197858, 4197859, 4197860, 4197860, 4197861, 4197861, 4197862, 4197862, 4197863, 4197863, 4197865, 4312275, 4312276, 4312276, 4312277, 4312278, 4312278, 4312279, 4312279, 4312280, 4312281, 4312282, 4312282, 4312283, 4312284, 4312285, 4490873, 4574376, 4574378, 4574388, 5621152, 3848972, 4087962, 4197858, 4197858, 4197859, 4197860, 4197861, 4197861, 4197862, 4197863, 4312275, 4312279, 4312281, 4312283, 4490873, 4490873, 3848973, 4197859, 4197859, 4197860, 4197861, 4197861, 4197862, 4197863, 4312280, 4312283, 4312289, 4197860, 4197861, 4197865, 4312284, 4197861, 4197864, 4197866, 4490875, 3932327, 3932333, 4353960, 4239547, 3974000, 4260380, 4025351, 4286053, 4038761, 4407187, 4140884, 4140952, 4141014, 4458309, 4195526, 4371150, 4232699, 4504147, 4269865, 4701328, 4274874, 4274875, 4525234, 4410820, 4327014, 4327045, 4327060, 4327077, 4327082, 4327086, 4327087, 4327108, 4327162, 4327113, 4327162, 4415690, 4436925, 4551346, 4436938, 4436940, 4436987, 4436988, 4551407, 4551410, 4730001, 4413791, 4413847, 4413917, 4480348, 4427164, 4486967, 4467464, 4467505, 4467547, 4621573, 4504297, 4525531, 4546745, 4546744, 4546759, 4546747, 4546761, 4546746, 4546747, 4546747, 4546761, 4546747, 4546748, 4546750, 4546762, 4546749, 4546750, 4546762, 4546763, 4546747, 4546748, 4546748, 4546749, 4546749, 4546751, 4546762, 4546762, 4546763, 4546763, 4546764, 4546748, 4546749, 4546749, 4546750, 4546751, 4546763, 4546763, 4546767, 4546749, 4546750, 4546750, 4546751, 4546751, 4546752, 4546763, 4546764, 4546764, 4546765, 4546766, 4546750, 4546751, 4546751, 4546754, 4546765, 4546765, 4546766, 4546767, 4546751, 4546752, 4546752, 4546753, 4546753, 4546754, 4546754, 4546764, 4546764, 4546765, 4546765, 4546766, 4546766, 4546767, 4546767, 4546752, 4546753, 4546753, 4546754, 4546765, 4546766, 4546767, 4546767, 4546768, 4546768, 4546753, 4546754, 4546754, 4546755, 4546755, 4546765, 4546766, 4546766, 4546767, 4546767, 4546768, 4546768, 4546769, 4546769, 4546770, 4546754, 4546755, 4546756, 4546766, 4546767, 4546767, 4546768, 4546769, 4546755, 4546756, 4546756, 4546757, 4546758, 4546767, 4546768, 4546769, 4546769, 4546770, 4546771, 4546756, 4546757, 4546765, 4546766, 4546767, 4546767, 4546768, 4546769, 4546771, 4546772, 4546757, 4546767, 4546768, 4546768, 4546769, 4546769, 4546770, 4546772, 4546772, 4546768, 4546768, 4546769, 4546769, 4546770, 4546770, 4546771, 4546772, 4546773, 4546770, 4546774, 4546769, 4546774, 4546778, 4546778, 4546778, 4546779, 4661186, 4661188, 4546778, 4546779, 4546780, 4546780, 4546781, 4661179, 4661180, 4661182, 4661185, 4661186, 4661187, 4661189, 4546779, 4546780, 4546780, 4546781, 4546781, 4546783, 4661179, 4661182, 4661183, 4661186, 4661186, 4661187, 4839777, 4546780, 4546781, 4546781, 4546782, 4546784, 4661179, 4661180, 4661180, 4661181, 4661182, 4661183, 4661183, 4661186, 4661186, 4661187, 4661189, 4661192, 4700290, 4839777, 4923282, 4923283, 4546781, 4546782, 4546782, 4546783, 4546784, 4661180, 4661187, 4839777, 4839778, 4546782, 4546783, 4546784, 4546784, 4546785, 4661181, 4661181, 4661182, 4661182, 4661183, 4661184, 4661184, 4661186, 4661187, 4661188, 4661188, 4661189, 4661189, 4661192, 4839776, 4839776, 4839778, 4839778, 4546783, 4546784, 4546784, 4546785, 4661181, 4661182, 4661182, 4661183, 4661184, 4661184, 4661186, 4661186, 4661188, 4661188, 4661192, 4661193, 4839778, 4839778, 4839779, 5970057, 4546784, 4546785, 4546785, 4546786, 4661181, 4661182, 4661182, 4661183, 4661183, 4661184, 4661185, 4661185, 4661186, 4661187, 4661188, 4661189, 4661193, 4661195, 4700292, 4700293, 4702283, 4723313, 4839777, 4839779, 4839779, 4923299, 5333533, 4546785, 4661182, 4661183, 4661189, 4546786, 4546787, 4661182, 4661183, 4661183, 4661184, 4661184, 4661186, 4661187, 4661189, 4661190, 4661190, 4839779, 4839780, 4923286, 4546787, 4546788, 4661183, 4661184, 4661184, 4661185, 4839781, 7762300, 4661183, 4661184, 4661184, 4661185, 4661185, 4661186, 4661186, 4661187, 4661187, 4661188, 4661188, 4661189, 4661191, 4661191, 4661192, 4661192, 4839779, 4839780, 4839781, 4839781, 4923287, 5372536, 4661191, 4632622, 4704127, 4695594, 4735600, 4775579, 4775580, 4775580, 4775582, 4775583, 4775586, 4775594, 4775580, 4775581, 4775581, 4775582, 4775583, 4775583, 4775586, 4775586, 4775587, 4775588, 4775589, 4775590, 4775595, 4775596, 4775598, 4775599, 4775601, 4775603, 4775581, 4775582, 4775583, 4775584, 4775584, 4775585, 4775586, 4775587, 4775587, 4775588, 4775589, 4775589, 4775596, 4775596, 4775597, 4775598, 4775599, 4775600, 4775601, 4775601, 4775602, 4775605, 4775582, 4775583, 4775585, 4775585, 4775586, 4775587, 4775587, 4775588, 4775588, 4775589, 4775590, 4775591, 4775592, 4775596, 4775596, 4775597, 4775597, 4775598, 4775598, 4775599, 4775600, 4775601, 4775603, 4775604, 4775605, 4775584, 4775584, 4775585, 4775587, 4775588, 4775588, 4775589, 4775591, 4775593, 4775597, 4775598, 4775599, 4775600, 4775600, 4775604, 4775588, 4775590, 4775609, 4775585, 4775586, 4775587, 4775589, 4775590, 4775592, 4775600, 4775609, 4775610, 4775586, 4775587, 4775587, 4775588, 4775588, 4775589, 4775589, 4775590, 4775590, 4775591, 4775591, 4775592, 4775593, 4775593, 4775595, 4775598, 4775599, 4775606, 4775610, 4775610, 4775587, 4775588, 4775588, 4775589, 4775590, 4775590, 4775591, 4775592, 4775592, 4775593, 4775595, 4775595, 4775603, 4775605, 4775607, 4775611, 4775588, 4775589, 4775590, 4775590, 4775591, 4775591, 4775592, 4775594, 4775595, 4775598, 4775600, 4775611, 4775590, 4775591, 4775591, 4775592, 4775592, 4775593, 4775600, 4775606, 4775608, 4775612, 4775591, 4775591, 4775592, 4775593, 4775612, 4775612, 4775592, 4775593, 4775593, 4775595, 4775597, 4775602, 4775612, 4775612, 4775613, 4775592, 4775594, 4775602, 4775603, 4775606, 4775611, 4775612, 4775613, 4775593, 4775594, 4775594, 4775595, 4775596, 4775597, 4775597, 4775598, 4775598, 4775601, 4775602, 4775603, 4775604, 4775606, 4775607, 4775610, 4775612, 4775613, 4775613, 4775614, 4775594, 4775595, 4775597, 4775600, 4775605, 4775606, 4775607, 4775611, 4775613, 4775614, 4775614, 4775595, 4775596, 4775597, 4775598, 4775598, 4775599, 4775599, 4775603, 4775603, 4775605, 4775606, 4775606, 4775607, 4775613, 4775614, 4775614, 4775615, 4775596, 4775597, 4775598, 4775599, 4775603, 4775604, 4775606, 4775608, 4775613, 4775614, 4775615, 4775615, 4775597, 4775599, 4775599, 4775600, 4775603, 4775606, 4775608, 4775609, 4775615, 4775615, 4775616, 4775599, 4775600, 4775607, 4775608, 4775612, 4775615, 4775616, 4775616, 4775608, 4775608, 4775616, 4775606, 4775607, 4775609, 4775612, 4775615, 4775616, 4775601, 4775602, 4775606, 4775607, 4775609, 4775610, 4775617, 4775617, 4775602, 4775607, 4775613, 4775617, 4775618, 4775609, 4775618, 4775618, 4775619, 4775618, 4775619, 4775619, 4775610, 4775619, 4775620, 4775620, 4775621, 4775619, 4775610, 4775611, 4775612, 4775614, 4775615, 4775618, 5447947, 4775612, 4775614, 4775614, 4775615, 4775612, 4775613, 4775613, 4775614, 4775614, 4775615, 4775615, 4775616, 4775621, 4775622, 4775623, 4954193, 4954193, 5037699, 4775613, 4775614, 4775615, 4775616, 4775616, 4775621, 4775624, 5447947, 6084473, 4775614, 4775616, 4775616, 4775617, 4775623, 4775624, 4954194, 5486948, 4775615, 4775617, 4775617, 4775618, 4775622, 4775624, 4775625, 4775617, 4775618, 4775618, 4775621, 4775623, 4775624, 4775625, 5037700, 4775617, 4775618, 4775619, 4775619, 4775625, 4775626, 4954196, 4954196, 4775618, 4775619, 4775621, 4775625, 4775626, 4775626, 4816700, 4954194, 4954196, 4954196, 4954197, 5486951, 4775619, 4775620, 4775623, 4775623, 4775626, 4775627, 4954196, 5037702, 5486951, 4775620, 4775621, 4775621, 4775622, 4775622, 4775623, 4775625, 4775627, 4775627, 4954197, 4775622, 4775623, 4775627, 4775627, 4775628, 4790523, 5037703, 5447955, 6084476, 4775628, 4837960, 4954198, 4775625, 4775629, 4954199, 4775628, 4775630, 4954199, 4775625, 4775626, 4775630, 5037704, 5037713, 5447953, 4775630, 4790527, 4954200, 4775627, 4775630, 4775631, 4954201, 4775631, 4775631, 4775632, 4954201, 4954202, 4775632, 4775632, 4814713, 4954202, 5037708, 4775632, 4775633, 4775633, 4775634, 4775634, 4775635, 4790529, 4954203, 4954204, 4954204, 5037707, 5037715, 5447957, 5447959, 4775634, 4954204, 4954204, 4954205, 5037719, 5486958, 4775635, 4782073, 4782074, 4814713, 4814715, 4814716, 4814716, 4814717, 4814718, 4814718, 4816707, 4816709, 4837738, 4889085, 4954202, 4954203, 4954203, 4954204, 4954204, 4954205, 4954206, 5037709, 5037709, 5037710, 5037710, 5037712, 5037714, 5037718, 5037720, 5447958, 5447961, 5447961, 5447964, 5486961, 6084484, 6084492, 7991968, 4816709, 4954205, 4954205, 5037710, 4954205, 4788526, 4788528, 5044163, 4960657, 4805441, 4805444, 4805442, 4969113, 4969115, 4969119, 4853808, 4853811, 4853811, 4853814, 4853812, 4853813, 4853813, 4853816, 4853814, 4993299, 4993300, 4993300, 5076805, 4993303, 5076809, 4857803, 4857803, 4857804, 4995299, 4995300, 4995300, 4899905, 5016371, 5016372, 5099877, 4900362, 5016600, 5002550, 5067669, 5132770, 5132772, 5132772, 5132773, 5132784, 5132786, 5132788, 5132773, 5132787, 5132773, 5132774, 5132774, 5132789, 5132789, 5132790, 5132775, 5132776, 5132776, 5132787, 5132787, 5132788, 5132788, 5132789, 5132789, 5132790, 5132790, 5132793, 5132788, 5132788, 5132789, 5132790, 5132790, 5132791, 5132791, 5132789, 5132790, 5132790, 5132791, 5132790, 5132790, 5132791, 5132791, 5216291, 5132802, 5132801, 5132802, 5132802, 5132803, 5132803, 5216301, 5665541, 6263068, 8055306, 5132803, 5132804, 5216294, 5216294, 5132804, 5216295, 5216313, 5626543, 6263069, 7415637, 5132805, 5132806, 5132806, 5132807, 5132807, 5132811, 5155502, 5175865, 5216291, 5216292, 5216292, 5216293, 5216293, 5216294, 5216294, 5216295, 5216295, 5216296, 5216296, 5216297, 5216297, 5216298, 5216299, 5216300, 5216301, 5216301, 5216302, 5216303, 5216304, 5216304, 5216305, 5216307, 5216308, 5216309, 5216310, 5216311, 5216317, 5221800, 5299154, 5626543, 5626544, 5626544, 5626546, 5626547, 5626548, 5665542, 5665543, 5665544, 5665544, 5665545, 5665545, 5665546, 5665547, 5873497, 6180647, 6263068, 6263069, 6263069, 6263078, 6263079, 7815473, 8025502, 8025502, 8055309, 8170553, 5132806, 5132808, 5216293, 5216294, 5216294, 5216295, 5216295, 5216296, 5216296, 5216297, 5216299, 5216301, 5216303, 5216303, 5216309, 5216317, 5530511, 5626544, 5626545, 5665544, 5665546, 5665898, 6039874, 6733586, 7085633, 5132807, 5132809, 5216294, 5216296, 5216296, 5216297, 5216299, 5216306, 5216308, 5299155, 5334787, 5626544, 5216297, 5626545, 5216297, 5626545, 5216297, 5216297, 5626546, 5626546, 5351629, 5626549, 5178203, 5178221, 5178238, 5239020, 5218936, 5259366, 5299781, 5299791, 5299782, 5299797, 5299783, 5299783, 5299798, 5299799, 5299783, 5299783, 5299784, 5299797, 5299797, 5299783, 5299784, 5299784, 5299785, 5299785, 5299796, 5299798, 5299800, 5299801, 5299801, 5299784, 5299785, 5299798, 5299799, 5299801, 5299801, 5299803, 5299785, 5299786, 5299786, 5299787, 5299788, 5299788, 5299789, 5299790, 5299792, 5299792, 5299793, 5299793, 5299794, 5299794, 5299795, 5299795, 5299796, 5299797, 5299797, 5299798, 5299798, 5299799, 5299799, 5299800, 5299800, 5299801, 5299801, 5299802, 5299802, 5299824, 5299786, 5299787, 5299787, 5299789, 5299790, 5299791, 5299792, 5299792, 5299793, 5299793, 5299794, 5299795, 5299797, 5299797, 5299798, 5299798, 5299799, 5299799, 5299800, 5299800, 5299801, 5299801, 5299802, 5299802, 5299803, 5299805, 5299807, 5299794, 5299799, 5299800, 5299802, 5299789, 5299794, 5299801, 5299802, 5299818, 5299824, 5299791, 5299793, 5299793, 5299794, 5299800, 5299826, 5299827, 5299793, 5299827, 5299796, 5299804, 5299796, 5299796, 5299797, 5299828, 5299796, 5299797, 5299805, 5299810, 5299829, 5299829, 5299797, 5299798, 5299805, 5299806, 5299798, 5299799, 5299831, 5299799, 5299815, 5299831, 5299799, 5299800, 5299807, 5299800, 5299801, 5299801, 5299802, 5299802, 5299804, 5299807, 5299808, 5299808, 5299812, 5299833, 5299801, 5299802, 5299802, 5299803, 5299803, 5299804, 5299804, 5299805, 5299805, 5299806, 5299806, 5299807, 5299808, 5299809, 5299832, 5299833, 5299833, 5299802, 5299803, 5299803, 5299804, 5299804, 5299805, 5299805, 5299810, 5299833, 5299803, 5299804, 5299804, 5299805, 5299806, 5299809, 5299809, 5299810, 5299834, 5299804, 5299805, 5299805, 5299806, 5299807, 5299809, 5299811, 5299816, 5299834, 5299834, 5299805, 5299806, 5299806, 5299807, 5299808, 5299810, 5299810, 5299835, 5299835, 5299806, 5299807, 5299807, 5299808, 5299808, 5299809, 5299809, 5299812, 5299817, 5299807, 5299808, 5299808, 5299809, 5299809, 5299810, 5299812, 5299813, 5299808, 5299809, 5299809, 5299810, 5299810, 5299811, 5299812, 5299812, 5299814, 5299817, 5710045, 5299809, 5299810, 5299810, 5299811, 5299811, 5299812, 5299813, 5299814, 5299837, 5299810, 5299811, 5299811, 5299812, 5299812, 5299813, 5299814, 5299815, 5299815, 5299816, 5299837, 5710046, 5299811, 5299812, 5299812, 5299813, 5299813, 5299814, 5299814, 5299818, 5299838, 5665361, 5710046, 5749046, 5749047, 5749047, 5749048, 5749049, 5957000, 6346571, 6346572, 5299812, 5299813, 5299813, 5299814, 5299814, 5299816, 5299816, 5299817, 5299817, 5299824, 5299839, 5710047, 5710048, 5749047, 5749050, 5299813, 5299814, 5299814, 5299815, 5299816, 5299817, 5299817, 5299818, 5299820, 5710047, 5749049, 5299814, 5299815, 5299815, 5299816, 5299816, 5299817, 5299817, 5299818, 5299818, 5299819, 5299820, 5299821, 5299839, 5299840, 5710048, 6346574, 5299815, 5299816, 5299816, 5299817, 5299817, 5299818, 5299819, 5299820, 5299825, 5299827, 5299839, 5299840, 5299841, 5710048, 5710050, 5710053, 5749047, 5749048, 5749049, 5749050, 5749051, 6346574, 8138816, 5299816, 5299817, 5299817, 5299818, 5299818, 5299819, 5299820, 5299820, 5299821, 5299821, 5299840, 5299841, 5299841, 5361179, 5689827, 5710049, 5710053, 5710053, 5710054, 5710055, 5710055, 5749049, 5749050, 5749050, 6346575, 7898979, 8109007, 5299817, 5299818, 5299818, 5299819, 5299819, 5299820, 5299820, 5299821, 5299821, 5299823, 5299824, 5299832, 5299840, 5299841, 5299841, 5299842, 5710049, 5710049, 5710051, 5710052, 5710053, 5710055, 5749049, 5749050, 5749051, 5749052, 5749053, 6346583, 8109008, 8138815, 8254059, 8679500, 5299818, 5299819, 5299819, 5299820, 5299821, 5299822, 5299824, 5299825, 5299825, 5299833, 5299842, 5710050, 5710054, 5749052, 5749052, 6346575, 8109009, 5299819, 5299820, 5299820, 5299821, 5299821, 5299822, 5299822, 5299823, 5299827, 5299832, 5299841, 5299842, 5299842, 5710050, 5710051, 5710053, 5710054, 5749050, 5749052, 5749053, 5749054, 6346576, 5299820, 5299821, 5299821, 5299822, 5299822, 5299823, 5299823, 5299824, 5299825, 5299827, 5299842, 5299843, 5710051, 5710053, 5749053, 6346576, 5299821, 5299822, 5299822, 5299823, 5299823, 5299824, 5299824, 5299825, 5299832, 5299843, 5418297, 5710051, 5749054, 5299822, 5299823, 5299823, 5299824, 5299825, 5710052, 5710053, 5299823, 5299824, 5299824, 5299825, 5299826, 5299826, 5299827, 5299829, 5299844, 5299844, 5710052, 5299824, 5299825, 5299825, 5299826, 5299827, 5299828, 5299829, 5299844, 5299845, 5299825, 5299826, 5299826, 5299827, 5299827, 5299828, 5299830, 5299830, 5299844, 6346579, 5299826, 5299827, 5299827, 5299828, 5299828, 5299829, 5299829, 5299834, 5299836, 5299845, 5710056, 5299827, 5299828, 5299828, 5299829, 5299829, 5299830, 5299831, 5299832, 5299845, 5299828, 5299829, 5299829, 5299830, 5299831, 5299831, 5299846, 5299847, 5299829, 5299830, 5299831, 5299832, 5299832, 5299844, 5299846, 5299847, 5299847, 5299830, 5299831, 5299831, 5299832, 5299832, 5299835, 5299845, 5299847, 5299848, 5299831, 5299832, 5299833, 5299833, 5299847, 5299832, 5299833, 5299833, 5299834, 5299840, 5299848, 5299848, 5299849, 5710057, 5299833, 5299834, 5299848, 5299849, 5299834, 5299835, 5299849, 5299849, 5299850, 5299835, 5299841, 5299849, 5299850, 5299837, 5299850, 5299850, 5299851, 5299848, 5299850, 5299851, 5710060, 5299852, 5299853, 5710062, 5749064, 5299855, 5710067, 5299857, 5710069, 7535750, 5299862, 5710071, 5299862, 5299863, 6346597, 5299864, 5299865, 5710073, 5749073, 6346598, 8254082, 5299865, 5299866, 5689852, 5710073, 5710074, 5710075, 5749073, 5749074, 5749075, 5749075, 5749078, 8109032, 5299866, 5299867, 5418320, 5418322, 5689852, 5710073, 5710074, 5710074, 5710075, 5710076, 5710077, 5710077, 5710078, 5710078, 5710079, 5710079, 5710080, 5749070, 5749071, 5749071, 5749072, 5749073, 5749073, 5749074, 5749074, 5749075, 5749075, 5749076, 5749076, 5749077, 5749078, 5957027, 5989291, 6123403, 6264179, 6264182, 6264183, 6346599, 6346600, 6346622, 7273178, 7899004, 8109032, 8109033, 8138840, 8256842, 5299867, 5710074, 5710079, 5749072, 6346600, 6346608, 5418321, 5710076, 5749071, 5749074, 6346600, 6346601, 8109034, 5310808, 5715551, 5422553, 5771423, 5465516, 5465517, 5792906, 8336922, 5536784, 5536794, 5536790, 5536794, 5536796, 5828542, 5867543, 5828548, 5867547, 5867548, 5828552, 5570458, 5845375, 5928291, 5928387, 5928483, 6063420, 6030931, 6114617, 6079895, 6079904, 6079914, 6100116, 6139126, 6080092, 6080266, 6139309, 6120281, 6120285, 6120282, 6120283, 6120283, 6120284, 6120285, 6120285, 6120286, 6120286, 6120287, 6120288, 6120288, 6120289, 6120295, 6120296, 6120297, 6120297, 6120298, 6120298, 6120299, 6120299, 6120300, 6120300, 6120283, 6120299, 6120301, 6120284, 6120285, 6120285, 6120286, 6120286, 6120287, 6120287, 6120288, 6120289, 6120289, 6120290, 6120295, 6120296, 6120298, 6120298, 6120299, 6120299, 6120300, 6120300, 6120304, 6120286, 6120286, 6120287, 6120287, 6120288, 6120288, 6120290, 6120290, 6120297, 6120298, 6120299, 6120300, 6120301, 6120302, 6120303, 6120287, 6120299, 6120300, 6120287, 6120288, 6120289, 6120291, 6120299, 6120300, 6120300, 6120302, 6120303, 6120304, 6120304, 6120305, 6120289, 6120290, 6120291, 6120293, 6120300, 6120301, 6120301, 6120302, 6120302, 6120304, 6120304, 6120301, 6120301, 6120302, 6120305, 6120290, 6120291, 6120291, 6120292, 6120301, 6120301, 6120302, 6120302, 6120303, 6120304, 6120306, 6120306, 6120307, 6120307, 6120308, 6120308, 6120291, 6120292, 6120301, 6120302, 6120303, 6120303, 6120306, 6120307, 6120307, 6120308, 6120302, 6120303, 6120304, 6120305, 6120307, 6120307, 6120308, 6120301, 6120302, 6120307, 6120308, 6120309, 6120303, 6120304, 6120309, 6120301, 6120303, 6120303, 6120304, 6120304, 6120308, 6120310, 6120311, 6120304, 6120306, 6120305, 6120308, 6120311, 6756828, 6120310, 6120312, 6120311, 6120311, 6120312, 6120312, 6120313, 6120313, 6120314, 6120314, 6120315, 6120315, 6120316, 6120317, 6120319, 6159297, 6159300, 8519256, 8549064, 6120313, 6120314, 6120314, 6120315, 6120316, 6120318, 6937049, 6120314, 6120315, 6120315, 6120316, 6120316, 6120318, 6120320, 6120320, 6159295, 6159296, 6159298, 6159300, 6316188, 6674402, 6756830, 6756831, 8519256, 8519256, 8519257, 6120315, 6120316, 6120316, 6120317, 6120318, 6120320, 6159298, 6159299, 6159299, 6159300, 6756824, 8519256, 6120316, 6120317, 6120317, 6120318, 6120319, 6120319, 6120320, 6120320, 6120321, 6120322, 6159297, 6159299, 6159299, 6159300, 6159300, 6159301, 6159301, 6674411, 6756825, 8309228, 8549065, 6120317, 6120318, 6120318, 6120319, 6120319, 6120320, 6120320, 6120321, 6120321, 6120322, 6159299, 6159300, 6159301, 6159301, 6159302, 6159302, 6159305, 6568230, 6756824, 6756825, 6120318, 6120319, 6120319, 6120320, 6120320, 6120321, 6120322, 6120324, 6159300, 6159300, 6159301, 6159301, 6159302, 6159302, 6159303, 6367253, 6756826, 8309230, 8519259, 6120319, 6120320, 6120320, 6120321, 6120321, 6120322, 6120322, 6120323, 6159298, 6159300, 6159301, 6159301, 6159302, 6159302, 6159303, 6159303, 6316190, 6568229, 6756825, 6756825, 6756826, 7183182, 7683399, 8309230, 8519260, 8664310, 6120321, 6159299, 6159299, 6159301, 6159301, 6159302, 6159302, 6756827, 6756836, 6120321, 6120322, 6120323, 6120323, 6120325, 6159301, 6159302, 6159303, 6159303, 6756826, 6756827, 6120322, 6120323, 6120324, 6159300, 6159302, 6159302, 6159303, 6159304, 6159304, 6159305, 6159305, 6756826, 6756828, 6756850, 8519261, 6120323, 6120324, 6120325, 6143090, 6159302, 6159302, 6159303, 6159303, 6159304, 6159304, 6367256, 6756827, 6756828, 8519261, 8522197, 6120325, 6120325, 6159301, 6159303, 6159304, 6159304, 6674422, 6756829, 6756831, 7579392, 8549069, 6120325, 6120327, 6159301, 6159302, 6159303, 6159303, 6159304, 6159304, 6756828, 6756829, 6756837, 7683407, 6120327, 6159304, 6159304, 6159306, 6756830, 8519263, 6120327, 6159304, 6159305, 6159307, 6159308, 6756830, 9089754, 9835704, 6159305, 6159306, 6756831, 6159306, 6159306, 6756832, 6165864, 6165869, 6182081, 8689850, 6198278, 6198279, 6198279, 6198281, 6198280, 6198280, 6198280, 6198281, 6198281, 6198283, 6198280, 6198281, 6198282, 6198281, 6198283, 6198281, 6198282, 6198298, 6198282, 6198283, 6198283, 6198284, 6198284, 6198285, 6198296, 6198297, 6198298, 6198298, 6198299, 6198299, 6198301, 6198283, 6198284, 6198284, 6198285, 6198286, 6198288, 6198295, 6198296, 6198298, 6198299, 6198299, 6198300, 6198284, 6198285, 6198285, 6198286, 6198286, 6198298, 6198299, 6198299, 6198300, 6198300, 6198301, 6198301, 6198285, 6198286, 6198287, 6198289, 6198295, 6198299, 6198299, 6198300, 6198300, 6198301, 6198301, 6198302, 6198286, 6198287, 6198288, 6198298, 6198299, 6198300, 6198300, 6198301, 6198301, 6198302, 6198302, 6198303, 6198287, 6198288, 6198290, 6198298, 6198300, 6198300, 6198301, 6198301, 6198302, 6198302, 6198303, 6198288, 6198299, 6198299, 6198300, 6198301, 6198302, 6198302, 6198303, 6198304, 6198289, 6198298, 6198302, 6198302, 6198303, 6198303, 6198304, 6198304, 6198301, 6198303, 6198303, 6198304, 6198305, 6198306, 6198305, 6198306, 6198310, 6198312, 6198313, 6198312, 6198312, 6198313, 6198313, 6198313, 6198313, 6198314, 6198314, 6198315, 6795823, 6198314, 6198315, 6198315, 6198316, 6198317, 6795824, 6795830, 6795831, 8558256, 8558256, 6198315, 6198316, 6198317, 6406252, 6572627, 6607232, 6713403, 6795823, 6795831, 6795833, 8558257, 8703308, 6198316, 6198317, 6198317, 6198318, 6402647, 6406252, 6572628, 6713402, 6713403, 6713403, 6713404, 6795823, 6795824, 6795824, 6795825, 6795831, 6795831, 6795832, 6795833, 6795834, 6877219, 7222183, 7722398, 7722401, 7722402, 7722403, 7966091, 7984984, 8348229, 8558257, 8558258, 8558259, 8588062, 8588065, 8588066, 8588066, 8703308, 6198317, 6198318, 6198318, 6198320, 6198992, 6355189, 6402649, 6402651, 6406253, 6438516, 6542763, 6572625, 6572628, 6607228, 6607229, 6607230, 6607232, 6713402, 6713403, 6713403, 6713404, 6713405, 6713408, 6713417, 6713418, 6795824, 6795824, 6795825, 6795825, 6795829, 6795832, 6795833, 6795833, 6795834, 6795834, 6795835, 6886927, 7222178, 7222181, 7257262, 7618389, 7984984, 7984984, 8348229, 8348229, 8348230, 8558258, 8558258, 8558259, 8558259, 8558260, 8588064, 8588065, 8588065, 8588066, 8588066, 8588068, 8703309, 8703315, 6198318, 6198319, 6198320, 6406249, 6533954, 6607233, 6713402, 6795824, 6795825, 6795825, 6795826, 6795835, 7966171, 7966172, 7984981, 8558259, 8588066, 8703309, 6198319, 6198320, 6198320, 6402650, 6406254, 6713403, 6713404, 6713404, 6713419, 6795813, 6795825, 6795826, 6795834, 6795835, 7722404, 8348230, 8558259, 6355191, 6406255, 6572630, 6607231, 6607234, 6713405, 6795825, 6795826, 6795826, 6795827, 6795835, 8558260, 6406255, 6795826, 6795826, 6795827, 6795828, 6199003, 6796182, 6199679, 6406938, 6512071, 6512072, 6512072, 6512073, 6512073, 6764112, 6952706, 6952707, 6952708, 8715141, 6952707, 7073504, 6606996, 6606997, 6606999, 6607000, 6607001, 7000179, 7000181, 7000182, 6610601, 7000174, 6776978, 7000175, 6614195, 6614196, 6614201, 6614201, 6614202, 6614202, 6780571, 7003780, 7003773, 8192929, 8556177, 6614214, 6921352, 7003772, 7003781, 7089350, 8192932, 8556179, 8766206, 8766207, 8766207, 6921353, 7003774, 7003781, 7123508, 7930351, 8174121, 6678725, 6678828, 6678829, 6678933, 6678933, 6847541, 7036139, 6869601, 7131472, 6887224, 7140286, 6946952, 6946952, 6946940, 6946955, 6946954, 6946955, 6946956, 7087729, 6981559, 7170150, 7170152, 8096729, 8932584, 8932585, 8962391, 7016154, 7016156, 7016157, 7016158, 7016158, 7016159, 7016160, 7016163, 7016161, 7016162, 7204759, 7204752, 7204753, 7204760, 7122337, 7204754, 8131333, 7228509, 7228512, 7228503, 7228506, 7228489, 7228515, 7228519, 7228504, 7228505, 7228507, 7228508, 7228508, 7228510, 7228518, 7228508, 7228509, 7228511, 7228510, 7228510, 7228514, 7228514, 7228504, 7228519, 7228524, 7228519, 7228525, 7228523, 7228518, 7228530, 7228519, 7228534, 8863332, 9073359, 7228524, 7310926, 7310926, 7310927, 7310928, 8237503, 9073360, 7228533, 7228536, 7310929, 8500088, 7310929, 7310930, 7310930, 9073363, 7737286, 8133494, 9073364, 7430665, 8500090, 7310932, 7310935, 7310935, 7310935, 7693587, 7310936, 7310937, 7310938, 7310939, 7737296, 7310941, 8500100, 9073374, 8500101, 7393320, 7393331, 7393332, 7393332, 7393332, 7393333, 7393335, 7393348, 7393349, 7393353, 7393354, 7393333, 7393348, 7393350, 7393353, 7393353, 7393334, 7393335, 7393335, 7393336, 7393337, 7393338, 7393338, 7393339, 7393340, 7393340, 7393341, 7393341, 7393342, 7393342, 7393343, 7393343, 7393346, 7393347, 7393347, 7393348, 7393348, 7393349, 7393349, 7393350, 7393350, 7393351, 7393351, 7393352, 7393352, 7393353, 7393353, 7393354, 7393355, 7393355, 7393338, 7393341, 7393342, 7393342, 7393349, 7393349, 7393350, 7393350, 7393340, 7393344, 7393351, 7393341, 7393344, 7393356, 7393356, 7393360, 7393356, 7393347, 7393353, 7393362, 7393347, 7393353, 7393356, 7393346, 7393346, 7393348, 7393356, 7393358, 7393364, 7393349, 7393356, 7393356, 7393364, 7393364, 7393347, 7393348, 7393348, 7393349, 7393356, 7393357, 7393364, 7393364, 7393349, 7393350, 7393350, 7393355, 7393356, 7393356, 7393357, 7393359, 7393360, 7393360, 7393364, 7393365, 7393365, 7393349, 7393350, 7393351, 7393353, 7393354, 7393356, 7393356, 7393357, 7393357, 7393358, 7393365, 7393365, 7393366, 7393351, 7393351, 7393355, 7393356, 7393356, 7393357, 7393357, 7393358, 7393358, 7393359, 7393359, 7393365, 7393366, 7393366, 7393356, 7393356, 7393357, 7393358, 7393358, 7393361, 7393365, 7393366, 7393366, 7393357, 7393358, 7393360, 7393361, 7393362, 7393365, 7393367, 7393367, 7393354, 7393358, 7393359, 7393359, 7393360, 7393368, 7393360, 7393370, 7393362, 7393363, 9185584, 7393362, 7393363, 7393363, 7393364, 7393364, 7393363, 7393363, 7393364, 7393365, 7393366, 7393363, 7393364, 7393364, 7393365, 7393365, 7393364, 7393365, 7393365, 7393366, 7393366, 7393367, 7393368, 7393369, 7393373, 7819704, 8319926, 8319927, 8701567, 8945753, 8945754, 9155781, 9155782, 9185588, 9300832, 7393365, 7393366, 7393366, 7393367, 7393367, 7393368, 7393368, 7393369, 7393369, 7393373, 7393373, 7513082, 8319926, 8563695, 8945753, 8945753, 8945755, 9185589, 7393366, 7393367, 7393367, 7393368, 7393368, 7393369, 7393369, 7393371, 7393373, 7393374, 7393374, 7725958, 7819702, 7823014, 8319926, 8431600, 8945754, 8945755, 9155782, 9155783, 9185588, 9185589, 9303592, 7393367, 7393368, 7393368, 7393369, 7393369, 7393370, 7393370, 7393371, 7393371, 7393372, 7393374, 7675688, 8021963, 8945755, 9155783, 9155785, 9300840, 7393368, 7393369, 7393369, 7393370, 7393370, 7393371, 7393371, 7393372, 7393374, 7393375, 7393375, 7512929, 7573575, 7819706, 8215914, 8319928, 8319929, 8319929, 8563697, 8582509, 8945754, 8945754, 8945755, 8945756, 8945757, 9155784, 9185591, 9185592, 7393369, 7393370, 7393370, 7393371, 7393371, 7393372, 7393372, 7393373, 7393375, 7393375, 7393376, 7819704, 8245142, 8319928, 8319929, 8319930, 8582503, 8582510, 8945755, 8945755, 9155784, 9155784, 9155786, 9185591, 9185592, 7393370, 7393371, 7393371, 7393372, 7393372, 7393373, 7393373, 7393374, 7393375, 7393376, 7393394, 7819707, 8215915, 8319928, 8448465, 8945755, 8945756, 9155785, 9155786, 9185592, 7393371, 7393372, 7393372, 7393373, 7393373, 7393375, 7393376, 7393376, 7393377, 7393380, 7819705, 8319928, 8432625, 8582511, 8582511, 8945756, 8945757, 9155785, 9155785, 9185592, 7393372, 7393373, 7393373, 7393374, 7393376, 7393377, 7393377, 7478929, 7819686, 7819708, 8319929, 8319930, 8582511, 8945756, 8945757, 9155785, 9155786, 9185593, 7393373, 7393374, 7393374, 7393375, 7393375, 7393376, 7393377, 7393377, 7393378, 8319930, 8319931, 8319931, 8448466, 8945757, 8945757, 9155785, 9155786, 9155786, 9155788, 9155789, 9185593, 9300837, 7393374, 7393375, 7393375, 7393376, 7393376, 7393377, 7393378, 7393378, 7819712, 8319931, 8945757, 8945758, 8945758, 9155786, 9300837, 7393375, 7393376, 7393376, 7393377, 7393378, 7393378, 7393379, 7393380, 7929278, 8582513, 8945758, 8945758, 8945759, 9185594, 9185595, 7393376, 7393378, 7393378, 7393379, 7393379, 7524877, 7819708, 7819710, 8582513, 8945758, 8945759, 9155787, 9155788, 9155789, 7393378, 7393378, 7393379, 7393379, 7393380, 8319934, 8563702, 8945759, 8945759, 9155790, 9185596, 9300839, 7393378, 7393380, 7393400, 7819709, 8945760, 9155788, 9155790, 7393379, 7393380, 7393380, 7478933, 8319934, 8945760, 8945763, 9155789, 9155791, 7393381, 8582516, 8945761, 7393381, 7393382, 7393382, 7393384, 7393385, 7393401, 7716102, 7819690, 7819710, 7975839, 7996127, 8174621, 8319933, 8319934, 8319934, 8319935, 8452329, 8563704, 8582515, 8582516, 8582516, 8945761, 8945761, 8945762, 8945764, 9155790, 9155790, 9185595, 9185597, 9185598, 9300841, 7393382, 7478934, 7512936, 7513091, 7523018, 7524880, 7819710, 7929281, 8143508, 8215921, 8319934, 8319935, 8319936, 8319936, 8582516, 8582517, 8945761, 8945761, 8945762, 8945763, 8945763, 9155790, 9155790, 9155791, 9185597, 9185597, 9185598, 9185599, 9187331, 9300841, 7393383, 7393386, 7819692, 7819711, 7819716, 8319934, 8319934, 8319935, 8319935, 8319936, 8319937, 8582515, 8582516, 8582517, 8582517, 8945761, 8945762, 8945762, 8945766, 9155790, 9155791, 9155791, 9155792, 9185598, 9185599, 9300842, 7696977, 8319936, 8945763, 8582518, 8582520, 8319937, 8945765, 9155796, 7393420, 7819733, 8035274, 8215941, 8582533, 9185618, 7556141, 9237179, 7564551, 7564556, 7564562, 7564626, 7564631, 7564702, 7564703, 7564704, 7564726, 8405627, 9031455, 9031458, 7564876, 8405713, 7575562, 7604038, 7632501, 7632502, 7632503, 7632657, 9065327, 8702084, 7632812, 7632813, 7632812, 8439654, 8439656, 8439657, 8702238, 9275512, 7634933, 9276571, 7652665, 8499861, 7656391, 7656391, 9077273, 8714028, 7753794, 7753797, 7999903, 8743917, 7958020, 7958143, 7958266, 8498368, 8000642, 8000718, 8000773, 8623656, 8038835, 8252014, 8058563, 9488388, 8158665, 8965172, 8246063, 8246051, 8246064, 8246042, 8246083, 8246076, 8246084, 8246085, 8246078, 8246086, 8246088, 9582151, 8746300, 9008881, 8746306, 8746307, 8746309, 9008887, 9008889, 9372133, 9372134, 9372134, 9372135, 9582162, 9582163, 9582163, 9582165, 9611970, 9611971, 9611971, 9729973, 8252692, 9012187, 8316275, 9617271, 8334383, 9771350, 8465191, 8771155, 9099614, 9481672, 8558309, 9738260, 8598888, 9185277, 8650570, 9211113, 8677148, 8677203, 8677272, 9587724, 8893645, 9313838, 8955885, 9101198, 9038461, 9038509, 9038527, 9038528, 9038575, 9038667, 9038601, 9038677, 9038743, 9142614, 9142616, 9405198, 9768443, 9768443, 9768444, 9978474, 10008278, 9077121, 9424393, 9096920, 9096996, 9097070, 9434363, 9246485, 9246498, 9246501, 9246486, 9246501, 9246501, 9246502, 9246487, 9246488, 9246488, 9246502, 9246502, 9246489, 9246489, 9246503, 9246503, 9246502, 9246503, 9246504, 9246504, 9246516, 9246517, 9872328, 9872329, 10082358, 10082359, 10085293, 10227409, 9490270, 9490272, 9509079, 9509083, 9509084, 9509084, 9509085, 9872329, 9872329, 9872330, 9872331, 10082357, 10082358, 10082358, 10082359, 10082359, 10082360, 10112166, 10112166, 9347057, 9408451, 9469845, 9601938, 9601941, 9471892, 10195052, 9503574, 9503576, 10210894, 10000866, 9511331, 10214792, 9698482, 9716260, 9733876, 9733956, 9734022, 9734023, 9734034, 9734035, 9734025, 9734035, 9734026, 9734036, 9734036, 9752845, 9752846, 9752848, 9752848, 9752849, 10116093, 10116094, 10116095, 10326122, 10326123, 10326124, 10355928, 10355929, 10471173, 9771656, 9771646, 9771657, 9771659, 9771660, 9771648, 9771661, 9771662, 9771650, 9771662, 9771651, 9771652, 9771661, 9771663, 9771663, 9771664, 9771673, 10134906, 10072597, 10134907, 10134908, 10134908, 10134909, 10134909, 10185574, 10185574, 10324362, 10344937, 10344937, 10344938, 10344939, 10344939, 10374743, 10374743, 10374744, 10374744, 10489988, 10492795, 10009811, 10609076, 10373531, 10435843, 10498140, 10498141, 10498155, 10498155, 10498156, 10498141, 10498142, 10498144, 10498156, 10498156, 10498157, 10498159, 10498142, 10498143, 10498143, 10498144, 10498144, 10498145, 10498153, 10498156, 10498156, 10498157, 10498157, 10498158, 10498158, 10498159, 10498146, 10498157, 10498157, 10498158, 10498159, 10498144, 10498157, 10498158, 10498159, 10498159, 10498160, 10498157, 10498158, 10498159, 10498160, 10498159, 10498160, 10498161, 10498159, 10498160, 10498162, 10498160, 10498163, 10498161, 10498163, 10498249, 10498171, 10498172, 10708185, 10498171, 10498172, 10498174, 10708184, 10708185, 10708185, 10708186, 10708187, 10708187, 10737992, 10498172, 10498173, 10498173, 10498174, 10498174, 10498175, 10516738, 10708184, 10708185, 10708185, 10708186, 10708186, 10708187, 10708187, 10708188, 10737991, 10737992, 10737992, 10737993, 10737993, 10737994, 10853236, 10855995, 10498173, 10498175, 10531591, 10708185, 10708186, 10708186, 10708188, 10737992, 10498174, 10498175, 10498175, 10708185, 10708186, 10708186, 10708187, 10708187, 10708188, 10708189, 10737994, 10737995, 10498176, 10708187, 10708187, 10708188, 10708189, 10548824, 10708187, 10708187, 10708188, 10708188, 10708190, 10498256, 10708188, 10708188, 10737996, 10853239, 10516738, 10708189, 10708189, 10737996, 10498344, 10708275, 10708277, 10535311, 10535316, 10726761, 10756570, 10565020, 10565102, 10565183, 10771503, 10599485, 10599487, 10758848, 10758848, 10663687, 10727891, 10823056, 10877062, 10897637, 10918198, 10918198, 10918200, 10918213, 10918198, 10918199, 10918199, 10918200, 10918212, 10918213, 10918199, 10918200, 10918200, 10918201, 10918201, 10918202, 10918214, 10918214, 10918215, 10918215, 10918216, 10918200, 10918201, 10918201, 10918202, 10918202, 10918203, 10918212, 10918213, 10918213, 10918214, 10918214, 10918215, 10918215, 10918216, 10918216, 10918217, 10918217, 10918201, 10918202, 10918202, 10918203, 10918214, 10918215, 10918215, 10918216, 10918216, 10918217, 10918217, 10918202, 10918203, 10918214, 10918215, 10918216, 10918216, 10918217, 10918217, 10918218, 10918203, 10918204, 10918204, 10918214, 10918215, 10918216, 10918216, 10918217, 10918217, 10918218, 10918218, 10918204, 10918205, 10918205, 10918207, 10918214, 10918215, 10918215, 10918216, 10918216, 10918217, 10918217, 10918218, 10918218, 10918219, 10918217, 10918217, 10918218, 10918218, 10918219, 10918219, 10918220, 10918217, 10918217, 10918218, 10918218, 10918220, 10918218, 10918220, 10918227, 10918227, 10918227, 10918228, 10918229, 10918229, 10918230, 11063263, 10918228, 10918229, 10948020, 10918228, 10918229, 10918229, 10918231, 10948021, 10918229, 10918230, 10918230, 10918231, 10918231, 10948020, 10948020, 10948021, 10918230, 10918231, 10918231, 10918232, 10918232, 10948020, 10948021, 10948022, 10948022, 10948023, 11063265, 10918231, 10918232, 10918232, 10918233, 10918233, 10921151, 10948019, 10948021, 10948022, 10948022, 10948023, 10948023, 11063266, 11063277, 11922192, 10918232, 10918233, 10918233, 10948020, 10948021, 10948021, 10948022, 10948022, 10948023, 10948023, 10948024, 11063266, 11066074, 10918233, 10918234, 10918234, 10921152, 10948020, 10948022, 10948022, 10948023, 10948023, 10948024, 10948024, 10948025, 11063267, 10918234, 10918235, 10918235, 10918236, 10918237, 10921152, 10921152, 10948018, 10948021, 10948021, 10948022, 10948023, 10948023, 10948024, 10948024, 10948025, 10948025, 10948026, 11063267, 11063328, 11063340, 10918235, 10918236, 10948023, 10948023, 10948024, 10948024, 10948025, 10948027, 10918238, 10948022, 10948023, 10948024, 10948024, 10948025, 10948025, 10948026, 10948028, 11063268, 10948025, 10948026, 10948026, 11063271, 10924079, 10924082, 10924083, 10924082, 10924083, 10924083, 10924084, 10924195, 10950953, 10950954, 10950954, 10950953, 10950955, 10950954, 10950955, 10950955, 10950954, 10924311, 10951066, 10977808, 10977809, 10977810, 10977827, 10977810, 10977811, 10977811, 10977812, 10977814, 10977812, 10977812, 10977811, 10977812, 10977812, 10977813, 10977813, 10977814, 10977815, 10977827, 10977830, 10977812, 10977813, 10977813, 10977814, 10977815, 10977827, 10977827, 10977828, 10977829, 10977829, 10977830, 10977813, 10977814, 10977814, 10977826, 10977827, 10977827, 10977828, 10977829, 10977829, 10977830, 10977814, 10977815, 10977815, 10977816, 10977816, 10977817, 10977827, 10977827, 10977828, 10977828, 10977829, 10977829, 10977830, 10977830, 10977831, 10977831, 10977832, 10977832, 10977815, 10977816, 10977816, 10977817, 10977817, 10977818, 10977818, 10977819, 10977827, 10977827, 10977828, 10977828, 10977829, 10977829, 10977830, 10977830, 10977831, 10977831, 10977832, 10977832, 10977833, 10977816, 10977817, 10977817, 10977818, 10977818, 10977819, 10977820, 10977827, 10977828, 10977828, 10977829, 10977829, 10977830, 10977830, 10977831, 10977831, 10977832, 10977832, 10977833, 10977833, 10977817, 10977818, 10977818, 10977829, 10977830, 10977830, 10977831, 10977831, 10977832, 10977832, 10977833, 10977833, 10977834, 10977818, 10977819, 10977822, 10977830, 10977830, 10977831, 10977831, 10977832, 10977832, 10977833, 10977833, 10977834, 10977834, 10977819, 10977829, 10977830, 10977830, 10977831, 10977831, 10977832, 10977832, 10977833, 10977835, 10977822, 10977829, 10977830, 10977831, 10977831, 10977832, 10977832, 10977833, 10977833, 10977834, 10977834, 10977836, 10977821, 10977831, 10977832, 10977832, 10977833, 10977836, 10977832, 10977833, 10977834, 10977833, 10977833, 10977836, 10977836, 10977840, 10977841, 10977842, 10977840, 10977842, 10977843, 10977844, 11093070, 10977841, 10977842, 10977843, 10977844, 10977846, 10977842, 10977843, 10977843, 10977844, 10977844, 10977845, 10977845, 10977846, 11093071, 11095830, 10977843, 10977844, 10977844, 10977845, 10977845, 10977846, 10977847, 11093072, 10977844, 10977845, 10977845, 10977846, 10977846, 10977847, 10977847, 11093072, 11095891, 12264460, 10977845, 10977846, 10977846, 10977847, 10977847, 10977848, 10977849, 11093073, 11093117, 12264518, 10977846, 10977847, 10977847, 10977848, 10977848, 10977849, 10977850, 11093073, 11093080, 11093089, 11095832, 10977847, 10977848, 10977848, 10977849, 10977850, 10977850, 10977852, 11093074, 11093085, 11093127, 11093128, 11093136, 11093137, 11095833, 15020867, 10977848, 10977849, 10977849, 10977852, 11093074, 11093074, 11093079, 11093124, 11093140, 11095833, 11095882, 10977849, 10977850, 10977851, 10977851, 11093075, 11093081, 11093126, 11093135, 10977850, 10977851, 11093075, 11093140, 11095834, 10977852, 10977852, 10977853, 10977853, 10993209, 11093075, 11093076, 11093082, 11093087, 11093096, 11093129, 11093132, 11093144, 11095835, 12264464, 11093076, 11093077, 11093083, 11093083, 11093077, 11093078, 11093078, 11093079, 10981292, 11094803, 11008594, 11111219, 11208300, 11208301, 11208302, 11208302, 11208303, 11208303, 11208304, 11208304, 11208305, 11208305, 11208306, 11208306, 11208307, 11208307, 11208308, 11208308, 11208309, 11208310, 11208310, 11208311, 11208311, 11208312, 11208313, 11208313, 11208314, 11208315, 11208316, 11208316, 11208317, 11208318, 11208319, 11208319, 11208321, 11208344, 11208348, 11208350, 11208351, 11208304, 11208306, 11208306, 11208307, 11208307, 11208308, 11208318, 11208305, 11208308, 11208321, 11208306, 11208307, 11208308, 11208309, 11208309, 11208321, 11208307, 11208307, 11208308, 11208308, 11208309, 11208310, 11208314, 11208319, 11208320, 11208320, 11208309, 11208309, 11208309, 11208310, 11208310, 11208311, 11208319, 11208310, 11208311, 11208311, 11208312, 11208312, 11208315, 11208324, 11208312, 11208313, 11208317, 11208318, 11208321, 11208324, 11208347, 11208396, 11208314, 11208315, 11208315, 11208316, 11208316, 11208317, 11208317, 11208318, 11208318, 11208319, 11208319, 11208320, 11208321, 11208321, 11208322, 11208322, 11208323, 11208324, 11208324, 11208325, 11208326, 11208327, 11208327, 11208328, 11208329, 11208330, 11208330, 11208331, 11208332, 11208333, 11208334, 11208334, 11208335, 11208335, 11208336, 11208336, 11208337, 11208337, 11208339, 11208341, 11208342, 11208343, 11208345, 11208346, 11208349, 11208350, 11208351, 11208351, 11208353, 11208353, 11208354, 11208357, 11208357, 11208358, 11208359, 11208359, 11208360, 11208361, 11208362, 11208366, 11208376, 11208396, 11208315, 11208316, 11208318, 11208319, 11208323, 11208326, 11208336, 11208337, 11208339, 11208396, 11208317, 11208317, 11208319, 11208319, 11208324, 11208334, 11208352, 11208354, 11208358, 11208369, 11208396, 11208317, 11208318, 11208319, 11208320, 11208321, 11208322, 11208323, 11208323, 11208324, 11208324, 11208325, 11208327, 11208328, 11208329, 11208330, 11208334, 11208338, 11208339, 11208354, 11208372, 11208384, 11208396, 11208319, 11208323, 11208329, 11208333, 11208338, 11208348, 11208359, 11208319, 11208320, 11208320, 11208321, 11208325, 11208355, 11208321, 11208321, 11208324, 11208337, 11208347, 11208354, 11208354, 11208361, 11208393, 11208396, 11208322, 11208396, 12379687, 11208322, 11208323, 11208324, 11208330, 11208340, 11208348, 11208355, 11208357, 11208323, 11208324, 11208324, 11208325, 11208325, 11208326, 11208327, 11208327, 11208328, 11208329, 11208330, 11208330, 11208331, 11208332, 11208333, 11208333, 11208335, 11208336, 11208337, 11208338, 11208339, 11208340, 11208341, 11208342, 11208343, 11208344, 11208346, 11208346, 11208347, 11208348, 11208350, 11208353, 11208357, 11208363, 11208370, 11208375, 11208380, 11208396, 11211116, 11211121, 11211123, 11633752, 11208324, 11208325, 11208328, 11208342, 11208397, 11208325, 11208326, 11208330, 11208333, 11208344, 11208326, 11208327, 11208327, 11208328, 11208329, 11208330, 11208331, 11208332, 11208333, 11208338, 11208343, 11208345, 11208378, 11208382, 11208396, 11208327, 11208346, 11208382, 11208328, 11208330, 11208365, 11208396, 11208330, 11208330, 11208332, 11208333, 11208333, 11208335, 11208337, 11208342, 11208347, 11208354, 11208355, 11208359, 11208360, 11208364, 11208396, 11208331, 11208332, 11208335, 11208361, 11208331, 11208333, 11208334, 11208347, 11208359, 11208368, 11208373, 11208332, 11208333, 11208333, 11208334, 11208335, 11208336, 11208336, 11208341, 11208342, 11208342, 11208344, 11208345, 11208346, 11208348, 11208350, 11208356, 11208359, 11208359, 11208360, 11208362, 11208364, 11208367, 11208371, 11208380, 11208396, 11208334, 11208351, 11208367, 11208334, 11208335, 11208336, 11208351, 11208335, 11208336, 11208336, 11208347, 11208352, 11208363, 11208366, 11208371, 11208396, 11208336, 11208337, 11208338, 11208396, 11208338, 11208339, 11208339, 11208340, 11208342, 11208345, 11208346, 11208347, 11208349, 11208349, 11208350, 11208351, 11208353, 11208353, 11208356, 11208357, 11208358, 11208359, 11208360, 11208363, 11208365, 11208369, 11208370, 11208381, 11208396, 11208339, 11208340, 11208340, 11208343, 11208348, 11208349, 11208358, 11208366, 11208369, 11208370, 11208396, 11208341, 11208342, 11208342, 11208343, 11208343, 11208344, 11208344, 11208345, 11208346, 11208347, 11208348, 11208348, 11208349, 11208350, 11208351, 11208351, 11208352, 11208353, 11208355, 11208355, 11208357, 11208359, 11208359, 11208360, 11208360, 11208361, 11208362, 11208363, 11208364, 11208364, 11208366, 11208368, 11208368, 11208369, 11208370, 11208371, 11208372, 11208372, 11208373, 11208379, 11208390, 11208390, 11208394, 11208396, 11208342, 11208343, 11208343, 11208348, 11208350, 11208366, 11208367, 11208343, 11208345, 11208345, 11208346, 11208348, 11208351, 11208352, 11208361, 11208396, 11208344, 11208345, 11208345, 11208346, 11208346, 11208347, 11208347, 11208348, 11208348, 11208349, 11208350, 11208351, 11208351, 11208352, 11208352, 11208354, 11208355, 11208356, 11208358, 11208358, 11208359, 11208360, 11208363, 11208363, 11208365, 11208368, 11208369, 11208371, 11208377, 11208378, 11208380, 11208396, 11208396, 11208346, 11208349, 11208346, 11208347, 11208349, 11208361, 11208368, 11208347, 11208348, 11208348, 11208353, 11208355, 11208356, 11208365, 11208381, 11208349, 11208349, 11208350, 11208351, 11208353, 11208356, 11208370, 11208371, 11208395, 11208398, 11208413, 11208349, 11208352, 11208355, 11208356, 11208369, 11208388, 11208394, 11208396, 11208400, 11208351, 11208354, 11208355, 11208357, 11208366, 11208367, 11208368, 11208371, 11208380, 11208389, 11208396, 11208363, 11208364, 11208371, 11208373, 11208378, 11208352, 11208358, 11208364, 11208366, 11208386, 11208354, 11208354, 11208356, 11208356, 11208357, 11208358, 11208358, 11208363, 11208365, 11208366, 11208370, 11208372, 11208379, 11208399, 11208360, 11208365, 11208396, 11211086, 11208355, 11208357, 11208357, 11208360, 11208373, 11208396, 11208397, 11208357, 11208359, 11208360, 11208363, 11208364, 11208366, 11208374, 11208380, 11208385, 11208392, 11208408, 11208363, 11208379, 11208358, 11208359, 11208360, 11208361, 11208361, 11208363, 11208369, 11208370, 11208373, 11208375, 11208380, 11208393, 11208399, 11208403, 11208405, 11208418, 11208361, 11208362, 11208364, 11208368, 11208369, 11208371, 11208372, 11208373, 11208374, 11208376, 11208379, 11208414, 11208361, 11208362, 11208364, 11208368, 11208368, 11208371, 11208373, 11208374, 11208375, 11208376, 11208377, 11208380, 11208383, 11208388, 11208399, 11208402, 11208404, 11208361, 11208362, 11208363, 11208365, 11208367, 11208371, 11208376, 11208378, 11208389, 11208393, 11208394, 11208399, 11208405, 11208420, 11208365, 11208367, 11208375, 11208377, 11208400, 11208377, 11208380, 11208400, 11208364, 11208366, 11208370, 11208372, 11208375, 11208378, 11208380, 11208381, 11208382, 11208384, 11208393, 11208396, 11208401, 11208408, 11208367, 11208368, 11208368, 11208369, 11208370, 11208372, 11208372, 11208374, 11208377, 11208378, 11208379, 11208384, 11208385, 11208393, 11208395, 11208396, 11208398, 11208402, 11208403, 11208405, 11208370, 11208370, 11208423, 11208369, 11208370, 11208371, 11208372, 11208373, 11208374, 11208374, 11208375, 11208376, 11208377, 11208378, 11208379, 11208380, 11208380, 11208382, 11208385, 11208390, 11208394, 11208395, 11208397, 11208398, 11208400, 11208403, 11208415, 11208423, 11208372, 11208381, 11208386, 11208389, 11208389, 11208424, 11208409, 11208425, 11208382, 11208385, 11208387, 11208405, 11208405, 11208382, 11208396, 11208400, 11208376, 11208377, 11208378, 11208383, 11208384, 11208387, 11208388, 11208389, 11208398, 11208401, 11208375, 11208381, 11208406, 11208377, 11208378, 11208381, 11208382, 11208385, 11208389, 11208393, 11208397, 11208412, 11208415, 11208378, 11208380, 11208381, 11208381, 11208382, 11208383, 11208384, 11208389, 11208394, 11208398, 11208414, 11208385, 11208394, 11208396, 11208382, 11208383, 11208385, 11208388, 11208396, 11208397, 11208408, 11208414, 11208384, 11208385, 11208386, 11208387, 11208389, 11208392, 11208392, 11208400, 11208404, 11208425, 11208383, 11208386, 11208395, 11208398, 11208404, 11208384, 11208390, 11208405, 11208384, 11208385, 11208386, 11208387, 11208389, 11208394, 11208396, 11208396, 11208410, 11208431, 11208388, 11208399, 11208387, 11208392, 11208408, 11208388, 11208389, 11208390, 11208392, 11208392, 11208395, 11208396, 11208397, 11208398, 11208402, 11208388, 11208388, 11208389, 11208390, 11208391, 11208391, 11208393, 11208394, 11208397, 11208397, 11208398, 11208399, 11208401, 11208403, 11208405, 11208406, 11208407, 11208415, 11208415, 11208418, 11208388, 11208390, 11208394, 11208433, 11208390, 11208390, 11208392, 11208393, 11208394, 11208394, 11208395, 11208396, 11208396, 11208397, 11208399, 11208403, 11208405, 11208408, 11208413, 11208413, 11208414, 11208434, 11208396, 11208402, 11208415, 11208425, 11208396, 11208399, 11208410, 11208412, 11208414, 11208415, 11208429, 11208393, 11208394, 11208395, 11208396, 11208396, 11208397, 11208397, 11208399, 11208401, 11208401, 11208402, 11208403, 11208404, 11208404, 11208405, 11208406, 11208410, 11208411, 11208411, 11208412, 11208414, 11208415, 11208417, 11208417, 11208418, 11208426, 11208429, 11208430, 11208431, 11208435, 11208435, 11208410, 11208422, 11208395, 11208395, 11208396, 11208397, 11208397, 11208398, 11208398, 11208399, 11208399, 11208400, 11208405, 11208416, 11208417, 11208418, 11208419, 11208397, 11208398, 11208401, 11208405, 11208417, 11208424, 11208428, 11208433, 11208399, 11208401, 11208402, 11208407, 11208427, 11208400, 11208401, 11208403, 11208432, 11208399, 11208400, 11208401, 11208402, 11208402, 11208403, 11208403, 11208405, 11208405, 11208406, 11208411, 11208413, 11208418, 11208420, 11208421, 11208424, 11208425, 11208439, 11208400, 11208401, 11208402, 11208402, 11208403, 11208403, 11208404, 11208406, 11208406, 11208409, 11208410, 11208411, 11208414, 11208415, 11208416, 11208421, 11208432, 11208439, 11208439, 11208401, 11208402, 11208403, 11208410, 11208411, 11208413, 11208414, 11208417, 11208426, 11208439, 11208440, 11208402, 11208403, 11208403, 11208404, 11208405, 11208405, 11208406, 11208406, 11208407, 11208408, 11208408, 11208410, 11208410, 11208411, 11208412, 11208415, 11208416, 11208420, 11208420, 11208422, 11208423, 11208427, 11208428, 11208434, 11208435, 11208437, 11208440, 11208404, 11208405, 11208405, 11208406, 11208407, 11208408, 11208412, 11208413, 11208414, 11208415, 11208427, 11208436, 11208406, 11208407, 11208408, 11208409, 11208410, 11208412, 11208413, 11208416, 11208417, 11208418, 11208419, 11208428, 11208406, 11208408, 11208414, 11208416, 11208421, 11208422, 11208424, 11208427, 11208428, 11208430, 11208406, 11208407, 11208411, 11208412, 11208413, 11208414, 11208417, 11208418, 11208425, 11208429, 11208430, 11208409, 11208410, 11208410, 11208411, 11208412, 11208414, 11208415, 11208416, 11208417, 11208419, 11208422, 11208423, 11208429, 11208430, 11208431, 11208436, 11208442, 11208412, 11208414, 11208415, 11208421, 11208423, 11208424, 11208428, 11208430, 11208431, 11208409, 11208410, 11208418, 11208424, 11208430, 11208432, 11208415, 11208419, 11208421, 11208424, 11208426, 11208428, 11208431, 11208432, 11208435, 11208444, 11208411, 11208412, 11208415, 11208418, 11208419, 11208424, 11208430, 11208431, 11208444, 11208416, 11208420, 11208425, 11208425, 11208429, 11208432, 11208436, 11208418, 11208420, 11208426, 11208431, 11208432, 11208434, 11208415, 11208416, 11208422, 11208426, 11208426, 11208431, 11208433, 11208434, 11208422, 11208424, 11208427, 11208430, 11208439, 11208416, 11208417, 11208419, 11208422, 11208427, 11208432, 11208434, 11208417, 11208420, 11208422, 11208429, 11208433, 11208434, 11208439, 11208423, 11208425, 11208428, 11208428, 11208429, 11208439, 11208444, 11208420, 11208421, 11208422, 11208425, 11208428, 11208429, 11208435, 11208440, 11208441, 11208444, 11208421, 11208424, 11208436, 11208424, 11208426, 11208429, 11208430, 11208432, 11208425, 11208427, 11208430, 11208433, 11208434, 11208437, 11208438, 11208446, 11208425, 11208430, 11208433, 11208436, 11208437, 11208445, 11208446, 11208426, 11208431, 11208434, 11208434, 11208438, 11208440, 11208447, 11208432, 11208433, 11208439, 11208443, 11208439, 11208428, 11208429, 11208430, 11208430, 11208433, 11208433, 11208434, 11208435, 11208436, 11208438, 11208440, 11208440, 11208441, 11208444, 11208449, 11208450, 11208451, 11208452, 11208452, 11208453, 11208453, 11208430, 11208430, 11208434, 11208437, 11208441, 11208442, 11208434, 11208434, 11208435, 11208435, 11208437, 11208441, 11208450, 11208455, 11208435, 11208435, 11208440, 11208442, 11208447, 11208449, 11208451, 11208455, 11208441, 11208442, 11208451, 11208453, 11208456, 11208439, 11208443, 11208436, 11208438, 11208457, 11208438, 11208439, 11208439, 11208440, 11208441, 11208442, 11208442, 11208443, 11208445, 11208446, 11208447, 11208448, 11208449, 11208451, 11208452, 11208454, 11208454, 11208457, 11208457, 11208458, 11208458, 11208440, 11208440, 11208441, 11208441, 11208442, 11208444, 11208445, 11208447, 11208450, 11208451, 11208453, 11208454, 11208456, 11208458, 11208459, 11208441, 11208441, 11208442, 11208443, 11208444, 11208446, 11208446, 11208447, 11208450, 11208453, 11208455, 11208459, 11633811, 11208448, 11208451, 11208460, 11208444, 11208445, 11208447, 11208448, 11208451, 11208460, 11208444, 11208447, 11208452, 11208458, 11208461, 11208445, 11208446, 11208448, 11208454, 11208457, 11208458, 11208461, 11208448, 11208451, 11208446, 11208447, 11208449, 11208450, 11208456, 11208458, 11208462, 11208448, 11208449, 11208448, 11208450, 11208449, 11208450, 11208450, 11208452, 11208459, 11208450, 11208451, 11208451, 11208465, 11208452, 11208453, 11208453, 11208455, 11208455, 11208456, 11208456, 11208458, 11208460, 11208461, 11208461, 11208462, 11208464, 11208465, 11208465, 11208470, 11208472, 11211135, 11211184, 11208453, 11208454, 11208457, 11208466, 11208454, 11208455, 11208456, 11208456, 11208457, 11208458, 11208459, 11208461, 11208462, 11208462, 11208465, 11208466, 11208467, 11208470, 11208473, 11211185, 11225419, 12379763, 11208456, 11208457, 11208457, 11208461, 11208457, 11208468, 11208458, 11208459, 11208460, 11208461, 11208462, 11208464, 11208464, 11208467, 11208468, 11208470, 11208471, 11208472, 11208473, 11208473, 11208474, 11208475, 11208460, 11208464, 11208469, 11208475, 11208460, 11208461, 11208462, 11208463, 11208464, 11208464, 11208465, 11208468, 11208469, 11208470, 11208470, 11208471, 11208473, 11208474, 11208475, 11208476, 11211191, 11633821, 11208464, 11208470, 11208477, 11208472, 11208464, 11208465, 11208467, 11208468, 11208468, 11208469, 11208470, 11208471, 11208471, 11208472, 11208474, 11208476, 11208476, 11208478, 11208466, 11208467, 11208470, 11208474, 11208467, 11208468, 11208468, 11208470, 11208471, 11208472, 11208473, 11208477, 11208479, 11208479, 11208469, 11208472, 11208473, 11208473, 11208475, 11208469, 11208470, 11208471, 11208471, 11208473, 11208473, 11208474, 11208475, 11208478, 11208479, 11208480, 11208481, 11211144, 11211192, 11208472, 11208474, 11208475, 11208481, 11208481, 11208475, 11208477, 11208474, 11208475, 11208475, 11208476, 11208482, 11208482, 11211146, 11208475, 11208477, 11208476, 11208477, 11208477, 11208478, 11208484, 11211196, 11208478, 11208479, 11208480, 11208481, 11208481, 11208482, 11208483, 11208484, 11208485, 11208485, 11211148, 11211149, 11211197, 11211199, 14147492, 15609116, 11208480, 11208481, 11208481, 11208482, 11208483, 11208484, 11208484, 11208485, 11208485, 11208486, 11208481, 11208482, 11208484, 11208486, 11208482, 11208483, 11208483, 11208484, 11208484, 11208485, 11208485, 11208486, 11208486, 11208487, 11211150, 11208483, 11208484, 11208484, 11208485, 11208486, 11208487, 11208487, 11208484, 11208486, 11208488, 11208485, 11208486, 11208487, 11208488, 11208486, 11208487, 11208488, 11208489, 11208489, 11208488, 11208489, 11208490, 11208490, 11211154, 11208491, 11208491, 11208492, 11208493, 11211155, 11211155, 11211204, 11211204, 11211206, 11211206, 11386006, 11633837, 11633837, 11633838, 11633838, 12351468, 12379774, 12379780, 12379782, 12379785, 12379842, 26585963, 11211156, 11211156, 11213818, 11213819, 11213820, 11213820, 11213821, 11213821, 11213823, 11213827, 11213829, 11213830, 11213848, 11213849, 11213860, 11213861, 11213862, 11213862, 11213865, 11213866, 11213866, 11213867, 11213867, 11213879, 11213879, 11213822, 11213864, 11213867, 11213867, 11213868, 11213868, 11213868, 11213861, 11213868, 11213869, 11213869, 11213865, 11213869, 11213869, 11213870, 11213870, 11213875, 11213840, 11213878, 11213943, 11213896, 11213897, 11213907, 11213904, 11213908, 11213909, 11213909, 11213905, 11213907, 11213910, 11213910, 11213911, 11213938, 11213911, 11213915, 11213914, 11213913, 11213913, 11213913, 11213914, 11213914, 11213915, 11213919, 11213915, 11213916, 11213916, 11213917, 11213917, 11213918, 11213918, 11213919, 11213919, 11213920, 11213921, 11213922, 11213924, 11213925, 11213925, 11213927, 11213927, 11213930, 11213932, 11213934, 11213939, 11213942, 11213916, 11213917, 11213917, 11213918, 11213918, 11213919, 11213919, 11213920, 11213920, 11213921, 11213921, 11213922, 11213922, 11213923, 11213924, 11213925, 11213925, 11213926, 11213927, 11213928, 11213929, 11213929, 11213930, 11213931, 11213932, 11213932, 11213933, 11213935, 11213935, 11213936, 11213937, 11213937, 11213939, 11213942, 11213942, 11213943, 11213943, 11213918, 11213918, 11213919, 11213919, 11213920, 11213921, 11213922, 11213924, 11213928, 11213930, 11213931, 11213936, 11213943, 11213943, 11213918, 11213919, 11213919, 11213921, 11213921, 11213923, 11213928, 11213931, 11213934, 11213943, 11213943, 11213944, 11213919, 11213920, 11213920, 11213921, 11213922, 11213925, 11213927, 11213929, 11213929, 11213932, 11213940, 11213940, 11213943, 11213943, 11213944, 11213944, 11213920, 11213921, 11213921, 11213922, 11213922, 11213923, 11213924, 11213927, 11213928, 11213929, 11213931, 11213932, 11213933, 11213935, 11213937, 11213938, 11213940, 11213941, 11213943, 11213944, 11213945, 11213921, 11213922, 11213923, 11213924, 11213925, 11213930, 11213930, 11213932, 11213935, 11213936, 11213939, 11213945, 11213945, 11213922, 11213923, 11213925, 11213934, 11213938, 11213940, 11213944, 11213945, 11213945, 11213946, 11213924, 11213925, 11213926, 11213935, 11213938, 11213938, 11213939, 11213939, 11213940, 11213944, 11213944, 11213946, 11213924, 11213926, 11213926, 11213927, 11213928, 11213934, 11213936, 11213939, 11213944, 11213945, 11213947, 11213926, 11213927, 11213930, 11213932, 11213932, 11213934, 11213934, 11213937, 11213937, 11213939, 11213941, 11213942, 11213944, 11213945, 11213946, 11213947, 11213947, 11213927, 11213938, 11213927, 11213929, 11213931, 11213932, 11213933, 11213934, 11213935, 11213936, 11213938, 11213938, 11213939, 11213939, 11213941, 11213942, 11213943, 11213945, 11213947, 11213948, 11213949, 11213947, 11213948, 11213949, 11213934, 11213947, 11213950, 11213950, 11213943, 11213945, 11213945, 11213951, 11213937, 11213952, 11213937, 11213943, 11213948, 11213952, 11213941, 11213945, 11213944, 11213953, 11213953, 11213939, 11213940, 11213941, 11213942, 11213945, 11213948, 11213951, 11213952, 11213954, 11213941, 11213942, 11213943, 11213947, 11213952, 11213955, 11213942, 11213944, 11213956, 11213944, 11213951, 11213953, 11213955, 11213956, 11213945, 11213949, 11213954, 11213955, 11213956, 11213956, 11213957, 11213947, 11213947, 11213950, 11213954, 11213957, 11213958, 11213956, 11213957, 11213959, 11213951, 11213955, 11213959, 11213959, 11213954, 11213959, 11213960, 11213952, 11213954, 11213959, 11213960, 11213961, 11213956, 11213957, 11213960, 11213961, 11213962, 11636568, 11213959, 11213962, 11213962, 11213963, 11213958, 11213961, 11213963, 11213962, 11213964, 11213963, 11213964, 11213964, 11213965, 11213962, 11213963, 11213965, 11213966, 11213964, 11213965, 11213966, 11213966, 11213966, 11213967, 11213967, 11213968, 11213967, 11213968, 11213968, 11213969, 11213969, 11213970, 11213970, 11213971, 11213971, 11213972, 11213973, 11213973, 11213974, 11213974, 11213975, 11213976, 11213977, 11213979, 11213980, 11213981, 11213982, 11213983, 11213984, 11213984, 11213985, 11213987, 11213987, 11213988, 11213988, 11213989, 11213989, 11213991, 11213992, 11213996, 11213999, 11214001, 11214004, 11214006, 11214009, 11214014, 11214015, 11214015, 11214016, 11214016, 11214017, 11214017, 11214018, 11214018, 11538015, 11567158, 11636576, 11636576, 11636577, 12382513, 13169377, 15101988, 11213971, 11213972, 11213972, 11213973, 11213974, 11213975, 11213976, 11213977, 11213978, 11213980, 11213982, 11213984, 11213985, 11213986, 11213986, 11213993, 11213993, 11213997, 11214002, 11214003, 11214004, 11214009, 11214014, 11214015, 11214016, 11214017, 11214017, 11214018, 11214018, 11214019, 11636576, 11213973, 11213975, 11213982, 11213994, 11214017, 11214018, 11214019, 11214016, 11214017, 11214020, 11636578, 11214002, 11214019, 11214020, 11213989, 11213981, 11213990, 11214020, 11214021, 11214022, 11214020, 11214022, 11214021, 11214023, 11214021, 11213993, 11636583, 11214010, 11214025, 11214026, 11214025, 11213990, 11213991, 11214014, 11214027, 11214027, 11214027, 11213998, 11214029, 11214027, 11214028, 11214030, 11214029, 11214030, 11214032, 11214031, 11214032, 11214032, 11214012, 11214013, 11214033, 11636590, 11214017, 11214031, 11214032, 11214033, 11340453, 11214011, 11214023, 11214034, 11214014, 11214033, 11214034, 11214035, 11214033, 11214036, 11214037, 11214035, 11214036, 11214038, 11214041, 11214039, 11214040, 11214042, 11214038, 11214041, 11214044, 11214045, 11214045, 11214046, 11214047, 11214048, 11214049, 11214050, 11214049, 11214051, 11214049, 11214049, 11214050, 11214052, 11214053, 11214054, 11214054, 11214056, 11214054, 11214057, 11214060, 11214061, 11214063, 11214061, 11214062, 11214062, 11214063, 11214063, 11214061, 11214062, 11214063, 11214064, 11214062, 11214063, 11214063, 11214064, 11214063, 11214064, 11214064, 11214065, 11214064, 11214065, 11214065, 26588749, 11214065, 11214066, 11636623, 12382568, 11214066, 11214067, 11219871, 11264979, 11278208, 11300810, 11388797, 11388797, 11388798, 11388799, 11416916, 11538065, 11567068, 11567070, 11567116, 11567148, 11567176, 11567182, 11612748, 11612748, 11612749, 11612749, 11612750, 11636623, 11636624, 11636624, 11636625, 11636625, 11636626, 11636626, 11636627, 11651428, 11654838, 11728538, 11751246, 11751248, 11751248, 11751250, 11878622, 11953797, 12024910, 12382558, 12382559, 12382560, 12382560, 12382561, 12382561, 12382562, 12382562, 12382563, 12382564, 12382565, 12382566, 12382566, 12382567, 12382568, 12382568, 12382569, 12382569, 12382570, 12382571, 12382571, 12382572, 12382573, 12382574, 12382574, 12382577, 12382625, 12382626, 12382629, 12382630, 12382632, 12382632, 12382634, 12568642, 12657964, 13153154, 13288670, 13432453, 13623154, 13795002, 14269073, 14269073, 14269074, 14269074, 14924918, 15102036, 15611913, 16064505, 16357694, 16357696, 16357697, 16357698, 18928136, 19096684, 19211162, 24084160, 26588751, 11612750, 12382626, 14269073, 11225729, 11642482, 11642484, 11242396, 11402970, 11315904, 11316017, 11316127, 11687659, 11342362, 11631221, 11676903, 11387565, 11387566, 11699502, 11723380, 11466919, 11922772, 11563536, 11563541, 11563541, 11563542, 11563543, 11563541, 11563542, 11563543, 12557310, 16532439, 11609308, 11667360, 11811368, 12557304, 12557308, 11787494, 11609307, 11811370, 11811370, 11619821, 11839529, 11655058, 11655073, 11655076, 11655088, 11857135, 11857136, 11771184, 11891318, 11862076, 11862081, 12050435, 11960641, 11920071, 11920143, 11920144, 11920146, 11920190, 11989699, 11920218, 11920224, 11920294, 11920230, 11920276, 11920298, 11920266, 11920327, 11920333, 11920334, 11920346, 11920357, 11965900, 11989775, 11989775, 12735710, 12735712, 12735713, 12735716, 12735720, 13375548, 14622223, 12011446, 12011445, 12011447, 12011446, 12011447, 12011452, 12011445, 12011447, 12011448, 12011448, 12011449, 12011449, 12035320, 12035321, 12781258, 12035322, 12035322, 12149946, 12781259, 12781271, 12035323, 12035323, 12781273, 12035324, 12035327, 12059194, 12059181, 12059196, 12059182, 12059183, 12059183, 12059184, 12059184, 12059195, 12059195, 12059196, 12059196, 12059197, 12059197, 12059198, 12059183, 12059184, 12059196, 12059196, 12059197, 12059197, 12059198, 12059198, 12059184, 12059196, 12059197, 12059197, 12059198, 12059199, 12059199, 12059197, 12059197, 12059198, 12059198, 12059200, 12059198, 12059199, 12059198, 12059199, 12059199, 12059208, 12059210, 12059209, 12059210, 12805137, 12805138, 12805138, 12059210, 12059211, 12059211, 12273246, 12301193, 12379923, 12805131, 12805132, 12805133, 12805133, 12805134, 12805135, 12805135, 12805140, 12805141, 12805144, 12805145, 12805146, 12805197, 13759307, 13855025, 16034482, 19665839, 12059211, 12805134, 13855027, 14691645, 12059212, 12059213, 12059213, 12082937, 12137679, 12148993, 12148995, 12151110, 12151111, 12173819, 12173820, 12173820, 12173821, 12173823, 12173824, 12173825, 12218912, 12266559, 12301194, 12301195, 12301195, 12373593, 12374590, 12379924, 12379926, 12385371, 12474653, 12517743, 12776826, 12801787, 12805131, 12805131, 12805132, 12805132, 12805133, 12805133, 12805134, 12805134, 12805135, 12805135, 12805136, 12805137, 12805138, 12805138, 12805139, 12805139, 12805140, 12805141, 12805141, 12805142, 12805143, 12805143, 12805144, 12805144, 12805145, 12805146, 12805146, 12805198, 12805198, 12805201, 12805204, 12805204, 12805205, 12805206, 12952274, 12991214, 13424492, 13592172, 13653789, 13711244, 13855029, 14045726, 14449841, 14691644, 14691645, 14691645, 14691646, 14691646, 14691647, 15347488, 15524609, 16034479, 16034483, 16034484, 16780269, 16780270, 19633733, 19633734, 20040612, 12059213, 12151111, 12173819, 12173821, 12173824, 12173824, 12301194, 12379926, 12382592, 12444086, 12776828, 12776831, 12805127, 12805134, 12805134, 12805135, 12805135, 12805136, 12805138, 12805139, 12805140, 12805141, 12805142, 12805143, 12805143, 12805144, 12805144, 12805145, 12805146, 12805147, 12805149, 12805198, 12805199, 12805204, 12805206, 12805207, 12936860, 14045727, 14572857, 14691644, 14691646, 14691647, 14691647, 14691648, 15347489, 16034474, 12059214, 12173821, 12805133, 12805135, 12805142, 12805147, 14691647, 14691648, 16034478, 16034485, 16780271, 12301193, 12805135, 12805148, 13759375, 12088804, 13726046, 12095679, 12823403, 12106673, 12106769, 12106864, 12197652, 12216161, 12883682, 12238789, 12238791, 12238791, 12894930, 12894992, 12895002, 12243025, 12243026, 12243029, 12243030, 12897046, 12897049, 12897053, 12897054, 12288440, 12288428, 12288441, 12288443, 12288431, 12288442, 12288442, 12288444, 12288445, 12288443, 12288444, 12288443, 12288445, 12288446, 12288447, 12288447, 12288450, 12288455, 12919763, 12288457, 12415816, 12919756, 12919756, 12919757, 12919765, 12919829, 13665714, 19748355, 12607306, 12919756, 12919756, 12919757, 12919758, 12919758, 12919759, 12919769, 12919770, 12919828, 13195160, 13969650, 14160351, 12919832, 12919759, 12378623, 12378624, 12964845, 12964846, 12473918, 15554849, 12487300, 12631156, 12543187, 12543189, 12543190, 12543190, 13047129, 13047129, 13047130, 13047133, 13047137, 13047139, 13047139, 13817721, 13953237, 12687983, 12688116, 12688249, 13119658, 12689986, 13120538, 12693539, 13122304, 12700651, 12700652, 12700653, 12700654, 13125860, 13125863, 13125871, 15012372, 12705980, 12706041, 12706102, 13128585, 12711580, 13131356, 12775010, 13163052, 12828976, 15076535, 12835770, 13193421, 12890104, 12890321, 12890538, 13220802, 12926182, 12926199, 13238648, 13238659, 12976285, 12976375, 12976465, 13263771, 13494455, 13494458, 13494464, 13494464, 13798166, 15409277, 13522773, 13522774, 13544375, 13547722, 13551050, 13551058, 13551062, 13551052, 13551052, 13551063, 13551075, 13551055, 13551056, 13551058, 13551062, 13551066, 13551072, 13551072, 13551076, 13551055, 13551055, 13551056, 13551057, 13551067, 13551069, 13551069, 13551071, 13551071, 13551055, 13551056, 13551056, 13551057, 13551058, 13551072, 13551073, 13551073, 13551056, 13551057, 13551057, 13551058, 13551058, 13551059, 13551061, 13551061, 13551062, 13551062, 13551063, 13551063, 13551064, 13551065, 13551067, 13551067, 13551068, 13551068, 13551069, 13551071, 13551071, 13551072, 13551072, 13551073, 13551073, 13551077, 13551057, 13551058, 13551058, 13551059, 13551060, 13551060, 13551061, 13551061, 13551062, 13551062, 13551063, 13551064, 13551064, 13551065, 13551065, 13551066, 13551067, 13551068, 13551069, 13551069, 13551070, 13551071, 13551072, 13551072, 13551073, 13551074, 13551075, 13551058, 13551059, 13551060, 13551060, 13551061, 13551061, 13551062, 13551062, 13551063, 13551063, 13551064, 13551065, 13551065, 13551066, 13551066, 13551067, 13551067, 13551068, 13551069, 13551071, 13551072, 13551073, 13551073, 13551074, 13551074, 13551075, 13551076, 13551077, 13551078, 13551078, 13551083, 13551059, 13551062, 13551062, 13551063, 13551064, 13551069, 13551070, 13551073, 13551075, 13551061, 13551061, 13551062, 13551063, 13551064, 13551064, 13551065, 13551066, 13551067, 13551068, 13551073, 13551063, 13551065, 13551074, 13551063, 13551063, 13551064, 13551065, 13551066, 13551068, 13551069, 13551071, 13551085, 13551063, 13551064, 13551064, 13551065, 13551066, 13551066, 13551067, 13551064, 13551065, 13551065, 13551066, 13551066, 13551067, 13551067, 13551068, 13551068, 13551069, 13551087, 13551065, 13551066, 13551066, 13551067, 13551067, 13551068, 13551069, 13551070, 13551072, 13551076, 13551081, 13551087, 13551066, 13551067, 13551067, 13551068, 13551068, 13551069, 13551069, 13551073, 13551085, 13551088, 13551088, 13551067, 13551068, 13551068, 13551069, 13551069, 13551070, 13551073, 13551068, 13551069, 13551069, 13551070, 13551070, 13551071, 13551071, 13551074, 13551078, 13551069, 13551070, 13551070, 13551071, 13551071, 13551074, 13551078, 13551079, 13551080, 13551070, 13551071, 13551071, 13551072, 13551072, 13551073, 13551079, 13551080, 13551090, 13551091, 13551071, 13551072, 13551072, 13551073, 13551073, 13551074, 13551074, 13551075, 13551075, 13551076, 13551079, 13551079, 13551089, 13551090, 13551091, 13551072, 13551073, 13551073, 13551074, 13551074, 13551075, 13551076, 13551076, 13551079, 13551080, 13551083, 13551085, 13551085, 13551088, 13551089, 13551091, 13551073, 13551074, 13551074, 13551075, 13551075, 13551076, 13551076, 13551077, 13551077, 13551080, 13551080, 13551084, 13551086, 13551092, 13551074, 13551075, 13551075, 13551076, 13551076, 13551077, 13551077, 13551079, 13551081, 13551081, 13551082, 13551082, 13551085, 13551086, 13551092, 13551093, 13551075, 13551076, 13551076, 13551077, 13551078, 13551078, 13551081, 13551081, 13551084, 13551092, 13551093, 13551076, 13551077, 13551077, 13551078, 13551078, 13551080, 13551082, 13551082, 13551086, 13551093, 13551093, 13551077, 13551078, 13551078, 13551079, 13551079, 13551082, 13551082, 13551083, 13551083, 13551084, 13551085, 13551093, 13551094, 13551094, 13551078, 13551079, 13551079, 13551080, 13551083, 13551084, 13551085, 13551088, 13551094, 13551094, 13551095, 13551079, 13551080, 13551080, 13551081, 13551082, 13551082, 13551083, 13551084, 13551086, 13551086, 13551087, 13551088, 13551094, 13551095, 13551080, 13551081, 13551081, 13551083, 13551084, 13551084, 13551085, 13551085, 13551087, 13551089, 13551089, 13551094, 13551095, 13551095, 13551096, 13551081, 13551083, 13551083, 13551084, 13551084, 13551085, 13551085, 13551086, 13551086, 13551087, 13551087, 13551088, 13551095, 13551096, 13551096, 13551082, 13551084, 13551085, 13551085, 13551086, 13551087, 13551088, 13551089, 13551091, 13551094, 13551096, 13551096, 13551097, 13551083, 13551085, 13551086, 13551087, 13551096, 13551097, 13551084, 13551086, 13551097, 15437582, 13551085, 13551086, 13551086, 13551088, 13551098, 18138471, 13551086, 13551087, 13551088, 13551094, 13551098, 13551098, 15437583, 13551087, 13551088, 13551088, 13551090, 13551090, 13551091, 13551091, 13551093, 13551098, 13551099, 13551099, 13875893, 15437583, 15437584, 16270547, 17526204, 13551088, 13551089, 13551089, 13551090, 13551090, 13551091, 13551093, 13551093, 13551094, 13551095, 13551097, 13551097, 13551099, 13551099, 13551100, 13551136, 13551141, 13551143, 14078893, 14321663, 14600966, 15437584, 15437584, 16093426, 13551089, 13551090, 13551093, 13551093, 13551099, 13551100, 13551100, 13551136, 13551136, 13551142, 14457180, 14600965, 14982266, 16093427, 16270547, 13551090, 13551093, 13551094, 13551094, 13551100, 13551100, 13551101, 13551137, 13551137, 14338110, 14496730, 15437584, 15437585, 16780421, 13551091, 13551092, 13551092, 13551093, 13551100, 13551101, 13551101, 13551137, 13551138, 13551147, 13551150, 14457181, 15437586, 15437586, 16780417, 13551093, 13551101, 13551146, 15037268, 13551095, 13551101, 13551102, 13551102, 15437587, 20096650, 13551095, 13551096, 13551100, 13551102, 13551102, 13551142, 13551095, 13551101, 13551102, 13551139, 13551103, 13551103, 13551104, 13551097, 13551103, 13551104, 15437587, 15437589, 13551104, 13551104, 13551105, 13551141, 13551141, 13551100, 13551104, 13551141, 15437589, 16780417, 13551105, 13551105, 13551104, 13551106, 13551106, 13551107, 13551108, 13551108, 13551109, 13551154, 13551160, 13551109, 13551110, 27757271, 13551109, 13551110, 13551111, 13551114, 13551147, 13551149, 13551150, 13551151, 13551153, 13551155, 13551156, 14464328, 15437593, 13551111, 13551145, 13551147, 13551148, 13551149, 13551150, 13551150, 13551151, 13551151, 13551152, 13551152, 13551153, 13551154, 13551154, 13551155, 13551155, 13551156, 13551156, 13551157, 13551157, 13826486, 14001447, 14190919, 14321679, 14457192, 14600977, 14600978, 14791674, 15318805, 15437594, 15437594, 15437595, 15437596, 15437596, 16270558, 16270562, 16270566, 16780433, 20265206, 13551146, 13551146, 13551147, 13551147, 13551148, 13551148, 13551149, 13551150, 13551150, 13551151, 13551151, 13551152, 13551152, 13551153, 13551153, 13551154, 13551154, 13551155, 13551155, 13551156, 13551156, 13551157, 13551157, 14190919, 14217139, 14338123, 14505324, 14600974, 14600977, 14600979, 14791677, 14963525, 15437594, 15437595, 15437595, 15437596, 15437596, 15437597, 16780434, 17526220, 13551157, 13551182, 13551184, 13551182, 13551201, 13551183, 13551189, 13551183, 13551184, 13551185, 13551186, 13551190, 13551193, 13551198, 13551200, 13551184, 13551185, 13551186, 13551187, 13551187, 13551188, 13551188, 13551189, 13551189, 13551190, 13551191, 13551191, 13551192, 13551192, 13551193, 13551196, 13551199, 13551199, 13551200, 13551200, 13551202, 13551185, 13551186, 13551186, 13551187, 13551187, 13551188, 13551188, 13551189, 13551190, 13551191, 13551191, 13551192, 13551193, 13551194, 13551196, 13551200, 13551200, 13551201, 13551201, 13551202, 13551202, 13551205, 13551187, 13551187, 13551188, 13551189, 13551189, 13551188, 13551189, 13551189, 13551190, 13551190, 13551191, 13551192, 13551210, 13551211, 13551189, 13551190, 13551190, 13551191, 13551191, 13551192, 13551193, 13551195, 13551210, 13551190, 13551191, 13551191, 13551192, 13551194, 13551195, 13551204, 13551207, 13551211, 13551211, 13551191, 13551192, 13551192, 13551193, 13551193, 13551194, 13551196, 13551204, 13551211, 13551212, 13551212, 13551192, 13551193, 13551193, 13551194, 13551195, 13551195, 13551197, 13551197, 13551203, 13551205, 13551212, 13551212, 13551193, 13551194, 13551194, 13551195, 13551195, 13551196, 13551196, 13551197, 13551198, 13551204, 13551207, 13551212, 13551213, 13551194, 13551195, 13551195, 13551196, 13551197, 13551197, 13551198, 13551213, 13551213, 13551214, 13551195, 13551196, 13551196, 13551197, 13551197, 13551198, 13551198, 13551213, 13551214, 13551196, 13551197, 13551197, 13551198, 13551198, 13551199, 13551199, 13551200, 13551205, 13551206, 13551206, 13551207, 13551210, 13551214, 13551214, 13551197, 13551198, 13551198, 13551199, 13551200, 13551200, 13551202, 13551203, 13551206, 13551206, 13551214, 13551215, 13551215, 13551198, 13551199, 13551199, 13551200, 13551200, 13551201, 13551201, 13551207, 13551208, 13551209, 13551215, 13551215, 13551216, 13551199, 13551200, 13551200, 13551201, 13551205, 13551207, 13551215, 13551216, 13551216, 13551200, 13551201, 13551201, 13551202, 13551207, 13551208, 13551208, 13551216, 13551216, 13551217, 13551201, 13551202, 13551202, 13551208, 13551209, 13551210, 13551216, 13551217, 13551202, 13551203, 13551204, 13551204, 13551205, 13551205, 13551208, 13551208, 13551209, 13551209, 13551210, 13551211, 13551212, 13551213, 13551216, 13551217, 13551217, 13551218, 13551203, 13551204, 13551204, 13551205, 13551208, 13551208, 13551209, 13551210, 13551210, 13551211, 13551211, 13551212, 13551217, 13551218, 13551218, 13551205, 13551206, 13551209, 13551209, 13551210, 13551210, 13551211, 13551212, 13551217, 13551218, 13551218, 13551219, 13551210, 13551218, 13551206, 13551219, 13551219, 13551207, 13551209, 13551211, 13551212, 13551219, 13551220, 13551208, 13551213, 13551220, 13551213, 13551221, 13551221, 13551213, 13551215, 13551223, 14321727, 13551223, 13551223, 13551224, 15437645, 15437648, 13551217, 13551217, 13551223, 13551224, 14321726, 15318855, 15437646, 16093490, 16270610, 13551216, 13551217, 13551217, 13551224, 13551224, 15437647, 15437649, 16780485, 13551217, 13551219, 13551224, 13551225, 13551225, 14190972, 14321724, 14601029, 14601030, 14791729, 15437648, 15437649, 16270612, 16270615, 16780484, 16780486, 13551218, 13551219, 13551224, 13551225, 13551225, 13551226, 15437649, 15437649, 16270611, 13551220, 13551220, 13551225, 13551226, 15291766, 15437650, 13551220, 13551226, 13551226, 13826541, 16093492, 16093494, 13551226, 13551226, 13551227, 15437650, 13551227, 13551227, 15437649, 13551228, 13551228, 13826543, 13551231, 13551231, 13551232, 13551233, 13655675, 14321736, 14321738, 14338182, 14457253, 14464388, 14505384, 14601039, 14859834, 14963584, 15211234, 15318866, 15437656, 15437657, 16093498, 16093499, 16270619, 13551233, 13655670, 13655676, 13991965, 14297100, 14321736, 14321737, 14321737, 14321741, 14338183, 14399801, 14457254, 14505385, 14601037, 14601038, 14601038, 14601039, 14601040, 14791736, 14791737, 14963585, 15027884, 15082722, 15218517, 15218518, 15225641, 15241748, 15318866, 15437654, 15437654, 15437655, 15437655, 15437656, 15437657, 15437657, 16077916, 16077917, 16093499, 16120921, 16270619, 16617961, 16780484, 16780494, 16780495, 17526279, 20011089, 20411849, 13551235, 13655669, 13655671, 13655676, 13682870, 13743718, 13932316, 13986787, 14190981, 14264214, 14297101, 14297102, 14297103, 14297106, 14321734, 14321736, 14321737, 14321738, 14338184, 14338185, 14399801, 14457248, 14457252, 14457253, 14457253, 14457254, 14457255, 14464388, 14505384, 14601037, 14601038, 14601038, 14601039, 14601040, 14601040, 14738717, 14791735, 14791736, 14791738, 14791738, 14812695, 14933014, 14963585, 15027885, 15117157, 15201276, 15211238, 15318868, 15437654, 15437655, 15437655, 15437656, 15437656, 15437657, 15437657, 15437658, 15437659, 15527039, 16077917, 16093498, 16093499, 16270620, 16270621, 16270622, 16270623, 16780484, 16780491, 16780493, 17497389, 20096720, 20096721, 13826549, 13760122, 13760125, 13760129, 13760134, 13760134, 13760134, 16182371, 15542112, 15542115, 15315696, 15542116, 16197957, 13814508, 13814519, 13814522, 13814521, 13814520, 13814533, 15569304, 14453390, 16402270, 15569309, 13845347, 16927556, 13923232, 15623663, 15623664, 13936217, 15630156, 14101863, 14101874, 14101875, 14101877, 14101875, 14101876, 15712985, 14101889, 14780712, 14876367, 15712984, 14876366, 15712985, 14200709, 15762403, 14313408, 14313559, 14313710, 14982281, 14422359, 15873229, 14432756, 14432832, 14432907, 15878520, 14451796, 16532710, 14606709, 17069296, 14789784, 16056939, 14830740, 14830740, 14830739, 14830741, 16130300, 16077415, 15958626, 16077417, 16077417, 14883180, 16107152, 14977209, 16150651, 15042983, 15042983, 15042987, 15042974, 15042988, 15042988, 15042988, 15042993, 15067621, 16183540, 15043004, 15251267, 15709470, 15084068, 15067623, 15175604, 17526371, 15092251, 15092252, 15092254, 15092254, 15092255, 15092241, 15092255, 15092253, 15092256, 15092243, 15092256, 15092257, 15092258, 15092259, 15092260, 15092266, 16208172, 15371556, 15108703, 15170320, 15275902, 15371556, 15371557, 15562257, 15752858, 16089386, 16208174, 16208175, 16208176, 16208176, 17357216, 17551003, 17551013, 15124795, 15124973, 15125147, 15125148, 15125147, 15125147, 15125148, 15125151, 15125151, 15244217, 15292348, 15388001, 15388003, 15750550, 16224621, 16224621, 17057584, 16224622, 15248382, 15248383, 15248384, 15312970, 16167450, 16286239, 17629071, 15308216, 15479535, 15363282, 15363272, 15363286, 15363287, 15363284, 15363287, 15363288, 15363287, 15363288, 15363289, 15363276, 15363289, 15363289, 15363290, 15744804, 16117268, 15363302, 15697772, 15697772, 16343691, 16343691, 15411418, 15507072, 15697772, 16224900, 16289694, 16343690, 16343691, 16343692, 16343692, 15377557, 15377558, 15377559, 15377560, 16350827, 16350827, 16350828, 15442380, 16383235, 15459414, 15459483, 15459547, 15459548, 15459547, 15459547, 15459550, 15459549, 15459548, 15459550, 15459552, 15459552, 16391819, 17224783, 18480440, 15679532, 16391820, 17734660, 15555204, 16391822, 17224789, 15555204, 15650854, 15650853, 15650855, 15650856, 15650854, 15650842, 15650843, 15650844, 15650855, 15650856, 15650857, 15650843, 15650858, 15650859, 15650845, 15650856, 15650858, 15650859, 15650848, 15650859, 15650860, 15650861, 15650861, 15650860, 15650862, 15650863, 16487473, 16487475, 16487474, 16487475, 16789757, 16487475, 16487476, 17320438, 15650872, 15650873, 15775187, 15882667, 16368684, 16487475, 16487475, 16487476, 16487477, 15650875, 15841557, 16368685, 16487475, 16487475, 16487476, 16487477, 16487477, 16487477, 15650875, 15650876, 16487478, 15650876, 16368688, 16487478, 16487480, 17320441, 15788538, 15841558, 16487477, 16487478, 16487479, 15899514, 15899515, 15912865, 16611803, 15926213, 15926214, 15926216, 16151082, 16215382, 16625154, 16032252, 16032253, 16032253, 16032253, 16032254, 16032254, 16032254, 16032255, 16032255, 16032256, 16204102, 16357673, 16678172, 16678174, 16678174, 18021008, 18021011, 16204102, 16678174, 16678174, 16678175, 16678173, 16204103, 16074168, 16699130, 16114468, 16114544, 16114619, 16600563, 16126325, 16725210, 16168451, 16746272, 16314810, 16819452, 16375949, 16375950, 16375951, 16375951, 16375952, 16375953, 16375953, 16375957, 16630883, 16850021, 16850022, 16850023, 16850023, 18938646, 16850022, 16850023, 16850024, 16850023, 16850024, 18192851, 16850023, 16850025, 16850025, 16850026, 16850028, 16413465, 16413462, 16868779, 16868783, 16504547, 16702304, 16914318, 16914319, 16523455, 16923774, 16614212, 16614252, 16969185, 16683089, 16683092, 16683192, 17003592, 16683295, 17003693, 16840482, 17082287, 16851333, 17743557, 16871247, 16871248, 16871251, 16871252, 16871337, 16871338, 16871341, 16871342, 16871429, 16871431, 16871432, 17097760, 17097761, 17930725, 17097763, 16885813, 16885814, 17104951, 17104952, 16900062, 17112077, 17112078, 16932276, 16932352, 16932427, 17961223, 17032360, 17032427, 17032471, 17178288, 17086513, 17086513, 17086515, 17086514, 17086515, 17086515, 17086516, 17086516, 17086517, 17086519, 17205303, 17205304, 17205304, 18038268, 17205304, 17205305, 17205303, 17205306, 19293928, 17205306, 17216156, 17270154, 17324091, 17324075, 17324076, 17324077, 17324078, 17324079, 17324091, 17324092, 17324077, 17324078, 17324078, 17324079, 17324079, 17324092, 17324092, 17324078, 17324079, 17324079, 17324080, 17324083, 17324091, 17324092, 17324093, 17324093, 17324095, 17324096, 17324079, 17324080, 17324080, 17324083, 17324093, 17324094, 17324094, 17324095, 17324097, 17324080, 17324081, 17324095, 17324095, 17324096, 17324097, 17324098, 17324081, 17324082, 17324083, 17324083, 17324084, 17324084, 17324085, 17324092, 17324095, 17324095, 17324096, 17324096, 17324097, 17324098, 17324082, 17324083, 17324083, 17324084, 17324084, 17324085, 17324085, 17324092, 17324093, 17324093, 17324094, 17324094, 17324095, 17324095, 17324096, 17324096, 17324097, 17324097, 17324098, 17324098, 17324099, 17324099, 17324100, 17324100, 17324083, 17324084, 17324084, 17324085, 17324093, 17324096, 17324096, 17324097, 17324098, 17324099, 17324100, 17324084, 17324085, 17324085, 17324086, 17324097, 17324097, 17324099, 17324099, 17324101, 17324085, 17324086, 17324097, 17324098, 17324099, 17324100, 17324101, 17324101, 17324086, 17324087, 17324094, 17324095, 17324096, 17324100, 17324100, 17324101, 17324087, 17324090, 17324097, 17324098, 17324098, 17324100, 17324101, 17324090, 17324095, 17324096, 17324098, 17324099, 17324099, 17324100, 17324101, 17324101, 17324096, 17324100, 17324101, 17324102, 17324100, 17324104, 17324108, 17324109, 17324109, 17324109, 17324111, 17324106, 17324106, 17324109, 17324107, 17324108, 17324109, 17324110, 17324108, 17324109, 17324110, 17324111, 17964355, 17979936, 18666932, 17324109, 17324110, 17324111, 17324111, 17964355, 17979938, 18157056, 18666921, 17324109, 17324110, 17324111, 17324111, 17324112, 17644413, 17964355, 17979937, 17979937, 18157057, 18157060, 18473135, 18666930, 19147690, 19412713, 17324111, 17324111, 17324112, 17324112, 17830359, 17979937, 17979938, 18157058, 18157062, 18504399, 17324111, 17324112, 17324112, 17324113, 17324114, 17979938, 17979938, 18157058, 18157058, 19412719, 17324112, 17324113, 17324113, 17964357, 17979937, 17979938, 19412720, 17324113, 17324114, 17979939, 17324114, 17324115, 17324116, 17324116, 17376981, 17830361, 17979937, 17979939, 17979940, 17979941, 18157059, 18157060, 18666924, 18666934, 17324115, 17324116, 17324116, 17324117, 17324117, 17355120, 17384062, 17413480, 17532256, 17734017, 17745093, 17784022, 17784023, 17807889, 17814429, 17830361, 17903911, 17903912, 17936959, 17964358, 17964359, 17965162, 17979938, 17979939, 17979939, 17979940, 17979940, 17979941, 17979942, 18007362, 18157058, 18157059, 18157059, 18157060, 18157060, 18157061, 18157062, 18157063, 18157064, 18157065, 18157066, 18157066, 18157067, 18157068, 18157069, 18315553, 18472027, 18473138, 18666923, 18666924, 18666925, 18666926, 18666928, 18666928, 18666930, 18666930, 18666931, 18666931, 18666932, 18666933, 18666934, 18666935, 18666935, 18666936, 18666936, 18666937, 19119529, 19147693, 19412716, 19412716, 19412717, 19412719, 19412720, 19412721, 19412721, 19895891, 20462740, 20863052, 22266185, 22266185, 17324116, 17324117, 17964357, 17964358, 17964359, 17979940, 17979942, 18157063, 17324117, 17324118, 17454377, 17475598, 17626381, 17964360, 17979940, 17979941, 17979941, 17979943, 18157061, 18157061, 18157062, 18157065, 18666923, 18666930, 18666934, 18666935, 18666936, 18666936, 18666937, 19412720, 19412721, 21983162, 22151709, 17324118, 17376983, 17573042, 17626381, 17644418, 17807890, 17903912, 17936962, 17964355, 17964360, 17979941, 17979941, 17979942, 17979943, 17979943, 18157061, 18157061, 18157062, 18157067, 18270776, 18666933, 18666934, 18666936, 18666936, 18666937, 19412719, 19412721, 19412722, 21983163, 17461920, 17645523, 17734019, 17903913, 17964358, 17964360, 17964361, 17979939, 17979942, 17979943, 17979944, 18157060, 18157062, 18157063, 18666926, 18666927, 18666932, 18666932, 18666935, 18666937, 18666937, 19412720, 19412721, 21609855, 17663387, 17331117, 17331183, 17331250, 18670506, 17386136, 18010958, 17429858, 17956787, 18209936, 19465597, 17444026, 18726899, 17502858, 18053734, 18246439, 17584650, 18110214, 17599747, 18117768, 17627092, 18131435, 17740407, 17992174, 17822029, 18915921, 17928657, 17928657, 18282217, 18969212, 19714999, 17964730, 17964731, 18300253, 18477385, 17966943, 18988357, 18002668, 18496343, 18143932, 18143932, 18389855, 18566975, 18166089, 19087931, 18243942, 18243943, 18428783, 18616981, 18616987, 18291675, 18291676, 19150719, 18640847, 18304760, 18647392, 18336623, 18336623, 18336624, 18663322, 18410173, 18470615, 18483719, 18483721, 18483722, 18483719, 18483722, 18483856, 18483855, 18483736, 18736870, 19992527, 18559751, 18736871, 18736875, 18483990, 18483991, 18559883, 18737004, 18549818, 18549820, 18577218, 18592799, 18604610, 18604613, 18604600, 18604615, 18604613, 18604614, 18604614, 18604615, 18604615, 18604618, 18604618, 18620196, 18797316, 18797317, 18797321, 18797322, 19113391, 19307181, 19307193, 19759786, 18620201, 18620199, 18797319, 18797319, 19307194, 18606244, 18621022, 18613622, 18801826, 19311684, 18635762, 18635776, 18635763, 18635778, 18635780, 18635764, 18635778, 18635780, 18635764, 18635766, 18635779, 18635780, 18635765, 18635766, 18635767, 18635778, 18635780, 18635780, 18635781, 18635781, 18635782, 18635782, 18635783, 18635783, 18635766, 18635780, 18635780, 18635781, 18635782, 18635782, 18635783, 18635783, 18635782, 18635783, 18635768, 18635781, 18635784, 18635785, 18635782, 18635782, 18635783, 18635783, 18635784, 18635784, 18635785, 18635785, 18635786, 18812899, 18812904, 18635795, 18635797, 18812905, 19322764, 18635795, 18635796, 18635797, 18635797, 18812900, 18812900, 18812901, 18812904, 19128978, 19322766, 19322772, 19322774, 19322774, 19322775, 19322776, 20068561, 18635796, 18635797, 18635798, 18812900, 18812901, 19322765, 19322765, 19322772, 18635797, 18635798, 18812901, 18812902, 18812903, 18812907, 19322766, 19322776, 20068558, 18635798, 18635799, 18812902, 18812902, 18812907, 18812909, 19160243, 19322771, 19322771, 19322772, 19322774, 19322775, 19322776, 19322777, 19322777, 20068562, 18635799, 18635800, 18812902, 18812904, 18812904, 18812907, 18812908, 19322776, 19322777, 19322777, 19803535, 20068563, 22639003, 18635800, 18635801, 18635801, 18812902, 18812902, 18812903, 18812903, 18812904, 18812904, 18812905, 18812906, 18812907, 18812907, 18812908, 18812908, 18812909, 18812910, 19127678, 19265816, 19322767, 19322768, 19322770, 19322772, 19322773, 19322773, 19322775, 19322777, 19322777, 19322778, 19322778, 19322779, 20068563, 20068564, 20068564, 21528671, 22922027, 18812903, 18812904, 19322767, 19322778, 20068561, 18812908, 18812910, 19322779, 20068559, 19322777, 20068565, 18690620, 18690648, 18690654, 19293231, 19350189, 19350212, 18840357, 18990003, 18990020, 18990004, 18990005, 18990006, 18990023, 18990005, 18990006, 18990010, 18990010, 18990011, 18990020, 18990020, 18990021, 18990022, 18990006, 18990007, 18990007, 18990008, 18990009, 18990010, 18990010, 18990011, 18990011, 18990012, 18990013, 18990014, 18990017, 18990020, 18990020, 18990021, 18990021, 18990022, 18990022, 18990023, 18990023, 18990024, 18990025, 18990026, 18990008, 18990010, 18990010, 18990011, 18990011, 18990012, 18990012, 18990013, 18990014, 18990021, 18990022, 18990022, 18990024, 18990009, 18990010, 18990013, 18990021, 18990022, 18990029, 18990009, 18990010, 18990010, 18990014, 18990015, 18990021, 18990024, 18990030, 18990030, 18990010, 18990011, 18990012, 18990014, 18990031, 18990011, 18990012, 18990013, 18990014, 18990015, 18990023, 18990031, 18990023, 18990024, 18990032, 18990013, 18990014, 18990014, 18990015, 18990016, 18990025, 18990025, 18990032, 18990014, 18990015, 18990015, 18990016, 18990025, 18990025, 18990027, 18990033, 18990015, 18990016, 18990016, 18990017, 18990017, 18990025, 18990033, 18990017, 18990019, 18990027, 18990027, 18990034, 18990034, 18990017, 18990018, 18990019, 18990019, 18990026, 18990027, 18990028, 18990034, 18990035, 18990018, 18990019, 18990019, 18990020, 18990020, 18990021, 18990027, 18990028, 18990029, 18990035, 18990036, 18990019, 18990020, 18990020, 18990021, 18990027, 18990028, 18990029, 18990035, 18990036, 18990020, 18990021, 18990029, 18990036, 18990021, 18990022, 18990028, 18990029, 18990036, 18990022, 18990029, 18990030, 18990031, 18990032, 18990033, 18990033, 18990034, 18990037, 18990029, 18990030, 18990030, 18990037, 18990038, 18990038, 18990041, 18990033, 18990035, 18990042, 18990043, 18990035, 18990036, 18990043, 19499890, 19499893, 18990036, 18990037, 18990037, 18990041, 18990044, 19306098, 19499885, 19499885, 19499886, 19499893, 19499894, 19499895, 19499896, 19980654, 20245677, 20245680, 20245681, 20245681, 20245682, 22816120, 22984668, 18990037, 18990038, 18990039, 18990044, 19306099, 19337365, 19488638, 19499885, 19499886, 19499891, 19499892, 19499893, 19499893, 19499894, 19499895, 19499896, 19499896, 19980654, 20245676, 20245677, 20245681, 20245682, 23099146, 18990038, 18990039, 18990040, 18990040, 18990041, 18990043, 18990045, 18990046, 18994465, 19304775, 19337363, 19337363, 19499886, 19499888, 19499888, 19499892, 19499893, 19499894, 19499894, 19499896, 19499896, 19499897, 19499897, 20245677, 20245681, 20245682, 20245682, 22816123, 18990045, 19499887, 19499895, 19499897, 19499897, 18990040, 18990045, 18990046, 19442936, 19499887, 19499891, 20245683, 18990043, 18990045, 18990046, 18990047, 19148518, 19337364, 19499888, 19499898, 19952493, 20245684, 23099148, 18990047, 18990048, 19499888, 19499898, 19499895, 19499898, 18990048, 19499889, 19499889, 19499897, 18990048, 19499900, 18990049, 19499895, 19499901, 19499897, 20245683, 18990051, 19499893, 19499903, 19499904, 18990052, 18990053, 18990053, 18990054, 19262518, 19337370, 19337371, 19337373, 19352844, 19499892, 19499893, 19499893, 19499894, 19499895, 19499896, 19499899, 19499900, 19499901, 19499902, 19499903, 19499903, 19499904, 19499904, 19952498, 20004134, 20245684, 20245685, 20245685, 20245686, 20245688, 22816130, 18990053, 18990054, 19337370, 19499894, 19499899, 19499901, 19499903, 19499904, 18990054, 18990055, 19148524, 19337371, 19499894, 19499901, 19499902, 19499903, 19499903, 20245684, 20245686, 19120433, 19337372, 19385631, 19499895, 19499900, 19499903, 19337372, 19499895, 19499897, 19499905, 18998932, 19504357, 19063899, 20282621, 19217477, 19613638, 19250823, 19630290, 19307006, 19307007, 19307007, 19658377, 19658377, 19658387, 19531882, 19531892, 23370074, 19534996, 20518163, 19619586, 19619608, 19619753, 19619919, 19619967, 19814874, 20560656, 19622168, 19622174, 19622174, 19622175, 19622175, 19622176, 19815969, 19815970, 19815971, 19622189, 19815972, 19815966, 19815971, 19815969, 20296731, 19815972, 19684703, 19684704, 19684704, 19684703, 19684704, 19684707, 19684708, 19847226, 19847226, 19847230, 19847235, 20593021, 23163462, 19847227, 19847227, 19847235, 19847236, 19847239, 19715649, 19862707, 19781234, 19895498, 19895843, 19895844, 20698589, 19952804, 23552056, 19987251, 19998509, 20009756, 20009748, 20009734, 20009734, 20009739, 20009742, 20009744, 20009745, 20009735, 20009736, 20009737, 20009737, 20009738, 20009739, 20009740, 20009740, 20009741, 20009741, 20009742, 20009742, 20009743, 20009743, 20009744, 20009744, 20009745, 20009745, 20009746, 20009746, 20009752, 20009754, 20009756, 20009759, 20009761, 20009736, 20009741, 20009745, 20009747, 20009754, 20009738, 20009738, 20009739, 20009739, 20009740, 20009740, 20009741, 20009741, 20009742, 20009742, 20009743, 20009743, 20009744, 20009744, 20009745, 20009746, 20009750, 20009752, 20009756, 20009745, 20009746, 20009763, 20009742, 20009743, 20009762, 20009743, 20009744, 20009745, 20009746, 20009742, 20009743, 20009743, 20009743, 20009744, 20009744, 20009746, 20009746, 20009748, 20009746, 20009748, 20009749, 20009749, 20009744, 20009746, 20009747, 20009747, 20009749, 20009749, 20009764, 20009765, 20009745, 20009746, 20009746, 20009747, 20009747, 20009748, 20009750, 20009750, 20009754, 20009755, 20009765, 20009766, 20009746, 20009747, 20009747, 20009748, 20009748, 20009749, 20009750, 20009751, 20009751, 20009760, 20009761, 20009765, 20009766, 20009747, 20009748, 20009748, 20009749, 20009749, 20009750, 20009751, 20009752, 20009766, 20009766, 20009767, 20009748, 20009749, 20009749, 20009750, 20009750, 20009751, 20009751, 20009752, 20009752, 20009766, 20009767, 20009749, 20009750, 20009750, 20009751, 20009751, 20009752, 20009752, 20009760, 20009762, 20009767, 20009750, 20009751, 20009751, 20009752, 20009752, 20009753, 20009754, 20009760, 20009762, 20009766, 20009767, 20009768, 20009768, 20009751, 20009752, 20009752, 20009753, 20009753, 20009754, 20009760, 20009762, 20009767, 20009768, 20009768, 20009769, 20009769, 20009752, 20009753, 20009753, 20009754, 20009754, 20009755, 20009759, 20009763, 20009764, 20009769, 20009753, 20009754, 20009754, 20009755, 20009758, 20009759, 20009760, 20009761, 20009762, 20009762, 20009763, 20009764, 20009769, 20009769, 20009770, 20009770, 20009754, 20009755, 20009755, 20009757, 20009760, 20009761, 20009761, 20009764, 20009765, 20009769, 20009770, 20009770, 20009771, 20009755, 20009756, 20009756, 20009757, 20009757, 20009759, 20009760, 20009760, 20009761, 20009762, 20009762, 20009763, 20009763, 20009764, 20009765, 20009765, 20009769, 20009769, 20009770, 20009770, 20009771, 20009771, 20009772, 20009756, 20009757, 20009758, 20009760, 20009761, 20009761, 20009762, 20009762, 20009763, 20009764, 20009764, 20009765, 20009765, 20009766, 20009768, 20009770, 20009770, 20009771, 20009771, 20009772, 20009772, 20009757, 20009759, 20009761, 20009761, 20009762, 20009763, 20009763, 20009764, 20009764, 20009765, 20009766, 20009767, 20009768, 20009771, 20009771, 20009772, 20009772, 20009773, 20009759, 20009761, 20009762, 20009763, 20009764, 20009766, 20009770, 20009771, 20009772, 20009772, 20009773, 20009773, 20009774, 20009763, 20009772, 20009773, 20009774, 20009763, 20009767, 20009773, 20009772, 20009773, 20009774, 20009774, 20009769, 20009775, 20009775, 20462354, 20009765, 20009767, 20009769, 20009770, 20009771, 20009775, 20009776, 20009767, 20009767, 20009768, 20009768, 20009769, 20009770, 20009771, 20009776, 20009767, 20009768, 20009770, 20009771, 20009773, 20009776, 20009769, 20009769, 20009770, 20009771, 20009772, 20009774, 20009777, 20009769, 20009771, 20009771, 20009772, 20009774, 20009777, 20009777, 20009770, 20009771, 20009772, 20009773, 20009774, 20009775, 20009776, 20009771, 20009772, 20009772, 20009773, 20009774, 20009777, 20009778, 20009772, 20009773, 20009774, 20009774, 20009775, 20009776, 20009778, 20009780, 20009780, 20009773, 20009774, 20009774, 20009775, 20009776, 20009776, 20009778, 20009778, 20009779, 21010986, 20009774, 20009775, 20009775, 20009776, 20009776, 20009777, 20009777, 20009778, 20726658, 21779540, 20009775, 20009776, 20009776, 20009777, 20009777, 20009778, 20009778, 20009779, 20009779, 20009780, 20009780, 20009781, 20009776, 20009777, 20009777, 20009778, 20009779, 20009780, 20009780, 20009781, 20009781, 20009777, 20009778, 20009778, 20009779, 20009780, 20009780, 20009781, 20009782, 20009778, 20009779, 20009779, 20009780, 20009780, 20009781, 20009782, 20503430, 20009779, 20009780, 20009780, 20009781, 20009781, 20009782, 20009780, 20009781, 20009782, 20009782, 20009783, 20009783, 20009781, 20009782, 20009782, 20009783, 20009783, 20009784, 20009782, 20009783, 20009783, 20009784, 20755548, 20009783, 20009784, 20009784, 20009785, 20009785, 20755549, 20755555, 20009784, 20009785, 20009785, 20009785, 20009786, 20009786, 20755550, 20755550, 20755554, 20755555, 20755556, 21746365, 23325997, 20009786, 20009787, 20009787, 20009788, 20009788, 20009826, 20016967, 20134213, 20137907, 20195565, 20276619, 20355391, 20426843, 20428227, 20442453, 20462365, 20490529, 20490531, 20503435, 20503456, 20527259, 20726664, 20726665, 20726666, 20755549, 20755550, 20755550, 20755551, 20755551, 20755552, 20755553, 20755553, 20755554, 20755554, 20755555, 20755555, 20755556, 20755556, 20755557, 20755557, 21746367, 22215664, 22215666, 23023434, 23325996, 23494543, 23609020, 23609021, 23609021, 23641104, 20009787, 20009788, 20009788, 20009789, 20009791, 20014667, 20019003, 20021593, 20053972, 20083342, 20134214, 20134853, 20392612, 20426842, 20428227, 20428227, 20462365, 20462365, 20462366, 20490527, 20490529, 20490530, 20527259, 20693706, 20695284, 20721666, 20726365, 20726664, 20726665, 20726666, 20726666, 20727454, 20755551, 20755551, 20755552, 20755552, 20755553, 20755554, 20755555, 20755555, 20755556, 20755556, 20755557, 20755557, 20755558, 21746367, 22652283, 23494544, 23609019, 23609020, 23609021, 23609021, 23609022, 30986611, 20009788, 20009789, 20009830, 20019004, 20355392, 20462364, 20462365, 20462366, 20462367, 20490530, 20695479, 20727455, 20755551, 20755552, 20755553, 20755553, 20755554, 20755555, 20755555, 20755556, 20755556, 20755557, 20755557, 20755558, 20755559, 21679659, 21746367, 22796330, 23325996, 23609021, 20428228, 20462366, 20490530, 20503458, 20727455, 20755552, 20755552, 20755553, 20755553, 20755555, 20755555, 20755556, 20755556, 20755557, 20755558, 20755558, 23325998, 23609022, 20009790, 20009876, 20276624, 20755557, 20755558, 20462367, 20755553, 20755555, 20755559, 20755555, 20009877, 20009885, 20755606, 20490585, 20009971, 20755652, 20019567, 20760451, 20024171, 20734658, 20028243, 20028259, 20028303, 20471622, 20764812, 20764829, 20033415, 20767380, 20098168, 20098237, 20098308, 20799818, 20156911, 20829121, 20258653, 20258654, 20552667, 20879990, 20259933, 20880630, 20266049, 20590507, 20381364, 20381370, 20381439, 20381446, 20381509, 20381517, 20941424, 20941433, 20543468, 20543471, 21022399, 21022401, 20701024, 20701072, 21101188, 20701181, 20701290, 21101347, 20775449, 21138388, 20843909, 20843911, 20843913, 21172619, 21172620, 21172623, 20846677, 20846679, 20846680, 20846680, 20846758, 20908983, 21174003, 21145118, 21174004, 20846839, 23744528, 20875139, 21159351, 20914952, 20914958, 20914958, 20914960, 20914959, 20914959, 20914960, 20914962, 20914960, 20914960, 20914961, 20914961, 20956045, 20943123, 20956050, 21148072, 21208148, 21208148, 21208149, 21208149, 21208152, 20943123, 21208145, 21208145, 21208146, 21208147, 21208150, 21208150, 21208151, 23692959, 20943126, 21208145, 21208151, 21179261, 21208146, 20943125, 20971283, 20971286, 20971283, 20971284, 20971284, 20971285, 20971285, 20971287, 20971288, 20971288, 20971288, 20971288, 21236307, 22160413, 21207420, 21236311, 21236312, 23806753, 21236311, 21207421, 21236311, 21236312, 21236309, 21236312, 22696421, 21236311, 21236313, 20984214, 21236313, 21236314, 21236314, 21236314, 21236314, 20997093, 20997094, 20997115, 20997117, 20997137, 20997138, 20997139, 20997141, 20997139, 21249237, 21249234, 21220347, 21249234, 21249233, 21249233, 21249235, 21249239, 21018229, 21259782, 21044791, 21044792, 21044862, 21044863, 21044938, 21273165, 21273165, 21377637, 21439488, 21380793, 21441061, 21381180, 21441255, 21441258, 21433574, 21467461, 21442956, 21472147, 21443557, 21443557, 21443558, 21443558, 21443559, 21443558, 21443558, 21443560, 21443560, 21443563, 21443561, 21443562, 21472443, 21472443, 22396553, 21472444, 21472444, 21443576, 21472444, 21472445, 21472445, 21472446, 21472447, 21472448, 21472451, 21472445, 21472451, 21472446, 21472452, 21472453, 21445132, 21445156, 21445166, 21445201, 21445204, 21445200, 21445245, 21445268, 21473294, 21445321, 21445354, 21473342, 21473343, 21445448, 21473391, 21501315, 21501314, 21501315, 21501316, 21501315, 21501316, 21501316, 21501317, 21501317, 21501318, 21501318, 21501319, 21501320, 21501330, 21501316, 21501317, 21501317, 21501318, 21501318, 21501319, 21501319, 21501320, 21501317, 21501318, 21501318, 21501319, 21501319, 21501320, 21501320, 21501321, 21501322, 21501322, 21501323, 21501318, 21501319, 21501319, 21501320, 21501320, 21501321, 21501321, 21501322, 21501322, 21501323, 21501319, 21501320, 21501320, 21501321, 21501321, 21501322, 21501322, 21501323, 21501323, 21501338, 21501338, 21501320, 21501321, 21501321, 21501322, 21501322, 21501323, 21501323, 21501321, 21501322, 21501322, 21501323, 21501324, 21501339, 21501339, 21501322, 21501323, 21501323, 21501324, 21501324, 21501325, 21501339, 21501323, 21501324, 21501324, 21501325, 21501325, 21501326, 21501337, 21501340, 21501324, 21501325, 21501325, 21501326, 21501335, 21501337, 21501339, 21501340, 21501341, 21501341, 21501325, 21501326, 21501326, 21501327, 21501335, 21501335, 21501338, 21501338, 21501341, 21501341, 21501342, 21501326, 21501327, 21501327, 21501328, 21501336, 21501336, 21501338, 21501339, 21501341, 21501341, 21501342, 21501342, 21501343, 21501327, 21501328, 21501328, 21501329, 21501330, 21501336, 21501336, 21501337, 21501337, 21501338, 21501338, 21501339, 21501340, 21501341, 21501342, 21501342, 21501343, 21501343, 21501328, 21501329, 21501329, 21501330, 21501335, 21501336, 21501337, 21501337, 21501338, 21501338, 21501339, 21501339, 21501340, 21501340, 21501341, 21501341, 21501342, 21501342, 21501343, 21501343, 21501344, 21501329, 21501330, 21501330, 21501337, 21501337, 21501338, 21501338, 21501339, 21501339, 21501340, 21501340, 21501341, 21501341, 21501342, 21501342, 21501343, 21501343, 21501344, 21501344, 21501345, 21501338, 21501339, 21501340, 21501340, 21501343, 21501344, 21501346, 21501332, 21501340, 21501342, 21501342, 21501343, 21501344, 21501344, 21501345, 21501346, 21501332, 21501340, 21501344, 21501344, 21501345, 21501345, 21501345, 21501343, 21501345, 21501346, 21501347, 21501348, 21501349, 21501346, 21501347, 21501347, 21501348, 21501348, 21501349, 21501349, 21501351, 21501352, 24071776, 21501347, 21501348, 21501348, 21501349, 21501349, 21501350, 21501350, 21501352, 21501348, 21501349, 21501349, 21501350, 21501350, 21501351, 21501352, 21501349, 21501350, 21501350, 21501351, 21501352, 21501353, 21501353, 21501350, 21501351, 21501351, 21501352, 21501352, 21501353, 21501353, 21501354, 21501354, 21501351, 21501352, 21501352, 21501353, 21501353, 21501354, 21501354, 21501352, 21501353, 21501353, 21501354, 21501354, 21501355, 21501353, 21501354, 21501354, 21501355, 21501355, 21501354, 21501355, 21501355, 21501356, 21501355, 21501356, 21501356, 21501357, 21501356, 21501357, 21501357, 21501358, 21501357, 21501358, 21501358, 21984494, 21984497, 22094804, 22099292, 22492151, 22525331, 22961450, 23888654, 23986151, 24071781, 24071782, 24354806, 24354806, 31732396, 21501358, 21501359, 21501359, 21501360, 21529937, 21569556, 21592474, 21592475, 21592476, 21713847, 21743837, 21743838, 21756778, 21756779, 21890805, 21893111, 21915019, 21943181, 21958377, 21984485, 21984497, 21984503, 21984503, 21984504, 21984505, 21984506, 21984508, 21984509, 21984509, 21984512, 22113607, 22170956, 22385149, 22425444, 22425446, 22492151, 22492154, 22551359, 22681170, 22760316, 22832681, 22961450, 22961450, 22961452, 22981285, 23040045, 23111498, 23760869, 23769220, 23769817, 24043259, 24043261, 24043262, 24043263, 24071779, 24071781, 24071781, 24071782, 24071782, 24071783, 24240329, 24240488, 24354805, 24354806, 24354806, 24354807, 24354807, 24386913, 24386914, 31732396, 21501359, 21501360, 21501360, 21501361, 21501361, 21501469, 21555380, 21569553, 21569556, 21569558, 21592474, 21592475, 21592477, 21619599, 21715417, 21743838, 21756727, 21756777, 21756778, 21756779, 21756780, 21818647, 21818647, 21818648, 21958377, 21984489, 21984490, 21984495, 21984498, 21984501, 21984502, 21984503, 21984504, 21984505, 21984505, 21984506, 21984506, 21984507, 21984509, 21984509, 21984510, 21984510, 21984511, 21984645, 22099293, 22099293, 22099295, 22170956, 22290536, 22385149, 22425445, 22425446, 22492150, 22492152, 22492153, 22492153, 22525332, 22525350, 22551359, 22551361, 22551362, 22832683, 22832683, 22961448, 22961450, 22961451, 23111500, 23657569, 23986152, 23986153, 24043261, 24071781, 24071781, 24071782, 24071782, 24071783, 24071783, 24071784, 24240330, 24354806, 24354807, 24354807, 24354808, 31732397, 21501360, 21504815, 21569557, 21592475, 21620280, 21627706, 21743839, 21756779, 21756779, 21756780, 21811856, 21984495, 21984503, 21984507, 21984508, 21984513, 22078250, 22170957, 22354280, 22385150, 22425445, 22492152, 22492153, 22492154, 22832683, 22961450, 22961451, 22961453, 23171677, 23198751, 23289636, 23398070, 23986153, 23986161, 24071782, 24071783, 24071783, 24071784, 24071784, 24240330, 24271593, 24354807, 24354807, 24354808, 21592476, 21592476, 21756779, 21984504, 21984514, 22425446, 22492154, 22961451, 23245096, 24252063, 24354807, 24354808, 22425446, 24071783, 24071784, 24240331, 21962315, 24071785, 21501589, 24387033, 21508324, 22089096, 21558530, 21847240, 21609412, 22038538, 21637766, 21637769, 21637771, 21637772, 21660687, 21886866, 22239169, 23029666, 24308543, 22052712, 24139995, 21683605, 21683593, 21683606, 21683606, 21683606, 21683608, 21683606, 21683608, 21683607, 21683609, 21683607, 21683608, 21683620, 22516575, 23052581, 21847911, 22476280, 22772305, 23052582, 23052582, 23052583, 24162915, 21737850, 21875030, 21739240, 21739306, 21739375, 24190811, 21754068, 23087813, 21926347, 23975311, 21929488, 24568878, 21986326, 21986328, 21986329, 21986333, 21986333, 21986394, 21986437, 24597298, 22734646, 23967002, 21986462, 22363134, 21986545, 24597404, 22012108, 22012109, 22239887, 22239891, 22012210, 22012198, 22012211, 22012212, 22012213, 22012212, 22012212, 22012214, 22012212, 22012213, 22012225, 22213810, 22239942, 22680878, 22747585, 22806796, 23216885, 24327216, 22239937, 22239940, 22633601, 22680878, 24327215, 24327216, 29368338, 22426391, 24327218, 22122370, 22122466, 22122558, 22295110, 22135952, 22135952, 22135959, 22135953, 22135974, 22301798, 22301814, 22742750, 24389087, 22395556, 24389093, 22868680, 22280264, 22373962, 22284892, 22883932, 22328693, 22798823, 22385016, 22426338, 22415442, 22415469, 22415471, 22949217, 24528848, 22415544, 22415569, 22415617, 22415618, 22415684, 22415762, 22415761, 22415828, 22485765, 22949391, 24477895, 22423277, 23224531, 22467655, 22467634, 22467637, 22467653, 22467641, 22467644, 22467658, 22467662, 22467642, 22467647, 22467647, 22467661, 22467649, 22467658, 22467663, 22467649, 22467667, 22467670, 22467672, 22467654, 22467655, 22467663, 22467667, 22467669, 22467672, 22467680, 22467652, 22467666, 22467655, 22467669, 22467654, 22467656, 22467657, 22467659, 22467675, 22467679, 22467656, 22467657, 22467657, 22467659, 22467670, 22467672, 22467673, 22467675, 22467676, 22467662, 22467672, 22467662, 22467663, 22467666, 22467671, 22467660, 22467663, 22467671, 22467674, 22467678, 22467663, 22467675, 22467678, 22467678, 22467679, 22467688, 22467661, 22467665, 22467672, 22467676, 22467676, 22467677, 22467678, 22467681, 22467682, 22467687, 22467670, 22467676, 22467678, 22467679, 22467681, 22467681, 22467666, 22467681, 22467684, 22467676, 22467677, 22467679, 22467682, 22467683, 22467676, 22467684, 22467681, 22467685, 22467678, 22467688, 22975312, 23164334, 24554944, 22467687, 22467687, 22467688, 22467689, 22467690, 22618525, 23034525, 23164337, 24554946, 24837969, 24554945, 22467690, 22467700, 24837971, 24554948, 22467691, 22467700, 24554948, 22467692, 22467697, 22467698, 22467703, 22596777, 24554949, 22467700, 22975318, 24554950, 22467695, 22467697, 22654123, 24469328, 24754761, 22467699, 22908612, 22467695, 22467696, 22467699, 22467702, 22908613, 22975319, 22975320, 23008501, 23444617, 24554950, 22908614, 23034527, 24554952, 24801905, 24837975, 24837976, 22467698, 22467700, 22975321, 23034532, 24554952, 22467700, 22467703, 22908615, 23444621, 22467703, 24554953, 22582464, 24554954, 22467709, 22467819, 22467821, 22868321, 22975324, 23444623, 24554953, 24554953, 24554956, 23937687, 24554956, 22908619, 22908620, 24554958, 24554957, 24837983, 23881247, 24554959, 24554961, 24554961, 24554962, 24837985, 22467952, 22467951, 22467951, 22975454, 23411954, 24555089, 22555710, 24598965, 22655155, 22655156, 22655159, 22655162, 24931712, 24648690, 24648692, 24931718, 22669889, 22670120, 22670344, 23076679, 22688265, 24665242, 22697245, 22697243, 22697244, 22697246, 24669733, 23090102, 24669735, 24669733, 24669735, 22725873, 22725875, 22725883, 24684048, 24967074, 24967078, 22739809, 23659277, 22769383, 24705805, 22840596, 22873725, 23054789, 23095084, 23095086, 23161791, 25024446, 22906887, 22907022, 22907151, 23195083, 23079728, 24860975, 23207216, 24924719, 23254988, 23261973, 23268940, 23268942, 23268952, 23268953, 23268953, 23268953, 23268952, 23268958, 23268963, 23845253, 23268966, 23375956, 23845256, 23268999, 23309249, 23375956, 23845255, 24955587, 25110854, 23309250, 23269040, 23309290, 23349542, 23349544, 23349545, 23349546, 23349546, 23349547, 23349548, 23349547, 23349548, 23349549, 23349550, 24995879, 24995880, 23475461, 23475462, 24995881, 24995882, 23349561, 23416252, 23416254, 23860863, 23885551, 24910254, 24995881, 24995882, 24995884, 25278907, 23416253, 23416253, 23885552, 24995883, 24995884, 25278908, 23416252, 23416254, 23475464, 23885552, 25278908, 25278909, 24127363, 25278909, 23416254, 24995886, 23349570, 23416255, 25278911, 24995891, 23482957, 23482958, 23482958, 23482959, 23482945, 23482946, 23482959, 23482960, 23482960, 23482961, 23482947, 23482960, 23482960, 23482961, 23482960, 23482962, 23482957, 23482961, 23482961, 23482963, 23482963, 23482970, 24976963, 23952258, 23482974, 23758836, 23952258, 24235903, 25034069, 25062591, 25345614, 25345615, 23482975, 23482976, 23516140, 23542166, 23744102, 23823936, 23952258, 23952259, 23952260, 23952261, 23952262, 24280443, 24701703, 24760030, 25062589, 25062589, 25062590, 25062591, 25062591, 25062592, 25235426, 25262399, 25345615, 25345615, 25345624, 25377723, 23542170, 23952259, 24280444, 24445323, 24532924, 25062590, 25062591, 25345615, 25345615, 23952260, 24098976, 25034071, 25062591, 23486158, 23489349, 23955452, 23549325, 23549363, 23549391, 23549404, 25095796, 23549445, 23549458, 23549468, 23549474, 23549473, 23549479, 23549485, 25095843, 25095845, 25264392, 25268680, 25378869, 23549487, 23549565, 23549652, 23549705, 23549766, 23549810, 23549847, 23985700, 23601373, 23601374, 23601374, 23601375, 23601375, 23601376, 23601379, 23601377, 23601378, 23601367, 23601378, 23601379, 24596442, 24811672, 25321609, 25404822, 23705285, 23755617, 24339651, 25093275, 25121798, 25121798, 25404822, 25404823, 25121799, 23809190, 24551989, 23860997, 23861000, 23861000, 24141277, 24540653, 25251609, 23909854, 23909865, 24165705, 24005244, 24084634, 24019284, 24019380, 24019477, 25613871, 24025783, 25305480, 24034710, 24228132, 24164019, 24164007, 24164020, 24164020, 24164021, 24164022, 24164033, 25100558, 25403120, 25403121, 25686144, 24164929, 24293252, 24355952, 25499084, 24372180, 25507200, 24402007, 25522116, 24421550, 24421541, 24421556, 24421556, 24421542, 24421557, 24421543, 24421544, 24421552, 24421555, 24421555, 24421556, 24421556, 24421557, 24421557, 24421558, 24421558, 24421558, 24421558, 24421559, 24421561, 24421561, 24421562, 24421560, 24421562, 24421564, 24421562, 25531885, 24421570, 25531885, 25531887, 24421570, 25503364, 25531888, 25814911, 25531888, 25531887, 25531888, 25531889, 25814912, 25814913, 24421572, 25531887, 25531887, 25531889, 24421572, 24421573, 24705203, 25503366, 25503367, 24421573, 24421575, 24749742, 24806339, 25117575, 25119388, 25189315, 25503367, 25503370, 25531887, 25531888, 25531888, 25531889, 25531889, 25531890, 25531890, 25700437, 25814913, 25814914, 25814914, 25814915, 25531888, 25531890, 25531890, 25531891, 25158584, 25531891, 25531892, 25700438, 24421577, 25185450, 25700439, 25531892, 24705206, 24461227, 25834749, 24578742, 24578743, 24578857, 24578857, 24578970, 24578972, 25610591, 25893515, 24714992, 25650086, 24721651, 24721653, 25964959, 25964959, 24842009, 26025140, 24896153, 26052210, 24905178, 25773700, 24988843, 24988845, 24988846, 24988846, 26098555, 25506561, 25815533, 26015341, 25077924, 25077925, 25636204, 25831549, 25860072, 26143096, 25860073, 25191138, 25916687, 25220306, 26214287, 25294790, 25294791, 25607616, 26137052, 26251528, 26251529, 25407678, 25407686, 25407819, 25996430, 25407958, 26308111, 25582885, 25582885, 26395576, 26112552, 25591507, 26116862, 25813591, 26142275, 25813792, 26228005, 25817216, 26512742, 25895608, 25895605, 26268912, 26268914, 25920442, 25920442, 26195699, 25978771, 25947665, 26294941, 25949333, 25949478, 25949623, 26578944, 25957067, 25957174, 25957281, 26214118, 26020398, 26499858, 26021967, 26332093, 26024280, 26333251, 26616275, 26037097, 26037098, 26037098, 26037100, 26622683, 26339660, 26133697, 26339660, 26654789, 26038297, 26340261, 26194480, 26194583, 26194686, 26418452, 26230293, 26407734, 26275961, 26742114, 26470962, 26470965, 26470965, 26470963, 26470967, 26470969, 26470971, 26470969, 26470968, 26470973, 26470978, 26528070, 26725141, 26871726, 26528075, 26839620, 26556597, 26556598, 26556598, 26556599, 26556600, 26556598, 26556600, 26556601, 26539924, 26591070, 26585172, 26585173, 26585175, 26585175, 26585174, 26585176, 26585177, 26585178, 26585176, 26585177, 26585179, 26585180, 26585179, 26585180, 26585181, 26613694, 26613694, 26613696, 26613696, 26613698, 26896723, 26613697, 26613698, 26613698, 26613699, 26613699, 26782247, 26613698, 26613700, 26613701, 26782247, 26896724, 26896724, 26613699, 26642204, 26642203, 26642219, 26642220, 26642204, 26642205, 26642205, 26642218, 26642218, 26642219, 26642220, 26642204, 26642205, 26642205, 26642206, 26642218, 26642219, 26642219, 26642220, 26642221, 26642205, 26642206, 26642206, 26642207, 26642220, 26642221, 26642221, 26642206, 26642207, 26642219, 26642220, 26642220, 26642221, 26642221, 26642222, 26642207, 26642208, 26642208, 26642220, 26642220, 26642221, 26642221, 26642222, 26642222, 26642208, 26642209, 26642210, 26642220, 26642220, 26642221, 26642221, 26642222, 26642222, 26642223, 26642221, 26642222, 26642222, 26642223, 26642223, 26642221, 26642223, 26642223, 26642224, 26642225, 26642234, 26642234, 26642235, 26642235, 26925140, 26925243, 26925244, 26642235, 26642235, 26642236, 26925244, 26925244, 26925245, 26642235, 26642236, 26642236, 26810768, 26925244, 26925245, 26642236, 26642237, 26810768, 26925245, 26925245, 26925246, 26642237, 26741320, 26810769, 26810772, 26830249, 26842032, 26877949, 26925245, 26925246, 26925246, 26925247, 27332123, 26642238, 26642240, 26719636, 26797490, 26810769, 26815058, 26842031, 26842032, 26842033, 26842034, 26842035, 26852442, 26925244, 26925245, 26925245, 26925246, 26925246, 26925247, 26925247, 26925248, 26957354, 26957355, 34302836, 26925246, 26925248, 26797046, 27002655, 26840415, 27024341, 26952757, 26952758, 27080513, 27080514, 26979301, 26979304, 26979371, 26979371, 26979305, 26979374, 26979375, 26979441, 26979442, 27010634, 27010636, 27093847, 27093848, 27093848, 27093849, 34471438, 27093848, 27093849, 26979629, 27093948, 26987892, 26987894, 26987896, 27098081, 27098083, 27098084, 27002777, 27105522, 27018271, 27113268, 27041838, 27041840, 27041840, 27041841, 27041841, 27041842, 27041842, 27041842, 27041843, 27041843, 27041843, 27041844, 27041844, 27041847, 27125054, 27125054, 27041856, 27125055, 27125056, 27125056, 27125054, 27125055, 27125055, 27125056, 27125056, 27125058, 27062656, 27135461, 27113673, 27160970, 27136130, 27172201, 27208057, 27208160, 27208161, 27208253, 27208252, 27208253, 27208253, 27208253, 27208254, 27208254, 27208254, 27208255, 27208255, 27208269, 27208270, 27208271, 27208272, 27208274, 27208255, 27208256, 27208261, 27208270, 27208270, 27208271, 27208271, 27208281, 27208256, 27208257, 27208257, 27208258, 27208264, 27208264, 27208265, 27208265, 27208267, 27208269, 27208270, 27208270, 27208271, 27208271, 27208272, 27208272, 27208273, 27208273, 27208257, 27208258, 27208259, 27208260, 27208261, 27208261, 27208262, 27208262, 27208263, 27208263, 27208264, 27208264, 27208265, 27208265, 27208266, 27208266, 27208267, 27208267, 27208268, 27208268, 27208269, 27208269, 27208270, 27208270, 27208271, 27208271, 27208272, 27208272, 27208273, 27208273, 27208274, 27208281, 27208258, 27208259, 27208259, 27208260, 27208261, 27208261, 27208262, 27208262, 27208263, 27208263, 27208264, 27208264, 27208265, 27208265, 27208266, 27208267, 27208268, 27208269, 27208270, 27208271, 27208271, 27208272, 27208272, 27208273, 27208273, 27208259, 27208260, 27208263, 27208264, 27208265, 27208265, 27208266, 27208266, 27208267, 27208270, 27208271, 27208271, 27208272, 27208272, 27208273, 27208273, 27208275, 27208265, 27208267, 27208271, 27208272, 27208264, 27208271, 27208274, 27208274, 27208274, 27208270, 27208275, 27208267, 27208274, 27208275, 27208267, 27208268, 27208269, 27208272, 27208276, 27208276, 27208268, 27208269, 27208270, 27208276, 27208277, 27208269, 27208270, 27208271, 27208277, 27208277, 27208269, 27208270, 27208271, 27208278, 27208279, 27208270, 27208271, 27208271, 27208273, 27208274, 27208277, 27208277, 27208278, 27208278, 27208279, 27208271, 27208272, 27208272, 27208273, 27208273, 27208274, 27208274, 27208277, 27208278, 27208278, 27208279, 27208279, 27208272, 27208273, 27208273, 27208274, 27208274, 27208275, 27208276, 27208277, 27208278, 27208279, 27208279, 27208281, 27208273, 27208274, 27208274, 27208275, 27208276, 27208277, 27208278, 27208278, 27208279, 27208279, 27208280, 27208280, 27208291, 27208274, 27208275, 27208275, 27208276, 27208276, 27208278, 27208279, 27208279, 27208280, 27208280, 27208275, 27208276, 27208279, 27208279, 27208280, 27208280, 27208281, 27208282, 27208276, 27208277, 27208279, 27208280, 27208280, 27208281, 27208277, 27208278, 27208278, 27208279, 27208280, 27208281, 27208281, 27208282, 27208282, 27208283, 27208278, 27208279, 27208281, 27208281, 27208282, 27208282, 27208283, 27208279, 27208282, 27208282, 27208285, 27208282, 27208283, 27208283, 27208281, 27208282, 27208283, 27208283, 27208284, 27208282, 27208283, 27208284, 27208284, 27208283, 27208284, 27208284, 27208285, 27208285, 27208284, 27208285, 27208285, 27208286, 27208286, 27208287, 27208285, 27208286, 27208286, 27208287, 27208289, 27240377, 34585860, 27208286, 27208287, 27208287, 27208288, 27208288, 27208289, 27208289, 27208290, 27240374, 27240376, 27240379, 27240380, 27240381, 27208287, 27208288, 27208288, 27208289, 27208289, 27208290, 27208291, 27208295, 27208297, 27240376, 27240377, 27240379, 27240379, 28735758, 33294066, 34585861, 27208288, 27208289, 27208289, 27208290, 27208290, 27208291, 27208291, 27208292, 27208294, 27208297, 27208298, 27208298, 27240358, 27240374, 27240376, 27240376, 27240377, 27240378, 27240378, 27240379, 27240379, 27615149, 27615150, 28735758, 29495546, 30403832, 33294069, 34585861, 27208289, 27208290, 27208290, 27208291, 27208291, 27208292, 27208292, 27208293, 27208293, 27208294, 27208295, 27208296, 27208297, 27208298, 27208298, 27208299, 27208299, 27240357, 27240358, 27240359, 27240367, 27240376, 27240377, 27240378, 27240378, 27240379, 27240379, 27240380, 27240380, 27240382, 27615149, 27615150, 28023272, 28735758, 28735759, 28964674, 29222921, 29996051, 31422349, 34585862, 27208290, 27208291, 27208291, 27208292, 27208292, 27208293, 27208293, 27208294, 27208295, 27208295, 27208298, 27208299, 27208299, 27208300, 27240359, 27240372, 27240377, 27240378, 27240378, 27240379, 27240379, 27240380, 27240380, 27240381, 27240382, 27240384, 27615150, 27848353, 34585862, 27208291, 27208292, 27208292, 27208293, 27208293, 27208294, 27208294, 27208295, 27208297, 27208298, 27208299, 27208300, 27240359, 27240362, 27240363, 27240365, 27240377, 27240378, 27240379, 27240380, 27240380, 27240381, 27240382, 27596979, 27615151, 29118432, 29495547, 34585863, 27208292, 27208293, 27208293, 27208294, 27208294, 27208296, 27208299, 27208300, 27208300, 27208301, 27237292, 27240360, 27240360, 27240363, 27240378, 27240379, 27240379, 27240380, 27240380, 27240381, 27240381, 27240382, 27848354, 27208293, 27208294, 27208294, 27208295, 27208295, 27208296, 27208299, 27208300, 27208301, 27208301, 27240359, 27240360, 27240360, 27240364, 27240373, 27240377, 27240381, 27240382, 27240383, 29495548, 34585864, 27208294, 27208295, 27208295, 27208296, 27208298, 27208299, 27208300, 27208301, 27208301, 27240360, 27240368, 27240379, 27240380, 27240381, 27240382, 27240384, 27615152, 30862564, 31966372, 27208295, 27208296, 27208296, 27208297, 27208297, 27208298, 27208299, 27208300, 27208300, 27208301, 27208301, 27208302, 27208302, 27240359, 27240361, 27240364, 27240365, 27240373, 27240380, 27240381, 27240382, 27615150, 27615152, 27615153, 27208296, 27208297, 27208297, 27208298, 27208298, 27208299, 27208299, 27208300, 27208301, 27208301, 27208302, 27208302, 27208303, 27240361, 27240362, 27240362, 27240380, 27240382, 27240382, 27240383, 27240386, 27615152, 27848356, 27208297, 27208298, 27208298, 27208299, 27208299, 27208300, 27208301, 27208301, 27208302, 27208303, 27208303, 27240361, 27240362, 27240377, 27240378, 27240380, 27240381, 27240385, 27615149, 29495550, 27208298, 27208299, 27208299, 27208300, 27208300, 27208301, 27208302, 27208302, 27208303, 27208303, 27240359, 27240361, 27240362, 27240363, 27240363, 27240369, 27240380, 27240382, 27240383, 27240384, 27615155, 27208299, 27208300, 27208300, 27208301, 27208301, 27208302, 27208302, 27208303, 27208304, 27240362, 27240363, 27240364, 27240365, 27240367, 27240370, 27240380, 27240381, 27240381, 27240384, 27208300, 27208301, 27208301, 27208302, 27208302, 27208303, 27208304, 27208305, 27240363, 27240364, 27240372, 27240380, 27240384, 27848358, 27208301, 27208302, 27208303, 27208303, 27208304, 27208304, 27208305, 27240363, 27240364, 27240366, 27240371, 27615156, 27208302, 27208303, 27208303, 27208304, 27208304, 27208305, 27208305, 27240364, 27240379, 27240380, 27240381, 27240385, 27240386, 27596983, 28735764, 27208303, 27208304, 27208304, 27208305, 27240365, 27240365, 27240366, 27240369, 27240375, 27240381, 27240383, 27240384, 27240386, 27240387, 27240388, 27208305, 27208306, 27240364, 27240366, 27240380, 27208305, 27208306, 27208306, 27208307, 27240366, 27240366, 27240367, 27240368, 27240370, 27240383, 27240383, 27240385, 27240387, 27208306, 27208307, 27208307, 27208308, 27240365, 27240366, 27240366, 27240367, 27240367, 27240369, 27240377, 27240380, 27240381, 27240382, 27240383, 27240384, 27240384, 27240385, 27240386, 27240386, 27240387, 27240387, 27240388, 27208307, 27225064, 27240367, 27240386, 27240388, 27208308, 27208309, 27240366, 27240367, 27240367, 27240368, 27240368, 27240370, 27240372, 27240373, 27240381, 27240383, 27240384, 27240385, 27240386, 27240387, 27240387, 27240388, 27240388, 27240389, 27240389, 27240390, 27240390, 27615157, 27615158, 27615160, 29495556, 34585871, 27208309, 27225065, 27240367, 27240367, 27240368, 27240368, 27240369, 27240372, 27240372, 27240375, 27240378, 27240381, 27240382, 27240385, 27240386, 27240386, 27240387, 27240388, 27240388, 27240389, 27240389, 27240390, 27240390, 27240391, 27240392, 27241732, 27848362, 28564838, 28735768, 29495557, 27240367, 27240368, 27240368, 27240369, 27240369, 27240370, 27240382, 27240385, 27240387, 27240388, 27240388, 27240389, 27240389, 27240390, 27240390, 27240392, 27596988, 27615160, 27689191, 27241831, 27241911, 27241915, 27241991, 27242000, 27257215, 27257225, 27266354, 27269422, 27272425, 27272444, 27272432, 27272441, 27272445, 27272425, 27272426, 27272426, 27272430, 27272439, 27272439, 27272426, 27272427, 27272427, 27272437, 27272439, 27272441, 27272442, 27272443, 27272443, 27272444, 27272445, 27272447, 27272427, 27272428, 27272431, 27272433, 27272439, 27272441, 27272442, 27272443, 27272443, 27272444, 27272444, 27272445, 27272428, 27272430, 27272433, 27272433, 27272441, 27272442, 27272442, 27272443, 27272443, 27272444, 27272444, 27272445, 27272445, 27272446, 27272446, 27272447, 27272447, 27272448, 27272448, 27272449, 27272449, 27272464, 27272430, 27272430, 27272431, 27272432, 27272434, 27272438, 27272440, 27272441, 27272442, 27272443, 27272443, 27272444, 27272444, 27272445, 27272445, 27272446, 27272447, 27272448, 27272449, 27272450, 27272453, 27272432, 27272450, 27272446, 27272447, 27272447, 27272448, 27272450, 27272451, 27272467, 27272437, 27272446, 27272446, 27272450, 27272456, 27272435, 27272444, 27272453, 27272441, 27272446, 27272448, 27272449, 27272450, 27272452, 27272452, 27272453, 27272453, 27272454, 27272451, 27272444, 27272445, 27272447, 27272449, 27272441, 27272451, 27272450, 27272452, 27272453, 27272454, 27272449, 27272452, 27272455, 27272471, 27272457, 27272458, 27272451, 27272456, 27272452, 27272458, 27272456, 27272462, 27272457, 27272454, 27272460, 27272461, 27272455, 27272457, 27272458, 27272459, 27272461, 27272459, 27272460, 27272461, 27272461, 27272462, 27272463, 27272478, 27272455, 27272456, 27272458, 27272461, 27272456, 27272457, 27272458, 27272459, 27272460, 27272463, 27272457, 27272458, 27272458, 27272459, 27272459, 27272461, 27272463, 27272464, 27272468, 27272458, 27272459, 27272460, 27272461, 27272461, 27272462, 27272463, 27272459, 27272460, 27272461, 27272461, 27272463, 27272463, 27272464, 27272464, 27272465, 27280541, 34617947, 27272460, 27272461, 27272461, 27272462, 27272462, 27272463, 27272463, 27272464, 27272464, 27272465, 27272465, 27272466, 27647235, 27272461, 27272462, 27272462, 27272463, 27272463, 27272464, 27272464, 27272465, 27272465, 27272466, 27272467, 27272481, 27517662, 27647232, 31998458, 27272462, 27272463, 27272463, 27272464, 27272464, 27272465, 27272465, 27272466, 27272466, 27272467, 28767845, 27272463, 27272464, 27272464, 27272465, 27272465, 27272466, 27272466, 27272467, 27272464, 27272465, 27272465, 27272466, 27272466, 27272467, 27272467, 27272468, 27272483, 27272465, 27272466, 27272466, 27272467, 27272467, 27272468, 27272468, 27272471, 27272483, 27272483, 27272484, 27272466, 27272467, 27272467, 27272468, 27272468, 27272469, 27272483, 27272484, 27272484, 27272485, 27272467, 27272468, 27272468, 27272469, 27272469, 27272470, 27272471, 27272471, 27272473, 27272484, 27272484, 27272485, 27272468, 27272469, 27272469, 27272470, 27272470, 27272471, 27272471, 27272472, 27272483, 27272484, 27272485, 27272486, 27272488, 27272469, 27272470, 27272470, 27272471, 27272471, 27272472, 27272472, 27272473, 27272473, 27272474, 27272478, 27272480, 27272485, 27272485, 27272486, 27272486, 27272487, 27272488, 27272489, 27272490, 27272491, 27272470, 27272471, 27272471, 27272472, 27272472, 27272473, 27272473, 27272474, 27272478, 27272485, 27272485, 27272486, 27272486, 27272487, 27272489, 27272489, 27272490, 27272471, 27272472, 27272472, 27272473, 27272473, 27272474, 27272474, 27272475, 27272478, 27272478, 27272479, 27272480, 27272480, 27272482, 27272483, 27272485, 27272486, 27272486, 27272487, 27272487, 27272488, 27272488, 27272472, 27272473, 27272473, 27272474, 27272475, 27272476, 27272476, 27272479, 27272480, 27272481, 27272481, 27272482, 27272486, 27272486, 27272487, 27272487, 27272488, 27272489, 27272490, 27272473, 27272474, 27272474, 27272475, 27272481, 27272481, 27272483, 27272485, 27272487, 27272487, 27272488, 27272489, 27272491, 34617954, 27272474, 27272475, 27272476, 27272476, 27272477, 27272482, 27272487, 27272487, 27272488, 27272489, 27272489, 27272490, 27272475, 27272476, 27272477, 27272477, 27272488, 27272488, 27272489, 27272490, 27272490, 27272493, 27272476, 27272488, 27272489, 27272489, 27272490, 27272490, 27272491, 27272485, 27272489, 27272489, 27272491, 27272493, 27272489, 27272490, 27647244, 27272490, 27272490, 27272491, 27272493, 27272480, 27272490, 34617957, 27272491, 27272491, 27272493, 27272493, 27272494, 27272494, 27272494, 27272494, 27272495, 27272495, 27272495, 27272496, 27272495, 27272496, 27272496, 27272497, 27272497, 27272498, 27272499, 27272499, 27272499, 27272500, 27272501, 27272501, 27272502, 27272502, 27272503, 27272503, 27272504, 27272504, 27272505, 27272511, 27647255, 27647257, 27880458, 27912378, 31998474, 33326154, 34617968, 27272502, 27272503, 27272503, 27272504, 27272504, 27272505, 27272505, 27272506, 27272507, 27272508, 27273829, 27343986, 27412134, 27412135, 27412136, 27647253, 27647254, 27647254, 27647255, 27647255, 27647256, 27647256, 27647257, 27647257, 27647258, 27665568, 27665569, 27701105, 27721286, 27721286, 27721287, 27731513, 27794233, 27818600, 27880459, 27899951, 28055383, 28060252, 28063001, 28245302, 28596935, 28596936, 28767862, 28767864, 28767865, 28767865, 29235713, 29235714, 29527652, 29527653, 29527653, 29527654, 30435915, 30435926, 30435936, 30435940, 30854802, 31023790, 31998473, 31998474, 31998476, 31998476, 32118188, 32145007, 33163827, 33326127, 33537503, 34617968, 27272503, 27272504, 27272504, 27272505, 27272506, 27272506, 27272507, 27272507, 27412136, 27517683, 27572564, 27647252, 27647254, 27647255, 27647255, 27647256, 27647256, 27647257, 27647257, 27647258, 27721287, 27731514, 27736915, 27927545, 28518798, 29150538, 29527653, 30276034, 30287406, 31458425, 31998473, 31998476, 32381686, 34617969, 27272504, 27272505, 27272505, 27272506, 27272506, 27272507, 27272507, 27272508, 27273830, 27280564, 27412136, 27459615, 27520234, 27572563, 27629084, 27629086, 27629086, 27647251, 27647253, 27647254, 27647255, 27647256, 27647257, 27647257, 27647258, 27647258, 27721287, 27721287, 27721288, 27880460, 27897125, 28055384, 28063003, 28636860, 28767865, 28767866, 29120361, 29284853, 29527653, 29527654, 29527654, 30435939, 30854803, 31998474, 31998477, 33326143, 34617969, 27272505, 27272506, 27272506, 27272507, 27272508, 27273831, 27313017, 27412137, 27572566, 27572567, 27629084, 27629085, 27647253, 27647254, 27647255, 27647257, 27647257, 27647258, 27647258, 27647259, 27647259, 27721288, 27880460, 28596939, 28767865, 28767866, 28996781, 29108542, 29527655, 31998475, 33326174, 34617970, 27272506, 27272507, 27272507, 27272509, 27272509, 27273831, 27280564, 27412137, 27412138, 27459616, 27518839, 27572566, 27629085, 27647252, 27647254, 27647254, 27647255, 27647256, 27647256, 27647257, 27647258, 27647259, 27647259, 27701107, 27721288, 27721289, 27731516, 27880461, 28767866, 28767867, 29527654, 31270279, 31998476, 31998478, 31998478, 32381688, 34617970, 27272508, 27647258, 27647259, 27721289, 27731516, 27880461, 27912203, 28245304, 28767866, 34617971, 27272508, 27272509, 27412138, 27495709, 27518840, 27647255, 27647256, 27647257, 27647257, 27647258, 27647259, 27647260, 27647260, 27721289, 27721290, 27880462, 28063002, 28767867, 28767868, 31998479, 31998479, 32381689, 34617971, 27272509, 27273833, 27280565, 27459618, 27518924, 27647256, 27647256, 27647257, 27647257, 27647258, 27647259, 27647259, 27647260, 27647261, 27647261, 27701109, 27927549, 28055381, 28063170, 28245305, 28767868, 28996783, 29235718, 29527656, 29599843, 30276037, 34617972, 27272510, 27647259, 27647260, 27647261, 27731517, 29527657, 30320253, 27647259, 27647260, 27647260, 27647261, 27721291, 27880463, 28767869, 29078676, 29235718, 34617973, 27647259, 27647260, 27880464, 29918154, 31998481, 33326176, 34617973, 27721291, 27880464, 33326133, 27272530, 27647276, 27275167, 27275166, 27275169, 27275169, 27275170, 27275312, 27965761, 27648596, 32383024, 27648589, 27648596, 27648593, 27275458, 27648740, 27288637, 27288641, 27288639, 27288640, 27288642, 27655329, 29086747, 27655333, 27655333, 27655335, 27729364, 27353544, 27687786, 27415483, 28839362, 27551782, 27551783, 27551784, 27551785, 27551782, 27551784, 34757615, 27786905, 27860933, 28907513, 29027196, 27860935, 28206048, 28907513, 29746327, 34757618, 27646736, 27646737, 27646738, 27646794, 27646798, 27834378, 27646855, 27646858, 27834439, 28955048, 27718960, 27719044, 27719120, 27870587, 27762877, 28125653, 32390202, 27765182, 27765267, 27765351, 27765353, 27765354, 27893684, 32244907, 27893685, 27767976, 27895000, 27872638, 27872643, 27872642, 27872642, 27872640, 27965642, 27947332, 27947334, 27947333, 29067942, 27947330, 27985674, 27985676, 27985677, 27985676, 27985680, 27985681, 27985677, 27985680, 27985681, 27985765, 27985767, 27985768, 28953532, 28003852, 28077882, 28003854, 28003854, 27985856, 27985857, 28237141, 28003936, 28003938, 29884335, 28022003, 28022002, 28022005, 28022014, 28022005, 28022006, 28022006, 28022022, 28022005, 28022006, 28022008, 28022023, 28022023, 28022004, 28022005, 28022006, 28022024, 28022005, 28022006, 28022007, 28022024, 28022006, 28022007, 28022007, 28022009, 28022009, 28022011, 28022019, 28022024, 28022024, 28022025, 28022027, 28022008, 28022008, 28022009, 28022009, 28022010, 28022012, 28022025, 28022026, 28022027, 28022008, 28022009, 28022010, 28022010, 28022025, 28022029, 28022009, 28022010, 28022010, 28022011, 28022011, 28022025, 28022026, 28022026, 28022027, 28022028, 28022010, 28022011, 28022011, 28022014, 28022026, 28022026, 28022027, 28022027, 28022011, 28022012, 28022013, 28022021, 28022026, 28022027, 28022027, 28022012, 28022013, 28022014, 28022021, 28022027, 28022027, 28022028, 28022031, 28022013, 28022015, 28022027, 28022028, 28022028, 28022028, 28022028, 28022029, 28022029, 28022030, 28022031, 28022028, 28022029, 28022029, 28022037, 28022030, 28022031, 28096050, 28022037, 28022037, 28022038, 28022042, 28022043, 28022043, 28022044, 28040339, 28096056, 28096056, 28096057, 28106284, 28169391, 28255229, 29142634, 29142635, 29142635, 29371550, 29453438, 29902421, 29902423, 29902423, 29983351, 30402928, 30650803, 31398646, 32373244, 34992738, 28022043, 28022044, 28022044, 28022045, 28022045, 28022046, 28040339, 28075876, 28096056, 28096057, 28096057, 28106284, 28111687, 28255227, 28255228, 28255229, 28286972, 28302316, 28339195, 28430146, 28430146, 28430834, 28437769, 28809344, 28971705, 28971706, 29142634, 29142635, 29142635, 29142636, 29257014, 29348785, 29371550, 29495130, 29527397, 29610485, 29610486, 29670607, 29781104, 29902423, 29902423, 29902424, 29902424, 29974610, 30650804, 30810702, 30810702, 30810711, 31398559, 32488147, 32756457, 33700910, 33700915, 33912275, 34985508, 34992739, 28022044, 28022045, 28022046, 28040339, 28075876, 28096057, 28106284, 28134810, 28255230, 28302316, 28339194, 28430152, 28437772, 28620073, 28809345, 29142635, 29142635, 29142636, 29610492, 29902423, 31041732, 31398561, 32373244, 32373247, 33700920, 33700924, 34985361, 34992739, 28022045, 28096058, 28106285, 28255230, 28620073, 29142636, 29902424, 30299203, 32373248, 32756458, 34247229, 28040339, 28075877, 28255230, 29142636, 29610485, 31229574, 34992740, 28075878, 28096059, 29142636, 28430161, 34992741, 28096060, 29142637, 29142638, 29902426, 29902426, 34992742, 28096060, 28255233, 28998710, 28058648, 28058646, 28058648, 28058649, 28058650, 28058648, 28058648, 28124592, 29160949, 28124593, 29513440, 28638383, 32774767, 35011050, 28129723, 28129723, 28129724, 28129724, 28309076, 29196482, 35046586, 30864559, 32427094, 28149905, 28309078, 28170085, 28170085, 28170086, 28170086, 28170071, 28170086, 28170086, 28170087, 28170087, 28170087, 28329258, 35066768, 28170102, 28180314, 28243034, 28329259, 28361002, 28504175, 28504178, 29216665, 29601426, 29976452, 30724834, 30959218, 32447276, 28180314, 28208840, 28329259, 28329260, 28376345, 28504180, 28512091, 28694102, 28694103, 29085660, 29088342, 29216665, 29216665, 29445580, 29569161, 29684515, 29684515, 29789132, 29976453, 29976453, 29976454, 30366949, 32447277, 32593808, 32830486, 33986305, 35066769, 28190539, 28190538, 28190540, 28190540, 28190541, 32457501, 28339485, 28522319, 28659035, 28704328, 28704329, 29694738, 29694743, 29986679, 30058866, 30160976, 30894963, 34175686, 28201341, 28201343, 28361551, 28428850, 28247587, 28247683, 28247690, 28247780, 28247800, 29124504, 28247818, 29124518, 28315976, 28315977, 29161285, 30049396, 28316752, 29409679, 28364726, 28426585, 28488414, 28488429, 28488430, 28488430, 28488430, 28488431, 28488431, 28488432, 28488433, 28488432, 28488445, 28663352, 28853273, 29375837, 35225940, 28488446, 28488447, 28505096, 28520173, 28520342, 28520346, 28535519, 28572395, 28663351, 28670974, 28853274, 29120571, 29204907, 29359330, 29375836, 29375837, 29375837, 29375842, 29490214, 29539550, 29604752, 29843686, 30135621, 30135624, 30135625, 30296793, 30636130, 30719471, 31043907, 31043910, 31043911, 31631762, 32606446, 32606448, 33934093, 33934103, 33934118, 34145477, 34145478, 35225940, 28572396, 28663351, 28853275, 29244832, 29375837, 29461534, 29843689, 30034212, 30135625, 31043911, 32606449, 32606450, 35225941, 29375838, 31631824, 29375839, 30135627, 28521758, 28521759, 28521759, 32623110, 30030968, 30152287, 28527412, 29863176, 28551916, 28551923, 28551924, 28551926, 28695094, 29875436, 29875438, 30167378, 28552259, 28552263, 28552257, 28552267, 28552278, 28787242, 29407754, 29875604, 28582603, 28582603, 28582604, 28582605, 28582608, 29890772, 30182709, 30931092, 31090995, 32653535, 29422925, 28656358, 28656358, 28656359, 30219587, 31127876, 29288870, 29459800, 30338566, 31715799, 28838264, 28838264, 28838265, 28838267, 28838272, 28838277, 28838274, 28838273, 28838273, 28838276, 28838275, 28838282, 28838278, 28838281, 28838291, 29422429, 30018604, 30018604, 31058925, 29908167, 29028200, 29550759, 29550760, 34320396, 34320399, 30310548, 29550761, 35400866, 29379838, 30078735, 29550767, 28839640, 29028879, 28848075, 28848240, 28848402, 31064018, 28853510, 28853512, 28853513, 28853514, 30318164, 29787292, 29910872, 30318166, 31226451, 30318165, 28853844, 30026392, 28854091, 28854094, 33172487, 30318455, 28860308, 30321561, 29022215, 33256548, 29127527, 29524455, 29218116, 29218117, 29218118, 29218119, 29218115, 29218115, 29218116, 29218116, 29218118, 29218120, 29218121, 29740677, 29740677, 29740678, 31234536, 29740678, 30379144, 31408746, 29740679, 31248847, 35590782, 29740679, 30500467, 31084299, 29609675, 29740681, 30208529, 30208530, 30208531, 29740683, 29596655, 29596661, 32644930, 34488102, 29752708, 29837045, 29765105, 31522341, 29921383, 29921383, 29921384, 29921384, 29921383, 29921385, 29921384, 29921386, 29921387, 31600480, 30092312, 32348237, 29950230, 30092312, 30092313, 30092313, 30560169, 30852101, 30869725, 31760386, 30852101, 29975382, 30119315, 29979074, 30152902, 30001230, 30132235, 30132235, 30132236, 30600085, 30892023, 35950862, 30006596, 30006597, 30006598, 30602769, 31802986, 30134918, 30230229, 30246736, 30263225, 30263238, 30263226, 30263227, 30263240, 30263241, 30263241, 30263243, 30263227, 30263228, 30263241, 30263242, 30263242, 30263243, 30263243, 30263228, 30263229, 30263240, 30263242, 30263242, 30263243, 30263243, 30263244, 30263243, 30263243, 30263244, 30263244, 30263245, 30263243, 30263253, 30263254, 30263255, 32519166, 31771410, 30263257, 30263258, 32456079, 33493853, 30263257, 30263258, 30263258, 30603918, 30648004, 30675555, 30731091, 31023030, 31197622, 33877064, 30263258, 30263259, 30377621, 30615738, 30731091, 30731092, 30969728, 31023027, 31023030, 31023031, 31023031, 31095218, 31931311, 31931313, 31931313, 31931314, 33493851, 33493852, 33493854, 33493854, 33493855, 36113346, 30263259, 30731091, 30731093, 30731093, 30731094, 30731094, 30780233, 31023028, 31023031, 31023031, 31023032, 31095218, 31413527, 31771412, 31931315, 32519165, 33493853, 33493855, 34821530, 34821532, 34821557, 35032884, 36113347, 30263261, 30492159, 30615740, 30648005, 30731091, 30731093, 30731093, 30731094, 30731095, 30731100, 30901706, 30965563, 31023029, 31023031, 31023032, 31023032, 31095216, 31190474, 31383165, 31454909, 31523537, 31771412, 31771414, 31931312, 32519165, 32641309, 32828509, 32831090, 32862470, 33371621, 33493852, 33493853, 33493855, 33493855, 33493856, 33608757, 33877065, 34821525, 34821529, 34821553, 35032884, 36113347, 33493854, 36113348, 30731098, 32350186, 30326728, 30523898, 30434636, 30701435, 30491982, 30491993, 30492022, 30492059, 31137403, 30492096, 30492166, 30492286, 31137501, 30492513, 30845757, 30502605, 30765594, 35447348, 30590675, 36277065, 30675546, 30937246, 30721059, 30721069, 30721070, 30721071, 30721073, 30721073, 30721071, 30721071, 30721071, 31251943, 30721083, 31752448, 32460788, 33722766, 36342259, 30904597, 31752452, 32160228, 34043975, 30844654, 30884850, 30884853, 34053194, 34187867, 36344909, 30944590, 30944591, 33111272, 32690759, 30968231, 30968231, 30968231, 30968232, 31375523, 31083585, 31188202, 31375523, 31375524, 31959355, 32283805, 32283811, 33846344, 33846347, 36465839, 30978056, 31088496, 31028582, 33876523, 36496013, 31032764, 31032766, 31032766, 36498106, 31804570, 31407793, 34025147, 35206317, 36498108, 31087862, 31087994, 31088122, 31088126, 31360529, 32931604, 31198937, 31198939, 31198926, 31198939, 31198940, 31198940, 31198941, 31198940, 31198942, 31198943, 31198928, 31198928, 31198929, 31198940, 31198940, 31198941, 31198942, 31198942, 31198943, 31198943, 31198944, 31198944, 31198940, 31198941, 31198941, 31198943, 31198943, 31198944, 31198941, 31198944, 31198944, 31198945, 31198946, 31198943, 31198945, 31198946, 31198949, 31198956, 31198952, 31198955, 31490878, 32239259, 36581194, 31198955, 32399157, 33430659, 31490879, 31671520, 33233504, 33961703, 36581195, 31248082, 32239260, 32987017, 33961701, 36581195, 31198958, 35289402, 31198958, 31490880, 31563068, 31652049, 31766620, 33961702, 33961704, 31198960, 31303560, 31490881, 31490881, 32239262, 32399169, 33961704, 33961706, 36581197, 31248082, 31369562, 31490881, 31490881, 32399166, 32399171, 33961702, 33961705, 33961707, 35289378, 31652051, 33961704, 33961705, 33961706, 36581198, 31490883, 35289414, 36581201, 33961712, 31237566, 34127545, 31297218, 31297219, 31297221, 31297322, 31540018, 31540019, 34010840, 31297420, 36630432, 31319178, 31319181, 31550997, 34021819, 31408227, 31408231, 31408298, 31595553, 31756721, 34449586, 31540168, 31540175, 31540177, 31540178, 36751809, 31661496, 31661497, 36751812, 35459995, 31580032, 31681445, 31632938, 31707877, 31667879, 32225853, 31676213, 36819831, 31782796, 31782800, 31782801, 31782813, 31782813, 31782818, 31782802, 31782803, 31782804, 31782805, 31782817, 31782818, 31782818, 31782819, 31782819, 31782820, 31782804, 31782815, 31782818, 31782819, 31782819, 31782820, 31782820, 31782818, 31782819, 31782819, 31782820, 31782820, 31782821, 31782821, 31782820, 31782820, 31782821, 31782829, 34216284, 36873131, 32531197, 31782832, 31782833, 31782833, 31782834, 31782834, 32691099, 32691100, 33496103, 33525442, 33841182, 34253640, 34253642, 36873134, 31782834, 31782836, 31855003, 31855006, 31861846, 31950260, 32173315, 32179597, 32340097, 32531199, 32531200, 32570583, 32691097, 32691099, 33109966, 33278955, 33588297, 33588299, 33588301, 34162072, 34253639, 34253640, 34253641, 34253642, 34253642, 34253644, 34373353, 35581294, 35581310, 36873134, 31782835, 31943988, 32173315, 32187750, 32283322, 32366650, 32473056, 32531200, 32531201, 32542572, 32691097, 32691100, 32691101, 32691104, 32691107, 33278953, 33588298, 33713591, 33722599, 33722763, 34253639, 34253640, 34253641, 34253642, 34253643, 34253643, 34253646, 34373355, 34400172, 34400174, 34636853, 35118615, 35581319, 35792671, 35792675, 36050105, 36873135, 32173316, 32283325, 32531200, 32691107, 33278953, 34253641, 34253641, 34253643, 34253643, 34253644, 34636853, 35792673, 32753399, 35581318, 36873136, 31950262, 32531201, 31818062, 34271262, 31927187, 31927189, 31927189, 31927190, 31927190, 33660484, 34325824, 34325825, 32603383, 32763281, 34325826, 33182149, 34709037, 35653486, 31940868, 31940870, 33358047, 36952158, 31944670, 31944716, 31944761, 32772062, 32020774, 34372616, 32105152, 32105153, 32111425, 34414807, 34414804, 34414808, 32117696, 32117699, 32117700, 32117703, 32117752, 32698638, 32698639, 34421082, 32117808, 33692935, 32131409, 33393397, 32132062, 32132252, 32132442, 32865941, 32144133, 33290554, 32334297, 32966841, 32503080, 33105725, 32563808, 32563808, 32563812, 32563814, 32673816, 37263627, 32673817, 34644135, 32921697, 35971775, 32576372, 32576372, 32576376, 35033627, 34650415, 34650417, 32592683, 32779840, 32646573, 34685519, 32783827, 32783828, 32783829, 32783829, 32783832, 33031704, 33031705, 33191605, 34754147, 34754148, 35137357, 36081816, 37373639, 33043078, 32897373, 37430410, 32950495, 32950540, 32950542, 32950517, 33126417, 37456987, 36165203, 37457026, 32966996, 32967065, 32967134, 34040445, 33163291, 33278194, 33250960, 34987713, 33279565, 33279578, 33279578, 33279579, 33279579, 33279580, 33279580, 33279581, 33279578, 33279579, 33279579, 33279580, 33279585, 33279581, 33279592, 33858345, 34244482, 35002019, 35002020, 35002021, 35148552, 35385230, 35385231, 36329718, 36329721, 37621513, 33439478, 34336674, 35002019, 33279593, 33439482, 35002022, 35148553, 36329673, 37621514, 33439477, 33439478, 33439478, 33439482, 34027336, 35002022, 35002023, 36541051, 37621515, 35385233, 37621516, 33290956, 33302324, 33302322, 33302323, 33302325, 33302326, 35013391, 36809855, 33450850, 33450860, 34931601, 33358348, 34066721, 33368013, 34071550, 33393095, 33462853, 33532610, 33579306, 33599351, 33599375, 33599374, 33599379, 33599386, 33599376, 33599384, 33599361, 33599367, 33599379, 33599383, 33599373, 33599380, 33599384, 33599394, 33599387, 33599387, 33599388, 33599402, 33599373, 33599374, 33599388, 33599389, 33599393, 33599368, 33599373, 33599391, 33599385, 33599387, 33599389, 33599391, 33599388, 33599391, 33599390, 33599393, 33599387, 33599388, 33599392, 33599394, 33599396, 33599394, 33599396, 33599398, 35545122, 33599379, 33599401, 33599396, 33599397, 33599389, 33599397, 33599398, 33599398, 33599399, 33599402, 33599381, 33599381, 33599390, 33599398, 33599409, 33599394, 33599406, 33599400, 33599400, 33599400, 33599392, 33599395, 33599397, 33599399, 35161918, 35161923, 35161922, 34187237, 37781417, 35161926, 33599409, 33599414, 35161927, 35161927, 34187307, 35308459, 37781420, 36489581, 36489597, 37781420, 33599411, 34284702, 34530544, 33599415, 36489604, 35161931, 35161931, 33599418, 35161931, 35161932, 37781424, 33599425, 33661550, 35161929, 33599416, 34187246, 34984111, 35161933, 37781425, 33599418, 34187247, 35161934, 35161935, 33661690, 35161935, 35161936, 36489608, 34018260, 35161931, 35161934, 35161935, 35161935, 33599424, 34691352, 35545145, 37781428, 37781428, 34187249, 35281648, 34187254, 35545148, 34187255, 35308470, 34496598, 35545150, 35161943, 35161945, 34749486, 33626002, 34031559, 33708370, 35216413, 33723695, 33723842, 33723979, 33723989, 35224223, 35224225, 33748361, 35236419, 34061432, 38012439, 34200505, 35462484, 34436924, 34436936, 34437019, 34437025, 34437111, 34437112, 34437113, 34437114, 34437114, 34437115, 34437115, 34437115, 34437117, 35580788, 35580789, 38200280, 34606103, 35580789, 36908328, 36908463, 38200281, 35580788, 34516844, 34738459, 34648919, 35686693, 34655384, 35689923, 34775086, 34775089, 34775096, 34775139, 34775146, 34775097, 34775094, 34775079, 34775097, 34775093, 34775099, 34775152, 34775095, 34775102, 34775145, 34775097, 34775100, 34775103, 34775105, 34775113, 34775099, 34775109, 36132986, 35749780, 35749780, 35749781, 35749780, 34775116, 35749783, 35896314, 37288811, 37845390, 35864685, 35749786, 36070992, 38369278, 35749788, 35749789, 38369283, 35749792, 35749794, 34775251, 35084485, 34775257, 34775259, 35749831, 35749836, 34775264, 37077541, 34775277, 37077579, 38369369, 35749877, 35749874, 38369370, 34960076, 38461761, 34970025, 35847252, 35019372, 37410948, 35113800, 35113868, 35113937, 35919226, 35209383, 35966920, 35966921, 35268062, 35268063, 35268150, 35268151, 35268238, 35268238, 35996349, 35996349, 37324029, 35277953, 36001207, 35393774, 35393777, 35393776, 35393776, 35393777, 35393778, 35393780, 35393780, 36059120, 36059121, 36059118, 36059119, 36059121, 37386762, 38678613, 37386790, 36059123, 35398960, 36208257, 35461693, 35461693, 36476288, 36093075, 35636420, 38799933, 35644360, 35644362, 38803904, 36184410, 35662424, 35662428, 36193467, 36576682, 35662701, 36193581, 35693206, 37747863, 35783300, 38873375, 35899544, 36312000, 37851032, 36368821, 36546642, 36479999, 36480064, 36480133, 36602302, 36541323, 37960520, 36560872, 36560952, 36561033, 36642745, 36649756, 39306603, 36724444, 36724445, 36724445, 36724447, 36724447, 36724448, 36724459, 36724459, 36724460, 36724446, 36724446, 36724448, 36724448, 36724461, 36724447, 36724448, 36724448, 36724449, 36724449, 36724450, 36724451, 36724461, 36724461, 36724462, 36724449, 36724464, 36724449, 36724450, 36724464, 36724450, 36724451, 36724452, 36724462, 36724463, 36724463, 36724465, 36724465, 36724451, 36724452, 36724453, 36724453, 36724454, 36724462, 36724463, 36724463, 36724464, 36724464, 36724465, 36724465, 36724466, 36724466, 36724467, 36724467, 36724468, 36724452, 36724453, 36724454, 36724463, 36724463, 36724464, 36724464, 36724466, 36724466, 36724467, 36724467, 36724468, 36724468, 36724453, 36724466, 36724467, 36724467, 36724468, 36724455, 36724465, 36724466, 36724467, 36724467, 36724469, 36724469, 36724465, 36724465, 36724467, 36724468, 36724468, 36724469, 36724468, 36724469, 36724474, 36724477, 39343954, 36724475, 36724476, 36724477, 36724478, 37107673, 39343955, 36724476, 36724478, 36724478, 36724479, 36724479, 36724566, 37107673, 37765118, 38052164, 38052164, 39343955, 36724477, 36724478, 36724478, 36724479, 36724479, 37107673, 37107674, 38052139, 38052161, 38052168, 38263492, 38263492, 38263494, 38910022, 39343956, 36724479, 36724479, 39343956, 36724480, 36724480, 36724480, 36724481, 36724483, 36870996, 37052845, 37107675, 37107675, 37107678, 37776764, 37816328, 38052134, 38052136, 38052138, 38052139, 38052143, 38052167, 38263493, 38263494, 38263494, 39343957, 36724481, 36724482, 36724482, 36724483, 36724483, 36728848, 36844177, 36844178, 36855048, 36870997, 36975904, 37107674, 37107675, 37107676, 37589905, 38052000, 38052004, 38052104, 38052125, 38052129, 38052133, 38052139, 38052141, 38052144, 38052165, 38052165, 38052166, 38052167, 38052167, 38052168, 38052171, 38052173, 38263494, 38263494, 38263495, 38263496, 38263496, 38391880, 38520928, 39336579, 39343958, 36724482, 36724483, 36724484, 36728849, 36839367, 36844179, 36870997, 37107675, 37107675, 37107676, 37107676, 37589478, 38052105, 38052129, 38052138, 38052140, 38052142, 38052163, 38052164, 38052165, 38052172, 38263494, 38263495, 39343958, 36870996, 37107677, 37107677, 37107678, 37589436, 37589477, 38052144, 39343959, 36870998, 37107676, 37107677, 38052134, 38052165, 38065706, 38263497, 39343959, 37107678, 38052109, 38052147, 39343960, 37107678, 38052144, 39343960, 39343961, 36724666, 37107773, 36733227, 36733228, 38056472, 39348338, 36954263, 36954264, 36954267, 36954266, 36954269, 38167059, 38167062, 39458856, 38167008, 39458859, 36963884, 36963885, 36963887, 36963887, 36963888, 38171844, 39463666, 37630616, 38171848, 38171849, 38171851, 36985627, 38182719, 37017524, 37017525, 37017525, 37017525, 37017526, 39490486, 39483108, 39490486, 37254204, 37254204, 37254205, 37254205, 37923294, 38198667, 39490487, 37221538, 39592494, 37227351, 37227416, 37227485, 37359191, 37366878, 37366878, 39657785, 38373348, 37381224, 39672336, 37490869, 37490869, 37490883, 37490884, 37490884, 37490885, 37490870, 37490883, 37490885, 37490885, 37490872, 37490884, 37490885, 37490885, 37490886, 37490886, 37490886, 37490888, 37490887, 37490888, 37490893, 38646702, 39727166, 37490900, 37703180, 38435319, 38608771, 38646703, 39727167, 37490900, 38435369, 38435375, 38646704, 39727167, 37490901, 37490902, 38009210, 38148331, 38435311, 38435316, 38435318, 38435319, 38435322, 38435327, 38435335, 38435342, 38435342, 38435344, 38435344, 38435345, 38435347, 38435351, 38435353, 38435354, 38435356, 38435369, 38435373, 38435376, 38435380, 38597359, 38646704, 38646704, 38646706, 38646706, 38775090, 38904138, 38941491, 38981652, 39727168, 38646704, 39727168, 38435324, 39727169, 39727169, 38435356, 37915477, 39939464, 38297343, 40130394, 38454465, 38454419, 40208938, 38454505, 38454503, 40208984, 40208987, 38455404, 39150094, 38527547, 40245504, 38805772, 38805772, 39304146, 39092763, 38829049, 38829061, 38829061, 40396254, 38908191, 39144037, 39055168, 40509309, 39379539, 39379603, 39591034, 39379762, 40671557, 39379724, 39379739, 39379772, 39379747, 39379762, 39379753, 39379776, 39379769, 39379781, 39379778, 39379778, 39379782, 39379785, 39379786, 39379782, 39379787, 39379792, 39379765, 39379793, 39379776, 39379798, 39379825, 39379797, 39379799, 39379793, 39379792, 39379798, 39379801, 39379806, 39379808, 39379775, 39379783, 39379806, 39379781, 39379801, 39379800, 39379800, 39379795, 39379811, 39379804, 39379805, 39379810, 39379792, 39379794, 39379806, 39379808, 39379809, 39379811, 39379788, 39379793, 39379795, 39379807, 39379811, 39379812, 39379806, 39379812, 39379803, 39379832, 39379815, 39379818, 39379807, 39379812, 39379822, 39379798, 39379813, 39379814, 39379799, 39379812, 39379814, 39379814, 39379816, 39379819, 39379820, 39379821, 39379840, 39379804, 39379813, 39379815, 39379821, 39379826, 39379817, 39379817, 39379818, 39379822, 39379828, 39379807, 39379818, 39379821, 39379821, 39379825, 39379823, 39379824, 39379828, 39379827, 39379819, 39379823, 39379828, 39379832, 39379840, 39379817, 39379825, 39379828, 39379827, 39379829, 39379832, 39379823, 39379836, 39379821, 40671628, 39379825, 39379831, 39591165, 40671628, 39591165, 40671629, 39379826, 39591166, 40671630, 39379826, 40671630, 39379831, 39379834, 40671631, 39379832, 39379841, 39712672, 40671631, 40671632, 39379840, 39591168, 40671632, 40664254, 40671633, 39379838, 39591167, 40664255, 40671633, 39379841, 39379842, 39379844, 40671634, 39379835, 39379840, 39379846, 40671635, 39461636, 39591171, 40671635, 39591172, 39591174, 39379842, 39379869, 39379846, 39591174, 40671637, 39379847, 39379870, 39576502, 40671638, 39379845, 40671638, 39379847, 39379871, 40671639, 39379846, 39379847, 39379857, 39379871, 40671639, 39379850, 39379851, 39379853, 39379872, 39379873, 39591175, 40671640, 39379853, 39379873, 39379848, 39379850, 39379873, 39379850, 39379855, 39379874, 39379874, 39591178, 40671642, 39379874, 39591179, 40671642, 39379853, 39379854, 39379875, 39379875, 40671643, 39379855, 39379875, 39379877, 40671643, 39379876, 40671644, 39379854, 39379874, 39379876, 39379877, 39591181, 39848616, 40671644, 39379871, 39379877, 39379877, 40671645, 39379877, 39379878, 39379878, 39379867, 39379879, 39379879, 39591184, 39379879, 39379880, 39379880, 39379881, 39379882, 39379882, 39379884, 39379885, 40671653, 40671654, 40671655, 39591195, 39591198, 39379896, 40671666, 39379899, 39553270, 39591203, 39591203, 39591204, 39591204, 39719587, 39848637, 39926151, 40341615, 40671667, 39379900, 39591206, 39848637, 40004232, 40671667, 39591206, 40671668, 39591205, 39406953, 39952255, 39543456, 39672994, 39703833, 40833642, 39726656, 39726657, 40845052, 39773216, 39773292, 39773368, 40045398, 39802516, 39802519, 39802521, 39802524, 39802507, 39802509, 39802510, 39802512, 39802512, 39802523, 39802523, 39802524, 39802524, 39802508, 39802523, 39802524, 39802524, 39802525, 39802510, 39802524, 39802524, 39802525, 39802525, 39802526, 39802525, 39802526, 39802526, 39802527, 39802527, 39802527, 39802528, 39802528, 39802529, 40882983, 40882985, 40882986, 39802539, 39802540, 39802541, 39930908, 40882987, 39802541, 40059957, 40875609, 40882987, 39802541, 40875609, 40882988, 39829937, 40875610, 40882988, 40882989, 40882989, 39844783, 40904147, 39857348, 39857421, 39857489, 40910468, 40045538, 41004497, 40059291, 40059292, 40059292, 40188340, 41011370, 41011371, 40160841, 40160885, 41062170, 40317387, 40317388, 40317389, 40317389, 40317390, 40317391, 40317391, 40317392, 40317392, 40317392, 41140417, 41140418, 41140419, 41140419, 41140420, 41140421, 41140421, 41140422, 41140422, 40392091, 40392093, 41177768, 41177770, 40472418, 40472419, 40472428, 41217934, 41217934, 41217939, 40497556, 41230508, 40628621, 40883965, 40915665, 40915735, 40915805, 41439621, 41095591, 41529524, 41139320, 41288298, 41303347, 41633399, 41437265, 41700379, 41804969, 41884209, 41900508, 41931984, 41948687, 41948688, 41948688, 41948689, 41948690, 41948835, 41948836, 41948833, 41948837, 41948837, 41948838, 41948838, 41948981, 41948984, 41948984, 41948985, 41948985, 41948985, 41956215, 41956215], "xaxis": "x", "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 29, 27550, 1237, 1324, 877, 475, 205, 962, 125, 3088, 193, 164, 22, 2, 365, 420, 377, 94, 844, 1705, 19519, 7251, 1705, 1827, 1688, 150, 1616, 1042, 1831, 246, 619, 380, 469, 308, 581, 553, 138, 710, 2251, 9345, 2255, 275, 451, 582, 191, 852, 605, 429, 277, 462, 1928, 69, 276, 680, 267, 1863, 202, 151, 280, 197, 484, 567, 452, 1221, 717, 81, 126, 1043, 449, 197, 878, 1895, 2773, 247, 194, 165, 648, 621, 1, 0, 0, 0, 0, 584, 362, 661, 141, 4, 468, 307, 580, 1, 379, 552, 95, 137, 453, 1449, 1309, 6501, 953, 51511, 30783, 5472, 15573, 3741, 1771, 881, 4273, 4058, 4535, 3273, 240, 307, 249, 474, 206, 691, 736, 2957, 592, 70, 3463, 327, 542, 549, 507, 2688, 1586, 1199, 2401, 118, 2456, 2849, 2413, 1214, 3, 709, 2598, 1663, 7361, 3812, 7366, 2093, 3463, 679, 1015, 8365, 2894, 1362, 364, 885, 1583, 645, 1039, 1698, 1715, 514, 77, 103, 172, 925, 991, 345, 325, 259, 392, 2611, 1540, 1080, 485, 56, 72, 2114, 301, 1066, 1100, 217, 591, 350, 137, 625, 1715, 214, 322, 5159, 1100, 301, 2467, 254, 518, 169, 1829, 806, 2063, 806, 493, 395, 453, 1026, 455, 312, 586, 484, 688, 727, 597, 1185, 376, 394, 211, 888, 347, 858, 714, 302, 2459, 78, 157, 1207, 485, 170, 417, 459, 126, 631, 646, 183, 4, 344, 215, 246, 294, 415, 375, 889, 630, 253, 323, 2118, 903, 900, 692, 1142, 284, 3, 140, 1415, 891, 770, 1159, 461, 1, 637, 176, 1101, 340, 890, 898, 1796, 218, 2119, 1842, 1196, 348, 302, 1547, 338, 437, 71, 947, 393, 816, 654, 904, 1584, 113, 343, 237, 1158, 1092, 646, 887, 241, 631, 948, 133, 176, 1040, 859, 250, 132, 519, 1, 3157, 170, 475, 901, 715, 207, 725, 975, 1844, 1830, 442, 394, 251, 1675, 647, 786, 693, 807, 255, 565, 1845, 1197, 535, 846, 174, 1216, 546, 1144, 593, 563, 368, 284, 69, 807, 636, 1846, 173, 833, 501, 2078, 1082, 635, 170, 185, 1234, 2748, 630, 3, 4, 1022, 0, 0, 394, 186, 178, 513, 168, 187, 0, 75, 1141, 900, 1, 534, 254, 248, 0, 2348, 1187, 743, 818, 857, 283, 109, 2422, 1453, 1, 347, 102, 0, 0, 0, 1249, 2, 256, 1065, 1809, 0, 1140, 156, 552, 1248, 619, 171, 24, 0, 216, 301, 1025, 2713, 3100, 174, 1233, 14, 688, 2270, 1668, 2264, 120, 10, 0, 946, 117, 2606, 203, 1583, 534, 322, 2664, 2816, 724, 1766, 0, 1181, 881, 2447, 1162, 1031, 1710, 3244, 1821, 539, 842, 635, 8, 0, 0, 1795, 1298, 1562, 1450, 1336, 213, 1202, 1, 450, 101, 0, 0, 533, 518, 2159, 495, 1904, 2, 0, 1829, 618, 1122, 3026, 1573, 2259, 1293, 1254, 282, 1127, 60, 1583, 3925, 2855, 3592, 266, 975, 119, 0, 0, 7001, 6238, 4884, 1306, 2444, 3, 0, 22632, 18749, 5220, 1842, 392, 0, 0, 38529, 7829, 4881, 862, 0, 0, 51299, 38849, 1785, 0, 0, 0, 0, 68312, 3075, 0, 0, 123660, 1, 450, 9420, 86, 368, 5460, 12140, 10424, 106, 8873, 165, 326, 759, 869, 1837, 901, 138, 966, 238, 539, 302, 225, 4, 245, 407, 90, 67, 128, 100, 183, 663, 582, 1485, 6658, 338, 161, 742, 0, 0, 0, 243, 204, 1562, 1855, 2159, 1851, 186, 240, 274, 210, 208, 564, 342, 87, 104, 262, 3973, 1117, 1229, 127, 206, 447, 6320, 6560, 92, 567, 601, 99, 1319, 258, 318, 502, 1048, 174, 4, 1482, 8761, 470, 785, 1201, 709, 471, 196, 2004, 607, 171, 183, 542, 267, 2326, 582, 105, 897, 491, 2153, 1344, 1279, 581, 1636, 2380, 1227, 263, 61, 242, 1260, 263, 155, 434, 598, 240, 277, 411, 920, 253, 413, 129, 191, 1193, 616, 899, 1897, 6300, 91, 64, 493, 319, 205, 166, 561, 479, 443, 272, 180, 1352, 207, 786, 610, 330, 125, 480, 203, 407, 407, 320, 939, 1344, 71, 173, 84, 296, 97, 242, 1118, 265, 897, 1085, 276, 69, 241, 934, 670, 510, 289, 72, 170, 152, 429, 125, 198, 1224, 577, 359, 1273, 624, 453, 78, 230, 120, 169, 968, 835, 100, 139, 611, 266, 448, 579, 519, 493, 203, 138, 1259, 519, 788, 918, 1332, 472, 1280, 361, 264, 612, 233, 7, 1038, 462, 449, 378, 243, 580, 581, 221, 311, 333, 188, 405, 59, 361, 254, 608, 515, 68, 846, 226, 1039, 72, 271, 5, 246, 323, 244, 242, 433, 452, 220, 704, 637, 463, 241, 511, 312, 204, 278, 464, 259, 2, 77, 6, 919, 3, 137, 332, 1098, 288, 569, 688, 187, 372, 172, 622, 487, 451, 787, 1080, 287, 581, 229, 1297, 953, 54, 404, 128, 169, 360, 786, 190, 446, 463, 1108, 111, 2153, 4247, 105, 225, 461, 615, 410, 1212, 2277, 2664, 1576, 3759, 67, 20879, 114, 166, 35718, 14166, 11832, 0, 21749, 15157, 36220, 0, 30, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 4, 0, 1, 0, 25, 32955, 716, 1197, 10729, 4230, 270, 74, 37, 652, 102, 582, 19, 734, 417, 1, 172, 154, 109, 233, 167, 59, 191, 1400, 16306, 1692, 1, 1844, 403, 8833, 3785, 95, 1254, 1050, 294, 191, 142, 364, 140, 130, 477, 747, 412, 146, 129, 2698, 9908, 104, 1119, 220, 249, 983, 240, 556, 408, 405, 6380, 81, 104, 1460, 367, 80, 195, 140, 117, 184, 1410, 9304, 67, 280, 1155, 527, 887, 216, 516, 280, 179, 402, 125, 1148, 704, 960, 7892, 299, 271, 96, 281, 493, 1021, 294, 528, 143, 559, 187, 890, 966, 2235, 104, 432, 344, 2052, 7, 293, 177, 190, 215, 871, 190, 418, 368, 281, 143, 3, 1319, 365, 196, 139, 403, 155, 131, 476, 110, 746, 304, 141, 348, 1869, 118, 229, 255, 27, 294, 1, 338, 705, 1156, 250, 411, 1854, 6, 9888, 73, 72943, 1, 1, 87168, 2047, 1749, 3193, 12079, 8228, 12090, 10634, 7648, 1830, 65, 7, 877, 363, 16, 9, 241, 30, 7, 352, 4149, 4044, 4542, 15910, 11861, 23306, 19482, 2536, 1063, 234, 367, 2238, 376, 1846, 1355, 213, 158, 33, 615, 941, 2165, 2141, 1098, 813, 2, 276, 3079, 1186, 2379, 1589, 129, 6, 8856, 10612, 8401, 3240, 1343, 21, 20754, 10218, 2360, 837, 57, 2, 59789, 9242, 1834, 341, 1196, 26, 3, 8, 438, 95576, 10458, 455, 5, 3933, 1096, 184, 2, 7, 45, 90997, 3395, 3524, 18631, 3940, 211, 581, 2, 238, 72, 725, 5, 53, 7815, 22482, 64199, 11821, 695, 175, 401, 50, 596, 31, 13, 168, 66, 24, 364, 5, 3362, 7355, 1276, 110, 22763, 5977, 266, 453, 159, 101232, 343, 2976, 3450, 3895, 918, 611, 314, 739, 169, 772, 364, 91, 7, 273, 156, 304, 138, 1024, 190, 2, 616, 47, 236, 118, 131, 640, 131, 12270, 12174, 39250, 18790, 2425, 6070, 3483, 7693, 713, 4724, 1012, 1363, 27, 625, 1700, 2, 542, 675, 643, 695, 7109, 2465, 671, 201, 86, 710, 10, 134, 656, 11, 4, 5421, 3143, 1327, 416, 456, 338, 606, 478, 10, 157, 247, 256, 5618, 3987, 1828, 1036, 3701, 715, 862, 1093, 1792, 8, 210, 493, 155, 22677, 2407, 1080, 2029, 4284, 3878, 5485, 1634, 1261, 849, 6, 2355, 564, 1369, 510, 1199, 314, 120, 333, 42, 3926, 7606, 2360, 9100, 4746, 4862, 2273, 1945, 19, 349, 279, 813, 888, 58, 1370, 7378, 1522, 1004, 360, 181, 220, 468, 522, 3506, 901, 1217, 771, 302, 683, 557, 101, 169, 558, 57, 1831, 5014, 5104, 1411, 32, 254, 272, 305, 315, 363, 769, 883, 376, 5, 543, 221, 3056, 2319, 1050, 1789, 1861, 528, 1089, 29, 308, 2893, 11663, 2781, 2118, 417, 3103, 51, 1645, 24, 245, 585, 291, 8566, 702, 302, 521, 184, 42, 536, 290, 613, 413, 4352, 2966, 1527, 716, 831, 386, 713, 1571, 452, 3740, 8701, 3986, 2080, 602, 2958, 369, 1501, 2147, 3252, 1590, 295, 7067, 1080, 203, 1168, 807, 205, 272, 1224, 541, 40, 3060, 331, 23, 1422, 13, 1317, 3143, 1904, 8118, 3327, 1671, 637, 49, 475, 316, 439, 59, 1989, 1071, 28, 1468, 724, 336, 1591, 1831, 1352, 846, 822, 3896, 934, 234, 203, 598, 474, 585, 20, 3324, 480, 332, 634, 418, 1072, 92, 717, 28, 29, 1432, 477, 19, 7, 91, 22, 626, 333, 1007, 18, 2482, 2231, 1805, 373, 3412, 334, 253, 355, 447, 12, 2065, 372, 271, 1222, 1569, 335, 242, 544, 3073, 316, 2032, 2569, 814, 5, 213, 1467, 3031, 17879, 1952, 695, 364, 260, 8, 4, 451, 1125, 708, 1962, 392, 326, 211, 559, 11, 228, 3259, 512, 761, 1149, 655, 2546, 419, 294, 476, 7052, 451, 400, 51475, 1817, 11458, 5469, 4065, 3003, 4040, 3502, 861, 2859, 1153, 2473, 1887, 64, 2519, 773, 0, 5564, 32955, 6866, 2914, 695, 4898, 3156, 278, 5143, 586, 3494, 803, 738, 1587, 1, 3597, 720, 2185, 412, 694, 460, 12707, 10510, 7230, 3630, 5360, 163, 6081, 758, 3059, 988, 923, 2290, 2234, 6326, 4899, 5047, 3281, 502, 4503, 2894, 760, 920, 626, 8939, 7814, 4432, 3128, 458, 2418, 6, 189, 1328, 3015, 8950, 8260, 905, 2164, 479, 2550, 985, 8804, 1069, 12681, 1885, 2716, 9, 1719, 1392, 613, 26189, 2102, 5901, 693, 1677, 833, 1819, 1981, 1011, 277, 976, 15033, 46402, 3999, 597, 4835, 4783, 5, 14692, 3572, 693, 3414, 1668, 28678, 8503, 26670, 24193, 5236, 21022, 16429, 10446, 7675, 81298, 0, 73025, 323, 27, 306, 354, 3, 8, 22, 33, 236, 212, 80, 77, 71, 14, 2, 49, 2, 6, 1, 2, 6, 1, 29, 9, 0, 33, 2, 25, 59, 209, 105, 253, 368, 0, 0, 0, 0, 0, 0, 0, 12728, 5941, 1775, 2566, 13117, 1708, 83, 570, 972, 2353, 4450, 990, 5323, 885, 750, 754, 68, 708, 396, 1034, 487, 217, 419, 683, 166, 278, 411, 1029, 23, 135, 300, 102, 418, 73, 238, 186, 460, 215, 228, 443, 618, 79, 156, 195, 129, 167, 32, 108, 154, 198, 873, 272, 745, 1349, 379, 2177, 0, 2075, 655, 479, 2236, 263, 698, 882, 603, 177, 1145, 256, 640, 495, 730, 142, 341, 220, 138, 27, 306, 79, 209, 189, 0, 1304, 1185, 344, 412, 232, 258, 450, 542, 278, 561, 129, 236, 539, 476, 364, 183, 23, 259, 38, 102, 149, 0, 1467, 512, 281, 464, 493, 419, 83, 1604, 116, 280, 29, 2, 270, 195, 11, 186, 129, 213, 99, 194, 645, 982, 193, 1599, 991, 202, 409, 3516, 662, 2223, 935, 214, 1549, 536, 222, 228, 347, 368, 291, 125, 67, 870, 184, 584, 177, 518, 180, 124, 85, 833, 0, 484, 263, 271, 91, 121, 157, 159, 295, 593, 127, 44, 0, 273, 707, 2, 343, 79, 417, 115, 274, 486, 0, 460, 857, 1718, 231, 503, 76, 151, 17, 3, 0, 588, 1069, 407, 157, 693, 173, 110, 163, 197, 964, 219, 179, 2, 27, 0, 0, 1365, 265, 1423, 7, 211, 726, 5, 282, 374, 423, 43, 363, 105, 560, 170, 274, 656, 409, 18, 271, 150, 979, 0, 191, 402, 101, 159, 176, 107, 180, 114, 249, 1594, 4900, 2553, 706, 4, 514, 589, 532, 555, 174, 305, 224, 321, 231, 109, 183, 169, 218, 435, 182, 339, 315, 707, 1, 55, 638, 0, 2031, 122, 160, 259, 145, 489, 601, 277, 210, 224, 255, 92, 1789, 156, 834, 322, 2561, 306, 280, 1398, 8, 274, 841, 259, 25, 218, 559, 372, 887, 983, 123, 369, 343, 34, 243, 198, 446, 0, 0, 193, 575, 271, 1059, 373, 191, 2, 66, 678, 128, 310, 8, 0, 172, 347, 192, 350, 226, 250, 358, 266, 33, 145, 140, 6, 195, 445, 706, 75, 125, 215, 159, 365, 346, 109, 48, 1256, 1355, 598, 2663, 312, 405, 795, 528, 241, 1089, 260, 369, 417, 122, 462, 178, 252, 271, 242, 170, 298, 0, 511, 321, 340, 287, 475, 270, 729, 321, 258, 418, 191, 161, 70, 277, 730, 225, 705, 153, 452, 144, 234, 209, 155, 260, 305, 411, 68, 250, 99, 0, 509, 285, 269, 1, 750, 212, 3, 418, 402, 864, 99, 248, 916, 319, 607, 783, 903, 198, 446, 376, 169, 106, 186, 281, 188, 805, 914, 209, 761, 60, 0, 0, 0, 218, 195, 280, 533, 153, 499, 165, 520, 11, 444, 373, 404, 497, 98, 372, 357, 1121, 356, 58, 1082, 74, 506, 152, 490, 226, 602, 199, 770, 196, 190, 346, 356, 268, 395, 0, 1117, 410, 318, 689, 177, 1981, 831, 530, 96, 439, 378, 853, 239, 221, 404, 118, 3, 279, 331, 349, 429, 64, 199, 2697, 215, 420, 484, 297, 403, 273, 42, 0, 272, 141, 308, 142, 269, 501, 1230, 749, 228, 441, 244, 242, 233, 490, 238, 173, 741, 222, 385, 362, 271, 201, 214, 0, 370, 409, 294, 728, 317, 4, 292, 199, 307, 363, 136, 214, 532, 749, 97, 419, 391, 347, 4, 90, 117, 223, 0, 445, 141, 101, 0, 391, 323, 417, 96, 239, 270, 230, 377, 108, 342, 537, 363, 152, 500, 219, 209, 156, 375, 273, 274, 341, 295, 483, 104, 469, 326, 524, 280, 100, 366, 560, 271, 587, 217, 216, 559, 408, 122, 463, 107, 168, 145, 182, 214, 756, 433, 48, 374, 342, 472, 272, 381, 43, 444, 229, 407, 726, 481, 199, 240, 559, 289, 373, 1448, 381, 649, 217, 140, 1067, 361, 672, 198, 168, 636, 2826, 201, 2767, 1023, 864, 220, 888, 138, 105, 78, 228, 155, 257, 183, 145, 181, 208, 194, 1, 195, 128, 400, 47, 166, 2, 364, 117, 139, 219, 1580, 529, 1059, 22, 294, 363, 204, 449, 635, 584, 2, 160, 373, 278, 231, 116, 32, 439, 341, 490, 760, 372, 122, 338, 371, 219, 1, 1219, 103, 242, 2645, 1024, 463, 623, 23, 3375, 333, 527, 522, 1389, 0, 7922, 5300, 4919, 2079, 4478, 4441, 5935, 663, 2575, 10565, 4183, 6616, 11226, 21016, 22470, 27, 22, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 69, 0, 0, 0, 0, 4, 0, 0, 0, 1, 0, 1, 0, 3, 8, 4000, 1525, 247, 3132, 590, 279, 67, 161, 7, 134, 2268, 171, 58, 714, 6175, 5351, 306, 357, 73, 397, 161, 230, 1699, 828, 271, 237, 88, 999, 249, 109, 142, 124, 61, 22, 146, 72, 19, 510, 421, 2331, 206, 89, 681, 32, 152, 29, 44, 58, 62, 224, 3, 2, 7, 0, 0, 0, 0, 23, 145, 71, 8, 399, 573, 30, 1599, 2396, 32, 34, 1, 297, 14, 590, 85, 89, 238, 60, 1185, 462, 15685, 9509, 756, 147, 2089, 192, 1210, 114, 75, 210, 950, 76, 345, 830, 363, 3, 258, 31, 603, 4466, 318, 11062, 158, 97, 81, 282, 1228, 80, 189, 45, 120, 552, 993, 512, 1426, 570, 480, 453, 265, 159, 7, 101, 247, 96, 31, 742, 91, 71, 6158, 452, 459, 752, 668, 165, 54, 236, 525, 3600, 148, 179, 355, 387, 82, 78, 62, 1374, 728, 114, 57, 64, 45, 207, 460, 148, 276, 21, 454, 291, 27, 1691, 296, 67, 294, 172, 193, 173, 432, 310, 266, 312, 115, 669, 76, 22, 33, 174, 212, 166, 141, 393, 419, 77, 96, 300, 36, 829, 3, 237, 301, 670, 455, 64, 4, 134, 126, 292, 32, 302, 2, 384, 222, 535, 3603, 72, 151, 212, 75, 129, 121, 185, 95, 114, 103, 473, 98, 41, 6, 244, 86, 141, 33, 75, 536, 317, 11, 13, 276, 129, 1469, 171, 439, 461, 272, 3134, 1046, 1812, 3532, 52, 406, 211, 2304, 372, 1544, 391, 395, 474, 501, 109, 266, 199, 812, 637, 821, 29, 109, 60, 547, 28, 7, 2, 308, 3, 95, 5, 295, 4, 0, 348, 71, 6, 51, 2, 128, 128, 100, 142, 325, 528, 422, 474, 926, 13, 621, 76, 238, 93, 64, 73, 256, 67, 73, 418, 168, 79, 0, 281, 320, 297, 13, 70, 309, 144, 28, 460, 46, 273, 3, 187, 177, 552, 1089, 96, 1406, 157, 170, 93, 277, 726, 34, 6, 204, 588, 920, 169, 196, 346, 4, 110, 92, 232, 387, 6, 0, 1267, 979, 205, 305, 380, 57, 1, 98, 134, 409, 357, 1, 197, 1953, 1797, 1550, 590, 350, 7, 234, 195, 136, 154, 252, 2012, 150, 0, 0, 51, 94, 301, 265, 1161, 254, 44, 22, 210, 455, 130, 165, 1135, 11, 339, 127, 3, 754, 2357, 459, 296, 212, 7, 183, 224, 1027, 390, 199, 1380, 1579, 116, 0, 0, 2365, 554, 298, 133, 103, 74, 327, 168, 334, 1040, 0, 0, 3049, 758, 169, 34, 1534, 173, 1313, 3, 126, 3111, 12, 0, 287, 143, 93, 163, 69, 801, 452, 369, 746, 605, 1295, 47, 1, 396, 1332, 76, 143, 92, 1036, 168, 205, 145, 267, 298, 500, 171, 184, 108, 132, 265, 411, 6, 63, 167, 6, 2, 499, 243, 197, 0, 331, 1082, 889, 1353, 4, 0, 460, 236, 62, 991, 215, 311, 828, 1062, 146, 2867, 341, 310, 861, 497, 996, 457, 235, 395, 2996, 5333, 0, 0, 208, 456, 28, 108, 236, 396, 1007, 340, 135, 266, 469, 2, 8613, 11601, 447, 576, 2140, 160, 1, 120, 65, 20, 182, 31, 50, 68, 86, 52, 63, 37, 37, 16, 47, 62, 29, 2, 0, 23, 257, 118, 131, 783, 375, 825, 2911, 468, 752, 2306, 0, 0, 0, 0, 0, 806, 463, 75, 425, 54, 191, 236, 372, 252, 264, 46, 104, 116, 144, 98, 195, 126, 357, 572, 235, 473, 3270, 285, 873, 1393, 237, 109, 37, 622, 86, 153, 802, 839, 51, 78, 41, 89, 130, 0, 32, 16, 410, 134, 625, 13, 139, 714, 0, 159, 106, 76, 146, 288, 23, 260, 306, 125, 119, 45, 36, 108, 0, 79, 175, 192, 104, 23, 151, 85, 180, 30, 90, 373, 51, 131, 29, 41, 37, 313, 53, 80, 152, 265, 47, 62, 84, 38, 38, 103, 115, 15, 36, 46, 61, 6, 60, 25, 11, 130, 8, 20, 143, 2, 10, 102, 97, 2, 25, 305, 28, 191, 89, 194, 101, 40, 125, 127, 256, 31, 124, 453, 36, 147, 80, 140, 88, 130, 29, 163, 780, 2075, 80, 236, 855, 166, 450, 262, 215, 1003, 265, 579, 374, 1478, 4744, 5665, 1067, 2074, 8640, 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 1, 1, 1, 2, 2, 14, 3, 17, 3, 1, 3, 2, 1, 1, 1, 1, 1, 90, 114, 23, 1, 2, 2, 2, 3, 10, 1, 10, 1, 2, 2, 5, 4, 7, 2, 1, 1, 2, 160, 7, 2, 4, 8, 5, 5, 1, 4, 7, 7, 7, 2, 6, 1, 1, 1, 323, 5, 2, 6, 12, 3, 6, 6, 10, 18, 7, 4, 5, 4, 6, 11, 4, 3, 7, 41, 31, 126, 109, 38, 43, 38, 20, 8, 1, 5, 2, 3, 1, 3, 8, 21, 8, 13, 6, 9, 3, 10, 8, 8, 4, 37, 43, 87, 155, 49, 15, 19, 4, 7, 4, 2, 2, 2, 3, 6, 2, 1, 3, 9, 5, 3, 6, 8, 11, 9, 4, 4, 7, 7, 3, 5, 8, 4, 4, 3, 7, 7, 13, 7, 3, 19, 8, 6, 5, 4, 6, 4, 6, 11, 20, 8, 8, 5, 5, 6, 24, 3, 15, 5, 9, 3, 5, 0, 1, 6, 1, 2, 4, 3, 2, 1, 0, 2, 5, 4, 1, 16, 10, 17, 15, 2, 2, 8, 1, 0, 42, 46, 11, 4, 4, 5, 0, 123, 29, 27, 27, 14, 5, 1, 2, 1, 0, 0, 0, 149, 71, 75, 12, 23, 5, 3, 2, 5, 2, 1, 1, 0, 0, 0, 0, 53, 53, 26, 21, 9, 7, 5, 4, 1, 0, 0, 0, 77, 29, 18, 15, 4, 4, 8, 1, 1, 1, 1, 0, 0, 0, 79, 68, 21, 9, 2, 1, 1, 1, 1, 2, 2, 2, 0, 53, 34, 24, 2, 4, 1, 1, 0, 0, 0, 71, 19, 11, 8, 1, 5, 1, 1, 2, 2, 1, 0, 0, 0, 0, 37, 11, 15, 9, 6, 4, 1, 1, 1, 1, 0, 0, 0, 0, 24, 12, 10, 2, 3, 6, 1, 0, 0, 0, 0, 20, 3, 2, 1, 1, 6, 0, 0, 16, 8, 4, 1, 3, 2, 1, 0, 0, 0, 0, 0, 2, 2, 2, 1, 1, 7, 0, 0, 2, 3, 1, 2, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 3, 1, 1, 0, 0, 0, 1, 2, 0, 2, 0, 2, 1, 0, 0, 3, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 23, 2234, 1030, 1081, 583, 1026, 171, 28, 199, 233, 4, 87, 1217, 16179, 13814, 1, 1, 1, 514, 873, 891, 159, 695, 187, 153, 708, 228, 362, 225, 196, 231, 606, 164, 172, 30, 165, 194, 11, 9, 2, 16, 6, 0, 0, 0, 0, 9, 0, 6, 0, 0, 197, 88, 232, 1055, 696, 21560, 1, 1, 14787, 1430, 1238, 4581, 6068, 77, 1205, 1832, 1003, 1091, 1252, 379, 837, 2882, 192, 366, 416, 112, 896, 1285, 469, 630, 962, 1829, 7, 490, 305, 688, 345, 691, 486, 848, 1936, 1379, 918, 211, 99, 330, 304, 1170, 735, 537, 222, 68, 202, 1820, 965, 2414, 1364, 613, 1603, 339, 2431, 251, 224, 1020, 396, 10, 718, 22, 17, 58, 403, 18, 141, 145, 1, 79, 522, 375, 186, 5, 1012, 752, 275, 1143, 2118, 470, 15, 649, 852, 746, 760, 154, 330, 285, 964, 502, 124, 206, 212, 234, 493, 367, 1455, 616, 189, 178, 385, 72, 270, 109, 257, 269, 497, 357, 269, 420, 120, 1031, 276, 208, 2471, 511, 280, 634, 377, 640, 57, 2, 326, 316, 20, 67, 279, 428, 240, 28, 101, 124, 75, 167, 326, 369, 826, 128, 194, 316, 1046, 542, 236, 231, 175, 781, 425, 3, 77, 367, 370, 478, 1304, 856, 186, 156, 280, 124, 281, 528, 148, 0, 471, 168, 78, 327, 361, 846, 493, 512, 257, 258, 278, 370, 261, 308, 3, 185, 314, 827, 466, 260, 55, 376, 478, 6, 387, 193, 117, 9, 131, 17, 101, 129, 281, 633, 159, 222, 328, 498, 390, 742, 219, 436, 128, 91, 138, 243, 195, 155, 179, 139, 23, 486, 177, 1444, 391, 314, 479, 156, 176, 300, 487, 282, 137, 670, 195, 266, 45, 758, 377, 456, 358, 528, 155, 193, 463, 392, 90, 278, 117, 3, 5, 103, 199, 315, 472, 130, 113, 186, 331, 414, 268, 353, 565, 270, 457, 237, 513, 378, 482, 180, 379, 200, 315, 388, 228, 317, 154, 623, 169, 432, 343, 480, 200, 397, 157, 229, 889, 91, 391, 190, 490, 1466, 483, 254, 168, 504, 839, 194, 316, 2, 624, 125, 3, 2, 357, 210, 269, 282, 256, 623, 2, 138, 2, 301, 473, 318, 262, 323, 103, 189, 58, 0, 179, 344, 489, 233, 529, 111, 259, 103, 691, 185, 309, 277, 131, 23, 6, 647, 110, 156, 524, 136, 1, 260, 154, 617, 269, 38, 329, 172, 218, 358, 1, 0, 2, 5, 345, 1464, 378, 376, 48, 243, 630, 154, 116, 181, 286, 106, 0, 1, 111, 516, 141, 619, 579, 100, 285, 596, 267, 172, 286, 581, 869, 8, 32, 517, 288, 25, 67, 136, 34, 142, 271, 224, 112, 406, 672, 109, 127, 6, 130, 4, 6, 2, 512, 344, 97, 142, 102, 167, 840, 84, 411, 232, 440, 467, 324, 609, 371, 37, 86, 86, 377, 486, 540, 591, 257, 481, 259, 38, 668, 132, 255, 168, 684, 447, 357, 211, 152, 248, 985, 154, 58, 1532, 137, 1452, 391, 420, 312, 627, 135, 85, 291, 277, 90, 41, 131, 1018, 591, 391, 286, 258, 0, 0, 141, 0, 1, 989, 284, 254, 365, 71, 4, 2, 184, 218, 259, 69, 132, 0, 57, 412, 201, 553, 5875, 2109, 881, 65, 360, 585, 838, 757, 86, 475, 856, 217, 46, 20, 18, 184, 2, 0, 91, 90, 138, 357, 395, 258, 2143, 121, 962, 389, 278, 189, 1023, 244, 343, 285, 42, 1995, 1758, 1990, 1810, 2300, 3598, 1222, 687, 434, 532, 96, 0, 645, 44, 112, 530, 0, 453, 814, 2404, 1716, 2010, 870, 974, 142, 188, 6, 102, 295, 267, 166, 62, 1255, 346, 770, 1532, 300, 150, 100, 64, 1154, 1225, 1613, 448, 239, 721, 434, 631, 139, 223, 179, 529, 821, 3602, 1896, 1798, 1058, 622, 696, 407, 1176, 618, 178, 241, 411, 544, 742, 155, 270, 210, 250, 3560, 2465, 1056, 560, 74, 287, 129, 89, 200, 68, 376, 1, 5544, 3424, 4001, 3127, 665, 1820, 76, 158, 530, 612, 124, 234, 152, 1, 427, 176, 91, 640, 136, 49, 267, 39, 52, 1109, 1, 2552, 3094, 2203, 1672, 565, 92, 131, 1225, 17, 236, 420, 258, 530, 177, 625, 239, 288, 378, 220, 398, 5874, 1635, 308, 6, 540, 489, 712, 465, 287, 908, 52, 322, 223, 641, 440, 6140, 3184, 1453, 1656, 1548, 438, 503, 328, 100, 450, 401, 176, 488, 160, 72, 121, 246, 177, 811, 665, 369, 2995, 2069, 474, 577, 1106, 1811, 560, 274, 240, 1011, 313, 2, 101, 116, 447, 6, 69, 453, 154, 373, 130, 3, 1009, 397, 427, 676, 1757, 1200, 798, 436, 980, 1658, 949, 537, 265, 2, 341, 747, 244, 157, 247, 544, 364, 880, 170, 903, 530, 687, 1755, 785, 769, 606, 114, 485, 38, 178, 144, 360, 265, 87, 238, 381, 450, 502, 1100, 504, 109, 437, 529, 552, 221, 150, 282, 288, 44, 333, 234, 761, 578, 520, 317, 159, 281, 174, 285, 1133, 617, 836, 1094, 688, 388, 193, 128, 989, 129, 585, 434, 130, 113, 430, 292, 662, 748, 1110, 284, 835, 763, 1103, 720, 818, 303, 394, 235, 251, 820, 277, 830, 464, 758, 1064, 176, 127, 466, 772, 279, 482, 108, 334, 213, 11, 265, 112, 453, 30, 95, 201, 286, 235, 397, 486, 752, 692, 20, 217, 280, 777, 188, 1309, 306, 245, 23, 1038, 262, 755, 398, 521, 9, 694, 2, 267, 101, 102, 814, 376, 538, 427, 174, 126, 242, 142, 653, 421, 256, 518, 190, 198, 487, 342, 409, 890, 619, 226, 467, 314, 287, 200, 157, 227, 177, 501, 410, 1175, 177, 245, 392, 714, 226, 53, 316, 630, 140, 419, 517, 487, 234, 474, 687, 465, 261, 529, 176, 158, 500, 90, 261, 492, 115, 157, 233, 409, 189, 234, 143, 801, 272, 658, 462, 1304, 176, 499, 446, 748, 778, 0, 392, 293, 156, 1642, 463, 220, 243, 1349, 516, 271, 107, 445, 366, 68, 259, 629, 850, 433, 624, 959, 258, 220, 1302, 741, 583, 817, 260, 1286, 858, 306, 743, 1118, 314, 282, 1321, 238, 1437, 4172, 3111, 292, 482, 525, 262, 647, 495, 281, 112, 582, 239, 177, 156, 455, 359, 2256, 1875, 1463, 100, 844, 1515, 990, 141, 3270, 1159, 101, 543, 426, 143, 246, 269, 17239, 146, 7393, 463, 6457, 32594, 0, 0, 0, 544, 1025, 10145, 18475, 408, 259, 77, 415, 249, 137, 103, 227, 60, 998, 207, 118, 198, 70, 316, 148, 137, 229, 540, 180, 87, 948, 655, 180, 430, 470, 207, 2548, 8612, 0, 0, 0, 0, 1735, 128, 211, 582, 235, 374, 125, 98, 410, 486, 130, 86, 203, 241, 400, 129, 184, 382, 432, 359, 641, 1262, 368, 2785, 6133, 0, 0, 171, 148, 215, 1118, 473, 30, 162, 56, 127, 76, 29, 257, 84, 215, 73, 105, 117, 261, 134, 67, 314, 64, 167, 139, 194, 55, 75, 180, 102, 124, 226, 156, 225, 311, 139, 234, 393, 170, 536, 206, 129, 140, 117, 85, 197, 104, 165, 271, 184, 54, 255, 198, 147, 240, 136, 228, 312, 510, 312, 324, 147, 36, 878, 86, 260, 133, 165, 135, 132, 265, 136, 83, 517, 466, 89, 233, 332, 1463, 121, 224, 375, 657, 339, 795, 98, 753, 3148, 449, 746, 10227, 0, 54, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 6953, 1658, 113, 840, 93, 8081, 44, 248, 40, 107, 147, 133, 339, 6011, 4679, 1, 1, 695, 426, 672, 3431, 1162, 657, 401, 209, 1082, 605, 85, 427, 64, 52, 168, 989, 560, 215, 169, 210, 93, 2, 338, 168, 169, 185, 137, 143, 337, 716, 9469, 2703, 331, 9, 32, 308, 171, 209, 186, 45, 383, 39, 68, 41, 144, 308, 181, 135, 591, 479, 20541, 2, 16236, 1991, 1725, 2181, 4771, 1426, 263, 3531, 249, 336, 673, 842, 407, 51, 773, 173, 740, 2381, 687, 1023, 748, 3168, 4834, 1716, 2448, 163, 723, 359, 527, 115, 219, 704, 15, 30, 48, 414, 267, 96, 20, 768, 100, 1695, 1457, 244, 1444, 1778, 396, 125, 443, 882, 274, 1518, 169, 1038, 478, 915, 357, 1451, 416, 1228, 290, 467, 105, 156, 70, 159, 472, 224, 266, 25, 297, 701, 418, 543, 170, 664, 165, 310, 379, 132, 100, 661, 237, 11, 23, 127, 1151, 494, 665, 157, 484, 93, 15, 288, 331, 81, 7, 5, 101, 461, 459, 345, 18, 334, 418, 99, 140, 2, 125, 214, 199, 2237, 2239, 285, 103, 194, 48, 98, 79, 143, 88, 447, 66, 50, 159, 304, 556, 56, 79, 183, 121, 35, 245, 148, 106, 1, 12, 147, 82, 334, 403, 212, 51, 328, 147, 113, 312, 921, 270, 741, 310, 252, 19, 209, 351, 666, 294, 95, 94, 121, 103, 148, 19, 115, 335, 141, 367, 168, 686, 419, 174, 59, 373, 367, 83, 198, 85, 26, 256, 106, 48, 1, 275, 158, 1, 335, 9, 197, 44, 352, 252, 100, 495, 687, 280, 570, 380, 595, 457, 494, 364, 496, 211, 571, 67, 213, 444, 90, 90, 141, 122, 459, 113, 916, 545, 464, 940, 3, 3, 49, 523, 151, 572, 51, 473, 149, 739, 2017, 313, 88, 215, 527, 257, 198, 114, 264, 201, 114, 242, 65, 94, 106, 451, 2576, 57, 362, 301, 253, 329, 38, 101, 60, 279, 48, 4, 127, 6863, 367, 1270, 498, 756, 482, 285, 267, 269, 167, 397, 38, 66, 70, 148, 92, 111, 159, 195, 4867, 8582, 195, 216, 581, 1517, 1512, 181, 992, 930, 364, 300, 193, 568, 147, 1802, 5, 117, 403, 159, 186, 277, 64, 156, 4912, 1365, 351, 945, 440, 592, 1159, 335, 29, 317, 57, 3, 467, 149, 93, 279, 1499, 264, 1505, 1993, 3674, 686, 1252, 2149, 0, 407, 917, 1723, 548, 259, 117, 1408, 822, 626, 65, 724, 1322, 72, 833, 255, 670, 311, 354, 644, 522, 157, 1091, 88, 338, 88, 140, 410, 254, 164, 974, 1248, 357, 608, 155, 71, 107, 2, 158, 27, 249, 393, 209, 236, 62, 76, 1646, 178, 878, 2272, 305, 196, 243, 154, 235, 668, 38, 101, 191, 147, 188, 11, 122, 14, 888, 2494, 1692, 899, 250, 939, 1687, 839, 97, 301, 773, 142, 23, 213, 14, 245, 111, 79, 15, 497, 770, 40, 152, 869, 268, 177, 67, 2390, 39, 162, 1791, 1410, 30, 161, 1716, 343, 185, 448, 54, 238, 224, 94, 80, 201, 436, 1954, 3643, 2326, 164, 115, 1295, 290, 445, 755, 318, 201, 261, 265, 691, 1, 39, 734, 92, 1186, 327, 169, 67, 129, 55, 475, 582, 82, 143, 252, 352, 1929, 1037, 20, 49, 48, 816, 298, 46, 2870, 724, 89, 264, 6253, 247, 315, 3, 203, 717, 105, 221, 273, 58, 400, 1400, 2, 419, 536, 699, 240, 382, 427, 559, 5295, 682, 4, 2, 86, 913, 147, 709, 99, 1243, 1247, 257, 641, 112, 418, 154, 96, 37, 191, 581, 978, 258, 160, 126, 4, 590, 443, 7, 877, 260, 146, 116, 26, 5568, 1867, 680, 422, 82, 252, 461, 1192, 1039, 1117, 251, 171, 246, 298, 254, 4398, 466, 122, 807, 782, 4580, 810, 76, 301, 57, 128, 341, 1197, 1067, 401, 4, 2, 145, 26, 1726, 375, 9, 873, 1268, 0, 66, 291, 256, 242, 458, 118, 297, 1162, 35, 88, 1111, 0, 429, 64, 2, 948, 7, 550, 1056, 290, 87, 300, 100, 234, 451, 450, 216, 336, 56, 227, 91, 350, 1249, 766, 190, 595, 3, 268, 616, 773, 255, 246, 301, 2319, 1014, 1388, 237, 104, 864, 168, 260, 178, 212, 633, 185, 425, 656, 494, 2373, 581, 643, 209, 131, 243, 1365, 21, 578, 572, 2596, 1165, 331, 2077, 560, 167, 735, 36, 245, 120, 111, 351, 226, 166, 245, 248, 364, 200, 371, 1, 427, 1153, 799, 1443, 8174, 17572, 93, 427, 311, 1417, 92, 924, 0, 331, 2699, 0, 15339, 22468, 523, 17, 20, 232, 61, 158, 62, 54, 45, 36, 38, 29, 2, 77, 53, 19, 104, 163, 34, 577, 5103, 0, 0, 0, 0, 0, 2080, 438, 233, 173, 443, 628, 551, 405, 242, 153, 257, 170, 16, 73, 271, 55, 43, 223, 0, 125, 308, 60, 81, 69, 313, 84, 22, 103, 526, 197, 139, 346, 2106, 11004, 146, 68, 96, 60, 103, 418, 1686, 204, 145, 100, 19, 433, 230, 232, 167, 71, 30, 138, 189, 61, 147, 504, 120, 32, 573, 131, 147, 620, 467, 41, 204, 44, 37, 37, 130, 258, 227, 42, 30, 3, 17, 74, 95, 179, 54, 146, 42, 46, 66, 192, 54, 133, 175, 413, 38, 100, 176, 41, 124, 305, 59, 80, 257, 68, 45, 414, 506, 63, 60, 35, 66, 155, 62, 374, 523, 363, 409, 4138, 28, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 2, 6, 3389, 385, 27, 107, 761, 2934, 172, 16, 1, 96, 105, 86, 56, 78, 79, 22, 457, 516, 12186, 10293, 105, 91, 800, 263, 537, 989, 648, 132, 256, 135, 92, 108, 187, 411, 169, 77, 39, 1957, 1711, 173, 262, 12, 3, 97, 106, 87, 57, 78, 128, 79, 272, 61, 459, 736, 325, 17879, 14597, 1941, 528, 1335, 3465, 3026, 191, 176, 1074, 1114, 855, 81, 805, 634, 2623, 254, 1092, 401, 770, 51, 16, 955, 712, 784, 2695, 5673, 2741, 5605, 1648, 801, 3, 2775, 89, 13, 20, 269, 3, 76, 72, 802, 108, 216, 175, 24, 265, 92, 136, 1850, 1, 341, 794, 547, 740, 834, 969, 84, 511, 118, 66, 371, 2003, 130, 149, 715, 304, 387, 1096, 46, 2301, 1054, 295, 524, 167, 141, 236, 77, 817, 472, 50, 209, 343, 94, 167, 450, 238, 126, 346, 329, 548, 493, 516, 156, 154, 279, 307, 1, 619, 670, 1166, 160, 378, 381, 94, 195, 253, 954, 244, 157, 282, 148, 310, 123, 410, 456, 381, 237, 317, 192, 178, 378, 54, 237, 945, 431, 8, 142, 144, 237, 1105, 136, 155, 153, 656, 280, 487, 714, 182, 131, 184, 137, 119, 82, 171, 829, 2, 154, 2, 78, 447, 343, 138, 5, 217, 769, 160, 986, 910, 573, 656, 172, 161, 85, 4, 542, 188, 131, 255, 379, 156, 120, 107, 193, 705, 261, 558, 2, 117, 142, 380, 255, 191, 102, 79, 1015, 157, 279, 150, 310, 156, 655, 2, 51, 656, 161, 17, 299, 956, 172, 108, 314, 228, 304, 371, 42, 55, 1682, 77, 132, 5, 264, 194, 587, 978, 1668, 419, 328, 1390, 350, 257, 4, 2, 56, 276, 4525, 3379, 1630, 1162, 227, 1892, 169, 17, 281, 623, 435, 87, 100, 2, 619, 5833, 2004, 1801, 2437, 2, 128, 146, 134, 133, 179, 228, 458, 53, 492, 235, 47, 276, 6368, 3035, 413, 8561, 113, 271, 610, 42, 507, 470, 108, 636, 81, 249, 195, 357, 419, 216, 131, 183, 4, 210, 84, 305, 169, 367, 4565, 4960, 364, 49, 239, 383, 157, 236, 931, 263, 262, 794, 277, 222, 256, 160, 472, 270, 7382, 183, 6, 55, 135, 95, 437, 232, 277, 4, 352, 26, 1456, 968, 1108, 18, 81, 158, 6, 267, 189, 100, 563, 162, 3, 4, 2, 228, 110, 1002, 283, 928, 593, 1505, 359, 689, 1890, 2802, 1652, 980, 3543, 2317, 1336, 454, 105, 3690, 666, 1279, 1170, 170, 206, 174, 1096, 595, 474, 190, 547, 990, 109, 82, 299, 62, 89, 1211, 1, 5, 363, 163, 644, 90, 535, 4, 116, 280, 49, 660, 499, 270, 216, 351, 1, 5, 236, 262, 91, 172, 732, 571, 147, 58, 228, 372, 14, 55, 733, 6, 240, 173, 179, 136, 95, 145, 384, 546, 1, 464, 299, 128, 41, 113, 16, 330, 229, 550, 463, 98, 2706, 463, 452, 387, 1355, 134, 364, 167, 318, 66, 320, 0, 770, 954, 81, 33, 940, 280, 146, 2, 954, 6, 136, 3399, 1081, 453, 4118, 272, 363, 417, 133, 5, 5, 197, 120, 217, 317, 311, 493, 0, 677, 135, 280, 4214, 548, 968, 300, 319, 388, 346, 3, 1353, 1, 0, 0, 161, 2603, 220, 237, 112, 282, 310, 170, 1093, 353, 483, 262, 5, 321, 439, 193, 104, 717, 174, 3734, 7244, 2400, 1350, 307, 1, 738, 153, 103, 931, 4, 74, 116, 165, 191, 615, 619, 167, 471, 5318, 0, 2729, 1002, 608, 246, 59, 637, 121, 817, 1556, 5855, 1551, 76, 441, 157, 407, 284, 1, 287, 192, 408, 300, 385, 1619, 269, 4082, 251, 638, 547, 1572, 134, 227, 227, 874, 50, 305, 1184, 366, 1272, 1543, 114, 440, 2580, 160, 303, 381, 277, 448, 818, 402, 2048, 1, 149, 76, 205, 145, 512, 780, 462, 173, 4, 324, 880, 360, 199, 206, 1613, 202, 620, 1909, 363, 371, 152, 194, 133, 461, 672, 279, 226, 193, 554, 311, 234, 477, 359, 374, 557, 94, 747, 132, 2119, 215, 181, 544, 157, 628, 476, 350, 766, 442, 304, 360, 634, 0, 310, 50, 1038, 278, 83, 311, 786, 373, 1312, 486, 1689, 409, 335, 645, 742, 279, 924, 3268, 0, 142, 156, 1109, 3325, 0, 607, 1226, 7729, 475, 1624, 9285, 32308, 23, 1, 5, 2, 60, 6, 2, 9, 81, 7, 61, 1, 1, 1, 4, 1, 27, 3, 0, 4, 1, 65, 442, 15, 301, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1748, 183, 1288, 736, 210, 167, 904, 130, 58, 296, 1795, 58, 82, 430, 166, 77, 147, 52, 217, 266, 211, 1506, 143, 109, 238, 53, 26, 102, 96, 158, 9, 123, 188, 73, 340, 83, 611, 69, 228, 93, 191, 82, 153, 80, 117, 179, 230, 408, 859, 791, 1081, 1487, 1953, 7880, 38, 1302, 0, 0, 178, 110, 267, 267, 136, 84, 162, 22, 513, 12, 182, 0, 0, 324, 57, 177, 169, 115, 46, 38, 121, 361, 47, 130, 94, 323, 184, 1, 146, 323, 62, 101, 23, 101, 245, 151, 83, 106, 3, 77, 95, 88, 335, 3, 0, 1, 129, 56, 10, 57, 60, 103, 80, 132, 155, 121, 153, 151, 59, 63, 104, 109, 84, 179, 152, 363, 72, 792, 23, 0, 32, 28, 273, 156, 45, 35, 143, 243, 77, 120, 168, 284, 74, 147, 102, 60, 183, 152, 90, 76, 0, 79, 114, 0, 44, 0, 58, 266, 352, 36, 53, 73, 0, 201, 13, 196, 135, 140, 146, 139, 70, 23, 140, 273, 312, 138, 668, 77, 144, 142, 83, 24, 220, 16, 54, 101, 25, 101, 244, 44, 52, 0, 83, 73, 0, 8, 113, 315, 20, 51, 82, 158, 38, 72, 7, 63, 99, 138, 119, 92, 2, 187, 11, 35, 256, 56, 141, 407, 8, 6, 69, 2, 50, 258, 322, 76, 92, 0, 190, 34, 139, 81, 151, 272, 364, 103, 217, 0, 108, 115, 177, 311, 207, 45, 1046, 237, 570, 222, 864, 99, 170, 926, 188, 896, 9, 270, 849, 1392, 11, 1925, 3135, 65, 5592, 442, 3298, 23782, 0, 3326, 17, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 1, 1, 0, 0, 4, 6, 0, 0, 0, 2, 0, 0, 2, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 3, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 1, 1, 0, 0, 0, 2, 0, 0, 1, 0, 1, 1, 1, 31, 2, 2, 2, 20, 20, 5, 10, 7, 9, 2, 2, 1, 2, 1, 1, 3, 2, 2, 1, 5, 1, 12, 9, 1, 7, 18, 5, 8, 4, 5, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 4, 3, 4, 1, 1, 3, 2, 2, 5, 2, 1, 1, 3, 3, 2, 1, 2, 2, 1, 1, 2, 0, 12, 3, 2, 0, 2, 1, 1, 0, 0, 0, 0, 0, 5, 11, 10, 6, 1, 4, 2, 2, 3, 3, 4, 0, 0, 0, 0, 9, 3, 3, 1, 1, 2, 2, 2, 4, 1, 3, 0, 0, 0, 0, 21, 15, 4, 3, 1, 2, 2, 2, 3, 10, 10, 6, 3, 3, 0, 0, 0, 0, 0, 22, 5, 6, 6, 1, 4, 5, 3, 19, 7, 6, 1, 0, 0, 0, 0, 0, 0, 0, 13, 2, 2, 4, 3, 2, 3, 4, 26, 18, 2, 0, 0, 0, 0, 0, 0, 3, 10, 1, 4, 11, 11, 13, 1, 1, 0, 1, 1, 2, 2, 1, 2, 2, 14, 1, 9, 2, 0, 0, 0, 10, 2, 3, 2, 2, 3, 1, 2, 0, 1, 3, 3, 0, 0, 0, 7, 3, 1, 2, 0, 3, 5, 1, 2, 3, 2, 1, 0, 3, 2, 2, 1, 1, 0, 0, 0, 4, 2, 2, 4, 0, 1, 1, 1, 3, 1, 2, 1, 0, 0, 0, 0, 2, 0, 0, 2, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 1, 3, 0, 2, 1, 3, 1, 0, 0, 3, 2, 0, 0, 1, 0, 0, 0, 0, 18, 14, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 5, 5, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 1, 2, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 2, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 1, 1, 2, 1, 1, 2, 2, 15, 3, 1, 1, 1, 2, 2, 6, 1, 1, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 6, 0, 0, 0, 1, 0, 1, 2, 1, 6, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 7, 1, 1, 1, 1, 1, 3, 1, 7, 2, 94, 37, 2, 1, 1, 2, 1, 1, 2, 1, 1, 4, 1, 0, 2, 0, 0, 0, 0, 1, 0, 11, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 3, 1, 1, 3, 1, 5, 2, 3, 1, 18, 1, 7, 85, 36, 1, 1, 6, 1, 9, 1, 2, 2, 1, 4, 0, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 4, 0, 12, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 2, 4, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 4, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 9, 20, 10, 0, 0, 0, 0, 0, 9, 16, 2, 8, 1, 1, 2, 4, 2, 2, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 1, 2, 2, 3, 2, 1, 2, 2, 1, 1, 1, 1, 3, 1, 1, 1, 5, 4, 16, 1, 9, 1, 4, 58, 34, 3, 2, 2, 2, 6, 20, 28, 2, 1, 1, 6, 18, 11, 1, 1, 1, 5, 1, 1, 0, 0, 3, 1, 1, 0, 0, 0, 9, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 2, 1, 1, 3, 1, 1, 1, 11, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 2, 2, 5, 1, 2, 1, 1, 3, 1, 1, 4, 2, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 1, 1, 6, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 4, 1, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 3, 1, 1, 1, 3, 1, 4, 1, 1, 1, 1, 1, 2, 4, 6, 1, 1, 1, 3, 2, 1, 19, 5, 4, 1, 4, 4, 2, 2, 6, 3, 3, 3, 1, 5, 7, 4, 3, 2, 5, 1, 3, 1, 5, 4, 5, 7, 10, 16, 9, 1, 1, 2, 3, 3, 4, 3, 1, 3, 3, 4, 2, 3, 1, 2, 2, 6, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 2, 1, 0, 0, 2, 1, 2, 0, 0, 2, 3, 1, 0, 0, 0, 0, 4, 4, 2, 0, 0, 0, 8, 2, 0, 0, 0, 0, 8, 3, 2, 0, 0, 0, 0, 0, 2, 4, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 4, 2, 1, 2, 0, 0, 0, 0, 0, 1, 1, 2, 2, 2, 0, 0, 1, 2, 0, 2, 2, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 4, 3, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 6, 4, 12, 4, 1, 1, 1, 2, 178, 1, 2, 1, 956, 28, 1, 2, 1, 6, 4, 8, 1, 2, 4, 3, 2, 1, 9, 1, 141, 537, 22, 5, 14, 16, 8, 35, 6, 9, 56, 18, 47, 69, 23, 50, 69, 43, 39, 53, 26, 25, 7, 28, 12, 29, 16, 36, 4, 4, 1, 1, 7, 1, 122, 9, 22, 1, 1, 11, 13, 10, 15, 63, 27, 33, 11, 52, 25, 87, 60, 73, 43, 70, 55, 34, 10, 6, 44, 12, 10, 10, 1, 12, 23, 14, 1, 6, 15, 11, 1, 16, 1, 17, 1, 1, 1, 7, 66, 3, 13, 10, 2, 24, 2, 1, 29, 25, 7, 14, 1, 1, 10, 23, 14, 4, 11, 10, 37, 14, 1, 3, 9, 1, 13, 5, 3, 17, 1, 4, 1, 1, 1, 48, 24, 20, 1, 1, 12, 2, 105, 2, 41, 21, 8, 3, 2, 18, 32, 2, 63, 58, 27, 82, 75, 1, 10, 11, 1, 1, 2, 1, 26, 123, 63, 12, 1, 1, 21, 24, 16, 3, 3, 1, 5, 1, 1, 138, 73, 49, 65, 11, 5, 50, 46, 2, 2, 3, 24, 5, 1, 286, 69, 33, 14, 32, 31, 32, 7, 3, 4, 2, 2, 10, 22, 3, 1, 291, 23, 7, 16, 56, 127, 49, 60, 21, 22, 6, 2, 8, 2, 11, 24, 7, 1, 162, 51, 18, 78, 164, 77, 88, 61, 14, 2, 2, 2, 12, 21, 2, 1, 4, 4, 5, 46, 103, 124, 37, 18, 3, 3, 5, 4, 5, 26, 47, 2, 24, 8, 38, 32, 9, 12, 6, 2, 4, 4, 2, 7, 5, 1, 19, 4, 12, 4, 2, 5, 3, 1, 1, 1, 103, 17, 25, 2, 44, 3, 4, 15, 1, 303, 229, 35, 49, 2, 9, 7, 9, 0, 428, 53, 44, 70, 9, 10, 4, 2, 3, 2, 0, 0, 0, 0, 0, 0, 523, 310, 106, 35, 9, 6, 3, 3, 7, 1, 0, 434, 111, 36, 11, 6, 11, 7, 1, 1, 0, 0, 0, 536, 140, 118, 92, 2, 9, 11, 3, 6, 1, 0, 380, 210, 80, 29, 8, 8, 4, 5, 5, 0, 0, 0, 271, 127, 58, 29, 17, 19, 2, 9, 3, 298, 120, 53, 36, 16, 20, 2, 6, 4, 1, 0, 0, 0, 278, 109, 63, 43, 14, 16, 4, 2, 2, 6, 9, 2, 0, 0, 242, 151, 32, 5, 8, 1, 0, 0, 0, 237, 74, 17, 28, 6, 4, 5, 13, 8, 1, 0, 0, 0, 284, 78, 14, 26, 11, 1, 4, 5, 10, 9, 0, 0, 0, 202, 76, 29, 16, 14, 6, 9, 3, 13, 0, 0, 0, 214, 19, 18, 23, 7, 3, 3, 2, 0, 119, 68, 22, 13, 15, 20, 7, 4, 3, 4, 5, 3, 0, 47, 61, 23, 14, 6, 11, 1, 1, 0, 56, 34, 15, 1, 3, 3, 3, 0, 0, 62, 31, 22, 11, 3, 13, 5, 2, 0, 0, 0, 43, 32, 17, 3, 3, 18, 8, 1, 0, 39, 33, 2, 4, 15, 0, 0, 37, 2, 5, 6, 19, 17, 1, 1, 0, 0, 20, 16, 11, 34, 1, 1, 0, 0, 0, 0, 0, 8, 9, 2, 4, 14, 0, 0, 16, 24, 0, 0, 0, 0, 134, 7, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 95, 9, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 1, 0, 0, 12, 1, 1, 3, 2, 6, 20, 1, 3, 1, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 2, 2, 1, 1, 1, 2, 1, 1, 7, 1, 1, 3, 3, 1, 1, 1, 2, 1, 2, 3, 1, 3, 4, 1, 11, 15, 2, 7, 2, 1, 2, 12, 12, 1, 1, 23, 7, 7, 2, 10, 3, 2, 2, 24, 37, 6, 15, 2, 4, 4, 7, 9, 12, 12, 7, 25, 2, 2, 31, 7, 5, 1, 3, 2, 14, 5, 1, 1, 4, 38, 24, 23, 10, 2, 6, 16, 2, 31, 14, 18, 1, 1, 3, 8, 4, 7, 2, 2, 4, 7, 11, 33, 25, 2, 3, 3, 13, 2, 5, 16, 2, 6, 18, 6, 5, 5, 3, 13, 14, 9, 4, 2, 34, 4, 15, 14, 10, 16, 3, 2, 9, 3, 16, 18, 15, 19, 6, 6, 4, 1, 4, 1, 4, 1, 4, 1, 4, 2, 0, 0, 2, 2, 7, 2, 4, 0, 0, 0, 0, 0, 0, 0, 22, 1, 24, 6, 4, 2, 0, 0, 0, 0, 0, 0, 0, 14, 33, 9, 11, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 25, 7, 1, 1, 3, 0, 0, 0, 0, 62, 26, 4, 4, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 6, 16, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 8, 8, 23, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 13, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 6, 6, 1, 1, 1, 1, 2, 30, 7, 1, 2, 4, 2, 2, 1, 2, 3, 1, 1, 4, 2, 1, 2, 1, 1, 35, 9, 12, 1, 2, 1, 2, 4, 3, 1, 2, 1, 2, 10, 2, 2, 2, 2, 1, 1, 1, 1, 17, 4, 3, 1, 7, 1, 10, 4, 1, 1, 1, 4, 1, 2, 4, 8, 2, 1, 4, 2, 1, 1, 2, 1, 2, 2, 8, 1, 3, 3, 2, 10, 2, 1, 5, 5, 5, 1, 2, 1, 1, 1, 1, 4, 1, 1, 7, 7, 1, 3, 1, 4, 3, 1, 3, 2, 5, 3, 6, 1, 3, 2, 8, 1, 2, 4, 4, 4, 7, 2, 1, 17, 3, 1, 2, 2, 3, 1, 3, 1, 1, 1, 1, 1, 2, 2, 2, 6, 2, 2, 1, 1, 2, 5, 4, 2, 1, 3, 2, 8, 2, 2, 1, 4, 1, 1, 2, 3, 2, 7, 2, 2, 3, 1, 1, 4, 3, 6, 9, 3, 3, 8, 2, 1, 3, 3, 2, 3, 6, 2, 2, 2, 3, 8, 5, 2, 7, 3, 7, 6, 2, 1, 4, 6, 4, 2, 2, 6, 4, 4, 16, 6, 35, 7, 4, 2, 1, 4, 3, 2, 2, 6, 4, 25, 12, 6, 2, 2, 2, 2, 3, 6, 9, 2, 3, 4, 2, 2, 3, 6, 27, 3, 1, 10, 2, 5, 9, 2, 3, 3, 7, 3, 17, 5, 1, 2, 2, 9, 5, 3, 3, 15, 4, 11, 1, 3, 2, 2, 4, 3, 2, 3, 2, 3, 4, 1, 3, 4, 2, 2, 11, 11, 3, 4, 4, 5, 4, 10, 4, 4, 12, 2, 9, 3, 2, 29, 1, 2, 6, 2, 6, 3, 1, 1, 2, 1, 2, 2, 3, 8, 1, 3, 1, 0, 3, 4, 6, 1, 11, 8, 10, 4, 1, 2, 1, 1, 2, 7, 3, 0, 0, 0, 13, 2, 10, 3, 3, 1, 4, 0, 0, 7, 10, 2, 2, 2, 1, 0, 0, 11, 2, 2, 2, 1, 1, 4, 5, 4, 3, 4, 3, 1, 4, 0, 3, 9, 4, 1, 6, 1, 0, 0, 4, 4, 4, 2, 3, 6, 0, 0, 0, 0, 0, 0, 14, 3, 1, 2, 1, 5, 0, 0, 0, 4, 3, 2, 1, 7, 2, 1, 2, 4, 0, 2, 2, 2, 1, 8, 0, 0, 0, 0, 2, 0, 0, 1, 4, 0, 1, 1, 0, 2, 6, 1, 0, 0, 0, 1, 0, 0, 3, 9, 4, 0, 2, 2, 2, 0, 0, 1, 4, 0, 0, 0, 2, 3, 21, 45, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 25, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 5, 1, 1, 4, 0, 0, 0, 0, 0, 0, 1, 1, 4, 0, 0, 0, 8, 0, 0, 0, 2, 0, 1, 0, 1, 1, 13, 5, 1, 1, 1, 3, 1, 1, 6, 56, 4, 2, 2, 70, 21, 24, 3, 20, 11, 57, 31, 103, 818, 9, 1, 12, 4, 8, 5, 62, 2, 1, 7, 2, 1, 16, 1, 4, 15, 21, 0, 2, 3, 2, 20, 11, 55, 0, 0, 0, 0, 9, 20, 0, 0, 102, 0, 0, 0, 0, 0, 81, 21, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 1, 0, 1, 1, 2, 1, 2, 2, 1, 1, 1, 1, 1, 2, 1, 1, 6, 5, 1, 1, 1, 1, 2, 3, 1, 8, 8, 1, 1, 1, 2, 1, 103, 1, 1, 4, 3, 1, 2, 1, 2, 8, 7, 2, 1, 2, 1, 4, 1, 1, 1, 13, 5, 1, 2, 15, 20, 14, 1, 5, 2, 1, 1, 10, 8, 2, 2, 1, 5, 4, 31, 32, 1, 2, 8, 2, 8, 47, 15, 11, 32, 31, 33, 17, 5, 4, 2, 1, 1, 2, 2, 2, 2, 5, 5, 2, 5, 1, 1, 1, 2, 1, 16, 3, 1, 4, 6, 1, 3, 2, 1, 2, 1, 1, 2, 3, 3, 2, 1, 1, 3, 8, 2, 2, 2, 3, 3, 7, 1, 3, 6, 4, 3, 141, 13, 5, 1, 3, 3, 2, 8, 3, 1, 1, 90, 40, 90, 42, 28, 11, 6, 7, 12, 9, 5, 7, 2, 3, 1, 1, 1, 17, 44, 22, 19, 13, 4, 11, 2, 2, 43, 10, 9, 8, 7, 2, 3, 2, 1, 95, 65, 26, 9, 8, 9, 5, 1, 1, 1, 108, 33, 38, 25, 4, 4, 2, 1, 1, 125, 47, 62, 13, 25, 9, 5, 1, 1, 63, 73, 34, 33, 14, 15, 10, 5, 80, 61, 32, 7, 7, 2, 7, 4, 5, 3, 0, 159, 83, 29, 30, 7, 2, 10, 8, 1, 174, 8, 39, 69, 7, 2, 23, 8, 10, 6, 1, 0, 187, 105, 43, 56, 9, 16, 20, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 124, 45, 52, 58, 19, 14, 1, 1, 2, 1, 1, 0, 0, 0, 0, 125, 75, 75, 24, 32, 1, 23, 6, 7, 0, 0, 119, 56, 37, 2, 12, 23, 29, 16, 6, 27, 10, 6, 1, 1, 0, 0, 104, 83, 30, 49, 42, 5, 9, 11, 0, 1, 1, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 123, 32, 65, 17, 12, 25, 12, 7, 2, 5, 3, 4, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 69, 67, 54, 44, 12, 8, 20, 3, 10, 6, 3, 1, 12, 10, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 37, 33, 16, 20, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 91, 67, 41, 5, 42, 0, 14, 14, 14, 1, 1, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 95, 78, 32, 31, 14, 13, 10, 12, 9, 0, 13, 1, 0, 0, 0, 0, 109, 41, 67, 46, 7, 10, 17, 11, 1, 2, 0, 0, 0, 137, 114, 53, 30, 10, 0, 0, 66, 80, 33, 46, 7, 10, 7, 9, 2, 2, 0, 145, 190, 43, 34, 14, 14, 0, 3, 1, 138, 129, 39, 43, 18, 12, 1, 4, 8, 0, 234, 67, 58, 42, 20, 44, 12, 8, 10, 4, 0, 186, 170, 58, 15, 23, 19, 21, 16, 47, 105, 66, 24, 55, 28, 13, 100, 2, 150, 60, 16, 99, 25, 16, 71, 2, 1, 83, 45, 2, 56, 11, 16, 22, 173, 2, 16, 74, 16, 33, 90, 16, 42, 26, 24, 17, 81, 2, 1, 0, 23, 15, 91, 1, 66, 38, 86, 4, 2, 38, 27, 223, 3, 18, 145, 9, 2, 23, 17, 19, 0, 15, 7, 0, 0, 35, 0, 16, 0, 0, 37, 0, 21, 20, 0, 853, 50, 0, 0, 0, 0, 618, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 0, 0, 1, 0, 1, 1, 2, 491, 59, 6, 9, 1, 17, 9, 3, 7, 8, 3, 1, 15, 80, 13, 39, 4, 14, 13, 3, 4, 3, 1, 1, 158, 13, 16, 16, 5, 71, 19, 9, 10, 3, 6, 4, 37, 180, 18, 48, 12, 18, 11, 1, 21, 28, 2, 29, 23, 23, 3, 1, 9, 84, 5, 26, 8, 2, 1, 1, 12, 3, 23, 1, 7, 1, 3, 5, 10, 2, 5, 1, 1, 1, 5, 1, 14, 15, 20, 10, 8, 12, 6, 2, 2, 2, 6, 3, 1, 5, 12, 14, 25, 67, 5, 8, 5, 4, 7, 4, 4, 3, 5, 1, 1, 2, 22, 30, 9, 8, 2, 10, 3, 2, 1, 36, 4, 6, 2, 1, 2, 1, 15, 34, 2, 1, 1, 9, 11, 2, 8, 4, 33, 3, 14, 2, 1, 1, 11, 2, 16, 3, 7, 0, 34, 8, 16, 13, 2, 179, 250, 37, 42, 11, 5, 1, 1, 1, 1, 0, 0, 0, 0, 149, 23, 9, 1, 1, 3, 0, 225, 98, 52, 10, 8, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 204, 40, 8, 3, 2, 2, 0, 0, 0, 0, 0, 0, 199, 36, 22, 3, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 129, 45, 4, 1, 2, 2, 2, 2, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 7, 4, 9, 4, 3, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 9, 4, 8, 1, 9, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 5, 5, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 3, 1, 1, 2, 1, 6, 1, 1, 57, 28, 9, 15, 21, 2, 2, 1, 8, 13, 30, 23, 1, 39, 19, 20, 20, 3, 1, 3, 5, 4, 7, 31, 11, 44, 22, 17, 13, 5, 5, 6, 4, 12, 22, 2, 1, 21, 24, 6, 1, 3, 4, 6, 20, 36, 24, 1, 1, 32, 6, 3, 5, 3, 8, 21, 27, 51, 2, 2, 1, 3, 9, 5, 16, 9, 34, 23, 30, 64, 3, 2, 4, 5, 3, 4, 3, 4, 11, 4, 2, 4, 2, 5, 7, 10, 2, 3, 2, 10, 2, 8, 1, 3, 1, 10, 1, 2, 2, 1, 14, 4, 5, 3, 2, 4, 13, 5, 5, 0, 6, 26, 11, 1, 1, 0, 0, 0, 0, 0, 52, 29, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 7, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 21, 8, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 4, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 4, 12, 5, 1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 5, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 2, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 3, 9, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 0, 1, 1, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 10, 8, 13, 59, 40, 1, 1, 2, 1, 1, 166, 3, 1, 1, 1, 138, 37, 75, 1, 1, 4, 34, 9, 23, 31, 54, 129, 87, 89, 25, 14, 2, 1, 46, 18, 59, 238, 140, 67, 63, 37, 7, 4, 5, 2, 3, 1, 2, 1, 14, 30, 8, 15, 16, 35, 27, 7, 17, 16, 8, 76, 1, 2, 2, 1, 2, 15, 5, 1, 19, 18, 2, 18, 81, 4, 4, 2, 1, 6, 12, 9, 1, 1, 2, 12, 10, 13, 19, 2, 2, 3, 78, 31, 4, 29, 11, 10, 12, 2, 3, 2, 1, 2, 1, 5, 5, 2, 1, 22, 5, 85, 16, 26, 10, 3, 7, 4, 94, 5, 12, 4, 32, 22, 25, 2, 13, 4, 2, 7, 3, 1, 11, 31, 65, 14, 3, 3, 2, 4, 5, 96, 74, 5, 5, 2, 2, 1, 4, 10, 6, 8, 33, 6, 4, 9, 2, 21, 1, 0, 33, 7, 10, 4, 6, 149, 11, 3, 1, 3, 82, 1, 1, 6, 9, 402, 178, 49, 30, 13, 5, 3, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 336, 111, 41, 7, 11, 4, 1, 2, 1, 6, 1, 0, 0, 0, 0, 0, 0, 0, 424, 100, 30, 18, 2, 4, 1, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 470, 43, 15, 2, 4, 5, 2, 7, 3, 1, 5, 0, 0, 0, 0, 0, 0, 392, 54, 35, 9, 6, 1, 1, 5, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 287, 23, 20, 11, 6, 3, 1, 1, 3, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 187, 61, 5, 6, 5, 3, 1, 1, 14, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 101, 35, 18, 1, 4, 1, 8, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 23, 5, 7, 4, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 69, 13, 5, 3, 1, 1, 3, 5, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 56, 6, 2, 4, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 25, 8, 2, 5, 5, 5, 4, 1, 0, 0, 0, 0, 0, 0, 0, 20, 1, 2, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 2, 5, 3, 1, 0, 0, 0, 0, 0, 0, 0, 3, 1, 3, 0, 0, 0, 0, 1, 6, 3, 0, 0, 0, 0, 0, 0, 1, 0, 0, 12, 3, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 2, 0, 1, 2, 2, 2, 4, 1, 1, 1, 0, 0, 0, 0, 2, 0, 12, 0, 1, 1, 1, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 1, 7, 1, 1, 1, 1, 11, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 0, 1, 0, 8, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 4, 2, 0, 1, 0, 1, 0, 1, 2, 7, 2, 0, 2, 18, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 1, 1, 1, 1, 2, 5, 2, 1, 1, 3, 4, 3, 3, 27, 9, 2, 2, 18, 12, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 1, 4, 1, 5, 3, 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 3, 1, 2, 1, 2, 9, 1, 3, 2, 31, 38, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 3, 9, 2, 3, 1, 22, 1, 1, 19, 8, 3, 2, 6, 15, 3, 4, 1, 1, 1, 11, 24, 141, 8, 22, 1, 1, 1, 5, 3, 1, 1, 1, 2, 20, 15, 3, 2, 3, 2, 2, 3, 3, 4, 2, 2, 2, 2, 2, 1, 2, 1, 0, 8, 1, 0, 22, 1, 1, 0, 0, 0, 0, 0, 0, 0, 15, 23, 2, 2, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 3, 0, 0, 0, 0, 0, 0, 3, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 1, 0, 0, 0, 2, 0, 1, 0, 4, 2, 1, 1, 9, 18, 1, 3, 1, 1, 134, 5, 1, 13, 3, 2, 6, 2, 2, 5, 5, 127, 94, 131, 28, 7, 3, 2, 2, 1, 2, 48, 105, 57, 23, 1, 3, 1, 45, 59, 30, 4, 7, 6, 28, 27, 7, 1, 1, 114, 33, 2, 6, 25, 16, 5, 2, 6, 188, 7, 18, 27, 8, 33, 101, 58, 37, 6, 26, 30, 24, 4, 3, 8, 13, 20, 2, 18, 140, 69, 17, 14, 23, 4, 25, 8, 16, 5, 10, 1, 10, 25, 13, 2, 2, 5, 4, 1, 7, 12, 17, 3, 1, 2, 0, 15, 3, 0, 6, 12, 4, 1, 0, 95, 21, 8, 1, 11, 0, 0, 0, 190, 120, 24, 50, 3, 0, 0, 0, 0, 0, 0, 126, 51, 72, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 74, 122, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 12, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 2, 1, 2, 1, 1, 1, 1, 5, 1, 18, 2, 4, 1, 1, 1, 1, 18, 48, 27, 3, 3, 4, 1, 1, 1, 2, 1, 59, 8, 3, 1, 2, 2, 3, 2, 1, 1, 332, 88, 4, 15, 20, 10, 1, 4, 8, 13, 12, 29, 10, 13, 2, 1, 3, 5, 419, 19, 13, 44, 14, 6, 5, 3, 6, 12, 7, 28, 7, 31, 108, 21, 11, 1, 4, 1, 3, 97, 51, 33, 31, 18, 3, 2, 4, 2, 26, 46, 47, 156, 161, 79, 31, 13, 6, 3, 6, 18, 5, 30, 5, 20, 15, 33, 5, 7, 11, 1, 3, 1, 19, 3, 6, 13, 3, 20, 43, 10, 3, 4, 3, 3, 3, 7, 4, 8, 35, 13, 38, 27, 10, 6, 1, 4, 18, 2, 9, 6, 27, 41, 8, 3, 2, 2, 1, 5, 4, 8, 9, 4, 1, 6, 6, 5, 4, 5, 3, 7, 5, 17, 3, 7, 2, 1, 3, 0, 13, 18, 13, 4, 1, 1, 29, 73, 19, 6, 2, 3, 1, 0, 0, 25, 53, 9, 4, 1, 5, 2, 0, 214, 62, 7, 15, 6, 1, 2, 0, 0, 0, 331, 97, 37, 9, 21, 18, 1, 0, 0, 0, 240, 49, 16, 19, 20, 1, 1, 0, 0, 0, 0, 138, 34, 25, 17, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 58, 47, 27, 1, 0, 0, 0, 0, 0, 0, 0, 37, 24, 3, 1, 0, 0, 0, 0, 63, 1, 0, 0, 0, 3, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 10, 348, 130, 471, 374, 2422, 93, 936, 245, 1658, 6010, 169, 2080, 3228, 50, 2, 37, 10, 204, 2, 282, 532, 105, 163, 68, 378, 188, 1050, 214, 697, 15, 120, 25, 1, 1, 1, 1, 96, 132, 84, 53, 42, 46, 48, 223, 200, 53, 51, 131, 170, 24, 4, 10, 214, 109, 415, 1020, 175, 481, 70, 52, 165, 69, 94, 461, 689, 62, 145, 82, 134, 2430, 413, 615, 9907, 509, 6, 4, 803, 15141, 34, 11, 87, 3, 1, 4, 2067, 1744, 5813, 536, 913, 2080, 216, 1048, 1855, 19, 77, 364, 6, 596, 284, 496, 1310, 114, 691, 395, 943, 12, 1168, 47, 52, 127, 24, 57, 1, 72, 169, 465, 246, 98, 374, 128, 392, 239, 380, 822, 25, 139, 170, 75, 87, 121, 341, 415, 1204, 21, 54, 17, 87, 253, 204, 10, 191, 2, 197, 131, 90, 688, 77, 877, 244, 318, 51, 78, 192, 141, 127, 36, 217, 35, 390, 82, 174, 77, 151, 243, 375, 98, 4, 203, 559, 17, 958, 339, 194, 339, 361, 241, 146, 409, 115, 95, 542, 169, 133, 159, 413, 486, 46, 47, 833, 103, 102, 106, 2, 277, 218, 155, 490, 5, 250, 92, 62, 76, 1129, 1144, 67, 428, 152, 219, 165, 176, 44, 2, 219, 6, 0, 2813, 121, 12, 104, 65, 154, 245, 68, 824, 805, 1114, 17, 21, 650, 95, 552, 25, 410, 8, 348, 56, 1140, 11, 7, 45, 111, 67, 46, 85, 662, 170, 349, 65, 335, 328, 44, 87, 86, 38, 35, 260, 18, 20, 52, 8, 122, 0, 0, 0, 0, 190, 478, 41, 16, 127, 885, 280, 106, 188, 206, 134, 722, 463, 18, 702, 134, 136, 48, 41, 195, 98, 54, 42, 102, 291, 138, 195, 18, 990, 106, 25, 168, 1062, 1035, 571, 16, 5, 406, 36, 149, 297, 19, 65, 257, 78, 71, 48, 180, 104, 3, 362, 1522, 66, 31, 259, 25, 245, 18, 70, 1106, 2321, 272, 431, 259, 859, 14, 90, 100, 5, 154, 125, 6, 257, 147, 285, 92, 37, 159, 66, 57, 8, 198, 191, 71, 250, 161, 1401, 123, 53, 115, 524, 3979, 1847, 172, 172, 4, 85, 136, 2, 528, 5562, 9, 14, 1273, 6908, 1719, 7, 34, 23, 22, 2, 153, 6, 171, 183, 5, 35, 231, 77, 182, 6, 5, 28, 106, 79, 105, 38, 20, 1282, 96, 8480, 14, 4, 177, 2, 84, 107, 11, 8, 1926, 869, 8429, 86, 45, 272, 142, 407, 186, 426, 144, 246, 100, 22, 33, 155, 88, 349, 22, 63, 125, 128, 86, 73, 197, 124, 55, 195, 258, 105, 653, 288, 21, 1, 215, 565, 39, 161, 6, 84, 28, 60, 44, 741, 424, 1262, 117, 8, 43, 91, 48, 642, 102, 117, 190, 12, 177, 171, 7, 70, 689, 317, 1665, 90, 77, 181, 531, 167, 954, 485, 136, 439, 197, 845, 146, 432, 125, 300, 160, 275, 95, 72, 79, 90, 241, 166, 413, 60, 78, 179, 125, 262, 466, 529, 365, 327, 144, 46, 19, 17, 286, 168, 657, 399, 28, 739, 197, 59, 11, 327, 41, 1, 117, 247, 41, 190, 118, 82, 56, 196, 189, 203, 3, 63, 76, 106, 130, 140, 236, 182, 75, 85, 100, 18, 51, 290, 24, 0, 89, 532, 68, 196, 328, 187, 92, 76, 45, 166, 132, 100, 25, 173, 583, 216, 99, 321, 73, 239, 2, 108, 44, 366, 42, 21, 167, 0, 0, 323, 188, 463, 143, 582, 266, 0, 86, 118, 216, 236, 32, 137, 118, 1, 8, 128, 4, 3, 97, 132, 109, 21, 383, 2, 363, 1, 136, 85, 372, 114, 248, 151, 76, 42, 191, 217, 603, 158, 64, 172, 176, 31, 64, 187, 99, 131, 52, 17, 512, 115, 433, 76, 8, 73, 407, 768, 61, 64, 12, 66, 148, 8, 151, 96, 202, 514, 68, 149, 124, 76, 130, 244, 110, 4, 164, 12, 201, 90, 381, 119, 33, 109, 16, 257, 98, 20, 243, 205, 320, 75, 52, 349, 62, 404, 53, 27, 2, 337, 220, 34, 920, 77, 510, 234, 104, 222, 210, 36, 424, 53, 296, 399, 75, 102, 84, 423, 180, 0, 246, 92, 126, 20, 4, 171, 237, 281, 541, 169, 141, 1, 117, 200, 189, 109, 1, 199, 203, 21, 174, 135, 230, 2, 0, 661, 448, 150, 18, 4, 62, 235, 157, 43, 170, 24, 78, 86, 159, 236, 460, 48, 138, 33, 122, 276, 84, 233, 72, 683, 61, 151, 19, 123, 0, 94, 1075, 230, 106, 535, 434, 545, 78, 73, 166, 90, 321, 138, 78, 44, 1, 10, 63, 37, 75, 67, 83, 18, 167, 32, 87, 181, 240, 536, 256, 217, 140, 74, 223, 74, 6, 74, 160, 614, 1, 165, 209, 0, 43, 0, 18, 232, 125, 5, 64, 118, 80, 212, 0, 7, 89, 112, 201, 27, 199, 56, 0, 34, 38, 17, 198, 9, 537, 86, 109, 174, 188, 62, 145, 48, 6, 72, 30, 231, 231, 93, 6, 13, 51, 174, 63, 117, 103, 116, 546, 242, 110, 116, 16, 4, 24, 45, 2, 171, 322, 244, 266, 180, 157, 654, 62, 164, 202, 421, 140, 333, 98, 74, 40, 36, 77, 193, 86, 139, 32, 217, 159, 92, 1, 94, 172, 43, 156, 598, 200, 16, 110, 297, 191, 1273, 2337, 74, 1014, 228, 878, 714, 31, 247, 89, 126, 52, 144, 234, 279, 432, 66, 3, 32, 216, 30, 16, 78, 93, 40, 264, 25, 113, 565, 120, 12, 297, 101, 149, 148, 63, 94, 610, 20, 30, 256, 26, 87, 72, 329, 55, 446, 102, 175, 20, 98, 63, 68, 2, 165, 61, 97, 190, 86, 286, 61, 147, 297, 868, 61, 119, 222, 237, 138, 28, 171, 118, 59, 174, 197, 413, 125, 176, 85, 20, 106, 460, 509, 680, 153, 215, 427, 188, 74, 538, 109, 1, 54, 326, 349, 160, 257, 72, 169, 756, 13, 479, 95, 84, 86, 10, 62, 86, 191, 377, 75, 421, 9, 402, 98, 328, 164, 1, 318, 120, 162, 160, 501, 14, 118, 67, 800, 167, 100, 177, 166, 14, 277, 107, 45, 149, 2, 64, 104, 390, 480, 18, 398, 71, 104, 21, 231, 115, 19, 229, 285, 2, 175, 162, 210, 81, 10, 369, 1, 79, 124, 152, 62, 26, 154, 343, 243, 51, 367, 165, 306, 11, 7, 75, 1, 113, 176, 238, 262, 188, 246, 109, 105, 125, 98, 196, 124, 149, 63, 353, 139, 65, 8, 319, 132, 249, 39, 72, 364, 122, 373, 76, 117, 44, 260, 481, 148, 100, 33, 100, 244, 177, 41, 66, 19, 117, 583, 24, 32, 290, 25, 248, 9, 31, 276, 194, 58, 161, 243, 201, 159, 246, 247, 1, 189, 102, 176, 119, 399, 143, 121, 248, 99, 609, 180, 73, 1, 239, 110, 93, 319, 21, 60, 86, 163, 125, 159, 19, 257, 65, 27, 238, 328, 331, 124, 125, 45, 211, 53, 147, 87, 111, 49, 37, 428, 210, 225, 111, 369, 145, 191, 126, 43, 322, 115, 232, 81, 199, 15, 110, 268, 162, 354, 274, 175, 118, 121, 64, 133, 233, 78, 103, 127, 105, 155, 1, 2, 416, 54, 17, 329, 116, 249, 321, 352, 85, 5, 140, 11, 42, 4, 230, 242, 321, 1, 196, 548, 91, 424, 170, 931, 831, 473, 549, 163, 1097, 556, 2, 286, 324, 220, 153, 186, 589, 245, 578, 1048, 1, 157, 546, 431, 187, 126, 116, 233, 350, 69, 2, 92, 92, 256, 301, 202, 209, 199, 5, 205, 403, 161, 599, 150, 105, 1, 25, 158, 125, 45, 125, 85, 614, 139, 79, 146, 299, 202, 10, 593, 853, 453, 151, 175, 352, 312, 44, 493, 9, 354, 102, 344, 737, 2, 149, 108, 983, 161, 1075, 472, 76, 73, 17, 161, 597, 178, 176, 208, 157, 234, 49, 266, 391, 113, 615, 65, 91, 68, 76, 19, 0, 80, 152, 3, 245, 328, 351, 158, 1, 415, 943, 293, 14, 596, 54, 544, 1477, 535, 3, 449, 2, 247, 162, 128, 288, 1800, 403, 34, 98, 294, 128, 296, 43, 261, 77, 1428, 1712, 7340, 53, 34, 425, 1158, 2125, 48, 4023, 296, 5975, 136, 115, 189, 908, 532, 51, 1015, 81, 45, 715, 259, 1725, 21, 4, 0, 0, 687, 3285, 519, 140, 974, 2379, 336, 3910, 149, 919, 52, 67, 9, 460, 597, 367, 819, 123, 256, 0, 0, 0, 240, 1969, 51, 95, 569, 150, 97, 3685, 101, 523, 240, 610, 76, 87, 373, 45, 94, 164, 54, 35, 42, 462, 181, 74, 105, 50, 188, 29, 2355, 73, 594, 59, 800, 386, 182, 2142, 51, 56, 183, 98, 29, 789, 0, 0, 18, 4, 9, 100, 553, 781, 362, 134, 68, 373, 340, 220, 666, 4, 199, 83, 34, 81, 521, 22, 363, 72, 242, 222, 2300, 100, 400, 86, 120, 38, 99, 169, 240, 265, 148, 50, 58, 227, 1129, 11, 1509, 1138, 217, 4219, 56, 47, 159, 10, 380, 0, 0, 780, 149, 223, 22, 99, 18, 133, 665, 34, 328, 1967, 97, 255, 0, 102, 454, 115, 600, 5957, 1082, 96, 0, 4267, 15290, 636, 12, 59, 74, 355, 80, 551, 2115, 0, 0, 0, 0, 0, 0, 888, 10339, 250, 377, 50, 6, 15, 54, 66, 1884, 637, 69, 42, 123, 2280, 176, 912, 79, 24, 289, 123, 99, 409, 7236, 0, 107, 709, 131, 145, 94, 117, 1197, 71, 68, 333, 128, 51, 617, 1666, 130, 78, 46, 382, 364, 277, 64, 1041, 745, 0, 804, 1492, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 1768, 27, 26, 501, 352, 13, 19, 8, 2, 18, 15, 134, 50, 49, 136, 91, 388, 2321, 5677, 2119, 1, 1, 568, 203, 294, 385, 349, 29, 27, 54, 206, 77, 177, 355, 231, 301, 43, 14, 20, 4, 0, 0, 17, 14, 55, 24, 89, 30, 49, 52, 12, 387, 38, 244, 6, 205, 16, 1, 45, 48, 269, 132, 3791, 53, 2, 13038, 145, 65, 305, 161, 118, 60, 84, 118, 235, 495, 29, 21, 4, 73, 107, 137, 59, 25, 29, 3, 1194, 3518, 1291, 1974, 1934, 852, 127, 1021, 866, 1163, 15, 59, 1956, 44, 50, 169, 59, 204, 144, 212, 257, 5, 294, 29, 160, 43, 198, 276, 1, 590, 29, 91, 13, 224, 249, 454, 5321, 2, 773, 152, 166, 408, 159, 43, 776, 202, 82, 85, 36, 303, 52, 464, 137, 190, 159, 33, 121, 79, 150, 113, 67, 68, 42, 218, 1215, 209, 229, 327, 42, 70, 201, 109, 89, 107, 2, 94, 98, 146, 20, 274, 243, 164, 123, 264, 337, 90, 308, 34, 38, 37, 111, 80, 55, 164, 803, 63, 74, 34, 55, 28, 595, 59, 244, 254, 137, 41, 89, 74, 94, 58, 11, 28, 153, 530, 93, 73, 296, 107, 60, 67, 4, 49, 114, 202, 135, 400, 37, 79, 2, 333, 2, 2, 53, 87, 29, 938, 140, 225, 62, 101, 28, 51, 707, 9, 4, 43, 3, 406, 77, 118, 143, 152, 76, 22, 13, 6, 82, 99, 208, 35, 161, 43, 184, 695, 91, 16, 60, 401, 119, 75, 351, 239, 31, 56, 61, 200, 127, 180, 6, 17, 377, 264, 179, 442, 2175, 63, 32, 94, 478, 38, 51, 377, 29, 2, 22, 168, 120, 95, 39, 69, 202, 225, 74, 39, 76, 62, 84, 67, 83, 35, 133, 38, 43, 407, 248, 771, 189, 117, 207, 17, 215, 287, 121, 84, 118, 69, 122, 296, 122, 109, 57, 95, 81, 114, 32, 21, 293, 139, 85, 56, 70, 60, 755, 62, 80, 184, 199, 708, 196, 188, 34, 163, 97, 75, 68, 213, 376, 1, 3, 96, 79, 1034, 539, 0, 212, 491, 261, 29, 42, 62, 17, 35, 354, 207, 66, 433, 293, 203, 707, 1, 126, 213, 70, 204, 1240, 273, 788, 869, 28, 281, 1011, 534, 804, 4865, 1, 6504, 107, 146, 33, 107, 22, 13, 19, 50, 1, 9, 172, 39, 18, 35, 6, 87, 65, 162, 59, 90, 33, 55, 15, 40, 35, 19, 52, 2, 17, 118, 1, 17, 54, 162, 119, 102, 289, 658, 325, 162, 3903, 0, 0, 0, 0, 0, 0, 0, 0, 506, 66, 58, 39, 66, 256, 74, 87, 54, 54, 101, 96, 19, 156, 106, 46, 353, 39, 123, 145, 47, 78, 49, 63, 210, 338, 68, 794, 76, 2157, 0, 58, 33, 351, 28, 5, 58, 66, 42, 37, 127, 0, 33, 32, 28, 57, 47, 40, 28, 36, 21, 17, 59, 34, 268, 49, 73, 0, 88, 8, 53, 46, 46, 67, 8, 26, 30, 53, 15, 22, 352, 19, 47, 170, 34, 7, 26, 58, 101, 20, 42, 18, 0, 34, 55, 34, 33, 0, 157, 107, 116, 39, 72, 44, 46, 32, 14, 56, 14, 39, 34, 65, 29, 354, 156, 33, 40, 3, 60, 21, 41, 1, 32, 16, 159, 67, 80, 87, 48, 65, 45, 7, 3, 106, 2, 79, 18, 32, 48, 53, 78, 44, 41, 32, 210, 53, 70, 24, 36, 52, 149, 495, 369, 322, 28, 80, 644, 573, 90, 1273, 0, 564, 2253, 0, 0, 1095, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 2, 2, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 3, 3, 4, 10, 1, 0, 6, 0, 3, 5, 2, 15, 6, 4, 2, 3, 1, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 16, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 1, 72, 22, 19, 6, 2, 4, 10, 36, 12, 324, 16, 1, 14, 5, 2, 60, 1, 50, 12, 1, 5, 5, 32, 6, 21, 1, 1, 4, 41, 3, 7, 1, 7, 3, 2, 2, 1, 1, 1, 7, 7, 0, 0, 0, 11, 74, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20, 0, 0, 0, 66, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 4, 1, 1, 1, 2, 4, 1, 2, 1, 2, 2, 1, 4, 2, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 5, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 2, 1, 1, 1, 1, 5, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 14, 7, 2, 3, 2, 1, 4, 1, 1, 2, 1, 3, 3, 2, 1, 2, 4, 1, 1, 1, 5, 3, 1, 1, 1, 1, 25, 3, 5, 3, 2, 3, 11, 2, 2, 8, 2, 3, 5, 1, 4, 1, 2, 2, 5, 1, 2, 1, 4, 10, 2, 3, 1, 7, 18, 3, 3, 7, 8, 4, 3, 4, 3, 9, 2, 2, 5, 1, 1, 3, 3, 4, 2, 4, 9, 2, 4, 2, 2, 1, 1, 1, 1, 1, 2, 13, 2, 1, 1, 1, 2, 4, 1, 2, 1, 16, 1, 9, 6, 9, 3, 5, 1, 3, 1, 2, 2, 2, 2, 3, 4, 2, 1, 2, 2, 3, 4, 7, 2, 1, 1, 1, 1, 1, 6, 1, 7, 1, 4, 7, 6, 2, 2, 1, 21, 19, 11, 10, 4, 5, 4, 3, 3, 10, 2, 2, 5, 30, 12, 2, 6, 9, 3, 1, 2, 1, 1, 12, 22, 12, 3, 5, 6, 2, 43, 28, 4, 13, 6, 17, 1, 4, 4, 74, 44, 10, 7, 2, 7, 5, 6, 4, 150, 37, 5, 11, 2, 3, 3, 4, 1, 1, 218, 65, 41, 7, 8, 4, 11, 1, 2, 4, 1, 9, 3, 1, 3, 297, 70, 14, 2, 5, 4, 4, 1, 2, 6, 3, 2, 4, 3, 3, 10, 415, 47, 18, 4, 3, 8, 4, 1, 2, 4, 8, 13, 3, 2, 465, 190, 21, 20, 9, 5, 2, 2, 15, 20, 2, 4, 3, 5, 1, 1, 502, 114, 8, 21, 3, 7, 2, 6, 2, 10, 5, 499, 210, 69, 48, 12, 1, 2, 7, 6, 16, 6, 347, 241, 101, 3, 2, 6, 9, 2, 4, 4, 3, 24, 4, 2, 438, 151, 47, 1, 14, 5, 9, 10, 6, 2, 4, 686, 71, 34, 11, 5, 3, 17, 3, 11, 9, 2, 6, 9, 2, 579, 112, 6, 18, 35, 43, 47, 86, 6, 34, 31, 4, 200, 36, 1, 366, 20, 48, 95, 14, 29, 2, 2, 7, 13, 3, 11, 162, 45, 2, 47, 23, 121, 49, 35, 23, 5, 47, 13, 20, 175, 14, 7, 21, 8, 25, 7, 12, 2, 23, 3, 3, 0, 26, 17, 4, 2, 3, 0, 29, 24, 2, 21, 27, 1, 0, 3, 34, 30, 12, 1, 4, 3, 24, 57, 2, 5, 0, 0, 0, 0, 0, 14, 12, 63, 43, 30, 12, 6, 5, 5, 5, 3, 1, 41, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 5, 2, 5, 172, 32, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 28, 6, 6, 40, 5, 1, 0, 0, 0, 0, 0, 0, 0, 46, 5, 21, 3, 105, 10, 2, 0, 0, 0, 0, 0, 0, 0, 0, 8, 119, 0, 0, 1, 60, 2, 3, 0, 0, 8, 2, 4, 25, 4, 0, 3, 2, 26, 0, 42, 3, 1, 26, 25, 3, 0, 0, 75, 1, 1, 0, 0, 23, 33, 0, 0, 0, 35, 4, 22, 4, 20, 3, 41, 3, 1, 0, 0, 5, 1, 0, 21, 1003, 29, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 529, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 1, 10, 2, 2, 1, 1, 3, 2, 1, 1, 3, 1, 1, 1, 1, 3, 1, 2, 2, 1, 2, 1, 1, 5, 8, 12, 5, 5, 5, 2, 8, 4, 1, 1, 4, 5, 1, 3, 3, 9, 4, 2, 2, 1, 2, 5, 2, 6, 1, 5, 7, 10, 3, 2, 2, 4, 2, 1, 22, 20, 9, 6, 3, 5, 1, 1, 3, 22, 19, 21, 2, 2, 2, 2, 2, 1, 2, 82, 14, 7, 4, 5, 2, 5, 2, 1, 1, 1, 138, 37, 8, 5, 8, 1, 2, 3, 2, 2, 4, 3, 227, 50, 11, 10, 1, 4, 1, 2, 1, 2, 2, 4, 2, 290, 62, 41, 1, 3, 1, 4, 1, 2, 1, 387, 53, 26, 8, 1, 13, 8, 2, 2, 499, 53, 35, 4, 8, 7, 5, 4, 4, 11, 4, 2, 5, 20, 1, 581, 39, 50, 29, 14, 10, 3, 2, 4, 7, 22, 10, 3, 503, 162, 26, 63, 5, 4, 3, 3, 8, 3, 27, 7, 1, 397, 169, 61, 32, 5, 4, 12, 5, 1, 477, 113, 32, 29, 2, 3, 3, 33, 9, 5, 634, 42, 64, 9, 30, 3, 36, 6, 500, 266, 1, 21, 2, 1, 2, 2, 28, 7, 6, 21, 9, 7, 7, 145, 21, 4, 308, 15, 19, 25, 1, 5, 38, 7, 8, 6, 3, 2, 220, 33, 6, 29, 28, 72, 21, 40, 10, 17, 76, 16, 467, 5, 1, 4, 16, 28, 20, 5, 3, 31, 22, 4, 25, 3, 3, 29, 4, 5, 6, 1, 30, 4, 3, 0, 70, 3, 2, 0, 0, 5, 20, 39, 6, 0, 0, 0, 0, 0, 39, 27, 2, 66, 4, 0, 0, 0, 2, 4, 74, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 31, 4, 7, 8, 17, 2, 0, 0, 0, 32, 25, 5, 8, 0, 0, 22, 96, 2, 0, 0, 0, 27, 22, 5, 0, 32, 1, 0, 7, 4, 0, 27, 25, 994, 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 550, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 0, 1, 1, 3, 1, 1, 2, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 3, 6, 3, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 6, 1, 2, 2, 4, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 4, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 1, 0, 1, 1, 1, 2, 1, 2, 4, 1, 1, 1, 1, 1, 2, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 14, 2, 6, 1, 3, 2, 7, 1, 1, 4, 5, 11, 2, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 2, 2, 1, 1, 1, 1, 8, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 3, 3, 3, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 3, 0, 0, 0, 1, 0, 1, 2, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 2, 6, 0, 0, 2, 0, 0, 1, 2, 1, 0, 1, 2, 1, 0, 1, 2, 1, 3, 1, 1, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 1, 1, 3, 2, 1, 1, 1, 3, 2, 1, 1, 2, 1, 15, 1, 9, 6, 1, 2, 2, 1, 2, 1, 1, 14, 71, 7, 1, 2, 8, 4, 6, 3, 36, 12, 1, 4, 2, 4, 1, 449, 3, 5, 2, 7, 2, 1, 2, 11, 15, 11, 1, 4, 41, 134, 74, 17, 78, 36, 81, 17, 7, 4, 6, 27, 15, 20, 31, 29, 35, 38, 40, 207, 256, 1, 2, 1, 1, 11, 1, 33, 6, 5, 27, 11, 8, 30, 28, 1, 44, 2, 13, 10, 11, 8, 3, 12, 1, 9, 11, 9, 24, 19, 7, 1, 1, 15, 5, 9, 17, 9, 27, 64, 1, 10, 6, 6, 12, 8, 21, 35, 8, 4, 6, 9, 11, 21, 11, 23, 40, 2, 10, 6, 6, 9, 7, 6, 15, 3, 1, 1, 5, 6, 16, 11, 8, 6, 7, 1, 5, 17, 8, 0, 0, 0, 14, 10, 4, 11, 0, 0, 0, 0, 6, 6, 4, 13, 35, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 20, 7, 57, 0, 0, 0, 0, 0, 0, 14, 1, 33, 29, 1, 0, 0, 0, 0, 0, 27, 14, 59, 0, 0, 0, 0, 65, 25, 0, 385, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 121, 36, 13, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 2, 0, 0, 0, 0, 0, 0, 36, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 2, 0, 1, 0, 6, 0, 0, 0, 1, 0, 3, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 3, 3, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 3, 4, 11, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 3, 1, 3, 1, 9, 4, 18, 1, 32, 12, 12, 27, 13, 20, 2, 1, 3, 2, 4, 3, 2, 3, 8, 2, 4, 3, 1, 3, 6, 1, 9, 3, 4, 12, 4, 21, 2, 1, 1, 0, 0, 1, 1, 0, 0, 2, 3, 4, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 5, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 3, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 2, 0, 0, 0, 0, 1, 1, 1, 4, 1, 1, 13, 1, 2, 1, 3, 1, 6, 2, 1, 9, 5, 9, 8, 4, 5, 1, 1, 2, 2, 1, 2, 2, 2, 11, 29, 32, 30, 1, 3, 7, 1, 4, 1, 1, 2, 1, 1, 1, 3, 1, 1, 1, 8, 13, 1, 2, 4, 1, 1, 2, 5, 2, 2, 12, 1, 1, 1, 2, 2, 1, 4, 5, 2, 1, 3, 1, 4, 3, 6, 11, 8, 3, 3, 2, 4, 5, 3, 2, 2, 2, 6, 4, 2, 2, 2, 1, 2, 4, 3, 3, 2, 8, 3, 4, 3, 3, 1, 2, 6, 9, 2, 2, 3, 11, 1, 6, 2, 1, 8, 2, 6, 5, 3, 1, 9, 2, 2, 1, 3, 4, 5, 12, 4, 3, 2, 9, 4, 2, 6, 4, 11, 7, 13, 1, 6, 4, 5, 6, 3, 5, 8, 2, 2, 6, 7, 5, 3, 2, 3, 3, 3, 9, 4, 6, 7, 8, 1, 5, 1, 1, 1, 1, 2, 3, 2, 4, 0, 0, 2, 17, 3, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 6, 4, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 16, 3, 2, 1, 1, 19, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 6, 6, 8, 0, 0, 0, 0, 3, 1, 8, 1, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 2, 0, 0, 0, 0, 5, 0, 0, 0, 16, 14, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 1, 1, 0, 0, 0, 2, 1, 0, 1, 0, 1, 1, 0, 2, 1, 0, 0, 1, 2, 3, 2, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 6, 3, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 0, 1, 1, 1, 16, 1, 1, 1, 1, 45, 163, 1, 7, 3, 12, 7, 10, 10, 10, 15, 19, 11, 5, 6, 7, 4, 5, 1, 3, 3, 1, 3, 1, 1, 51, 3, 1, 5, 1, 8, 19, 16, 1, 6, 18, 53, 57, 5, 23, 15, 27, 8, 4, 17, 17, 4, 3, 3, 1, 4, 1, 9, 2, 1, 16, 1, 8, 7, 10, 1, 8, 3, 1, 2, 1, 2, 1, 3, 1, 6, 2, 3, 10, 11, 11, 11, 2, 2, 1, 36, 12, 17, 13, 12, 2, 3, 2, 2, 2, 1, 1, 20, 29, 19, 24, 20, 23, 2, 8, 1, 2, 3, 2, 1, 11, 27, 16, 2, 8, 13, 1, 1, 5, 1, 1, 25, 29, 6, 19, 10, 8, 10, 5, 5, 2, 2, 26, 50, 11, 21, 18, 20, 2, 4, 3, 1, 13, 49, 14, 28, 69, 19, 2, 6, 3, 2, 2, 1, 1, 34, 68, 2, 24, 24, 7, 6, 17, 2, 1, 3, 1, 1, 55, 19, 40, 18, 17, 1, 10, 7, 4, 5, 78, 68, 64, 7, 2, 20, 6, 3, 7, 6, 26, 5, 2, 7, 3, 4, 62, 47, 15, 12, 15, 14, 20, 4, 10, 1, 17, 3, 1, 116, 77, 17, 6, 6, 2, 32, 42, 14, 12, 11, 29, 6, 8, 15, 8, 3, 2, 19, 40, 23, 3, 1, 114, 22, 11, 17, 11, 4, 11, 8, 35, 47, 16, 10, 6, 5, 6, 6, 39, 74, 38, 2, 1, 15, 4, 9, 24, 13, 25, 13, 33, 13, 25, 4, 8, 5, 20, 55, 39, 4, 1, 4, 4, 7, 13, 11, 6, 3, 6, 36, 10, 1, 2, 1, 3, 5, 5, 1, 13, 7, 5, 4, 13, 2, 3, 3, 3, 1, 0, 14, 16, 10, 5, 3, 7, 1, 41, 12, 10, 12, 9, 9, 4, 5, 15, 14, 7, 5, 9, 4, 9, 27, 11, 20, 5, 10, 4, 30, 6, 13, 15, 4, 5, 7, 22, 29, 37, 15, 8, 2, 2, 45, 42, 35, 10, 10, 2, 1, 59, 37, 21, 4, 9, 5, 9, 1, 1, 59, 43, 9, 16, 2, 8, 8, 8, 3, 0, 69, 33, 50, 25, 14, 10, 9, 11, 0, 0, 20, 19, 13, 38, 11, 22, 15, 13, 2, 3, 5, 2, 19, 12, 11, 21, 29, 3, 8, 11, 1, 41, 6, 20, 9, 6, 7, 19, 2, 41, 10, 12, 9, 6, 16, 6, 0, 29, 7, 21, 21, 8, 12, 26, 37, 20, 8, 6, 4, 29, 10, 12, 25, 5, 1, 31, 4, 13, 19, 0, 47, 57, 31, 6, 2, 0, 0, 68, 23, 3, 197, 25, 7, 0, 0, 0, 0, 0, 0, 0, 215, 13, 5, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 17, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 2, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 2, 2, 1, 1, 0, 0, 1, 1, 0, 0, 2, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 8, 10, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 6, 1, 2, 4, 4, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 3, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 2, 2, 0, 0, 1, 0, 1, 0, 2, 0, 0, 2, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 12, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 1, 2, 3, 12, 1, 0, 6, 0, 0, 0, 1, 0, 1, 1, 1, 1, 106, 73, 12, 10, 6, 3, 1, 1, 1, 1, 112, 17, 22, 5, 1, 13, 10, 1, 181, 20, 24, 34, 24, 19, 10, 4, 1, 1, 2, 139, 61, 57, 33, 28, 18, 9, 3, 6, 2, 79, 68, 56, 47, 26, 10, 12, 8, 1, 2, 2, 113, 19, 45, 20, 10, 7, 4, 180, 89, 44, 39, 4, 1, 2, 301, 63, 39, 17, 7, 4, 4, 438, 92, 94, 43, 8, 2, 2, 3, 427, 208, 87, 43, 19, 4, 2, 4, 7, 2, 502, 164, 73, 18, 11, 7, 3, 8, 1, 5, 1, 876, 171, 20, 14, 8, 7, 11, 8, 6, 17, 25, 1, 1, 927, 231, 37, 1, 3, 33, 56, 48, 18, 24, 22, 16, 3, 25, 105, 50, 5, 2, 430, 21, 23, 39, 12, 55, 117, 88, 83, 9, 54, 67, 20, 53, 9, 60, 45, 216, 185, 8, 3, 19, 18, 6, 24, 38, 68, 86, 41, 70, 37, 118, 21, 11, 11, 13, 128, 86, 11, 3, 1, 24, 14, 13, 9, 22, 8, 1, 6, 13, 10, 3, 4, 17, 12, 1, 1, 6, 14, 9, 9, 13, 2, 18, 11, 61, 10, 37, 10, 7, 87, 42, 27, 71, 22, 20, 14, 14, 2, 0, 49, 43, 64, 49, 27, 8, 26, 9, 44, 44, 60, 52, 7, 26, 34, 66, 67, 13, 36, 10, 37, 15, 143, 69, 30, 53, 25, 13, 35, 14, 2, 157, 17, 81, 40, 33, 72, 9, 237, 64, 34, 65, 70, 1, 155, 42, 81, 118, 6, 104, 100, 149, 39, 123, 142, 26, 1, 405, 61, 1, 1, 1189, 16, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 456, 29, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 54, 6, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 0, 1, 0, 1, 0, 1, 3, 2, 2, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 7, 2, 1, 3, 3, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 4, 1, 2, 0, 0, 2, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 6, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 2, 4, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 2, 1, 1, 3, 3, 2, 1, 1, 2, 1, 2, 3, 2, 2, 3, 1, 3, 1, 1, 1, 2, 1, 1, 2, 1, 4, 1, 2, 2, 1, 1, 1, 1, 1, 2, 2, 5, 2, 1, 1, 2, 3, 2, 1, 3, 4, 2, 2, 3, 4, 2, 2, 1, 1, 1, 0, 0, 0, 3, 1, 2, 2, 3, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 4, 1, 0, 1, 2, 1, 1, 0, 0, 1, 0, 0, 3, 2, 0, 0, 0, 1, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 0, 2, 0, 1, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 24, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 5, 2, 2, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 4, 18, 9, 4, 2, 3, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 1, 1, 1, 3, 4, 45, 8, 3, 1, 1, 3, 1, 1, 1, 2, 6, 7, 1, 1, 1, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 25, 1, 0, 0, 0, 1, 2, 17, 8, 16, 15, 2, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 2, 1, 1, 1, 1, 1, 1, 1, 5, 3, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 0, 0, 0, 6, 4, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 2, 4, 5, 2, 7, 6, 6, 51, 5, 1, 2, 3, 4, 1, 1, 2, 1, 1, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 3, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 3, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 1, 1, 1, 3, 1, 3, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 6, 1, 2, 1, 1, 3, 3, 5, 12, 4, 3, 3, 3, 1, 2, 5, 12, 4, 1, 1, 2, 7, 26, 4, 3, 1, 2, 6, 2, 7, 125, 8, 12, 14, 16, 9, 1, 60, 73, 7, 6, 2, 4, 24, 18, 24, 24, 53, 151, 6, 9, 4, 6, 10, 5, 4, 13, 6, 3, 3, 17, 9, 11, 0, 0, 0, 7, 13, 4, 0, 0, 0, 3, 10, 15, 0, 0, 0, 15, 25, 0, 0, 0, 0, 83, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 18, 147, 8, 107, 20, 14, 196, 19, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 7, 1, 1, 1, 2, 1, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 1, 1, 1, 11, 1, 6, 153, 75, 6, 3, 1, 1, 1, 1, 576, 18, 1, 1, 2, 2, 1, 1, 3140, 74, 16, 2, 7, 12, 5, 3, 4, 15, 17, 23, 62, 26, 13, 9, 1, 6, 1465, 398, 44, 17, 25, 63, 16, 47, 37, 84, 151, 131, 137, 121, 71, 51, 61, 15, 13, 3, 35, 18, 30, 174, 256, 633, 361, 111, 42, 4, 4, 1, 308, 38, 13, 22, 10, 23, 77, 44, 57, 34, 20, 60, 26, 120, 33, 16, 16, 5, 38, 136, 45, 302, 169, 54, 15, 16, 20, 70, 25, 36, 72, 5, 6, 15, 17, 29, 26, 139, 220, 33, 30, 3, 21, 3, 17, 19, 25, 21, 14, 21, 23, 11, 18, 5, 24, 23, 8, 7, 69, 14, 13, 37, 71, 57, 28, 6, 2, 24, 29, 15, 37, 5, 23, 35, 40, 15, 4, 92, 30, 12, 17, 7, 19, 12, 9, 7, 7, 107, 136, 24, 7, 17, 8, 17, 25, 81, 13, 28, 12, 116, 42, 20, 47, 13, 39, 10, 31, 46, 57, 6, 4, 125, 65, 6, 74, 29, 75, 16, 42, 171, 107, 33, 13, 1, 11, 5, 71, 26, 36, 25, 36, 72, 63, 43, 10, 47, 19, 28, 49, 41, 12, 4, 38, 16, 11, 16, 28, 56, 41, 32, 19, 12, 17, 85, 100, 51, 20, 12, 8, 34, 4, 27, 95, 18, 9, 8, 28, 103, 5, 20, 11, 6, 23, 33, 9, 9, 2, 44, 46, 4, 64, 70, 70, 133, 32, 4, 127, 295, 150, 11, 9, 4, 824, 297, 46, 23, 1, 0, 0, 2130, 556, 106, 47, 8, 4, 4, 1, 0, 0, 0, 0, 0, 2484, 412, 77, 21, 1, 1, 5, 1, 3, 0, 0, 0, 0, 0, 0, 0, 2393, 167, 88, 33, 5, 3, 3, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1802, 265, 64, 45, 14, 20, 3, 2, 3, 5, 2, 4, 1, 2, 12, 6, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1508, 132, 35, 17, 12, 15, 2, 8, 2, 1, 5, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1209, 178, 52, 14, 7, 3, 2, 3, 1, 7, 8, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 938, 120, 25, 4, 15, 1, 5, 14, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 717, 115, 69, 4, 2, 3, 2, 6, 6, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 547, 61, 36, 3, 3, 7, 3, 10, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 323, 95, 45, 14, 7, 5, 2, 4, 10, 1, 11, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 210, 51, 22, 5, 13, 5, 2, 3, 1, 4, 19, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 135, 50, 19, 5, 4, 4, 7, 2, 11, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 77, 37, 6, 10, 4, 2, 9, 2, 4, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 24, 6, 9, 9, 11, 12, 14, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 3, 6, 3, 4, 26, 3, 1, 0, 0, 0, 0, 0, 0, 11, 6, 6, 2, 2, 2, 3, 0, 0, 0, 0, 0, 7, 3, 2, 3, 2, 5, 2, 0, 0, 0, 0, 0, 0, 0, 0, 3, 4, 6, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 10, 1, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 27, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 0, 0, 0, 0, 38, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 4, 1, 1, 1, 1, 16, 7, 5, 1, 1, 8, 2, 1, 2, 3, 1, 2, 40, 14, 1, 1, 2, 1, 2, 4, 3, 3, 1, 2, 34, 3, 1, 4, 5, 11, 13, 7, 9, 5, 10, 4, 3, 1, 1, 1, 1, 2, 1, 2, 1, 1, 3, 1, 1, 2, 1, 1, 1, 5, 5, 3, 21, 14, 11, 7, 13, 14, 3, 4, 1, 3, 1, 4, 1, 3, 2, 3, 1, 2, 1, 1, 1, 1, 5, 2, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 1, 4, 1, 2, 2, 1, 2, 4, 2, 2, 2, 2, 2, 1, 1, 1, 3, 2, 1, 1, 1, 1, 5, 1, 0, 1, 2, 2, 3, 1, 3, 2, 1, 2, 0, 2, 0, 1, 1, 2, 1, 1, 1, 4, 2, 3, 1, 5, 4, 9, 4, 3, 2, 7, 2, 2, 4, 4, 1, 1, 1, 1, 7, 16, 2, 0, 0, 2, 4, 18, 3, 4, 1, 3, 1, 0, 1, 0, 0, 0, 4, 13, 2, 4, 4, 5, 2, 5, 3, 1, 1, 1, 0, 22, 7, 10, 5, 3, 3, 0, 2, 4, 1, 1, 1, 0, 0, 0, 23, 14, 0, 1, 11, 7, 5, 0, 1, 1, 0, 21, 10, 21, 6, 18, 2, 1, 2, 16, 23, 23, 10, 10, 6, 3, 2, 1, 24, 10, 12, 11, 6, 1, 2, 3, 4, 1, 2, 39, 22, 37, 24, 8, 9, 1, 2, 1, 2, 76, 41, 16, 19, 13, 2, 0, 1, 4, 1, 8, 2, 172, 44, 28, 14, 5, 1, 5, 3, 2, 4, 12, 1, 1, 170, 152, 63, 22, 5, 2, 4, 3, 9, 3, 6, 10, 16, 47, 2, 5, 1, 1, 1, 1, 1, 196, 68, 23, 19, 5, 6, 4, 6, 3, 5, 35, 92, 4, 1, 1, 1, 1, 212, 41, 31, 31, 5, 3, 19, 7, 4, 2, 5, 3, 9, 3, 7, 10, 117, 107, 6, 2, 1, 2, 32, 61, 23, 5, 5, 10, 1, 16, 22, 11, 10, 7, 7, 106, 193, 6, 3, 1, 2, 19, 14, 12, 10, 13, 4, 5, 4, 27, 54, 2, 1, 1, 0, 9, 7, 2, 10, 7, 10, 4, 47, 71, 6, 2, 1, 6, 3, 6, 4, 32, 55, 4, 5, 1, 1, 7, 8, 37, 4, 2, 3, 1, 2, 15, 19, 2, 1, 19, 24, 0, 21, 12, 6, 1, 9, 7, 0, 8, 10, 3, 11, 4, 1, 5, 4, 33, 2, 10, 11, 9, 9, 9, 6, 6, 1, 5, 3, 1, 26, 10, 401, 4, 10, 1, 2, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 148, 155, 52, 33, 6, 13, 11, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 52, 14, 13, 3, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 27, 2, 8, 8, 3, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 3, 9, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 8, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 3, 4, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 1, 2, 1, 0, 2, 0, 0, 2, 0, 1, 1, 1, 0, 0, 0, 1, 0, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 1, 1, 1, 2, 1, 2, 1, 1, 2, 2, 3, 3, 5, 1, 1, 2, 1, 4, 2, 1, 2, 2, 3, 1, 1, 2, 1, 1, 1, 6, 4, 4, 2, 2, 1, 3, 5, 3, 3, 1, 2, 23, 8, 1, 1, 9, 6, 4, 1, 9, 14, 2, 1, 17, 3, 2, 3, 19, 14, 1, 31, 2, 2, 2, 33, 43, 5, 1, 9, 2, 28, 70, 5, 5, 8, 3, 1, 1, 1, 3, 3, 2, 1, 9, 2, 0, 1, 2, 1, 38, 6, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 8, 3, 1, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 4, 1, 1, 5, 16, 12, 14, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 8, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 3, 0, 0, 1, 2, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 1, 2, 2, 79, 11, 1, 2, 1, 1, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 1, 2, 1, 0, 0, 0, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 2, 3, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 1, 1, 3, 3, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 5, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 9, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 1, 5, 1, 1, 1, 2, 17, 3, 1, 8, 12, 4, 14, 6, 2, 2, 5, 5, 38, 23, 29, 5, 4, 9, 14, 1, 3, 1, 1, 1, 0, 0, 1, 2, 0, 0, 3, 2, 3, 0, 0, 0, 0, 0, 0, 0, 6, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 4, 1, 1, 0, 2, 1, 0, 0, 1, 0, 12, 0, 0, 2, 0, 1, 0, 1, 1, 2, 1, 2, 1, 1, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 1, 1, 0, 0, 2, 3, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 12, 0, 0, 1, 1, 4, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 2, 2, 2, 2, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 5, 5, 5, 1, 1, 1, 2, 1, 1, 1, 4, 3, 1, 1, 2, 1, 1, 2, 1, 1, 1, 2, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 3, 1, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 2, 1, 1, 1, 3, 4, 3, 3, 12, 25, 24, 3, 1, 2, 3, 2, 21, 6, 4, 2, 2, 3, 7, 22, 2, 1, 2, 4, 1, 2, 2, 0, 0, 0, 2, 2, 1, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 2, 3, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 4, 0, 2, 3, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 2, 0, 1, 0, 1, 1, 11, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 0, 0, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 3, 14, 2, 3, 1, 10, 1, 1, 6, 1, 2, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 2, 1, 2, 3, 3, 2, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 4, 8, 4, 0, 2, 0, 0, 3, 1, 0, 0, 3, 1, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 2, 2, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 12, 5, 4, 6, 2, 1, 2, 6, 2, 16, 1, 1, 4, 2, 4, 24, 9, 4, 2, 4, 4, 1, 17, 5, 1, 5, 1, 1, 32, 8, 1, 2, 8, 7, 23, 5, 20, 4, 2, 4, 1, 16, 5, 22, 17, 2, 2, 12, 82, 12, 4, 2, 1, 5, 1, 1, 3, 7, 7, 3, 19, 9, 8, 2, 1, 2, 4, 3, 3, 2, 1, 3, 4, 2, 9, 7, 1, 1, 5, 3, 1, 1, 11, 2, 1, 2, 13, 2, 0, 16, 6, 1, 1, 0, 0, 24, 5, 2, 3, 1, 0, 0, 0, 0, 0, 0, 3, 2, 19, 9, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 2, 1, 32, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20, 3, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 2, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0, 2, 2, 2, 2, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 1, 5, 12, 1, 2, 5, 3, 60, 1, 1, 1, 2, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 2, 2, 0, 0, 1, 0, 4, 0, 1, 1, 0, 0, 1, 1, 3, 0, 1, 0, 1, 0, 1, 3, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 3, 2, 1, 1, 1, 1, 1, 1, 2, 3, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 2, 1, 3, 2, 1, 1, 1, 3, 1, 1, 1, 2, 1, 2, 1, 1, 2, 1, 1, 1, 4, 2, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 2, 1, 1, 1, 2, 2, 5, 2, 2, 0, 1, 1, 0, 0, 0, 0, 2, 0, 0, 2, 0, 1, 1, 0, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 4, 0, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 2, 1, 0, 0, 1, 0, 1, 2, 0, 2, 2, 0, 1, 0, 1, 2, 2, 5, 3, 0, 0, 1, 3, 2, 1, 2, 3, 1, 1, 2, 0, 0, 2, 0, 0, 2, 1, 3, 3, 0, 1, 1, 1, 0, 3, 0, 2, 3, 3, 3, 0, 0, 0, 1, 3, 1, 0, 1, 2, 3, 1, 2, 3, 0, 1, 1, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, 0, 3, 6, 3, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 4, 5, 5, 3, 1, 7, 11, 4, 1, 1, 5, 2, 3, 4, 2, 2, 4, 2, 1, 6, 2, 1, 2, 2, 0, 0, 0, 2, 1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 6, 12, 6, 0, 4, 0, 1, 1, 3, 0, 0, 0, 1, 2, 0, 1, 1, 2, 1, 3, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 2, 0, 2, 0, 1, 2, 1, 0, 1, 0, 3, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 3, 1, 3, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 1, 2, 2, 0, 0], "yaxis": "y"}], "layout": {"height": 300, "legend": {"tracegroupgap": 0}, "shapes": [{"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 65132, "x1": 65132, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 129050, "x1": 129050, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 193172, "x1": 193172, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 367247, "x1": 367247, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 380973, "x1": 380973, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 413507, "x1": 413507, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 11208464, "x1": 11208464, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 11213954, "x1": 11213954, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}], "template": {"data": {"bar": [{"error_x": {"color": "rgb(36,36,36)"}, "error_y": {"color": "rgb(36,36,36)"}, "marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "baxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmapgl"}], "histogram": [{"marker": {"line": {"color": "white", "width": 0.6}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "rgb(237,237,237)"}, "line": {"color": "white"}}, "header": {"fill": {"color": "rgb(217,217,217)"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "colorscale": {"diverging": [[0.0, "rgb(103,0,31)"], [0.1, "rgb(178,24,43)"], [0.2, "rgb(214,96,77)"], [0.3, "rgb(244,165,130)"], [0.4, "rgb(253,219,199)"], [0.5, "rgb(247,247,247)"], [0.6, "rgb(209,229,240)"], [0.7, "rgb(146,197,222)"], [0.8, "rgb(67,147,195)"], [0.9, "rgb(33,102,172)"], [1.0, "rgb(5,48,97)"]], "sequential": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "sequentialminus": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]]}, "colorway": ["#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF"], "font": {"color": "rgb(36,36,36)"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "white", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "white", "polar": {"angularaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "radialaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "scene": {"xaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "zaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}, "shapedefaults": {"fillcolor": "black", "line": {"width": 0}, "opacity": 0.3}, "ternary": {"aaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "baxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "caxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}}, "title": {"text": "3L"}, "width": 750, "xaxis": {"anchor": "y", "domain": [0.0, 1.0], "title": {"text": "midpoint"}}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0], "title": {"text": "depth"}}}}, "text/html": ["<div>                            <div id=\"1419f028-03ae-4910-8faf-ff2fa5c6d11a\" class=\"plotly-graph-div\" style=\"height:300px; width:750px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"1419f028-03ae-4910-8faf-ff2fa5c6d11a\")) {                    Plotly.newPlot(                        \"1419f028-03ae-4910-8faf-ff2fa5c6d11a\",                        [{\"hovertemplate\":\"midpoint=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"\",\"marker\":{\"color\":\"lightsalmon\",\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"showlegend\":false,\"x\":[32518,32549,32549,32570,32572,32580,32580,32584,32639,49475,64432,64477,64478,64478,64482,64483,96573,183555,190392,190491,20981717,65068,65098,65099,65100,65100,65101,65102,65102,65103,65104,65105,65107,65108,65109,65109,65114,65120,65123,65125,65128,65129,65129,65130,65100,65101,65101,65102,65103,65105,65106,65106,65109,65120,65121,65121,65122,65125,65126,65129,65129,65130,65130,65102,65104,65113,65130,65130,65131,65102,65130,65130,65131,65131,65104,65107,65131,65131,65132,65132,65131,65132,65133,65109,65132,65133,65133,65134,65133,65135,65115,65135,65135,65136,65136,65136,65116,65138,65139,65139,65140,65148,97036,97037,96992,65142,65145,65150,65151,65151,65151,65150,65152,65153,65154,65155,65156,65156,65158,65159,65159,65159,65160,65160,65161,65162,65162,65163,65163,65164,65164,65165,65165,65166,65166,65167,65168,65170,65170,65171,65172,65173,65173,65174,65175,65176,65176,65177,65178,65178,65179,65179,65180,65181,65181,65182,65182,65183,65183,65184,65184,65185,65185,65186,65186,65187,65187,65188,65162,65163,65163,65164,65165,65166,65166,65167,65168,65171,65175,65177,65178,65179,65180,65181,65182,65183,65184,65185,65185,65186,65186,65187,65187,65188,65188,65163,65164,65165,65179,65181,65184,65185,65187,65187,65164,65165,65165,65166,65166,65167,65167,65168,65170,65171,65172,65174,65174,65176,65178,65178,65180,65181,65182,65182,65183,65184,65186,65186,65187,65187,65188,65188,65189,65166,65167,65170,65172,65174,65178,65180,65181,65182,65186,65187,65188,65188,65190,65169,65181,65183,65184,65184,65187,65188,65189,65189,65190,65168,65170,65183,65188,65169,65169,65174,65176,65181,65182,65182,65185,65185,65186,65189,65189,65190,65191,65179,65181,65182,65184,65185,65186,65186,65190,65174,65175,65177,65183,65184,65185,65190,65191,65192,65172,65176,65177,65179,65183,65186,65187,65189,65190,65190,65191,65178,65191,65191,65182,65191,65174,65193,65176,65179,65194,65194,65190,65196,65189,65194,65184,65187,65193,65195,65195,65196,65183,65191,65192,65194,65197,65190,65193,65196,65196,65197,65199,65186,65187,65188,65190,65192,65193,65194,65198,65198,65195,65192,65194,65200,65201,65192,65195,65195,65196,65198,65198,65199,65199,65200,65200,65201,65195,65200,65201,65196,65197,65202,97028,97074,65194,65196,65198,65201,65202,65203,97074,65201,65196,65199,65199,65200,65201,65204,97029,65196,65198,65199,65199,65200,65201,65202,65202,65203,65203,65204,65205,97030,97072,97076,65197,65199,65202,65203,65204,97030,65202,65203,65204,65204,65205,65206,65206,97077,65200,65201,65204,65201,65201,65202,65203,65204,65204,65205,65205,65206,65207,65207,97078,65205,65207,65202,65203,65203,65204,65205,65205,65206,65206,65207,97078,65203,65204,65204,65205,65205,65206,65206,65207,65207,65208,65208,65209,97033,97079,65205,65205,65206,65206,65207,65207,65208,65208,65209,65209,66653,97034,65205,65206,65207,65207,65208,65210,97034,65207,65207,65208,65208,65207,65208,65208,65209,65210,65210,65211,65208,65209,65209,65210,65210,65211,65211,97036,97082,65209,65210,65210,65211,65211,65212,97036,65210,65211,65211,65212,65212,65244,97037,65211,65212,65212,65213,97037,97083,65212,65213,65213,65245,97038,97084,97091,65213,65214,97038,97084,65214,65256,65215,65218,65220,65225,65226,65227,65227,65228,65228,65229,65230,65230,65231,65232,65232,65233,65234,65235,65236,65238,65239,65239,65240,65241,65244,65247,65250,65251,65251,65253,65254,65255,65255,65256,65256,65257,97039,97085,97090,65228,65229,65229,65230,65230,65231,65232,65234,65237,65257,65257,65258,65258,65261,65236,65239,65238,65238,65239,65240,65240,65266,65239,65240,65241,65241,65242,65244,65246,65257,65265,65267,65267,65268,65269,65240,65241,65241,65242,65243,65243,65244,65245,65246,65251,65264,65266,65267,65267,65268,65241,65264,65267,65242,65243,65243,65244,65244,65245,65246,65247,65248,65249,65251,65252,65252,65254,65255,65257,65258,65258,65261,65262,65264,65265,65265,65266,65266,65267,65267,65268,65269,65270,65270,65246,65246,65248,65258,65269,65244,65245,65254,65263,65269,65270,65245,65248,65249,65262,65266,65270,65270,65246,65247,65248,65249,65254,65266,65267,65268,65269,65270,65271,65249,65267,65271,65271,65272,65268,65249,65251,65261,65267,65268,65269,65269,65270,65270,65271,65272,65251,65252,65253,65256,65259,65264,65269,65270,65272,65272,65273,65274,65273,65253,65272,65255,65257,65257,65263,65264,65267,65269,65270,65270,65272,65273,65274,65274,65272,65271,65273,65274,65275,65260,65265,65274,65276,65263,65261,65262,65265,65268,65272,65274,65275,65276,65277,65278,65278,65279,65280,65275,65277,65279,65280,65280,65281,65276,65280,65281,65281,65282,65278,65282,65284,65284,65275,65282,65285,65277,65285,65286,65283,65286,65278,65287,65289,65288,65289,65284,65285,65286,65286,65290,65290,65290,65291,65289,65291,65291,65292,65289,65289,65290,65290,65291,65291,65292,65293,65290,65292,65292,65291,65292,65292,65293,65291,65292,65292,65293,65293,65294,65294,65292,65293,65294,65293,65294,65294,65294,65295,65296,65295,65296,65297,65296,65297,65297,97080,65297,65298,65298,97081,65299,65300,65331,97081,97081,97104,97126,97127,97127,97131,129222,197666,65300,97082,97128,97082,97113,68143,98570,98962,113964,128863,128864,128865,128865,128866,128866,128867,128868,128869,128871,128872,128873,128875,128879,128883,128887,128889,128894,128899,128903,128904,128907,128908,128909,128909,128910,128939,128865,128866,128866,128867,128867,128872,128873,128877,128883,128887,128890,128894,128896,128897,128900,128901,128907,128909,128909,128910,128910,128867,128868,128909,128910,128867,128873,128874,128911,128868,128870,128871,128873,128887,128891,128891,128901,128903,128910,128911,128911,128912,128870,128870,128871,128874,128875,128881,128888,128891,128897,128902,128903,128910,128911,128912,128912,128870,128912,128912,128913,128913,128914,128913,128914,128880,128886,128896,128916,128917,128918,128917,128918,128918,128921,128918,128914,128922,128924,128924,128928,128928,128921,128922,128932,128933,128934,128934,128935,128939,128939,128940,128941,128942,128940,128943,128944,128945,128944,128946,128947,128948,128950,128950,128951,128952,128952,128952,128953,128952,128953,128954,128954,128954,128955,128955,128959,128962,128956,128957,128957,128958,128958,128959,128959,128960,128960,128961,128961,128962,128962,128963,128964,128965,128967,128968,128985,128985,128957,128958,128958,128959,128959,128960,128960,128961,128961,128963,128985,128958,128959,128960,128960,128961,128963,128964,128959,128960,128960,128961,128961,128962,128964,128964,128960,128961,128961,128962,128962,128963,128961,128962,128962,128963,128963,128965,128962,128963,128963,128964,128965,128966,128963,128964,128964,128965,128966,128966,128967,128971,128972,128964,128965,128965,128966,128966,128967,128968,128982,128985,128989,128965,128966,128966,128967,128967,128968,128969,128969,128972,128972,128979,128987,128990,128966,128967,128967,128968,128969,128969,128970,128972,128972,128973,128980,128982,128984,128986,128987,128990,128967,128968,128968,128971,128968,128969,128973,128984,128987,128969,128970,128970,128971,128971,128972,128972,128973,128973,128974,128975,128976,128977,128980,128981,128981,128982,128983,128984,128984,128985,128986,128988,128989,128989,128990,128990,128992,128970,128971,128971,128972,128972,128973,128973,128974,128974,128975,128975,128976,128977,128978,128979,128980,128981,128981,128982,128982,128984,128985,128986,128986,128987,128987,128988,128988,128989,128990,128992,128971,128972,128972,128974,128974,128975,128976,128978,128982,128985,128985,128993,128972,128973,128974,128974,128975,128975,128976,128976,128977,128979,128983,128991,128993,128973,128974,128974,128975,128975,128976,128976,128977,128977,128982,128983,128983,128985,128986,128986,128987,128989,128990,128991,128994,128974,128975,128975,128976,128976,128977,128977,128978,128978,128981,128981,128983,128984,128984,128985,128986,128987,128988,128989,128991,128993,128975,128976,128976,128977,128977,128978,128986,128987,128987,128989,128991,128992,128993,128976,128977,128978,128978,128979,128983,128983,128984,128984,128985,128986,128987,128988,128989,128992,128995,128977,128978,128978,128979,128979,128985,128988,128990,128991,128978,128979,128979,128980,128981,128983,128984,128985,128986,128986,128987,128988,128988,128989,128990,128990,128991,128992,128992,128993,128993,128996,128979,128980,128980,128982,128982,128984,128985,128986,128988,128989,128980,128981,128981,128983,128984,128985,128986,128986,128987,128987,128988,128989,128990,128991,128991,128992,128992,128993,128993,128994,128997,128981,128982,128984,128985,128986,128987,128987,128989,128990,128990,128991,128993,128993,128994,128996,128997,128998,128982,128983,128984,128985,128986,128987,128987,128988,128988,128989,128990,128990,128992,128992,128994,128995,128997,128998,128984,128988,128990,128991,128993,128990,128991,128985,128992,128994,128989,128990,128991,128992,128993,128997,128990,128993,128988,128989,128990,128991,128992,128993,128990,128994,128995,128994,128991,128992,128993,128995,128995,128997,128993,128995,128996,128997,129003,128993,128994,128996,128996,128997,129004,128995,128995,128996,128996,128997,128997,128998,128998,128999,129001,129001,129004,128995,128997,128997,128998,129000,129004,128996,128997,128997,128998,128999,129000,129001,128998,128998,129004,129006,128998,128999,129004,128999,129000,129000,129001,129001,129002,129002,129003,129003,129004,129004,129005,129005,129006,129006,129007,161072,129000,129001,129001,129002,129002,129003,129003,129004,129004,129005,129005,129006,129007,129007,129016,129001,129002,129002,129003,129005,129008,129002,129003,129003,129004,129004,129005,129005,129006,129006,129007,129007,129008,129008,129003,129004,129004,129005,129005,129006,129007,129007,129008,129009,129004,129005,129005,129006,129007,129007,129008,129009,129009,129005,129006,129007,129007,129008,129008,129009,129010,129006,129007,129007,129008,129008,129009,129010,129010,129007,129008,129008,129009,129009,129010,129010,129011,129008,129009,129011,129011,129009,129010,129010,129011,129011,129012,129020,129010,129011,129011,129012,129012,129011,129012,129012,129013,129012,129013,129013,129013,129014,129014,161080,129015,129016,129016,129017,129018,129018,129019,129020,129020,129021,129022,129022,129023,129026,129027,129028,129028,129029,129031,129032,129033,129037,129037,129044,129045,129051,129054,129056,129057,129058,129059,129060,129060,129061,132614,161080,161113,229524,229524,248082,271219,129016,129017,129017,129018,129018,129019,129019,129020,129020,129021,129021,129022,129022,129023,129023,129024,129024,129025,129026,129027,129027,129028,129028,129029,129029,129031,129031,129032,129033,129035,129037,129038,129038,129039,129039,129044,129045,129046,129047,129048,129048,129049,129049,129051,129052,129052,129053,129054,129056,129058,129059,129059,129060,129060,129061,129061,161081,129017,129018,129018,129019,129019,129021,129021,129022,129022,129023,129023,129024,129027,129028,129033,129041,129044,129046,129047,129059,129060,129061,129062,161114,129018,129019,129020,129021,129021,129022,129022,129023,129024,129024,129025,129026,129028,129028,129043,129047,129054,129059,129061,129062,129062,161082,129020,129022,129023,129024,129025,129029,129060,129020,129022,129023,129024,129030,129030,129033,129050,129058,129061,129061,129062,129063,129021,129022,129022,129023,129023,129024,129024,129025,129025,129026,129027,129028,129029,129030,129030,129032,129033,129034,129037,129048,129049,129051,129053,129055,129061,129061,129062,129063,129063,129064,161083,129024,129025,129026,129031,129032,129034,129056,129061,129062,129063,129064,161084,129025,129026,129028,129050,129065,129025,129026,129026,129033,161085,129025,129026,129027,129028,129028,129030,129031,129033,129066,161085,129026,129027,129028,129028,129029,129029,129031,129032,129033,129033,129034,129036,129039,129066,161086,229529,129028,129028,129029,129030,129031,129032,129033,129034,129035,129037,129038,129039,129049,129051,129052,129054,129064,129065,129065,129066,129066,129067,161117,129029,129029,129051,129054,129060,129065,129066,129066,129067,129029,129030,129033,129034,129035,129035,129037,129038,129038,129039,129040,129044,129045,129046,129047,129051,129054,129054,129055,129057,129059,129061,129064,129065,129067,129068,161087,129030,129031,129033,129034,129035,129036,129039,129040,129050,129065,129067,129068,129031,129032,129032,129033,129034,129035,129036,129036,129037,129037,129038,129039,129046,129049,129052,129055,129056,129060,129064,129065,129066,129067,129068,129068,129069,161088,161121,129032,129035,129035,129037,129038,129039,129046,129056,129056,129060,129068,129069,248071,129035,129035,129036,129036,129037,129038,129039,129041,129054,129055,129062,129070,129036,129036,129037,129040,129070,129071,129037,129037,129039,129071,129072,129038,129039,129039,129040,129040,129041,129041,129042,129042,129043,129043,129044,129044,129049,129056,129069,129069,129070,129070,129071,129072,161092,129039,129040,129040,129042,129044,129044,129045,129053,129070,129070,129072,129072,129073,129041,129041,129042,129042,129043,129044,129044,129045,129049,129058,129065,129070,129071,129072,129072,129073,161093,129041,129042,129043,129046,129048,129061,129071,129072,129074,129042,129043,129043,129044,129044,129045,129045,129046,129047,129051,129057,129058,129061,129061,129069,129072,129072,129073,129073,129074,129074,161094,161127,248076,129043,129044,129046,129049,129055,129057,129071,129072,129075,129045,129045,129046,129047,129068,129073,129045,129046,129047,129063,129073,129074,129046,129047,129047,129048,129059,129061,129063,129067,129072,129073,129074,129075,129076,161096,129047,129049,129063,129074,129076,129048,129049,129050,129052,129053,129056,129060,129063,129064,129066,129069,129070,129071,129073,129075,129076,129077,129077,129049,129051,129054,129060,129065,129075,129077,129078,161097,129050,129051,129052,129055,129055,129060,129062,129063,129065,129065,129071,129073,129075,129075,129076,129076,129077,129077,129078,129052,129057,129075,129078,161098,129062,129063,129074,129077,129079,129127,129077,129079,129078,129078,129079,129080,129068,129078,129081,129069,129070,129080,129081,129081,129082,129083,161135,129069,129082,129083,161134,129071,129083,129084,129084,129070,129072,129071,129072,129070,129086,129074,129084,129086,129074,129076,129078,129072,129074,129076,129080,129081,129082,129082,129085,129087,129088,129077,129075,129076,129077,129087,129087,129088,129090,129090,129076,129076,129077,129077,129078,129090,129091,129089,129077,129078,129079,129083,129085,129086,129090,129090,129091,129092,129079,129080,129089,129091,129092,129080,129088,129089,129090,129093,129080,129091,129092,129092,129081,129085,129087,129087,129089,129090,129090,129091,129092,129092,129093,129094,129090,129091,129091,129092,129094,129094,129095,129089,129091,129094,129095,129095,129097,129088,129094,129095,129095,129097,129097,129098,129091,129092,129095,129095,129096,129097,129097,129098,129098,129098,129099,129096,129097,129097,129099,129100,129095,129098,129099,129099,129100,129100,129101,129099,129100,129101,129101,129102,129099,129101,129102,129100,129102,129100,129101,129101,129102,129103,129103,129101,129102,129102,129103,129104,248106,129102,129103,129103,129104,129104,129103,129104,129104,129105,129104,129105,129105,129105,129106,129106,129107,129108,129149,129155,132571,132583,132589,132591,132595,132660,135404,135802,161092,161126,161126,161157,161159,161176,161222,229569,229570,248109,248128,254946,21046271,161127,161093,161127,132618,132643,132643,136075,136065,136075,136093,136095,136083,136110,136159,164615,164618,164630,164641,136224,164690,164723,251673,141724,167446,142515,167839,193111,193145,193146,193147,193147,193148,193149,193149,193150,193156,193175,193176,193176,193177,193177,193178,193178,193179,193147,193149,193149,193176,193177,193178,193179,193179,193149,193178,193179,193179,193180,193150,193180,193151,193152,193163,193169,193171,193178,193179,193180,193181,193181,193181,193181,193182,193153,193179,193180,193182,193182,193182,193166,193186,193189,193191,193252,261599,193189,193193,193200,193201,193205,193205,193206,193209,193209,193209,193213,193217,193223,193226,193252,193252,193209,193209,193210,193210,193210,193211,193211,193212,193213,193213,193214,193214,193215,193215,193216,193217,193218,193219,193220,193222,193223,193223,193225,193225,193226,193227,193228,193228,193229,193229,193230,193230,193231,193231,193232,193232,193233,193233,193234,193234,193235,193236,193237,193237,193238,193239,193242,193244,193244,193245,193245,193246,193251,193252,193252,193213,193214,193214,193216,193217,193220,193223,193227,193229,193229,193231,193235,193239,193239,193244,193246,193253,193215,193228,193229,193239,193240,193247,193230,193245,193217,193218,193225,193227,193229,193230,193231,193233,193236,193242,193255,193219,193231,193235,193238,193240,193238,193227,193231,193232,193241,193242,193233,193257,193235,193237,193238,193238,193235,193260,193263,193237,193239,193241,193236,193239,193244,193263,193240,193249,193250,193250,193241,193249,193250,193241,193248,193243,193243,193245,193246,193247,193248,193249,193249,193250,193250,193251,193252,193253,193254,193254,193255,193258,193261,193267,193244,193268,193244,193253,193245,193246,193246,193247,193247,193248,193248,193249,193249,193250,193250,193251,193251,193252,193252,193253,193253,193254,193255,193255,193256,193256,193257,193258,193258,193259,193260,193260,193262,193263,193263,193268,193269,193271,193248,193255,193269,193248,193252,193254,193255,193270,193292,193249,193251,193270,193249,193253,193255,193257,193271,193250,193251,193252,193253,193253,193254,193255,193256,193256,193258,193260,193261,193263,193271,193253,193254,193263,193271,193272,261476,193254,193256,193257,193258,193259,193266,193272,193275,193265,193273,193255,193256,193273,193255,193256,193256,193257,193258,193259,193260,193265,193267,193274,193276,193277,193256,193257,193258,193259,193259,193260,193265,193266,193267,193268,193274,193277,193296,193257,193258,193259,193260,193261,193261,193266,193268,193268,193274,193275,193277,193259,193260,193260,193261,193262,193262,193265,193268,193269,193273,193274,193275,193275,193278,261646,280184,193260,193262,193269,193276,193261,193262,193263,193263,193267,193270,193273,193276,193276,193279,193261,193262,193267,193262,193263,193264,193264,193267,193268,193268,193269,193269,193271,193274,193277,193277,193280,193300,261646,193264,193265,193265,193267,193269,193271,193271,193277,193277,193278,193300,261647,193265,193266,193266,193268,193270,193271,193272,193278,193278,193279,193281,261649,193266,193267,193268,193269,193270,193271,193272,193273,193276,193279,193279,193282,193270,193271,193272,193273,193273,193279,193280,193270,193272,193274,193279,193280,193271,193281,193281,193275,193282,193273,193282,193285,193274,193276,193274,193275,193275,193276,193283,261652,193276,193277,193283,193284,193286,233749,193276,193278,193281,193284,193286,193277,193278,193278,193284,193285,193279,193285,193285,193279,193286,193280,193282,193282,193286,193286,193308,287131,193284,193286,193287,193287,193288,193289,193289,193290,193291,193291,193292,193294,193292,193293,193294,193295,193295,193296,193297,193298,193298,193299,193301,193301,193302,193303,193303,193304,193309,193310,193310,193312,193313,193314,193314,193315,193315,193321,193321,193322,193322,193323,193323,193324,193324,193325,193325,193326,261661,261662,261662,261663,280202,193294,193296,193296,193297,193298,193299,193300,193302,193304,193307,193309,193311,193312,193316,193317,193319,193321,193322,193323,193324,193324,193325,193325,193326,193326,193296,193298,193313,193324,193324,193325,193297,193298,193299,193300,193301,193304,193305,193318,193324,193324,193325,193326,193327,193327,193328,193328,261666,193299,193324,193326,193327,193328,193328,193329,193321,193325,193326,193328,193329,193328,261667,193311,193331,193324,193331,193332,193313,193316,193332,193331,193328,193331,193333,193325,193328,193330,193334,193335,193337,193339,193338,193340,193339,193342,193340,193341,193343,193334,193344,193343,193344,193345,193335,193336,193344,193347,193337,193346,193348,193339,193347,193348,193348,193343,193346,193349,193349,193348,193349,193348,193348,193350,193352,193353,193351,193354,193351,193352,193354,193352,193353,193354,193354,193355,193352,193354,193355,193353,193354,193354,193355,193355,193356,193354,193355,193356,193356,193355,193356,193356,193357,193356,193357,193357,193357,193358,193358,193359,233794,241861,261534,261692,261693,261694,261694,261695,261695,261696,261696,280235,280254,287072,261693,261695,261695,261696,261696,261697,280235,274234,274241,274399,302142,274564,302303,290381,310216,329712,329721,329877,329882,329883,330044,330028,330029,330030,330029,330031,330030,330031,330031,330032,330046,330047,330047,330048,330049,330049,330050,330051,330031,330032,330032,330043,330043,330044,330044,330045,330046,330046,330047,330047,330048,330048,330049,330049,330050,330050,330051,330051,330053,330032,330033,330041,330045,330046,330047,330047,330048,330048,330049,330049,330050,330050,330051,330051,330052,330054,330033,330034,330034,330035,330036,330036,330037,330038,330039,330039,330040,330040,330041,330041,330043,330045,330045,330046,330046,330047,330047,330048,330048,330049,330049,330050,330050,330051,330051,330052,330052,330053,330054,330034,330035,330037,330038,330038,330039,330039,330041,330042,330042,330043,330046,330047,330048,330048,330049,330049,330050,330050,330051,330051,330052,330052,330053,330043,330044,330049,330055,330059,330051,330050,330042,330052,330042,330050,330046,330051,330052,330053,330044,330046,330053,330047,330048,330048,330054,330057,330055,330053,330054,330055,330058,330048,330054,330055,330055,330056,330056,330055,330055,330051,330056,330057,330059,330057,330058,330057,330058,330059,330058,330058,330060,330062,330059,348583,330057,330057,330061,330063,330060,330061,330062,330064,348584,330060,330061,330060,330063,330061,330062,330062,330063,330063,330064,330064,330066,348586,330062,330063,330063,330064,330065,330066,348586,330063,330064,330064,330065,330065,330066,330066,330067,330071,348586,348587,348606,330064,330065,330065,330066,330066,330067,330067,330068,330068,330070,330073,330074,348587,348587,355424,355458,330065,330066,330066,330067,330067,330068,330068,330069,330070,348587,348588,355459,330066,330067,330067,330068,330068,330069,330069,330070,330072,330074,330074,348588,348608,355463,330067,330068,330068,330069,330070,330070,330071,330073,330073,330074,330074,330075,348589,330068,330069,330069,330070,330071,330071,330073,348589,348648,355426,330069,330070,330070,330071,330071,330072,330072,330073,330074,330075,330076,348590,348609,355427,371781,330070,330071,330071,330072,330073,330073,330075,330076,330076,330077,348590,348610,355427,355526,330071,330072,330072,330076,330076,330077,330077,348591,348610,348610,355428,330072,330073,330073,330076,330077,330077,348591,355428,330073,330074,330074,330076,330077,330078,330078,348592,348611,348613,348641,355429,330074,330075,330075,330076,330077,330078,348592,348612,330075,330077,330078,330079,348592,348593,330076,330079,330079,330080,348593,348643,348645,355430,330078,330079,330080,348594,355431,348621,330080,330080,348595,330081,348595,330082,330082,348596,348650,330082,330084,348596,355433,330084,348596,348597,348616,348597,348598,348598,367110,367111,367112,367112,367113,367113,367114,367119,367120,367121,367122,367125,367129,367130,367130,367133,367143,367186,367130,367130,367131,367121,367131,367131,367115,367131,367132,367132,367132,367126,367131,367132,367133,367133,367138,367139,367130,367131,367132,367132,367140,367140,367144,367173,373992,374056,367132,367141,367141,373993,367142,367143,367145,367148,367148,367149,367149,367150,367173,367150,367151,367151,367152,367152,367153,367153,367154,367154,367155,367155,367156,367156,367157,367157,367158,367158,367159,367159,367160,367161,367161,367162,367162,367164,367165,367166,367166,367167,367167,367168,367168,367169,367169,367170,367170,367171,367171,367172,367172,367173,367173,367174,367174,367175,367175,367176,367177,367177,367179,367179,367180,367180,367181,367181,367182,367182,367183,367183,367184,367184,367186,367186,367187,367187,367188,367193,367194,367198,367203,367204,367204,367206,367151,367152,367152,367153,367153,367154,367155,367155,367156,367157,367158,367159,367160,367162,367163,367163,367168,367171,367171,367172,367173,367176,367177,367180,367181,367181,367184,367187,367206,367153,367153,367156,367158,367160,367173,367177,367153,367169,367177,367154,367156,367157,367159,367161,367164,367168,367171,367171,367173,367175,367177,367179,367179,367181,367184,367185,367200,367205,367155,367156,367156,367157,367157,367158,367159,367159,367161,367162,367169,367170,367171,367172,367172,367174,367174,367175,367178,367178,367179,367180,367183,367184,367184,367206,367206,367208,13787706,367162,367164,367178,367158,367177,367179,367159,367163,367169,367171,367175,367175,367181,367181,367159,367163,367164,367167,367176,367179,367180,367182,367162,367163,367165,367167,367174,367174,367175,367178,367182,367183,367184,367186,367187,367189,367192,367162,367167,367168,367174,367174,367176,367181,367178,367183,367185,367163,367166,367172,367178,367183,367184,367164,367165,367166,367168,367169,367175,367176,367179,367179,367180,367182,367183,367184,367184,367186,367188,367167,367172,367174,367175,367183,367185,367177,367187,367191,367177,367179,367180,367181,367189,367171,367175,367176,367179,367181,367186,367189,367174,367177,367179,367179,367181,367185,367187,367191,367172,367177,367179,367181,367183,367189,367192,367177,367191,367174,367179,367190,367191,367193,367197,367181,367182,367185,367188,367189,367192,367179,367179,367181,367184,367185,367185,367186,367188,367190,367196,367218,367178,367184,367180,367183,367184,367187,367190,367199,367191,367195,367184,367189,367191,367196,367184,367185,367186,367188,367189,367193,367220,373984,367190,367192,367193,367194,367195,367185,367186,367188,367190,367191,367193,367193,367198,367200,367187,367187,367188,367191,367195,367195,367187,367190,367192,367194,367194,367195,367195,367196,367198,367199,367200,367201,367224,367189,367190,367190,367191,367192,367194,367195,367198,367198,367200,367200,367201,367201,367204,367205,367225,367189,367190,367192,367192,367193,367193,367195,367196,367197,367199,367200,367202,367205,367225,367190,367193,367195,367197,367197,367202,367203,367218,367226,367192,367193,367196,367196,367197,367201,367201,367206,367226,367195,367196,367198,367198,367200,367201,367194,367194,367195,367196,367197,367198,367199,367201,367202,367203,367204,367205,367227,367195,367195,367196,367197,367199,367201,367201,367228,367195,367196,367196,367198,367199,367201,367202,367203,367209,367219,367196,367197,367197,367198,367199,367200,367200,367202,367204,367204,367205,367205,367206,367207,367210,367229,367198,367199,367200,367201,367203,367207,367208,367209,367211,373991,367198,367199,367200,367201,367202,367206,367209,367211,367222,367227,367200,367203,367206,367207,367208,367204,367207,367201,367202,367203,367203,367204,367204,367205,367205,367206,367206,367207,367208,367208,367209,367209,367210,367212,367212,367213,367229,367231,367231,367203,367203,367205,367205,367206,367206,367207,367207,367208,367208,367209,367211,367203,367232,367204,367205,367206,367206,367207,367207,367208,367208,367209,367209,367210,367210,367211,367213,367230,367233,373994,367205,367206,367207,367207,367208,367208,367209,367209,367210,367212,367216,367219,367229,367231,367233,367207,367207,367208,367208,367209,367210,367210,367207,367208,367209,367209,367210,367211,367211,367213,367214,367215,367226,367232,367235,367209,367210,367210,367211,367211,367212,367212,367213,367214,367215,367217,367217,367219,367223,367228,367230,367232,367233,367235,367210,367211,367211,367212,367213,367214,367215,367216,367216,367226,367234,367236,367211,367212,367212,367213,367213,367214,367214,367215,367215,367216,367216,367217,367217,367218,367218,367219,367223,367227,367229,367232,367234,367234,367236,367236,367237,367212,367213,367213,367214,367214,367215,367216,367216,367217,367217,367219,367220,367223,367224,367227,367229,367233,367233,367235,367237,367213,367214,367214,367215,367215,367216,367217,367217,367218,367219,367221,367225,367230,367235,367237,367214,367215,367215,367216,367217,367217,367218,367218,367219,367220,367221,367221,367223,367225,367228,367230,367234,367234,367235,367236,367238,367215,367216,367216,367217,367217,367218,367218,367219,367219,367220,367221,367221,367224,367225,367226,367227,367228,367228,367229,367229,367231,367231,367234,367234,367235,367236,367236,367238,367216,367217,367217,367218,367218,367219,367220,367221,367221,367222,367224,367227,367227,367231,367235,367236,367238,367239,367217,367218,367218,367219,367220,367221,367221,367222,367222,367223,367226,367229,367232,367232,367234,367235,367237,367237,367239,367219,367220,367222,367223,367226,367228,367231,367232,367238,367240,367219,367220,367220,367221,367222,367225,367227,367229,367233,367237,367238,367240,367220,367221,367221,367222,367223,367224,367228,367229,367230,367231,367232,367235,367236,367237,367237,367238,367239,367240,367241,367222,367223,367223,367224,367224,367227,367228,367232,367234,367237,367238,367239,367239,367241,367223,367224,367225,367227,367229,367230,367231,367233,367234,367239,367240,367241,367242,367224,367224,367225,367226,367228,367230,367231,367232,367235,367238,367238,367240,367240,367242,367242,367230,367241,367243,367227,367229,367230,367231,367232,367233,367234,367236,367239,367239,367240,367241,367243,367243,367226,367227,367235,367239,367240,367242,367243,367244,367230,367231,367234,367235,367236,367240,367242,367244,367228,367231,367240,367243,367244,367245,367229,367230,367232,367232,367233,367236,367242,367243,367243,367243,367246,367244,367237,367244,367247,367236,367245,367235,367235,367236,367240,367241,367245,367248,367235,367236,367237,367239,367241,367248,367238,367239,367240,367241,367248,367249,367238,367238,367239,367240,367242,367244,367246,367247,367247,367249,374045,367241,367242,367250,367243,367246,367248,367250,367242,367249,367251,367242,367249,367249,367251,367242,367243,367244,367247,367249,367252,367243,367252,367245,367246,367247,367249,367249,367250,367251,367252,367253,367251,367247,367248,367250,367250,367251,367252,367252,367253,367254,367254,367252,367254,367255,367253,367255,367252,367254,367256,367257,367253,367254,367255,367255,367257,367254,367255,367256,367258,367255,367256,367256,367258,367258,367256,367257,367257,367259,367257,367258,367259,367259,367259,367260,374055,374076,374120,367260,367261,367261,367262,367263,367263,367264,367264,367265,367265,367266,367266,367267,367268,367269,367270,367270,367271,367271,367273,367273,367274,367274,367275,367276,367278,367278,367279,367279,367280,367280,367281,367281,374023,374057,374069,374122,367263,367264,367265,367265,367266,367266,367267,367267,367268,367269,367270,367270,367271,367273,367275,367276,367277,367278,367279,367279,367280,367280,367281,367281,367282,374024,374058,367272,367276,367281,367282,367282,367265,367266,367267,367269,367268,367283,367274,367282,367283,367284,367274,367278,367279,367282,367284,367284,367283,367284,367285,367278,367283,367283,367284,367285,367276,367284,367286,367285,367287,367276,367281,367286,367287,367288,367288,367288,367289,367285,367286,367290,367283,367289,367290,367285,367288,367289,367291,367290,367292,367289,367292,367288,367291,367293,367294,367291,367294,367295,367295,367296,367292,367296,367294,367297,367294,367295,367296,367297,367297,367296,367297,367297,367298,367297,367298,367298,367297,367298,367299,367298,367299,367299,367299,367300,367300,374042,367301,374042,374043,374077,374083,374084,374141,390362,1474058,2457029,3282791,5790560,374043,380784,380785,380786,380787,380787,380788,380790,380806,380811,380812,380816,380817,380817,380818,380818,380819,380822,380842,380786,380787,380788,380790,380819,380819,380788,380789,380791,380819,380820,380791,380820,380821,380790,380792,380821,380821,380795,380808,380793,380822,380795,380797,380809,380811,380816,380821,380822,380823,380823,380824,380824,380824,380825,380826,380837,380839,380840,380840,380845,380846,380849,380850,380850,380850,380851,380851,380851,380852,380852,380894,380853,380854,380854,380855,380855,380856,380856,380857,380857,380858,380858,380859,380859,380861,380862,380863,380864,380864,380866,380868,380868,380869,380869,380870,380870,380871,380872,380872,380873,380873,380874,380874,380875,380875,380876,380876,380877,380881,380887,380892,380894,380894,380854,380855,380855,380856,380856,380857,380858,380859,380860,380863,380864,380865,380867,380869,380869,380870,380870,380871,380873,380873,380874,380875,380877,380877,380895,380856,380856,380860,380866,380867,380870,380870,380871,380871,380873,380857,380864,380870,380871,380871,380872,380873,380874,380876,380857,380859,380859,380862,380868,380870,380870,380871,380871,380878,380883,380889,380896,380858,380859,380860,380860,380861,380861,380864,380866,380867,380869,380870,380871,380871,380872,380872,380873,380874,380876,380877,380879,380879,380883,380864,380867,380868,380871,380872,380872,380873,380873,380875,380876,380879,380884,380872,380873,380874,380876,380862,380863,380864,380867,380868,380868,380870,380872,380872,380873,380873,380874,380874,380878,380878,380885,380863,380865,380869,380874,380874,380875,380874,380874,380875,380878,380886,380874,380874,380876,380897,380868,380869,380871,380874,380875,380876,380877,380880,380882,380873,380875,380876,380877,380883,380898,380876,380888,380876,380872,380876,380877,380878,380878,380879,380873,380878,380879,380874,380878,380879,380880,380886,380879,380879,380887,380876,380879,380880,380880,380881,380883,380884,380885,380878,380879,380880,380881,380881,380882,380883,380886,380901,380903,380906,380882,380893,380882,380881,380882,380882,380883,380888,380883,380884,380884,380885,380886,380888,380889,380889,380891,380905,380907,380909,380884,380885,380885,380886,380886,380887,380888,380890,380891,380892,380896,380897,380898,380908,380885,380886,380886,380887,380887,380888,380888,380889,380889,380890,380892,380893,380897,380897,380898,380900,380906,380910,380910,380886,380887,380887,380888,380888,380889,380889,380890,380890,380891,380891,380892,380893,380893,380896,380897,380898,380899,380900,380902,380903,380904,380910,380911,380887,380889,380889,380890,380890,380891,380891,380892,380893,380894,380894,380895,380898,380904,380909,380911,380888,380889,380889,380890,380890,380891,380891,380892,380893,380893,380894,380894,380895,380897,380898,380898,380899,380900,380900,380901,380903,380904,380909,380912,380889,380890,380891,380892,380892,380890,380891,380891,380892,380895,380895,380899,380906,380913,380891,380892,380893,380893,380894,380894,380896,380896,380897,380899,380900,380900,380903,380904,380911,380913,380892,380893,380893,380894,380894,380895,380896,380896,380897,380900,380901,380903,380904,380907,380911,380912,380913,380914,380893,380894,380894,380895,380895,380896,380896,380897,380897,380898,380901,380905,380906,380906,380907,380908,380912,380913,380914,380894,380895,380895,380896,380897,380897,380912,380915,380895,380896,380896,380897,380898,380898,380899,380902,380902,380903,380904,380906,380907,380908,380913,380915,380896,380897,380897,380898,380898,380899,380900,380902,380903,380904,380905,380906,380907,380907,380910,380913,380914,380915,380916,380897,380898,380899,380899,380903,380916,380916,380898,380899,380899,380900,380903,380917,380899,380900,380902,380902,380904,380904,380908,380917,380900,380901,380902,380903,380904,380905,380905,380906,380908,380909,380909,380910,380910,380911,380912,380915,380917,380917,380918,380901,380902,380902,380903,380903,380905,380905,380906,380906,380907,380908,380908,380909,380914,380916,380918,380902,380905,380906,380907,380908,380911,380913,380916,380919,380906,380906,380912,380919,380919,380906,380907,380916,380907,380912,380921,380908,380915,380909,380910,380910,380911,380911,380912,380913,380914,380915,380915,380916,380916,380917,380917,380919,380920,380920,380921,380921,380922,380922,380910,380911,380912,380912,380913,380915,380915,380916,380917,380917,380918,380918,380919,380920,380921,380921,380922,380923,380946,380911,380913,380914,380916,380917,380918,380920,380921,380921,380923,380923,380946,380916,380919,380920,380921,380923,380924,380915,380922,380924,380917,380922,380925,380915,380916,380918,380918,380920,380921,380921,380925,380925,380917,380918,380923,380926,380924,380919,380920,380921,380922,380923,380924,380926,380927,380920,380920,380921,380922,380927,380927,380920,380925,380928,380921,380922,380923,380926,380928,380928,380922,380923,380923,380926,380928,380929,380923,380927,380929,380929,380927,380930,380926,380928,380929,380930,380930,380928,380931,380928,380929,380930,380931,380929,380932,380930,380931,380932,380931,380932,380932,380933,380933,380932,380933,380933,380934,380934,380934,397213,380934,380935,380958,380935,380936,380937,380937,380938,380938,380939,380940,380940,380941,380943,380943,380944,380948,380950,380955,380957,380959,380966,380968,380969,380969,380970,397179,397215,397217,397229,1701596,380937,380938,380939,380939,380940,380941,380941,380942,380942,380943,380947,380947,380951,380952,380952,380953,380955,380955,380959,380963,380963,380964,380965,380965,380966,380966,380967,380967,380968,380968,380969,380969,380970,380970,380941,380942,380943,380948,380966,380970,380971,380940,380971,380971,380972,380944,380972,380973,380946,380971,380972,380973,380974,380946,380958,380974,380974,380974,380975,380950,380973,380975,380976,380954,380976,380977,380977,380978,380978,380975,380981,380973,380982,380983,380985,380981,380982,380986,380987,380988,380988,380984,380988,380989,380991,380982,380983,380993,380992,380993,380994,380996,380996,380997,380997,380998,380995,380997,380999,380999,381000,381000,381000,381000,381001,380999,381001,381001,381002,381002,381003,381003,381004,381005,397202,397213,397213,397248,397249,397251,397254,397262,397264,397266,397269,397313,397313,655838,655839,655854,655855,985356,1480912,1480913,1701628,1701629,1701629,1701630,2114959,2578292,2578302,2756889,3289643,3887177,5679409,5679410,5794652,5797411,21172219,381005,397214,397249,397214,397250,413412,413422,413423,413424,413424,413425,413427,413428,413430,413433,413434,413436,413444,413445,413446,413454,413455,413456,413457,413457,413458,413458,413425,413425,413429,413434,413458,413458,413459,413449,413459,413460,413460,413460,413459,413462,413462,413452,413462,413463,413464,413465,413468,413469,413470,413471,413479,413480,413481,413482,413483,413489,413491,413492,413492,413492,413493,413493,413494,413495,413495,413496,413496,413497,413497,413498,413498,413499,413499,413500,413500,413501,413501,413502,413503,413503,413504,413504,413505,413505,413506,413506,413507,413508,413508,413509,413509,413510,413510,413511,413511,413513,413515,413515,413516,413517,413517,413520,413521,413523,413524,413527,413528,413532,413532,413534,413561,413495,413496,413496,413497,413497,413499,413499,413500,413500,413501,413501,413502,413502,413504,413506,413507,413507,413508,413509,413509,413510,413510,413511,413534,413534,413498,413502,413508,413509,413509,413510,413510,413511,413500,413501,413510,413511,413535,413498,413506,413509,413512,413499,413502,413503,413504,413505,413510,413511,413511,413512,413512,413513,413516,413527,413502,413502,413504,413506,413507,413510,413511,413511,413512,413512,413514,413515,413518,413512,413538,413507,413507,413511,413512,413513,413515,413504,413508,413513,413514,413505,413508,413509,413510,413512,413513,413514,413514,413516,413523,413507,413508,413514,413512,413514,413515,413540,413508,413511,413515,413515,413517,413518,413519,413510,413512,413514,413514,413515,413516,413516,413517,413517,413518,413518,413541,413514,413515,413512,413512,413514,413514,413515,413517,413518,413520,413531,413541,413543,413518,413518,413520,413543,413518,413518,413519,413520,413520,413527,413542,413515,413519,413539,413519,413520,413528,413519,413520,413520,413521,413522,413531,413520,413521,413546,413519,413520,413521,413521,413522,413523,413539,413521,413521,413522,413522,413523,413524,413525,413530,413533,413534,413534,413547,413522,413523,413523,413524,413524,413525,413527,413531,413531,413534,413534,413535,413535,413537,413548,413523,413524,413524,413525,413529,413531,413532,413533,413533,413534,413535,413535,413536,413541,413546,413548,413548,413524,413525,413525,413526,413527,413527,413528,413530,413530,413531,413531,413532,413532,413533,413534,413535,413535,413536,413536,413538,413538,413539,413545,413546,413547,413549,413525,413526,413527,413527,413529,413530,413531,413531,413532,413533,413534,413535,413536,413538,413542,413548,413549,413526,413527,413527,413529,413529,413530,413531,413531,413532,413533,413533,413534,413535,413536,413536,413537,413537,413538,413544,413546,413546,413548,413550,413527,413528,413531,413536,413537,413538,413550,413528,413529,413529,413530,413530,413531,413531,413532,413532,413533,413533,413534,413534,413535,413535,413536,413537,413537,413538,413538,413539,413540,413540,413541,413542,413542,413543,413543,413544,413545,413547,413547,413548,413549,413551,413551,413529,413533,413533,413535,413535,413536,413537,413533,413535,413552,413534,413535,413539,413546,413546,413552,413535,413536,413536,413540,413543,413533,413534,413535,413536,413537,413539,413541,413553,413535,413537,413537,413539,413540,413540,413554,413537,413540,413542,413555,413536,413537,413538,413538,413539,413539,413540,413541,413542,413544,413555,413538,413539,413539,413541,413541,413542,413546,413553,413554,413555,413555,672105,413539,413539,413540,413540,413542,413543,413545,413556,413539,413540,413542,413540,413541,413541,413543,413543,413544,413544,413545,413546,413546,413547,413548,413552,413554,413555,413557,672106,413541,413542,413542,413543,413544,413544,413545,413546,413547,413550,413551,413557,413559,672124,1571635,413542,413544,413545,413552,413553,413555,413557,413558,413544,413545,413547,413550,413556,413558,413545,413546,413559,413545,413550,413546,413547,413547,413548,413549,413549,413550,413551,413552,413553,413553,413555,413555,413556,413556,413557,413558,413558,413559,413560,413585,413547,413548,413549,413550,413557,413558,413559,413560,413560,413548,413549,413550,413550,413551,413554,413555,413556,413556,413557,413558,413558,413559,413559,413560,413561,413550,413550,413551,413551,413552,413553,413554,413555,413556,413556,413557,413559,413559,413560,413560,413561,413561,413553,413555,413558,413560,413560,413561,413562,413562,413597,413553,413558,413559,413561,413561,413563,413554,413561,413562,413563,413563,413557,413558,413560,413561,413562,413563,413564,413558,413558,413558,413560,413562,413564,413565,413561,413563,413565,413566,413562,413563,413561,413562,413563,413563,413564,413565,413566,413567,413562,413567,413564,413564,413566,413567,413567,413568,413568,413567,413568,413569,672135,413565,413567,413569,413567,413567,413568,413568,413569,413570,413569,413570,413569,413571,413569,413570,413570,413571,413571,672138,413570,413571,413571,413572,672121,413571,413572,413572,413572,413573,413573,413574,413575,413575,413576,413576,413577,413578,413578,413579,413579,413580,413582,413582,413584,413585,413590,413594,413596,413598,413599,413600,413603,413607,413608,413609,413609,619904,672123,672124,672130,672135,672137,672139,672140,672140,672141,672141,999376,1121154,1497197,1497199,2079250,2131244,2856680,3903454,413575,413576,413576,413577,413577,413578,413578,413579,413579,413580,413580,413581,413581,413582,413582,413583,413587,413588,413588,413589,413589,413590,413591,413591,413592,413592,413593,413594,413594,413595,413596,413596,413597,413598,413598,413599,413600,413600,413601,413602,413602,413603,413603,413604,413604,413605,413605,413606,413606,413607,413607,413608,413608,413609,413609,413610,1245706,2131244,413577,413579,413581,413588,413589,413600,413608,413609,413609,413610,413579,672140,1497196,413579,413580,413582,413583,413586,413607,413608,413609,413610,413611,413582,413583,413584,413584,413612,413585,413604,413611,413583,413593,413612,413584,413591,413601,413603,413603,413605,413609,413611,413612,413613,572214,413598,413610,413611,413611,413613,413585,413587,413588,413614,413586,413587,413588,413593,413596,413603,413609,413610,413611,413612,413613,413613,413614,413614,413615,672148,413607,413612,413613,413613,413592,413615,413598,413601,413603,413605,413614,413616,413596,413597,413600,413604,413614,413615,413616,413616,907321,413618,413617,2131266,413609,672151,413616,413620,413621,413622,413603,413602,413614,413622,413623,413620,413621,413623,413618,413621,413624,413612,413618,413619,413622,413623,413624,413625,413612,413616,413625,413626,413621,413627,413625,413627,413627,413628,413626,413628,413628,672143,413628,413629,1001661,413631,413629,413630,413631,413623,413626,413631,413632,413629,413623,413623,413629,413631,413632,413633,413633,413633,413634,413627,413631,413632,413633,413634,413635,413634,413634,413635,413634,413635,413633,413634,413635,672165,413633,413636,413636,413637,413637,413635,413637,413637,413638,672169,413636,413638,413639,413639,413638,413639,413640,413639,413639,413640,413640,413641,413639,413640,413640,413641,413642,413640,413641,413641,413642,413641,413642,413643,413642,413643,413643,413644,672158,413644,413645,413646,426590,426591,426594,450455,514618,545882,559147,566329,566632,566680,569468,572246,572247,572251,602556,605257,612259,619940,642848,672158,672158,672159,672159,672160,672160,672163,672165,672171,672173,672174,672174,672175,672175,672176,672176,672177,672177,672178,673414,829366,830860,873161,873162,873163,899024,899026,907348,919740,988482,988484,988485,999949,1001557,1001676,1025633,1025646,1104983,1104987,1118600,1118603,1118604,1118606,1121189,1121190,1121191,1132693,1148043,1148044,1241454,1497231,1497231,1497232,1497232,1497233,1497233,1497234,1535777,1571687,1571689,1571691,1717949,1717949,1717950,1717951,1717953,1717954,1844780,2036076,2131278,2131279,2131279,2131280,2131287,2131288,2131289,2131290,2131290,2131291,2131291,2131292,2131292,2480197,2480198,2480200,2594615,2594617,2594619,2594620,2773209,2773210,2856727,3266963,3266964,3289746,3305963,3305964,3903497,5455893,5810973,5813732,413646,514619,569384,572246,672159,672175,672176,672176,1118604,1148044,1497233,1717952,3266964,612268,672160,672173,1717953,2131291,2773211,439551,439552,439558,1001443,1038594,1510197,2493161,487278,487281,708992,1158015,615618,615624,773159,673252,773165,678143,804438,963072,704693,817705,817721,719056,719131,719203,824957,719649,983828,719743,982428,725161,827937,725316,725412,725504,828099,730851,730862,730862,730863,730865,730867,730868,730864,730870,730866,730874,730883,830791,830792,830775,830776,770877,830795,830797,830800,1277225,830782,2289915,791484,861103,796904,796979,797055,863881,810914,810917,810912,1317248,1795854,870817,826247,878466,878474,872062,901373,930672,930672,930697,930673,930685,930687,930687,930688,930688,930689,930689,930690,930690,930691,930692,930694,930696,930701,930703,930683,930685,930686,930687,930687,930688,930688,930689,930689,930690,930690,930691,930692,930692,930693,930695,930697,930697,930699,930699,930701,930702,930703,930704,930705,930693,930706,930709,930711,930712,930713,930699,930700,930701,930700,930702,930702,930708,930703,930720,930703,930703,930707,930719,930703,930704,930704,930705,930712,930720,930720,930703,930704,930704,930705,930705,930706,930707,930721,930721,930723,1165877,1377132,1379719,1391223,2738724,930704,930705,930705,930706,930707,930709,930711,930718,930721,930721,930722,1377133,1379720,2389807,2389809,930705,930706,930706,930707,930707,930710,930715,930721,930722,930722,930723,1830221,1976478,2389820,2389820,930706,930707,930707,930708,930708,930710,930711,930712,930713,930722,930722,930723,930723,930724,1165878,1377134,1755763,1830217,1976481,930707,930708,930708,930709,930710,930712,930712,930720,930722,930723,930723,930724,1157557,1165878,1377134,1379718,1976480,2389816,3031741,930708,930709,930710,930710,930711,930714,930718,930719,930723,930723,930724,1087904,1165879,1165880,1379721,1976481,2389823,930709,930710,930713,930721,930723,930724,930724,930725,930726,1165882,930713,930715,930716,930717,930718,930721,930723,930724,930724,930725,930725,1377136,2389812,2389818,930712,930712,930714,930715,930724,930725,930725,930726,1549601,930714,930715,930725,1165884,1377137,2389813,930713,930714,930723,930726,1165881,930715,930716,930718,930726,930726,930721,930728,2389813,930727,930718,930720,930727,930728,1165884,1755769,1976486,930719,930722,930724,930726,1406580,930728,930729,930729,930720,930723,930729,930730,1087903,1379727,1755771,1830228,930729,1500080,1976489,930731,930732,2389832,930732,1247024,1087906,930732,1131704,930734,1379731,930733,930734,1157566,1499996,930735,930731,1379733,930735,930736,930736,930737,1129631,2389823,930736,930737,1379331,1755777,930738,1247030,1377149,1755779,1377149,930738,930739,930739,930740,1087912,1165894,1257958,1284178,1377147,1377150,1406589,1500132,1755778,1755779,1830237,1976495,1976496,1976497,2103452,2389826,2389837,2738749,930739,930740,930740,1087913,1125545,1131709,1131710,1157569,1157571,1157573,1165894,1165895,1257887,1363534,1377150,1377151,1379737,1755779,1755780,1755780,1755781,1755784,1794324,1830237,1976495,1976496,1976496,1976498,1976499,2389826,2389837,2389838,2389840,2738743,2853162,3031757,3525510,930740,1036025,1087913,1157573,1157573,1165894,1165895,1165898,1306921,1377148,1377151,1379734,1379737,1391241,1391243,1755780,1755780,1755781,1830234,1855746,1855829,1976496,1976497,1976499,2389826,2389827,2389837,2389838,2389838,2389839,2389840,2738746,3031756,1125549,1129636,1165896,1165898,1284180,1377151,1455795,1755777,1755780,1755781,1755782,1830235,1830240,1855746,1936455,1976497,1976497,1976498,1976499,2389827,2389828,2389836,2389837,2389840,2738745,930742,1344643,1379738,1125546,1377152,1379739,1755782,1976498,3564512,933209,1378398,1141328,1961049,1245107,1245112,1245114,1245114,1245118,1245120,2133696,1323093,1323094,1534350,1288909,1288911,1520734,1534351,1548442,1288912,1534352,1912981,1534356,1247991,1248067,1248102,1248142,1914472,1316281,3190466,1320365,1320363,1320369,2171315,1571968,1571971,1328548,1328546,1364808,1578651,1332705,1332706,1332707,1366891,1578144,1578147,1701128,1956776,2177492,2590824,2590830,3054160,1384415,1384417,1384417,1384418,1384418,1384418,1384419,1603996,1603998,1392741,1603996,1604007,1606580,1982626,2021169,2203343,2616671,1401050,1401051,1401064,1401064,1401065,1401065,1401053,1401062,1401063,1401065,1401065,1401066,1401066,1401068,1401069,1401067,1401067,1401064,1401068,1401071,1401076,1612318,1482204,1401080,1614907,1401080,1413457,1614907,1990951,1401082,1519349,1519351,1519352,1612321,1614908,1626412,1626413,1641762,1990947,1990948,1990950,1990951,1990951,2029494,2211667,1612322,2211668,1612319,1612322,2005536,1612324,1614911,1425845,1425846,1425898,2637394,1425952,1624762,1563333,1563334,1563336,1563337,1563340,1563343,1693454,1693457,2072085,2292805,1696045,2706134,1585043,1585065,1585088,1991186,1585190,1827362,2083011,2717071,1586264,2717605,1589524,1589594,1589670,1589719,1709232,2085275,2085276,2719336,1637651,1637649,1637652,1637650,1637653,1637653,1637654,1637666,1730621,2743296,1730620,1730623,1733210,1760064,1683165,1782836,1758557,1758646,1758735,1793741,1796337,1796340,1796341,1796342,1809957,1812544,2822644,1824048,1823559,1823584,1823585,1823603,1823563,1823564,1823568,1823580,1823581,1823586,1823587,1823588,1823606,1823588,1823606,1823589,1823589,1823608,1823590,1823596,1823601,1823594,1823615,2836255,1823606,1826167,2302175,2836267,2836268,1823612,2836262,1823613,1823630,1823631,1826171,1826174,1826175,1837672,2202214,2202217,2202217,2202219,2240761,2276671,2276673,2422933,2422935,2422936,2563649,2836262,2836263,2836263,2836264,2836272,2836273,2836274,2836275,2836275,2836276,3185182,3185182,3185183,1823632,1826171,1826174,1826176,1826177,1833568,1837673,1837680,1902232,1946439,2202217,2202217,2276672,2422934,2422935,2422937,2836275,1826180,1826185,1826190,2200368,1826192,1837696,2202235,1827978,2425142,1828732,1828753,1828757,1828758,1828734,1828735,1828737,1828741,1828753,1828754,1828759,1828760,1828760,1828761,1828761,1828779,1828737,1828780,1828762,1828762,1828756,1828763,1828781,1828767,2838853,1828779,1828780,1828798,1840259,2204797,2279251,2425517,5037406,2204800,2204802,1828785,2838849,1828786,1828804,1855614,1903803,1904815,1949025,1998638,2098238,2204801,2204803,2204803,2204804,2204805,2243345,2279259,2279261,2279261,2304769,2425519,2425520,2425521,2425522,2425524,2733067,2786856,2838848,2838849,2838849,2838850,2838850,2838858,2838860,2838860,2838861,2838862,2838863,3077921,3480780,1828796,1828805,1840266,1855615,1949025,1998639,2013447,2204802,2204803,2204803,2204804,2204804,2279258,2304768,2425520,2425521,2475744,2733068,2838850,2838850,2838851,2838859,2838862,3302191,2838849,2838860,1904836,2204822,2204822,2467478,2838867,2838869,3187788,3480799,1843534,2212183,1851764,1851769,1851744,1851770,1851771,1867120,2216307,2216309,2216310,2216310,2254852,2290764,2437025,2850355,2850356,2850365,2850366,1882454,1882457,1882458,1882458,1882459,1882459,2452362,1975998,2231647,1931662,2452365,2865694,2865706,1975869,2231648,2865704,2231648,1978840,2913887,1980909,1980911,1980984,1981060,2280972,2280972,2280973,2380938,2915032,2069329,2069402,2069402,2069477,2069478,2069492,2069532,2069533,2069534,2069535,2069543,2069544,2325183,2325183,2399640,2545899,2959229,2959229,2959240,3308149,3422565,3422566,3601160,2077854,2963392,2168501,2168502,2374668,3008726,2595385,2198121,2389474,2367702,3108314,2397306,2489079,2577101,3213013,2580830,2580817,2580833,2580818,2580834,2580819,2580834,2580834,2580819,2580834,2580834,2580820,2580834,2580820,2580821,2580822,2580835,2580835,2580836,2580821,2580822,2580822,2580835,2580835,2580836,2580836,2580823,2580823,2580835,2580835,2580836,2580836,2580837,2580836,2580837,2580836,2580836,2580837,2580837,2580838,2580837,2580837,2580838,2580843,2580849,3214880,3214894,2580849,2580850,2580850,2619382,3214881,3214893,2580850,2580851,2655009,2655293,2689518,2801552,2801553,2801555,3109099,3214882,3214887,3214892,3214893,2580851,2595418,2619380,2619380,2619383,2655290,2655292,2680886,2801552,2801553,2801554,2801555,2801558,2801559,2999522,3023325,3109100,3214881,3214882,3214883,3214888,3214889,3214891,3214892,3214893,3214893,3214894,3214894,3214895,3214895,3214896,3524153,3563800,3563803,3678218,3678222,3678224,3856813,3940318,4389567,2619376,2619380,2619381,2619381,2655010,2655290,2655291,2655291,2680802,2680886,2790837,2801553,2801553,2801554,2801554,2801556,2801558,2843320,2843539,3109100,3109100,3214881,3214882,3214882,3214883,3214883,3214884,3214887,3214891,3214892,3214893,3214893,3214894,3214894,3214895,3214895,3214896,3214896,3214897,3214898,3563800,3563800,3563801,3563801,3563802,3678219,3678221,3678223,3678225,3856813,3856813,3940318,6894576,2801554,2609997,2609998,3229463,2695381,2657918,2657922,2657923,2657923,2657924,2657924,2657924,2657911,2657925,2657925,2657926,2657927,2657928,2840095,3253439,2881737,2882037,3253425,2693836,2693838,2719345,2800050,2840098,2840098,2840100,2840100,3147645,3253426,3253426,3253437,3253438,3253438,3253439,3716765,2729178,2729179,2729464,2729462,2729743,2729744,2729744,2729745,2729745,2729743,2729746,2729746,2729748,2729748,2729749,2729747,2729751,2729751,2729752,2729753,2729753,2729751,2876004,2755341,2876005,3289348,2876007,3289337,2876007,2876008,2876010,3289336,3289337,3289337,3289347,5061553,2755257,3289337,3289338,2876010,3289338,2729830,2876010,3289339,3289348,2876009,2876010,2876012,3289339,3289340,3289340,2876011,2729915,3183643,2780759,2780759,2780760,2780761,2780762,2780762,2780763,2780847,2780848,2780848,2780848,2780849,2780849,2780849,2780850,2780851,2780934,2780935,2780936,2780938,2780935,2780936,2780937,2780938,2780937,2780937,2780938,2780939,3314929,3314931,3314929,3956861,3314930,2901602,3663851,2901602,2901603,3314932,3314932,3314943,3314944,3106407,2798198,2910232,2942173,2942181,3395562,3395552,3000834,3011550,3022253,3022253,3022254,3022254,3022267,3022268,3022270,3022253,3022254,3022254,3022255,3022255,3022268,3022268,3022269,3022270,3022254,3022255,3022255,3022256,3022257,3022258,3022268,3022269,3022270,3022271,3022272,3022272,3022273,3022255,3022256,3022257,3022269,3022270,3022270,3022256,3022258,3022258,3022271,3022271,3022272,3022272,3022273,3022258,3022258,3022259,3022259,3022270,3022271,3022271,3022272,3022272,3022273,3022273,3022274,3022275,3022273,3022273,3022272,3022272,3022274,3022274,3022275,3022275,3022273,3022275,3022275,3022276,3022273,3022274,3022275,3022276,3022276,3022275,3022277,3022276,3022277,3022278,3022278,3022279,3022280,3022283,3022284,3435598,3435610,3022285,3022285,3022286,3435599,3435610,3022286,3022287,3022290,3435599,3435599,3435600,3435611,3022287,3022287,3022288,3435598,3435599,3435600,3022287,3022288,3435599,3435600,3435612,3435612,3022288,3022289,3022289,3435600,3435601,3435611,3435612,3435613,3022289,3022290,3022290,3359413,3435600,3435601,3435601,3435602,3435603,3435610,3435611,3435611,3435612,3435612,3435613,3435613,3435614,3581578,3784519,3784520,3784520,3784521,3898939,3022290,3022291,3227074,3435601,3435601,3435602,3435602,3435609,3435612,3435612,3435614,3784518,3784519,3784520,3898935,3898937,4077532,3435601,3435602,3435602,3435603,3435605,3435608,3435612,3435613,3435613,3435614,3435615,3898942,3072497,3383609,3435602,3435603,3435604,3435611,3435613,3435616,3784519,3784522,4161038,3435610,3435617,4077534,3435605,3105604,3105909,3105864,3106042,3106139,3106140,3106214,3106221,3106255,3106290,3477613,3477606,3940942,4003069,4119536,3122769,3122770,3122845,3122846,3122919,3485949,3485950,3275957,3276017,3276093,3276167,3276216,3276224,3911507,4025931,3303696,3576309,3418204,3633576,3431870,3431871,3989315,4282329,3465811,3657375,3637360,3637361,3637361,3743143,3743144,3743154,3743156,4385074,3658521,4395654,3696549,4121657,3744939,3744940,3744942,4260273,3796934,3796935,3848912,3848912,3848912,3848913,3848921,3848923,3848932,3848933,3848913,3848923,3848925,3848929,3848914,3848915,3848920,3848924,3848924,3848925,3848926,3848926,3848927,3848927,3848929,3848929,3848930,3848931,3848931,3848932,3848915,3848916,3848917,3848918,3848918,3848920,3848920,3848921,3848921,3848922,3848922,3848923,3848923,3848924,3848924,3848925,3848925,3848926,3848926,3848927,3848927,3848928,3848929,3848929,3848930,3848930,3848931,3848931,3848932,3848934,3848934,3848935,3848936,3848940,3848916,3848921,3848925,3848926,3848927,3848917,3848918,3848919,3848920,3848921,3848922,3848923,3848923,3848924,3848925,3848925,3848926,3848926,3848927,3848927,3848928,3848928,3848929,3848930,3848930,3848931,3848931,3848932,3848936,3848924,3848924,3848927,3848930,3848929,3848927,3848932,3848945,3848931,3848929,3848931,3848946,3848947,3848927,3848930,3848931,3848938,3848927,3848930,3848932,3848933,3848944,3848948,3848930,3848932,3848935,3848936,3848947,3848948,3848929,3848933,3848936,3848930,3848931,3848932,3848932,3848933,3848934,3848934,3848935,3848936,3848939,3848933,3848933,3848934,3848935,3848935,3848950,3848950,3848951,3848932,3848933,3848933,3848934,3848935,3848939,3848951,3848933,3848934,3848934,3848935,3848935,3848936,3848937,3848938,3848938,3848952,3848934,3848935,3848935,3848936,3848936,3848937,3848939,3848939,3848950,3848951,3848952,3848952,3848935,3848936,3848936,3848937,3848937,3848939,3848939,3848940,3848940,3848942,3848943,3848952,3848952,3848953,3848953,3848936,3848937,3848937,3848938,3848938,3848939,3848940,3848941,3848942,3848944,3848952,3848953,3848953,3848955,3848937,3848938,3848938,3848939,3848940,3848941,3848941,3848942,3848943,3848944,3848950,3848952,3848953,3848953,3848954,3848954,3848938,3848939,3848939,3848940,3848940,3848941,3848941,3848942,3848942,3848943,3848943,3848951,3848952,3848953,3848953,3848954,3848954,3848956,3848939,3848940,3848940,3848941,3848941,3848942,3848942,3848943,3848945,3848947,3848949,3848953,3848954,3848954,3848955,3848955,3848940,3848941,3848941,3848942,3848942,3848943,3848943,3848944,3848944,3848945,3848946,3848947,3848953,3848954,3848955,3848955,3848942,3848942,3848943,3848943,3848944,3848944,3848945,3848946,3848947,3848954,3848955,3848955,3848956,3848957,3848943,3848945,3848947,3848955,3848955,3848956,3848956,3848957,3848957,3848958,3848943,3848944,3848944,3848945,3848945,3848955,3848956,3848956,3848959,3848944,3848945,3848945,3848946,3848946,3848947,3848956,3848957,4197847,3848945,3848946,3848946,3848947,3848947,3848948,3848949,3848953,3848956,3848957,4197847,4197847,4197848,4312263,4351372,5621139,3848946,3848947,3848947,3848948,3848948,3848949,3848950,3848957,3848958,3848960,4197847,3848947,3848948,3848948,3848949,3848950,3848950,3848951,3848957,3848960,4197847,4197848,4197852,3848948,3848949,3848949,3848950,3848951,3848951,3848952,3848954,3848959,3848959,4197849,3848949,3848950,3848950,3848951,3848951,3848952,3848953,3848954,3848959,4197849,4197850,4312265,3848950,3848951,3848951,3848952,3848952,3848953,3848959,3848960,3848960,3848951,3848952,3848952,3848953,3848953,3848954,3848954,3848960,3848960,3848961,4197852,4574366,4574370,3848952,3848953,3848953,3848954,3848954,3848955,3848955,3848956,3848957,3848960,3848961,3848961,4197852,4312271,3848953,3848954,3848954,3848955,3848957,3848961,4197851,4197854,4312273,3848954,3848955,3848955,3848956,3848956,3848957,3848957,3848961,3848962,3848963,4197853,4197854,4574387,3848955,3848956,3848956,3848957,3848957,3848958,3848958,3848961,3848962,3848962,3890638,4197852,4312270,3848956,3848957,3848957,3848958,3848959,3848959,3848960,3848962,3848963,4059403,4312277,4574370,3848957,3848958,3848958,3848959,3848959,3848962,3848963,3848963,4197855,3848958,3848959,3848959,3848960,3848960,3848961,3848961,3848962,3848963,3848963,3848964,3848964,4197857,3848959,3848960,3848960,3848961,3848962,3848964,3848964,3848965,4490867,3848960,3848961,3848961,3848962,3848962,3848964,3848964,4040822,4490867,3848961,3848962,3848962,3848963,3848964,3848965,3848965,3848966,4197857,4312271,4312271,3848962,3848963,3848963,3848964,3848965,3848965,3848966,3848966,4312279,3848963,3848964,3848964,3848966,3848966,4312279,4490869,3848964,3848965,3848965,3848966,3848966,3848967,3848967,3848968,4312276,4574382,3848965,3848966,3848967,3848967,3848968,3848968,4197858,4312273,4312277,4351383,4490869,3848967,3848968,3848968,3848968,3848968,4087959,6810309,3848968,3848969,4197859,4197863,4312274,4312280,3848969,3848970,3848970,4197857,4197858,4197859,4197859,4197860,4197861,4312277,4312278,4312280,4312281,4312282,4312286,4312286,4490871,4490872,4574377,3848970,3848971,3848971,3848972,3911480,3937154,3943857,4022235,4061914,4061916,4087961,4088006,4088013,4138058,4197854,4197855,4197857,4197857,4197858,4197859,4197859,4197860,4197860,4197861,4197861,4197862,4197862,4197863,4197863,4197864,4240776,4272276,4312274,4312275,4312275,4312276,4312276,4312278,4312278,4312279,4312280,4312281,4312281,4312282,4312282,4312283,4312285,4490870,4490870,4490872,4490872,4574376,4574377,4574377,4574379,4574385,4574387,7173556,3848971,3848972,3848972,3890642,4087961,4087992,4088013,4131378,4197855,4197856,4197857,4197857,4197858,4197859,4197860,4197860,4197861,4197861,4197862,4197862,4197863,4197863,4197865,4312275,4312276,4312276,4312277,4312278,4312278,4312279,4312279,4312280,4312281,4312282,4312282,4312283,4312284,4312285,4490873,4574376,4574378,4574388,5621152,3848972,4087962,4197858,4197858,4197859,4197860,4197861,4197861,4197862,4197863,4312275,4312279,4312281,4312283,4490873,4490873,3848973,4197859,4197859,4197860,4197861,4197861,4197862,4197863,4312280,4312283,4312289,4197860,4197861,4197865,4312284,4197861,4197864,4197866,4490875,3932327,3932333,4353960,4239547,3974000,4260380,4025351,4286053,4038761,4407187,4140884,4140952,4141014,4458309,4195526,4371150,4232699,4504147,4269865,4701328,4274874,4274875,4525234,4410820,4327014,4327045,4327060,4327077,4327082,4327086,4327087,4327108,4327162,4327113,4327162,4415690,4436925,4551346,4436938,4436940,4436987,4436988,4551407,4551410,4730001,4413791,4413847,4413917,4480348,4427164,4486967,4467464,4467505,4467547,4621573,4504297,4525531,4546745,4546744,4546759,4546747,4546761,4546746,4546747,4546747,4546761,4546747,4546748,4546750,4546762,4546749,4546750,4546762,4546763,4546747,4546748,4546748,4546749,4546749,4546751,4546762,4546762,4546763,4546763,4546764,4546748,4546749,4546749,4546750,4546751,4546763,4546763,4546767,4546749,4546750,4546750,4546751,4546751,4546752,4546763,4546764,4546764,4546765,4546766,4546750,4546751,4546751,4546754,4546765,4546765,4546766,4546767,4546751,4546752,4546752,4546753,4546753,4546754,4546754,4546764,4546764,4546765,4546765,4546766,4546766,4546767,4546767,4546752,4546753,4546753,4546754,4546765,4546766,4546767,4546767,4546768,4546768,4546753,4546754,4546754,4546755,4546755,4546765,4546766,4546766,4546767,4546767,4546768,4546768,4546769,4546769,4546770,4546754,4546755,4546756,4546766,4546767,4546767,4546768,4546769,4546755,4546756,4546756,4546757,4546758,4546767,4546768,4546769,4546769,4546770,4546771,4546756,4546757,4546765,4546766,4546767,4546767,4546768,4546769,4546771,4546772,4546757,4546767,4546768,4546768,4546769,4546769,4546770,4546772,4546772,4546768,4546768,4546769,4546769,4546770,4546770,4546771,4546772,4546773,4546770,4546774,4546769,4546774,4546778,4546778,4546778,4546779,4661186,4661188,4546778,4546779,4546780,4546780,4546781,4661179,4661180,4661182,4661185,4661186,4661187,4661189,4546779,4546780,4546780,4546781,4546781,4546783,4661179,4661182,4661183,4661186,4661186,4661187,4839777,4546780,4546781,4546781,4546782,4546784,4661179,4661180,4661180,4661181,4661182,4661183,4661183,4661186,4661186,4661187,4661189,4661192,4700290,4839777,4923282,4923283,4546781,4546782,4546782,4546783,4546784,4661180,4661187,4839777,4839778,4546782,4546783,4546784,4546784,4546785,4661181,4661181,4661182,4661182,4661183,4661184,4661184,4661186,4661187,4661188,4661188,4661189,4661189,4661192,4839776,4839776,4839778,4839778,4546783,4546784,4546784,4546785,4661181,4661182,4661182,4661183,4661184,4661184,4661186,4661186,4661188,4661188,4661192,4661193,4839778,4839778,4839779,5970057,4546784,4546785,4546785,4546786,4661181,4661182,4661182,4661183,4661183,4661184,4661185,4661185,4661186,4661187,4661188,4661189,4661193,4661195,4700292,4700293,4702283,4723313,4839777,4839779,4839779,4923299,5333533,4546785,4661182,4661183,4661189,4546786,4546787,4661182,4661183,4661183,4661184,4661184,4661186,4661187,4661189,4661190,4661190,4839779,4839780,4923286,4546787,4546788,4661183,4661184,4661184,4661185,4839781,7762300,4661183,4661184,4661184,4661185,4661185,4661186,4661186,4661187,4661187,4661188,4661188,4661189,4661191,4661191,4661192,4661192,4839779,4839780,4839781,4839781,4923287,5372536,4661191,4632622,4704127,4695594,4735600,4775579,4775580,4775580,4775582,4775583,4775586,4775594,4775580,4775581,4775581,4775582,4775583,4775583,4775586,4775586,4775587,4775588,4775589,4775590,4775595,4775596,4775598,4775599,4775601,4775603,4775581,4775582,4775583,4775584,4775584,4775585,4775586,4775587,4775587,4775588,4775589,4775589,4775596,4775596,4775597,4775598,4775599,4775600,4775601,4775601,4775602,4775605,4775582,4775583,4775585,4775585,4775586,4775587,4775587,4775588,4775588,4775589,4775590,4775591,4775592,4775596,4775596,4775597,4775597,4775598,4775598,4775599,4775600,4775601,4775603,4775604,4775605,4775584,4775584,4775585,4775587,4775588,4775588,4775589,4775591,4775593,4775597,4775598,4775599,4775600,4775600,4775604,4775588,4775590,4775609,4775585,4775586,4775587,4775589,4775590,4775592,4775600,4775609,4775610,4775586,4775587,4775587,4775588,4775588,4775589,4775589,4775590,4775590,4775591,4775591,4775592,4775593,4775593,4775595,4775598,4775599,4775606,4775610,4775610,4775587,4775588,4775588,4775589,4775590,4775590,4775591,4775592,4775592,4775593,4775595,4775595,4775603,4775605,4775607,4775611,4775588,4775589,4775590,4775590,4775591,4775591,4775592,4775594,4775595,4775598,4775600,4775611,4775590,4775591,4775591,4775592,4775592,4775593,4775600,4775606,4775608,4775612,4775591,4775591,4775592,4775593,4775612,4775612,4775592,4775593,4775593,4775595,4775597,4775602,4775612,4775612,4775613,4775592,4775594,4775602,4775603,4775606,4775611,4775612,4775613,4775593,4775594,4775594,4775595,4775596,4775597,4775597,4775598,4775598,4775601,4775602,4775603,4775604,4775606,4775607,4775610,4775612,4775613,4775613,4775614,4775594,4775595,4775597,4775600,4775605,4775606,4775607,4775611,4775613,4775614,4775614,4775595,4775596,4775597,4775598,4775598,4775599,4775599,4775603,4775603,4775605,4775606,4775606,4775607,4775613,4775614,4775614,4775615,4775596,4775597,4775598,4775599,4775603,4775604,4775606,4775608,4775613,4775614,4775615,4775615,4775597,4775599,4775599,4775600,4775603,4775606,4775608,4775609,4775615,4775615,4775616,4775599,4775600,4775607,4775608,4775612,4775615,4775616,4775616,4775608,4775608,4775616,4775606,4775607,4775609,4775612,4775615,4775616,4775601,4775602,4775606,4775607,4775609,4775610,4775617,4775617,4775602,4775607,4775613,4775617,4775618,4775609,4775618,4775618,4775619,4775618,4775619,4775619,4775610,4775619,4775620,4775620,4775621,4775619,4775610,4775611,4775612,4775614,4775615,4775618,5447947,4775612,4775614,4775614,4775615,4775612,4775613,4775613,4775614,4775614,4775615,4775615,4775616,4775621,4775622,4775623,4954193,4954193,5037699,4775613,4775614,4775615,4775616,4775616,4775621,4775624,5447947,6084473,4775614,4775616,4775616,4775617,4775623,4775624,4954194,5486948,4775615,4775617,4775617,4775618,4775622,4775624,4775625,4775617,4775618,4775618,4775621,4775623,4775624,4775625,5037700,4775617,4775618,4775619,4775619,4775625,4775626,4954196,4954196,4775618,4775619,4775621,4775625,4775626,4775626,4816700,4954194,4954196,4954196,4954197,5486951,4775619,4775620,4775623,4775623,4775626,4775627,4954196,5037702,5486951,4775620,4775621,4775621,4775622,4775622,4775623,4775625,4775627,4775627,4954197,4775622,4775623,4775627,4775627,4775628,4790523,5037703,5447955,6084476,4775628,4837960,4954198,4775625,4775629,4954199,4775628,4775630,4954199,4775625,4775626,4775630,5037704,5037713,5447953,4775630,4790527,4954200,4775627,4775630,4775631,4954201,4775631,4775631,4775632,4954201,4954202,4775632,4775632,4814713,4954202,5037708,4775632,4775633,4775633,4775634,4775634,4775635,4790529,4954203,4954204,4954204,5037707,5037715,5447957,5447959,4775634,4954204,4954204,4954205,5037719,5486958,4775635,4782073,4782074,4814713,4814715,4814716,4814716,4814717,4814718,4814718,4816707,4816709,4837738,4889085,4954202,4954203,4954203,4954204,4954204,4954205,4954206,5037709,5037709,5037710,5037710,5037712,5037714,5037718,5037720,5447958,5447961,5447961,5447964,5486961,6084484,6084492,7991968,4816709,4954205,4954205,5037710,4954205,4788526,4788528,5044163,4960657,4805441,4805444,4805442,4969113,4969115,4969119,4853808,4853811,4853811,4853814,4853812,4853813,4853813,4853816,4853814,4993299,4993300,4993300,5076805,4993303,5076809,4857803,4857803,4857804,4995299,4995300,4995300,4899905,5016371,5016372,5099877,4900362,5016600,5002550,5067669,5132770,5132772,5132772,5132773,5132784,5132786,5132788,5132773,5132787,5132773,5132774,5132774,5132789,5132789,5132790,5132775,5132776,5132776,5132787,5132787,5132788,5132788,5132789,5132789,5132790,5132790,5132793,5132788,5132788,5132789,5132790,5132790,5132791,5132791,5132789,5132790,5132790,5132791,5132790,5132790,5132791,5132791,5216291,5132802,5132801,5132802,5132802,5132803,5132803,5216301,5665541,6263068,8055306,5132803,5132804,5216294,5216294,5132804,5216295,5216313,5626543,6263069,7415637,5132805,5132806,5132806,5132807,5132807,5132811,5155502,5175865,5216291,5216292,5216292,5216293,5216293,5216294,5216294,5216295,5216295,5216296,5216296,5216297,5216297,5216298,5216299,5216300,5216301,5216301,5216302,5216303,5216304,5216304,5216305,5216307,5216308,5216309,5216310,5216311,5216317,5221800,5299154,5626543,5626544,5626544,5626546,5626547,5626548,5665542,5665543,5665544,5665544,5665545,5665545,5665546,5665547,5873497,6180647,6263068,6263069,6263069,6263078,6263079,7815473,8025502,8025502,8055309,8170553,5132806,5132808,5216293,5216294,5216294,5216295,5216295,5216296,5216296,5216297,5216299,5216301,5216303,5216303,5216309,5216317,5530511,5626544,5626545,5665544,5665546,5665898,6039874,6733586,7085633,5132807,5132809,5216294,5216296,5216296,5216297,5216299,5216306,5216308,5299155,5334787,5626544,5216297,5626545,5216297,5626545,5216297,5216297,5626546,5626546,5351629,5626549,5178203,5178221,5178238,5239020,5218936,5259366,5299781,5299791,5299782,5299797,5299783,5299783,5299798,5299799,5299783,5299783,5299784,5299797,5299797,5299783,5299784,5299784,5299785,5299785,5299796,5299798,5299800,5299801,5299801,5299784,5299785,5299798,5299799,5299801,5299801,5299803,5299785,5299786,5299786,5299787,5299788,5299788,5299789,5299790,5299792,5299792,5299793,5299793,5299794,5299794,5299795,5299795,5299796,5299797,5299797,5299798,5299798,5299799,5299799,5299800,5299800,5299801,5299801,5299802,5299802,5299824,5299786,5299787,5299787,5299789,5299790,5299791,5299792,5299792,5299793,5299793,5299794,5299795,5299797,5299797,5299798,5299798,5299799,5299799,5299800,5299800,5299801,5299801,5299802,5299802,5299803,5299805,5299807,5299794,5299799,5299800,5299802,5299789,5299794,5299801,5299802,5299818,5299824,5299791,5299793,5299793,5299794,5299800,5299826,5299827,5299793,5299827,5299796,5299804,5299796,5299796,5299797,5299828,5299796,5299797,5299805,5299810,5299829,5299829,5299797,5299798,5299805,5299806,5299798,5299799,5299831,5299799,5299815,5299831,5299799,5299800,5299807,5299800,5299801,5299801,5299802,5299802,5299804,5299807,5299808,5299808,5299812,5299833,5299801,5299802,5299802,5299803,5299803,5299804,5299804,5299805,5299805,5299806,5299806,5299807,5299808,5299809,5299832,5299833,5299833,5299802,5299803,5299803,5299804,5299804,5299805,5299805,5299810,5299833,5299803,5299804,5299804,5299805,5299806,5299809,5299809,5299810,5299834,5299804,5299805,5299805,5299806,5299807,5299809,5299811,5299816,5299834,5299834,5299805,5299806,5299806,5299807,5299808,5299810,5299810,5299835,5299835,5299806,5299807,5299807,5299808,5299808,5299809,5299809,5299812,5299817,5299807,5299808,5299808,5299809,5299809,5299810,5299812,5299813,5299808,5299809,5299809,5299810,5299810,5299811,5299812,5299812,5299814,5299817,5710045,5299809,5299810,5299810,5299811,5299811,5299812,5299813,5299814,5299837,5299810,5299811,5299811,5299812,5299812,5299813,5299814,5299815,5299815,5299816,5299837,5710046,5299811,5299812,5299812,5299813,5299813,5299814,5299814,5299818,5299838,5665361,5710046,5749046,5749047,5749047,5749048,5749049,5957000,6346571,6346572,5299812,5299813,5299813,5299814,5299814,5299816,5299816,5299817,5299817,5299824,5299839,5710047,5710048,5749047,5749050,5299813,5299814,5299814,5299815,5299816,5299817,5299817,5299818,5299820,5710047,5749049,5299814,5299815,5299815,5299816,5299816,5299817,5299817,5299818,5299818,5299819,5299820,5299821,5299839,5299840,5710048,6346574,5299815,5299816,5299816,5299817,5299817,5299818,5299819,5299820,5299825,5299827,5299839,5299840,5299841,5710048,5710050,5710053,5749047,5749048,5749049,5749050,5749051,6346574,8138816,5299816,5299817,5299817,5299818,5299818,5299819,5299820,5299820,5299821,5299821,5299840,5299841,5299841,5361179,5689827,5710049,5710053,5710053,5710054,5710055,5710055,5749049,5749050,5749050,6346575,7898979,8109007,5299817,5299818,5299818,5299819,5299819,5299820,5299820,5299821,5299821,5299823,5299824,5299832,5299840,5299841,5299841,5299842,5710049,5710049,5710051,5710052,5710053,5710055,5749049,5749050,5749051,5749052,5749053,6346583,8109008,8138815,8254059,8679500,5299818,5299819,5299819,5299820,5299821,5299822,5299824,5299825,5299825,5299833,5299842,5710050,5710054,5749052,5749052,6346575,8109009,5299819,5299820,5299820,5299821,5299821,5299822,5299822,5299823,5299827,5299832,5299841,5299842,5299842,5710050,5710051,5710053,5710054,5749050,5749052,5749053,5749054,6346576,5299820,5299821,5299821,5299822,5299822,5299823,5299823,5299824,5299825,5299827,5299842,5299843,5710051,5710053,5749053,6346576,5299821,5299822,5299822,5299823,5299823,5299824,5299824,5299825,5299832,5299843,5418297,5710051,5749054,5299822,5299823,5299823,5299824,5299825,5710052,5710053,5299823,5299824,5299824,5299825,5299826,5299826,5299827,5299829,5299844,5299844,5710052,5299824,5299825,5299825,5299826,5299827,5299828,5299829,5299844,5299845,5299825,5299826,5299826,5299827,5299827,5299828,5299830,5299830,5299844,6346579,5299826,5299827,5299827,5299828,5299828,5299829,5299829,5299834,5299836,5299845,5710056,5299827,5299828,5299828,5299829,5299829,5299830,5299831,5299832,5299845,5299828,5299829,5299829,5299830,5299831,5299831,5299846,5299847,5299829,5299830,5299831,5299832,5299832,5299844,5299846,5299847,5299847,5299830,5299831,5299831,5299832,5299832,5299835,5299845,5299847,5299848,5299831,5299832,5299833,5299833,5299847,5299832,5299833,5299833,5299834,5299840,5299848,5299848,5299849,5710057,5299833,5299834,5299848,5299849,5299834,5299835,5299849,5299849,5299850,5299835,5299841,5299849,5299850,5299837,5299850,5299850,5299851,5299848,5299850,5299851,5710060,5299852,5299853,5710062,5749064,5299855,5710067,5299857,5710069,7535750,5299862,5710071,5299862,5299863,6346597,5299864,5299865,5710073,5749073,6346598,8254082,5299865,5299866,5689852,5710073,5710074,5710075,5749073,5749074,5749075,5749075,5749078,8109032,5299866,5299867,5418320,5418322,5689852,5710073,5710074,5710074,5710075,5710076,5710077,5710077,5710078,5710078,5710079,5710079,5710080,5749070,5749071,5749071,5749072,5749073,5749073,5749074,5749074,5749075,5749075,5749076,5749076,5749077,5749078,5957027,5989291,6123403,6264179,6264182,6264183,6346599,6346600,6346622,7273178,7899004,8109032,8109033,8138840,8256842,5299867,5710074,5710079,5749072,6346600,6346608,5418321,5710076,5749071,5749074,6346600,6346601,8109034,5310808,5715551,5422553,5771423,5465516,5465517,5792906,8336922,5536784,5536794,5536790,5536794,5536796,5828542,5867543,5828548,5867547,5867548,5828552,5570458,5845375,5928291,5928387,5928483,6063420,6030931,6114617,6079895,6079904,6079914,6100116,6139126,6080092,6080266,6139309,6120281,6120285,6120282,6120283,6120283,6120284,6120285,6120285,6120286,6120286,6120287,6120288,6120288,6120289,6120295,6120296,6120297,6120297,6120298,6120298,6120299,6120299,6120300,6120300,6120283,6120299,6120301,6120284,6120285,6120285,6120286,6120286,6120287,6120287,6120288,6120289,6120289,6120290,6120295,6120296,6120298,6120298,6120299,6120299,6120300,6120300,6120304,6120286,6120286,6120287,6120287,6120288,6120288,6120290,6120290,6120297,6120298,6120299,6120300,6120301,6120302,6120303,6120287,6120299,6120300,6120287,6120288,6120289,6120291,6120299,6120300,6120300,6120302,6120303,6120304,6120304,6120305,6120289,6120290,6120291,6120293,6120300,6120301,6120301,6120302,6120302,6120304,6120304,6120301,6120301,6120302,6120305,6120290,6120291,6120291,6120292,6120301,6120301,6120302,6120302,6120303,6120304,6120306,6120306,6120307,6120307,6120308,6120308,6120291,6120292,6120301,6120302,6120303,6120303,6120306,6120307,6120307,6120308,6120302,6120303,6120304,6120305,6120307,6120307,6120308,6120301,6120302,6120307,6120308,6120309,6120303,6120304,6120309,6120301,6120303,6120303,6120304,6120304,6120308,6120310,6120311,6120304,6120306,6120305,6120308,6120311,6756828,6120310,6120312,6120311,6120311,6120312,6120312,6120313,6120313,6120314,6120314,6120315,6120315,6120316,6120317,6120319,6159297,6159300,8519256,8549064,6120313,6120314,6120314,6120315,6120316,6120318,6937049,6120314,6120315,6120315,6120316,6120316,6120318,6120320,6120320,6159295,6159296,6159298,6159300,6316188,6674402,6756830,6756831,8519256,8519256,8519257,6120315,6120316,6120316,6120317,6120318,6120320,6159298,6159299,6159299,6159300,6756824,8519256,6120316,6120317,6120317,6120318,6120319,6120319,6120320,6120320,6120321,6120322,6159297,6159299,6159299,6159300,6159300,6159301,6159301,6674411,6756825,8309228,8549065,6120317,6120318,6120318,6120319,6120319,6120320,6120320,6120321,6120321,6120322,6159299,6159300,6159301,6159301,6159302,6159302,6159305,6568230,6756824,6756825,6120318,6120319,6120319,6120320,6120320,6120321,6120322,6120324,6159300,6159300,6159301,6159301,6159302,6159302,6159303,6367253,6756826,8309230,8519259,6120319,6120320,6120320,6120321,6120321,6120322,6120322,6120323,6159298,6159300,6159301,6159301,6159302,6159302,6159303,6159303,6316190,6568229,6756825,6756825,6756826,7183182,7683399,8309230,8519260,8664310,6120321,6159299,6159299,6159301,6159301,6159302,6159302,6756827,6756836,6120321,6120322,6120323,6120323,6120325,6159301,6159302,6159303,6159303,6756826,6756827,6120322,6120323,6120324,6159300,6159302,6159302,6159303,6159304,6159304,6159305,6159305,6756826,6756828,6756850,8519261,6120323,6120324,6120325,6143090,6159302,6159302,6159303,6159303,6159304,6159304,6367256,6756827,6756828,8519261,8522197,6120325,6120325,6159301,6159303,6159304,6159304,6674422,6756829,6756831,7579392,8549069,6120325,6120327,6159301,6159302,6159303,6159303,6159304,6159304,6756828,6756829,6756837,7683407,6120327,6159304,6159304,6159306,6756830,8519263,6120327,6159304,6159305,6159307,6159308,6756830,9089754,9835704,6159305,6159306,6756831,6159306,6159306,6756832,6165864,6165869,6182081,8689850,6198278,6198279,6198279,6198281,6198280,6198280,6198280,6198281,6198281,6198283,6198280,6198281,6198282,6198281,6198283,6198281,6198282,6198298,6198282,6198283,6198283,6198284,6198284,6198285,6198296,6198297,6198298,6198298,6198299,6198299,6198301,6198283,6198284,6198284,6198285,6198286,6198288,6198295,6198296,6198298,6198299,6198299,6198300,6198284,6198285,6198285,6198286,6198286,6198298,6198299,6198299,6198300,6198300,6198301,6198301,6198285,6198286,6198287,6198289,6198295,6198299,6198299,6198300,6198300,6198301,6198301,6198302,6198286,6198287,6198288,6198298,6198299,6198300,6198300,6198301,6198301,6198302,6198302,6198303,6198287,6198288,6198290,6198298,6198300,6198300,6198301,6198301,6198302,6198302,6198303,6198288,6198299,6198299,6198300,6198301,6198302,6198302,6198303,6198304,6198289,6198298,6198302,6198302,6198303,6198303,6198304,6198304,6198301,6198303,6198303,6198304,6198305,6198306,6198305,6198306,6198310,6198312,6198313,6198312,6198312,6198313,6198313,6198313,6198313,6198314,6198314,6198315,6795823,6198314,6198315,6198315,6198316,6198317,6795824,6795830,6795831,8558256,8558256,6198315,6198316,6198317,6406252,6572627,6607232,6713403,6795823,6795831,6795833,8558257,8703308,6198316,6198317,6198317,6198318,6402647,6406252,6572628,6713402,6713403,6713403,6713404,6795823,6795824,6795824,6795825,6795831,6795831,6795832,6795833,6795834,6877219,7222183,7722398,7722401,7722402,7722403,7966091,7984984,8348229,8558257,8558258,8558259,8588062,8588065,8588066,8588066,8703308,6198317,6198318,6198318,6198320,6198992,6355189,6402649,6402651,6406253,6438516,6542763,6572625,6572628,6607228,6607229,6607230,6607232,6713402,6713403,6713403,6713404,6713405,6713408,6713417,6713418,6795824,6795824,6795825,6795825,6795829,6795832,6795833,6795833,6795834,6795834,6795835,6886927,7222178,7222181,7257262,7618389,7984984,7984984,8348229,8348229,8348230,8558258,8558258,8558259,8558259,8558260,8588064,8588065,8588065,8588066,8588066,8588068,8703309,8703315,6198318,6198319,6198320,6406249,6533954,6607233,6713402,6795824,6795825,6795825,6795826,6795835,7966171,7966172,7984981,8558259,8588066,8703309,6198319,6198320,6198320,6402650,6406254,6713403,6713404,6713404,6713419,6795813,6795825,6795826,6795834,6795835,7722404,8348230,8558259,6355191,6406255,6572630,6607231,6607234,6713405,6795825,6795826,6795826,6795827,6795835,8558260,6406255,6795826,6795826,6795827,6795828,6199003,6796182,6199679,6406938,6512071,6512072,6512072,6512073,6512073,6764112,6952706,6952707,6952708,8715141,6952707,7073504,6606996,6606997,6606999,6607000,6607001,7000179,7000181,7000182,6610601,7000174,6776978,7000175,6614195,6614196,6614201,6614201,6614202,6614202,6780571,7003780,7003773,8192929,8556177,6614214,6921352,7003772,7003781,7089350,8192932,8556179,8766206,8766207,8766207,6921353,7003774,7003781,7123508,7930351,8174121,6678725,6678828,6678829,6678933,6678933,6847541,7036139,6869601,7131472,6887224,7140286,6946952,6946952,6946940,6946955,6946954,6946955,6946956,7087729,6981559,7170150,7170152,8096729,8932584,8932585,8962391,7016154,7016156,7016157,7016158,7016158,7016159,7016160,7016163,7016161,7016162,7204759,7204752,7204753,7204760,7122337,7204754,8131333,7228509,7228512,7228503,7228506,7228489,7228515,7228519,7228504,7228505,7228507,7228508,7228508,7228510,7228518,7228508,7228509,7228511,7228510,7228510,7228514,7228514,7228504,7228519,7228524,7228519,7228525,7228523,7228518,7228530,7228519,7228534,8863332,9073359,7228524,7310926,7310926,7310927,7310928,8237503,9073360,7228533,7228536,7310929,8500088,7310929,7310930,7310930,9073363,7737286,8133494,9073364,7430665,8500090,7310932,7310935,7310935,7310935,7693587,7310936,7310937,7310938,7310939,7737296,7310941,8500100,9073374,8500101,7393320,7393331,7393332,7393332,7393332,7393333,7393335,7393348,7393349,7393353,7393354,7393333,7393348,7393350,7393353,7393353,7393334,7393335,7393335,7393336,7393337,7393338,7393338,7393339,7393340,7393340,7393341,7393341,7393342,7393342,7393343,7393343,7393346,7393347,7393347,7393348,7393348,7393349,7393349,7393350,7393350,7393351,7393351,7393352,7393352,7393353,7393353,7393354,7393355,7393355,7393338,7393341,7393342,7393342,7393349,7393349,7393350,7393350,7393340,7393344,7393351,7393341,7393344,7393356,7393356,7393360,7393356,7393347,7393353,7393362,7393347,7393353,7393356,7393346,7393346,7393348,7393356,7393358,7393364,7393349,7393356,7393356,7393364,7393364,7393347,7393348,7393348,7393349,7393356,7393357,7393364,7393364,7393349,7393350,7393350,7393355,7393356,7393356,7393357,7393359,7393360,7393360,7393364,7393365,7393365,7393349,7393350,7393351,7393353,7393354,7393356,7393356,7393357,7393357,7393358,7393365,7393365,7393366,7393351,7393351,7393355,7393356,7393356,7393357,7393357,7393358,7393358,7393359,7393359,7393365,7393366,7393366,7393356,7393356,7393357,7393358,7393358,7393361,7393365,7393366,7393366,7393357,7393358,7393360,7393361,7393362,7393365,7393367,7393367,7393354,7393358,7393359,7393359,7393360,7393368,7393360,7393370,7393362,7393363,9185584,7393362,7393363,7393363,7393364,7393364,7393363,7393363,7393364,7393365,7393366,7393363,7393364,7393364,7393365,7393365,7393364,7393365,7393365,7393366,7393366,7393367,7393368,7393369,7393373,7819704,8319926,8319927,8701567,8945753,8945754,9155781,9155782,9185588,9300832,7393365,7393366,7393366,7393367,7393367,7393368,7393368,7393369,7393369,7393373,7393373,7513082,8319926,8563695,8945753,8945753,8945755,9185589,7393366,7393367,7393367,7393368,7393368,7393369,7393369,7393371,7393373,7393374,7393374,7725958,7819702,7823014,8319926,8431600,8945754,8945755,9155782,9155783,9185588,9185589,9303592,7393367,7393368,7393368,7393369,7393369,7393370,7393370,7393371,7393371,7393372,7393374,7675688,8021963,8945755,9155783,9155785,9300840,7393368,7393369,7393369,7393370,7393370,7393371,7393371,7393372,7393374,7393375,7393375,7512929,7573575,7819706,8215914,8319928,8319929,8319929,8563697,8582509,8945754,8945754,8945755,8945756,8945757,9155784,9185591,9185592,7393369,7393370,7393370,7393371,7393371,7393372,7393372,7393373,7393375,7393375,7393376,7819704,8245142,8319928,8319929,8319930,8582503,8582510,8945755,8945755,9155784,9155784,9155786,9185591,9185592,7393370,7393371,7393371,7393372,7393372,7393373,7393373,7393374,7393375,7393376,7393394,7819707,8215915,8319928,8448465,8945755,8945756,9155785,9155786,9185592,7393371,7393372,7393372,7393373,7393373,7393375,7393376,7393376,7393377,7393380,7819705,8319928,8432625,8582511,8582511,8945756,8945757,9155785,9155785,9185592,7393372,7393373,7393373,7393374,7393376,7393377,7393377,7478929,7819686,7819708,8319929,8319930,8582511,8945756,8945757,9155785,9155786,9185593,7393373,7393374,7393374,7393375,7393375,7393376,7393377,7393377,7393378,8319930,8319931,8319931,8448466,8945757,8945757,9155785,9155786,9155786,9155788,9155789,9185593,9300837,7393374,7393375,7393375,7393376,7393376,7393377,7393378,7393378,7819712,8319931,8945757,8945758,8945758,9155786,9300837,7393375,7393376,7393376,7393377,7393378,7393378,7393379,7393380,7929278,8582513,8945758,8945758,8945759,9185594,9185595,7393376,7393378,7393378,7393379,7393379,7524877,7819708,7819710,8582513,8945758,8945759,9155787,9155788,9155789,7393378,7393378,7393379,7393379,7393380,8319934,8563702,8945759,8945759,9155790,9185596,9300839,7393378,7393380,7393400,7819709,8945760,9155788,9155790,7393379,7393380,7393380,7478933,8319934,8945760,8945763,9155789,9155791,7393381,8582516,8945761,7393381,7393382,7393382,7393384,7393385,7393401,7716102,7819690,7819710,7975839,7996127,8174621,8319933,8319934,8319934,8319935,8452329,8563704,8582515,8582516,8582516,8945761,8945761,8945762,8945764,9155790,9155790,9185595,9185597,9185598,9300841,7393382,7478934,7512936,7513091,7523018,7524880,7819710,7929281,8143508,8215921,8319934,8319935,8319936,8319936,8582516,8582517,8945761,8945761,8945762,8945763,8945763,9155790,9155790,9155791,9185597,9185597,9185598,9185599,9187331,9300841,7393383,7393386,7819692,7819711,7819716,8319934,8319934,8319935,8319935,8319936,8319937,8582515,8582516,8582517,8582517,8945761,8945762,8945762,8945766,9155790,9155791,9155791,9155792,9185598,9185599,9300842,7696977,8319936,8945763,8582518,8582520,8319937,8945765,9155796,7393420,7819733,8035274,8215941,8582533,9185618,7556141,9237179,7564551,7564556,7564562,7564626,7564631,7564702,7564703,7564704,7564726,8405627,9031455,9031458,7564876,8405713,7575562,7604038,7632501,7632502,7632503,7632657,9065327,8702084,7632812,7632813,7632812,8439654,8439656,8439657,8702238,9275512,7634933,9276571,7652665,8499861,7656391,7656391,9077273,8714028,7753794,7753797,7999903,8743917,7958020,7958143,7958266,8498368,8000642,8000718,8000773,8623656,8038835,8252014,8058563,9488388,8158665,8965172,8246063,8246051,8246064,8246042,8246083,8246076,8246084,8246085,8246078,8246086,8246088,9582151,8746300,9008881,8746306,8746307,8746309,9008887,9008889,9372133,9372134,9372134,9372135,9582162,9582163,9582163,9582165,9611970,9611971,9611971,9729973,8252692,9012187,8316275,9617271,8334383,9771350,8465191,8771155,9099614,9481672,8558309,9738260,8598888,9185277,8650570,9211113,8677148,8677203,8677272,9587724,8893645,9313838,8955885,9101198,9038461,9038509,9038527,9038528,9038575,9038667,9038601,9038677,9038743,9142614,9142616,9405198,9768443,9768443,9768444,9978474,10008278,9077121,9424393,9096920,9096996,9097070,9434363,9246485,9246498,9246501,9246486,9246501,9246501,9246502,9246487,9246488,9246488,9246502,9246502,9246489,9246489,9246503,9246503,9246502,9246503,9246504,9246504,9246516,9246517,9872328,9872329,10082358,10082359,10085293,10227409,9490270,9490272,9509079,9509083,9509084,9509084,9509085,9872329,9872329,9872330,9872331,10082357,10082358,10082358,10082359,10082359,10082360,10112166,10112166,9347057,9408451,9469845,9601938,9601941,9471892,10195052,9503574,9503576,10210894,10000866,9511331,10214792,9698482,9716260,9733876,9733956,9734022,9734023,9734034,9734035,9734025,9734035,9734026,9734036,9734036,9752845,9752846,9752848,9752848,9752849,10116093,10116094,10116095,10326122,10326123,10326124,10355928,10355929,10471173,9771656,9771646,9771657,9771659,9771660,9771648,9771661,9771662,9771650,9771662,9771651,9771652,9771661,9771663,9771663,9771664,9771673,10134906,10072597,10134907,10134908,10134908,10134909,10134909,10185574,10185574,10324362,10344937,10344937,10344938,10344939,10344939,10374743,10374743,10374744,10374744,10489988,10492795,10009811,10609076,10373531,10435843,10498140,10498141,10498155,10498155,10498156,10498141,10498142,10498144,10498156,10498156,10498157,10498159,10498142,10498143,10498143,10498144,10498144,10498145,10498153,10498156,10498156,10498157,10498157,10498158,10498158,10498159,10498146,10498157,10498157,10498158,10498159,10498144,10498157,10498158,10498159,10498159,10498160,10498157,10498158,10498159,10498160,10498159,10498160,10498161,10498159,10498160,10498162,10498160,10498163,10498161,10498163,10498249,10498171,10498172,10708185,10498171,10498172,10498174,10708184,10708185,10708185,10708186,10708187,10708187,10737992,10498172,10498173,10498173,10498174,10498174,10498175,10516738,10708184,10708185,10708185,10708186,10708186,10708187,10708187,10708188,10737991,10737992,10737992,10737993,10737993,10737994,10853236,10855995,10498173,10498175,10531591,10708185,10708186,10708186,10708188,10737992,10498174,10498175,10498175,10708185,10708186,10708186,10708187,10708187,10708188,10708189,10737994,10737995,10498176,10708187,10708187,10708188,10708189,10548824,10708187,10708187,10708188,10708188,10708190,10498256,10708188,10708188,10737996,10853239,10516738,10708189,10708189,10737996,10498344,10708275,10708277,10535311,10535316,10726761,10756570,10565020,10565102,10565183,10771503,10599485,10599487,10758848,10758848,10663687,10727891,10823056,10877062,10897637,10918198,10918198,10918200,10918213,10918198,10918199,10918199,10918200,10918212,10918213,10918199,10918200,10918200,10918201,10918201,10918202,10918214,10918214,10918215,10918215,10918216,10918200,10918201,10918201,10918202,10918202,10918203,10918212,10918213,10918213,10918214,10918214,10918215,10918215,10918216,10918216,10918217,10918217,10918201,10918202,10918202,10918203,10918214,10918215,10918215,10918216,10918216,10918217,10918217,10918202,10918203,10918214,10918215,10918216,10918216,10918217,10918217,10918218,10918203,10918204,10918204,10918214,10918215,10918216,10918216,10918217,10918217,10918218,10918218,10918204,10918205,10918205,10918207,10918214,10918215,10918215,10918216,10918216,10918217,10918217,10918218,10918218,10918219,10918217,10918217,10918218,10918218,10918219,10918219,10918220,10918217,10918217,10918218,10918218,10918220,10918218,10918220,10918227,10918227,10918227,10918228,10918229,10918229,10918230,11063263,10918228,10918229,10948020,10918228,10918229,10918229,10918231,10948021,10918229,10918230,10918230,10918231,10918231,10948020,10948020,10948021,10918230,10918231,10918231,10918232,10918232,10948020,10948021,10948022,10948022,10948023,11063265,10918231,10918232,10918232,10918233,10918233,10921151,10948019,10948021,10948022,10948022,10948023,10948023,11063266,11063277,11922192,10918232,10918233,10918233,10948020,10948021,10948021,10948022,10948022,10948023,10948023,10948024,11063266,11066074,10918233,10918234,10918234,10921152,10948020,10948022,10948022,10948023,10948023,10948024,10948024,10948025,11063267,10918234,10918235,10918235,10918236,10918237,10921152,10921152,10948018,10948021,10948021,10948022,10948023,10948023,10948024,10948024,10948025,10948025,10948026,11063267,11063328,11063340,10918235,10918236,10948023,10948023,10948024,10948024,10948025,10948027,10918238,10948022,10948023,10948024,10948024,10948025,10948025,10948026,10948028,11063268,10948025,10948026,10948026,11063271,10924079,10924082,10924083,10924082,10924083,10924083,10924084,10924195,10950953,10950954,10950954,10950953,10950955,10950954,10950955,10950955,10950954,10924311,10951066,10977808,10977809,10977810,10977827,10977810,10977811,10977811,10977812,10977814,10977812,10977812,10977811,10977812,10977812,10977813,10977813,10977814,10977815,10977827,10977830,10977812,10977813,10977813,10977814,10977815,10977827,10977827,10977828,10977829,10977829,10977830,10977813,10977814,10977814,10977826,10977827,10977827,10977828,10977829,10977829,10977830,10977814,10977815,10977815,10977816,10977816,10977817,10977827,10977827,10977828,10977828,10977829,10977829,10977830,10977830,10977831,10977831,10977832,10977832,10977815,10977816,10977816,10977817,10977817,10977818,10977818,10977819,10977827,10977827,10977828,10977828,10977829,10977829,10977830,10977830,10977831,10977831,10977832,10977832,10977833,10977816,10977817,10977817,10977818,10977818,10977819,10977820,10977827,10977828,10977828,10977829,10977829,10977830,10977830,10977831,10977831,10977832,10977832,10977833,10977833,10977817,10977818,10977818,10977829,10977830,10977830,10977831,10977831,10977832,10977832,10977833,10977833,10977834,10977818,10977819,10977822,10977830,10977830,10977831,10977831,10977832,10977832,10977833,10977833,10977834,10977834,10977819,10977829,10977830,10977830,10977831,10977831,10977832,10977832,10977833,10977835,10977822,10977829,10977830,10977831,10977831,10977832,10977832,10977833,10977833,10977834,10977834,10977836,10977821,10977831,10977832,10977832,10977833,10977836,10977832,10977833,10977834,10977833,10977833,10977836,10977836,10977840,10977841,10977842,10977840,10977842,10977843,10977844,11093070,10977841,10977842,10977843,10977844,10977846,10977842,10977843,10977843,10977844,10977844,10977845,10977845,10977846,11093071,11095830,10977843,10977844,10977844,10977845,10977845,10977846,10977847,11093072,10977844,10977845,10977845,10977846,10977846,10977847,10977847,11093072,11095891,12264460,10977845,10977846,10977846,10977847,10977847,10977848,10977849,11093073,11093117,12264518,10977846,10977847,10977847,10977848,10977848,10977849,10977850,11093073,11093080,11093089,11095832,10977847,10977848,10977848,10977849,10977850,10977850,10977852,11093074,11093085,11093127,11093128,11093136,11093137,11095833,15020867,10977848,10977849,10977849,10977852,11093074,11093074,11093079,11093124,11093140,11095833,11095882,10977849,10977850,10977851,10977851,11093075,11093081,11093126,11093135,10977850,10977851,11093075,11093140,11095834,10977852,10977852,10977853,10977853,10993209,11093075,11093076,11093082,11093087,11093096,11093129,11093132,11093144,11095835,12264464,11093076,11093077,11093083,11093083,11093077,11093078,11093078,11093079,10981292,11094803,11008594,11111219,11208300,11208301,11208302,11208302,11208303,11208303,11208304,11208304,11208305,11208305,11208306,11208306,11208307,11208307,11208308,11208308,11208309,11208310,11208310,11208311,11208311,11208312,11208313,11208313,11208314,11208315,11208316,11208316,11208317,11208318,11208319,11208319,11208321,11208344,11208348,11208350,11208351,11208304,11208306,11208306,11208307,11208307,11208308,11208318,11208305,11208308,11208321,11208306,11208307,11208308,11208309,11208309,11208321,11208307,11208307,11208308,11208308,11208309,11208310,11208314,11208319,11208320,11208320,11208309,11208309,11208309,11208310,11208310,11208311,11208319,11208310,11208311,11208311,11208312,11208312,11208315,11208324,11208312,11208313,11208317,11208318,11208321,11208324,11208347,11208396,11208314,11208315,11208315,11208316,11208316,11208317,11208317,11208318,11208318,11208319,11208319,11208320,11208321,11208321,11208322,11208322,11208323,11208324,11208324,11208325,11208326,11208327,11208327,11208328,11208329,11208330,11208330,11208331,11208332,11208333,11208334,11208334,11208335,11208335,11208336,11208336,11208337,11208337,11208339,11208341,11208342,11208343,11208345,11208346,11208349,11208350,11208351,11208351,11208353,11208353,11208354,11208357,11208357,11208358,11208359,11208359,11208360,11208361,11208362,11208366,11208376,11208396,11208315,11208316,11208318,11208319,11208323,11208326,11208336,11208337,11208339,11208396,11208317,11208317,11208319,11208319,11208324,11208334,11208352,11208354,11208358,11208369,11208396,11208317,11208318,11208319,11208320,11208321,11208322,11208323,11208323,11208324,11208324,11208325,11208327,11208328,11208329,11208330,11208334,11208338,11208339,11208354,11208372,11208384,11208396,11208319,11208323,11208329,11208333,11208338,11208348,11208359,11208319,11208320,11208320,11208321,11208325,11208355,11208321,11208321,11208324,11208337,11208347,11208354,11208354,11208361,11208393,11208396,11208322,11208396,12379687,11208322,11208323,11208324,11208330,11208340,11208348,11208355,11208357,11208323,11208324,11208324,11208325,11208325,11208326,11208327,11208327,11208328,11208329,11208330,11208330,11208331,11208332,11208333,11208333,11208335,11208336,11208337,11208338,11208339,11208340,11208341,11208342,11208343,11208344,11208346,11208346,11208347,11208348,11208350,11208353,11208357,11208363,11208370,11208375,11208380,11208396,11211116,11211121,11211123,11633752,11208324,11208325,11208328,11208342,11208397,11208325,11208326,11208330,11208333,11208344,11208326,11208327,11208327,11208328,11208329,11208330,11208331,11208332,11208333,11208338,11208343,11208345,11208378,11208382,11208396,11208327,11208346,11208382,11208328,11208330,11208365,11208396,11208330,11208330,11208332,11208333,11208333,11208335,11208337,11208342,11208347,11208354,11208355,11208359,11208360,11208364,11208396,11208331,11208332,11208335,11208361,11208331,11208333,11208334,11208347,11208359,11208368,11208373,11208332,11208333,11208333,11208334,11208335,11208336,11208336,11208341,11208342,11208342,11208344,11208345,11208346,11208348,11208350,11208356,11208359,11208359,11208360,11208362,11208364,11208367,11208371,11208380,11208396,11208334,11208351,11208367,11208334,11208335,11208336,11208351,11208335,11208336,11208336,11208347,11208352,11208363,11208366,11208371,11208396,11208336,11208337,11208338,11208396,11208338,11208339,11208339,11208340,11208342,11208345,11208346,11208347,11208349,11208349,11208350,11208351,11208353,11208353,11208356,11208357,11208358,11208359,11208360,11208363,11208365,11208369,11208370,11208381,11208396,11208339,11208340,11208340,11208343,11208348,11208349,11208358,11208366,11208369,11208370,11208396,11208341,11208342,11208342,11208343,11208343,11208344,11208344,11208345,11208346,11208347,11208348,11208348,11208349,11208350,11208351,11208351,11208352,11208353,11208355,11208355,11208357,11208359,11208359,11208360,11208360,11208361,11208362,11208363,11208364,11208364,11208366,11208368,11208368,11208369,11208370,11208371,11208372,11208372,11208373,11208379,11208390,11208390,11208394,11208396,11208342,11208343,11208343,11208348,11208350,11208366,11208367,11208343,11208345,11208345,11208346,11208348,11208351,11208352,11208361,11208396,11208344,11208345,11208345,11208346,11208346,11208347,11208347,11208348,11208348,11208349,11208350,11208351,11208351,11208352,11208352,11208354,11208355,11208356,11208358,11208358,11208359,11208360,11208363,11208363,11208365,11208368,11208369,11208371,11208377,11208378,11208380,11208396,11208396,11208346,11208349,11208346,11208347,11208349,11208361,11208368,11208347,11208348,11208348,11208353,11208355,11208356,11208365,11208381,11208349,11208349,11208350,11208351,11208353,11208356,11208370,11208371,11208395,11208398,11208413,11208349,11208352,11208355,11208356,11208369,11208388,11208394,11208396,11208400,11208351,11208354,11208355,11208357,11208366,11208367,11208368,11208371,11208380,11208389,11208396,11208363,11208364,11208371,11208373,11208378,11208352,11208358,11208364,11208366,11208386,11208354,11208354,11208356,11208356,11208357,11208358,11208358,11208363,11208365,11208366,11208370,11208372,11208379,11208399,11208360,11208365,11208396,11211086,11208355,11208357,11208357,11208360,11208373,11208396,11208397,11208357,11208359,11208360,11208363,11208364,11208366,11208374,11208380,11208385,11208392,11208408,11208363,11208379,11208358,11208359,11208360,11208361,11208361,11208363,11208369,11208370,11208373,11208375,11208380,11208393,11208399,11208403,11208405,11208418,11208361,11208362,11208364,11208368,11208369,11208371,11208372,11208373,11208374,11208376,11208379,11208414,11208361,11208362,11208364,11208368,11208368,11208371,11208373,11208374,11208375,11208376,11208377,11208380,11208383,11208388,11208399,11208402,11208404,11208361,11208362,11208363,11208365,11208367,11208371,11208376,11208378,11208389,11208393,11208394,11208399,11208405,11208420,11208365,11208367,11208375,11208377,11208400,11208377,11208380,11208400,11208364,11208366,11208370,11208372,11208375,11208378,11208380,11208381,11208382,11208384,11208393,11208396,11208401,11208408,11208367,11208368,11208368,11208369,11208370,11208372,11208372,11208374,11208377,11208378,11208379,11208384,11208385,11208393,11208395,11208396,11208398,11208402,11208403,11208405,11208370,11208370,11208423,11208369,11208370,11208371,11208372,11208373,11208374,11208374,11208375,11208376,11208377,11208378,11208379,11208380,11208380,11208382,11208385,11208390,11208394,11208395,11208397,11208398,11208400,11208403,11208415,11208423,11208372,11208381,11208386,11208389,11208389,11208424,11208409,11208425,11208382,11208385,11208387,11208405,11208405,11208382,11208396,11208400,11208376,11208377,11208378,11208383,11208384,11208387,11208388,11208389,11208398,11208401,11208375,11208381,11208406,11208377,11208378,11208381,11208382,11208385,11208389,11208393,11208397,11208412,11208415,11208378,11208380,11208381,11208381,11208382,11208383,11208384,11208389,11208394,11208398,11208414,11208385,11208394,11208396,11208382,11208383,11208385,11208388,11208396,11208397,11208408,11208414,11208384,11208385,11208386,11208387,11208389,11208392,11208392,11208400,11208404,11208425,11208383,11208386,11208395,11208398,11208404,11208384,11208390,11208405,11208384,11208385,11208386,11208387,11208389,11208394,11208396,11208396,11208410,11208431,11208388,11208399,11208387,11208392,11208408,11208388,11208389,11208390,11208392,11208392,11208395,11208396,11208397,11208398,11208402,11208388,11208388,11208389,11208390,11208391,11208391,11208393,11208394,11208397,11208397,11208398,11208399,11208401,11208403,11208405,11208406,11208407,11208415,11208415,11208418,11208388,11208390,11208394,11208433,11208390,11208390,11208392,11208393,11208394,11208394,11208395,11208396,11208396,11208397,11208399,11208403,11208405,11208408,11208413,11208413,11208414,11208434,11208396,11208402,11208415,11208425,11208396,11208399,11208410,11208412,11208414,11208415,11208429,11208393,11208394,11208395,11208396,11208396,11208397,11208397,11208399,11208401,11208401,11208402,11208403,11208404,11208404,11208405,11208406,11208410,11208411,11208411,11208412,11208414,11208415,11208417,11208417,11208418,11208426,11208429,11208430,11208431,11208435,11208435,11208410,11208422,11208395,11208395,11208396,11208397,11208397,11208398,11208398,11208399,11208399,11208400,11208405,11208416,11208417,11208418,11208419,11208397,11208398,11208401,11208405,11208417,11208424,11208428,11208433,11208399,11208401,11208402,11208407,11208427,11208400,11208401,11208403,11208432,11208399,11208400,11208401,11208402,11208402,11208403,11208403,11208405,11208405,11208406,11208411,11208413,11208418,11208420,11208421,11208424,11208425,11208439,11208400,11208401,11208402,11208402,11208403,11208403,11208404,11208406,11208406,11208409,11208410,11208411,11208414,11208415,11208416,11208421,11208432,11208439,11208439,11208401,11208402,11208403,11208410,11208411,11208413,11208414,11208417,11208426,11208439,11208440,11208402,11208403,11208403,11208404,11208405,11208405,11208406,11208406,11208407,11208408,11208408,11208410,11208410,11208411,11208412,11208415,11208416,11208420,11208420,11208422,11208423,11208427,11208428,11208434,11208435,11208437,11208440,11208404,11208405,11208405,11208406,11208407,11208408,11208412,11208413,11208414,11208415,11208427,11208436,11208406,11208407,11208408,11208409,11208410,11208412,11208413,11208416,11208417,11208418,11208419,11208428,11208406,11208408,11208414,11208416,11208421,11208422,11208424,11208427,11208428,11208430,11208406,11208407,11208411,11208412,11208413,11208414,11208417,11208418,11208425,11208429,11208430,11208409,11208410,11208410,11208411,11208412,11208414,11208415,11208416,11208417,11208419,11208422,11208423,11208429,11208430,11208431,11208436,11208442,11208412,11208414,11208415,11208421,11208423,11208424,11208428,11208430,11208431,11208409,11208410,11208418,11208424,11208430,11208432,11208415,11208419,11208421,11208424,11208426,11208428,11208431,11208432,11208435,11208444,11208411,11208412,11208415,11208418,11208419,11208424,11208430,11208431,11208444,11208416,11208420,11208425,11208425,11208429,11208432,11208436,11208418,11208420,11208426,11208431,11208432,11208434,11208415,11208416,11208422,11208426,11208426,11208431,11208433,11208434,11208422,11208424,11208427,11208430,11208439,11208416,11208417,11208419,11208422,11208427,11208432,11208434,11208417,11208420,11208422,11208429,11208433,11208434,11208439,11208423,11208425,11208428,11208428,11208429,11208439,11208444,11208420,11208421,11208422,11208425,11208428,11208429,11208435,11208440,11208441,11208444,11208421,11208424,11208436,11208424,11208426,11208429,11208430,11208432,11208425,11208427,11208430,11208433,11208434,11208437,11208438,11208446,11208425,11208430,11208433,11208436,11208437,11208445,11208446,11208426,11208431,11208434,11208434,11208438,11208440,11208447,11208432,11208433,11208439,11208443,11208439,11208428,11208429,11208430,11208430,11208433,11208433,11208434,11208435,11208436,11208438,11208440,11208440,11208441,11208444,11208449,11208450,11208451,11208452,11208452,11208453,11208453,11208430,11208430,11208434,11208437,11208441,11208442,11208434,11208434,11208435,11208435,11208437,11208441,11208450,11208455,11208435,11208435,11208440,11208442,11208447,11208449,11208451,11208455,11208441,11208442,11208451,11208453,11208456,11208439,11208443,11208436,11208438,11208457,11208438,11208439,11208439,11208440,11208441,11208442,11208442,11208443,11208445,11208446,11208447,11208448,11208449,11208451,11208452,11208454,11208454,11208457,11208457,11208458,11208458,11208440,11208440,11208441,11208441,11208442,11208444,11208445,11208447,11208450,11208451,11208453,11208454,11208456,11208458,11208459,11208441,11208441,11208442,11208443,11208444,11208446,11208446,11208447,11208450,11208453,11208455,11208459,11633811,11208448,11208451,11208460,11208444,11208445,11208447,11208448,11208451,11208460,11208444,11208447,11208452,11208458,11208461,11208445,11208446,11208448,11208454,11208457,11208458,11208461,11208448,11208451,11208446,11208447,11208449,11208450,11208456,11208458,11208462,11208448,11208449,11208448,11208450,11208449,11208450,11208450,11208452,11208459,11208450,11208451,11208451,11208465,11208452,11208453,11208453,11208455,11208455,11208456,11208456,11208458,11208460,11208461,11208461,11208462,11208464,11208465,11208465,11208470,11208472,11211135,11211184,11208453,11208454,11208457,11208466,11208454,11208455,11208456,11208456,11208457,11208458,11208459,11208461,11208462,11208462,11208465,11208466,11208467,11208470,11208473,11211185,11225419,12379763,11208456,11208457,11208457,11208461,11208457,11208468,11208458,11208459,11208460,11208461,11208462,11208464,11208464,11208467,11208468,11208470,11208471,11208472,11208473,11208473,11208474,11208475,11208460,11208464,11208469,11208475,11208460,11208461,11208462,11208463,11208464,11208464,11208465,11208468,11208469,11208470,11208470,11208471,11208473,11208474,11208475,11208476,11211191,11633821,11208464,11208470,11208477,11208472,11208464,11208465,11208467,11208468,11208468,11208469,11208470,11208471,11208471,11208472,11208474,11208476,11208476,11208478,11208466,11208467,11208470,11208474,11208467,11208468,11208468,11208470,11208471,11208472,11208473,11208477,11208479,11208479,11208469,11208472,11208473,11208473,11208475,11208469,11208470,11208471,11208471,11208473,11208473,11208474,11208475,11208478,11208479,11208480,11208481,11211144,11211192,11208472,11208474,11208475,11208481,11208481,11208475,11208477,11208474,11208475,11208475,11208476,11208482,11208482,11211146,11208475,11208477,11208476,11208477,11208477,11208478,11208484,11211196,11208478,11208479,11208480,11208481,11208481,11208482,11208483,11208484,11208485,11208485,11211148,11211149,11211197,11211199,14147492,15609116,11208480,11208481,11208481,11208482,11208483,11208484,11208484,11208485,11208485,11208486,11208481,11208482,11208484,11208486,11208482,11208483,11208483,11208484,11208484,11208485,11208485,11208486,11208486,11208487,11211150,11208483,11208484,11208484,11208485,11208486,11208487,11208487,11208484,11208486,11208488,11208485,11208486,11208487,11208488,11208486,11208487,11208488,11208489,11208489,11208488,11208489,11208490,11208490,11211154,11208491,11208491,11208492,11208493,11211155,11211155,11211204,11211204,11211206,11211206,11386006,11633837,11633837,11633838,11633838,12351468,12379774,12379780,12379782,12379785,12379842,26585963,11211156,11211156,11213818,11213819,11213820,11213820,11213821,11213821,11213823,11213827,11213829,11213830,11213848,11213849,11213860,11213861,11213862,11213862,11213865,11213866,11213866,11213867,11213867,11213879,11213879,11213822,11213864,11213867,11213867,11213868,11213868,11213868,11213861,11213868,11213869,11213869,11213865,11213869,11213869,11213870,11213870,11213875,11213840,11213878,11213943,11213896,11213897,11213907,11213904,11213908,11213909,11213909,11213905,11213907,11213910,11213910,11213911,11213938,11213911,11213915,11213914,11213913,11213913,11213913,11213914,11213914,11213915,11213919,11213915,11213916,11213916,11213917,11213917,11213918,11213918,11213919,11213919,11213920,11213921,11213922,11213924,11213925,11213925,11213927,11213927,11213930,11213932,11213934,11213939,11213942,11213916,11213917,11213917,11213918,11213918,11213919,11213919,11213920,11213920,11213921,11213921,11213922,11213922,11213923,11213924,11213925,11213925,11213926,11213927,11213928,11213929,11213929,11213930,11213931,11213932,11213932,11213933,11213935,11213935,11213936,11213937,11213937,11213939,11213942,11213942,11213943,11213943,11213918,11213918,11213919,11213919,11213920,11213921,11213922,11213924,11213928,11213930,11213931,11213936,11213943,11213943,11213918,11213919,11213919,11213921,11213921,11213923,11213928,11213931,11213934,11213943,11213943,11213944,11213919,11213920,11213920,11213921,11213922,11213925,11213927,11213929,11213929,11213932,11213940,11213940,11213943,11213943,11213944,11213944,11213920,11213921,11213921,11213922,11213922,11213923,11213924,11213927,11213928,11213929,11213931,11213932,11213933,11213935,11213937,11213938,11213940,11213941,11213943,11213944,11213945,11213921,11213922,11213923,11213924,11213925,11213930,11213930,11213932,11213935,11213936,11213939,11213945,11213945,11213922,11213923,11213925,11213934,11213938,11213940,11213944,11213945,11213945,11213946,11213924,11213925,11213926,11213935,11213938,11213938,11213939,11213939,11213940,11213944,11213944,11213946,11213924,11213926,11213926,11213927,11213928,11213934,11213936,11213939,11213944,11213945,11213947,11213926,11213927,11213930,11213932,11213932,11213934,11213934,11213937,11213937,11213939,11213941,11213942,11213944,11213945,11213946,11213947,11213947,11213927,11213938,11213927,11213929,11213931,11213932,11213933,11213934,11213935,11213936,11213938,11213938,11213939,11213939,11213941,11213942,11213943,11213945,11213947,11213948,11213949,11213947,11213948,11213949,11213934,11213947,11213950,11213950,11213943,11213945,11213945,11213951,11213937,11213952,11213937,11213943,11213948,11213952,11213941,11213945,11213944,11213953,11213953,11213939,11213940,11213941,11213942,11213945,11213948,11213951,11213952,11213954,11213941,11213942,11213943,11213947,11213952,11213955,11213942,11213944,11213956,11213944,11213951,11213953,11213955,11213956,11213945,11213949,11213954,11213955,11213956,11213956,11213957,11213947,11213947,11213950,11213954,11213957,11213958,11213956,11213957,11213959,11213951,11213955,11213959,11213959,11213954,11213959,11213960,11213952,11213954,11213959,11213960,11213961,11213956,11213957,11213960,11213961,11213962,11636568,11213959,11213962,11213962,11213963,11213958,11213961,11213963,11213962,11213964,11213963,11213964,11213964,11213965,11213962,11213963,11213965,11213966,11213964,11213965,11213966,11213966,11213966,11213967,11213967,11213968,11213967,11213968,11213968,11213969,11213969,11213970,11213970,11213971,11213971,11213972,11213973,11213973,11213974,11213974,11213975,11213976,11213977,11213979,11213980,11213981,11213982,11213983,11213984,11213984,11213985,11213987,11213987,11213988,11213988,11213989,11213989,11213991,11213992,11213996,11213999,11214001,11214004,11214006,11214009,11214014,11214015,11214015,11214016,11214016,11214017,11214017,11214018,11214018,11538015,11567158,11636576,11636576,11636577,12382513,13169377,15101988,11213971,11213972,11213972,11213973,11213974,11213975,11213976,11213977,11213978,11213980,11213982,11213984,11213985,11213986,11213986,11213993,11213993,11213997,11214002,11214003,11214004,11214009,11214014,11214015,11214016,11214017,11214017,11214018,11214018,11214019,11636576,11213973,11213975,11213982,11213994,11214017,11214018,11214019,11214016,11214017,11214020,11636578,11214002,11214019,11214020,11213989,11213981,11213990,11214020,11214021,11214022,11214020,11214022,11214021,11214023,11214021,11213993,11636583,11214010,11214025,11214026,11214025,11213990,11213991,11214014,11214027,11214027,11214027,11213998,11214029,11214027,11214028,11214030,11214029,11214030,11214032,11214031,11214032,11214032,11214012,11214013,11214033,11636590,11214017,11214031,11214032,11214033,11340453,11214011,11214023,11214034,11214014,11214033,11214034,11214035,11214033,11214036,11214037,11214035,11214036,11214038,11214041,11214039,11214040,11214042,11214038,11214041,11214044,11214045,11214045,11214046,11214047,11214048,11214049,11214050,11214049,11214051,11214049,11214049,11214050,11214052,11214053,11214054,11214054,11214056,11214054,11214057,11214060,11214061,11214063,11214061,11214062,11214062,11214063,11214063,11214061,11214062,11214063,11214064,11214062,11214063,11214063,11214064,11214063,11214064,11214064,11214065,11214064,11214065,11214065,26588749,11214065,11214066,11636623,12382568,11214066,11214067,11219871,11264979,11278208,11300810,11388797,11388797,11388798,11388799,11416916,11538065,11567068,11567070,11567116,11567148,11567176,11567182,11612748,11612748,11612749,11612749,11612750,11636623,11636624,11636624,11636625,11636625,11636626,11636626,11636627,11651428,11654838,11728538,11751246,11751248,11751248,11751250,11878622,11953797,12024910,12382558,12382559,12382560,12382560,12382561,12382561,12382562,12382562,12382563,12382564,12382565,12382566,12382566,12382567,12382568,12382568,12382569,12382569,12382570,12382571,12382571,12382572,12382573,12382574,12382574,12382577,12382625,12382626,12382629,12382630,12382632,12382632,12382634,12568642,12657964,13153154,13288670,13432453,13623154,13795002,14269073,14269073,14269074,14269074,14924918,15102036,15611913,16064505,16357694,16357696,16357697,16357698,18928136,19096684,19211162,24084160,26588751,11612750,12382626,14269073,11225729,11642482,11642484,11242396,11402970,11315904,11316017,11316127,11687659,11342362,11631221,11676903,11387565,11387566,11699502,11723380,11466919,11922772,11563536,11563541,11563541,11563542,11563543,11563541,11563542,11563543,12557310,16532439,11609308,11667360,11811368,12557304,12557308,11787494,11609307,11811370,11811370,11619821,11839529,11655058,11655073,11655076,11655088,11857135,11857136,11771184,11891318,11862076,11862081,12050435,11960641,11920071,11920143,11920144,11920146,11920190,11989699,11920218,11920224,11920294,11920230,11920276,11920298,11920266,11920327,11920333,11920334,11920346,11920357,11965900,11989775,11989775,12735710,12735712,12735713,12735716,12735720,13375548,14622223,12011446,12011445,12011447,12011446,12011447,12011452,12011445,12011447,12011448,12011448,12011449,12011449,12035320,12035321,12781258,12035322,12035322,12149946,12781259,12781271,12035323,12035323,12781273,12035324,12035327,12059194,12059181,12059196,12059182,12059183,12059183,12059184,12059184,12059195,12059195,12059196,12059196,12059197,12059197,12059198,12059183,12059184,12059196,12059196,12059197,12059197,12059198,12059198,12059184,12059196,12059197,12059197,12059198,12059199,12059199,12059197,12059197,12059198,12059198,12059200,12059198,12059199,12059198,12059199,12059199,12059208,12059210,12059209,12059210,12805137,12805138,12805138,12059210,12059211,12059211,12273246,12301193,12379923,12805131,12805132,12805133,12805133,12805134,12805135,12805135,12805140,12805141,12805144,12805145,12805146,12805197,13759307,13855025,16034482,19665839,12059211,12805134,13855027,14691645,12059212,12059213,12059213,12082937,12137679,12148993,12148995,12151110,12151111,12173819,12173820,12173820,12173821,12173823,12173824,12173825,12218912,12266559,12301194,12301195,12301195,12373593,12374590,12379924,12379926,12385371,12474653,12517743,12776826,12801787,12805131,12805131,12805132,12805132,12805133,12805133,12805134,12805134,12805135,12805135,12805136,12805137,12805138,12805138,12805139,12805139,12805140,12805141,12805141,12805142,12805143,12805143,12805144,12805144,12805145,12805146,12805146,12805198,12805198,12805201,12805204,12805204,12805205,12805206,12952274,12991214,13424492,13592172,13653789,13711244,13855029,14045726,14449841,14691644,14691645,14691645,14691646,14691646,14691647,15347488,15524609,16034479,16034483,16034484,16780269,16780270,19633733,19633734,20040612,12059213,12151111,12173819,12173821,12173824,12173824,12301194,12379926,12382592,12444086,12776828,12776831,12805127,12805134,12805134,12805135,12805135,12805136,12805138,12805139,12805140,12805141,12805142,12805143,12805143,12805144,12805144,12805145,12805146,12805147,12805149,12805198,12805199,12805204,12805206,12805207,12936860,14045727,14572857,14691644,14691646,14691647,14691647,14691648,15347489,16034474,12059214,12173821,12805133,12805135,12805142,12805147,14691647,14691648,16034478,16034485,16780271,12301193,12805135,12805148,13759375,12088804,13726046,12095679,12823403,12106673,12106769,12106864,12197652,12216161,12883682,12238789,12238791,12238791,12894930,12894992,12895002,12243025,12243026,12243029,12243030,12897046,12897049,12897053,12897054,12288440,12288428,12288441,12288443,12288431,12288442,12288442,12288444,12288445,12288443,12288444,12288443,12288445,12288446,12288447,12288447,12288450,12288455,12919763,12288457,12415816,12919756,12919756,12919757,12919765,12919829,13665714,19748355,12607306,12919756,12919756,12919757,12919758,12919758,12919759,12919769,12919770,12919828,13195160,13969650,14160351,12919832,12919759,12378623,12378624,12964845,12964846,12473918,15554849,12487300,12631156,12543187,12543189,12543190,12543190,13047129,13047129,13047130,13047133,13047137,13047139,13047139,13817721,13953237,12687983,12688116,12688249,13119658,12689986,13120538,12693539,13122304,12700651,12700652,12700653,12700654,13125860,13125863,13125871,15012372,12705980,12706041,12706102,13128585,12711580,13131356,12775010,13163052,12828976,15076535,12835770,13193421,12890104,12890321,12890538,13220802,12926182,12926199,13238648,13238659,12976285,12976375,12976465,13263771,13494455,13494458,13494464,13494464,13798166,15409277,13522773,13522774,13544375,13547722,13551050,13551058,13551062,13551052,13551052,13551063,13551075,13551055,13551056,13551058,13551062,13551066,13551072,13551072,13551076,13551055,13551055,13551056,13551057,13551067,13551069,13551069,13551071,13551071,13551055,13551056,13551056,13551057,13551058,13551072,13551073,13551073,13551056,13551057,13551057,13551058,13551058,13551059,13551061,13551061,13551062,13551062,13551063,13551063,13551064,13551065,13551067,13551067,13551068,13551068,13551069,13551071,13551071,13551072,13551072,13551073,13551073,13551077,13551057,13551058,13551058,13551059,13551060,13551060,13551061,13551061,13551062,13551062,13551063,13551064,13551064,13551065,13551065,13551066,13551067,13551068,13551069,13551069,13551070,13551071,13551072,13551072,13551073,13551074,13551075,13551058,13551059,13551060,13551060,13551061,13551061,13551062,13551062,13551063,13551063,13551064,13551065,13551065,13551066,13551066,13551067,13551067,13551068,13551069,13551071,13551072,13551073,13551073,13551074,13551074,13551075,13551076,13551077,13551078,13551078,13551083,13551059,13551062,13551062,13551063,13551064,13551069,13551070,13551073,13551075,13551061,13551061,13551062,13551063,13551064,13551064,13551065,13551066,13551067,13551068,13551073,13551063,13551065,13551074,13551063,13551063,13551064,13551065,13551066,13551068,13551069,13551071,13551085,13551063,13551064,13551064,13551065,13551066,13551066,13551067,13551064,13551065,13551065,13551066,13551066,13551067,13551067,13551068,13551068,13551069,13551087,13551065,13551066,13551066,13551067,13551067,13551068,13551069,13551070,13551072,13551076,13551081,13551087,13551066,13551067,13551067,13551068,13551068,13551069,13551069,13551073,13551085,13551088,13551088,13551067,13551068,13551068,13551069,13551069,13551070,13551073,13551068,13551069,13551069,13551070,13551070,13551071,13551071,13551074,13551078,13551069,13551070,13551070,13551071,13551071,13551074,13551078,13551079,13551080,13551070,13551071,13551071,13551072,13551072,13551073,13551079,13551080,13551090,13551091,13551071,13551072,13551072,13551073,13551073,13551074,13551074,13551075,13551075,13551076,13551079,13551079,13551089,13551090,13551091,13551072,13551073,13551073,13551074,13551074,13551075,13551076,13551076,13551079,13551080,13551083,13551085,13551085,13551088,13551089,13551091,13551073,13551074,13551074,13551075,13551075,13551076,13551076,13551077,13551077,13551080,13551080,13551084,13551086,13551092,13551074,13551075,13551075,13551076,13551076,13551077,13551077,13551079,13551081,13551081,13551082,13551082,13551085,13551086,13551092,13551093,13551075,13551076,13551076,13551077,13551078,13551078,13551081,13551081,13551084,13551092,13551093,13551076,13551077,13551077,13551078,13551078,13551080,13551082,13551082,13551086,13551093,13551093,13551077,13551078,13551078,13551079,13551079,13551082,13551082,13551083,13551083,13551084,13551085,13551093,13551094,13551094,13551078,13551079,13551079,13551080,13551083,13551084,13551085,13551088,13551094,13551094,13551095,13551079,13551080,13551080,13551081,13551082,13551082,13551083,13551084,13551086,13551086,13551087,13551088,13551094,13551095,13551080,13551081,13551081,13551083,13551084,13551084,13551085,13551085,13551087,13551089,13551089,13551094,13551095,13551095,13551096,13551081,13551083,13551083,13551084,13551084,13551085,13551085,13551086,13551086,13551087,13551087,13551088,13551095,13551096,13551096,13551082,13551084,13551085,13551085,13551086,13551087,13551088,13551089,13551091,13551094,13551096,13551096,13551097,13551083,13551085,13551086,13551087,13551096,13551097,13551084,13551086,13551097,15437582,13551085,13551086,13551086,13551088,13551098,18138471,13551086,13551087,13551088,13551094,13551098,13551098,15437583,13551087,13551088,13551088,13551090,13551090,13551091,13551091,13551093,13551098,13551099,13551099,13875893,15437583,15437584,16270547,17526204,13551088,13551089,13551089,13551090,13551090,13551091,13551093,13551093,13551094,13551095,13551097,13551097,13551099,13551099,13551100,13551136,13551141,13551143,14078893,14321663,14600966,15437584,15437584,16093426,13551089,13551090,13551093,13551093,13551099,13551100,13551100,13551136,13551136,13551142,14457180,14600965,14982266,16093427,16270547,13551090,13551093,13551094,13551094,13551100,13551100,13551101,13551137,13551137,14338110,14496730,15437584,15437585,16780421,13551091,13551092,13551092,13551093,13551100,13551101,13551101,13551137,13551138,13551147,13551150,14457181,15437586,15437586,16780417,13551093,13551101,13551146,15037268,13551095,13551101,13551102,13551102,15437587,20096650,13551095,13551096,13551100,13551102,13551102,13551142,13551095,13551101,13551102,13551139,13551103,13551103,13551104,13551097,13551103,13551104,15437587,15437589,13551104,13551104,13551105,13551141,13551141,13551100,13551104,13551141,15437589,16780417,13551105,13551105,13551104,13551106,13551106,13551107,13551108,13551108,13551109,13551154,13551160,13551109,13551110,27757271,13551109,13551110,13551111,13551114,13551147,13551149,13551150,13551151,13551153,13551155,13551156,14464328,15437593,13551111,13551145,13551147,13551148,13551149,13551150,13551150,13551151,13551151,13551152,13551152,13551153,13551154,13551154,13551155,13551155,13551156,13551156,13551157,13551157,13826486,14001447,14190919,14321679,14457192,14600977,14600978,14791674,15318805,15437594,15437594,15437595,15437596,15437596,16270558,16270562,16270566,16780433,20265206,13551146,13551146,13551147,13551147,13551148,13551148,13551149,13551150,13551150,13551151,13551151,13551152,13551152,13551153,13551153,13551154,13551154,13551155,13551155,13551156,13551156,13551157,13551157,14190919,14217139,14338123,14505324,14600974,14600977,14600979,14791677,14963525,15437594,15437595,15437595,15437596,15437596,15437597,16780434,17526220,13551157,13551182,13551184,13551182,13551201,13551183,13551189,13551183,13551184,13551185,13551186,13551190,13551193,13551198,13551200,13551184,13551185,13551186,13551187,13551187,13551188,13551188,13551189,13551189,13551190,13551191,13551191,13551192,13551192,13551193,13551196,13551199,13551199,13551200,13551200,13551202,13551185,13551186,13551186,13551187,13551187,13551188,13551188,13551189,13551190,13551191,13551191,13551192,13551193,13551194,13551196,13551200,13551200,13551201,13551201,13551202,13551202,13551205,13551187,13551187,13551188,13551189,13551189,13551188,13551189,13551189,13551190,13551190,13551191,13551192,13551210,13551211,13551189,13551190,13551190,13551191,13551191,13551192,13551193,13551195,13551210,13551190,13551191,13551191,13551192,13551194,13551195,13551204,13551207,13551211,13551211,13551191,13551192,13551192,13551193,13551193,13551194,13551196,13551204,13551211,13551212,13551212,13551192,13551193,13551193,13551194,13551195,13551195,13551197,13551197,13551203,13551205,13551212,13551212,13551193,13551194,13551194,13551195,13551195,13551196,13551196,13551197,13551198,13551204,13551207,13551212,13551213,13551194,13551195,13551195,13551196,13551197,13551197,13551198,13551213,13551213,13551214,13551195,13551196,13551196,13551197,13551197,13551198,13551198,13551213,13551214,13551196,13551197,13551197,13551198,13551198,13551199,13551199,13551200,13551205,13551206,13551206,13551207,13551210,13551214,13551214,13551197,13551198,13551198,13551199,13551200,13551200,13551202,13551203,13551206,13551206,13551214,13551215,13551215,13551198,13551199,13551199,13551200,13551200,13551201,13551201,13551207,13551208,13551209,13551215,13551215,13551216,13551199,13551200,13551200,13551201,13551205,13551207,13551215,13551216,13551216,13551200,13551201,13551201,13551202,13551207,13551208,13551208,13551216,13551216,13551217,13551201,13551202,13551202,13551208,13551209,13551210,13551216,13551217,13551202,13551203,13551204,13551204,13551205,13551205,13551208,13551208,13551209,13551209,13551210,13551211,13551212,13551213,13551216,13551217,13551217,13551218,13551203,13551204,13551204,13551205,13551208,13551208,13551209,13551210,13551210,13551211,13551211,13551212,13551217,13551218,13551218,13551205,13551206,13551209,13551209,13551210,13551210,13551211,13551212,13551217,13551218,13551218,13551219,13551210,13551218,13551206,13551219,13551219,13551207,13551209,13551211,13551212,13551219,13551220,13551208,13551213,13551220,13551213,13551221,13551221,13551213,13551215,13551223,14321727,13551223,13551223,13551224,15437645,15437648,13551217,13551217,13551223,13551224,14321726,15318855,15437646,16093490,16270610,13551216,13551217,13551217,13551224,13551224,15437647,15437649,16780485,13551217,13551219,13551224,13551225,13551225,14190972,14321724,14601029,14601030,14791729,15437648,15437649,16270612,16270615,16780484,16780486,13551218,13551219,13551224,13551225,13551225,13551226,15437649,15437649,16270611,13551220,13551220,13551225,13551226,15291766,15437650,13551220,13551226,13551226,13826541,16093492,16093494,13551226,13551226,13551227,15437650,13551227,13551227,15437649,13551228,13551228,13826543,13551231,13551231,13551232,13551233,13655675,14321736,14321738,14338182,14457253,14464388,14505384,14601039,14859834,14963584,15211234,15318866,15437656,15437657,16093498,16093499,16270619,13551233,13655670,13655676,13991965,14297100,14321736,14321737,14321737,14321741,14338183,14399801,14457254,14505385,14601037,14601038,14601038,14601039,14601040,14791736,14791737,14963585,15027884,15082722,15218517,15218518,15225641,15241748,15318866,15437654,15437654,15437655,15437655,15437656,15437657,15437657,16077916,16077917,16093499,16120921,16270619,16617961,16780484,16780494,16780495,17526279,20011089,20411849,13551235,13655669,13655671,13655676,13682870,13743718,13932316,13986787,14190981,14264214,14297101,14297102,14297103,14297106,14321734,14321736,14321737,14321738,14338184,14338185,14399801,14457248,14457252,14457253,14457253,14457254,14457255,14464388,14505384,14601037,14601038,14601038,14601039,14601040,14601040,14738717,14791735,14791736,14791738,14791738,14812695,14933014,14963585,15027885,15117157,15201276,15211238,15318868,15437654,15437655,15437655,15437656,15437656,15437657,15437657,15437658,15437659,15527039,16077917,16093498,16093499,16270620,16270621,16270622,16270623,16780484,16780491,16780493,17497389,20096720,20096721,13826549,13760122,13760125,13760129,13760134,13760134,13760134,16182371,15542112,15542115,15315696,15542116,16197957,13814508,13814519,13814522,13814521,13814520,13814533,15569304,14453390,16402270,15569309,13845347,16927556,13923232,15623663,15623664,13936217,15630156,14101863,14101874,14101875,14101877,14101875,14101876,15712985,14101889,14780712,14876367,15712984,14876366,15712985,14200709,15762403,14313408,14313559,14313710,14982281,14422359,15873229,14432756,14432832,14432907,15878520,14451796,16532710,14606709,17069296,14789784,16056939,14830740,14830740,14830739,14830741,16130300,16077415,15958626,16077417,16077417,14883180,16107152,14977209,16150651,15042983,15042983,15042987,15042974,15042988,15042988,15042988,15042993,15067621,16183540,15043004,15251267,15709470,15084068,15067623,15175604,17526371,15092251,15092252,15092254,15092254,15092255,15092241,15092255,15092253,15092256,15092243,15092256,15092257,15092258,15092259,15092260,15092266,16208172,15371556,15108703,15170320,15275902,15371556,15371557,15562257,15752858,16089386,16208174,16208175,16208176,16208176,17357216,17551003,17551013,15124795,15124973,15125147,15125148,15125147,15125147,15125148,15125151,15125151,15244217,15292348,15388001,15388003,15750550,16224621,16224621,17057584,16224622,15248382,15248383,15248384,15312970,16167450,16286239,17629071,15308216,15479535,15363282,15363272,15363286,15363287,15363284,15363287,15363288,15363287,15363288,15363289,15363276,15363289,15363289,15363290,15744804,16117268,15363302,15697772,15697772,16343691,16343691,15411418,15507072,15697772,16224900,16289694,16343690,16343691,16343692,16343692,15377557,15377558,15377559,15377560,16350827,16350827,16350828,15442380,16383235,15459414,15459483,15459547,15459548,15459547,15459547,15459550,15459549,15459548,15459550,15459552,15459552,16391819,17224783,18480440,15679532,16391820,17734660,15555204,16391822,17224789,15555204,15650854,15650853,15650855,15650856,15650854,15650842,15650843,15650844,15650855,15650856,15650857,15650843,15650858,15650859,15650845,15650856,15650858,15650859,15650848,15650859,15650860,15650861,15650861,15650860,15650862,15650863,16487473,16487475,16487474,16487475,16789757,16487475,16487476,17320438,15650872,15650873,15775187,15882667,16368684,16487475,16487475,16487476,16487477,15650875,15841557,16368685,16487475,16487475,16487476,16487477,16487477,16487477,15650875,15650876,16487478,15650876,16368688,16487478,16487480,17320441,15788538,15841558,16487477,16487478,16487479,15899514,15899515,15912865,16611803,15926213,15926214,15926216,16151082,16215382,16625154,16032252,16032253,16032253,16032253,16032254,16032254,16032254,16032255,16032255,16032256,16204102,16357673,16678172,16678174,16678174,18021008,18021011,16204102,16678174,16678174,16678175,16678173,16204103,16074168,16699130,16114468,16114544,16114619,16600563,16126325,16725210,16168451,16746272,16314810,16819452,16375949,16375950,16375951,16375951,16375952,16375953,16375953,16375957,16630883,16850021,16850022,16850023,16850023,18938646,16850022,16850023,16850024,16850023,16850024,18192851,16850023,16850025,16850025,16850026,16850028,16413465,16413462,16868779,16868783,16504547,16702304,16914318,16914319,16523455,16923774,16614212,16614252,16969185,16683089,16683092,16683192,17003592,16683295,17003693,16840482,17082287,16851333,17743557,16871247,16871248,16871251,16871252,16871337,16871338,16871341,16871342,16871429,16871431,16871432,17097760,17097761,17930725,17097763,16885813,16885814,17104951,17104952,16900062,17112077,17112078,16932276,16932352,16932427,17961223,17032360,17032427,17032471,17178288,17086513,17086513,17086515,17086514,17086515,17086515,17086516,17086516,17086517,17086519,17205303,17205304,17205304,18038268,17205304,17205305,17205303,17205306,19293928,17205306,17216156,17270154,17324091,17324075,17324076,17324077,17324078,17324079,17324091,17324092,17324077,17324078,17324078,17324079,17324079,17324092,17324092,17324078,17324079,17324079,17324080,17324083,17324091,17324092,17324093,17324093,17324095,17324096,17324079,17324080,17324080,17324083,17324093,17324094,17324094,17324095,17324097,17324080,17324081,17324095,17324095,17324096,17324097,17324098,17324081,17324082,17324083,17324083,17324084,17324084,17324085,17324092,17324095,17324095,17324096,17324096,17324097,17324098,17324082,17324083,17324083,17324084,17324084,17324085,17324085,17324092,17324093,17324093,17324094,17324094,17324095,17324095,17324096,17324096,17324097,17324097,17324098,17324098,17324099,17324099,17324100,17324100,17324083,17324084,17324084,17324085,17324093,17324096,17324096,17324097,17324098,17324099,17324100,17324084,17324085,17324085,17324086,17324097,17324097,17324099,17324099,17324101,17324085,17324086,17324097,17324098,17324099,17324100,17324101,17324101,17324086,17324087,17324094,17324095,17324096,17324100,17324100,17324101,17324087,17324090,17324097,17324098,17324098,17324100,17324101,17324090,17324095,17324096,17324098,17324099,17324099,17324100,17324101,17324101,17324096,17324100,17324101,17324102,17324100,17324104,17324108,17324109,17324109,17324109,17324111,17324106,17324106,17324109,17324107,17324108,17324109,17324110,17324108,17324109,17324110,17324111,17964355,17979936,18666932,17324109,17324110,17324111,17324111,17964355,17979938,18157056,18666921,17324109,17324110,17324111,17324111,17324112,17644413,17964355,17979937,17979937,18157057,18157060,18473135,18666930,19147690,19412713,17324111,17324111,17324112,17324112,17830359,17979937,17979938,18157058,18157062,18504399,17324111,17324112,17324112,17324113,17324114,17979938,17979938,18157058,18157058,19412719,17324112,17324113,17324113,17964357,17979937,17979938,19412720,17324113,17324114,17979939,17324114,17324115,17324116,17324116,17376981,17830361,17979937,17979939,17979940,17979941,18157059,18157060,18666924,18666934,17324115,17324116,17324116,17324117,17324117,17355120,17384062,17413480,17532256,17734017,17745093,17784022,17784023,17807889,17814429,17830361,17903911,17903912,17936959,17964358,17964359,17965162,17979938,17979939,17979939,17979940,17979940,17979941,17979942,18007362,18157058,18157059,18157059,18157060,18157060,18157061,18157062,18157063,18157064,18157065,18157066,18157066,18157067,18157068,18157069,18315553,18472027,18473138,18666923,18666924,18666925,18666926,18666928,18666928,18666930,18666930,18666931,18666931,18666932,18666933,18666934,18666935,18666935,18666936,18666936,18666937,19119529,19147693,19412716,19412716,19412717,19412719,19412720,19412721,19412721,19895891,20462740,20863052,22266185,22266185,17324116,17324117,17964357,17964358,17964359,17979940,17979942,18157063,17324117,17324118,17454377,17475598,17626381,17964360,17979940,17979941,17979941,17979943,18157061,18157061,18157062,18157065,18666923,18666930,18666934,18666935,18666936,18666936,18666937,19412720,19412721,21983162,22151709,17324118,17376983,17573042,17626381,17644418,17807890,17903912,17936962,17964355,17964360,17979941,17979941,17979942,17979943,17979943,18157061,18157061,18157062,18157067,18270776,18666933,18666934,18666936,18666936,18666937,19412719,19412721,19412722,21983163,17461920,17645523,17734019,17903913,17964358,17964360,17964361,17979939,17979942,17979943,17979944,18157060,18157062,18157063,18666926,18666927,18666932,18666932,18666935,18666937,18666937,19412720,19412721,21609855,17663387,17331117,17331183,17331250,18670506,17386136,18010958,17429858,17956787,18209936,19465597,17444026,18726899,17502858,18053734,18246439,17584650,18110214,17599747,18117768,17627092,18131435,17740407,17992174,17822029,18915921,17928657,17928657,18282217,18969212,19714999,17964730,17964731,18300253,18477385,17966943,18988357,18002668,18496343,18143932,18143932,18389855,18566975,18166089,19087931,18243942,18243943,18428783,18616981,18616987,18291675,18291676,19150719,18640847,18304760,18647392,18336623,18336623,18336624,18663322,18410173,18470615,18483719,18483721,18483722,18483719,18483722,18483856,18483855,18483736,18736870,19992527,18559751,18736871,18736875,18483990,18483991,18559883,18737004,18549818,18549820,18577218,18592799,18604610,18604613,18604600,18604615,18604613,18604614,18604614,18604615,18604615,18604618,18604618,18620196,18797316,18797317,18797321,18797322,19113391,19307181,19307193,19759786,18620201,18620199,18797319,18797319,19307194,18606244,18621022,18613622,18801826,19311684,18635762,18635776,18635763,18635778,18635780,18635764,18635778,18635780,18635764,18635766,18635779,18635780,18635765,18635766,18635767,18635778,18635780,18635780,18635781,18635781,18635782,18635782,18635783,18635783,18635766,18635780,18635780,18635781,18635782,18635782,18635783,18635783,18635782,18635783,18635768,18635781,18635784,18635785,18635782,18635782,18635783,18635783,18635784,18635784,18635785,18635785,18635786,18812899,18812904,18635795,18635797,18812905,19322764,18635795,18635796,18635797,18635797,18812900,18812900,18812901,18812904,19128978,19322766,19322772,19322774,19322774,19322775,19322776,20068561,18635796,18635797,18635798,18812900,18812901,19322765,19322765,19322772,18635797,18635798,18812901,18812902,18812903,18812907,19322766,19322776,20068558,18635798,18635799,18812902,18812902,18812907,18812909,19160243,19322771,19322771,19322772,19322774,19322775,19322776,19322777,19322777,20068562,18635799,18635800,18812902,18812904,18812904,18812907,18812908,19322776,19322777,19322777,19803535,20068563,22639003,18635800,18635801,18635801,18812902,18812902,18812903,18812903,18812904,18812904,18812905,18812906,18812907,18812907,18812908,18812908,18812909,18812910,19127678,19265816,19322767,19322768,19322770,19322772,19322773,19322773,19322775,19322777,19322777,19322778,19322778,19322779,20068563,20068564,20068564,21528671,22922027,18812903,18812904,19322767,19322778,20068561,18812908,18812910,19322779,20068559,19322777,20068565,18690620,18690648,18690654,19293231,19350189,19350212,18840357,18990003,18990020,18990004,18990005,18990006,18990023,18990005,18990006,18990010,18990010,18990011,18990020,18990020,18990021,18990022,18990006,18990007,18990007,18990008,18990009,18990010,18990010,18990011,18990011,18990012,18990013,18990014,18990017,18990020,18990020,18990021,18990021,18990022,18990022,18990023,18990023,18990024,18990025,18990026,18990008,18990010,18990010,18990011,18990011,18990012,18990012,18990013,18990014,18990021,18990022,18990022,18990024,18990009,18990010,18990013,18990021,18990022,18990029,18990009,18990010,18990010,18990014,18990015,18990021,18990024,18990030,18990030,18990010,18990011,18990012,18990014,18990031,18990011,18990012,18990013,18990014,18990015,18990023,18990031,18990023,18990024,18990032,18990013,18990014,18990014,18990015,18990016,18990025,18990025,18990032,18990014,18990015,18990015,18990016,18990025,18990025,18990027,18990033,18990015,18990016,18990016,18990017,18990017,18990025,18990033,18990017,18990019,18990027,18990027,18990034,18990034,18990017,18990018,18990019,18990019,18990026,18990027,18990028,18990034,18990035,18990018,18990019,18990019,18990020,18990020,18990021,18990027,18990028,18990029,18990035,18990036,18990019,18990020,18990020,18990021,18990027,18990028,18990029,18990035,18990036,18990020,18990021,18990029,18990036,18990021,18990022,18990028,18990029,18990036,18990022,18990029,18990030,18990031,18990032,18990033,18990033,18990034,18990037,18990029,18990030,18990030,18990037,18990038,18990038,18990041,18990033,18990035,18990042,18990043,18990035,18990036,18990043,19499890,19499893,18990036,18990037,18990037,18990041,18990044,19306098,19499885,19499885,19499886,19499893,19499894,19499895,19499896,19980654,20245677,20245680,20245681,20245681,20245682,22816120,22984668,18990037,18990038,18990039,18990044,19306099,19337365,19488638,19499885,19499886,19499891,19499892,19499893,19499893,19499894,19499895,19499896,19499896,19980654,20245676,20245677,20245681,20245682,23099146,18990038,18990039,18990040,18990040,18990041,18990043,18990045,18990046,18994465,19304775,19337363,19337363,19499886,19499888,19499888,19499892,19499893,19499894,19499894,19499896,19499896,19499897,19499897,20245677,20245681,20245682,20245682,22816123,18990045,19499887,19499895,19499897,19499897,18990040,18990045,18990046,19442936,19499887,19499891,20245683,18990043,18990045,18990046,18990047,19148518,19337364,19499888,19499898,19952493,20245684,23099148,18990047,18990048,19499888,19499898,19499895,19499898,18990048,19499889,19499889,19499897,18990048,19499900,18990049,19499895,19499901,19499897,20245683,18990051,19499893,19499903,19499904,18990052,18990053,18990053,18990054,19262518,19337370,19337371,19337373,19352844,19499892,19499893,19499893,19499894,19499895,19499896,19499899,19499900,19499901,19499902,19499903,19499903,19499904,19499904,19952498,20004134,20245684,20245685,20245685,20245686,20245688,22816130,18990053,18990054,19337370,19499894,19499899,19499901,19499903,19499904,18990054,18990055,19148524,19337371,19499894,19499901,19499902,19499903,19499903,20245684,20245686,19120433,19337372,19385631,19499895,19499900,19499903,19337372,19499895,19499897,19499905,18998932,19504357,19063899,20282621,19217477,19613638,19250823,19630290,19307006,19307007,19307007,19658377,19658377,19658387,19531882,19531892,23370074,19534996,20518163,19619586,19619608,19619753,19619919,19619967,19814874,20560656,19622168,19622174,19622174,19622175,19622175,19622176,19815969,19815970,19815971,19622189,19815972,19815966,19815971,19815969,20296731,19815972,19684703,19684704,19684704,19684703,19684704,19684707,19684708,19847226,19847226,19847230,19847235,20593021,23163462,19847227,19847227,19847235,19847236,19847239,19715649,19862707,19781234,19895498,19895843,19895844,20698589,19952804,23552056,19987251,19998509,20009756,20009748,20009734,20009734,20009739,20009742,20009744,20009745,20009735,20009736,20009737,20009737,20009738,20009739,20009740,20009740,20009741,20009741,20009742,20009742,20009743,20009743,20009744,20009744,20009745,20009745,20009746,20009746,20009752,20009754,20009756,20009759,20009761,20009736,20009741,20009745,20009747,20009754,20009738,20009738,20009739,20009739,20009740,20009740,20009741,20009741,20009742,20009742,20009743,20009743,20009744,20009744,20009745,20009746,20009750,20009752,20009756,20009745,20009746,20009763,20009742,20009743,20009762,20009743,20009744,20009745,20009746,20009742,20009743,20009743,20009743,20009744,20009744,20009746,20009746,20009748,20009746,20009748,20009749,20009749,20009744,20009746,20009747,20009747,20009749,20009749,20009764,20009765,20009745,20009746,20009746,20009747,20009747,20009748,20009750,20009750,20009754,20009755,20009765,20009766,20009746,20009747,20009747,20009748,20009748,20009749,20009750,20009751,20009751,20009760,20009761,20009765,20009766,20009747,20009748,20009748,20009749,20009749,20009750,20009751,20009752,20009766,20009766,20009767,20009748,20009749,20009749,20009750,20009750,20009751,20009751,20009752,20009752,20009766,20009767,20009749,20009750,20009750,20009751,20009751,20009752,20009752,20009760,20009762,20009767,20009750,20009751,20009751,20009752,20009752,20009753,20009754,20009760,20009762,20009766,20009767,20009768,20009768,20009751,20009752,20009752,20009753,20009753,20009754,20009760,20009762,20009767,20009768,20009768,20009769,20009769,20009752,20009753,20009753,20009754,20009754,20009755,20009759,20009763,20009764,20009769,20009753,20009754,20009754,20009755,20009758,20009759,20009760,20009761,20009762,20009762,20009763,20009764,20009769,20009769,20009770,20009770,20009754,20009755,20009755,20009757,20009760,20009761,20009761,20009764,20009765,20009769,20009770,20009770,20009771,20009755,20009756,20009756,20009757,20009757,20009759,20009760,20009760,20009761,20009762,20009762,20009763,20009763,20009764,20009765,20009765,20009769,20009769,20009770,20009770,20009771,20009771,20009772,20009756,20009757,20009758,20009760,20009761,20009761,20009762,20009762,20009763,20009764,20009764,20009765,20009765,20009766,20009768,20009770,20009770,20009771,20009771,20009772,20009772,20009757,20009759,20009761,20009761,20009762,20009763,20009763,20009764,20009764,20009765,20009766,20009767,20009768,20009771,20009771,20009772,20009772,20009773,20009759,20009761,20009762,20009763,20009764,20009766,20009770,20009771,20009772,20009772,20009773,20009773,20009774,20009763,20009772,20009773,20009774,20009763,20009767,20009773,20009772,20009773,20009774,20009774,20009769,20009775,20009775,20462354,20009765,20009767,20009769,20009770,20009771,20009775,20009776,20009767,20009767,20009768,20009768,20009769,20009770,20009771,20009776,20009767,20009768,20009770,20009771,20009773,20009776,20009769,20009769,20009770,20009771,20009772,20009774,20009777,20009769,20009771,20009771,20009772,20009774,20009777,20009777,20009770,20009771,20009772,20009773,20009774,20009775,20009776,20009771,20009772,20009772,20009773,20009774,20009777,20009778,20009772,20009773,20009774,20009774,20009775,20009776,20009778,20009780,20009780,20009773,20009774,20009774,20009775,20009776,20009776,20009778,20009778,20009779,21010986,20009774,20009775,20009775,20009776,20009776,20009777,20009777,20009778,20726658,21779540,20009775,20009776,20009776,20009777,20009777,20009778,20009778,20009779,20009779,20009780,20009780,20009781,20009776,20009777,20009777,20009778,20009779,20009780,20009780,20009781,20009781,20009777,20009778,20009778,20009779,20009780,20009780,20009781,20009782,20009778,20009779,20009779,20009780,20009780,20009781,20009782,20503430,20009779,20009780,20009780,20009781,20009781,20009782,20009780,20009781,20009782,20009782,20009783,20009783,20009781,20009782,20009782,20009783,20009783,20009784,20009782,20009783,20009783,20009784,20755548,20009783,20009784,20009784,20009785,20009785,20755549,20755555,20009784,20009785,20009785,20009785,20009786,20009786,20755550,20755550,20755554,20755555,20755556,21746365,23325997,20009786,20009787,20009787,20009788,20009788,20009826,20016967,20134213,20137907,20195565,20276619,20355391,20426843,20428227,20442453,20462365,20490529,20490531,20503435,20503456,20527259,20726664,20726665,20726666,20755549,20755550,20755550,20755551,20755551,20755552,20755553,20755553,20755554,20755554,20755555,20755555,20755556,20755556,20755557,20755557,21746367,22215664,22215666,23023434,23325996,23494543,23609020,23609021,23609021,23641104,20009787,20009788,20009788,20009789,20009791,20014667,20019003,20021593,20053972,20083342,20134214,20134853,20392612,20426842,20428227,20428227,20462365,20462365,20462366,20490527,20490529,20490530,20527259,20693706,20695284,20721666,20726365,20726664,20726665,20726666,20726666,20727454,20755551,20755551,20755552,20755552,20755553,20755554,20755555,20755555,20755556,20755556,20755557,20755557,20755558,21746367,22652283,23494544,23609019,23609020,23609021,23609021,23609022,30986611,20009788,20009789,20009830,20019004,20355392,20462364,20462365,20462366,20462367,20490530,20695479,20727455,20755551,20755552,20755553,20755553,20755554,20755555,20755555,20755556,20755556,20755557,20755557,20755558,20755559,21679659,21746367,22796330,23325996,23609021,20428228,20462366,20490530,20503458,20727455,20755552,20755552,20755553,20755553,20755555,20755555,20755556,20755556,20755557,20755558,20755558,23325998,23609022,20009790,20009876,20276624,20755557,20755558,20462367,20755553,20755555,20755559,20755555,20009877,20009885,20755606,20490585,20009971,20755652,20019567,20760451,20024171,20734658,20028243,20028259,20028303,20471622,20764812,20764829,20033415,20767380,20098168,20098237,20098308,20799818,20156911,20829121,20258653,20258654,20552667,20879990,20259933,20880630,20266049,20590507,20381364,20381370,20381439,20381446,20381509,20381517,20941424,20941433,20543468,20543471,21022399,21022401,20701024,20701072,21101188,20701181,20701290,21101347,20775449,21138388,20843909,20843911,20843913,21172619,21172620,21172623,20846677,20846679,20846680,20846680,20846758,20908983,21174003,21145118,21174004,20846839,23744528,20875139,21159351,20914952,20914958,20914958,20914960,20914959,20914959,20914960,20914962,20914960,20914960,20914961,20914961,20956045,20943123,20956050,21148072,21208148,21208148,21208149,21208149,21208152,20943123,21208145,21208145,21208146,21208147,21208150,21208150,21208151,23692959,20943126,21208145,21208151,21179261,21208146,20943125,20971283,20971286,20971283,20971284,20971284,20971285,20971285,20971287,20971288,20971288,20971288,20971288,21236307,22160413,21207420,21236311,21236312,23806753,21236311,21207421,21236311,21236312,21236309,21236312,22696421,21236311,21236313,20984214,21236313,21236314,21236314,21236314,21236314,20997093,20997094,20997115,20997117,20997137,20997138,20997139,20997141,20997139,21249237,21249234,21220347,21249234,21249233,21249233,21249235,21249239,21018229,21259782,21044791,21044792,21044862,21044863,21044938,21273165,21273165,21377637,21439488,21380793,21441061,21381180,21441255,21441258,21433574,21467461,21442956,21472147,21443557,21443557,21443558,21443558,21443559,21443558,21443558,21443560,21443560,21443563,21443561,21443562,21472443,21472443,22396553,21472444,21472444,21443576,21472444,21472445,21472445,21472446,21472447,21472448,21472451,21472445,21472451,21472446,21472452,21472453,21445132,21445156,21445166,21445201,21445204,21445200,21445245,21445268,21473294,21445321,21445354,21473342,21473343,21445448,21473391,21501315,21501314,21501315,21501316,21501315,21501316,21501316,21501317,21501317,21501318,21501318,21501319,21501320,21501330,21501316,21501317,21501317,21501318,21501318,21501319,21501319,21501320,21501317,21501318,21501318,21501319,21501319,21501320,21501320,21501321,21501322,21501322,21501323,21501318,21501319,21501319,21501320,21501320,21501321,21501321,21501322,21501322,21501323,21501319,21501320,21501320,21501321,21501321,21501322,21501322,21501323,21501323,21501338,21501338,21501320,21501321,21501321,21501322,21501322,21501323,21501323,21501321,21501322,21501322,21501323,21501324,21501339,21501339,21501322,21501323,21501323,21501324,21501324,21501325,21501339,21501323,21501324,21501324,21501325,21501325,21501326,21501337,21501340,21501324,21501325,21501325,21501326,21501335,21501337,21501339,21501340,21501341,21501341,21501325,21501326,21501326,21501327,21501335,21501335,21501338,21501338,21501341,21501341,21501342,21501326,21501327,21501327,21501328,21501336,21501336,21501338,21501339,21501341,21501341,21501342,21501342,21501343,21501327,21501328,21501328,21501329,21501330,21501336,21501336,21501337,21501337,21501338,21501338,21501339,21501340,21501341,21501342,21501342,21501343,21501343,21501328,21501329,21501329,21501330,21501335,21501336,21501337,21501337,21501338,21501338,21501339,21501339,21501340,21501340,21501341,21501341,21501342,21501342,21501343,21501343,21501344,21501329,21501330,21501330,21501337,21501337,21501338,21501338,21501339,21501339,21501340,21501340,21501341,21501341,21501342,21501342,21501343,21501343,21501344,21501344,21501345,21501338,21501339,21501340,21501340,21501343,21501344,21501346,21501332,21501340,21501342,21501342,21501343,21501344,21501344,21501345,21501346,21501332,21501340,21501344,21501344,21501345,21501345,21501345,21501343,21501345,21501346,21501347,21501348,21501349,21501346,21501347,21501347,21501348,21501348,21501349,21501349,21501351,21501352,24071776,21501347,21501348,21501348,21501349,21501349,21501350,21501350,21501352,21501348,21501349,21501349,21501350,21501350,21501351,21501352,21501349,21501350,21501350,21501351,21501352,21501353,21501353,21501350,21501351,21501351,21501352,21501352,21501353,21501353,21501354,21501354,21501351,21501352,21501352,21501353,21501353,21501354,21501354,21501352,21501353,21501353,21501354,21501354,21501355,21501353,21501354,21501354,21501355,21501355,21501354,21501355,21501355,21501356,21501355,21501356,21501356,21501357,21501356,21501357,21501357,21501358,21501357,21501358,21501358,21984494,21984497,22094804,22099292,22492151,22525331,22961450,23888654,23986151,24071781,24071782,24354806,24354806,31732396,21501358,21501359,21501359,21501360,21529937,21569556,21592474,21592475,21592476,21713847,21743837,21743838,21756778,21756779,21890805,21893111,21915019,21943181,21958377,21984485,21984497,21984503,21984503,21984504,21984505,21984506,21984508,21984509,21984509,21984512,22113607,22170956,22385149,22425444,22425446,22492151,22492154,22551359,22681170,22760316,22832681,22961450,22961450,22961452,22981285,23040045,23111498,23760869,23769220,23769817,24043259,24043261,24043262,24043263,24071779,24071781,24071781,24071782,24071782,24071783,24240329,24240488,24354805,24354806,24354806,24354807,24354807,24386913,24386914,31732396,21501359,21501360,21501360,21501361,21501361,21501469,21555380,21569553,21569556,21569558,21592474,21592475,21592477,21619599,21715417,21743838,21756727,21756777,21756778,21756779,21756780,21818647,21818647,21818648,21958377,21984489,21984490,21984495,21984498,21984501,21984502,21984503,21984504,21984505,21984505,21984506,21984506,21984507,21984509,21984509,21984510,21984510,21984511,21984645,22099293,22099293,22099295,22170956,22290536,22385149,22425445,22425446,22492150,22492152,22492153,22492153,22525332,22525350,22551359,22551361,22551362,22832683,22832683,22961448,22961450,22961451,23111500,23657569,23986152,23986153,24043261,24071781,24071781,24071782,24071782,24071783,24071783,24071784,24240330,24354806,24354807,24354807,24354808,31732397,21501360,21504815,21569557,21592475,21620280,21627706,21743839,21756779,21756779,21756780,21811856,21984495,21984503,21984507,21984508,21984513,22078250,22170957,22354280,22385150,22425445,22492152,22492153,22492154,22832683,22961450,22961451,22961453,23171677,23198751,23289636,23398070,23986153,23986161,24071782,24071783,24071783,24071784,24071784,24240330,24271593,24354807,24354807,24354808,21592476,21592476,21756779,21984504,21984514,22425446,22492154,22961451,23245096,24252063,24354807,24354808,22425446,24071783,24071784,24240331,21962315,24071785,21501589,24387033,21508324,22089096,21558530,21847240,21609412,22038538,21637766,21637769,21637771,21637772,21660687,21886866,22239169,23029666,24308543,22052712,24139995,21683605,21683593,21683606,21683606,21683606,21683608,21683606,21683608,21683607,21683609,21683607,21683608,21683620,22516575,23052581,21847911,22476280,22772305,23052582,23052582,23052583,24162915,21737850,21875030,21739240,21739306,21739375,24190811,21754068,23087813,21926347,23975311,21929488,24568878,21986326,21986328,21986329,21986333,21986333,21986394,21986437,24597298,22734646,23967002,21986462,22363134,21986545,24597404,22012108,22012109,22239887,22239891,22012210,22012198,22012211,22012212,22012213,22012212,22012212,22012214,22012212,22012213,22012225,22213810,22239942,22680878,22747585,22806796,23216885,24327216,22239937,22239940,22633601,22680878,24327215,24327216,29368338,22426391,24327218,22122370,22122466,22122558,22295110,22135952,22135952,22135959,22135953,22135974,22301798,22301814,22742750,24389087,22395556,24389093,22868680,22280264,22373962,22284892,22883932,22328693,22798823,22385016,22426338,22415442,22415469,22415471,22949217,24528848,22415544,22415569,22415617,22415618,22415684,22415762,22415761,22415828,22485765,22949391,24477895,22423277,23224531,22467655,22467634,22467637,22467653,22467641,22467644,22467658,22467662,22467642,22467647,22467647,22467661,22467649,22467658,22467663,22467649,22467667,22467670,22467672,22467654,22467655,22467663,22467667,22467669,22467672,22467680,22467652,22467666,22467655,22467669,22467654,22467656,22467657,22467659,22467675,22467679,22467656,22467657,22467657,22467659,22467670,22467672,22467673,22467675,22467676,22467662,22467672,22467662,22467663,22467666,22467671,22467660,22467663,22467671,22467674,22467678,22467663,22467675,22467678,22467678,22467679,22467688,22467661,22467665,22467672,22467676,22467676,22467677,22467678,22467681,22467682,22467687,22467670,22467676,22467678,22467679,22467681,22467681,22467666,22467681,22467684,22467676,22467677,22467679,22467682,22467683,22467676,22467684,22467681,22467685,22467678,22467688,22975312,23164334,24554944,22467687,22467687,22467688,22467689,22467690,22618525,23034525,23164337,24554946,24837969,24554945,22467690,22467700,24837971,24554948,22467691,22467700,24554948,22467692,22467697,22467698,22467703,22596777,24554949,22467700,22975318,24554950,22467695,22467697,22654123,24469328,24754761,22467699,22908612,22467695,22467696,22467699,22467702,22908613,22975319,22975320,23008501,23444617,24554950,22908614,23034527,24554952,24801905,24837975,24837976,22467698,22467700,22975321,23034532,24554952,22467700,22467703,22908615,23444621,22467703,24554953,22582464,24554954,22467709,22467819,22467821,22868321,22975324,23444623,24554953,24554953,24554956,23937687,24554956,22908619,22908620,24554958,24554957,24837983,23881247,24554959,24554961,24554961,24554962,24837985,22467952,22467951,22467951,22975454,23411954,24555089,22555710,24598965,22655155,22655156,22655159,22655162,24931712,24648690,24648692,24931718,22669889,22670120,22670344,23076679,22688265,24665242,22697245,22697243,22697244,22697246,24669733,23090102,24669735,24669733,24669735,22725873,22725875,22725883,24684048,24967074,24967078,22739809,23659277,22769383,24705805,22840596,22873725,23054789,23095084,23095086,23161791,25024446,22906887,22907022,22907151,23195083,23079728,24860975,23207216,24924719,23254988,23261973,23268940,23268942,23268952,23268953,23268953,23268953,23268952,23268958,23268963,23845253,23268966,23375956,23845256,23268999,23309249,23375956,23845255,24955587,25110854,23309250,23269040,23309290,23349542,23349544,23349545,23349546,23349546,23349547,23349548,23349547,23349548,23349549,23349550,24995879,24995880,23475461,23475462,24995881,24995882,23349561,23416252,23416254,23860863,23885551,24910254,24995881,24995882,24995884,25278907,23416253,23416253,23885552,24995883,24995884,25278908,23416252,23416254,23475464,23885552,25278908,25278909,24127363,25278909,23416254,24995886,23349570,23416255,25278911,24995891,23482957,23482958,23482958,23482959,23482945,23482946,23482959,23482960,23482960,23482961,23482947,23482960,23482960,23482961,23482960,23482962,23482957,23482961,23482961,23482963,23482963,23482970,24976963,23952258,23482974,23758836,23952258,24235903,25034069,25062591,25345614,25345615,23482975,23482976,23516140,23542166,23744102,23823936,23952258,23952259,23952260,23952261,23952262,24280443,24701703,24760030,25062589,25062589,25062590,25062591,25062591,25062592,25235426,25262399,25345615,25345615,25345624,25377723,23542170,23952259,24280444,24445323,24532924,25062590,25062591,25345615,25345615,23952260,24098976,25034071,25062591,23486158,23489349,23955452,23549325,23549363,23549391,23549404,25095796,23549445,23549458,23549468,23549474,23549473,23549479,23549485,25095843,25095845,25264392,25268680,25378869,23549487,23549565,23549652,23549705,23549766,23549810,23549847,23985700,23601373,23601374,23601374,23601375,23601375,23601376,23601379,23601377,23601378,23601367,23601378,23601379,24596442,24811672,25321609,25404822,23705285,23755617,24339651,25093275,25121798,25121798,25404822,25404823,25121799,23809190,24551989,23860997,23861000,23861000,24141277,24540653,25251609,23909854,23909865,24165705,24005244,24084634,24019284,24019380,24019477,25613871,24025783,25305480,24034710,24228132,24164019,24164007,24164020,24164020,24164021,24164022,24164033,25100558,25403120,25403121,25686144,24164929,24293252,24355952,25499084,24372180,25507200,24402007,25522116,24421550,24421541,24421556,24421556,24421542,24421557,24421543,24421544,24421552,24421555,24421555,24421556,24421556,24421557,24421557,24421558,24421558,24421558,24421558,24421559,24421561,24421561,24421562,24421560,24421562,24421564,24421562,25531885,24421570,25531885,25531887,24421570,25503364,25531888,25814911,25531888,25531887,25531888,25531889,25814912,25814913,24421572,25531887,25531887,25531889,24421572,24421573,24705203,25503366,25503367,24421573,24421575,24749742,24806339,25117575,25119388,25189315,25503367,25503370,25531887,25531888,25531888,25531889,25531889,25531890,25531890,25700437,25814913,25814914,25814914,25814915,25531888,25531890,25531890,25531891,25158584,25531891,25531892,25700438,24421577,25185450,25700439,25531892,24705206,24461227,25834749,24578742,24578743,24578857,24578857,24578970,24578972,25610591,25893515,24714992,25650086,24721651,24721653,25964959,25964959,24842009,26025140,24896153,26052210,24905178,25773700,24988843,24988845,24988846,24988846,26098555,25506561,25815533,26015341,25077924,25077925,25636204,25831549,25860072,26143096,25860073,25191138,25916687,25220306,26214287,25294790,25294791,25607616,26137052,26251528,26251529,25407678,25407686,25407819,25996430,25407958,26308111,25582885,25582885,26395576,26112552,25591507,26116862,25813591,26142275,25813792,26228005,25817216,26512742,25895608,25895605,26268912,26268914,25920442,25920442,26195699,25978771,25947665,26294941,25949333,25949478,25949623,26578944,25957067,25957174,25957281,26214118,26020398,26499858,26021967,26332093,26024280,26333251,26616275,26037097,26037098,26037098,26037100,26622683,26339660,26133697,26339660,26654789,26038297,26340261,26194480,26194583,26194686,26418452,26230293,26407734,26275961,26742114,26470962,26470965,26470965,26470963,26470967,26470969,26470971,26470969,26470968,26470973,26470978,26528070,26725141,26871726,26528075,26839620,26556597,26556598,26556598,26556599,26556600,26556598,26556600,26556601,26539924,26591070,26585172,26585173,26585175,26585175,26585174,26585176,26585177,26585178,26585176,26585177,26585179,26585180,26585179,26585180,26585181,26613694,26613694,26613696,26613696,26613698,26896723,26613697,26613698,26613698,26613699,26613699,26782247,26613698,26613700,26613701,26782247,26896724,26896724,26613699,26642204,26642203,26642219,26642220,26642204,26642205,26642205,26642218,26642218,26642219,26642220,26642204,26642205,26642205,26642206,26642218,26642219,26642219,26642220,26642221,26642205,26642206,26642206,26642207,26642220,26642221,26642221,26642206,26642207,26642219,26642220,26642220,26642221,26642221,26642222,26642207,26642208,26642208,26642220,26642220,26642221,26642221,26642222,26642222,26642208,26642209,26642210,26642220,26642220,26642221,26642221,26642222,26642222,26642223,26642221,26642222,26642222,26642223,26642223,26642221,26642223,26642223,26642224,26642225,26642234,26642234,26642235,26642235,26925140,26925243,26925244,26642235,26642235,26642236,26925244,26925244,26925245,26642235,26642236,26642236,26810768,26925244,26925245,26642236,26642237,26810768,26925245,26925245,26925246,26642237,26741320,26810769,26810772,26830249,26842032,26877949,26925245,26925246,26925246,26925247,27332123,26642238,26642240,26719636,26797490,26810769,26815058,26842031,26842032,26842033,26842034,26842035,26852442,26925244,26925245,26925245,26925246,26925246,26925247,26925247,26925248,26957354,26957355,34302836,26925246,26925248,26797046,27002655,26840415,27024341,26952757,26952758,27080513,27080514,26979301,26979304,26979371,26979371,26979305,26979374,26979375,26979441,26979442,27010634,27010636,27093847,27093848,27093848,27093849,34471438,27093848,27093849,26979629,27093948,26987892,26987894,26987896,27098081,27098083,27098084,27002777,27105522,27018271,27113268,27041838,27041840,27041840,27041841,27041841,27041842,27041842,27041842,27041843,27041843,27041843,27041844,27041844,27041847,27125054,27125054,27041856,27125055,27125056,27125056,27125054,27125055,27125055,27125056,27125056,27125058,27062656,27135461,27113673,27160970,27136130,27172201,27208057,27208160,27208161,27208253,27208252,27208253,27208253,27208253,27208254,27208254,27208254,27208255,27208255,27208269,27208270,27208271,27208272,27208274,27208255,27208256,27208261,27208270,27208270,27208271,27208271,27208281,27208256,27208257,27208257,27208258,27208264,27208264,27208265,27208265,27208267,27208269,27208270,27208270,27208271,27208271,27208272,27208272,27208273,27208273,27208257,27208258,27208259,27208260,27208261,27208261,27208262,27208262,27208263,27208263,27208264,27208264,27208265,27208265,27208266,27208266,27208267,27208267,27208268,27208268,27208269,27208269,27208270,27208270,27208271,27208271,27208272,27208272,27208273,27208273,27208274,27208281,27208258,27208259,27208259,27208260,27208261,27208261,27208262,27208262,27208263,27208263,27208264,27208264,27208265,27208265,27208266,27208267,27208268,27208269,27208270,27208271,27208271,27208272,27208272,27208273,27208273,27208259,27208260,27208263,27208264,27208265,27208265,27208266,27208266,27208267,27208270,27208271,27208271,27208272,27208272,27208273,27208273,27208275,27208265,27208267,27208271,27208272,27208264,27208271,27208274,27208274,27208274,27208270,27208275,27208267,27208274,27208275,27208267,27208268,27208269,27208272,27208276,27208276,27208268,27208269,27208270,27208276,27208277,27208269,27208270,27208271,27208277,27208277,27208269,27208270,27208271,27208278,27208279,27208270,27208271,27208271,27208273,27208274,27208277,27208277,27208278,27208278,27208279,27208271,27208272,27208272,27208273,27208273,27208274,27208274,27208277,27208278,27208278,27208279,27208279,27208272,27208273,27208273,27208274,27208274,27208275,27208276,27208277,27208278,27208279,27208279,27208281,27208273,27208274,27208274,27208275,27208276,27208277,27208278,27208278,27208279,27208279,27208280,27208280,27208291,27208274,27208275,27208275,27208276,27208276,27208278,27208279,27208279,27208280,27208280,27208275,27208276,27208279,27208279,27208280,27208280,27208281,27208282,27208276,27208277,27208279,27208280,27208280,27208281,27208277,27208278,27208278,27208279,27208280,27208281,27208281,27208282,27208282,27208283,27208278,27208279,27208281,27208281,27208282,27208282,27208283,27208279,27208282,27208282,27208285,27208282,27208283,27208283,27208281,27208282,27208283,27208283,27208284,27208282,27208283,27208284,27208284,27208283,27208284,27208284,27208285,27208285,27208284,27208285,27208285,27208286,27208286,27208287,27208285,27208286,27208286,27208287,27208289,27240377,34585860,27208286,27208287,27208287,27208288,27208288,27208289,27208289,27208290,27240374,27240376,27240379,27240380,27240381,27208287,27208288,27208288,27208289,27208289,27208290,27208291,27208295,27208297,27240376,27240377,27240379,27240379,28735758,33294066,34585861,27208288,27208289,27208289,27208290,27208290,27208291,27208291,27208292,27208294,27208297,27208298,27208298,27240358,27240374,27240376,27240376,27240377,27240378,27240378,27240379,27240379,27615149,27615150,28735758,29495546,30403832,33294069,34585861,27208289,27208290,27208290,27208291,27208291,27208292,27208292,27208293,27208293,27208294,27208295,27208296,27208297,27208298,27208298,27208299,27208299,27240357,27240358,27240359,27240367,27240376,27240377,27240378,27240378,27240379,27240379,27240380,27240380,27240382,27615149,27615150,28023272,28735758,28735759,28964674,29222921,29996051,31422349,34585862,27208290,27208291,27208291,27208292,27208292,27208293,27208293,27208294,27208295,27208295,27208298,27208299,27208299,27208300,27240359,27240372,27240377,27240378,27240378,27240379,27240379,27240380,27240380,27240381,27240382,27240384,27615150,27848353,34585862,27208291,27208292,27208292,27208293,27208293,27208294,27208294,27208295,27208297,27208298,27208299,27208300,27240359,27240362,27240363,27240365,27240377,27240378,27240379,27240380,27240380,27240381,27240382,27596979,27615151,29118432,29495547,34585863,27208292,27208293,27208293,27208294,27208294,27208296,27208299,27208300,27208300,27208301,27237292,27240360,27240360,27240363,27240378,27240379,27240379,27240380,27240380,27240381,27240381,27240382,27848354,27208293,27208294,27208294,27208295,27208295,27208296,27208299,27208300,27208301,27208301,27240359,27240360,27240360,27240364,27240373,27240377,27240381,27240382,27240383,29495548,34585864,27208294,27208295,27208295,27208296,27208298,27208299,27208300,27208301,27208301,27240360,27240368,27240379,27240380,27240381,27240382,27240384,27615152,30862564,31966372,27208295,27208296,27208296,27208297,27208297,27208298,27208299,27208300,27208300,27208301,27208301,27208302,27208302,27240359,27240361,27240364,27240365,27240373,27240380,27240381,27240382,27615150,27615152,27615153,27208296,27208297,27208297,27208298,27208298,27208299,27208299,27208300,27208301,27208301,27208302,27208302,27208303,27240361,27240362,27240362,27240380,27240382,27240382,27240383,27240386,27615152,27848356,27208297,27208298,27208298,27208299,27208299,27208300,27208301,27208301,27208302,27208303,27208303,27240361,27240362,27240377,27240378,27240380,27240381,27240385,27615149,29495550,27208298,27208299,27208299,27208300,27208300,27208301,27208302,27208302,27208303,27208303,27240359,27240361,27240362,27240363,27240363,27240369,27240380,27240382,27240383,27240384,27615155,27208299,27208300,27208300,27208301,27208301,27208302,27208302,27208303,27208304,27240362,27240363,27240364,27240365,27240367,27240370,27240380,27240381,27240381,27240384,27208300,27208301,27208301,27208302,27208302,27208303,27208304,27208305,27240363,27240364,27240372,27240380,27240384,27848358,27208301,27208302,27208303,27208303,27208304,27208304,27208305,27240363,27240364,27240366,27240371,27615156,27208302,27208303,27208303,27208304,27208304,27208305,27208305,27240364,27240379,27240380,27240381,27240385,27240386,27596983,28735764,27208303,27208304,27208304,27208305,27240365,27240365,27240366,27240369,27240375,27240381,27240383,27240384,27240386,27240387,27240388,27208305,27208306,27240364,27240366,27240380,27208305,27208306,27208306,27208307,27240366,27240366,27240367,27240368,27240370,27240383,27240383,27240385,27240387,27208306,27208307,27208307,27208308,27240365,27240366,27240366,27240367,27240367,27240369,27240377,27240380,27240381,27240382,27240383,27240384,27240384,27240385,27240386,27240386,27240387,27240387,27240388,27208307,27225064,27240367,27240386,27240388,27208308,27208309,27240366,27240367,27240367,27240368,27240368,27240370,27240372,27240373,27240381,27240383,27240384,27240385,27240386,27240387,27240387,27240388,27240388,27240389,27240389,27240390,27240390,27615157,27615158,27615160,29495556,34585871,27208309,27225065,27240367,27240367,27240368,27240368,27240369,27240372,27240372,27240375,27240378,27240381,27240382,27240385,27240386,27240386,27240387,27240388,27240388,27240389,27240389,27240390,27240390,27240391,27240392,27241732,27848362,28564838,28735768,29495557,27240367,27240368,27240368,27240369,27240369,27240370,27240382,27240385,27240387,27240388,27240388,27240389,27240389,27240390,27240390,27240392,27596988,27615160,27689191,27241831,27241911,27241915,27241991,27242000,27257215,27257225,27266354,27269422,27272425,27272444,27272432,27272441,27272445,27272425,27272426,27272426,27272430,27272439,27272439,27272426,27272427,27272427,27272437,27272439,27272441,27272442,27272443,27272443,27272444,27272445,27272447,27272427,27272428,27272431,27272433,27272439,27272441,27272442,27272443,27272443,27272444,27272444,27272445,27272428,27272430,27272433,27272433,27272441,27272442,27272442,27272443,27272443,27272444,27272444,27272445,27272445,27272446,27272446,27272447,27272447,27272448,27272448,27272449,27272449,27272464,27272430,27272430,27272431,27272432,27272434,27272438,27272440,27272441,27272442,27272443,27272443,27272444,27272444,27272445,27272445,27272446,27272447,27272448,27272449,27272450,27272453,27272432,27272450,27272446,27272447,27272447,27272448,27272450,27272451,27272467,27272437,27272446,27272446,27272450,27272456,27272435,27272444,27272453,27272441,27272446,27272448,27272449,27272450,27272452,27272452,27272453,27272453,27272454,27272451,27272444,27272445,27272447,27272449,27272441,27272451,27272450,27272452,27272453,27272454,27272449,27272452,27272455,27272471,27272457,27272458,27272451,27272456,27272452,27272458,27272456,27272462,27272457,27272454,27272460,27272461,27272455,27272457,27272458,27272459,27272461,27272459,27272460,27272461,27272461,27272462,27272463,27272478,27272455,27272456,27272458,27272461,27272456,27272457,27272458,27272459,27272460,27272463,27272457,27272458,27272458,27272459,27272459,27272461,27272463,27272464,27272468,27272458,27272459,27272460,27272461,27272461,27272462,27272463,27272459,27272460,27272461,27272461,27272463,27272463,27272464,27272464,27272465,27280541,34617947,27272460,27272461,27272461,27272462,27272462,27272463,27272463,27272464,27272464,27272465,27272465,27272466,27647235,27272461,27272462,27272462,27272463,27272463,27272464,27272464,27272465,27272465,27272466,27272467,27272481,27517662,27647232,31998458,27272462,27272463,27272463,27272464,27272464,27272465,27272465,27272466,27272466,27272467,28767845,27272463,27272464,27272464,27272465,27272465,27272466,27272466,27272467,27272464,27272465,27272465,27272466,27272466,27272467,27272467,27272468,27272483,27272465,27272466,27272466,27272467,27272467,27272468,27272468,27272471,27272483,27272483,27272484,27272466,27272467,27272467,27272468,27272468,27272469,27272483,27272484,27272484,27272485,27272467,27272468,27272468,27272469,27272469,27272470,27272471,27272471,27272473,27272484,27272484,27272485,27272468,27272469,27272469,27272470,27272470,27272471,27272471,27272472,27272483,27272484,27272485,27272486,27272488,27272469,27272470,27272470,27272471,27272471,27272472,27272472,27272473,27272473,27272474,27272478,27272480,27272485,27272485,27272486,27272486,27272487,27272488,27272489,27272490,27272491,27272470,27272471,27272471,27272472,27272472,27272473,27272473,27272474,27272478,27272485,27272485,27272486,27272486,27272487,27272489,27272489,27272490,27272471,27272472,27272472,27272473,27272473,27272474,27272474,27272475,27272478,27272478,27272479,27272480,27272480,27272482,27272483,27272485,27272486,27272486,27272487,27272487,27272488,27272488,27272472,27272473,27272473,27272474,27272475,27272476,27272476,27272479,27272480,27272481,27272481,27272482,27272486,27272486,27272487,27272487,27272488,27272489,27272490,27272473,27272474,27272474,27272475,27272481,27272481,27272483,27272485,27272487,27272487,27272488,27272489,27272491,34617954,27272474,27272475,27272476,27272476,27272477,27272482,27272487,27272487,27272488,27272489,27272489,27272490,27272475,27272476,27272477,27272477,27272488,27272488,27272489,27272490,27272490,27272493,27272476,27272488,27272489,27272489,27272490,27272490,27272491,27272485,27272489,27272489,27272491,27272493,27272489,27272490,27647244,27272490,27272490,27272491,27272493,27272480,27272490,34617957,27272491,27272491,27272493,27272493,27272494,27272494,27272494,27272494,27272495,27272495,27272495,27272496,27272495,27272496,27272496,27272497,27272497,27272498,27272499,27272499,27272499,27272500,27272501,27272501,27272502,27272502,27272503,27272503,27272504,27272504,27272505,27272511,27647255,27647257,27880458,27912378,31998474,33326154,34617968,27272502,27272503,27272503,27272504,27272504,27272505,27272505,27272506,27272507,27272508,27273829,27343986,27412134,27412135,27412136,27647253,27647254,27647254,27647255,27647255,27647256,27647256,27647257,27647257,27647258,27665568,27665569,27701105,27721286,27721286,27721287,27731513,27794233,27818600,27880459,27899951,28055383,28060252,28063001,28245302,28596935,28596936,28767862,28767864,28767865,28767865,29235713,29235714,29527652,29527653,29527653,29527654,30435915,30435926,30435936,30435940,30854802,31023790,31998473,31998474,31998476,31998476,32118188,32145007,33163827,33326127,33537503,34617968,27272503,27272504,27272504,27272505,27272506,27272506,27272507,27272507,27412136,27517683,27572564,27647252,27647254,27647255,27647255,27647256,27647256,27647257,27647257,27647258,27721287,27731514,27736915,27927545,28518798,29150538,29527653,30276034,30287406,31458425,31998473,31998476,32381686,34617969,27272504,27272505,27272505,27272506,27272506,27272507,27272507,27272508,27273830,27280564,27412136,27459615,27520234,27572563,27629084,27629086,27629086,27647251,27647253,27647254,27647255,27647256,27647257,27647257,27647258,27647258,27721287,27721287,27721288,27880460,27897125,28055384,28063003,28636860,28767865,28767866,29120361,29284853,29527653,29527654,29527654,30435939,30854803,31998474,31998477,33326143,34617969,27272505,27272506,27272506,27272507,27272508,27273831,27313017,27412137,27572566,27572567,27629084,27629085,27647253,27647254,27647255,27647257,27647257,27647258,27647258,27647259,27647259,27721288,27880460,28596939,28767865,28767866,28996781,29108542,29527655,31998475,33326174,34617970,27272506,27272507,27272507,27272509,27272509,27273831,27280564,27412137,27412138,27459616,27518839,27572566,27629085,27647252,27647254,27647254,27647255,27647256,27647256,27647257,27647258,27647259,27647259,27701107,27721288,27721289,27731516,27880461,28767866,28767867,29527654,31270279,31998476,31998478,31998478,32381688,34617970,27272508,27647258,27647259,27721289,27731516,27880461,27912203,28245304,28767866,34617971,27272508,27272509,27412138,27495709,27518840,27647255,27647256,27647257,27647257,27647258,27647259,27647260,27647260,27721289,27721290,27880462,28063002,28767867,28767868,31998479,31998479,32381689,34617971,27272509,27273833,27280565,27459618,27518924,27647256,27647256,27647257,27647257,27647258,27647259,27647259,27647260,27647261,27647261,27701109,27927549,28055381,28063170,28245305,28767868,28996783,29235718,29527656,29599843,30276037,34617972,27272510,27647259,27647260,27647261,27731517,29527657,30320253,27647259,27647260,27647260,27647261,27721291,27880463,28767869,29078676,29235718,34617973,27647259,27647260,27880464,29918154,31998481,33326176,34617973,27721291,27880464,33326133,27272530,27647276,27275167,27275166,27275169,27275169,27275170,27275312,27965761,27648596,32383024,27648589,27648596,27648593,27275458,27648740,27288637,27288641,27288639,27288640,27288642,27655329,29086747,27655333,27655333,27655335,27729364,27353544,27687786,27415483,28839362,27551782,27551783,27551784,27551785,27551782,27551784,34757615,27786905,27860933,28907513,29027196,27860935,28206048,28907513,29746327,34757618,27646736,27646737,27646738,27646794,27646798,27834378,27646855,27646858,27834439,28955048,27718960,27719044,27719120,27870587,27762877,28125653,32390202,27765182,27765267,27765351,27765353,27765354,27893684,32244907,27893685,27767976,27895000,27872638,27872643,27872642,27872642,27872640,27965642,27947332,27947334,27947333,29067942,27947330,27985674,27985676,27985677,27985676,27985680,27985681,27985677,27985680,27985681,27985765,27985767,27985768,28953532,28003852,28077882,28003854,28003854,27985856,27985857,28237141,28003936,28003938,29884335,28022003,28022002,28022005,28022014,28022005,28022006,28022006,28022022,28022005,28022006,28022008,28022023,28022023,28022004,28022005,28022006,28022024,28022005,28022006,28022007,28022024,28022006,28022007,28022007,28022009,28022009,28022011,28022019,28022024,28022024,28022025,28022027,28022008,28022008,28022009,28022009,28022010,28022012,28022025,28022026,28022027,28022008,28022009,28022010,28022010,28022025,28022029,28022009,28022010,28022010,28022011,28022011,28022025,28022026,28022026,28022027,28022028,28022010,28022011,28022011,28022014,28022026,28022026,28022027,28022027,28022011,28022012,28022013,28022021,28022026,28022027,28022027,28022012,28022013,28022014,28022021,28022027,28022027,28022028,28022031,28022013,28022015,28022027,28022028,28022028,28022028,28022028,28022029,28022029,28022030,28022031,28022028,28022029,28022029,28022037,28022030,28022031,28096050,28022037,28022037,28022038,28022042,28022043,28022043,28022044,28040339,28096056,28096056,28096057,28106284,28169391,28255229,29142634,29142635,29142635,29371550,29453438,29902421,29902423,29902423,29983351,30402928,30650803,31398646,32373244,34992738,28022043,28022044,28022044,28022045,28022045,28022046,28040339,28075876,28096056,28096057,28096057,28106284,28111687,28255227,28255228,28255229,28286972,28302316,28339195,28430146,28430146,28430834,28437769,28809344,28971705,28971706,29142634,29142635,29142635,29142636,29257014,29348785,29371550,29495130,29527397,29610485,29610486,29670607,29781104,29902423,29902423,29902424,29902424,29974610,30650804,30810702,30810702,30810711,31398559,32488147,32756457,33700910,33700915,33912275,34985508,34992739,28022044,28022045,28022046,28040339,28075876,28096057,28106284,28134810,28255230,28302316,28339194,28430152,28437772,28620073,28809345,29142635,29142635,29142636,29610492,29902423,31041732,31398561,32373244,32373247,33700920,33700924,34985361,34992739,28022045,28096058,28106285,28255230,28620073,29142636,29902424,30299203,32373248,32756458,34247229,28040339,28075877,28255230,29142636,29610485,31229574,34992740,28075878,28096059,29142636,28430161,34992741,28096060,29142637,29142638,29902426,29902426,34992742,28096060,28255233,28998710,28058648,28058646,28058648,28058649,28058650,28058648,28058648,28124592,29160949,28124593,29513440,28638383,32774767,35011050,28129723,28129723,28129724,28129724,28309076,29196482,35046586,30864559,32427094,28149905,28309078,28170085,28170085,28170086,28170086,28170071,28170086,28170086,28170087,28170087,28170087,28329258,35066768,28170102,28180314,28243034,28329259,28361002,28504175,28504178,29216665,29601426,29976452,30724834,30959218,32447276,28180314,28208840,28329259,28329260,28376345,28504180,28512091,28694102,28694103,29085660,29088342,29216665,29216665,29445580,29569161,29684515,29684515,29789132,29976453,29976453,29976454,30366949,32447277,32593808,32830486,33986305,35066769,28190539,28190538,28190540,28190540,28190541,32457501,28339485,28522319,28659035,28704328,28704329,29694738,29694743,29986679,30058866,30160976,30894963,34175686,28201341,28201343,28361551,28428850,28247587,28247683,28247690,28247780,28247800,29124504,28247818,29124518,28315976,28315977,29161285,30049396,28316752,29409679,28364726,28426585,28488414,28488429,28488430,28488430,28488430,28488431,28488431,28488432,28488433,28488432,28488445,28663352,28853273,29375837,35225940,28488446,28488447,28505096,28520173,28520342,28520346,28535519,28572395,28663351,28670974,28853274,29120571,29204907,29359330,29375836,29375837,29375837,29375842,29490214,29539550,29604752,29843686,30135621,30135624,30135625,30296793,30636130,30719471,31043907,31043910,31043911,31631762,32606446,32606448,33934093,33934103,33934118,34145477,34145478,35225940,28572396,28663351,28853275,29244832,29375837,29461534,29843689,30034212,30135625,31043911,32606449,32606450,35225941,29375838,31631824,29375839,30135627,28521758,28521759,28521759,32623110,30030968,30152287,28527412,29863176,28551916,28551923,28551924,28551926,28695094,29875436,29875438,30167378,28552259,28552263,28552257,28552267,28552278,28787242,29407754,29875604,28582603,28582603,28582604,28582605,28582608,29890772,30182709,30931092,31090995,32653535,29422925,28656358,28656358,28656359,30219587,31127876,29288870,29459800,30338566,31715799,28838264,28838264,28838265,28838267,28838272,28838277,28838274,28838273,28838273,28838276,28838275,28838282,28838278,28838281,28838291,29422429,30018604,30018604,31058925,29908167,29028200,29550759,29550760,34320396,34320399,30310548,29550761,35400866,29379838,30078735,29550767,28839640,29028879,28848075,28848240,28848402,31064018,28853510,28853512,28853513,28853514,30318164,29787292,29910872,30318166,31226451,30318165,28853844,30026392,28854091,28854094,33172487,30318455,28860308,30321561,29022215,33256548,29127527,29524455,29218116,29218117,29218118,29218119,29218115,29218115,29218116,29218116,29218118,29218120,29218121,29740677,29740677,29740678,31234536,29740678,30379144,31408746,29740679,31248847,35590782,29740679,30500467,31084299,29609675,29740681,30208529,30208530,30208531,29740683,29596655,29596661,32644930,34488102,29752708,29837045,29765105,31522341,29921383,29921383,29921384,29921384,29921383,29921385,29921384,29921386,29921387,31600480,30092312,32348237,29950230,30092312,30092313,30092313,30560169,30852101,30869725,31760386,30852101,29975382,30119315,29979074,30152902,30001230,30132235,30132235,30132236,30600085,30892023,35950862,30006596,30006597,30006598,30602769,31802986,30134918,30230229,30246736,30263225,30263238,30263226,30263227,30263240,30263241,30263241,30263243,30263227,30263228,30263241,30263242,30263242,30263243,30263243,30263228,30263229,30263240,30263242,30263242,30263243,30263243,30263244,30263243,30263243,30263244,30263244,30263245,30263243,30263253,30263254,30263255,32519166,31771410,30263257,30263258,32456079,33493853,30263257,30263258,30263258,30603918,30648004,30675555,30731091,31023030,31197622,33877064,30263258,30263259,30377621,30615738,30731091,30731092,30969728,31023027,31023030,31023031,31023031,31095218,31931311,31931313,31931313,31931314,33493851,33493852,33493854,33493854,33493855,36113346,30263259,30731091,30731093,30731093,30731094,30731094,30780233,31023028,31023031,31023031,31023032,31095218,31413527,31771412,31931315,32519165,33493853,33493855,34821530,34821532,34821557,35032884,36113347,30263261,30492159,30615740,30648005,30731091,30731093,30731093,30731094,30731095,30731100,30901706,30965563,31023029,31023031,31023032,31023032,31095216,31190474,31383165,31454909,31523537,31771412,31771414,31931312,32519165,32641309,32828509,32831090,32862470,33371621,33493852,33493853,33493855,33493855,33493856,33608757,33877065,34821525,34821529,34821553,35032884,36113347,33493854,36113348,30731098,32350186,30326728,30523898,30434636,30701435,30491982,30491993,30492022,30492059,31137403,30492096,30492166,30492286,31137501,30492513,30845757,30502605,30765594,35447348,30590675,36277065,30675546,30937246,30721059,30721069,30721070,30721071,30721073,30721073,30721071,30721071,30721071,31251943,30721083,31752448,32460788,33722766,36342259,30904597,31752452,32160228,34043975,30844654,30884850,30884853,34053194,34187867,36344909,30944590,30944591,33111272,32690759,30968231,30968231,30968231,30968232,31375523,31083585,31188202,31375523,31375524,31959355,32283805,32283811,33846344,33846347,36465839,30978056,31088496,31028582,33876523,36496013,31032764,31032766,31032766,36498106,31804570,31407793,34025147,35206317,36498108,31087862,31087994,31088122,31088126,31360529,32931604,31198937,31198939,31198926,31198939,31198940,31198940,31198941,31198940,31198942,31198943,31198928,31198928,31198929,31198940,31198940,31198941,31198942,31198942,31198943,31198943,31198944,31198944,31198940,31198941,31198941,31198943,31198943,31198944,31198941,31198944,31198944,31198945,31198946,31198943,31198945,31198946,31198949,31198956,31198952,31198955,31490878,32239259,36581194,31198955,32399157,33430659,31490879,31671520,33233504,33961703,36581195,31248082,32239260,32987017,33961701,36581195,31198958,35289402,31198958,31490880,31563068,31652049,31766620,33961702,33961704,31198960,31303560,31490881,31490881,32239262,32399169,33961704,33961706,36581197,31248082,31369562,31490881,31490881,32399166,32399171,33961702,33961705,33961707,35289378,31652051,33961704,33961705,33961706,36581198,31490883,35289414,36581201,33961712,31237566,34127545,31297218,31297219,31297221,31297322,31540018,31540019,34010840,31297420,36630432,31319178,31319181,31550997,34021819,31408227,31408231,31408298,31595553,31756721,34449586,31540168,31540175,31540177,31540178,36751809,31661496,31661497,36751812,35459995,31580032,31681445,31632938,31707877,31667879,32225853,31676213,36819831,31782796,31782800,31782801,31782813,31782813,31782818,31782802,31782803,31782804,31782805,31782817,31782818,31782818,31782819,31782819,31782820,31782804,31782815,31782818,31782819,31782819,31782820,31782820,31782818,31782819,31782819,31782820,31782820,31782821,31782821,31782820,31782820,31782821,31782829,34216284,36873131,32531197,31782832,31782833,31782833,31782834,31782834,32691099,32691100,33496103,33525442,33841182,34253640,34253642,36873134,31782834,31782836,31855003,31855006,31861846,31950260,32173315,32179597,32340097,32531199,32531200,32570583,32691097,32691099,33109966,33278955,33588297,33588299,33588301,34162072,34253639,34253640,34253641,34253642,34253642,34253644,34373353,35581294,35581310,36873134,31782835,31943988,32173315,32187750,32283322,32366650,32473056,32531200,32531201,32542572,32691097,32691100,32691101,32691104,32691107,33278953,33588298,33713591,33722599,33722763,34253639,34253640,34253641,34253642,34253643,34253643,34253646,34373355,34400172,34400174,34636853,35118615,35581319,35792671,35792675,36050105,36873135,32173316,32283325,32531200,32691107,33278953,34253641,34253641,34253643,34253643,34253644,34636853,35792673,32753399,35581318,36873136,31950262,32531201,31818062,34271262,31927187,31927189,31927189,31927190,31927190,33660484,34325824,34325825,32603383,32763281,34325826,33182149,34709037,35653486,31940868,31940870,33358047,36952158,31944670,31944716,31944761,32772062,32020774,34372616,32105152,32105153,32111425,34414807,34414804,34414808,32117696,32117699,32117700,32117703,32117752,32698638,32698639,34421082,32117808,33692935,32131409,33393397,32132062,32132252,32132442,32865941,32144133,33290554,32334297,32966841,32503080,33105725,32563808,32563808,32563812,32563814,32673816,37263627,32673817,34644135,32921697,35971775,32576372,32576372,32576376,35033627,34650415,34650417,32592683,32779840,32646573,34685519,32783827,32783828,32783829,32783829,32783832,33031704,33031705,33191605,34754147,34754148,35137357,36081816,37373639,33043078,32897373,37430410,32950495,32950540,32950542,32950517,33126417,37456987,36165203,37457026,32966996,32967065,32967134,34040445,33163291,33278194,33250960,34987713,33279565,33279578,33279578,33279579,33279579,33279580,33279580,33279581,33279578,33279579,33279579,33279580,33279585,33279581,33279592,33858345,34244482,35002019,35002020,35002021,35148552,35385230,35385231,36329718,36329721,37621513,33439478,34336674,35002019,33279593,33439482,35002022,35148553,36329673,37621514,33439477,33439478,33439478,33439482,34027336,35002022,35002023,36541051,37621515,35385233,37621516,33290956,33302324,33302322,33302323,33302325,33302326,35013391,36809855,33450850,33450860,34931601,33358348,34066721,33368013,34071550,33393095,33462853,33532610,33579306,33599351,33599375,33599374,33599379,33599386,33599376,33599384,33599361,33599367,33599379,33599383,33599373,33599380,33599384,33599394,33599387,33599387,33599388,33599402,33599373,33599374,33599388,33599389,33599393,33599368,33599373,33599391,33599385,33599387,33599389,33599391,33599388,33599391,33599390,33599393,33599387,33599388,33599392,33599394,33599396,33599394,33599396,33599398,35545122,33599379,33599401,33599396,33599397,33599389,33599397,33599398,33599398,33599399,33599402,33599381,33599381,33599390,33599398,33599409,33599394,33599406,33599400,33599400,33599400,33599392,33599395,33599397,33599399,35161918,35161923,35161922,34187237,37781417,35161926,33599409,33599414,35161927,35161927,34187307,35308459,37781420,36489581,36489597,37781420,33599411,34284702,34530544,33599415,36489604,35161931,35161931,33599418,35161931,35161932,37781424,33599425,33661550,35161929,33599416,34187246,34984111,35161933,37781425,33599418,34187247,35161934,35161935,33661690,35161935,35161936,36489608,34018260,35161931,35161934,35161935,35161935,33599424,34691352,35545145,37781428,37781428,34187249,35281648,34187254,35545148,34187255,35308470,34496598,35545150,35161943,35161945,34749486,33626002,34031559,33708370,35216413,33723695,33723842,33723979,33723989,35224223,35224225,33748361,35236419,34061432,38012439,34200505,35462484,34436924,34436936,34437019,34437025,34437111,34437112,34437113,34437114,34437114,34437115,34437115,34437115,34437117,35580788,35580789,38200280,34606103,35580789,36908328,36908463,38200281,35580788,34516844,34738459,34648919,35686693,34655384,35689923,34775086,34775089,34775096,34775139,34775146,34775097,34775094,34775079,34775097,34775093,34775099,34775152,34775095,34775102,34775145,34775097,34775100,34775103,34775105,34775113,34775099,34775109,36132986,35749780,35749780,35749781,35749780,34775116,35749783,35896314,37288811,37845390,35864685,35749786,36070992,38369278,35749788,35749789,38369283,35749792,35749794,34775251,35084485,34775257,34775259,35749831,35749836,34775264,37077541,34775277,37077579,38369369,35749877,35749874,38369370,34960076,38461761,34970025,35847252,35019372,37410948,35113800,35113868,35113937,35919226,35209383,35966920,35966921,35268062,35268063,35268150,35268151,35268238,35268238,35996349,35996349,37324029,35277953,36001207,35393774,35393777,35393776,35393776,35393777,35393778,35393780,35393780,36059120,36059121,36059118,36059119,36059121,37386762,38678613,37386790,36059123,35398960,36208257,35461693,35461693,36476288,36093075,35636420,38799933,35644360,35644362,38803904,36184410,35662424,35662428,36193467,36576682,35662701,36193581,35693206,37747863,35783300,38873375,35899544,36312000,37851032,36368821,36546642,36479999,36480064,36480133,36602302,36541323,37960520,36560872,36560952,36561033,36642745,36649756,39306603,36724444,36724445,36724445,36724447,36724447,36724448,36724459,36724459,36724460,36724446,36724446,36724448,36724448,36724461,36724447,36724448,36724448,36724449,36724449,36724450,36724451,36724461,36724461,36724462,36724449,36724464,36724449,36724450,36724464,36724450,36724451,36724452,36724462,36724463,36724463,36724465,36724465,36724451,36724452,36724453,36724453,36724454,36724462,36724463,36724463,36724464,36724464,36724465,36724465,36724466,36724466,36724467,36724467,36724468,36724452,36724453,36724454,36724463,36724463,36724464,36724464,36724466,36724466,36724467,36724467,36724468,36724468,36724453,36724466,36724467,36724467,36724468,36724455,36724465,36724466,36724467,36724467,36724469,36724469,36724465,36724465,36724467,36724468,36724468,36724469,36724468,36724469,36724474,36724477,39343954,36724475,36724476,36724477,36724478,37107673,39343955,36724476,36724478,36724478,36724479,36724479,36724566,37107673,37765118,38052164,38052164,39343955,36724477,36724478,36724478,36724479,36724479,37107673,37107674,38052139,38052161,38052168,38263492,38263492,38263494,38910022,39343956,36724479,36724479,39343956,36724480,36724480,36724480,36724481,36724483,36870996,37052845,37107675,37107675,37107678,37776764,37816328,38052134,38052136,38052138,38052139,38052143,38052167,38263493,38263494,38263494,39343957,36724481,36724482,36724482,36724483,36724483,36728848,36844177,36844178,36855048,36870997,36975904,37107674,37107675,37107676,37589905,38052000,38052004,38052104,38052125,38052129,38052133,38052139,38052141,38052144,38052165,38052165,38052166,38052167,38052167,38052168,38052171,38052173,38263494,38263494,38263495,38263496,38263496,38391880,38520928,39336579,39343958,36724482,36724483,36724484,36728849,36839367,36844179,36870997,37107675,37107675,37107676,37107676,37589478,38052105,38052129,38052138,38052140,38052142,38052163,38052164,38052165,38052172,38263494,38263495,39343958,36870996,37107677,37107677,37107678,37589436,37589477,38052144,39343959,36870998,37107676,37107677,38052134,38052165,38065706,38263497,39343959,37107678,38052109,38052147,39343960,37107678,38052144,39343960,39343961,36724666,37107773,36733227,36733228,38056472,39348338,36954263,36954264,36954267,36954266,36954269,38167059,38167062,39458856,38167008,39458859,36963884,36963885,36963887,36963887,36963888,38171844,39463666,37630616,38171848,38171849,38171851,36985627,38182719,37017524,37017525,37017525,37017525,37017526,39490486,39483108,39490486,37254204,37254204,37254205,37254205,37923294,38198667,39490487,37221538,39592494,37227351,37227416,37227485,37359191,37366878,37366878,39657785,38373348,37381224,39672336,37490869,37490869,37490883,37490884,37490884,37490885,37490870,37490883,37490885,37490885,37490872,37490884,37490885,37490885,37490886,37490886,37490886,37490888,37490887,37490888,37490893,38646702,39727166,37490900,37703180,38435319,38608771,38646703,39727167,37490900,38435369,38435375,38646704,39727167,37490901,37490902,38009210,38148331,38435311,38435316,38435318,38435319,38435322,38435327,38435335,38435342,38435342,38435344,38435344,38435345,38435347,38435351,38435353,38435354,38435356,38435369,38435373,38435376,38435380,38597359,38646704,38646704,38646706,38646706,38775090,38904138,38941491,38981652,39727168,38646704,39727168,38435324,39727169,39727169,38435356,37915477,39939464,38297343,40130394,38454465,38454419,40208938,38454505,38454503,40208984,40208987,38455404,39150094,38527547,40245504,38805772,38805772,39304146,39092763,38829049,38829061,38829061,40396254,38908191,39144037,39055168,40509309,39379539,39379603,39591034,39379762,40671557,39379724,39379739,39379772,39379747,39379762,39379753,39379776,39379769,39379781,39379778,39379778,39379782,39379785,39379786,39379782,39379787,39379792,39379765,39379793,39379776,39379798,39379825,39379797,39379799,39379793,39379792,39379798,39379801,39379806,39379808,39379775,39379783,39379806,39379781,39379801,39379800,39379800,39379795,39379811,39379804,39379805,39379810,39379792,39379794,39379806,39379808,39379809,39379811,39379788,39379793,39379795,39379807,39379811,39379812,39379806,39379812,39379803,39379832,39379815,39379818,39379807,39379812,39379822,39379798,39379813,39379814,39379799,39379812,39379814,39379814,39379816,39379819,39379820,39379821,39379840,39379804,39379813,39379815,39379821,39379826,39379817,39379817,39379818,39379822,39379828,39379807,39379818,39379821,39379821,39379825,39379823,39379824,39379828,39379827,39379819,39379823,39379828,39379832,39379840,39379817,39379825,39379828,39379827,39379829,39379832,39379823,39379836,39379821,40671628,39379825,39379831,39591165,40671628,39591165,40671629,39379826,39591166,40671630,39379826,40671630,39379831,39379834,40671631,39379832,39379841,39712672,40671631,40671632,39379840,39591168,40671632,40664254,40671633,39379838,39591167,40664255,40671633,39379841,39379842,39379844,40671634,39379835,39379840,39379846,40671635,39461636,39591171,40671635,39591172,39591174,39379842,39379869,39379846,39591174,40671637,39379847,39379870,39576502,40671638,39379845,40671638,39379847,39379871,40671639,39379846,39379847,39379857,39379871,40671639,39379850,39379851,39379853,39379872,39379873,39591175,40671640,39379853,39379873,39379848,39379850,39379873,39379850,39379855,39379874,39379874,39591178,40671642,39379874,39591179,40671642,39379853,39379854,39379875,39379875,40671643,39379855,39379875,39379877,40671643,39379876,40671644,39379854,39379874,39379876,39379877,39591181,39848616,40671644,39379871,39379877,39379877,40671645,39379877,39379878,39379878,39379867,39379879,39379879,39591184,39379879,39379880,39379880,39379881,39379882,39379882,39379884,39379885,40671653,40671654,40671655,39591195,39591198,39379896,40671666,39379899,39553270,39591203,39591203,39591204,39591204,39719587,39848637,39926151,40341615,40671667,39379900,39591206,39848637,40004232,40671667,39591206,40671668,39591205,39406953,39952255,39543456,39672994,39703833,40833642,39726656,39726657,40845052,39773216,39773292,39773368,40045398,39802516,39802519,39802521,39802524,39802507,39802509,39802510,39802512,39802512,39802523,39802523,39802524,39802524,39802508,39802523,39802524,39802524,39802525,39802510,39802524,39802524,39802525,39802525,39802526,39802525,39802526,39802526,39802527,39802527,39802527,39802528,39802528,39802529,40882983,40882985,40882986,39802539,39802540,39802541,39930908,40882987,39802541,40059957,40875609,40882987,39802541,40875609,40882988,39829937,40875610,40882988,40882989,40882989,39844783,40904147,39857348,39857421,39857489,40910468,40045538,41004497,40059291,40059292,40059292,40188340,41011370,41011371,40160841,40160885,41062170,40317387,40317388,40317389,40317389,40317390,40317391,40317391,40317392,40317392,40317392,41140417,41140418,41140419,41140419,41140420,41140421,41140421,41140422,41140422,40392091,40392093,41177768,41177770,40472418,40472419,40472428,41217934,41217934,41217939,40497556,41230508,40628621,40883965,40915665,40915735,40915805,41439621,41095591,41529524,41139320,41288298,41303347,41633399,41437265,41700379,41804969,41884209,41900508,41931984,41948687,41948688,41948688,41948689,41948690,41948835,41948836,41948833,41948837,41948837,41948838,41948838,41948981,41948984,41948984,41948985,41948985,41948985,41956215,41956215],\"xaxis\":\"x\",\"y\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,29,27550,1237,1324,877,475,205,962,125,3088,193,164,22,2,365,420,377,94,844,1705,19519,7251,1705,1827,1688,150,1616,1042,1831,246,619,380,469,308,581,553,138,710,2251,9345,2255,275,451,582,191,852,605,429,277,462,1928,69,276,680,267,1863,202,151,280,197,484,567,452,1221,717,81,126,1043,449,197,878,1895,2773,247,194,165,648,621,1,0,0,0,0,584,362,661,141,4,468,307,580,1,379,552,95,137,453,1449,1309,6501,953,51511,30783,5472,15573,3741,1771,881,4273,4058,4535,3273,240,307,249,474,206,691,736,2957,592,70,3463,327,542,549,507,2688,1586,1199,2401,118,2456,2849,2413,1214,3,709,2598,1663,7361,3812,7366,2093,3463,679,1015,8365,2894,1362,364,885,1583,645,1039,1698,1715,514,77,103,172,925,991,345,325,259,392,2611,1540,1080,485,56,72,2114,301,1066,1100,217,591,350,137,625,1715,214,322,5159,1100,301,2467,254,518,169,1829,806,2063,806,493,395,453,1026,455,312,586,484,688,727,597,1185,376,394,211,888,347,858,714,302,2459,78,157,1207,485,170,417,459,126,631,646,183,4,344,215,246,294,415,375,889,630,253,323,2118,903,900,692,1142,284,3,140,1415,891,770,1159,461,1,637,176,1101,340,890,898,1796,218,2119,1842,1196,348,302,1547,338,437,71,947,393,816,654,904,1584,113,343,237,1158,1092,646,887,241,631,948,133,176,1040,859,250,132,519,1,3157,170,475,901,715,207,725,975,1844,1830,442,394,251,1675,647,786,693,807,255,565,1845,1197,535,846,174,1216,546,1144,593,563,368,284,69,807,636,1846,173,833,501,2078,1082,635,170,185,1234,2748,630,3,4,1022,0,0,394,186,178,513,168,187,0,75,1141,900,1,534,254,248,0,2348,1187,743,818,857,283,109,2422,1453,1,347,102,0,0,0,1249,2,256,1065,1809,0,1140,156,552,1248,619,171,24,0,216,301,1025,2713,3100,174,1233,14,688,2270,1668,2264,120,10,0,946,117,2606,203,1583,534,322,2664,2816,724,1766,0,1181,881,2447,1162,1031,1710,3244,1821,539,842,635,8,0,0,1795,1298,1562,1450,1336,213,1202,1,450,101,0,0,533,518,2159,495,1904,2,0,1829,618,1122,3026,1573,2259,1293,1254,282,1127,60,1583,3925,2855,3592,266,975,119,0,0,7001,6238,4884,1306,2444,3,0,22632,18749,5220,1842,392,0,0,38529,7829,4881,862,0,0,51299,38849,1785,0,0,0,0,68312,3075,0,0,123660,1,450,9420,86,368,5460,12140,10424,106,8873,165,326,759,869,1837,901,138,966,238,539,302,225,4,245,407,90,67,128,100,183,663,582,1485,6658,338,161,742,0,0,0,243,204,1562,1855,2159,1851,186,240,274,210,208,564,342,87,104,262,3973,1117,1229,127,206,447,6320,6560,92,567,601,99,1319,258,318,502,1048,174,4,1482,8761,470,785,1201,709,471,196,2004,607,171,183,542,267,2326,582,105,897,491,2153,1344,1279,581,1636,2380,1227,263,61,242,1260,263,155,434,598,240,277,411,920,253,413,129,191,1193,616,899,1897,6300,91,64,493,319,205,166,561,479,443,272,180,1352,207,786,610,330,125,480,203,407,407,320,939,1344,71,173,84,296,97,242,1118,265,897,1085,276,69,241,934,670,510,289,72,170,152,429,125,198,1224,577,359,1273,624,453,78,230,120,169,968,835,100,139,611,266,448,579,519,493,203,138,1259,519,788,918,1332,472,1280,361,264,612,233,7,1038,462,449,378,243,580,581,221,311,333,188,405,59,361,254,608,515,68,846,226,1039,72,271,5,246,323,244,242,433,452,220,704,637,463,241,511,312,204,278,464,259,2,77,6,919,3,137,332,1098,288,569,688,187,372,172,622,487,451,787,1080,287,581,229,1297,953,54,404,128,169,360,786,190,446,463,1108,111,2153,4247,105,225,461,615,410,1212,2277,2664,1576,3759,67,20879,114,166,35718,14166,11832,0,21749,15157,36220,0,30,8,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,4,0,1,0,25,32955,716,1197,10729,4230,270,74,37,652,102,582,19,734,417,1,172,154,109,233,167,59,191,1400,16306,1692,1,1844,403,8833,3785,95,1254,1050,294,191,142,364,140,130,477,747,412,146,129,2698,9908,104,1119,220,249,983,240,556,408,405,6380,81,104,1460,367,80,195,140,117,184,1410,9304,67,280,1155,527,887,216,516,280,179,402,125,1148,704,960,7892,299,271,96,281,493,1021,294,528,143,559,187,890,966,2235,104,432,344,2052,7,293,177,190,215,871,190,418,368,281,143,3,1319,365,196,139,403,155,131,476,110,746,304,141,348,1869,118,229,255,27,294,1,338,705,1156,250,411,1854,6,9888,73,72943,1,1,87168,2047,1749,3193,12079,8228,12090,10634,7648,1830,65,7,877,363,16,9,241,30,7,352,4149,4044,4542,15910,11861,23306,19482,2536,1063,234,367,2238,376,1846,1355,213,158,33,615,941,2165,2141,1098,813,2,276,3079,1186,2379,1589,129,6,8856,10612,8401,3240,1343,21,20754,10218,2360,837,57,2,59789,9242,1834,341,1196,26,3,8,438,95576,10458,455,5,3933,1096,184,2,7,45,90997,3395,3524,18631,3940,211,581,2,238,72,725,5,53,7815,22482,64199,11821,695,175,401,50,596,31,13,168,66,24,364,5,3362,7355,1276,110,22763,5977,266,453,159,101232,343,2976,3450,3895,918,611,314,739,169,772,364,91,7,273,156,304,138,1024,190,2,616,47,236,118,131,640,131,12270,12174,39250,18790,2425,6070,3483,7693,713,4724,1012,1363,27,625,1700,2,542,675,643,695,7109,2465,671,201,86,710,10,134,656,11,4,5421,3143,1327,416,456,338,606,478,10,157,247,256,5618,3987,1828,1036,3701,715,862,1093,1792,8,210,493,155,22677,2407,1080,2029,4284,3878,5485,1634,1261,849,6,2355,564,1369,510,1199,314,120,333,42,3926,7606,2360,9100,4746,4862,2273,1945,19,349,279,813,888,58,1370,7378,1522,1004,360,181,220,468,522,3506,901,1217,771,302,683,557,101,169,558,57,1831,5014,5104,1411,32,254,272,305,315,363,769,883,376,5,543,221,3056,2319,1050,1789,1861,528,1089,29,308,2893,11663,2781,2118,417,3103,51,1645,24,245,585,291,8566,702,302,521,184,42,536,290,613,413,4352,2966,1527,716,831,386,713,1571,452,3740,8701,3986,2080,602,2958,369,1501,2147,3252,1590,295,7067,1080,203,1168,807,205,272,1224,541,40,3060,331,23,1422,13,1317,3143,1904,8118,3327,1671,637,49,475,316,439,59,1989,1071,28,1468,724,336,1591,1831,1352,846,822,3896,934,234,203,598,474,585,20,3324,480,332,634,418,1072,92,717,28,29,1432,477,19,7,91,22,626,333,1007,18,2482,2231,1805,373,3412,334,253,355,447,12,2065,372,271,1222,1569,335,242,544,3073,316,2032,2569,814,5,213,1467,3031,17879,1952,695,364,260,8,4,451,1125,708,1962,392,326,211,559,11,228,3259,512,761,1149,655,2546,419,294,476,7052,451,400,51475,1817,11458,5469,4065,3003,4040,3502,861,2859,1153,2473,1887,64,2519,773,0,5564,32955,6866,2914,695,4898,3156,278,5143,586,3494,803,738,1587,1,3597,720,2185,412,694,460,12707,10510,7230,3630,5360,163,6081,758,3059,988,923,2290,2234,6326,4899,5047,3281,502,4503,2894,760,920,626,8939,7814,4432,3128,458,2418,6,189,1328,3015,8950,8260,905,2164,479,2550,985,8804,1069,12681,1885,2716,9,1719,1392,613,26189,2102,5901,693,1677,833,1819,1981,1011,277,976,15033,46402,3999,597,4835,4783,5,14692,3572,693,3414,1668,28678,8503,26670,24193,5236,21022,16429,10446,7675,81298,0,73025,323,27,306,354,3,8,22,33,236,212,80,77,71,14,2,49,2,6,1,2,6,1,29,9,0,33,2,25,59,209,105,253,368,0,0,0,0,0,0,0,12728,5941,1775,2566,13117,1708,83,570,972,2353,4450,990,5323,885,750,754,68,708,396,1034,487,217,419,683,166,278,411,1029,23,135,300,102,418,73,238,186,460,215,228,443,618,79,156,195,129,167,32,108,154,198,873,272,745,1349,379,2177,0,2075,655,479,2236,263,698,882,603,177,1145,256,640,495,730,142,341,220,138,27,306,79,209,189,0,1304,1185,344,412,232,258,450,542,278,561,129,236,539,476,364,183,23,259,38,102,149,0,1467,512,281,464,493,419,83,1604,116,280,29,2,270,195,11,186,129,213,99,194,645,982,193,1599,991,202,409,3516,662,2223,935,214,1549,536,222,228,347,368,291,125,67,870,184,584,177,518,180,124,85,833,0,484,263,271,91,121,157,159,295,593,127,44,0,273,707,2,343,79,417,115,274,486,0,460,857,1718,231,503,76,151,17,3,0,588,1069,407,157,693,173,110,163,197,964,219,179,2,27,0,0,1365,265,1423,7,211,726,5,282,374,423,43,363,105,560,170,274,656,409,18,271,150,979,0,191,402,101,159,176,107,180,114,249,1594,4900,2553,706,4,514,589,532,555,174,305,224,321,231,109,183,169,218,435,182,339,315,707,1,55,638,0,2031,122,160,259,145,489,601,277,210,224,255,92,1789,156,834,322,2561,306,280,1398,8,274,841,259,25,218,559,372,887,983,123,369,343,34,243,198,446,0,0,193,575,271,1059,373,191,2,66,678,128,310,8,0,172,347,192,350,226,250,358,266,33,145,140,6,195,445,706,75,125,215,159,365,346,109,48,1256,1355,598,2663,312,405,795,528,241,1089,260,369,417,122,462,178,252,271,242,170,298,0,511,321,340,287,475,270,729,321,258,418,191,161,70,277,730,225,705,153,452,144,234,209,155,260,305,411,68,250,99,0,509,285,269,1,750,212,3,418,402,864,99,248,916,319,607,783,903,198,446,376,169,106,186,281,188,805,914,209,761,60,0,0,0,218,195,280,533,153,499,165,520,11,444,373,404,497,98,372,357,1121,356,58,1082,74,506,152,490,226,602,199,770,196,190,346,356,268,395,0,1117,410,318,689,177,1981,831,530,96,439,378,853,239,221,404,118,3,279,331,349,429,64,199,2697,215,420,484,297,403,273,42,0,272,141,308,142,269,501,1230,749,228,441,244,242,233,490,238,173,741,222,385,362,271,201,214,0,370,409,294,728,317,4,292,199,307,363,136,214,532,749,97,419,391,347,4,90,117,223,0,445,141,101,0,391,323,417,96,239,270,230,377,108,342,537,363,152,500,219,209,156,375,273,274,341,295,483,104,469,326,524,280,100,366,560,271,587,217,216,559,408,122,463,107,168,145,182,214,756,433,48,374,342,472,272,381,43,444,229,407,726,481,199,240,559,289,373,1448,381,649,217,140,1067,361,672,198,168,636,2826,201,2767,1023,864,220,888,138,105,78,228,155,257,183,145,181,208,194,1,195,128,400,47,166,2,364,117,139,219,1580,529,1059,22,294,363,204,449,635,584,2,160,373,278,231,116,32,439,341,490,760,372,122,338,371,219,1,1219,103,242,2645,1024,463,623,23,3375,333,527,522,1389,0,7922,5300,4919,2079,4478,4441,5935,663,2575,10565,4183,6616,11226,21016,22470,27,22,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,69,0,0,0,0,4,0,0,0,1,0,1,0,3,8,4000,1525,247,3132,590,279,67,161,7,134,2268,171,58,714,6175,5351,306,357,73,397,161,230,1699,828,271,237,88,999,249,109,142,124,61,22,146,72,19,510,421,2331,206,89,681,32,152,29,44,58,62,224,3,2,7,0,0,0,0,23,145,71,8,399,573,30,1599,2396,32,34,1,297,14,590,85,89,238,60,1185,462,15685,9509,756,147,2089,192,1210,114,75,210,950,76,345,830,363,3,258,31,603,4466,318,11062,158,97,81,282,1228,80,189,45,120,552,993,512,1426,570,480,453,265,159,7,101,247,96,31,742,91,71,6158,452,459,752,668,165,54,236,525,3600,148,179,355,387,82,78,62,1374,728,114,57,64,45,207,460,148,276,21,454,291,27,1691,296,67,294,172,193,173,432,310,266,312,115,669,76,22,33,174,212,166,141,393,419,77,96,300,36,829,3,237,301,670,455,64,4,134,126,292,32,302,2,384,222,535,3603,72,151,212,75,129,121,185,95,114,103,473,98,41,6,244,86,141,33,75,536,317,11,13,276,129,1469,171,439,461,272,3134,1046,1812,3532,52,406,211,2304,372,1544,391,395,474,501,109,266,199,812,637,821,29,109,60,547,28,7,2,308,3,95,5,295,4,0,348,71,6,51,2,128,128,100,142,325,528,422,474,926,13,621,76,238,93,64,73,256,67,73,418,168,79,0,281,320,297,13,70,309,144,28,460,46,273,3,187,177,552,1089,96,1406,157,170,93,277,726,34,6,204,588,920,169,196,346,4,110,92,232,387,6,0,1267,979,205,305,380,57,1,98,134,409,357,1,197,1953,1797,1550,590,350,7,234,195,136,154,252,2012,150,0,0,51,94,301,265,1161,254,44,22,210,455,130,165,1135,11,339,127,3,754,2357,459,296,212,7,183,224,1027,390,199,1380,1579,116,0,0,2365,554,298,133,103,74,327,168,334,1040,0,0,3049,758,169,34,1534,173,1313,3,126,3111,12,0,287,143,93,163,69,801,452,369,746,605,1295,47,1,396,1332,76,143,92,1036,168,205,145,267,298,500,171,184,108,132,265,411,6,63,167,6,2,499,243,197,0,331,1082,889,1353,4,0,460,236,62,991,215,311,828,1062,146,2867,341,310,861,497,996,457,235,395,2996,5333,0,0,208,456,28,108,236,396,1007,340,135,266,469,2,8613,11601,447,576,2140,160,1,120,65,20,182,31,50,68,86,52,63,37,37,16,47,62,29,2,0,23,257,118,131,783,375,825,2911,468,752,2306,0,0,0,0,0,806,463,75,425,54,191,236,372,252,264,46,104,116,144,98,195,126,357,572,235,473,3270,285,873,1393,237,109,37,622,86,153,802,839,51,78,41,89,130,0,32,16,410,134,625,13,139,714,0,159,106,76,146,288,23,260,306,125,119,45,36,108,0,79,175,192,104,23,151,85,180,30,90,373,51,131,29,41,37,313,53,80,152,265,47,62,84,38,38,103,115,15,36,46,61,6,60,25,11,130,8,20,143,2,10,102,97,2,25,305,28,191,89,194,101,40,125,127,256,31,124,453,36,147,80,140,88,130,29,163,780,2075,80,236,855,166,450,262,215,1003,265,579,374,1478,4744,5665,1067,2074,8640,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,2,0,0,0,1,1,1,1,2,2,14,3,17,3,1,3,2,1,1,1,1,1,90,114,23,1,2,2,2,3,10,1,10,1,2,2,5,4,7,2,1,1,2,160,7,2,4,8,5,5,1,4,7,7,7,2,6,1,1,1,323,5,2,6,12,3,6,6,10,18,7,4,5,4,6,11,4,3,7,41,31,126,109,38,43,38,20,8,1,5,2,3,1,3,8,21,8,13,6,9,3,10,8,8,4,37,43,87,155,49,15,19,4,7,4,2,2,2,3,6,2,1,3,9,5,3,6,8,11,9,4,4,7,7,3,5,8,4,4,3,7,7,13,7,3,19,8,6,5,4,6,4,6,11,20,8,8,5,5,6,24,3,15,5,9,3,5,0,1,6,1,2,4,3,2,1,0,2,5,4,1,16,10,17,15,2,2,8,1,0,42,46,11,4,4,5,0,123,29,27,27,14,5,1,2,1,0,0,0,149,71,75,12,23,5,3,2,5,2,1,1,0,0,0,0,53,53,26,21,9,7,5,4,1,0,0,0,77,29,18,15,4,4,8,1,1,1,1,0,0,0,79,68,21,9,2,1,1,1,1,2,2,2,0,53,34,24,2,4,1,1,0,0,0,71,19,11,8,1,5,1,1,2,2,1,0,0,0,0,37,11,15,9,6,4,1,1,1,1,0,0,0,0,24,12,10,2,3,6,1,0,0,0,0,20,3,2,1,1,6,0,0,16,8,4,1,3,2,1,0,0,0,0,0,2,2,2,1,1,7,0,0,2,3,1,2,0,0,1,2,1,1,0,0,0,0,3,1,1,0,0,0,1,2,0,2,0,2,1,0,0,3,1,0,0,1,0,0,0,0,0,0,23,2234,1030,1081,583,1026,171,28,199,233,4,87,1217,16179,13814,1,1,1,514,873,891,159,695,187,153,708,228,362,225,196,231,606,164,172,30,165,194,11,9,2,16,6,0,0,0,0,9,0,6,0,0,197,88,232,1055,696,21560,1,1,14787,1430,1238,4581,6068,77,1205,1832,1003,1091,1252,379,837,2882,192,366,416,112,896,1285,469,630,962,1829,7,490,305,688,345,691,486,848,1936,1379,918,211,99,330,304,1170,735,537,222,68,202,1820,965,2414,1364,613,1603,339,2431,251,224,1020,396,10,718,22,17,58,403,18,141,145,1,79,522,375,186,5,1012,752,275,1143,2118,470,15,649,852,746,760,154,330,285,964,502,124,206,212,234,493,367,1455,616,189,178,385,72,270,109,257,269,497,357,269,420,120,1031,276,208,2471,511,280,634,377,640,57,2,326,316,20,67,279,428,240,28,101,124,75,167,326,369,826,128,194,316,1046,542,236,231,175,781,425,3,77,367,370,478,1304,856,186,156,280,124,281,528,148,0,471,168,78,327,361,846,493,512,257,258,278,370,261,308,3,185,314,827,466,260,55,376,478,6,387,193,117,9,131,17,101,129,281,633,159,222,328,498,390,742,219,436,128,91,138,243,195,155,179,139,23,486,177,1444,391,314,479,156,176,300,487,282,137,670,195,266,45,758,377,456,358,528,155,193,463,392,90,278,117,3,5,103,199,315,472,130,113,186,331,414,268,353,565,270,457,237,513,378,482,180,379,200,315,388,228,317,154,623,169,432,343,480,200,397,157,229,889,91,391,190,490,1466,483,254,168,504,839,194,316,2,624,125,3,2,357,210,269,282,256,623,2,138,2,301,473,318,262,323,103,189,58,0,179,344,489,233,529,111,259,103,691,185,309,277,131,23,6,647,110,156,524,136,1,260,154,617,269,38,329,172,218,358,1,0,2,5,345,1464,378,376,48,243,630,154,116,181,286,106,0,1,111,516,141,619,579,100,285,596,267,172,286,581,869,8,32,517,288,25,67,136,34,142,271,224,112,406,672,109,127,6,130,4,6,2,512,344,97,142,102,167,840,84,411,232,440,467,324,609,371,37,86,86,377,486,540,591,257,481,259,38,668,132,255,168,684,447,357,211,152,248,985,154,58,1532,137,1452,391,420,312,627,135,85,291,277,90,41,131,1018,591,391,286,258,0,0,141,0,1,989,284,254,365,71,4,2,184,218,259,69,132,0,57,412,201,553,5875,2109,881,65,360,585,838,757,86,475,856,217,46,20,18,184,2,0,91,90,138,357,395,258,2143,121,962,389,278,189,1023,244,343,285,42,1995,1758,1990,1810,2300,3598,1222,687,434,532,96,0,645,44,112,530,0,453,814,2404,1716,2010,870,974,142,188,6,102,295,267,166,62,1255,346,770,1532,300,150,100,64,1154,1225,1613,448,239,721,434,631,139,223,179,529,821,3602,1896,1798,1058,622,696,407,1176,618,178,241,411,544,742,155,270,210,250,3560,2465,1056,560,74,287,129,89,200,68,376,1,5544,3424,4001,3127,665,1820,76,158,530,612,124,234,152,1,427,176,91,640,136,49,267,39,52,1109,1,2552,3094,2203,1672,565,92,131,1225,17,236,420,258,530,177,625,239,288,378,220,398,5874,1635,308,6,540,489,712,465,287,908,52,322,223,641,440,6140,3184,1453,1656,1548,438,503,328,100,450,401,176,488,160,72,121,246,177,811,665,369,2995,2069,474,577,1106,1811,560,274,240,1011,313,2,101,116,447,6,69,453,154,373,130,3,1009,397,427,676,1757,1200,798,436,980,1658,949,537,265,2,341,747,244,157,247,544,364,880,170,903,530,687,1755,785,769,606,114,485,38,178,144,360,265,87,238,381,450,502,1100,504,109,437,529,552,221,150,282,288,44,333,234,761,578,520,317,159,281,174,285,1133,617,836,1094,688,388,193,128,989,129,585,434,130,113,430,292,662,748,1110,284,835,763,1103,720,818,303,394,235,251,820,277,830,464,758,1064,176,127,466,772,279,482,108,334,213,11,265,112,453,30,95,201,286,235,397,486,752,692,20,217,280,777,188,1309,306,245,23,1038,262,755,398,521,9,694,2,267,101,102,814,376,538,427,174,126,242,142,653,421,256,518,190,198,487,342,409,890,619,226,467,314,287,200,157,227,177,501,410,1175,177,245,392,714,226,53,316,630,140,419,517,487,234,474,687,465,261,529,176,158,500,90,261,492,115,157,233,409,189,234,143,801,272,658,462,1304,176,499,446,748,778,0,392,293,156,1642,463,220,243,1349,516,271,107,445,366,68,259,629,850,433,624,959,258,220,1302,741,583,817,260,1286,858,306,743,1118,314,282,1321,238,1437,4172,3111,292,482,525,262,647,495,281,112,582,239,177,156,455,359,2256,1875,1463,100,844,1515,990,141,3270,1159,101,543,426,143,246,269,17239,146,7393,463,6457,32594,0,0,0,544,1025,10145,18475,408,259,77,415,249,137,103,227,60,998,207,118,198,70,316,148,137,229,540,180,87,948,655,180,430,470,207,2548,8612,0,0,0,0,1735,128,211,582,235,374,125,98,410,486,130,86,203,241,400,129,184,382,432,359,641,1262,368,2785,6133,0,0,171,148,215,1118,473,30,162,56,127,76,29,257,84,215,73,105,117,261,134,67,314,64,167,139,194,55,75,180,102,124,226,156,225,311,139,234,393,170,536,206,129,140,117,85,197,104,165,271,184,54,255,198,147,240,136,228,312,510,312,324,147,36,878,86,260,133,165,135,132,265,136,83,517,466,89,233,332,1463,121,224,375,657,339,795,98,753,3148,449,746,10227,0,54,0,0,0,0,0,0,0,0,0,0,0,0,12,6953,1658,113,840,93,8081,44,248,40,107,147,133,339,6011,4679,1,1,695,426,672,3431,1162,657,401,209,1082,605,85,427,64,52,168,989,560,215,169,210,93,2,338,168,169,185,137,143,337,716,9469,2703,331,9,32,308,171,209,186,45,383,39,68,41,144,308,181,135,591,479,20541,2,16236,1991,1725,2181,4771,1426,263,3531,249,336,673,842,407,51,773,173,740,2381,687,1023,748,3168,4834,1716,2448,163,723,359,527,115,219,704,15,30,48,414,267,96,20,768,100,1695,1457,244,1444,1778,396,125,443,882,274,1518,169,1038,478,915,357,1451,416,1228,290,467,105,156,70,159,472,224,266,25,297,701,418,543,170,664,165,310,379,132,100,661,237,11,23,127,1151,494,665,157,484,93,15,288,331,81,7,5,101,461,459,345,18,334,418,99,140,2,125,214,199,2237,2239,285,103,194,48,98,79,143,88,447,66,50,159,304,556,56,79,183,121,35,245,148,106,1,12,147,82,334,403,212,51,328,147,113,312,921,270,741,310,252,19,209,351,666,294,95,94,121,103,148,19,115,335,141,367,168,686,419,174,59,373,367,83,198,85,26,256,106,48,1,275,158,1,335,9,197,44,352,252,100,495,687,280,570,380,595,457,494,364,496,211,571,67,213,444,90,90,141,122,459,113,916,545,464,940,3,3,49,523,151,572,51,473,149,739,2017,313,88,215,527,257,198,114,264,201,114,242,65,94,106,451,2576,57,362,301,253,329,38,101,60,279,48,4,127,6863,367,1270,498,756,482,285,267,269,167,397,38,66,70,148,92,111,159,195,4867,8582,195,216,581,1517,1512,181,992,930,364,300,193,568,147,1802,5,117,403,159,186,277,64,156,4912,1365,351,945,440,592,1159,335,29,317,57,3,467,149,93,279,1499,264,1505,1993,3674,686,1252,2149,0,407,917,1723,548,259,117,1408,822,626,65,724,1322,72,833,255,670,311,354,644,522,157,1091,88,338,88,140,410,254,164,974,1248,357,608,155,71,107,2,158,27,249,393,209,236,62,76,1646,178,878,2272,305,196,243,154,235,668,38,101,191,147,188,11,122,14,888,2494,1692,899,250,939,1687,839,97,301,773,142,23,213,14,245,111,79,15,497,770,40,152,869,268,177,67,2390,39,162,1791,1410,30,161,1716,343,185,448,54,238,224,94,80,201,436,1954,3643,2326,164,115,1295,290,445,755,318,201,261,265,691,1,39,734,92,1186,327,169,67,129,55,475,582,82,143,252,352,1929,1037,20,49,48,816,298,46,2870,724,89,264,6253,247,315,3,203,717,105,221,273,58,400,1400,2,419,536,699,240,382,427,559,5295,682,4,2,86,913,147,709,99,1243,1247,257,641,112,418,154,96,37,191,581,978,258,160,126,4,590,443,7,877,260,146,116,26,5568,1867,680,422,82,252,461,1192,1039,1117,251,171,246,298,254,4398,466,122,807,782,4580,810,76,301,57,128,341,1197,1067,401,4,2,145,26,1726,375,9,873,1268,0,66,291,256,242,458,118,297,1162,35,88,1111,0,429,64,2,948,7,550,1056,290,87,300,100,234,451,450,216,336,56,227,91,350,1249,766,190,595,3,268,616,773,255,246,301,2319,1014,1388,237,104,864,168,260,178,212,633,185,425,656,494,2373,581,643,209,131,243,1365,21,578,572,2596,1165,331,2077,560,167,735,36,245,120,111,351,226,166,245,248,364,200,371,1,427,1153,799,1443,8174,17572,93,427,311,1417,92,924,0,331,2699,0,15339,22468,523,17,20,232,61,158,62,54,45,36,38,29,2,77,53,19,104,163,34,577,5103,0,0,0,0,0,2080,438,233,173,443,628,551,405,242,153,257,170,16,73,271,55,43,223,0,125,308,60,81,69,313,84,22,103,526,197,139,346,2106,11004,146,68,96,60,103,418,1686,204,145,100,19,433,230,232,167,71,30,138,189,61,147,504,120,32,573,131,147,620,467,41,204,44,37,37,130,258,227,42,30,3,17,74,95,179,54,146,42,46,66,192,54,133,175,413,38,100,176,41,124,305,59,80,257,68,45,414,506,63,60,35,66,155,62,374,523,363,409,4138,28,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,2,6,3389,385,27,107,761,2934,172,16,1,96,105,86,56,78,79,22,457,516,12186,10293,105,91,800,263,537,989,648,132,256,135,92,108,187,411,169,77,39,1957,1711,173,262,12,3,97,106,87,57,78,128,79,272,61,459,736,325,17879,14597,1941,528,1335,3465,3026,191,176,1074,1114,855,81,805,634,2623,254,1092,401,770,51,16,955,712,784,2695,5673,2741,5605,1648,801,3,2775,89,13,20,269,3,76,72,802,108,216,175,24,265,92,136,1850,1,341,794,547,740,834,969,84,511,118,66,371,2003,130,149,715,304,387,1096,46,2301,1054,295,524,167,141,236,77,817,472,50,209,343,94,167,450,238,126,346,329,548,493,516,156,154,279,307,1,619,670,1166,160,378,381,94,195,253,954,244,157,282,148,310,123,410,456,381,237,317,192,178,378,54,237,945,431,8,142,144,237,1105,136,155,153,656,280,487,714,182,131,184,137,119,82,171,829,2,154,2,78,447,343,138,5,217,769,160,986,910,573,656,172,161,85,4,542,188,131,255,379,156,120,107,193,705,261,558,2,117,142,380,255,191,102,79,1015,157,279,150,310,156,655,2,51,656,161,17,299,956,172,108,314,228,304,371,42,55,1682,77,132,5,264,194,587,978,1668,419,328,1390,350,257,4,2,56,276,4525,3379,1630,1162,227,1892,169,17,281,623,435,87,100,2,619,5833,2004,1801,2437,2,128,146,134,133,179,228,458,53,492,235,47,276,6368,3035,413,8561,113,271,610,42,507,470,108,636,81,249,195,357,419,216,131,183,4,210,84,305,169,367,4565,4960,364,49,239,383,157,236,931,263,262,794,277,222,256,160,472,270,7382,183,6,55,135,95,437,232,277,4,352,26,1456,968,1108,18,81,158,6,267,189,100,563,162,3,4,2,228,110,1002,283,928,593,1505,359,689,1890,2802,1652,980,3543,2317,1336,454,105,3690,666,1279,1170,170,206,174,1096,595,474,190,547,990,109,82,299,62,89,1211,1,5,363,163,644,90,535,4,116,280,49,660,499,270,216,351,1,5,236,262,91,172,732,571,147,58,228,372,14,55,733,6,240,173,179,136,95,145,384,546,1,464,299,128,41,113,16,330,229,550,463,98,2706,463,452,387,1355,134,364,167,318,66,320,0,770,954,81,33,940,280,146,2,954,6,136,3399,1081,453,4118,272,363,417,133,5,5,197,120,217,317,311,493,0,677,135,280,4214,548,968,300,319,388,346,3,1353,1,0,0,161,2603,220,237,112,282,310,170,1093,353,483,262,5,321,439,193,104,717,174,3734,7244,2400,1350,307,1,738,153,103,931,4,74,116,165,191,615,619,167,471,5318,0,2729,1002,608,246,59,637,121,817,1556,5855,1551,76,441,157,407,284,1,287,192,408,300,385,1619,269,4082,251,638,547,1572,134,227,227,874,50,305,1184,366,1272,1543,114,440,2580,160,303,381,277,448,818,402,2048,1,149,76,205,145,512,780,462,173,4,324,880,360,199,206,1613,202,620,1909,363,371,152,194,133,461,672,279,226,193,554,311,234,477,359,374,557,94,747,132,2119,215,181,544,157,628,476,350,766,442,304,360,634,0,310,50,1038,278,83,311,786,373,1312,486,1689,409,335,645,742,279,924,3268,0,142,156,1109,3325,0,607,1226,7729,475,1624,9285,32308,23,1,5,2,60,6,2,9,81,7,61,1,1,1,4,1,27,3,0,4,1,65,442,15,301,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1748,183,1288,736,210,167,904,130,58,296,1795,58,82,430,166,77,147,52,217,266,211,1506,143,109,238,53,26,102,96,158,9,123,188,73,340,83,611,69,228,93,191,82,153,80,117,179,230,408,859,791,1081,1487,1953,7880,38,1302,0,0,178,110,267,267,136,84,162,22,513,12,182,0,0,324,57,177,169,115,46,38,121,361,47,130,94,323,184,1,146,323,62,101,23,101,245,151,83,106,3,77,95,88,335,3,0,1,129,56,10,57,60,103,80,132,155,121,153,151,59,63,104,109,84,179,152,363,72,792,23,0,32,28,273,156,45,35,143,243,77,120,168,284,74,147,102,60,183,152,90,76,0,79,114,0,44,0,58,266,352,36,53,73,0,201,13,196,135,140,146,139,70,23,140,273,312,138,668,77,144,142,83,24,220,16,54,101,25,101,244,44,52,0,83,73,0,8,113,315,20,51,82,158,38,72,7,63,99,138,119,92,2,187,11,35,256,56,141,407,8,6,69,2,50,258,322,76,92,0,190,34,139,81,151,272,364,103,217,0,108,115,177,311,207,45,1046,237,570,222,864,99,170,926,188,896,9,270,849,1392,11,1925,3135,65,5592,442,3298,23782,0,3326,17,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,0,1,1,0,0,4,6,0,0,0,2,0,0,2,0,0,1,2,1,0,1,0,1,0,1,0,1,0,1,0,1,3,1,1,1,1,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,1,1,0,0,0,2,0,0,1,0,1,1,1,31,2,2,2,20,20,5,10,7,9,2,2,1,2,1,1,3,2,2,1,5,1,12,9,1,7,18,5,8,4,5,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,4,3,4,1,1,3,2,2,5,2,1,1,3,3,2,1,2,2,1,1,2,0,12,3,2,0,2,1,1,0,0,0,0,0,5,11,10,6,1,4,2,2,3,3,4,0,0,0,0,9,3,3,1,1,2,2,2,4,1,3,0,0,0,0,21,15,4,3,1,2,2,2,3,10,10,6,3,3,0,0,0,0,0,22,5,6,6,1,4,5,3,19,7,6,1,0,0,0,0,0,0,0,13,2,2,4,3,2,3,4,26,18,2,0,0,0,0,0,0,3,10,1,4,11,11,13,1,1,0,1,1,2,2,1,2,2,14,1,9,2,0,0,0,10,2,3,2,2,3,1,2,0,1,3,3,0,0,0,7,3,1,2,0,3,5,1,2,3,2,1,0,3,2,2,1,1,0,0,0,4,2,2,4,0,1,1,1,3,1,2,1,0,0,0,0,2,0,0,2,1,0,1,0,0,1,0,1,0,1,2,0,0,1,3,0,2,1,3,1,0,0,3,2,0,0,1,0,0,0,0,18,14,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,2,0,1,0,1,5,5,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,1,2,0,0,0,1,1,1,0,0,0,1,1,0,0,2,3,7,0,0,0,0,0,0,0,0,0,1,1,2,1,1,1,5,0,0,0,0,0,0,0,0,0,0,2,1,1,1,1,1,2,1,1,2,2,15,3,1,1,1,2,2,6,1,1,0,0,1,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,1,1,1,2,1,0,0,0,0,0,0,1,2,1,0,6,0,0,0,1,0,1,2,1,6,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,1,0,0,0,0,7,1,1,1,1,1,3,1,7,2,94,37,2,1,1,2,1,1,2,1,1,4,1,0,2,0,0,0,0,1,0,11,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,1,1,3,1,5,2,3,1,18,1,7,85,36,1,1,6,1,9,1,2,2,1,4,0,6,1,1,0,0,0,0,0,0,0,4,0,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,2,4,10,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,4,3,1,0,0,0,0,0,0,0,0,0,0,0,2,0,1,9,20,10,0,0,0,0,0,9,16,2,8,1,1,2,4,2,2,1,3,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,0,0,0,1,0,1,0,2,0,1,0,1,1,2,2,3,2,1,2,2,1,1,1,1,3,1,1,1,5,4,16,1,9,1,4,58,34,3,2,2,2,6,20,28,2,1,1,6,18,11,1,1,1,5,1,1,0,0,3,1,1,0,0,0,9,4,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,2,1,1,3,1,1,1,11,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,2,2,5,1,2,1,1,3,1,1,4,2,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,1,1,6,1,2,1,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,4,1,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,1,1,1,3,1,1,1,3,1,4,1,1,1,1,1,2,4,6,1,1,1,3,2,1,19,5,4,1,4,4,2,2,6,3,3,3,1,5,7,4,3,2,5,1,3,1,5,4,5,7,10,16,9,1,1,2,3,3,4,3,1,3,3,4,2,3,1,2,2,6,2,2,2,2,2,1,1,1,1,1,2,1,0,0,2,1,2,0,0,2,3,1,0,0,0,0,4,4,2,0,0,0,8,2,0,0,0,0,8,3,2,0,0,0,0,0,2,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,4,2,1,2,0,0,0,0,0,1,1,2,2,2,0,0,1,2,0,2,2,1,0,0,1,0,1,0,1,1,0,0,1,0,1,4,3,0,0,0,0,0,1,0,1,0,1,1,1,0,0,0,6,4,12,4,1,1,1,2,178,1,2,1,956,28,1,2,1,6,4,8,1,2,4,3,2,1,9,1,141,537,22,5,14,16,8,35,6,9,56,18,47,69,23,50,69,43,39,53,26,25,7,28,12,29,16,36,4,4,1,1,7,1,122,9,22,1,1,11,13,10,15,63,27,33,11,52,25,87,60,73,43,70,55,34,10,6,44,12,10,10,1,12,23,14,1,6,15,11,1,16,1,17,1,1,1,7,66,3,13,10,2,24,2,1,29,25,7,14,1,1,10,23,14,4,11,10,37,14,1,3,9,1,13,5,3,17,1,4,1,1,1,48,24,20,1,1,12,2,105,2,41,21,8,3,2,18,32,2,63,58,27,82,75,1,10,11,1,1,2,1,26,123,63,12,1,1,21,24,16,3,3,1,5,1,1,138,73,49,65,11,5,50,46,2,2,3,24,5,1,286,69,33,14,32,31,32,7,3,4,2,2,10,22,3,1,291,23,7,16,56,127,49,60,21,22,6,2,8,2,11,24,7,1,162,51,18,78,164,77,88,61,14,2,2,2,12,21,2,1,4,4,5,46,103,124,37,18,3,3,5,4,5,26,47,2,24,8,38,32,9,12,6,2,4,4,2,7,5,1,19,4,12,4,2,5,3,1,1,1,103,17,25,2,44,3,4,15,1,303,229,35,49,2,9,7,9,0,428,53,44,70,9,10,4,2,3,2,0,0,0,0,0,0,523,310,106,35,9,6,3,3,7,1,0,434,111,36,11,6,11,7,1,1,0,0,0,536,140,118,92,2,9,11,3,6,1,0,380,210,80,29,8,8,4,5,5,0,0,0,271,127,58,29,17,19,2,9,3,298,120,53,36,16,20,2,6,4,1,0,0,0,278,109,63,43,14,16,4,2,2,6,9,2,0,0,242,151,32,5,8,1,0,0,0,237,74,17,28,6,4,5,13,8,1,0,0,0,284,78,14,26,11,1,4,5,10,9,0,0,0,202,76,29,16,14,6,9,3,13,0,0,0,214,19,18,23,7,3,3,2,0,119,68,22,13,15,20,7,4,3,4,5,3,0,47,61,23,14,6,11,1,1,0,56,34,15,1,3,3,3,0,0,62,31,22,11,3,13,5,2,0,0,0,43,32,17,3,3,18,8,1,0,39,33,2,4,15,0,0,37,2,5,6,19,17,1,1,0,0,20,16,11,34,1,1,0,0,0,0,0,8,9,2,4,14,0,0,16,24,0,0,0,0,134,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,9,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,1,0,1,0,2,0,1,0,1,0,1,1,0,0,12,1,1,3,2,6,20,1,3,1,9,0,0,0,0,0,0,0,0,0,0,1,2,1,0,1,0,1,0,1,0,1,0,1,1,1,1,2,1,1,1,1,2,1,1,2,2,1,1,1,2,1,1,7,1,1,3,3,1,1,1,2,1,2,3,1,3,4,1,11,15,2,7,2,1,2,12,12,1,1,23,7,7,2,10,3,2,2,24,37,6,15,2,4,4,7,9,12,12,7,25,2,2,31,7,5,1,3,2,14,5,1,1,4,38,24,23,10,2,6,16,2,31,14,18,1,1,3,8,4,7,2,2,4,7,11,33,25,2,3,3,13,2,5,16,2,6,18,6,5,5,3,13,14,9,4,2,34,4,15,14,10,16,3,2,9,3,16,18,15,19,6,6,4,1,4,1,4,1,4,1,4,2,0,0,2,2,7,2,4,0,0,0,0,0,0,0,22,1,24,6,4,2,0,0,0,0,0,0,0,14,33,9,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,7,1,1,3,0,0,0,0,62,26,4,4,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,6,16,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,8,8,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,13,9,0,0,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,6,6,1,1,1,1,2,30,7,1,2,4,2,2,1,2,3,1,1,4,2,1,2,1,1,35,9,12,1,2,1,2,4,3,1,2,1,2,10,2,2,2,2,1,1,1,1,17,4,3,1,7,1,10,4,1,1,1,4,1,2,4,8,2,1,4,2,1,1,2,1,2,2,8,1,3,3,2,10,2,1,5,5,5,1,2,1,1,1,1,4,1,1,7,7,1,3,1,4,3,1,3,2,5,3,6,1,3,2,8,1,2,4,4,4,7,2,1,17,3,1,2,2,3,1,3,1,1,1,1,1,2,2,2,6,2,2,1,1,2,5,4,2,1,3,2,8,2,2,1,4,1,1,2,3,2,7,2,2,3,1,1,4,3,6,9,3,3,8,2,1,3,3,2,3,6,2,2,2,3,8,5,2,7,3,7,6,2,1,4,6,4,2,2,6,4,4,16,6,35,7,4,2,1,4,3,2,2,6,4,25,12,6,2,2,2,2,3,6,9,2,3,4,2,2,3,6,27,3,1,10,2,5,9,2,3,3,7,3,17,5,1,2,2,9,5,3,3,15,4,11,1,3,2,2,4,3,2,3,2,3,4,1,3,4,2,2,11,11,3,4,4,5,4,10,4,4,12,2,9,3,2,29,1,2,6,2,6,3,1,1,2,1,2,2,3,8,1,3,1,0,3,4,6,1,11,8,10,4,1,2,1,1,2,7,3,0,0,0,13,2,10,3,3,1,4,0,0,7,10,2,2,2,1,0,0,11,2,2,2,1,1,4,5,4,3,4,3,1,4,0,3,9,4,1,6,1,0,0,4,4,4,2,3,6,0,0,0,0,0,0,14,3,1,2,1,5,0,0,0,4,3,2,1,7,2,1,2,4,0,2,2,2,1,8,0,0,0,0,2,0,0,1,4,0,1,1,0,2,6,1,0,0,0,1,0,0,3,9,4,0,2,2,2,0,0,1,4,0,0,0,2,3,21,45,2,1,0,0,0,0,0,0,0,0,25,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,0,0,0,1,1,1,1,1,5,1,1,4,0,0,0,0,0,0,1,1,4,0,0,0,8,0,0,0,2,0,1,0,1,1,13,5,1,1,1,3,1,1,6,56,4,2,2,70,21,24,3,20,11,57,31,103,818,9,1,12,4,8,5,62,2,1,7,2,1,16,1,4,15,21,0,2,3,2,20,11,55,0,0,0,0,9,20,0,0,102,0,0,0,0,0,81,21,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,0,1,0,1,1,2,1,2,2,1,1,1,1,1,2,1,1,6,5,1,1,1,1,2,3,1,8,8,1,1,1,2,1,103,1,1,4,3,1,2,1,2,8,7,2,1,2,1,4,1,1,1,13,5,1,2,15,20,14,1,5,2,1,1,10,8,2,2,1,5,4,31,32,1,2,8,2,8,47,15,11,32,31,33,17,5,4,2,1,1,2,2,2,2,5,5,2,5,1,1,1,2,1,16,3,1,4,6,1,3,2,1,2,1,1,2,3,3,2,1,1,3,8,2,2,2,3,3,7,1,3,6,4,3,141,13,5,1,3,3,2,8,3,1,1,90,40,90,42,28,11,6,7,12,9,5,7,2,3,1,1,1,17,44,22,19,13,4,11,2,2,43,10,9,8,7,2,3,2,1,95,65,26,9,8,9,5,1,1,1,108,33,38,25,4,4,2,1,1,125,47,62,13,25,9,5,1,1,63,73,34,33,14,15,10,5,80,61,32,7,7,2,7,4,5,3,0,159,83,29,30,7,2,10,8,1,174,8,39,69,7,2,23,8,10,6,1,0,187,105,43,56,9,16,20,3,1,0,0,0,0,0,0,0,0,0,0,124,45,52,58,19,14,1,1,2,1,1,0,0,0,0,125,75,75,24,32,1,23,6,7,0,0,119,56,37,2,12,23,29,16,6,27,10,6,1,1,0,0,104,83,30,49,42,5,9,11,0,1,1,5,1,0,0,0,0,0,0,0,0,0,0,123,32,65,17,12,25,12,7,2,5,3,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,67,54,44,12,8,20,3,10,6,3,1,12,10,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,37,33,16,20,3,1,1,1,1,1,0,0,0,0,0,0,91,67,41,5,42,0,14,14,14,1,1,3,2,0,0,0,0,0,0,0,0,0,95,78,32,31,14,13,10,12,9,0,13,1,0,0,0,0,109,41,67,46,7,10,17,11,1,2,0,0,0,137,114,53,30,10,0,0,66,80,33,46,7,10,7,9,2,2,0,145,190,43,34,14,14,0,3,1,138,129,39,43,18,12,1,4,8,0,234,67,58,42,20,44,12,8,10,4,0,186,170,58,15,23,19,21,16,47,105,66,24,55,28,13,100,2,150,60,16,99,25,16,71,2,1,83,45,2,56,11,16,22,173,2,16,74,16,33,90,16,42,26,24,17,81,2,1,0,23,15,91,1,66,38,86,4,2,38,27,223,3,18,145,9,2,23,17,19,0,15,7,0,0,35,0,16,0,0,37,0,21,20,0,853,50,0,0,0,0,618,3,0,0,0,0,0,0,0,0,0,0,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,2,1,1,1,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,2,1,0,0,0,1,0,1,1,2,491,59,6,9,1,17,9,3,7,8,3,1,15,80,13,39,4,14,13,3,4,3,1,1,158,13,16,16,5,71,19,9,10,3,6,4,37,180,18,48,12,18,11,1,21,28,2,29,23,23,3,1,9,84,5,26,8,2,1,1,12,3,23,1,7,1,3,5,10,2,5,1,1,1,5,1,14,15,20,10,8,12,6,2,2,2,6,3,1,5,12,14,25,67,5,8,5,4,7,4,4,3,5,1,1,2,22,30,9,8,2,10,3,2,1,36,4,6,2,1,2,1,15,34,2,1,1,9,11,2,8,4,33,3,14,2,1,1,11,2,16,3,7,0,34,8,16,13,2,179,250,37,42,11,5,1,1,1,1,0,0,0,0,149,23,9,1,1,3,0,225,98,52,10,8,5,1,1,0,0,0,0,0,0,0,0,0,0,0,204,40,8,3,2,2,0,0,0,0,0,0,199,36,22,3,3,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,129,45,4,1,2,2,2,2,1,3,0,0,0,0,0,0,0,0,0,0,58,7,4,9,4,3,3,1,0,0,0,0,0,0,0,0,0,0,0,5,9,4,8,1,9,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,4,1,2,1,1,0,0,0,0,0,0,5,5,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,1,3,1,1,1,1,3,1,1,2,1,6,1,1,57,28,9,15,21,2,2,1,8,13,30,23,1,39,19,20,20,3,1,3,5,4,7,31,11,44,22,17,13,5,5,6,4,12,22,2,1,21,24,6,1,3,4,6,20,36,24,1,1,32,6,3,5,3,8,21,27,51,2,2,1,3,9,5,16,9,34,23,30,64,3,2,4,5,3,4,3,4,11,4,2,4,2,5,7,10,2,3,2,10,2,8,1,3,1,10,1,2,2,1,14,4,5,3,2,4,13,5,5,0,6,26,11,1,1,0,0,0,0,0,52,29,1,0,0,0,0,0,0,0,0,0,116,7,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,21,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,4,1,1,1,1,0,0,0,0,0,0,0,1,3,1,1,1,0,0,0,0,0,0,0,1,1,4,12,5,1,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,0,0,1,0,1,0,1,1,1,5,1,2,1,0,0,0,0,0,0,0,0,1,2,1,1,2,1,2,1,1,1,0,0,0,0,0,0,0,1,1,1,1,1,1,1,3,9,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,0,1,1,2,0,0,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,8,13,59,40,1,1,2,1,1,166,3,1,1,1,138,37,75,1,1,4,34,9,23,31,54,129,87,89,25,14,2,1,46,18,59,238,140,67,63,37,7,4,5,2,3,1,2,1,14,30,8,15,16,35,27,7,17,16,8,76,1,2,2,1,2,15,5,1,19,18,2,18,81,4,4,2,1,6,12,9,1,1,2,12,10,13,19,2,2,3,78,31,4,29,11,10,12,2,3,2,1,2,1,5,5,2,1,22,5,85,16,26,10,3,7,4,94,5,12,4,32,22,25,2,13,4,2,7,3,1,11,31,65,14,3,3,2,4,5,96,74,5,5,2,2,1,4,10,6,8,33,6,4,9,2,21,1,0,33,7,10,4,6,149,11,3,1,3,82,1,1,6,9,402,178,49,30,13,5,3,3,2,0,0,0,0,0,0,0,0,0,0,336,111,41,7,11,4,1,2,1,6,1,0,0,0,0,0,0,0,424,100,30,18,2,4,1,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,470,43,15,2,4,5,2,7,3,1,5,0,0,0,0,0,0,392,54,35,9,6,1,1,5,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,287,23,20,11,6,3,1,1,3,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,61,5,6,5,3,1,1,14,1,4,0,0,0,0,0,0,0,0,0,101,35,18,1,4,1,8,2,1,1,0,0,0,0,0,0,0,0,0,0,88,23,5,7,4,3,1,0,0,0,0,0,0,0,0,0,0,0,69,13,5,3,1,1,3,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,56,6,2,4,2,2,1,1,0,0,0,0,0,0,0,25,8,2,5,5,5,4,1,0,0,0,0,0,0,0,20,1,2,2,6,0,0,0,0,0,0,0,0,0,6,2,5,3,1,0,0,0,0,0,0,0,3,1,3,0,0,0,0,1,6,3,0,0,0,0,0,0,1,0,0,12,3,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,2,0,1,2,2,2,4,1,1,1,0,0,0,0,2,0,12,0,1,1,1,0,0,0,3,1,1,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,0,0,1,0,1,0,1,2,1,0,1,0,1,0,1,0,2,1,1,1,7,1,1,1,1,11,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,0,1,0,8,0,0,0,1,0,1,0,1,0,2,4,2,0,1,0,1,0,1,2,7,2,0,2,18,9,1,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,1,1,1,1,2,5,2,1,1,3,4,3,3,27,9,2,2,18,12,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,1,0,1,1,0,0,1,0,1,0,1,0,2,1,1,1,4,1,5,3,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,3,1,2,1,2,9,1,3,2,31,38,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,3,9,2,3,1,22,1,1,19,8,3,2,6,15,3,4,1,1,1,11,24,141,8,22,1,1,1,5,3,1,1,1,2,20,15,3,2,3,2,2,3,3,4,2,2,2,2,2,1,2,1,0,8,1,0,22,1,1,0,0,0,0,0,0,0,15,23,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,0,0,0,0,0,3,4,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,0,0,1,0,1,0,2,1,0,0,0,2,0,1,0,4,2,1,1,9,18,1,3,1,1,134,5,1,13,3,2,6,2,2,5,5,127,94,131,28,7,3,2,2,1,2,48,105,57,23,1,3,1,45,59,30,4,7,6,28,27,7,1,1,114,33,2,6,25,16,5,2,6,188,7,18,27,8,33,101,58,37,6,26,30,24,4,3,8,13,20,2,18,140,69,17,14,23,4,25,8,16,5,10,1,10,25,13,2,2,5,4,1,7,12,17,3,1,2,0,15,3,0,6,12,4,1,0,95,21,8,1,11,0,0,0,190,120,24,50,3,0,0,0,0,0,0,126,51,72,5,1,0,0,0,0,0,0,0,0,0,0,74,122,10,0,0,0,0,0,0,0,0,0,0,88,3,4,0,0,0,0,0,0,0,0,0,0,15,12,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,2,1,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,2,1,2,1,2,1,1,1,1,5,1,18,2,4,1,1,1,1,18,48,27,3,3,4,1,1,1,2,1,59,8,3,1,2,2,3,2,1,1,332,88,4,15,20,10,1,4,8,13,12,29,10,13,2,1,3,5,419,19,13,44,14,6,5,3,6,12,7,28,7,31,108,21,11,1,4,1,3,97,51,33,31,18,3,2,4,2,26,46,47,156,161,79,31,13,6,3,6,18,5,30,5,20,15,33,5,7,11,1,3,1,19,3,6,13,3,20,43,10,3,4,3,3,3,7,4,8,35,13,38,27,10,6,1,4,18,2,9,6,27,41,8,3,2,2,1,5,4,8,9,4,1,6,6,5,4,5,3,7,5,17,3,7,2,1,3,0,13,18,13,4,1,1,29,73,19,6,2,3,1,0,0,25,53,9,4,1,5,2,0,214,62,7,15,6,1,2,0,0,0,331,97,37,9,21,18,1,0,0,0,240,49,16,19,20,1,1,0,0,0,0,138,34,25,17,2,1,1,0,0,0,0,0,0,0,0,58,47,27,1,0,0,0,0,0,0,0,37,24,3,1,0,0,0,0,63,1,0,0,0,3,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,10,348,130,471,374,2422,93,936,245,1658,6010,169,2080,3228,50,2,37,10,204,2,282,532,105,163,68,378,188,1050,214,697,15,120,25,1,1,1,1,96,132,84,53,42,46,48,223,200,53,51,131,170,24,4,10,214,109,415,1020,175,481,70,52,165,69,94,461,689,62,145,82,134,2430,413,615,9907,509,6,4,803,15141,34,11,87,3,1,4,2067,1744,5813,536,913,2080,216,1048,1855,19,77,364,6,596,284,496,1310,114,691,395,943,12,1168,47,52,127,24,57,1,72,169,465,246,98,374,128,392,239,380,822,25,139,170,75,87,121,341,415,1204,21,54,17,87,253,204,10,191,2,197,131,90,688,77,877,244,318,51,78,192,141,127,36,217,35,390,82,174,77,151,243,375,98,4,203,559,17,958,339,194,339,361,241,146,409,115,95,542,169,133,159,413,486,46,47,833,103,102,106,2,277,218,155,490,5,250,92,62,76,1129,1144,67,428,152,219,165,176,44,2,219,6,0,2813,121,12,104,65,154,245,68,824,805,1114,17,21,650,95,552,25,410,8,348,56,1140,11,7,45,111,67,46,85,662,170,349,65,335,328,44,87,86,38,35,260,18,20,52,8,122,0,0,0,0,190,478,41,16,127,885,280,106,188,206,134,722,463,18,702,134,136,48,41,195,98,54,42,102,291,138,195,18,990,106,25,168,1062,1035,571,16,5,406,36,149,297,19,65,257,78,71,48,180,104,3,362,1522,66,31,259,25,245,18,70,1106,2321,272,431,259,859,14,90,100,5,154,125,6,257,147,285,92,37,159,66,57,8,198,191,71,250,161,1401,123,53,115,524,3979,1847,172,172,4,85,136,2,528,5562,9,14,1273,6908,1719,7,34,23,22,2,153,6,171,183,5,35,231,77,182,6,5,28,106,79,105,38,20,1282,96,8480,14,4,177,2,84,107,11,8,1926,869,8429,86,45,272,142,407,186,426,144,246,100,22,33,155,88,349,22,63,125,128,86,73,197,124,55,195,258,105,653,288,21,1,215,565,39,161,6,84,28,60,44,741,424,1262,117,8,43,91,48,642,102,117,190,12,177,171,7,70,689,317,1665,90,77,181,531,167,954,485,136,439,197,845,146,432,125,300,160,275,95,72,79,90,241,166,413,60,78,179,125,262,466,529,365,327,144,46,19,17,286,168,657,399,28,739,197,59,11,327,41,1,117,247,41,190,118,82,56,196,189,203,3,63,76,106,130,140,236,182,75,85,100,18,51,290,24,0,89,532,68,196,328,187,92,76,45,166,132,100,25,173,583,216,99,321,73,239,2,108,44,366,42,21,167,0,0,323,188,463,143,582,266,0,86,118,216,236,32,137,118,1,8,128,4,3,97,132,109,21,383,2,363,1,136,85,372,114,248,151,76,42,191,217,603,158,64,172,176,31,64,187,99,131,52,17,512,115,433,76,8,73,407,768,61,64,12,66,148,8,151,96,202,514,68,149,124,76,130,244,110,4,164,12,201,90,381,119,33,109,16,257,98,20,243,205,320,75,52,349,62,404,53,27,2,337,220,34,920,77,510,234,104,222,210,36,424,53,296,399,75,102,84,423,180,0,246,92,126,20,4,171,237,281,541,169,141,1,117,200,189,109,1,199,203,21,174,135,230,2,0,661,448,150,18,4,62,235,157,43,170,24,78,86,159,236,460,48,138,33,122,276,84,233,72,683,61,151,19,123,0,94,1075,230,106,535,434,545,78,73,166,90,321,138,78,44,1,10,63,37,75,67,83,18,167,32,87,181,240,536,256,217,140,74,223,74,6,74,160,614,1,165,209,0,43,0,18,232,125,5,64,118,80,212,0,7,89,112,201,27,199,56,0,34,38,17,198,9,537,86,109,174,188,62,145,48,6,72,30,231,231,93,6,13,51,174,63,117,103,116,546,242,110,116,16,4,24,45,2,171,322,244,266,180,157,654,62,164,202,421,140,333,98,74,40,36,77,193,86,139,32,217,159,92,1,94,172,43,156,598,200,16,110,297,191,1273,2337,74,1014,228,878,714,31,247,89,126,52,144,234,279,432,66,3,32,216,30,16,78,93,40,264,25,113,565,120,12,297,101,149,148,63,94,610,20,30,256,26,87,72,329,55,446,102,175,20,98,63,68,2,165,61,97,190,86,286,61,147,297,868,61,119,222,237,138,28,171,118,59,174,197,413,125,176,85,20,106,460,509,680,153,215,427,188,74,538,109,1,54,326,349,160,257,72,169,756,13,479,95,84,86,10,62,86,191,377,75,421,9,402,98,328,164,1,318,120,162,160,501,14,118,67,800,167,100,177,166,14,277,107,45,149,2,64,104,390,480,18,398,71,104,21,231,115,19,229,285,2,175,162,210,81,10,369,1,79,124,152,62,26,154,343,243,51,367,165,306,11,7,75,1,113,176,238,262,188,246,109,105,125,98,196,124,149,63,353,139,65,8,319,132,249,39,72,364,122,373,76,117,44,260,481,148,100,33,100,244,177,41,66,19,117,583,24,32,290,25,248,9,31,276,194,58,161,243,201,159,246,247,1,189,102,176,119,399,143,121,248,99,609,180,73,1,239,110,93,319,21,60,86,163,125,159,19,257,65,27,238,328,331,124,125,45,211,53,147,87,111,49,37,428,210,225,111,369,145,191,126,43,322,115,232,81,199,15,110,268,162,354,274,175,118,121,64,133,233,78,103,127,105,155,1,2,416,54,17,329,116,249,321,352,85,5,140,11,42,4,230,242,321,1,196,548,91,424,170,931,831,473,549,163,1097,556,2,286,324,220,153,186,589,245,578,1048,1,157,546,431,187,126,116,233,350,69,2,92,92,256,301,202,209,199,5,205,403,161,599,150,105,1,25,158,125,45,125,85,614,139,79,146,299,202,10,593,853,453,151,175,352,312,44,493,9,354,102,344,737,2,149,108,983,161,1075,472,76,73,17,161,597,178,176,208,157,234,49,266,391,113,615,65,91,68,76,19,0,80,152,3,245,328,351,158,1,415,943,293,14,596,54,544,1477,535,3,449,2,247,162,128,288,1800,403,34,98,294,128,296,43,261,77,1428,1712,7340,53,34,425,1158,2125,48,4023,296,5975,136,115,189,908,532,51,1015,81,45,715,259,1725,21,4,0,0,687,3285,519,140,974,2379,336,3910,149,919,52,67,9,460,597,367,819,123,256,0,0,0,240,1969,51,95,569,150,97,3685,101,523,240,610,76,87,373,45,94,164,54,35,42,462,181,74,105,50,188,29,2355,73,594,59,800,386,182,2142,51,56,183,98,29,789,0,0,18,4,9,100,553,781,362,134,68,373,340,220,666,4,199,83,34,81,521,22,363,72,242,222,2300,100,400,86,120,38,99,169,240,265,148,50,58,227,1129,11,1509,1138,217,4219,56,47,159,10,380,0,0,780,149,223,22,99,18,133,665,34,328,1967,97,255,0,102,454,115,600,5957,1082,96,0,4267,15290,636,12,59,74,355,80,551,2115,0,0,0,0,0,0,888,10339,250,377,50,6,15,54,66,1884,637,69,42,123,2280,176,912,79,24,289,123,99,409,7236,0,107,709,131,145,94,117,1197,71,68,333,128,51,617,1666,130,78,46,382,364,277,64,1041,745,0,804,1492,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,1768,27,26,501,352,13,19,8,2,18,15,134,50,49,136,91,388,2321,5677,2119,1,1,568,203,294,385,349,29,27,54,206,77,177,355,231,301,43,14,20,4,0,0,17,14,55,24,89,30,49,52,12,387,38,244,6,205,16,1,45,48,269,132,3791,53,2,13038,145,65,305,161,118,60,84,118,235,495,29,21,4,73,107,137,59,25,29,3,1194,3518,1291,1974,1934,852,127,1021,866,1163,15,59,1956,44,50,169,59,204,144,212,257,5,294,29,160,43,198,276,1,590,29,91,13,224,249,454,5321,2,773,152,166,408,159,43,776,202,82,85,36,303,52,464,137,190,159,33,121,79,150,113,67,68,42,218,1215,209,229,327,42,70,201,109,89,107,2,94,98,146,20,274,243,164,123,264,337,90,308,34,38,37,111,80,55,164,803,63,74,34,55,28,595,59,244,254,137,41,89,74,94,58,11,28,153,530,93,73,296,107,60,67,4,49,114,202,135,400,37,79,2,333,2,2,53,87,29,938,140,225,62,101,28,51,707,9,4,43,3,406,77,118,143,152,76,22,13,6,82,99,208,35,161,43,184,695,91,16,60,401,119,75,351,239,31,56,61,200,127,180,6,17,377,264,179,442,2175,63,32,94,478,38,51,377,29,2,22,168,120,95,39,69,202,225,74,39,76,62,84,67,83,35,133,38,43,407,248,771,189,117,207,17,215,287,121,84,118,69,122,296,122,109,57,95,81,114,32,21,293,139,85,56,70,60,755,62,80,184,199,708,196,188,34,163,97,75,68,213,376,1,3,96,79,1034,539,0,212,491,261,29,42,62,17,35,354,207,66,433,293,203,707,1,126,213,70,204,1240,273,788,869,28,281,1011,534,804,4865,1,6504,107,146,33,107,22,13,19,50,1,9,172,39,18,35,6,87,65,162,59,90,33,55,15,40,35,19,52,2,17,118,1,17,54,162,119,102,289,658,325,162,3903,0,0,0,0,0,0,0,0,506,66,58,39,66,256,74,87,54,54,101,96,19,156,106,46,353,39,123,145,47,78,49,63,210,338,68,794,76,2157,0,58,33,351,28,5,58,66,42,37,127,0,33,32,28,57,47,40,28,36,21,17,59,34,268,49,73,0,88,8,53,46,46,67,8,26,30,53,15,22,352,19,47,170,34,7,26,58,101,20,42,18,0,34,55,34,33,0,157,107,116,39,72,44,46,32,14,56,14,39,34,65,29,354,156,33,40,3,60,21,41,1,32,16,159,67,80,87,48,65,45,7,3,106,2,79,18,32,48,53,78,44,41,32,210,53,70,24,36,52,149,495,369,322,28,80,644,573,90,1273,0,564,2253,0,0,1095,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,1,0,1,0,1,0,2,0,0,1,1,0,0,1,0,1,1,2,2,5,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,0,0,1,0,1,1,0,0,3,3,4,10,1,0,6,0,3,5,2,15,6,4,2,3,1,8,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,16,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,72,22,19,6,2,4,10,36,12,324,16,1,14,5,2,60,1,50,12,1,5,5,32,6,21,1,1,4,41,3,7,1,7,3,2,2,1,1,1,7,7,0,0,0,11,74,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,66,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,0,1,0,1,0,1,1,1,0,0,0,1,1,1,1,0,0,0,0,1,1,4,1,1,1,2,4,1,2,1,2,2,1,4,2,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,5,7,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,1,1,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,1,1,0,0,0,0,1,0,1,1,1,1,1,1,1,2,2,1,2,1,1,1,1,5,1,1,1,1,1,1,1,1,2,1,1,1,1,1,2,1,14,7,2,3,2,1,4,1,1,2,1,3,3,2,1,2,4,1,1,1,5,3,1,1,1,1,25,3,5,3,2,3,11,2,2,8,2,3,5,1,4,1,2,2,5,1,2,1,4,10,2,3,1,7,18,3,3,7,8,4,3,4,3,9,2,2,5,1,1,3,3,4,2,4,9,2,4,2,2,1,1,1,1,1,2,13,2,1,1,1,2,4,1,2,1,16,1,9,6,9,3,5,1,3,1,2,2,2,2,3,4,2,1,2,2,3,4,7,2,1,1,1,1,1,6,1,7,1,4,7,6,2,2,1,21,19,11,10,4,5,4,3,3,10,2,2,5,30,12,2,6,9,3,1,2,1,1,12,22,12,3,5,6,2,43,28,4,13,6,17,1,4,4,74,44,10,7,2,7,5,6,4,150,37,5,11,2,3,3,4,1,1,218,65,41,7,8,4,11,1,2,4,1,9,3,1,3,297,70,14,2,5,4,4,1,2,6,3,2,4,3,3,10,415,47,18,4,3,8,4,1,2,4,8,13,3,2,465,190,21,20,9,5,2,2,15,20,2,4,3,5,1,1,502,114,8,21,3,7,2,6,2,10,5,499,210,69,48,12,1,2,7,6,16,6,347,241,101,3,2,6,9,2,4,4,3,24,4,2,438,151,47,1,14,5,9,10,6,2,4,686,71,34,11,5,3,17,3,11,9,2,6,9,2,579,112,6,18,35,43,47,86,6,34,31,4,200,36,1,366,20,48,95,14,29,2,2,7,13,3,11,162,45,2,47,23,121,49,35,23,5,47,13,20,175,14,7,21,8,25,7,12,2,23,3,3,0,26,17,4,2,3,0,29,24,2,21,27,1,0,3,34,30,12,1,4,3,24,57,2,5,0,0,0,0,0,14,12,63,43,30,12,6,5,5,5,3,1,41,6,2,0,0,0,0,0,0,0,0,0,6,5,2,5,172,32,5,0,0,0,0,0,0,0,0,1,28,6,6,40,5,1,0,0,0,0,0,0,0,46,5,21,3,105,10,2,0,0,0,0,0,0,0,0,8,119,0,0,1,60,2,3,0,0,8,2,4,25,4,0,3,2,26,0,42,3,1,26,25,3,0,0,75,1,1,0,0,23,33,0,0,0,35,4,22,4,20,3,41,3,1,0,0,5,1,0,21,1003,29,1,0,0,0,0,0,0,0,0,0,529,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,1,2,1,1,1,1,2,1,1,10,2,2,1,1,3,2,1,1,3,1,1,1,1,3,1,2,2,1,2,1,1,5,8,12,5,5,5,2,8,4,1,1,4,5,1,3,3,9,4,2,2,1,2,5,2,6,1,5,7,10,3,2,2,4,2,1,22,20,9,6,3,5,1,1,3,22,19,21,2,2,2,2,2,1,2,82,14,7,4,5,2,5,2,1,1,1,138,37,8,5,8,1,2,3,2,2,4,3,227,50,11,10,1,4,1,2,1,2,2,4,2,290,62,41,1,3,1,4,1,2,1,387,53,26,8,1,13,8,2,2,499,53,35,4,8,7,5,4,4,11,4,2,5,20,1,581,39,50,29,14,10,3,2,4,7,22,10,3,503,162,26,63,5,4,3,3,8,3,27,7,1,397,169,61,32,5,4,12,5,1,477,113,32,29,2,3,3,33,9,5,634,42,64,9,30,3,36,6,500,266,1,21,2,1,2,2,28,7,6,21,9,7,7,145,21,4,308,15,19,25,1,5,38,7,8,6,3,2,220,33,6,29,28,72,21,40,10,17,76,16,467,5,1,4,16,28,20,5,3,31,22,4,25,3,3,29,4,5,6,1,30,4,3,0,70,3,2,0,0,5,20,39,6,0,0,0,0,0,39,27,2,66,4,0,0,0,2,4,74,6,2,0,0,0,0,0,0,0,0,0,0,0,31,4,7,8,17,2,0,0,0,32,25,5,8,0,0,22,96,2,0,0,0,27,22,5,0,32,1,0,7,4,0,27,25,994,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,550,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,1,1,1,1,2,1,0,0,0,0,1,0,2,0,0,1,0,1,1,3,1,1,2,0,1,0,0,0,0,0,1,0,1,0,1,0,1,0,3,6,3,0,1,0,1,0,1,0,1,2,1,1,0,0,0,0,0,1,0,1,0,1,1,1,1,1,1,2,2,0,0,1,0,0,0,0,0,0,1,1,1,1,1,1,1,2,6,1,2,2,4,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,4,1,1,1,1,1,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,0,1,0,1,1,1,2,1,2,4,1,1,1,1,1,2,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,1,0,1,0,1,1,1,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,1,2,1,1,1,2,1,1,1,14,2,6,1,3,2,7,1,1,4,5,11,2,1,1,2,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,0,0,0,2,2,1,1,1,1,8,2,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,0,1,0,2,1,3,3,3,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,3,0,0,0,1,0,1,2,0,1,1,0,0,1,0,1,0,1,0,1,1,1,1,0,0,0,0,2,1,1,0,0,0,0,2,6,0,0,2,0,0,1,2,1,0,1,2,1,0,1,2,1,3,1,1,1,1,3,1,0,0,0,0,0,0,0,0,0,0,1,0,2,1,1,1,3,2,1,1,1,3,2,1,1,2,1,15,1,9,6,1,2,2,1,2,1,1,14,71,7,1,2,8,4,6,3,36,12,1,4,2,4,1,449,3,5,2,7,2,1,2,11,15,11,1,4,41,134,74,17,78,36,81,17,7,4,6,27,15,20,31,29,35,38,40,207,256,1,2,1,1,11,1,33,6,5,27,11,8,30,28,1,44,2,13,10,11,8,3,12,1,9,11,9,24,19,7,1,1,15,5,9,17,9,27,64,1,10,6,6,12,8,21,35,8,4,6,9,11,21,11,23,40,2,10,6,6,9,7,6,15,3,1,1,5,6,16,11,8,6,7,1,5,17,8,0,0,0,14,10,4,11,0,0,0,0,6,6,4,13,35,0,0,0,0,0,0,0,0,0,0,5,20,7,57,0,0,0,0,0,0,14,1,33,29,1,0,0,0,0,0,27,14,59,0,0,0,0,65,25,0,385,1,2,2,0,0,0,0,0,0,0,0,0,0,22,121,36,13,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,2,0,0,0,0,0,0,36,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,2,0,1,0,6,0,0,0,1,0,3,0,0,1,0,1,0,1,0,1,0,1,0,1,2,0,0,0,1,1,0,0,1,0,1,0,1,1,0,0,1,0,2,1,0,0,0,1,1,0,0,1,0,1,1,1,0,0,0,1,3,3,1,1,0,0,1,0,0,0,0,0,1,1,0,0,1,1,0,0,1,1,1,1,1,1,3,4,11,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,1,1,1,1,1,1,1,1,3,1,3,1,9,4,18,1,32,12,12,27,13,20,2,1,3,2,4,3,2,3,8,2,4,3,1,3,6,1,9,3,4,12,4,21,2,1,1,0,0,1,1,0,0,2,3,4,8,0,0,0,0,0,0,0,0,0,0,0,0,2,2,5,0,0,0,0,0,4,6,0,0,0,0,0,0,0,3,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,0,0,0,0,1,1,1,4,1,1,13,1,2,1,3,1,6,2,1,9,5,9,8,4,5,1,1,2,2,1,2,2,2,11,29,32,30,1,3,7,1,4,1,1,2,1,1,1,3,1,1,1,8,13,1,2,4,1,1,2,5,2,2,12,1,1,1,2,2,1,4,5,2,1,3,1,4,3,6,11,8,3,3,2,4,5,3,2,2,2,6,4,2,2,2,1,2,4,3,3,2,8,3,4,3,3,1,2,6,9,2,2,3,11,1,6,2,1,8,2,6,5,3,1,9,2,2,1,3,4,5,12,4,3,2,9,4,2,6,4,11,7,13,1,6,4,5,6,3,5,8,2,2,6,7,5,3,2,3,3,3,9,4,6,7,8,1,5,1,1,1,1,2,3,2,4,0,0,2,17,3,1,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,6,4,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,16,3,2,1,1,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,6,6,8,0,0,0,0,3,1,8,1,0,0,0,0,0,0,0,2,1,0,0,0,0,2,0,0,0,4,0,2,0,0,0,0,5,0,0,0,16,14,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,0,1,0,1,1,1,0,0,0,2,1,0,1,0,1,1,0,2,1,0,0,1,2,3,2,1,1,0,0,0,1,0,0,0,0,0,0,6,3,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,0,0,0,1,0,1,1,1,16,1,1,1,1,45,163,1,7,3,12,7,10,10,10,15,19,11,5,6,7,4,5,1,3,3,1,3,1,1,51,3,1,5,1,8,19,16,1,6,18,53,57,5,23,15,27,8,4,17,17,4,3,3,1,4,1,9,2,1,16,1,8,7,10,1,8,3,1,2,1,2,1,3,1,6,2,3,10,11,11,11,2,2,1,36,12,17,13,12,2,3,2,2,2,1,1,20,29,19,24,20,23,2,8,1,2,3,2,1,11,27,16,2,8,13,1,1,5,1,1,25,29,6,19,10,8,10,5,5,2,2,26,50,11,21,18,20,2,4,3,1,13,49,14,28,69,19,2,6,3,2,2,1,1,34,68,2,24,24,7,6,17,2,1,3,1,1,55,19,40,18,17,1,10,7,4,5,78,68,64,7,2,20,6,3,7,6,26,5,2,7,3,4,62,47,15,12,15,14,20,4,10,1,17,3,1,116,77,17,6,6,2,32,42,14,12,11,29,6,8,15,8,3,2,19,40,23,3,1,114,22,11,17,11,4,11,8,35,47,16,10,6,5,6,6,39,74,38,2,1,15,4,9,24,13,25,13,33,13,25,4,8,5,20,55,39,4,1,4,4,7,13,11,6,3,6,36,10,1,2,1,3,5,5,1,13,7,5,4,13,2,3,3,3,1,0,14,16,10,5,3,7,1,41,12,10,12,9,9,4,5,15,14,7,5,9,4,9,27,11,20,5,10,4,30,6,13,15,4,5,7,22,29,37,15,8,2,2,45,42,35,10,10,2,1,59,37,21,4,9,5,9,1,1,59,43,9,16,2,8,8,8,3,0,69,33,50,25,14,10,9,11,0,0,20,19,13,38,11,22,15,13,2,3,5,2,19,12,11,21,29,3,8,11,1,41,6,20,9,6,7,19,2,41,10,12,9,6,16,6,0,29,7,21,21,8,12,26,37,20,8,6,4,29,10,12,25,5,1,31,4,13,19,0,47,57,31,6,2,0,0,68,23,3,197,25,7,0,0,0,0,0,0,0,215,13,5,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,17,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,1,2,2,0,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,2,2,1,1,0,0,1,1,0,0,2,1,0,0,1,0,1,0,1,1,1,0,0,0,1,2,1,1,0,0,0,0,0,1,0,1,0,1,1,1,1,8,10,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,6,1,2,4,4,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,3,2,2,1,0,0,0,0,0,0,0,0,1,0,1,1,2,2,2,0,0,1,0,1,0,2,0,0,2,0,1,0,1,1,1,1,1,1,1,12,1,1,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,1,2,3,12,1,0,6,0,0,0,1,0,1,1,1,1,106,73,12,10,6,3,1,1,1,1,112,17,22,5,1,13,10,1,181,20,24,34,24,19,10,4,1,1,2,139,61,57,33,28,18,9,3,6,2,79,68,56,47,26,10,12,8,1,2,2,113,19,45,20,10,7,4,180,89,44,39,4,1,2,301,63,39,17,7,4,4,438,92,94,43,8,2,2,3,427,208,87,43,19,4,2,4,7,2,502,164,73,18,11,7,3,8,1,5,1,876,171,20,14,8,7,11,8,6,17,25,1,1,927,231,37,1,3,33,56,48,18,24,22,16,3,25,105,50,5,2,430,21,23,39,12,55,117,88,83,9,54,67,20,53,9,60,45,216,185,8,3,19,18,6,24,38,68,86,41,70,37,118,21,11,11,13,128,86,11,3,1,24,14,13,9,22,8,1,6,13,10,3,4,17,12,1,1,6,14,9,9,13,2,18,11,61,10,37,10,7,87,42,27,71,22,20,14,14,2,0,49,43,64,49,27,8,26,9,44,44,60,52,7,26,34,66,67,13,36,10,37,15,143,69,30,53,25,13,35,14,2,157,17,81,40,33,72,9,237,64,34,65,70,1,155,42,81,118,6,104,100,149,39,123,142,26,1,405,61,1,1,1189,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,456,29,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,6,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,0,1,0,1,0,1,3,2,2,0,0,0,0,0,0,0,1,1,3,1,1,1,1,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,0,1,0,1,1,1,1,1,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,7,2,1,3,3,1,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,3,1,1,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,4,1,2,0,0,2,1,0,0,0,1,1,1,0,0,0,6,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,2,4,1,1,1,1,1,1,2,1,2,1,1,1,1,2,2,1,1,3,3,2,1,1,2,1,2,3,2,2,3,1,3,1,1,1,2,1,1,2,1,4,1,2,2,1,1,1,1,1,2,2,5,2,1,1,2,3,2,1,3,4,2,2,3,4,2,2,1,1,1,0,0,0,3,1,2,2,3,0,0,0,0,0,0,4,1,0,0,4,1,0,1,2,1,1,0,0,1,0,0,3,2,0,0,0,1,0,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,1,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,1,1,1,0,0,0,0,2,0,2,0,1,0,2,1,1,1,0,0,0,0,0,1,1,1,0,0,0,1,0,1,0,24,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,2,5,2,2,1,1,0,1,0,0,0,0,0,0,0,0,0,1,0,2,4,18,9,4,2,3,1,1,2,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,1,1,1,1,3,4,45,8,3,1,1,3,1,1,1,2,6,7,1,1,1,0,0,4,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,1,0,0,0,1,2,17,8,16,15,2,0,0,0,0,0,1,0,2,0,1,0,1,0,2,1,1,1,1,1,1,1,5,3,1,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,2,0,0,0,6,4,0,1,0,1,0,1,0,2,0,1,0,1,1,1,2,1,1,1,0,0,0,0,2,0,1,0,1,0,1,0,1,1,1,1,2,1,1,1,2,4,5,2,7,6,6,51,5,1,2,3,4,1,1,2,1,1,1,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,2,1,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,1,1,0,0,1,1,0,0,1,0,1,1,0,0,1,0,1,0,1,0,1,1,1,1,0,0,0,0,5,1,0,0,0,0,0,1,0,1,0,1,3,0,0,0,0,1,1,0,0,1,0,1,1,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,0,1,3,1,1,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,2,1,1,1,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,1,1,1,1,3,1,3,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,6,1,2,1,1,3,3,5,12,4,3,3,3,1,2,5,12,4,1,1,2,7,26,4,3,1,2,6,2,7,125,8,12,14,16,9,1,60,73,7,6,2,4,24,18,24,24,53,151,6,9,4,6,10,5,4,13,6,3,3,17,9,11,0,0,0,7,13,4,0,0,0,3,10,15,0,0,0,15,25,0,0,0,0,83,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,18,147,8,107,20,14,196,19,3,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,0,1,0,1,1,1,1,2,7,1,1,1,2,1,1,1,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,2,0,0,1,1,1,1,11,1,6,153,75,6,3,1,1,1,1,576,18,1,1,2,2,1,1,3140,74,16,2,7,12,5,3,4,15,17,23,62,26,13,9,1,6,1465,398,44,17,25,63,16,47,37,84,151,131,137,121,71,51,61,15,13,3,35,18,30,174,256,633,361,111,42,4,4,1,308,38,13,22,10,23,77,44,57,34,20,60,26,120,33,16,16,5,38,136,45,302,169,54,15,16,20,70,25,36,72,5,6,15,17,29,26,139,220,33,30,3,21,3,17,19,25,21,14,21,23,11,18,5,24,23,8,7,69,14,13,37,71,57,28,6,2,24,29,15,37,5,23,35,40,15,4,92,30,12,17,7,19,12,9,7,7,107,136,24,7,17,8,17,25,81,13,28,12,116,42,20,47,13,39,10,31,46,57,6,4,125,65,6,74,29,75,16,42,171,107,33,13,1,11,5,71,26,36,25,36,72,63,43,10,47,19,28,49,41,12,4,38,16,11,16,28,56,41,32,19,12,17,85,100,51,20,12,8,34,4,27,95,18,9,8,28,103,5,20,11,6,23,33,9,9,2,44,46,4,64,70,70,133,32,4,127,295,150,11,9,4,824,297,46,23,1,0,0,2130,556,106,47,8,4,4,1,0,0,0,0,0,2484,412,77,21,1,1,5,1,3,0,0,0,0,0,0,0,2393,167,88,33,5,3,3,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1802,265,64,45,14,20,3,2,3,5,2,4,1,2,12,6,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1508,132,35,17,12,15,2,8,2,1,5,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1209,178,52,14,7,3,2,3,1,7,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,938,120,25,4,15,1,5,14,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,717,115,69,4,2,3,2,6,6,3,0,0,0,0,0,0,0,0,0,0,0,547,61,36,3,3,7,3,10,10,0,0,0,0,0,0,0,0,0,0,323,95,45,14,7,5,2,4,10,1,11,6,2,0,0,0,0,0,0,0,0,0,0,0,210,51,22,5,13,5,2,3,1,4,19,4,2,0,0,0,0,0,0,0,0,0,0,135,50,19,5,4,4,7,2,11,1,1,0,0,0,0,0,0,0,0,0,77,37,6,10,4,2,9,2,4,7,0,0,0,0,0,0,0,0,0,0,0,15,24,6,9,9,11,12,14,1,0,0,0,0,0,0,0,0,0,0,8,3,6,3,4,26,3,1,0,0,0,0,0,0,11,6,6,2,2,2,3,0,0,0,0,0,7,3,2,3,2,5,2,0,0,0,0,0,0,0,0,3,4,6,5,0,0,0,0,0,0,0,0,0,0,0,2,7,0,0,0,10,1,8,1,0,0,0,0,0,0,0,0,0,15,27,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,0,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,0,0,1,0,1,1,1,1,1,1,4,1,1,1,1,16,7,5,1,1,8,2,1,2,3,1,2,40,14,1,1,2,1,2,4,3,3,1,2,34,3,1,4,5,11,13,7,9,5,10,4,3,1,1,1,1,2,1,2,1,1,3,1,1,2,1,1,1,5,5,3,21,14,11,7,13,14,3,4,1,3,1,4,1,3,2,3,1,2,1,1,1,1,5,2,1,1,1,1,2,2,2,2,1,1,1,4,1,2,2,1,2,4,2,2,2,2,2,1,1,1,3,2,1,1,1,1,5,1,0,1,2,2,3,1,3,2,1,2,0,2,0,1,1,2,1,1,1,4,2,3,1,5,4,9,4,3,2,7,2,2,4,4,1,1,1,1,7,16,2,0,0,2,4,18,3,4,1,3,1,0,1,0,0,0,4,13,2,4,4,5,2,5,3,1,1,1,0,22,7,10,5,3,3,0,2,4,1,1,1,0,0,0,23,14,0,1,11,7,5,0,1,1,0,21,10,21,6,18,2,1,2,16,23,23,10,10,6,3,2,1,24,10,12,11,6,1,2,3,4,1,2,39,22,37,24,8,9,1,2,1,2,76,41,16,19,13,2,0,1,4,1,8,2,172,44,28,14,5,1,5,3,2,4,12,1,1,170,152,63,22,5,2,4,3,9,3,6,10,16,47,2,5,1,1,1,1,1,196,68,23,19,5,6,4,6,3,5,35,92,4,1,1,1,1,212,41,31,31,5,3,19,7,4,2,5,3,9,3,7,10,117,107,6,2,1,2,32,61,23,5,5,10,1,16,22,11,10,7,7,106,193,6,3,1,2,19,14,12,10,13,4,5,4,27,54,2,1,1,0,9,7,2,10,7,10,4,47,71,6,2,1,6,3,6,4,32,55,4,5,1,1,7,8,37,4,2,3,1,2,15,19,2,1,19,24,0,21,12,6,1,9,7,0,8,10,3,11,4,1,5,4,33,2,10,11,9,9,9,6,6,1,5,3,1,26,10,401,4,10,1,2,1,4,1,0,0,0,0,0,0,0,0,148,155,52,33,6,13,11,4,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,14,13,3,4,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,27,2,8,8,3,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,3,9,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,2,2,1,0,0,0,0,0,0,0,1,0,1,1,1,1,2,0,0,0,0,0,0,1,0,1,0,1,3,4,1,2,1,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,0,0,1,2,1,0,2,0,0,2,0,1,1,1,0,0,0,1,0,2,1,1,1,1,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,1,3,0,0,0,0,1,1,1,1,1,1,2,1,1,1,1,3,1,1,1,2,1,2,1,1,2,2,3,3,5,1,1,2,1,4,2,1,2,2,3,1,1,2,1,1,1,6,4,4,2,2,1,3,5,3,3,1,2,23,8,1,1,9,6,4,1,9,14,2,1,17,3,2,3,19,14,1,31,2,2,2,33,43,5,1,9,2,28,70,5,5,8,3,1,1,1,3,3,2,1,9,2,0,1,2,1,38,6,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,8,3,1,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,3,2,1,1,0,0,0,0,0,0,0,1,1,2,4,1,1,5,16,12,14,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,8,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,3,0,0,1,2,0,1,0,1,1,0,0,1,0,1,0,1,2,1,2,2,79,11,1,2,1,1,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,1,1,1,0,0,0,0,1,1,1,2,1,0,0,0,2,1,1,1,1,0,0,0,0,0,0,2,3,1,0,0,0,0,0,0,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,2,2,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,1,0,1,2,1,1,1,3,3,3,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,1,5,1,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,9,0,0,0,0,0,0,1,1,1,0,0,0,1,0,1,1,1,5,1,1,1,2,17,3,1,8,12,4,14,6,2,2,5,5,38,23,29,5,4,9,14,1,3,1,1,1,0,0,1,2,0,0,3,2,3,0,0,0,0,0,0,0,6,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,4,1,1,0,2,1,0,0,1,0,12,0,0,2,0,1,0,1,1,2,1,2,1,1,2,1,0,1,0,0,0,0,0,0,0,0,0,1,2,0,0,0,1,1,0,0,2,3,1,5,0,0,0,0,0,0,0,0,0,0,0,1,0,12,0,0,1,1,4,0,0,0,0,0,0,1,0,1,1,0,0,1,1,1,2,2,2,2,1,1,1,2,1,1,1,1,2,1,5,5,5,1,1,1,2,1,1,1,4,3,1,1,2,1,1,2,1,1,1,2,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,2,0,0,0,0,1,0,1,1,0,0,2,3,1,0,0,0,1,1,2,1,0,0,0,0,0,2,0,1,0,1,0,1,0,1,2,1,2,1,1,1,3,4,3,3,12,25,24,3,1,2,3,2,21,6,4,2,2,3,7,22,2,1,2,4,1,2,2,0,0,0,2,2,1,5,1,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,2,3,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,2,3,0,0,0,0,1,1,1,1,0,0,0,0,1,0,1,0,1,0,1,0,2,0,1,0,4,0,2,3,1,1,0,0,0,0,0,0,1,1,1,0,0,0,2,0,1,0,1,1,11,1,1,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,0,0,0,0,1,2,1,0,1,0,1,0,3,14,2,3,1,10,1,1,6,1,2,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,1,1,1,1,1,1,0,2,1,1,1,1,1,1,1,1,1,1,1,2,1,1,2,1,1,2,1,2,3,3,2,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,3,0,0,2,0,0,0,1,0,0,0,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,2,1,0,0,1,0,1,0,1,0,1,1,0,0,1,1,1,1,1,3,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,3,1,1,1,1,2,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,0,0,0,0,1,0,2,0,1,0,4,8,4,0,2,0,0,3,1,0,0,3,1,0,0,0,1,0,1,1,1,1,1,1,2,1,0,0,0,0,0,0,0,0,0,6,0,1,1,0,0,1,0,1,1,0,0,2,2,0,0,1,0,1,0,1,0,2,0,0,1,0,1,2,1,0,1,0,1,0,1,0,1,0,1,12,5,4,6,2,1,2,6,2,16,1,1,4,2,4,24,9,4,2,4,4,1,17,5,1,5,1,1,32,8,1,2,8,7,23,5,20,4,2,4,1,16,5,22,17,2,2,12,82,12,4,2,1,5,1,1,3,7,7,3,19,9,8,2,1,2,4,3,3,2,1,3,4,2,9,7,1,1,5,3,1,1,11,2,1,2,13,2,0,16,6,1,1,0,0,24,5,2,3,1,0,0,0,0,0,0,3,2,19,9,3,0,0,0,0,0,0,0,0,0,0,1,1,0,2,1,32,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,3,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,1,1,1,0,0,0,0,0,2,1,1,2,1,0,0,0,0,0,0,1,0,2,2,2,2,12,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,1,0,0,1,0,1,1,1,1,1,1,2,1,5,12,1,2,5,3,60,1,1,1,2,1,1,0,0,1,0,0,0,0,0,2,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,2,2,0,0,1,0,4,0,1,1,0,0,1,1,3,0,1,0,1,0,1,3,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,3,2,1,1,1,1,1,1,2,3,1,1,2,1,1,1,1,1,1,2,1,1,1,1,1,1,3,1,1,1,1,2,1,3,2,1,1,1,3,1,1,1,2,1,2,1,1,2,1,1,1,4,2,1,1,1,1,2,1,1,2,1,2,1,1,2,1,1,1,2,2,5,2,2,0,1,1,0,0,0,0,2,0,0,2,0,1,1,0,1,1,0,0,0,1,0,0,0,0,1,0,0,0,4,0,1,0,1,1,0,0,0,0,0,0,0,1,1,0,0,0,2,1,0,0,1,0,1,2,0,2,2,0,1,0,1,2,2,5,3,0,0,1,3,2,1,2,3,1,1,2,0,0,2,0,0,2,1,3,3,0,1,1,1,0,3,0,2,3,3,3,0,0,0,1,3,1,0,1,2,3,1,2,3,0,1,1,2,2,1,1,1,1,0,0,0,0,0,2,0,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,1,0,1,0,1,1,0,3,6,3,0,1,1,1,1,1,1,1,1,1,4,5,5,3,1,7,11,4,1,1,5,2,3,4,2,2,4,2,1,6,2,1,2,2,0,0,0,2,1,1,0,0,1,0,0,0,1,0,0,0,0,0,0,0,2,0,6,12,6,0,4,0,1,1,3,0,0,0,1,2,0,1,1,2,1,3,1,2,2,1,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,0,0,0,2,0,2,0,1,2,1,0,1,0,3,0,1,0,1,0,1,0,1,0,1,1,3,1,3,0,0,0,0,0,0,0,1,1,3,1,2,2,0,0],\"yaxis\":\"y\",\"type\":\"scattergl\"}],                        {\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"midpoint\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"depth\"}},\"legend\":{\"tracegroupgap\":0},\"title\":{\"text\":\"3L\"},\"height\":300,\"width\":750,\"shapes\":[{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":65132,\"x1\":65132,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":129050,\"x1\":129050,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":193172,\"x1\":193172,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":367247,\"x1\":367247,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":380973,\"x1\":380973,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":413507,\"x1\":413507,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":11208464,\"x1\":11208464,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":11213954,\"x1\":11213954,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"}]},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('1419f028-03ae-4910-8faf-ff2fa5c6d11a');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}, {"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"hovertemplate": "midpoint=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "", "marker": {"color": "lightsalmon", "symbol": "circle"}, "mode": "markers", "name": "", "showlegend": false, "type": "scattergl", "x": [7233, 7236, 7236, 16860, 16878, 17031, 17031, 17032, 17069, 17069, 17487, 21348, 25299, 4840419, 13671862, 14299019, 14300293, 14483, 14485, 14487, 24281, 24282, 33796, 33832, 33968, 33986, 34063, 34063, 34064, 34065, 34065, 34066, 34066, 34067, 34068, 34071, 34071, 34074, 34075, 34076, 34078, 34079, 34080, 34083, 34084, 34084, 34085, 34085, 34086, 34086, 34088, 34093, 34094, 34094, 34095, 34095, 34096, 34100, 34100, 34101, 34101, 34139, 34065, 34066, 34066, 34067, 34068, 34068, 34071, 34071, 34072, 34076, 34078, 34079, 34080, 34084, 34085, 34087, 34088, 34090, 34095, 34096, 34099, 34100, 34100, 34101, 34101, 34102, 34067, 34101, 34102, 34102, 34098, 34102, 34102, 34103, 34073, 34102, 34103, 34069, 34071, 34078, 34103, 34104, 34090, 34096, 34099, 34104, 34074, 34104, 34105, 34105, 34091, 34107, 34108, 34098, 34101, 34108, 34108, 34111, 34111, 34112, 34112, 34113, 34115, 34115, 34116, 34116, 34117, 34120, 34120, 34105, 34120, 34121, 34121, 34122, 34122, 34122, 34123, 34123, 34123, 34124, 34124, 34125, 34127, 34127, 34130, 34130, 34131, 34131, 34131, 34132, 34132, 34132, 34132, 34133, 34133, 34133, 34135, 34136, 34136, 34137, 34137, 34137, 34138, 34138, 34139, 34140, 34140, 34141, 34141, 34142, 34142, 34143, 34143, 34144, 34145, 34145, 34146, 34146, 34147, 34148, 34149, 34150, 34150, 34152, 34152, 34153, 34153, 34156, 34159, 34160, 34162, 34168, 34172, 34177, 34140, 34141, 34141, 34142, 34142, 34144, 34144, 34145, 34146, 34148, 34150, 34151, 34152, 34153, 34158, 34177, 34141, 34142, 34143, 34145, 34146, 34149, 34151, 34151, 34153, 34142, 34143, 34143, 34145, 34145, 34146, 34146, 34147, 34148, 34148, 34149, 34149, 34151, 34152, 34154, 34143, 34144, 34144, 34145, 34145, 34146, 34146, 34147, 34147, 34148, 34148, 34149, 34149, 34150, 34150, 34151, 34151, 34152, 34152, 34155, 34144, 34145, 34146, 34146, 34147, 34148, 34149, 34149, 34150, 34150, 34152, 34153, 34179, 34145, 34146, 34146, 34147, 34147, 34148, 34149, 34149, 34150, 34151, 34152, 34153, 34153, 34180, 34147, 34148, 34149, 34154, 34148, 34149, 34150, 34150, 34151, 34154, 34148, 34149, 34150, 34151, 34152, 34149, 34150, 34150, 34151, 34151, 34152, 34153, 34154, 34155, 34155, 34158, 34165, 34182, 34151, 34152, 34152, 34153, 34155, 34156, 34151, 34152, 34152, 34153, 34153, 34154, 34155, 34156, 34156, 34159, 34153, 34153, 34154, 34158, 34159, 34153, 34154, 34154, 34155, 34155, 34157, 34157, 34154, 34155, 34156, 34157, 34158, 34155, 34156, 34156, 34157, 34158, 34158, 34160, 34161, 34156, 34158, 34158, 34159, 34157, 34158, 34158, 34159, 34159, 34161, 34162, 34170, 34173, 34186, 34159, 34160, 34160, 34160, 34162, 34160, 34161, 34161, 34163, 34164, 34164, 34167, 34162, 34163, 34163, 34164, 34164, 34165, 34166, 34167, 34168, 34177, 34164, 34164, 34165, 34164, 34165, 34165, 34165, 34166, 34166, 34170, 34166, 34167, 34169, 34167, 34168, 34169, 34170, 34171, 34171, 34172, 34173, 34191, 34168, 34169, 34169, 34170, 34170, 34171, 34171, 34172, 34172, 34173, 34173, 34174, 34174, 34175, 34176, 34176, 34177, 34178, 34186, 34191, 34191, 34169, 34170, 34170, 34171, 34171, 34172, 34172, 34173, 34173, 34174, 34174, 34176, 34177, 34170, 34171, 34171, 34172, 34172, 34173, 34173, 34174, 34174, 34175, 34176, 34180, 34190, 34171, 34172, 34172, 34173, 34173, 34174, 34174, 34175, 34172, 34173, 34173, 34174, 34174, 34175, 34175, 34176, 34178, 34179, 34173, 34174, 34174, 34175, 34175, 34176, 34176, 34177, 34177, 34178, 34178, 34179, 34194, 34174, 34175, 34175, 34176, 34176, 34177, 34177, 34178, 34178, 34179, 34179, 34181, 34181, 34182, 34175, 34176, 34176, 34177, 34177, 34178, 34178, 34179, 34179, 34180, 34180, 34182, 34176, 34177, 34177, 34178, 34178, 34179, 34179, 34180, 34180, 34181, 34182, 34182, 34183, 34183, 34184, 34193, 34194, 34195, 34177, 34178, 34178, 34179, 34179, 34180, 34180, 34181, 34181, 34183, 34184, 34187, 34196, 34178, 34179, 34179, 34180, 34180, 34181, 34181, 34182, 34183, 34184, 34184, 34193, 34194, 34196, 34179, 34180, 34180, 34181, 34181, 34182, 34182, 34183, 34183, 34184, 34184, 34185, 34186, 34190, 34197, 34180, 34181, 34181, 34182, 34182, 34183, 34183, 34184, 34184, 34185, 34185, 34186, 34187, 34188, 34192, 34193, 34194, 34196, 34197, 34181, 34182, 34182, 34183, 34183, 34184, 34184, 34185, 34185, 34186, 34187, 34182, 34183, 34183, 34184, 34184, 34185, 34185, 34187, 34187, 34188, 34194, 34198, 34183, 34184, 34184, 34185, 34185, 34186, 34186, 34187, 34187, 34188, 34190, 34196, 34199, 34184, 34185, 34185, 34186, 34186, 34187, 34187, 34188, 34197, 34199, 34185, 34186, 34186, 34187, 34187, 34188, 34188, 34189, 34190, 34192, 34193, 34196, 34198, 34200, 34186, 34187, 34187, 34188, 34188, 34189, 34189, 34190, 34191, 34194, 34195, 34197, 34198, 34200, 34187, 34188, 34188, 34189, 34189, 34190, 34191, 34193, 34194, 34196, 34196, 34197, 34198, 34198, 34199, 34201, 34188, 34189, 34189, 34190, 34191, 34192, 34192, 34194, 34198, 34199, 34200, 34201, 34201, 34189, 34190, 34190, 34191, 34191, 34192, 34193, 34193, 34198, 34201, 34202, 34190, 34191, 34191, 34192, 34192, 34193, 34193, 34194, 34194, 34196, 34197, 34198, 34199, 34200, 34200, 34201, 34202, 34202, 34191, 34192, 34192, 34193, 34193, 34194, 34195, 34195, 34196, 34196, 34197, 34198, 34198, 34199, 34199, 34200, 34201, 34201, 34202, 34203, 34192, 34193, 34193, 34194, 34194, 34195, 34195, 34196, 34197, 34197, 34198, 34198, 34199, 34199, 34200, 34201, 34201, 34202, 34203, 34203, 34193, 34194, 34194, 34196, 34199, 34200, 34194, 34195, 34195, 34196, 34196, 34197, 34197, 34198, 34198, 34199, 34199, 34200, 34200, 34201, 34201, 34202, 34202, 34203, 34203, 34204, 34204, 34195, 34196, 34196, 34197, 34197, 34198, 34198, 34199, 34199, 34200, 34200, 34201, 34201, 34202, 34203, 34203, 34204, 34204, 34205, 34196, 34197, 34197, 34198, 34198, 34199, 34199, 34200, 34200, 34201, 34201, 34202, 34203, 34203, 34204, 34204, 34205, 34205, 34197, 34198, 34198, 34199, 34199, 34200, 34200, 34201, 34201, 34202, 34202, 34203, 34204, 34205, 34205, 34206, 34198, 34199, 34200, 34200, 34201, 34201, 34202, 34203, 34204, 34204, 34205, 34206, 34206, 34199, 34200, 34200, 34201, 34202, 34202, 34203, 34204, 34205, 34206, 34207, 34201, 34202, 34203, 34203, 34204, 34205, 34205, 34201, 34202, 34202, 34203, 34203, 34204, 34204, 34205, 34206, 34207, 34208, 34202, 34203, 34203, 34204, 34205, 34206, 34206, 34207, 34208, 34208, 34203, 34204, 34204, 34205, 34205, 34206, 34207, 34207, 34208, 34209, 34204, 34205, 34205, 34206, 34207, 34207, 34208, 34209, 34205, 34206, 34206, 34207, 34208, 34208, 34209, 34209, 34210, 34206, 34207, 34208, 34208, 34209, 34209, 34210, 34210, 34207, 34208, 34208, 34209, 34209, 34210, 34210, 34211, 34208, 34209, 34209, 34210, 34210, 34211, 34211, 34209, 34210, 34211, 34211, 34212, 34210, 34211, 34211, 34212, 34212, 34211, 34212, 34212, 34213, 34212, 34213, 34213, 34213, 34214, 34214, 34215, 34216, 34216, 34217, 34217, 34218, 34219, 34219, 34220, 34220, 34221, 34222, 34223, 34224, 34224, 34225, 34226, 34227, 34229, 34231, 34232, 34233, 34233, 34234, 34235, 34236, 34237, 34238, 34239, 34241, 34241, 34250, 34250, 34251, 34251, 34252, 34252, 34595, 34637, 36129, 36156, 38456, 38485, 34216, 34217, 34217, 34218, 34218, 34219, 34219, 34220, 34220, 34221, 34221, 34222, 34223, 34223, 34224, 34224, 34225, 34225, 34226, 34226, 34227, 34228, 34229, 34230, 34230, 34231, 34231, 34232, 34233, 34233, 34234, 34235, 34236, 34237, 34238, 34238, 34239, 34239, 34240, 34240, 34241, 34243, 34244, 34246, 34247, 34249, 34249, 34250, 34251, 34251, 34252, 34252, 34253, 34595, 34637, 34217, 34218, 34218, 34219, 34219, 34220, 34220, 34221, 34223, 34224, 34224, 34225, 34225, 34226, 34226, 34227, 34228, 34230, 34231, 34235, 34237, 34239, 34240, 34241, 34243, 34245, 34248, 34252, 34218, 34219, 34219, 34220, 34220, 34221, 34221, 34222, 34224, 34226, 34227, 34230, 34231, 34232, 34234, 34236, 34237, 34253, 34254, 34219, 34220, 34221, 34221, 34224, 34224, 34226, 34235, 34241, 34254, 34220, 34221, 34221, 34222, 34223, 34223, 34224, 34224, 34225, 34226, 34226, 34227, 34228, 34237, 34237, 34242, 34248, 34255, 34221, 34222, 34222, 34223, 34225, 34228, 34230, 34241, 34253, 34222, 34223, 34224, 34224, 34225, 34225, 34226, 34228, 34228, 34229, 34230, 34232, 34233, 34233, 34234, 34237, 34239, 34241, 34253, 34256, 34223, 34224, 34224, 34225, 34225, 34226, 34227, 34227, 34228, 34233, 34233, 34236, 34239, 34240, 34242, 34224, 34225, 34225, 34226, 34227, 34227, 34228, 34228, 34229, 34232, 34234, 34237, 34239, 34240, 34251, 34225, 34226, 34226, 34227, 34227, 34228, 34229, 34230, 34230, 34231, 34234, 34234, 34235, 34236, 34244, 34246, 34255, 34257, 34226, 34227, 34227, 34228, 34228, 34229, 34229, 34230, 34233, 34234, 34238, 34240, 34241, 34243, 34245, 34251, 34258, 34227, 34228, 34228, 34229, 34229, 34230, 34232, 34235, 34244, 34248, 34258, 34228, 34229, 34229, 34231, 34231, 34232, 34233, 34236, 34245, 34229, 34230, 34230, 34231, 34232, 34232, 34233, 34234, 34235, 34236, 34236, 34238, 34239, 34242, 34245, 34258, 34230, 34231, 34231, 34232, 34233, 34235, 34236, 34238, 34240, 34246, 34247, 34232, 34233, 34233, 34240, 34243, 34247, 34250, 34260, 34260, 34232, 34233, 34233, 34237, 34244, 34248, 34254, 34261, 34233, 34234, 34234, 34236, 34241, 34243, 34244, 34245, 34247, 34260, 34261, 34261, 34234, 34235, 34235, 34236, 34236, 34237, 34237, 34238, 34238, 34239, 34240, 34241, 34242, 34242, 34243, 34243, 34244, 34244, 34245, 34246, 34247, 34247, 34248, 34249, 34249, 34250, 34251, 34251, 34259, 34261, 34262, 34604, 34235, 34236, 34236, 34237, 34238, 34238, 34239, 34239, 34241, 34241, 34242, 34242, 34243, 34244, 34245, 34248, 34249, 34250, 34252, 34253, 34254, 34258, 34262, 34237, 34237, 34238, 34239, 34239, 34240, 34241, 34243, 34243, 34244, 34246, 34247, 34248, 34250, 34250, 34252, 34252, 34257, 34259, 34261, 34263, 34238, 34239, 34240, 34240, 34242, 34244, 34249, 34257, 34240, 34247, 34249, 34250, 34251, 34259, 34261, 34264, 34247, 34264, 34241, 34241, 34242, 34244, 34245, 34245, 34247, 34248, 34249, 34250, 34251, 34252, 34258, 34264, 34265, 34248, 34249, 34265, 34242, 34243, 34243, 34244, 34247, 34248, 34251, 34243, 34244, 34245, 34245, 34246, 34247, 34248, 34249, 34249, 34250, 34251, 34252, 34253, 34253, 34255, 34256, 34256, 34260, 34260, 34261, 34264, 34266, 34244, 34245, 34245, 34246, 34247, 34247, 34248, 34249, 34250, 34251, 34251, 34252, 34253, 34254, 34254, 34261, 34263, 34264, 34265, 34265, 34267, 34248, 34250, 34254, 34267, 34246, 34248, 34248, 34250, 34251, 34252, 34253, 34254, 34255, 34257, 34264, 34267, 34268, 34248, 34249, 34249, 34250, 34251, 34252, 34253, 34255, 34257, 34267, 34268, 34249, 34249, 34254, 34260, 34263, 34269, 34252, 34257, 34258, 34250, 34251, 34252, 34252, 34253, 34254, 34255, 34256, 34256, 34260, 34267, 34268, 34269, 34270, 34252, 34253, 34254, 34256, 34257, 34257, 34264, 34269, 34270, 34270, 34252, 34253, 34253, 34254, 34255, 34258, 34262, 34269, 34270, 34271, 34253, 34257, 34259, 34255, 34256, 34257, 34258, 34259, 34260, 34261, 34263, 34270, 34271, 34255, 34256, 34258, 34259, 34259, 34270, 34272, 34257, 34257, 34258, 34258, 34259, 34260, 34260, 34262, 34262, 34264, 34265, 34267, 34269, 34269, 34271, 34272, 34273, 34257, 34260, 34273, 34258, 34259, 34259, 34260, 34260, 34261, 34261, 34262, 34263, 34265, 34267, 34268, 34269, 34271, 34273, 34274, 34260, 34272, 34260, 34261, 34262, 34262, 34264, 34264, 34270, 34274, 34275, 34261, 34262, 34262, 34263, 34263, 34264, 34264, 34265, 34265, 34267, 34268, 34268, 34269, 34270, 34271, 34271, 34272, 34273, 34273, 34274, 34275, 34275, 34262, 34264, 34267, 34272, 34275, 34263, 34264, 34265, 34266, 34266, 34267, 34268, 34269, 34270, 34270, 34271, 34271, 34272, 34273, 34273, 34274, 34274, 34275, 34275, 34276, 34276, 34264, 34265, 34266, 34266, 34268, 34268, 34269, 34269, 34270, 34270, 34271, 34271, 34272, 34272, 34274, 34275, 34275, 34276, 34277, 34265, 34266, 34267, 34268, 34268, 34269, 34269, 34271, 34271, 34273, 34273, 34274, 34274, 34275, 34275, 34276, 34276, 34277, 34277, 34266, 34267, 34278, 34267, 34268, 34268, 34269, 34269, 34270, 34272, 34274, 34275, 34277, 34278, 34278, 34268, 34269, 34272, 34273, 34274, 34274, 34276, 34278, 34279, 34269, 34270, 34270, 34271, 34272, 34273, 34273, 34274, 34274, 34275, 34275, 34276, 34276, 34277, 34277, 34278, 34278, 34279, 34279, 34270, 34271, 34271, 34273, 34273, 34274, 34274, 34276, 34277, 34278, 34280, 34272, 34273, 34275, 34279, 34272, 34274, 34276, 34276, 34277, 34280, 34273, 34274, 34275, 34275, 34276, 34276, 34277, 34278, 34278, 34279, 34279, 34280, 34281, 34281, 34276, 34277, 34277, 34279, 34276, 34276, 34277, 34277, 34278, 34279, 34279, 34280, 34280, 34281, 34281, 34282, 34282, 34283, 34277, 34278, 34278, 34279, 34279, 34280, 34280, 34281, 34282, 34282, 34283, 34283, 34278, 34279, 34279, 34280, 34281, 34281, 34282, 34282, 34283, 34283, 34284, 34279, 34280, 34281, 34282, 34282, 34283, 34284, 34284, 34280, 34281, 34281, 34282, 34282, 34283, 34283, 34284, 34284, 34285, 34281, 34282, 34282, 34283, 34283, 34284, 34284, 34285, 34285, 34282, 34283, 34283, 34284, 34284, 34285, 34286, 34283, 34284, 34284, 34285, 34286, 34286, 34284, 34285, 34285, 34286, 34286, 34287, 34285, 34286, 34286, 34287, 34287, 34286, 34287, 34287, 34288, 34287, 34288, 34288, 34288, 34289, 34289, 34738, 34290, 34291, 34291, 34630, 34632, 34632, 34674, 34681, 34685, 34690, 36166, 36194, 36196, 36217, 36220, 38493, 38522, 65914, 10129458, 18431536, 26617487, 34291, 34292, 34632, 34633, 34633, 34633, 34633, 34634, 34676, 34973, 34974, 34975, 34976, 34976, 34977, 34977, 34978, 34979, 34979, 34985, 34986, 34986, 34988, 34993, 34994, 34996, 35001, 35003, 35008, 35010, 35013, 35014, 35014, 35015, 35016, 35016, 35017, 35050, 34976, 34977, 34987, 35014, 35016, 35017, 35017, 34977, 35017, 35017, 35018, 35017, 35018, 35018, 34991, 35018, 35018, 35019, 35019, 35020, 35020, 35021, 34996, 35028, 35028, 35028, 36548, 35030, 35030, 35033, 35036, 35037, 35043, 35045, 35049, 35051, 35054, 35055, 35056, 35057, 35057, 35057, 35058, 35058, 35092, 35059, 35060, 35060, 35061, 35061, 35062, 35063, 35063, 35064, 35064, 35065, 35065, 35066, 35066, 35067, 35067, 35068, 35068, 35069, 35069, 35070, 35070, 35071, 35071, 35072, 35073, 35073, 35074, 35074, 35075, 35076, 35076, 35077, 35078, 35078, 35079, 35080, 35082, 35082, 35083, 35084, 35085, 35085, 35086, 35088, 35089, 35090, 35090, 35091, 35092, 35092, 35060, 35061, 35061, 35062, 35062, 35063, 35064, 35065, 35066, 35066, 35067, 35068, 35069, 35070, 35071, 35075, 35077, 35084, 35085, 35090, 35091, 35092, 35093, 35062, 35064, 35066, 35068, 35071, 35071, 35077, 35090, 35093, 35062, 35063, 35064, 35066, 35067, 35068, 35069, 35069, 35071, 35073, 35075, 35084, 35087, 35094, 35063, 35064, 35065, 35065, 35066, 35066, 35067, 35067, 35068, 35068, 35069, 35071, 35072, 35072, 35075, 35075, 35076, 35077, 35081, 35084, 35093, 35094, 35094, 35065, 35066, 35067, 35069, 35070, 35095, 35067, 35067, 35069, 35071, 35073, 35083, 35096, 35068, 35069, 35070, 35071, 35077, 35082, 35096, 35068, 35070, 35071, 35072, 35084, 35090, 35096, 35097, 35069, 35071, 35071, 35072, 35075, 35075, 35076, 35077, 35097, 35071, 35072, 35073, 35075, 35090, 35091, 35098, 35072, 35072, 35098, 35073, 35074, 35076, 35078, 35085, 35073, 35074, 35075, 35075, 35081, 35082, 35084, 35084, 35086, 35092, 35093, 35099, 35075, 35076, 35077, 35078, 35078, 35079, 35080, 35081, 35082, 35082, 35083, 35084, 35085, 35087, 35089, 35092, 35093, 35094, 35095, 35095, 35100, 35075, 35100, 35076, 35077, 35078, 35078, 35079, 35079, 35080, 35080, 35081, 35081, 35082, 35082, 35083, 35084, 35085, 35086, 35086, 35087, 35088, 35088, 35089, 35089, 35090, 35090, 35091, 35092, 35093, 35094, 35095, 35095, 35096, 35097, 35101, 35079, 35094, 35095, 35101, 35079, 35094, 35095, 35102, 35085, 35102, 35085, 35085, 35093, 35081, 35082, 35082, 35083, 35084, 35085, 35085, 35086, 35087, 35088, 35089, 35090, 35090, 35091, 35091, 35092, 35093, 35094, 35094, 35096, 35096, 35097, 35100, 35101, 35102, 35103, 35103, 35082, 35089, 35090, 35096, 35097, 35103, 35104, 35083, 35084, 35085, 35086, 35086, 35090, 35091, 35091, 35093, 35093, 35094, 35097, 35097, 35098, 35099, 35104, 35085, 35090, 35090, 35091, 35091, 35092, 35093, 35093, 35094, 35095, 35097, 35098, 35103, 35104, 35105, 35087, 35086, 35087, 35087, 35090, 35091, 35091, 35093, 35093, 35094, 35095, 35096, 35098, 35106, 35088, 35089, 35089, 35091, 35091, 35092, 35093, 35093, 35094, 35094, 35095, 35097, 35099, 35102, 35106, 35092, 35093, 35106, 35107, 35090, 35091, 35091, 35092, 35092, 35093, 35094, 35094, 35095, 35096, 35100, 35100, 35105, 35107, 35107, 35093, 35094, 35095, 35099, 35100, 35101, 35107, 35108, 35092, 35093, 35093, 35094, 35095, 35095, 35096, 35099, 35100, 35102, 35107, 35108, 35108, 35095, 35101, 35093, 35096, 35098, 35101, 35109, 35095, 35095, 35097, 35109, 35110, 35096, 35097, 35098, 35101, 35103, 35110, 35110, 35097, 35098, 35100, 35103, 35104, 35109, 35110, 35111, 35098, 35098, 35099, 35100, 35102, 35102, 35104, 35104, 35111, 35111, 35098, 35099, 35100, 35101, 35102, 35104, 35106, 35109, 35110, 35111, 35112, 38897, 35099, 35100, 35101, 35101, 35102, 35103, 35105, 35105, 35110, 35111, 35112, 35112, 35100, 35101, 35101, 35102, 35103, 35105, 35105, 35106, 35113, 35103, 35103, 35104, 35105, 35106, 35106, 35110, 35113, 35103, 35104, 35106, 35108, 35114, 35105, 35107, 35107, 35108, 35109, 35111, 35104, 35105, 35106, 35107, 35109, 35106, 35108, 35108, 35109, 35113, 35115, 35108, 35115, 35116, 35107, 35109, 35110, 35111, 35114, 35116, 35110, 35111, 35114, 35115, 35117, 35110, 35114, 35117, 35110, 35117, 35111, 35112, 35113, 35113, 35114, 35115, 35116, 35118, 35118, 35113, 35113, 35114, 35114, 35115, 35116, 35116, 35117, 35118, 35119, 35114, 35114, 35115, 35116, 35117, 35117, 35118, 35118, 35119, 35120, 36606, 35116, 35116, 35117, 35118, 35120, 35120, 35121, 35118, 35119, 35120, 35121, 35121, 35122, 35122, 35122, 35123, 35123, 35123, 35123, 35124, 35124, 35124, 35125, 35125, 35126, 35127, 35127, 35128, 35128, 35129, 35130, 35132, 35132, 35133, 35135, 35136, 35136, 35137, 35137, 35138, 35138, 35139, 35139, 35142, 35143, 35144, 35149, 35156, 35157, 35158, 35161, 35164, 35165, 35166, 35167, 35167, 35168, 36584, 36612, 36616, 36626, 36633, 36638, 36642, 36676, 38911, 38940, 66417, 35127, 35128, 35128, 35129, 35129, 35130, 35131, 35131, 35132, 35132, 35133, 35133, 35134, 35136, 35137, 35137, 35138, 35139, 35139, 35140, 35143, 35145, 35147, 35149, 35152, 35154, 35157, 35158, 35158, 35163, 35163, 35164, 35164, 35165, 35166, 35166, 35167, 35168, 35168, 36615, 35133, 35137, 35138, 35140, 35148, 35149, 35157, 35168, 35169, 35135, 35139, 35141, 35169, 35169, 35132, 35170, 36614, 35141, 35142, 35160, 35165, 35133, 35147, 35171, 35137, 35140, 35142, 35143, 35171, 35172, 38944, 35172, 35159, 35166, 35173, 35140, 35142, 35145, 35168, 35174, 35144, 35158, 35174, 35174, 35166, 35175, 35159, 35175, 35147, 35147, 35177, 35148, 35148, 35149, 35171, 35177, 35178, 35162, 35168, 35150, 35150, 35179, 35150, 35179, 35170, 35177, 35180, 35152, 35176, 35178, 35180, 35152, 35163, 35171, 35180, 35181, 35159, 35170, 35171, 35172, 35172, 35179, 35181, 35181, 35184, 35185, 35175, 35186, 35187, 35175, 35188, 35189, 35189, 35190, 35191, 35192, 35193, 35193, 35184, 35194, 35195, 35196, 35187, 35187, 35188, 35198, 35189, 35199, 35190, 35199, 35197, 35199, 35200, 35200, 35200, 35201, 35201, 35202, 35203, 35204, 35204, 35205, 35205, 35206, 35207, 35207, 35207, 35207, 35208, 35208, 35209, 35209, 35210, 35211, 35211, 36626, 36626, 36654, 36677, 36680, 36681, 38953, 38982, 39001, 39003, 39006, 42884, 53591, 26617947, 36627, 36627, 36628, 38042, 38043, 38044, 38044, 38045, 38046, 38047, 38049, 38065, 38066, 38067, 38068, 38069, 38069, 38070, 38070, 38112, 38118, 38045, 38045, 38070, 38071, 38071, 38071, 38047, 38048, 38070, 38071, 38072, 38049, 38072, 38072, 38073, 38072, 38073, 38074, 38077, 38092, 38093, 38094, 38093, 38095, 38096, 38096, 38096, 38096, 38097, 38097, 38098, 38099, 38099, 38100, 38100, 38101, 38101, 38102, 38102, 38103, 38103, 38104, 38105, 38106, 38106, 38107, 38107, 38108, 38109, 38109, 38110, 38110, 38111, 38112, 38113, 38114, 38115, 38115, 38116, 38117, 38117, 38118, 38118, 38119, 38119, 38120, 38120, 38121, 38121, 38122, 38122, 38123, 38123, 38124, 38124, 38125, 38125, 38126, 38126, 38127, 38128, 38128, 38129, 38130, 38132, 38136, 38138, 38138, 38139, 38140, 38141, 38141, 38143, 38145, 38145, 38146, 38146, 38100, 38101, 38102, 38102, 38105, 38107, 38112, 38116, 38118, 38119, 38119, 38120, 38120, 38121, 38121, 38122, 38125, 38146, 38146, 38100, 38120, 38122, 38124, 38127, 38110, 38115, 38121, 38122, 38122, 38104, 38110, 38121, 38122, 38123, 38103, 38105, 38115, 38116, 38121, 38122, 38122, 38131, 38148, 38118, 38119, 38121, 38122, 38123, 38123, 38124, 38124, 38126, 38149, 38119, 38120, 38122, 38122, 38123, 38124, 38127, 38131, 38149, 38123, 38123, 38124, 38125, 38125, 38134, 38135, 38146, 38127, 38127, 38124, 38151, 38126, 38127, 38120, 38127, 38153, 38116, 38126, 38127, 38129, 38134, 38130, 38125, 38136, 38129, 38131, 38131, 38156, 38125, 38126, 38157, 38125, 38136, 38133, 38136, 38132, 38134, 38132, 38135, 38160, 38143, 38130, 38133, 38135, 38136, 38131, 38133, 38135, 38137, 38139, 38162, 38138, 38143, 38163, 38136, 38137, 38138, 38141, 38142, 38155, 38138, 38139, 38138, 38144, 38147, 38164, 38138, 38165, 38139, 38138, 38139, 38139, 38140, 38141, 38141, 38144, 38149, 38140, 38140, 38141, 38141, 38142, 38144, 38146, 38148, 38149, 38140, 38141, 38141, 38142, 38142, 38144, 38145, 38147, 38167, 38141, 38142, 38142, 38143, 38143, 38144, 38145, 38145, 38146, 38146, 38147, 38147, 38148, 38149, 38153, 38155, 38159, 38160, 38161, 38164, 38165, 38166, 38166, 38167, 38167, 38142, 38143, 38145, 38146, 38148, 38143, 38144, 38145, 38146, 38146, 38147, 38147, 38148, 38149, 38149, 38150, 38150, 38152, 38157, 38162, 38163, 38163, 38164, 38167, 38168, 38144, 38145, 38146, 38146, 38147, 38147, 38148, 38148, 38149, 38149, 38150, 38152, 38152, 38153, 38154, 38156, 38157, 38158, 38159, 38161, 38162, 38163, 38164, 38165, 38166, 38167, 38167, 38168, 38168, 38169, 38146, 38146, 38147, 38147, 38148, 38148, 38149, 38149, 38150, 38151, 38157, 38160, 38164, 38165, 38166, 38168, 38168, 38169, 38169, 38147, 38148, 38148, 38148, 38170, 38148, 38149, 38151, 38152, 38155, 38159, 38166, 38167, 38168, 38169, 38170, 38171, 38149, 38150, 38150, 38151, 38151, 38152, 38153, 38154, 38163, 38164, 38165, 38169, 38170, 38171, 38171, 38150, 38151, 38151, 38152, 38152, 38153, 38154, 38155, 38156, 38157, 38157, 38160, 38161, 38164, 38169, 38170, 38171, 38172, 38151, 38152, 38153, 38160, 38161, 38166, 38169, 38172, 38172, 38153, 38153, 38154, 38154, 38155, 38156, 38162, 38167, 38170, 38172, 38173, 38153, 38154, 38155, 38157, 38172, 38173, 38173, 38154, 38155, 38157, 38157, 38159, 38167, 38171, 38174, 38156, 38162, 38164, 38174, 38174, 38158, 38170, 38172, 38171, 38172, 38175, 38175, 38159, 38169, 38173, 38175, 38175, 38176, 38176, 38160, 38169, 38176, 38176, 38177, 38168, 38177, 38177, 38178, 38177, 38178, 38173, 38178, 38179, 38167, 38169, 38179, 38180, 38181, 38181, 38174, 38179, 38181, 38182, 38174, 38182, 38179, 38183, 38183, 38183, 38184, 38184, 38185, 38179, 38183, 38185, 38185, 38186, 38186, 38186, 38203, 38182, 38186, 38187, 38187, 38185, 38186, 38187, 38188, 38183, 38188, 38189, 38189, 38189, 38190, 38189, 38190, 38188, 38189, 38190, 38191, 38191, 38191, 38191, 38192, 38192, 38192, 38193, 38193, 38194, 38195, 38195, 38196, 38196, 38197, 38200, 38201, 38205, 38205, 38210, 38211, 38211, 38212, 38213, 38214, 38215, 38215, 38218, 38218, 38219, 38219, 38220, 38220, 38221, 38221, 40445, 40474, 40497, 40499, 44376, 44396, 2392842, 38195, 38196, 38196, 38201, 38206, 38209, 38212, 38212, 38215, 38216, 38216, 38218, 38219, 38219, 38220, 38220, 38221, 38221, 38222, 38206, 38220, 38222, 38213, 38222, 38222, 38223, 38223, 38217, 38227, 38228, 38228, 38230, 38223, 38228, 38229, 38233, 38233, 38228, 38237, 38238, 38238, 38232, 38233, 38234, 38235, 38236, 38237, 38239, 38239, 38241, 38241, 38236, 38240, 38242, 38242, 38243, 38243, 38240, 38242, 38242, 38244, 38245, 38245, 38244, 38245, 38246, 38245, 38245, 38246, 44401, 38245, 38246, 38247, 38246, 38247, 38247, 38247, 38248, 38248, 40472, 38249, 38252, 40472, 40473, 40502, 40522, 40524, 40526, 40528, 40530, 40533, 44403, 44423, 67893, 13690986, 40473, 40476, 42696, 42697, 42698, 42698, 42699, 42699, 42700, 42700, 42703, 42704, 42709, 42711, 42715, 42716, 42717, 42719, 42720, 42721, 42721, 42722, 42723, 42723, 42724, 42724, 42725, 42725, 42726, 42767, 42699, 42699, 42700, 42701, 42712, 42720, 42720, 42722, 42726, 42726, 42699, 42700, 42700, 42702, 42726, 42727, 42700, 42701, 42701, 42703, 42709, 42720, 42721, 42726, 42727, 42727, 42701, 42720, 42727, 42727, 42728, 42703, 42710, 42720, 42722, 42722, 42727, 42727, 42728, 42728, 42728, 42729, 42723, 42726, 42729, 42729, 42730, 42730, 42732, 42732, 42731, 42736, 42737, 42735, 42736, 42743, 42736, 42745, 42745, 42746, 42741, 42746, 42741, 42742, 42748, 42744, 42744, 42745, 42746, 42747, 42748, 42749, 42745, 42750, 42750, 42750, 42750, 42751, 42751, 42752, 42752, 42752, 42753, 42752, 42753, 42753, 42753, 42754, 42754, 42755, 42756, 42756, 42757, 42757, 42758, 42758, 42759, 42759, 42760, 42762, 42762, 42763, 42764, 42764, 42765, 42765, 42766, 42766, 42767, 42767, 42768, 42769, 42770, 42770, 42771, 42772, 42772, 42773, 42773, 42774, 42774, 42775, 42775, 42776, 42777, 42777, 42778, 42778, 42779, 42779, 42780, 42780, 42781, 42782, 42782, 42783, 42787, 42787, 42796, 42801, 42756, 42757, 42757, 42758, 42759, 42759, 42760, 42760, 42762, 42764, 42765, 42766, 42767, 42768, 42770, 42770, 42771, 42772, 42773, 42774, 42774, 42775, 42775, 42776, 42776, 42777, 42778, 42778, 42779, 42779, 42780, 42801, 42802, 42757, 42758, 42758, 42760, 42764, 42767, 42771, 42773, 42774, 42775, 42776, 42776, 42777, 42778, 42780, 42802, 42759, 42759, 42761, 42761, 42762, 42763, 42768, 42770, 42771, 42774, 42775, 42776, 42776, 42777, 42777, 42779, 42768, 42769, 42770, 42772, 42772, 42773, 42774, 42776, 42777, 42778, 42779, 42761, 42761, 42763, 42769, 42771, 42772, 42776, 42776, 42777, 42777, 42778, 42780, 42771, 42772, 42775, 42779, 42780, 42763, 42769, 42776, 42779, 42781, 42764, 42768, 42771, 42773, 42774, 42776, 42777, 42779, 42779, 42780, 42778, 42779, 42779, 42780, 42781, 42767, 42769, 42772, 42774, 42775, 42775, 42772, 42781, 42774, 42782, 42783, 42777, 42778, 42779, 42780, 42781, 42784, 42785, 42790, 42779, 42782, 42783, 42785, 42779, 42781, 42785, 42788, 42778, 42788, 42781, 42783, 42787, 42788, 42779, 42780, 42781, 42786, 42786, 42787, 42782, 42782, 42785, 42787, 42788, 42789, 42795, 42813, 42782, 42788, 42783, 42788, 42789, 42783, 42785, 42788, 42789, 42793, 42784, 42788, 42788, 42789, 42790, 42792, 42786, 42787, 42787, 42788, 42789, 42789, 42790, 42790, 42791, 42791, 42792, 42792, 42793, 42793, 42794, 42795, 42797, 42816, 42788, 42791, 42791, 42792, 42794, 42795, 42789, 42792, 42794, 42789, 42792, 42792, 42793, 42794, 42795, 42813, 42818, 42790, 42791, 42792, 42792, 42793, 42793, 42794, 42795, 42796, 42799, 42813, 42792, 42792, 42793, 42794, 42795, 42800, 42819, 42792, 42794, 42794, 42795, 42796, 42797, 42797, 42814, 42794, 42794, 42795, 42796, 42796, 42798, 42801, 42814, 42794, 42795, 42795, 42796, 42797, 42797, 42798, 42798, 42801, 42804, 42795, 42796, 42796, 42797, 42797, 42798, 42798, 42799, 42799, 42803, 42803, 42812, 42816, 42796, 42797, 42798, 42798, 42799, 42799, 42800, 42800, 42801, 42802, 42805, 42808, 42811, 42816, 42816, 42818, 42822, 42797, 42798, 42798, 42799, 42799, 42800, 42800, 42801, 42801, 42802, 42803, 42803, 42804, 42805, 42808, 42808, 42812, 42814, 42815, 42817, 42817, 42822, 42798, 42799, 42800, 42802, 42799, 42800, 42800, 42801, 42801, 42802, 42803, 42804, 42804, 42809, 42813, 42818, 42823, 70168, 42800, 42801, 42801, 42802, 42802, 42803, 42804, 42805, 42805, 42807, 42808, 42808, 42810, 42810, 42811, 42812, 42812, 42813, 42818, 42821, 42823, 42824, 42801, 42802, 42802, 42803, 42803, 42804, 42805, 42805, 42806, 42807, 42808, 42810, 42811, 42812, 42814, 42815, 42818, 42819, 42824, 42802, 42803, 42803, 42804, 42804, 42805, 42806, 42811, 42812, 42819, 42825, 42803, 42804, 42804, 42805, 42805, 42806, 42806, 42807, 42807, 42808, 42808, 42809, 42809, 42810, 42811, 42812, 42813, 42814, 42814, 42815, 42816, 42817, 42818, 42820, 42825, 42804, 42805, 42805, 42806, 42806, 42807, 42807, 42808, 42808, 42809, 42810, 42812, 42814, 42820, 42823, 42825, 42826, 42805, 42806, 42806, 42807, 42807, 42808, 42809, 42809, 42810, 42811, 42812, 42813, 42814, 42817, 42820, 42821, 42826, 42806, 42807, 42807, 42808, 42808, 42809, 42809, 42810, 42811, 42813, 42813, 42825, 42826, 42827, 42807, 42808, 42808, 42810, 42811, 42812, 42813, 42817, 42821, 42822, 42822, 42827, 42808, 42809, 42810, 42811, 42814, 42824, 42828, 42809, 42810, 42810, 42811, 42811, 42812, 42812, 42813, 42813, 42814, 42815, 42815, 42816, 42817, 42817, 42818, 42818, 42819, 42820, 42821, 42823, 42824, 42824, 42825, 42826, 42827, 42828, 42828, 46683, 42810, 42811, 42811, 42812, 42812, 42813, 42813, 42815, 42815, 42817, 42818, 42822, 42823, 42824, 42825, 42827, 42829, 42811, 42812, 42812, 42813, 42814, 42814, 42815, 42815, 42819, 42822, 42822, 42824, 42825, 42829, 42812, 42813, 42814, 42815, 42815, 42816, 42816, 42818, 42822, 42824, 42829, 42830, 42813, 42814, 42814, 42815, 42816, 42817, 42819, 42820, 42820, 42821, 42825, 42830, 42830, 42814, 42815, 42815, 42817, 42817, 42818, 42819, 42820, 42821, 42822, 42823, 42824, 42825, 42827, 42828, 42830, 42831, 42815, 42816, 42817, 42818, 42819, 42820, 42821, 42821, 42825, 42826, 42829, 42831, 42816, 42818, 42820, 42820, 42822, 42826, 42832, 42818, 42819, 42819, 42820, 42821, 42821, 42822, 42827, 42829, 42829, 42831, 42832, 42827, 42832, 42819, 42820, 42828, 42820, 42821, 42822, 42822, 42823, 42826, 42826, 42828, 42828, 42830, 42831, 42831, 42832, 42833, 42834, 42821, 42822, 42823, 42823, 42824, 42824, 42825, 42825, 42826, 42826, 42829, 42834, 42825, 42826, 42828, 42829, 42824, 42825, 42826, 42827, 42827, 42829, 42829, 42830, 42830, 42832, 42834, 42835, 42836, 42826, 42827, 42828, 42831, 42836, 42826, 42827, 42831, 42833, 42837, 42827, 42828, 42828, 42829, 42830, 42831, 42831, 42832, 42833, 42834, 42835, 42836, 42837, 42831, 42832, 42834, 42836, 42838, 42831, 42833, 42835, 42838, 42831, 42833, 42839, 42834, 42839, 42834, 42840, 42835, 42840, 42835, 42840, 42841, 42836, 42836, 42839, 42841, 42836, 42838, 42837, 42838, 42838, 42839, 42839, 42840, 42840, 42841, 42841, 42842, 42842, 42870, 42871, 46697, 46717, 42838, 42839, 42839, 42840, 42841, 42842, 42842, 42843, 42871, 42872, 42839, 42840, 42840, 42841, 42841, 42843, 42843, 42841, 42842, 42843, 42843, 42844, 42841, 42842, 42842, 42843, 42843, 42844, 42844, 42842, 42843, 42844, 42845, 46700, 42844, 42845, 42845, 42844, 42845, 42846, 42845, 42846, 42846, 42846, 42847, 42847, 42848, 42849, 42850, 42850, 42851, 42854, 42854, 42857, 42861, 42863, 42866, 42868, 42869, 42872, 42873, 42873, 42874, 42874, 42875, 42875, 42876, 42876, 42877, 46702, 46703, 46723, 46728, 46753, 46762, 57384, 57410, 57415, 70191, 70193, 70213, 70276, 70278, 42849, 42850, 42850, 42851, 42851, 42852, 42855, 42855, 42856, 42859, 42860, 42861, 42861, 42862, 42862, 42863, 42863, 42864, 42867, 42867, 42868, 42869, 42870, 42870, 42871, 42871, 42872, 42873, 42873, 42874, 42874, 42875, 42875, 42876, 42876, 42877, 42877, 42851, 42856, 42864, 42866, 42876, 42877, 42877, 42878, 42862, 42864, 42878, 42865, 42873, 42878, 42879, 42865, 42879, 42876, 42879, 42880, 42856, 42881, 42883, 42862, 42873, 42883, 42882, 42883, 42880, 42884, 42886, 42883, 42873, 42875, 42881, 42889, 42889, 42889, 42890, 42890, 42877, 42889, 42890, 42891, 42879, 42881, 42882, 42883, 42888, 42889, 42889, 42890, 42890, 42891, 42891, 42892, 42889, 42892, 42884, 42893, 42885, 42886, 42894, 42894, 42895, 42893, 42895, 42896, 42893, 42894, 42896, 42897, 42889, 42896, 42896, 42892, 42893, 42897, 42898, 42896, 42897, 42898, 42898, 42899, 42896, 42900, 42896, 42899, 42900, 42898, 42899, 42900, 42900, 42901, 42901, 42898, 42899, 42899, 42900, 42901, 42902, 42899, 42900, 42901, 42901, 42902, 42902, 42901, 42901, 42902, 42902, 42903, 42901, 42902, 42903, 42903, 42902, 42903, 42903, 42904, 42903, 42904, 42904, 42904, 42905, 42905, 42906, 42907, 42909, 43023, 43026, 46731, 46732, 46752, 46754, 46782, 46789, 57413, 57438, 57439, 57467, 70222, 70242, 4303437, 4861872, 46732, 46752, 46733, 46735, 43215, 43218, 46924, 46924, 50557, 50558, 50559, 50559, 50560, 50560, 50561, 50563, 50568, 50569, 50570, 50571, 50572, 50573, 50573, 50574, 50575, 50576, 50576, 50577, 50577, 50578, 50559, 50560, 50560, 50561, 50562, 50563, 50572, 50574, 50574, 50576, 50576, 50577, 50578, 50578, 50561, 50561, 50575, 50578, 50579, 50561, 50579, 50562, 50566, 50575, 50576, 50578, 50578, 50579, 50579, 50580, 50580, 50580, 50579, 50580, 50582, 50579, 50584, 50579, 61249, 50585, 50589, 50619, 50590, 50587, 50587, 50588, 50588, 50589, 50589, 50590, 50592, 50593, 50593, 50594, 50603, 50605, 50623, 50624, 50624, 50628, 50628, 50630, 50631, 50653, 50594, 50603, 50594, 50595, 50595, 50594, 50595, 50595, 50596, 50595, 50596, 50596, 50596, 50597, 50653, 50597, 50599, 50602, 50606, 50607, 50618, 50628, 50634, 50639, 50653, 50598, 50599, 50599, 50600, 50600, 50601, 50602, 50602, 50603, 50604, 50604, 50605, 50605, 50606, 50606, 50607, 50607, 50608, 50608, 50609, 50609, 50610, 50610, 50611, 50611, 50612, 50612, 50613, 50613, 50614, 50615, 50615, 50616, 50616, 50617, 50617, 50618, 50618, 50619, 50620, 50620, 50621, 50621, 50622, 50622, 50623, 50623, 50624, 50624, 50625, 50625, 50626, 50626, 50627, 50628, 50628, 50629, 50629, 50630, 50631, 50632, 50632, 50633, 50634, 50635, 50635, 50637, 50639, 50643, 50647, 50652, 50653, 50653, 50654, 50599, 50600, 50600, 50601, 50603, 50604, 50605, 50606, 50606, 50607, 50608, 50609, 50609, 50611, 50611, 50612, 50613, 50617, 50620, 50620, 50621, 50624, 50626, 50626, 50627, 50628, 50628, 50629, 50635, 50653, 50654, 50603, 50605, 50611, 50612, 50621, 50624, 50629, 50607, 50614, 50615, 50619, 50622, 50623, 50602, 50605, 50609, 50613, 50614, 50614, 50615, 50620, 50621, 50623, 50626, 50627, 50628, 50630, 50609, 50610, 50613, 50616, 50618, 50620, 50622, 50623, 50627, 50630, 50606, 50610, 50624, 50626, 50631, 50611, 50609, 50615, 50624, 50625, 50635, 50609, 50614, 50625, 50632, 50632, 50637, 50616, 50629, 50631, 50611, 50613, 50612, 50613, 50615, 50617, 50660, 50614, 50626, 50635, 50639, 50615, 50620, 50624, 50625, 50629, 50636, 50615, 50626, 50631, 50644, 50616, 50617, 50617, 50618, 50619, 50620, 50621, 50622, 50626, 50627, 50628, 50629, 50629, 50633, 50634, 50635, 50635, 50636, 50637, 50640, 50641, 50641, 50644, 50646, 50647, 50648, 50662, 50663, 50666, 50620, 50626, 50629, 50630, 50635, 50637, 50638, 50662, 50663, 50619, 50620, 50622, 50631, 50631, 50634, 50635, 50638, 50638, 50663, 50621, 50623, 50634, 50637, 50638, 50621, 50625, 50633, 50643, 50664, 50622, 50628, 50630, 50631, 50631, 50632, 50632, 50637, 50638, 50639, 50644, 50637, 50625, 50625, 50626, 50627, 50628, 50630, 50631, 50632, 50632, 50633, 50636, 50638, 50639, 50640, 50641, 50648, 50666, 50670, 50625, 50633, 50641, 50664, 50666, 50625, 50629, 50634, 50639, 50641, 50645, 50653, 50626, 50629, 50632, 50633, 50635, 50639, 50642, 50634, 50634, 50635, 50635, 50636, 50637, 50637, 50640, 50641, 50642, 50643, 50644, 50661, 50632, 50634, 50635, 50637, 50639, 50641, 50642, 50633, 50643, 50644, 50669, 50651, 50632, 50636, 50636, 50649, 50633, 50636, 50638, 50641, 50650, 50670, 50634, 50635, 50645, 50648, 50636, 50638, 50638, 50639, 50643, 50650, 50640, 50641, 50645, 50646, 50647, 50647, 50651, 50652, 50639, 50640, 50640, 50645, 50647, 50648, 50652, 50655, 50673, 50640, 50640, 50641, 50644, 50647, 50657, 50641, 50641, 50642, 50644, 50645, 50646, 50646, 50648, 50649, 50652, 50655, 61280, 50675, 50641, 50642, 50642, 50643, 50645, 50645, 50647, 50647, 50648, 50649, 50650, 50652, 50653, 50654, 50656, 50663, 50675, 50679, 50642, 50643, 50643, 50645, 50645, 50646, 50647, 50648, 50649, 50649, 50650, 50650, 50653, 50654, 50654, 50656, 50657, 50675, 50644, 50644, 50645, 50646, 50646, 50648, 50648, 50650, 50651, 50654, 50657, 50644, 50645, 50646, 50646, 50647, 50647, 50648, 50649, 50649, 50650, 50650, 50651, 50651, 50655, 50656, 50660, 50680, 50646, 50647, 50647, 50648, 50649, 50651, 50652, 50655, 50658, 61334, 50647, 50648, 50649, 50650, 50651, 50652, 50652, 50654, 50655, 50661, 50677, 50650, 50652, 50652, 50653, 50656, 50656, 50649, 50650, 50651, 50653, 50653, 50678, 50649, 50650, 50651, 50651, 50652, 50653, 50653, 50654, 50651, 50652, 50652, 50654, 50656, 50657, 50661, 50661, 50679, 50652, 50653, 50654, 50654, 50655, 50661, 50668, 50653, 50654, 50655, 50655, 50656, 50660, 50662, 50664, 50681, 50685, 50654, 50655, 50656, 50656, 50657, 50657, 50659, 50660, 50661, 50681, 50656, 50656, 50657, 50660, 50661, 50672, 50676, 50681, 50682, 50656, 50657, 50657, 50660, 50682, 50657, 50658, 50660, 50661, 50661, 50662, 50662, 50663, 50664, 50665, 50669, 50673, 50674, 50677, 50683, 50658, 50659, 50660, 50661, 50661, 50662, 50662, 50663, 50664, 50665, 50670, 50675, 50676, 50683, 50683, 50659, 50660, 50660, 50661, 50661, 50662, 50662, 50663, 50663, 50665, 50665, 50666, 50666, 50667, 50668, 50669, 50670, 50670, 50671, 50672, 50673, 50674, 50674, 50675, 50676, 50677, 50678, 50680, 50680, 50682, 50683, 50684, 50684, 50662, 50663, 50666, 50662, 50664, 50676, 50685, 50664, 50665, 50665, 50667, 50671, 50685, 50664, 50665, 50686, 50664, 50665, 50665, 50666, 50667, 50668, 50668, 50669, 50673, 50686, 50665, 50666, 50666, 50668, 50669, 50670, 50674, 50678, 50687, 50666, 50667, 50668, 50669, 50669, 50670, 50671, 50674, 50674, 50675, 50687, 50687, 50667, 50668, 50669, 50669, 50670, 50671, 50671, 50672, 50672, 50674, 50674, 50675, 50680, 50685, 50687, 50688, 50669, 50670, 50670, 50671, 50671, 50672, 50672, 50673, 50675, 50677, 50677, 50680, 50682, 50684, 50687, 50688, 50688, 50689, 50671, 50680, 50671, 50672, 50673, 50676, 50687, 50689, 50690, 50672, 50674, 50674, 50675, 50675, 50676, 50677, 50677, 50678, 50688, 50688, 50690, 50673, 50674, 50675, 50675, 50676, 50676, 50677, 50677, 50679, 50679, 50680, 50681, 50682, 50686, 50688, 50689, 50690, 50691, 50676, 50691, 50675, 50678, 50687, 50689, 50692, 50676, 50677, 50680, 50683, 50683, 50687, 50690, 50692, 50692, 50677, 50679, 50679, 50686, 50692, 50693, 50680, 50681, 50682, 50682, 50685, 50689, 50693, 50693, 50694, 50680, 50680, 50681, 50682, 50694, 50685, 50694, 50695, 50682, 50683, 50691, 50695, 50682, 50683, 50686, 50686, 50687, 50688, 50693, 50695, 50695, 50696, 50690, 50695, 50696, 50696, 50696, 50688, 50692, 50697, 50691, 50697, 50697, 50692, 50697, 50698, 50696, 50697, 50699, 50693, 50697, 50699, 50699, 50691, 50693, 50700, 50697, 50698, 50700, 50700, 50701, 50701, 50701, 74116, 50702, 50702, 50703, 50703, 50704, 50701, 50704, 50704, 50704, 50705, 50705, 50706, 50705, 50706, 50706, 50706, 50707, 50707, 50707, 50708, 50708, 50709, 50710, 50711, 50712, 50713, 50714, 50715, 50719, 50719, 50721, 50722, 50725, 50726, 50726, 50727, 50727, 50728, 50728, 50729, 61314, 61315, 61340, 61343, 74143, 74206, 74208, 74209, 50710, 50711, 50712, 50712, 50713, 50714, 50715, 50720, 50720, 50721, 50722, 50722, 50723, 50724, 50725, 50725, 50726, 50727, 50727, 50728, 50728, 50729, 50729, 61315, 50714, 50714, 50726, 50727, 50728, 50729, 50730, 50713, 50714, 50724, 50726, 50730, 50714, 50715, 50729, 50730, 50730, 50731, 50716, 50730, 50716, 50717, 50718, 50721, 50723, 50725, 50725, 50726, 50728, 50730, 50730, 50731, 50731, 50732, 50733, 61319, 50718, 50723, 50725, 50729, 50731, 50731, 50732, 50732, 50733, 50720, 50726, 50732, 50734, 50730, 50727, 50730, 50731, 50735, 50731, 50737, 50738, 50737, 50739, 50737, 50738, 50739, 50738, 50740, 50735, 50737, 50738, 50739, 50739, 50740, 50736, 50737, 50739, 50741, 50739, 50741, 50742, 50741, 50743, 50741, 50743, 50744, 50742, 50744, 50742, 50742, 50743, 50744, 50745, 50743, 50743, 50744, 50745, 50744, 50744, 50745, 50746, 50744, 50745, 50745, 50746, 50746, 61332, 50745, 50746, 50746, 50747, 50746, 50747, 50747, 50747, 50748, 50748, 50749, 50750, 61334, 61335, 61360, 61362, 61384, 61387, 61388, 61389, 61390, 61393, 74143, 74163, 2399120, 2399120, 2447330, 4307359, 4865792, 61335, 61336, 71920, 71921, 71922, 71923, 71923, 71925, 71926, 71927, 71927, 71929, 71930, 71931, 71931, 71932, 71933, 71935, 71942, 71943, 71944, 71944, 71945, 71945, 71946, 71946, 71944, 71945, 71946, 71946, 71947, 71936, 71947, 71948, 71946, 71948, 71949, 71950, 71950, 71950, 71952, 71951, 71952, 71952, 71953, 71955, 71940, 71942, 71956, 71955, 71956, 71944, 71957, 84760, 71958, 71987, 84825, 71959, 71959, 71960, 71967, 71967, 71968, 71969, 71968, 71969, 71970, 71969, 71970, 71970, 71970, 71971, 71971, 72014, 72021, 71972, 71973, 71973, 71974, 71974, 71975, 71976, 71976, 71977, 71977, 71978, 71980, 71980, 71981, 71983, 71983, 71984, 71984, 71985, 71986, 71988, 71989, 71989, 71990, 71991, 71991, 71992, 71993, 71994, 71994, 71995, 71995, 71996, 71997, 71997, 71998, 71998, 71999, 71999, 72000, 72001, 72001, 72002, 72002, 72003, 72004, 72005, 72005, 72006, 72006, 72007, 72011, 72015, 72020, 72020, 72021, 72021, 72022, 72022, 72023, 71973, 71974, 71974, 71975, 71976, 71978, 71990, 71991, 71993, 71994, 71994, 71995, 71996, 71997, 71998, 71998, 72022, 72022, 71974, 71975, 71979, 71984, 71986, 71990, 71992, 71995, 71996, 71997, 71998, 71999, 72000, 72001, 72022, 72022, 72023, 71975, 71976, 71979, 71985, 71992, 71993, 71995, 71996, 71997, 71999, 72002, 72003, 72006, 72020, 72022, 72023, 72023, 71976, 71978, 71980, 71993, 71993, 71994, 71994, 71997, 71998, 71999, 72000, 72000, 72001, 72004, 72023, 72024, 71978, 71988, 71994, 71995, 71996, 71998, 71998, 71999, 72000, 72006, 72012, 72023, 72024, 71981, 72024, 71982, 72000, 72025, 72025, 72026, 71997, 72000, 72026, 71994, 72000, 72026, 72027, 72001, 72002, 72006, 72010, 72027, 72028, 71999, 72028, 72005, 72030, 71991, 72004, 72030, 72005, 72010, 71994, 72005, 72006, 72009, 71995, 72000, 72008, 72016, 72033, 72034, 71998, 71999, 72006, 72009, 72009, 72030, 72035, 72019, 72037, 72010, 72012, 72038, 72009, 72011, 72021, 72017, 72021, 72039, 84792, 72014, 72009, 72011, 72014, 72016, 72018, 72023, 72024, 72010, 72013, 72013, 72014, 72016, 72016, 84774, 72014, 72015, 72019, 72023, 72024, 72030, 72041, 72015, 72021, 72014, 72015, 72016, 72016, 72017, 72018, 72019, 72020, 72041, 72041, 72042, 84775, 72016, 72017, 72023, 72042, 72021, 72017, 72018, 72020, 72022, 72024, 72026, 72031, 72043, 72017, 72018, 72018, 72021, 72021, 72022, 72023, 72025, 72019, 72020, 72020, 72021, 72022, 72027, 72042, 72044, 72019, 72020, 72021, 72022, 72022, 72023, 72023, 72024, 72025, 72028, 72040, 72045, 72045, 72020, 72021, 72021, 72022, 72022, 72023, 72023, 72024, 72024, 72025, 72026, 72031, 72032, 72042, 72045, 72045, 72046, 72021, 72022, 72023, 72023, 72024, 72025, 72025, 72026, 72026, 72029, 72029, 72042, 72043, 72046, 72046, 72047, 72023, 72024, 72024, 72025, 72027, 72037, 72045, 72047, 72047, 72024, 72025, 72025, 72027, 72029, 72030, 72031, 72038, 72040, 72040, 72041, 72042, 72046, 72047, 72047, 72048, 72025, 72026, 72026, 72028, 72029, 72041, 72041, 72048, 72048, 72026, 72027, 72028, 72028, 72030, 72031, 72033, 72041, 72045, 72046, 72048, 72049, 72027, 72028, 72028, 72029, 72029, 72031, 72034, 72039, 72040, 72041, 72047, 72048, 72049, 72049, 72029, 72030, 72032, 72038, 72046, 72049, 72050, 72050, 72031, 72033, 72049, 72050, 72050, 72031, 72032, 72032, 72033, 72034, 72046, 72049, 72050, 72050, 72051, 72032, 72033, 72034, 72050, 72051, 72051, 72052, 72034, 72036, 72044, 72049, 72051, 72051, 72052, 72040, 72043, 72052, 72042, 72048, 72052, 72053, 72049, 72050, 72053, 72036, 72053, 72053, 72054, 72039, 72047, 72051, 72053, 72054, 72054, 72049, 72054, 72055, 72055, 72055, 72046, 72055, 72056, 72055, 72056, 72053, 72056, 72058, 72059, 72060, 72054, 72060, 72060, 72061, 72061, 72062, 72059, 72061, 72062, 72062, 72063, 72063, 72064, 72057, 72059, 72059, 84880, 72058, 72064, 72064, 72065, 84798, 72063, 72065, 72065, 72065, 72063, 72066, 72066, 72066, 72066, 72067, 72067, 72065, 72067, 72068, 72068, 72067, 72068, 72068, 72068, 72069, 72069, 72069, 72070, 72069, 72070, 72096, 72070, 72071, 72097, 84804, 84824, 84887, 1598862, 72072, 72073, 72073, 72080, 72080, 72086, 72086, 72087, 72087, 72088, 72088, 72091, 72094, 72095, 72095, 72096, 72096, 72097, 72097, 84805, 84825, 84888, 1332141, 72073, 72074, 72076, 72079, 72082, 72082, 72086, 72087, 72091, 72091, 72092, 72094, 72095, 72096, 72096, 72097, 72097, 72098, 84890, 4318117, 72081, 72092, 72098, 72098, 72099, 72099, 72101, 72104, 72105, 72106, 72107, 72107, 72109, 72111, 72112, 72110, 72112, 72113, 72113, 72114, 72116, 72116, 72117, 72119, 72120, 72121, 72121, 72121, 72121, 72122, 72122, 72123, 72158, 72158, 84829, 84830, 84830, 84831, 84832, 84845, 84850, 84915, 84916, 2341608, 2409807, 2409807, 4318046, 9421991, 26636403, 84831, 72261, 72259, 84931, 84934, 97536, 97537, 97538, 97539, 97539, 97540, 97540, 97541, 97542, 97547, 97549, 97556, 97556, 97557, 97557, 97558, 97560, 97561, 97569, 97542, 97557, 97558, 97558, 97540, 97558, 97559, 97542, 97550, 97559, 97559, 97560, 97560, 97560, 97560, 97561, 97561, 97561, 97562, 97558, 97559, 97561, 97569, 97633, 97573, 97576, 97576, 97576, 97576, 97577, 97632, 97577, 97578, 97579, 97580, 97580, 97581, 97581, 97582, 97583, 97583, 97584, 97585, 97588, 97588, 97589, 97589, 97590, 97590, 97591, 97592, 97593, 97593, 97594, 97595, 97595, 97596, 97597, 97597, 97598, 97598, 97599, 97599, 97600, 97601, 97601, 97602, 97603, 97603, 97604, 97604, 97605, 97606, 97606, 97608, 97608, 97609, 97609, 97610, 97611, 97612, 97612, 97613, 97613, 97614, 97615, 97616, 97618, 97619, 97620, 97620, 97621, 97621, 97622, 97622, 97623, 97624, 97624, 97625, 97627, 97629, 97632, 97633, 97633, 97634, 97635, 97581, 97582, 97585, 97588, 97590, 97596, 97596, 97598, 97600, 97601, 97602, 97604, 97609, 97610, 97612, 97616, 97618, 97620, 97634, 97598, 97600, 97602, 97603, 97605, 97605, 97620, 97635, 97606, 97621, 97583, 97584, 97588, 97599, 97600, 97601, 97601, 97602, 97603, 97604, 97606, 97610, 97616, 97623, 97636, 97599, 97601, 97604, 97604, 97605, 97608, 97624, 97633, 97636, 97586, 97589, 97607, 97623, 97625, 97637, 97605, 97595, 97607, 97611, 97614, 97604, 97594, 97612, 97640, 97593, 97601, 97608, 97609, 97641, 97597, 97616, 97613, 97615, 97616, 97622, 97644, 97601, 97615, 97634, 97620, 97627, 97640, 97613, 97614, 97644, 97628, 97634, 97625, 97634, 97648, 97625, 97635, 97619, 97650, 97614, 97621, 97627, 97617, 97621, 97623, 97651, 97615, 97621, 97617, 97616, 97617, 97620, 97624, 97627, 97628, 97630, 97631, 97638, 97640, 97652, 97620, 97621, 97625, 97619, 97619, 97622, 97626, 97629, 97646, 97653, 97653, 97619, 97621, 97624, 97629, 97630, 97636, 97654, 97622, 97623, 97624, 97625, 97642, 97654, 97623, 97623, 97627, 97630, 97632, 97633, 97634, 97641, 97642, 97655, 97630, 97637, 97624, 97625, 97626, 97627, 97628, 97631, 97631, 97633, 97640, 97651, 97655, 97656, 97656, 97627, 97629, 97630, 97632, 97641, 97647, 97653, 97657, 2422558, 97627, 97628, 97629, 97630, 97632, 97633, 97633, 97635, 97636, 97636, 97642, 97646, 97647, 97657, 97657, 97643, 97629, 97630, 97631, 97632, 97632, 97633, 97634, 97634, 97635, 97638, 97640, 97646, 97647, 97648, 97651, 97659, 97631, 97632, 97634, 97634, 97639, 97645, 97659, 97635, 97636, 97646, 97649, 97633, 97634, 97635, 97636, 97637, 97638, 97639, 97639, 97640, 97646, 97647, 97648, 97652, 97658, 97661, 97634, 97636, 97636, 97637, 97645, 97647, 97650, 97661, 97636, 97637, 97637, 97639, 97640, 97648, 97650, 97652, 97653, 97661, 97662, 97638, 97644, 97638, 97639, 97639, 97642, 97644, 97648, 97649, 97650, 97651, 97651, 97653, 97655, 97656, 97660, 97663, 4330803, 97639, 97640, 97641, 97643, 97645, 97650, 97651, 97651, 97652, 97653, 97653, 97654, 97661, 97664, 97640, 97644, 97646, 97647, 97649, 97652, 97655, 97656, 97664, 97642, 97644, 97646, 97647, 97648, 97650, 97651, 97652, 97653, 97655, 97664, 97665, 97650, 97644, 97645, 97645, 97647, 97652, 97653, 97657, 97665, 97666, 97654, 97659, 97666, 97646, 97651, 97654, 97658, 97659, 97667, 97648, 97656, 97657, 97665, 97667, 97647, 97649, 97655, 97655, 97656, 97658, 97659, 97668, 97654, 97656, 97668, 97654, 97655, 97662, 97669, 97653, 97659, 97667, 97670, 97670, 97657, 97657, 97659, 97671, 2422572, 97654, 97656, 97671, 97661, 97663, 97661, 97673, 97658, 97659, 97660, 97661, 97664, 97665, 97666, 97666, 97669, 97674, 97661, 97662, 97663, 97664, 97665, 97666, 97667, 97670, 97670, 97674, 97675, 97668, 97671, 97675, 97663, 97665, 97669, 97670, 97676, 97664, 97666, 97669, 97676, 97676, 97665, 97666, 97668, 97675, 97677, 2470788, 97669, 97674, 97677, 97667, 97669, 97673, 97677, 97678, 97678, 97678, 97698, 97670, 97679, 97671, 97673, 97675, 97679, 97687, 97679, 97680, 97687, 97680, 97680, 97681, 97674, 97678, 97681, 97681, 97682, 97682, 97683, 97683, 97683, 97684, 97684, 97684, 97685, 97686, 97706, 97686, 97687, 97688, 97688, 97689, 97690, 97691, 97692, 97694, 97695, 97696, 97696, 97699, 97703, 97703, 97704, 97704, 97705, 97706, 97707, 97707, 97708, 97708, 97709, 2422590, 2422590, 97690, 97691, 97692, 97693, 97695, 97697, 97702, 97705, 97706, 97707, 97707, 97708, 97708, 97709, 97709, 97707, 97707, 97709, 97710, 97711, 97711, 97712, 97713, 97714, 97713, 97703, 97715, 97705, 97716, 97706, 97706, 97707, 97717, 97717, 97707, 97708, 97708, 97718, 97708, 97709, 97717, 97718, 97719, 97719, 97719, 97721, 97723, 97722, 97723, 97724, 4330844, 97724, 97725, 97726, 97724, 97725, 97726, 97726, 97727, 97726, 97727, 97727, 97727, 97728, 97728, 97729, 102954, 133043, 327571, 363614, 437975, 499835, 500542, 500542, 500543, 502379, 688565, 703777, 738024, 744652, 753053, 971794, 975699, 995893, 1259947, 1344969, 1482151, 1611595, 1628261, 1642241, 1759623, 1759629, 1880099, 1880101, 1958421, 1960686, 2128384, 2128388, 2128392, 2128394, 2177915, 2392091, 2422609, 2422610, 2422610, 2422611, 2422611, 2422612, 2422612, 2422613, 2422613, 2470815, 2470816, 2470817, 2470817, 2470818, 2470819, 2470819, 2470821, 2470822, 2470826, 2691745, 2691752, 2891935, 2908556, 3053311, 3470739, 3473955, 3473955, 3473956, 3473956, 3473957, 3473957, 3473958, 3473958, 3473959, 4047877, 4114084, 4330848, 4330849, 4330880, 4330881, 4330882, 4330899, 4330900, 4330904, 4330945, 4889283, 8341886, 2128392, 4330849, 108190, 2427849, 168374, 4366180, 557424, 557424, 557425, 557426, 730395, 4560702, 557439, 2652465, 2173292, 629515, 629516, 2688510, 2733861, 1532479, 778282, 778298, 2762918, 778375, 778447, 2468786, 901952, 2530509, 903367, 903367, 903368, 903368, 903369, 2825435, 2825435, 2825437, 4733674, 3294761, 3876783, 907039, 907216, 907392, 4735736, 1279414, 4921697, 1309840, 3028673, 1378391, 1378476, 1378565, 1616155, 1391590, 2824854, 1408389, 2249897, 3077947, 1845875, 5763364, 1853682, 1853682, 3300592, 3300593, 5208831, 3300593, 3300595, 5208832, 1894069, 3026568, 2422196, 2422272, 2422347, 3584935, 2435444, 3591475, 2592225, 5578104, 2866644, 2866783, 2866924, 4858591, 3091410, 3625241, 3125472, 3125568, 3125667, 3642367, 3936585, 3158803, 5861487, 3186767, 3672918, 3421530, 3421534, 3421603, 3421604, 3421678, 3421679, 5992830, 5992831, 3662484, 3662484, 6113232, 5256342, 3789156, 4268330, 3819129, 4283317, 3823667, 6193830, 4159064, 4159065, 4159071, 4159075, 4159068, 4159070, 4159071, 4159072, 4159073, 4159074, 4159074, 4453286, 4453288, 4453288, 4922613, 4453289, 4453291, 6361529, 4453290, 4453291, 5504638, 4453291, 4922617, 4453293, 4258114, 4258115, 5662466, 4502809, 4611104, 6587573, 4686503, 4717022, 4747490, 4747491, 4747505, 4747491, 4747492, 4747492, 4747493, 4747493, 4747494, 4747506, 4747506, 4747507, 4747507, 4747508, 4747508, 4747492, 4747493, 4747493, 4747494, 4747505, 4747506, 4747507, 4747507, 4747508, 4747508, 4747509, 4747493, 4747494, 4747494, 4747495, 4747507, 4747507, 4747508, 4747508, 4747509, 4747494, 4747496, 4747496, 4747507, 4747508, 4747508, 4747509, 4747509, 4747510, 4747495, 4747496, 4747497, 4747508, 4747508, 4747509, 4747509, 4747510, 4747510, 4747511, 4747508, 4747509, 4747510, 4747511, 4747509, 4747510, 4747512, 4747513, 4747509, 4747510, 4747513, 4747510, 4747512, 4747520, 6655744, 4747521, 4747522, 4747522, 4747523, 4747523, 4747525, 4757902, 4795711, 4795713, 5016641, 5798854, 6655745, 6655841, 4747522, 4747523, 4747523, 4747524, 4747525, 4795713, 4795714, 4795716, 5016641, 5137490, 5216831, 5798853, 5798853, 5798854, 5798855, 5798855, 5798856, 5798856, 6655745, 6655841, 7214180, 4747523, 4747524, 4747524, 4795715, 4795717, 5016649, 5216832, 5795636, 5798853, 5798854, 5798854, 5798855, 5845237, 6164747, 6513407, 6655745, 6655746, 6655842, 7214179, 4747524, 4747525, 4747526, 4747527, 4795715, 4795717, 5016642, 5026407, 5026409, 5130237, 5795636, 5798854, 5798854, 5798855, 5798855, 5798856, 5798857, 5845237, 6515973, 6610647, 6655746, 4747525, 4747526, 4747527, 4747527, 4795716, 4795718, 4795718, 4887429, 5016643, 5216833, 5378208, 5430286, 5798853, 5798854, 5798855, 5798855, 5798856, 5798856, 5798857, 5798857, 5819147, 5819147, 5907165, 6438983, 6655747, 6655778, 6655843, 4747527, 4795715, 4795716, 4795717, 4795718, 4795719, 5798855, 5798855, 5798856, 5798857, 5998848, 6655747, 6655781, 6655807, 6655843, 4795717, 6655748, 5016644, 5798857, 5907167, 6655748, 5111804, 5798859, 6655749, 5798858, 6655749, 4768295, 5714565, 4838205, 6701189, 4843918, 4843919, 4843918, 4843920, 4843920, 4843906, 4843921, 4843921, 4843908, 4843922, 4843922, 4843923, 4843909, 4843923, 4843924, 4843923, 4843925, 4843923, 4843924, 4843925, 4843924, 4843925, 4843926, 4843927, 4843934, 6703951, 4843936, 5843843, 6703952, 4843938, 5064849, 5131499, 5482724, 5847061, 5847061, 5847062, 6703953, 5847062, 5064858, 5847063, 5847064, 6703954, 6704050, 6703957, 5027346, 5938772, 5285768, 5285785, 5285788, 5285793, 5285796, 5285845, 5285813, 5285855, 5285854, 5285858, 5285865, 5285930, 5285907, 5285934, 5285938, 5285940, 6068051, 5486052, 5300750, 6068075, 6068077, 6068078, 6924941, 6924968, 5305306, 5305308, 6077753, 6934645, 5315546, 6082873, 5419073, 6991527, 5476092, 6163146, 5513022, 5513098, 5513170, 7038603, 5527499, 5527570, 5527640, 7045824, 5686152, 6268173, 6268174, 6268175, 6268175, 6288466, 6908301, 7125066, 5719450, 5719825, 5720202, 7142120, 6008907, 6008905, 7286443, 6429556, 6113055, 6113129, 6113204, 7338591, 6121524, 6485860, 6660835, 6775811, 6843763, 6843764, 6843763, 6843764, 7703872, 6846982, 7703873, 7703874, 6850184, 6850196, 6850200, 6850198, 6850200, 6850184, 6850185, 6850186, 6850187, 6850196, 6850197, 6850199, 6850199, 6850200, 6850200, 6850201, 6850201, 6850186, 6850199, 6850200, 6850200, 6850201, 6850201, 6850202, 6850186, 6850187, 6850187, 6850198, 6850198, 6850201, 6850201, 6850202, 6850202, 6850199, 6850200, 6850201, 6850202, 6850202, 6850203, 6850188, 6850199, 6850202, 6850203, 6850203, 6850203, 6850204, 6850204, 6850190, 6850202, 6850204, 6850204, 6850203, 6850204, 6850205, 6850206, 7707089, 7707089, 6850215, 6870490, 7707090, 7707090, 6850216, 7707091, 7424119, 7707091, 6850216, 6850217, 6958510, 7707092, 7707123, 6850217, 7707092, 6850217, 6850218, 7707092, 7707093, 6850218, 7707040, 7707093, 7707093, 6958512, 7490329, 7564755, 7707093, 7707094, 7707094, 7707095, 6890784, 6890772, 6890786, 6890786, 7658226, 7727383, 7727384, 6942965, 6942967, 7753474, 7753476, 7066818, 7066818, 7815399, 7815400, 7815496, 7250183, 7764743, 7581983, 8072981, 7998037, 8281009, 8130451, 8130452, 8130453, 8347216, 8347217, 8279303, 8279304, 8421642, 8421643, 8284433, 8424207, 8425665, 8494919, 8473783, 8518882, 8563915, 8563942, 8563968, 8563969, 8563970, 8563970, 8563971, 8563973, 8563979, 8563981, 8563990, 8563991, 8563993, 8563995, 8563996, 8563997, 8563998, 8563999, 8563999, 8564000, 8564000, 8564001, 8564001, 8564002, 8564002, 8564003, 8564019, 8563970, 8563971, 8563972, 8563999, 8563999, 8564000, 8564000, 8564002, 8563971, 8563972, 8563997, 8563999, 8564000, 8564000, 8564001, 8564003, 8564000, 8564001, 8564002, 8564004, 8564003, 8564010, 8564012, 8564033, 8564012, 8564021, 8564021, 8564021, 8564023, 8564026, 8564023, 8564026, 8564027, 8564027, 8564027, 8564028, 8564029, 8564029, 8564029, 8564030, 8564032, 8564030, 8564031, 8564033, 8564031, 8564032, 8564032, 8564033, 8564033, 8564034, 8564034, 8564036, 8564038, 8564043, 8564045, 8564048, 8564049, 8564049, 8564050, 8564050, 8564051, 8564051, 8564053, 8564053, 8564054, 8564054, 8564055, 8564056, 8564056, 8564057, 8564059, 8564060, 8564075, 8564075, 8564076, 8564032, 8564033, 8564033, 8564034, 8564035, 8564037, 8564038, 8564038, 8564043, 8564046, 8564051, 8564051, 8564052, 8564053, 8564055, 8564055, 8564056, 8564056, 8564058, 8564069, 8564075, 8564076, 8564076, 8564077, 8564034, 8564034, 8564052, 8564055, 8564077, 8564034, 8564035, 8564035, 8564036, 8564036, 8564037, 8564037, 8564038, 8564039, 8564039, 8564040, 8564040, 8564041, 8564041, 8564042, 8564043, 8564044, 8564045, 8564045, 8564047, 8564048, 8564048, 8564049, 8564051, 8564052, 8564052, 8564053, 8564053, 8564054, 8564054, 8564055, 8564056, 8564056, 8564057, 8564058, 8564058, 8564059, 8564060, 8564060, 8564061, 8564062, 8564068, 8564071, 8564077, 8564078, 8564078, 8564079, 8564037, 8564038, 8564038, 8564041, 8564043, 8564046, 8564048, 8564050, 8564053, 8564054, 8564054, 8564056, 8564057, 8564059, 8564062, 8564078, 8564038, 8564040, 8564040, 8564049, 8564054, 8564054, 8564055, 8564058, 8564058, 8564080, 8564044, 8564054, 8564055, 8564080, 8564055, 8564055, 8564056, 8564057, 8564059, 8564056, 8564057, 8564058, 8564082, 8564055, 8564057, 8564058, 8564082, 8564056, 8564057, 8564058, 8564058, 8564058, 8564061, 8564081, 8564061, 8564059, 8564068, 8564060, 8564061, 8564062, 8564087, 8564088, 8564057, 8564062, 8564063, 8564087, 8564073, 8564064, 8564065, 8564065, 8564066, 8564068, 8564070, 8564073, 8564065, 8564066, 8564067, 8564068, 8564071, 8564071, 8564072, 8564071, 8564072, 8564069, 8564073, 8564069, 8564070, 8564070, 8564071, 8564072, 8564079, 8564070, 8564071, 8564071, 8564072, 8564072, 8564073, 8564073, 8564074, 8564074, 8564075, 8564075, 8564076, 8564077, 8564077, 8564078, 8564078, 8564079, 8564079, 8564082, 8564088, 8564090, 8564092, 8564093, 8564094, 8564094, 8564095, 8564071, 8564072, 8564072, 8564073, 8564073, 8564074, 8564075, 8564075, 8564076, 8564076, 8564077, 8564078, 8564079, 8564079, 8564080, 8564081, 8564090, 8564093, 8564094, 8564095, 8564095, 8564072, 8564073, 8564073, 8564074, 8564074, 8564075, 8564075, 8564076, 8564076, 8564077, 8564077, 8564078, 8564078, 8564079, 8564079, 8564080, 8564080, 8564081, 8564082, 8564083, 8564086, 8564089, 8564090, 8564093, 8564094, 8564094, 8564095, 8564095, 8564096, 8564096, 8564097, 8564074, 8564074, 8564078, 8564078, 8564096, 8564074, 8564075, 8564076, 8564076, 8564077, 8564078, 8564081, 8564075, 8564076, 8564076, 8564077, 8564077, 8564078, 8564078, 8564079, 8564080, 8564080, 8564081, 8564081, 8564082, 8564083, 8564086, 8564089, 8564089, 8564090, 8564096, 8564096, 8564097, 8564097, 8564098, 8564076, 8564077, 8564077, 8564078, 8564078, 8564079, 8564080, 8564080, 8564081, 8564081, 8564083, 8564089, 8564091, 8564092, 8564096, 8564096, 8564097, 8564098, 8564098, 8564099, 8564077, 8564078, 8564078, 8564079, 8564079, 8564080, 8564080, 8564081, 8564081, 8564082, 8564085, 8564089, 8564092, 8564095, 8564096, 8564097, 8564097, 8564098, 8564099, 8564078, 8564079, 8564079, 8564080, 8564081, 8564082, 8564083, 8564083, 8564094, 8564097, 8564097, 8564099, 8564079, 8564080, 8564080, 8564081, 8564082, 8564082, 8564083, 8564083, 8564084, 8564085, 8564089, 8564091, 8564092, 8564093, 8564095, 8564097, 8564097, 8564098, 8564098, 8564099, 8564099, 8564100, 8564080, 8564081, 8564081, 8564082, 8564083, 8564083, 8564084, 8564084, 8564085, 8564086, 8564088, 8564091, 8564092, 8564093, 8564094, 8564094, 8564096, 8564097, 8564097, 8564098, 8564098, 8564099, 8564099, 8564100, 8564100, 8564101, 8564081, 8564082, 8564082, 8564083, 8564083, 8564084, 8564085, 8564086, 8564094, 8564097, 8564098, 8564098, 8564099, 8564100, 8564100, 8564101, 8564101, 8564083, 8564083, 8564084, 8564084, 8564085, 8564085, 8564089, 8564094, 8564096, 8564099, 8564099, 8564100, 8564100, 8564101, 8564102, 8564085, 8564087, 8564093, 8564096, 8564098, 8564099, 8564100, 8564101, 8564101, 8564085, 8564086, 8564098, 8564099, 8564101, 8564102, 8564103, 8564085, 8564086, 8564087, 8564092, 8564094, 8564096, 8564100, 8564100, 8564101, 8564101, 8564102, 8564102, 8564103, 8564086, 8564087, 8564087, 8564089, 8564094, 8564096, 8564097, 8564100, 8564102, 8564103, 8564104, 8564087, 8564089, 8564092, 8564092, 8564098, 8564099, 8564101, 8564101, 8564102, 8564103, 8564103, 8564104, 8564088, 8564089, 8564090, 8564091, 8564097, 8564102, 8564102, 8564103, 8564103, 8564104, 8564105, 8564091, 8564093, 8564094, 8564095, 8564098, 8564099, 8564100, 8564101, 8564102, 8564102, 8564103, 8564104, 8564105, 8564105, 8564095, 8564105, 8564101, 8564099, 8564104, 8564105, 8564106, 8564107, 8564097, 8564101, 8564105, 8564106, 8564107, 8564102, 8564106, 8564108, 8564103, 8564103, 8564109, 8564109, 8564109, 8564110, 8564108, 8564110, 8564110, 8564105, 8564109, 8564111, 8564110, 8564110, 8564113, 8564112, 8564112, 8564113, 8564111, 8564111, 8564112, 8564112, 8564113, 8564113, 8564114, 8564110, 8564112, 8564113, 8564113, 8564114, 8564110, 8564110, 8564112, 8564114, 8564114, 8564115, 8564116, 8564113, 8564115, 8564116, 8564136, 8564114, 8564116, 8564114, 8564115, 8564116, 8564116, 8564117, 8564115, 8564115, 8564116, 8564117, 8564118, 8564116, 8564117, 8564118, 8564119, 8564117, 8564118, 8564118, 8564119, 8564119, 8564118, 8564119, 8564119, 8564120, 8564119, 8564120, 8564120, 8564121, 8564121, 8564135, 8564140, 8564150, 8564150, 8564151, 8564121, 8564126, 8564133, 8564134, 8564137, 8564141, 8564146, 8564147, 8564149, 8564149, 8564150, 8564150, 8564151, 8564151, 8564122, 8564123, 8564123, 8564125, 8564126, 8564130, 8564131, 8564135, 8564136, 8564137, 8564138, 8564141, 8564143, 8564144, 8564145, 8564145, 8564146, 8564147, 8564147, 8564148, 8564149, 8564149, 8564150, 8564150, 8564151, 8564151, 8564152, 9122480, 8564123, 8564124, 8564125, 8564126, 8564127, 8564127, 8564131, 8564133, 8564136, 8564137, 8564137, 8564138, 8564142, 8564147, 8564147, 8564148, 8564149, 8564149, 8564150, 8564150, 8564151, 8564151, 8564152, 8564152, 8564150, 8564153, 8564152, 8564153, 8564153, 8564127, 8564135, 8564145, 8564151, 8564155, 8564153, 8564156, 8564156, 8564156, 8564156, 8564160, 8564159, 8564151, 8564157, 8564160, 8564162, 8564163, 8564159, 8564149, 8564154, 8564163, 8564164, 8564165, 8564151, 8564155, 8564164, 8564164, 8564165, 8564166, 8564156, 8564166, 8564167, 8564157, 8564164, 8564165, 8564167, 8564167, 8564166, 8564161, 8564162, 8564165, 8564167, 8564168, 8564169, 8564169, 8564170, 8564170, 8564171, 8564171, 8564162, 8564167, 8564171, 8564172, 8564172, 9122501, 8564173, 8564174, 8564175, 8564174, 8564175, 8564173, 8564175, 8564176, 8564173, 8564176, 8564177, 8564175, 8564177, 8564176, 8564178, 8564176, 8564178, 8564176, 8564177, 8564178, 8564178, 8564177, 8564178, 8564179, 8564179, 8564178, 8564179, 8564179, 8564180, 8564179, 8564180, 8564180, 8564180, 8564181, 8564181, 8564182, 8564183, 8613218, 8614464, 8798538, 8833246, 8955662, 9009693, 9009693, 9032984, 9032984, 9040138, 9040138, 9040139, 9095399, 9122509, 9122509, 9122510, 9122510, 9122514, 9122517, 9122518, 9122520, 9122521, 9345763, 9366029, 10703176, 13668021, 17953954, 17953956, 18578131, 18581110, 8564199, 8603564, 9122509, 9122510, 9122517, 10703176, 11455150, 9122511, 9122525, 8642957, 8642959, 9161903, 9161905, 8662278, 8662384, 8662491, 9171676, 8664758, 9172804, 9032908, 9356879, 9102333, 9391596, 9347154, 9514001, 9455219, 9455220, 9568035, 9501798, 9501797, 9501900, 9501902, 9502003, 9502004, 9509052, 9591425, 9516105, 9516107, 9516107, 9516107, 9516108, 9516110, 9598478, 9598479, 9598478, 9598479, 9598480, 9626632, 9653742, 9680836, 9680837, 9680842, 9680837, 9680838, 9680839, 9680839, 9680840, 9680841, 9680841, 9680842, 9680842, 9680843, 9680843, 9680844, 9680844, 9680845, 9680845, 9680846, 9680846, 9680847, 9680847, 9680848, 9680848, 9680849, 9680850, 9680850, 9680851, 9680851, 9680852, 9680852, 9680853, 9680853, 9680854, 9680854, 9680855, 9680856, 9680857, 9680858, 9680860, 9680839, 9680840, 9680840, 9680842, 9680843, 9680844, 9680844, 9680845, 9680845, 9680846, 9680846, 9680847, 9680847, 9680848, 9680848, 9680849, 9680849, 9680850, 9680851, 9680852, 9680853, 9680853, 9680854, 9680856, 9680846, 9680847, 9680848, 9680842, 9680844, 9680846, 9680857, 9680848, 9680846, 9680848, 9680849, 9680850, 9680848, 9680848, 9680856, 9680849, 9680850, 9680851, 9680854, 9680856, 9680857, 9680860, 9680849, 9680850, 9680851, 9680852, 9680848, 9680849, 9680850, 9680850, 9680851, 9680851, 9680852, 9680849, 9680850, 9680850, 9680851, 9680852, 9680852, 9680855, 9680851, 9680851, 9680852, 9680852, 9680853, 9680853, 9680855, 9680856, 9680857, 9680861, 9680851, 9680852, 9680852, 9680853, 9680853, 9680854, 9680858, 9680859, 9680860, 9680852, 9680853, 9680853, 9680854, 9680854, 9680855, 9680857, 9680859, 9680860, 9680860, 9680861, 9680864, 9680853, 9680854, 9680854, 9680855, 9680855, 9680857, 9680857, 9680859, 9680859, 9680860, 9680861, 9680862, 9680862, 9680863, 9680854, 9680855, 9680855, 9680856, 9680857, 9680858, 9680861, 9680861, 9680862, 9680863, 9680855, 9680856, 9680856, 9680857, 9680858, 9680858, 9680859, 9680859, 9680860, 9680860, 9680861, 9680862, 9680863, 9680864, 9680864, 9680865, 9680868, 9680870, 9680871, 9680856, 9680857, 9680857, 9680858, 9680858, 9680859, 9680859, 9680860, 9680860, 9680861, 9680861, 9680862, 9680862, 9680863, 9680864, 9680864, 9680865, 9680865, 9680866, 9680867, 9680867, 9680868, 9680868, 9680871, 9680857, 9680858, 9680858, 9680859, 9680859, 9680860, 9680860, 9680861, 9680861, 9680862, 9680862, 9680863, 9680863, 9680864, 9680865, 9680865, 9680866, 9680866, 9680867, 9680867, 9680868, 9680858, 9680859, 9680859, 9680860, 9680860, 9680861, 9680862, 9680862, 9680863, 9680863, 9680865, 9680865, 9680866, 9680866, 9680868, 9680868, 9680873, 9680860, 9680860, 9680861, 9680862, 9680863, 9680864, 9680867, 9680860, 9680861, 9680861, 9680862, 9680863, 9680864, 9680864, 9680861, 9680862, 9680862, 9680863, 9680863, 9680864, 9680864, 9680865, 9680865, 9680868, 9680874, 9680862, 9680863, 9680863, 9680864, 9680864, 9680865, 9680865, 9680868, 9680863, 9680864, 9680864, 9680865, 9680865, 9680866, 9680868, 9680864, 9680865, 9680865, 9680866, 9680866, 9680867, 9680865, 9680866, 9680866, 9680867, 9680867, 9680868, 9680866, 9680867, 9680867, 9680868, 9680867, 9680868, 9680869, 9680868, 9680869, 9680869, 9680870, 9680870, 9680871, 9680872, 9680873, 9680874, 9680877, 9680869, 9680870, 9680870, 9680871, 9680871, 9680872, 9680872, 9680873, 9680873, 12013493, 14295875, 14295876, 9680870, 9680871, 9680871, 9680872, 9680872, 9680873, 31440777, 9680871, 9680872, 9680872, 9680873, 9680873, 9680874, 12295412, 18512297, 9680872, 9680873, 9680873, 9680874, 9680874, 9680875, 9680875, 9680878, 9680879, 9680873, 9680874, 9680874, 9680875, 9680875, 9680876, 9680876, 9680877, 9680878, 9680879, 9680880, 9680880, 9680881, 11261521, 12013496, 9680874, 9680875, 9680875, 9680876, 9680876, 9680877, 9680877, 9680878, 9680880, 9680880, 9680881, 9757428, 9994485, 11551741, 12013496, 13133459, 31440779, 9680875, 9680876, 9680876, 9680877, 9680877, 9680878, 9680880, 9680880, 9680881, 9680881, 9680882, 10882389, 11551740, 12013496, 12295414, 12368245, 13133459, 9680876, 9680877, 9680877, 9680878, 9680878, 9680879, 9680879, 9680880, 9680881, 9680881, 9764388, 10254451, 10602665, 10687893, 11261522, 11551743, 12013496, 12013497, 12295416, 12993070, 13133460, 9680877, 9680878, 9680878, 9680879, 9680880, 9680881, 9680882, 10254451, 11261523, 11261523, 11455442, 11551743, 12013497, 12295415, 12368246, 12368247, 12993067, 13133459, 13133460, 9680878, 9680879, 9680879, 9680880, 9680880, 9680881, 9680882, 9680882, 9680883, 9680883, 9757429, 9757429, 9994487, 10687892, 10687893, 10687894, 11261523, 11551745, 12295415, 12295416, 12295418, 12526112, 13012677, 13133460, 13133461, 9680879, 9680880, 9680880, 9680881, 9680881, 9680882, 9680882, 9680883, 9680883, 9680884, 9994488, 10687894, 10687894, 11261524, 11261524, 11551744, 11961964, 12013498, 12368250, 13012678, 9680880, 9680881, 9680881, 9680882, 9680883, 9680883, 9680884, 9680884, 9680885, 9757429, 9994488, 9994489, 10687893, 10687893, 10687894, 11261524, 11261525, 11551745, 12368247, 9680881, 9680882, 9680882, 9680883, 9680883, 9680884, 9994489, 10687893, 10687895, 10882392, 11261525, 11261526, 11551745, 12013499, 12013500, 12295417, 12295417, 12368248, 12368248, 13133462, 9680882, 9680883, 9680883, 9680884, 9680884, 9680885, 9757432, 9994489, 10254454, 10687895, 10687896, 10687898, 10861138, 10956561, 11261526, 11551745, 11735840, 12295417, 12368249, 9680883, 9680884, 9680885, 9680885, 10687897, 10742196, 10861143, 11261526, 11261527, 11551746, 11551747, 12295418, 9680884, 9680885, 9680885, 9680886, 9994490, 10687895, 10687897, 11261527, 11922068, 12295422, 9680885, 9680886, 10687900, 11551746, 9680886, 9680887, 9757434, 9994489, 10254456, 10370373, 10687896, 10687897, 10687897, 10687898, 10687898, 10687900, 11261527, 11261527, 11261528, 11261528, 11551750, 12013502, 12013503, 12013503, 12295419, 12360603, 12526115, 13133464, 9680887, 9680888, 9680888, 9680889, 9680890, 9685284, 9685285, 9757311, 9757430, 9757432, 9757434, 9757434, 9757435, 9764390, 9994489, 9994490, 9994491, 9994492, 9994493, 9994493, 10223662, 10254456, 10254457, 10366561, 10658321, 10687897, 10687897, 10687898, 10687898, 10687899, 10687899, 10687900, 10687902, 10722387, 10774053, 10861144, 10861145, 10882395, 11231419, 11261528, 11261528, 11261529, 11261529, 11265136, 11265139, 11313593, 11323230, 11551747, 11551747, 11551748, 11551748, 11551749, 11551749, 11551750, 11795308, 12013500, 12013502, 12013502, 12013503, 12013503, 12013504, 12275990, 12295420, 12295420, 12295421, 12295421, 12295423, 12360599, 12368251, 12368251, 12368252, 12993073, 13012683, 13133465, 14952745, 9680888, 9680889, 9680889, 9680890, 9680891, 9685283, 9757433, 9757435, 9757435, 9757437, 9924386, 9994490, 9994492, 9994493, 10254457, 10658321, 10658322, 10658324, 10678381, 10679195, 10687897, 10687898, 10687898, 10687899, 10687899, 10687901, 10687901, 11261528, 11261529, 11261529, 11261530, 11265139, 11528733, 11551746, 11551748, 11551748, 11551749, 11816742, 12013502, 12013503, 12013503, 12013504, 12013505, 12295420, 12295421, 12368251, 13060479, 13133466, 9680891, 9757435, 9757435, 9757436, 9775395, 9994493, 9994493, 10658322, 10687898, 10687898, 10687899, 10687899, 10882396, 11261529, 11261529, 11261530, 11551747, 11551749, 11942715, 12295421, 12295422, 12368252, 13133465, 13133466, 9757436, 10687899, 9994494, 11261531, 12013504, 10385827, 11286813, 10687901, 9785429, 10170265, 9689693, 9689694, 9689696, 9689697, 10692308, 11265939, 11556159, 9761722, 9833744, 9833868, 9833869, 9833871, 9833990, 9833991, 9833992, 9833993, 9833992, 9833994, 9833983, 9833995, 9833995, 9833985, 9833994, 9833997, 9833998, 12444809, 10764459, 11628306, 9834009, 10071052, 10071052, 10186305, 10331017, 10764457, 10764458, 10764458, 10764459, 10764461, 10937706, 11338088, 11338089, 11628307, 11628309, 11628309, 11628310, 12090063, 12090063, 12371981, 10071053, 9847908, 9847913, 10741839, 12378939, 9869916, 10782422, 9889991, 9890034, 9890109, 11366170, 10127361, 10911143, 10167892, 10167897, 11795262, 11104654, 10308104, 10308095, 10308105, 10308108, 10308111, 10308096, 10308108, 10308112, 10308098, 10308109, 10308110, 10308110, 10308111, 10308111, 10308112, 10308112, 10308113, 10308113, 10308114, 10308115, 10308115, 10308111, 10308113, 10308116, 10308111, 10308113, 10308115, 10568071, 11001513, 10308123, 11082848, 11842349, 10308123, 10971941, 11001516, 12327120, 10308125, 11001515, 11575146, 11865367, 12609038, 10308126, 10308126, 10523305, 10568075, 11001517, 11001517, 11001520, 11575147, 11575151, 12609039, 11001516, 11865367, 10308129, 10916291, 11001517, 11001517, 11001518, 11001518, 11415206, 11575148, 11575149, 11575150, 11865370, 12327122, 12609039, 12609041, 10503749, 10971941, 10991998, 11001518, 11001521, 11575148, 11865368, 11865369, 10916292, 11842353, 10350056, 11575149, 11865370, 11001521, 12609042, 11001521, 11001521, 11575151, 12327125, 10391991, 11043455, 10538614, 11690397, 10659651, 11750917, 10699382, 11197152, 10738495, 11187133, 10766452, 11804318, 10828038, 10828039, 10828041, 10828042, 10828038, 12869003, 10828051, 11231906, 11261479, 11261480, 11434727, 12125329, 12869002, 12941833, 11261480, 11261481, 11835111, 12941834, 12587086, 11261484, 11052249, 12237436, 11059932, 11060007, 11060077, 11954765, 11090777, 11392851, 11524464, 11524465, 11524466, 11524534, 11524533, 11524536, 11524603, 11524604, 11524605, 12183392, 12473612, 11635769, 11635769, 11635770, 11635756, 11635770, 11635771, 11635772, 11635772, 11635773, 11665345, 11635784, 11665346, 11665347, 12238976, 12242589, 11665346, 11665347, 11665348, 12238978, 12529197, 11675895, 11675898, 11685415, 12549265, 11677514, 11677576, 11677628, 11677640, 11677652, 11677662, 11686288, 11694907, 11694922, 11694907, 11694908, 11694908, 11694912, 11694922, 11694922, 11694923, 11694908, 11694923, 11694923, 11694924, 11694909, 11694910, 11694910, 11694913, 11694922, 11694923, 11694924, 11694924, 11694910, 11694912, 11694923, 11694924, 11694925, 11694925, 11694926, 11694911, 11694925, 11694925, 11694926, 11694926, 11694925, 11694925, 11694926, 11694927, 11694927, 11694927, 11694928, 11694929, 11694929, 11694932, 11694934, 11694917, 11694930, 11694928, 11694932, 11694928, 11694931, 11694938, 11694938, 12059288, 12268553, 11694938, 12268553, 13020530, 11694939, 11694940, 11694941, 11694943, 11963600, 11984917, 12046740, 12268554, 12268554, 12268555, 12268555, 12268556, 12272164, 12293836, 12558773, 12558774, 12558774, 12558775, 13020528, 13020529, 13302445, 13302446, 13302446, 13375277, 13794076, 11694940, 11694941, 11694941, 11694942, 11836373, 11850738, 11868170, 11868172, 11889423, 11906558, 12046740, 12268554, 12268555, 12268556, 12272164, 12558775, 12558775, 12558777, 12558777, 13020529, 13020529, 13020530, 13302443, 13302446, 13302447, 13302447, 13302449, 13375278, 13375280, 14140491, 11694941, 11963593, 12268555, 12268555, 12558776, 12568628, 13302447, 13375278, 12268555, 12293838, 12558776, 12558776, 12568628, 13302448, 13375278, 12268556, 12558776, 13302449, 11868174, 12067054, 12268556, 12268557, 12558777, 12268557, 12293839, 12268558, 12293840, 13302452, 12268562, 11763919, 11764013, 11764139, 12303185, 11803521, 13074825, 11857623, 11970787, 11867235, 12644932, 11977825, 11977845, 12105044, 12006558, 12714594, 12041408, 12041410, 12041413, 12041414, 12732015, 13193772, 12062664, 12441797, 12441798, 13193772, 13475689, 15406642, 12083913, 12083915, 12083915, 12083917, 12083919, 12084034, 12083926, 12463048, 12463048, 12463048, 12463049, 12463050, 13215024, 12084155, 13215140, 12118193, 12278686, 12232243, 12232251, 12232253, 12232254, 12232262, 12232281, 12232281, 12232316, 12537235, 12537250, 12827470, 12827471, 12274941, 12558578, 12398555, 12398556, 12620369, 13318523, 12423654, 12923138, 12439167, 12439204, 12439182, 12439219, 12640706, 12930928, 12522305, 13434222, 12781962, 14543621, 12842184, 12842169, 12842170, 12842170, 12842171, 12842183, 12842184, 12842184, 12842185, 12842185, 12842186, 12842186, 12842187, 12842187, 12842188, 12842189, 12842170, 12842171, 12842171, 12842172, 12842183, 12842183, 12842184, 12842184, 12842185, 12842185, 12842186, 12842186, 12842187, 12842187, 12842171, 12842183, 12842184, 12842184, 12842185, 12842185, 12842186, 12842186, 12842187, 12842188, 12842190, 12842173, 12842183, 12842184, 12842185, 12842186, 12842187, 12842187, 12842188, 12842189, 12842189, 12842185, 12842186, 12842186, 12842188, 12842189, 12842192, 12842197, 13876076, 12842198, 12842200, 13132403, 12842198, 12842198, 12842199, 12842200, 12842200, 12842201, 12845794, 12949307, 13109387, 13132401, 13132403, 13132403, 13132405, 13132406, 13311476, 13594158, 13594159, 13876075, 13876075, 13876076, 13876079, 12842199, 13132404, 13876075, 12842199, 12842200, 12949334, 13036102, 13132404, 13132406, 13594159, 13876079, 14714121, 12842200, 12842201, 12842201, 12842202, 12842202, 12842203, 12842204, 12867466, 12867467, 12903886, 13060902, 13132403, 13132404, 13132404, 13132405, 13132406, 13132406, 13132407, 13594159, 13594160, 13795680, 13876076, 13876076, 13876077, 13876080, 13948907, 14573730, 14714121, 14714122, 12842201, 12842202, 12842203, 12842205, 12867467, 12903885, 12948302, 13109389, 13132403, 13132404, 13132405, 13132405, 13132406, 13132406, 13132407, 13132407, 13291901, 13594158, 13594159, 13594159, 13594160, 13876077, 13876077, 13876078, 13876079, 13876080, 12842202, 12842205, 12845794, 12845795, 12845795, 12845796, 13132404, 13132405, 13132405, 13132406, 13132407, 13132408, 13132409, 13142258, 13540338, 13594160, 13594160, 13594161, 13594161, 13876077, 13876078, 13876078, 13948909, 16533403, 12842203, 12867468, 13132404, 13132406, 13132407, 13542626, 13594160, 13594161, 13876078, 13948909, 12842204, 12842205, 12845799, 12867469, 12903888, 13132405, 13132406, 13132407, 13132407, 13594161, 13594161, 13876078, 13876079, 13948909, 13109391, 13132406, 13132407, 13594161, 13876080, 13132406, 13594162, 13876080, 13132409, 13876080, 13948912, 13132407, 13132408, 12936090, 13523377, 13594165, 12849402, 12849402, 12849402, 12849403, 12849404, 12849404, 12849405, 12849405, 12849409, 12849410, 13136013, 12871076, 13506325, 13952517, 12907496, 13136014, 13597768, 13136016, 13597772, 12892748, 12892749, 12929168, 13157687, 13619440, 13619441, 13619442, 13901358, 13966538, 12946315, 13646224, 12965581, 12965587, 12965587, 12965588, 13655856, 13194106, 13194106, 13655860, 13325271, 13655860, 13655860, 13029986, 13611380, 13054413, 13238518, 13056433, 13701283, 13056485, 13239555, 13230023, 13230023, 13788078, 13326325, 13279615, 13523826, 13376589, 13376590, 13376591, 13376591, 13376592, 13861359, 14143278, 13861361, 14143279, 13861362, 14143278, 13422608, 13422620, 13422621, 13422622, 13422607, 13422608, 13422622, 13422623, 13422607, 13422608, 13422611, 13422623, 13422608, 13422609, 13422621, 13422623, 13422623, 13422624, 13422609, 13422611, 13422623, 13422624, 13422624, 13422610, 13422611, 13422611, 13422612, 13422612, 13422624, 13422624, 13422625, 13422612, 13422625, 13422625, 13422612, 13422613, 13422624, 13422625, 13422625, 13422626, 13422613, 13422626, 13422626, 13422628, 13422614, 13422626, 13422627, 13422626, 13422627, 13422627, 13422628, 13422628, 14166294, 14166294, 14166296, 13422639, 13716233, 13884378, 13884378, 14166297, 14166297, 14239126, 13422639, 13687618, 13884376, 13884378, 13884378, 13884379, 13884379, 14166296, 14166296, 14166297, 15004341, 13432477, 13432523, 13442304, 13601697, 13713965, 13813592, 13832839, 13865593, 13884377, 13884378, 13884378, 13884379, 13884379, 13884380, 13884380, 14123883, 14146866, 14166295, 14166296, 14166296, 14166297, 14166297, 14166298, 14166298, 14166299, 14166300, 14231476, 14239127, 14239128, 14606181, 14883558, 15004341, 15004342, 14166298, 13442360, 13442361, 13442390, 13442435, 13442425, 13442436, 14176199, 13442509, 13894291, 13442509, 13894335, 13894335, 13894336, 14176253, 14176253, 13462038, 13510898, 13559752, 13756207, 13684955, 14015543, 13741677, 13741805, 13741932, 14044063, 13768038, 14024598, 13780790, 13780827, 14063472, 14345391, 13790808, 14016934, 13909743, 14409855, 13952610, 13952611, 14431288, 14149371, 14005303, 14175718, 14009841, 14532736, 14163252, 14163265, 15374658, 14254698, 14192778, 14269457, 14204611, 14204567, 14204618, 14275355, 14204914, 14204919, 14204926, 14205222, 14205235, 14275708, 14630456, 14557632, 14238490, 14238491, 14574229, 14574232, 14243044, 14243061, 14243066, 14243074, 14243076, 14243141, 14576515, 14243080, 14294600, 14294600, 14243222, 14576594, 14281157, 14595560, 14308555, 14308682, 14308809, 14327470, 14346115, 14346117, 14346132, 14346117, 14346131, 14346132, 14346117, 14346118, 14346118, 14346119, 14346132, 14346133, 14346118, 14346119, 14346119, 14346120, 14346132, 14346133, 14346134, 14346134, 14346119, 14346121, 14346134, 14346134, 14346134, 14346135, 14346135, 14346135, 14346136, 14346136, 14346138, 14346136, 14346137, 14346136, 14346137, 14346138, 14346148, 14555305, 14628051, 14628051, 14346149, 14628051, 14628051, 14628052, 14628054, 14700882, 14346150, 14346151, 14346151, 14362993, 14555306, 14585637, 14628049, 14628051, 14628052, 14628052, 14628053, 14628053, 14628054, 14628054, 14628055, 14693231, 14700881, 14700882, 14700883, 14700883, 14700884, 14700886, 14858746, 15325586, 15325704, 15345313, 15466096, 15466097, 15884306, 25587466, 14628052, 14700883, 17285378, 14628051, 14628052, 14628055, 14628056, 15466097, 14628055, 14700884, 14628056, 14379849, 15482953, 14749172, 15061128, 14764485, 14764529, 14764561, 14910105, 14764633, 14797295, 14825140, 14825142, 14867554, 14867555, 14829956, 14869963, 14871105, 14890535, 14909950, 14909950, 14909951, 14909952, 14909967, 14909952, 14909967, 14909953, 14909954, 14909954, 14909955, 14909955, 14909956, 14909956, 14909957, 14909968, 14909968, 14909969, 14909969, 14909970, 14909970, 14909971, 14909972, 14909954, 14909955, 14909955, 14909956, 14909956, 14909957, 14909957, 14909958, 14909965, 14909968, 14909969, 14909969, 14909970, 14909970, 14909971, 14909971, 14909972, 14909972, 14909955, 14909956, 14909956, 14909957, 14909957, 14909958, 14909959, 14909968, 14909969, 14909969, 14909970, 14909970, 14909971, 14909971, 14909973, 14909956, 14909957, 14909957, 14909958, 14909969, 14909970, 14909970, 14909971, 14909972, 14909972, 14909957, 14909958, 14909958, 14909970, 14909970, 14909971, 14909971, 14909972, 14909972, 14909973, 14909974, 14909958, 14909959, 14909959, 14909960, 14909970, 14909970, 14909971, 14909971, 14909972, 14909972, 14909973, 14909974, 14909959, 14909960, 14909971, 14909971, 14909972, 14909972, 14909973, 14909974, 14909974, 14909960, 14909971, 14909972, 14909972, 14909973, 14909974, 14909974, 14909975, 14909975, 14909976, 14909972, 14909973, 14909973, 14909974, 14909974, 14909975, 14909976, 14909976, 14909973, 14909975, 14909974, 14909981, 14909982, 14909983, 14909983, 14909984, 14909986, 14909986, 14909987, 14982799, 14982799, 15748012, 14909984, 14909985, 14909985, 14909986, 14909986, 14909987, 14909987, 14909988, 14975147, 14975148, 14975150, 14982799, 14982800, 14982800, 14982801, 14982803, 15607621, 15648249, 15648275, 15748013, 15748014, 16910432, 14909985, 14909986, 14909986, 14909987, 14909987, 14909988, 14909988, 14975153, 14982800, 14982800, 14982801, 14982801, 14982802, 15140666, 15404760, 15627231, 15661493, 15675031, 15748013, 15748014, 14909986, 14909987, 14909987, 14909988, 14909988, 14909989, 14975149, 14975153, 14982800, 14982801, 14982801, 14982802, 14982803, 15140665, 15140667, 15607623, 15748014, 15748014, 15748015, 16840922, 14909987, 14909988, 14909988, 14909989, 14975149, 14975154, 14982801, 14982801, 14982802, 15661494, 15748014, 15748015, 14909988, 14909989, 14909989, 14909990, 14909990, 14909991, 14975149, 14975150, 14982800, 14982801, 14982802, 14982802, 14982803, 15137546, 15648261, 15748015, 15748016, 16840924, 14909989, 14909990, 14975150, 14975152, 14975152, 14975155, 14982802, 14982802, 14982803, 15607555, 15607623, 15607625, 15648269, 15748015, 15748016, 14909990, 14909991, 14946835, 14975151, 14975152, 14975155, 14982802, 14982803, 14982803, 14982805, 15607624, 15748016, 15748017, 15748021, 14909991, 14975151, 14975152, 14975154, 14975155, 14975156, 14982803, 14982803, 14982804, 14982805, 14982805, 15401607, 15607628, 15627235, 15648092, 15661477, 15748016, 15748017, 16180173, 14975152, 14975156, 14982802, 14982803, 14982804, 14982804, 14982806, 14982804, 14982804, 14983693, 15019660, 15040311, 15040327, 15040312, 15040316, 15040326, 15040326, 15040327, 15040327, 15040328, 15040329, 15040330, 15040328, 15040330, 15040329, 15040331, 15040330, 15040331, 15040332, 15040335, 15040331, 15040332, 15040333, 15040334, 15040335, 15040335, 15047978, 15040342, 15040343, 15040344, 15047978, 15047979, 15047979, 15040343, 15040345, 15040345, 15047979, 15047979, 15047980, 15047980, 15713428, 15047980, 15047981, 15047982, 15692411, 15047981, 15047981, 15047982, 15182831, 16924464, 15047983, 15713355, 15047982, 15047982, 15047983, 15055614, 15055614, 15055614, 15055615, 15055616, 15055616, 15055617, 15055618, 15055630, 15055631, 15055631, 15055632, 15055632, 15055616, 15055617, 15055617, 15055618, 15055618, 15055619, 15055620, 15055630, 15055631, 15055631, 15055632, 15055632, 15055617, 15055618, 15055618, 15055619, 15055619, 15055621, 15055621, 15055631, 15055632, 15055632, 15055633, 15055634, 15055635, 15055619, 15055620, 15055621, 15055631, 15055632, 15055632, 15055633, 15055633, 15055634, 15055619, 15055632, 15055633, 15055633, 15055634, 15055637, 15055620, 15055621, 15055622, 15055633, 15055633, 15055634, 15055634, 15055635, 15055635, 15055633, 15055634, 15055635, 15055635, 15055634, 15055634, 15055635, 15055635, 15055637, 15055637, 15055636, 15055636, 15055635, 15055636, 15055636, 15055645, 15055645, 15055646, 15055647, 15055647, 15055648, 15055648, 15213494, 15734304, 15820844, 15820845, 16239054, 15055647, 15055648, 15055648, 15055649, 15055649, 15055651, 15213497, 15213497, 15213500, 15214360, 15417115, 15422685, 15448398, 15474431, 15545457, 15643594, 15680452, 15680453, 15680454, 15680455, 15700063, 15721004, 15721078, 15721096, 15721105, 15734324, 15734324, 15734327, 15820844, 15820845, 15055648, 15055649, 15055649, 15055650, 15055650, 15055651, 15055652, 15213371, 15213496, 15213497, 15213497, 15213498, 15254965, 15254966, 15258894, 15422685, 15474432, 15580850, 15680450, 15680453, 15680453, 15680454, 15680454, 15680457, 15700062, 15700063, 15721075, 15721079, 15721081, 15820845, 15820845, 15820846, 15820850, 16239055, 16913754, 15055649, 15055650, 15055651, 15055651, 15055652, 15103526, 15213498, 15213499, 15254967, 15422685, 15422686, 15422687, 15474432, 15474437, 15680451, 15680452, 15680453, 15680453, 15680455, 15680457, 15700063, 15700063, 15700064, 15700065, 15721072, 15721080, 15721082, 15734306, 15734308, 15734325, 15820845, 15820846, 15820849, 16913754, 16932114, 17415897, 21199686, 15055650, 15055651, 15055651, 15055654, 15124345, 15213372, 15213375, 15213497, 15213498, 15213498, 15213499, 15214361, 15254965, 15254967, 15342952, 15417120, 15422686, 15474437, 15680453, 15680454, 15680456, 15680458, 15680459, 15700063, 15721006, 15721079, 15721081, 15721093, 15721103, 15721110, 15734306, 15751429, 15820846, 15820846, 15820847, 16239056, 15213498, 15213503, 15680456, 15700064, 15700065, 15820846, 15820847, 15151114, 15213499, 15213499, 15680456, 15680459, 15700064, 15820847, 15820848, 15213497, 15213498, 15254967, 15680456, 15680460, 15700066, 15820848, 15680460, 15248295, 15680459, 15820848, 15820849, 15213502, 15820850, 15721086, 15151427, 15868747, 15193056, 15283073, 15246588, 15308973, 15325338, 15955702, 15365116, 15854802, 15371103, 15371104, 15371112, 15371232, 15371236, 15371229, 15371237, 15371357, 15371345, 15371358, 15371360, 15371349, 15371359, 15371360, 15371346, 15371361, 15371362, 15371360, 15371360, 15371361, 15371362, 15371362, 15371363, 15371361, 15371361, 15371362, 15371363, 15371363, 15371364, 15371363, 15371364, 15371366, 15371369, 15371371, 15371369, 15371374, 15838321, 15857926, 15878943, 15978709, 15412828, 15857926, 15978708, 15978709, 15838318, 15857926, 15978709, 15978710, 15580550, 15857928, 15978709, 15978710, 16396920, 15580550, 15606264, 15838318, 15857927, 15857929, 15878971, 15878973, 15978710, 15978711, 17141129, 15857928, 17071617, 15857931, 15978714, 15373085, 15373088, 15373090, 15373091, 16397780, 15879831, 16397784, 15879734, 15440951, 15615344, 15454294, 15454295, 15454295, 15454296, 15454297, 15879782, 15879784, 15879788, 15899392, 15899393, 16020175, 16020176, 15920404, 15462155, 15924266, 15630266, 16008236, 15778609, 15778613, 16061557, 16182339, 15789740, 15789738, 15789738, 15789739, 15789739, 15789741, 15789740, 16067115, 16067116, 16187898, 16187901, 16187899, 16047505, 16047510, 16088032, 16187898, 16187899, 16047510, 16067118, 15841162, 15841163, 16073217, 16213610, 15893229, 15893230, 15893229, 15893236, 15893236, 15893237, 18058930, 16239644, 17332551, 17350924, 16118863, 16239645, 16239646, 15899554, 15899624, 15899692, 16242876, 16035288, 16170283, 16106065, 16346060, 16231558, 16408810, 16305032, 16305157, 16305131, 16305206, 16305269, 16305272, 16305272, 16305261, 16305273, 16305260, 16305273, 16305274, 16305275, 16305274, 16305274, 16305275, 16305275, 16305276, 16305274, 16305274, 16305277, 16305277, 16305278, 16305278, 16305279, 16305279, 16305280, 16305280, 16305281, 16305281, 16305282, 16305280, 16305281, 16324881, 16305288, 16345741, 16345923, 16445665, 16445666, 16305290, 16324883, 16324884, 16345886, 16345932, 16359126, 16365747, 16372616, 16445666, 16445667, 16542613, 16863876, 17608085, 16305292, 16324883, 16324884, 16324884, 16345742, 16345826, 16345925, 16359127, 16445666, 16445667, 16445669, 17538576, 18264946, 16324884, 16324884, 16324885, 16445668, 16863878, 16863879, 17538576, 16445669, 16344489, 16344490, 16344478, 16344479, 16344488, 16344489, 16344489, 16344490, 16344492, 16344492, 16344493, 16344494, 16344494, 16344495, 16344490, 16344493, 16344493, 16344489, 16344494, 16344494, 16344495, 16344497, 16344494, 16344494, 16344496, 16344500, 16344504, 16344505, 16378750, 16465271, 16465271, 16465272, 17576555, 16465271, 16465272, 16365495, 16465273, 16365432, 16365522, 16465272, 16465273, 16969509, 16465274, 16344509, 16365494, 16465274, 16465275, 17558182, 16365502, 16465275, 16465276, 16465276, 17576558, 16344509, 16365409, 16365509, 16365530, 16465275, 16465276, 16465276, 16465279, 16365498, 16365544, 16378756, 16465276, 16465277, 16465277, 16883487, 16355191, 16378757, 16465277, 16465278, 16465278, 16465279, 16365893, 16894189, 16386269, 16386385, 16386425, 16486193, 16486194, 16386437, 17579156, 17597517, 16386535, 16386535, 16386537, 16386538, 16386549, 16386549, 16386544, 16386546, 16386555, 16386538, 16386552, 16386557, 16386561, 16386516, 16386554, 16386555, 16386563, 16486278, 18081327, 18305557, 16386534, 16386558, 16386560, 16386560, 16386564, 16386564, 16386571, 16386563, 16386565, 16386578, 16386574, 16386554, 16386577, 16386580, 16386560, 16386573, 16386578, 16386582, 16386586, 16386584, 16386588, 16386586, 16386586, 16386584, 16386590, 16386594, 16386597, 16486315, 16486316, 16486318, 16486316, 16904526, 16486316, 16486317, 16486319, 16486320, 16904530, 16486320, 16486321, 16486321, 16399803, 16486322, 16386604, 16486323, 16386605, 16486323, 16386606, 16486323, 16904534, 16386607, 16486325, 16486327, 16774683, 16486324, 17579233, 16486326, 16486326, 16399809, 16486327, 16486328, 16486328, 17597596, 16486328, 16486329, 16412975, 16412976, 16412978, 16413017, 16413018, 16412978, 16412996, 16412997, 16412997, 16412995, 16412996, 16413000, 16499518, 16413019, 16413020, 16413025, 16413020, 16413026, 16413027, 16413027, 16413040, 16413028, 16413023, 16413029, 16413030, 16917750, 16499540, 16499541, 16499541, 16917751, 16499546, 16499546, 16499547, 16499551, 16499557, 16499557, 16499558, 16426220, 16506139, 16439952, 16440020, 16440085, 16440087, 16440089, 16513069, 16513072, 16447251, 16516668, 16586042, 16586043, 16586057, 16586059, 16586059, 16586043, 16586060, 16586044, 16586045, 16586045, 16586046, 16586046, 16586047, 16586047, 16586048, 16586048, 16586049, 16586049, 16586055, 16586056, 16586056, 16586057, 16586057, 16586058, 16586058, 16586059, 16586059, 16586060, 16586060, 16586061, 16586061, 16586062, 16586045, 16586046, 16586046, 16586047, 16586047, 16586048, 16586056, 16586057, 16586057, 16586058, 16586058, 16586059, 16586059, 16586060, 16586046, 16586047, 16586047, 16586048, 16586049, 16586049, 16586050, 16586058, 16586060, 16586060, 16586061, 16586048, 16586049, 16586057, 16586058, 16586058, 16586059, 16586060, 16586060, 16586061, 16586063, 16586061, 16586049, 16586050, 16586050, 16586051, 16586058, 16586059, 16586059, 16586060, 16586060, 16586061, 16586061, 16586062, 16586063, 16586064, 16586065, 16586066, 16586059, 16586059, 16586061, 16586061, 16586062, 16586062, 16586063, 16586064, 16586059, 16586059, 16586060, 16586060, 16586061, 16586062, 16586062, 16586064, 16586052, 16586059, 16586061, 16586062, 16586062, 16586063, 16586064, 16586065, 16586067, 16586055, 16586060, 16586061, 16586061, 16586062, 16586063, 16586063, 16586064, 16586068, 16586061, 16586064, 16586064, 16586065, 16586063, 16586068, 16586069, 16586069, 16586071, 16586068, 16586069, 16586069, 16586070, 16586070, 16586071, 16586071, 16586069, 16586070, 16586070, 16586071, 16586071, 16586072, 16586070, 16586071, 16586071, 16586072, 16586072, 16586071, 16586072, 16586072, 16586073, 16586072, 16586073, 16586073, 16586074, 16609027, 17748477, 16586073, 16586074, 16586074, 17004268, 21964898, 16586074, 16586075, 16586075, 16586076, 16586077, 16586078, 17004268, 17678966, 17678966, 17678967, 17697328, 18181111, 18405339, 21964901, 16586075, 16586076, 16586076, 16586077, 16586078, 16586078, 16586079, 16874418, 17004269, 17004271, 17018213, 17678966, 17697327, 17697328, 17697343, 17748479, 18165041, 18405348, 18405350, 23266491, 16586076, 16586077, 16586077, 16586078, 16586078, 16586079, 16586079, 17004269, 17251851, 17258604, 17398698, 17678966, 17678968, 17697327, 17748479, 17748479, 17748480, 18181111, 18405349, 18405350, 20351379, 16586077, 16586078, 16586078, 16586079, 16586080, 16586080, 17004270, 17004271, 17148052, 17158138, 17678966, 17678967, 17678968, 17697328, 17697344, 17748479, 17748479, 17748480, 17748480, 17748481, 18126401, 18405339, 18405340, 18405347, 18405349, 20351374, 20351375, 21964901, 16586078, 16586079, 16586079, 16586080, 16586080, 16586081, 16758746, 16941971, 17004270, 17004272, 17004273, 17018217, 17458023, 17508353, 17678966, 17678967, 17678967, 17678968, 17697325, 17697328, 17697328, 17697329, 17697329, 17697336, 17697339, 17697343, 17697344, 17697345, 17697346, 17748479, 17748479, 17748480, 17748480, 17748481, 17748481, 18115738, 18181110, 18181111, 18405339, 18405341, 18405341, 18405349, 18405349, 18405352, 21964901, 34893381, 16586079, 16586080, 16586080, 16586081, 16586081, 16586083, 16586083, 17004271, 17006330, 17678967, 17678969, 17678969, 17697329, 17697341, 17697345, 17748479, 17748480, 17748480, 17748482, 17864260, 18405350, 16586080, 16586081, 16586081, 16586082, 16874420, 17004271, 17004273, 17148054, 17678968, 17678970, 17697329, 17697330, 17748480, 17748481, 17748482, 18405340, 18405341, 16586081, 16586082, 16874421, 17004272, 17004273, 17090298, 17121344, 17572106, 17678968, 17678969, 17678970, 17697327, 17697330, 17697330, 17697331, 17697345, 17697346, 17748479, 17748481, 17748481, 17748482, 17748482, 18181114, 18405341, 20399190, 16586082, 16586083, 16646182, 17004272, 17004272, 17004274, 17090298, 17678969, 17678971, 17748481, 17748482, 18181113, 18181114, 16586083, 16586084, 17004273, 17678968, 17678969, 17678970, 17678970, 17678971, 17678971, 17697331, 17697340, 17697346, 17697347, 17748480, 17748482, 17748482, 17748483, 17748484, 18405355, 17004273, 17678970, 17697331, 17697332, 17697347, 17748484, 16874423, 17004274, 16874424, 17004275, 16631995, 17027236, 16706298, 17739085, 16779946, 17101209, 16931431, 17176955, 17162774, 17162774, 17162775, 17292625, 17967323, 17292625, 17297878, 17360178, 17422462, 17422463, 17422464, 17422464, 17422465, 17422474, 17422474, 17422475, 17422475, 17422476, 17422476, 17422477, 17422477, 17422478, 17422478, 17422479, 17422480, 17422483, 17422476, 17422477, 17422466, 17422477, 17422477, 17422478, 17422479, 17422479, 17422480, 17422481, 17422481, 17422482, 17422476, 17422478, 17422480, 17422480, 17422482, 17422484, 17422487, 17422489, 17422489, 17422490, 17816903, 18115532, 17422488, 17422490, 17508501, 17422488, 17422489, 17422490, 17422490, 18097173, 18097174, 18115546, 18115547, 18166684, 18599314, 18823554, 18823556, 17422489, 17422490, 17422490, 17422491, 17422491, 17422492, 17422493, 17422493, 17576342, 17692181, 17816904, 17816905, 18097171, 18097172, 18097173, 18097174, 18097174, 18115534, 18115535, 18166684, 18166684, 18166685, 18166685, 18549405, 18823545, 18823552, 17422491, 17448258, 18115535, 17422492, 17508503, 18097175, 18166686, 18166686, 18599317, 20769585, 17422492, 18097174, 18115535, 18115551, 17422493, 17422494, 17422494, 17422495, 17422496, 17422501, 17436423, 17436424, 17508504, 17670047, 17714962, 17783006, 17816907, 17876230, 17969047, 18097173, 18097174, 18097174, 18097175, 18097175, 18097176, 18097176, 18097177, 18115535, 18115536, 18115536, 18115537, 18115537, 18115538, 18115546, 18115547, 18115548, 18115551, 18115552, 18115552, 18166686, 18166686, 18166687, 18166687, 18166688, 18166688, 18166689, 18166691, 18166691, 18166692, 18329080, 18599317, 18599318, 18599319, 18599320, 18599320, 18823549, 18823555, 18823555, 18823558, 18823559, 20510444, 20769585, 21140531, 22383108, 17422495, 17422495, 17422496, 17783007, 17926561, 18097175, 18097176, 18097176, 18097177, 18097177, 18115536, 18115536, 18115538, 18115552, 18115553, 18115553, 18166687, 18166688, 18166688, 18823549, 18823560, 17422496, 17422498, 18097176, 18097177, 18115537, 18115538, 18166689, 18166689, 18166690, 18823558, 17422497, 17576348, 18115538, 18166688, 18166689, 18097177, 18115536, 18115538, 18115554, 18115554, 18166690, 18097179, 18166691, 18097179, 18115544, 17426593, 18168742, 17450369, 17450370, 17450371, 17450371, 18111122, 18180633, 18111121, 18129482, 18129484, 17474102, 17474185, 17474268, 18123101, 17594526, 17594527, 17594527, 17599141, 18183196, 18909569, 18183197, 18252710, 18201560, 17603759, 18206177, 17656620, 18232606, 17710041, 18240957, 18259317, 17730209, 17730210, 18269400, 18269414, 18269416, 17917624, 17917637, 18344752, 18414265, 17931192, 18351555, 17961884, 18366876, 18007442, 18408031, 18143533, 18143535, 18527214, 18476065, 18211332, 18211333, 18211334, 18211335, 18509962, 18561114, 18509964, 18509964, 19217975, 18329979, 18329980, 19277303, 18569286, 18430698, 18430777, 18430848, 18430850, 18619762, 18619747, 18515632, 18515695, 18515765, 18643829, 18558142, 18734517, 18771856, 18771868, 18771870, 18771870, 18771871, 18771856, 18771857, 18771871, 18771871, 18771872, 18771873, 18771857, 18771858, 18771858, 18771870, 18771871, 18771872, 18771872, 18771873, 18771858, 18771859, 18771872, 18771873, 18771859, 18771873, 18771873, 18771874, 18771874, 18771875, 18771860, 18771872, 18771873, 18771873, 18771874, 18771874, 18771875, 18771875, 18771876, 18771874, 18771876, 18790232, 18841383, 18771887, 18841384, 22720920, 18771886, 18790232, 18790233, 18790234, 18790247, 18841384, 18841385, 19274016, 18771887, 18771888, 18771888, 18790233, 18790234, 18790234, 18790246, 18790246, 18790249, 18841383, 18841383, 18841384, 18841384, 18841385, 18841386, 18841387, 19498255, 18771888, 18771889, 18771889, 18790233, 18790234, 18790235, 18790248, 18790249, 18790249, 18841384, 18841384, 18841385, 18841386, 18841386, 18841387, 19274017, 19498254, 19498255, 18771889, 18771890, 18790234, 18790234, 18790235, 18841385, 18841386, 19498245, 18790231, 18790232, 18790234, 18790235, 18790235, 18790236, 18790242, 18790248, 18790250, 18790253, 18841385, 18841387, 19274018, 19274018, 23681985, 18771891, 18790231, 18790233, 18790235, 18790236, 18790236, 18790237, 18790251, 18790251, 18790252, 18841386, 18841387, 18841388, 23681985, 18790236, 18790237, 18808575, 18808589, 18808592, 18808603, 18808577, 18808578, 18808591, 18808590, 18808592, 18808578, 18808594, 18808610, 18808579, 18808580, 18808580, 18808581, 18808582, 18808589, 18808591, 18808591, 18808592, 18808593, 18808593, 18808594, 18808594, 18808595, 18808595, 18808596, 18808596, 18808597, 18808597, 18808598, 18808598, 18808600, 18808601, 18808603, 18808610, 18808580, 18808590, 18808594, 18808595, 18808595, 18808596, 18808596, 18808597, 18808598, 18808599, 18808600, 18808581, 18808582, 18808585, 18808591, 18808594, 18808595, 18808595, 18808596, 18808596, 18808597, 18808598, 18808599, 18808601, 18808603, 18808603, 18808607, 18808608, 18808582, 18808592, 18808593, 18808594, 18808595, 18808596, 18808597, 18808599, 18808600, 18808602, 18808603, 18808605, 18808607, 18808608, 18808608, 18808609, 18808610, 18808596, 18808597, 18808598, 18808600, 18808601, 18808607, 18808607, 18808610, 18808597, 18808602, 18808618, 18808603, 18808605, 18808609, 18808621, 18808621, 18808606, 18808607, 18808615, 18808620, 18808607, 18808622, 18859743, 18808607, 18808619, 18859742, 18808608, 18808623, 18859743, 18808606, 18808607, 18808608, 18808620, 18808624, 19292372, 18808608, 18808613, 18808625, 18859744, 18808608, 18808609, 18808611, 18808612, 18808625, 18808625, 18859744, 18859745, 18808609, 18808610, 18808612, 18808612, 18808613, 18808619, 18808621, 18808625, 18859745, 18859746, 18859746, 18859747, 19292378, 19516611, 18808610, 18808611, 18808612, 18808612, 18808613, 18808614, 18808614, 18808615, 18808626, 18808627, 18808627, 18859745, 18859746, 18808611, 18808612, 18808612, 18808613, 18808613, 18808614, 18808614, 18808615, 18808616, 18808618, 18808620, 18808623, 18808624, 18808626, 18808627, 18808627, 18859742, 18859745, 18859745, 18859746, 18859747, 18859747, 19516617, 18808612, 18808613, 18808613, 18808615, 18808615, 18808616, 18808619, 18808623, 18808627, 18808628, 18859745, 18859746, 18859747, 18859750, 18808613, 18808616, 18808624, 18808626, 18808627, 18808628, 18808628, 18859745, 18859746, 18859747, 18859747, 18859748, 18859748, 19184676, 18808615, 18808615, 18808617, 18808618, 18808623, 18808625, 18808628, 18808629, 18859747, 18859747, 18859749, 18859751, 18808616, 18808628, 18859748, 18859748, 19292381, 19516609, 19516618, 18808616, 18808617, 18808624, 18808625, 18808627, 18808629, 18808629, 18808630, 18859748, 18859749, 18859750, 19516608, 18808618, 18808618, 18808620, 18808622, 18808628, 18808631, 18859748, 18859749, 18859749, 18859751, 21462640, 18808618, 18808626, 18808630, 18808630, 18808631, 18808631, 18808632, 18859749, 18859752, 18808620, 18808624, 18808631, 18808633, 18859749, 18859750, 18859750, 18808620, 18808630, 18808631, 18808625, 18808631, 18808632, 18859750, 18859754, 19292384, 18808632, 18859753, 18808624, 18859751, 18859752, 18859751, 18859752, 18859754, 18808634, 18859755, 19292386, 18859756, 18808633, 18808635, 18859755, 18808635, 18808636, 18808637, 18859756, 19516616, 18808632, 18808633, 18859757, 18808634, 18808636, 18808637, 18808638, 18808640, 18859757, 18859758, 18859759, 19292390, 18808639, 18859758, 18859758, 18859759, 18859759, 18859760, 18808639, 18859759, 18859760, 21203515, 18808642, 18859759, 18859760, 18859761, 18808641, 18859760, 18859761, 19292393, 18808641, 18808642, 18808643, 18808643, 18808644, 18859761, 18859761, 18859762, 18859762, 18859763, 18859763, 18859764, 18859768, 18906966, 19292394, 19292395, 19516622, 19516622, 19516627, 19516628, 19516629, 19516634, 18808643, 18859761, 18859762, 18859764, 18859765, 19292395, 18859757, 18859761, 18859762, 18859762, 18859763, 18859763, 18859764, 19516622, 19516632, 19516633, 19516633, 21462661, 18859762, 18859762, 18859763, 18859763, 18859764, 18859762, 18859764, 19292396, 18859764, 18910877, 18910878, 18910879, 18910879, 18910880, 18910881, 18910881, 18910879, 18910880, 18910880, 18910880, 18910881, 18910881, 18910882, 18910882, 18910894, 18910895, 18910896, 18910896, 18910881, 18910882, 18910882, 18910883, 18910883, 18910884, 18910884, 18910886, 18910896, 18910896, 18910897, 18910897, 18910898, 18910898, 18910899, 18910882, 18910883, 18910883, 18910884, 18910884, 18910886, 18910896, 18910896, 18910897, 18910897, 18910898, 18910898, 18910899, 18910899, 18910900, 18910900, 18910901, 18910883, 18910884, 18910884, 18910885, 18910886, 18910886, 18910893, 18910894, 18910895, 18910896, 18910897, 18910897, 18910898, 18910898, 18910899, 18910899, 18910900, 18910901, 18910903, 18910884, 18910885, 18910885, 18910886, 18910886, 18910887, 18910887, 18910896, 18910896, 18910897, 18910897, 18910898, 18910898, 18910899, 18910899, 18910900, 18910900, 18910901, 18910902, 18910904, 18910885, 18910886, 18910886, 18910887, 18910887, 18910888, 18910897, 18910897, 18910898, 18910898, 18910899, 18910899, 18910900, 18910900, 18910901, 18910901, 18910902, 18910886, 18910887, 18910888, 18910889, 18910898, 18910898, 18910899, 18910899, 18910900, 18910900, 18910901, 18910905, 18910887, 18910888, 18910888, 18910898, 18910899, 18910899, 18910900, 18910900, 18910901, 18910901, 18910902, 18910905, 18910888, 18910889, 18910899, 18910899, 18910900, 18910900, 18910901, 18910902, 18910903, 18910904, 18910890, 18910899, 18910900, 18910901, 18910901, 18910902, 18910902, 18910904, 18910901, 18910901, 18910902, 18910902, 18910904, 18910902, 18910902, 18910903, 18910905, 18910906, 18910902, 18910904, 18910909, 18910909, 18910909, 18910910, 18910910, 18910910, 18910912, 18910910, 18910911, 18910911, 18910912, 18910912, 18910913, 18910913, 19343528, 19567755, 19567756, 18910911, 18910912, 18910912, 18910913, 18910913, 18910914, 18910915, 19567764, 18910912, 18910913, 18910913, 18910914, 18910914, 19073287, 19343528, 19343529, 19343529, 19567756, 19567757, 19567758, 19567765, 19567766, 21513793, 23127318, 18910913, 18910914, 18910914, 18910915, 18910915, 18910916, 18910916, 18910918, 18910918, 18910920, 19185493, 19235830, 19343528, 19343529, 19343529, 19343530, 19343530, 19567757, 19567757, 19567758, 19567758, 19567760, 19567764, 19567767, 19567768, 19567769, 21254655, 18910914, 18910915, 18910915, 18910916, 18910916, 18910917, 18910917, 18910918, 18910920, 19110635, 19185492, 19343529, 19343529, 19343530, 19343530, 19343531, 19567757, 19567758, 19567759, 19567767, 19567769, 19567770, 23753118, 18910915, 18910916, 18910916, 18910917, 18910917, 18910918, 18910918, 18910919, 19132307, 19235829, 19335027, 19343528, 19343529, 19343529, 19343530, 19343530, 19343531, 19343531, 19567758, 19567758, 19567759, 19567759, 19567765, 19567766, 19567767, 19567767, 19567768, 19567768, 19567769, 19567770, 19567771, 21057422, 18910916, 18910917, 18910917, 18910918, 18910918, 18910920, 18910922, 19026678, 19056464, 19073292, 19132305, 19235827, 19235832, 19246727, 19343529, 19343529, 19343530, 19343530, 19343531, 19343531, 19343532, 19567759, 19567759, 19567760, 19567760, 19567762, 19567764, 19567765, 19567766, 19567770, 21513797, 21884742, 18910917, 18910918, 18910918, 18910919, 18910920, 18910920, 18910922, 18910925, 18910925, 19026675, 19073292, 19110635, 19132307, 19132307, 19132308, 19185496, 19235829, 19235831, 19235832, 19343529, 19343529, 19343530, 19343530, 19343531, 19343531, 19343532, 19343532, 19385278, 19437460, 19567759, 19567759, 19567760, 19567761, 19567763, 19567764, 19567765, 19567766, 19567767, 19567768, 19567769, 19567769, 19567770, 19567771, 22790438, 18910918, 18910919, 18910919, 18910920, 19234948, 19288821, 19343529, 19343530, 19343531, 19343532, 19343532, 19343533, 19567761, 19567761, 19567765, 19567768, 18910919, 18910920, 18910921, 18910921, 18910927, 19026680, 19132309, 19185494, 19185495, 19343529, 19343530, 19343532, 19343532, 19343533, 19343533, 19567760, 19567761, 19567768, 21513797, 23127321, 18910920, 18910921, 18910927, 19070926, 19073293, 19235834, 19343532, 19343533, 19343533, 19343534, 19567762, 19567768, 19567768, 19567771, 21513796, 19185497, 19343532, 19343532, 19343534, 19567762, 19567762, 19567764, 19567771, 19567772, 21513797, 18910922, 19132311, 19343533, 19343533, 19567761, 19567762, 18910923, 19288824, 19343535, 19508482, 19567762, 19567764, 19567770, 18910927, 19235834, 19343534, 19343534, 19343535, 19343535, 19567764, 19567771, 19567772, 19567773, 19567774, 19567772, 19343537, 19185500, 19343537, 19235840, 19225129, 19567768, 19567769, 19567769, 19005300, 19614966, 19142436, 19142454, 19142457, 19142457, 19142461, 19142471, 19683537, 19683539, 19459310, 19459312, 19202024, 19489091, 19230949, 19727785, 19235676, 19235681, 19235682, 19235682, 19235683, 19505919, 19730149, 19730158, 19730158, 19505921, 19505922, 19310371, 19310373, 19543268, 19767496, 19353711, 19353713, 19353713, 19353714, 19353715, 19564936, 19564937, 19564938, 19564938, 19789166, 19460085, 19460086, 19460087, 19460088, 19618123, 19510423, 19510424, 19618123, 19618124, 19842352, 19842356, 19842361, 19539337, 19881976, 19558991, 19667575, 19560754, 19560755, 19560761, 19560760, 19560760, 19560761, 19560763, 19560763, 19560764, 19560764, 19668458, 19892686, 19668458, 19668461, 19892696, 19668460, 19892689, 19892699, 19892699, 19668461, 19668461, 19668462, 19668462, 19668463, 19582567, 19622558, 19645413, 19935024, 19662549, 19662589, 19662677, 19719449, 19666736, 19666737, 19945679, 19945681, 19945684, 19676330, 19676416, 19676501, 19950567, 19744019, 23543877, 19759212, 19991944, 19776142, 19776158, 19776142, 19776144, 19776144, 19776145, 19776156, 19776159, 19776143, 19776144, 19776157, 19776143, 19776144, 19776144, 19776145, 19776158, 19776158, 19776159, 19776160, 19776161, 19776144, 19776145, 19776145, 19776146, 19776147, 19776156, 19776157, 19776158, 19776158, 19776159, 19776159, 19776160, 19776160, 19776161, 19776161, 19776145, 19776146, 19776146, 19776156, 19776160, 19776160, 19776161, 19776161, 19776162, 19776163, 19776146, 19776147, 19776148, 19776150, 19776159, 19776160, 19776160, 19776161, 19776161, 19776162, 19776162, 19776163, 19776147, 19776158, 19776159, 19776159, 19776160, 19776160, 19776161, 19776161, 19776162, 19776162, 19776163, 19776160, 19776161, 19776162, 19776162, 19776163, 19776163, 19776164, 19776160, 19776163, 19776165, 19776165, 19776172, 20000386, 19776171, 19776173, 19776175, 19776177, 20000386, 20000398, 19776172, 19776174, 20000389, 19776174, 19776175, 19776175, 20000387, 20000388, 20000389, 20000396, 19776175, 19776176, 19776176, 20000387, 20000388, 20000389, 20000399, 19776176, 19776176, 19776177, 20000388, 20000388, 20000389, 20000393, 20000397, 20000397, 19776176, 19776177, 19776177, 19776180, 19955110, 20000389, 20000390, 20000390, 20000398, 20000399, 19776177, 19776178, 19776180, 20000389, 20000389, 20000390, 20000390, 20000391, 20000398, 20000399, 20000401, 19776178, 19776179, 19776179, 19937301, 19955111, 20000389, 20000390, 20000390, 20000391, 20000391, 20000392, 20000393, 20000394, 20000395, 20000396, 20000397, 20000398, 20000398, 20000399, 20000400, 20000400, 20000401, 20000404, 20096577, 21946426, 19776180, 19776181, 19955111, 19986053, 20000390, 20000390, 20000391, 20000391, 20000392, 20000393, 20000394, 20000394, 20000395, 20000395, 20000396, 20000397, 20000397, 20000398, 20000399, 20000399, 20000400, 20000400, 20000401, 20000401, 20000402, 20000403, 20000403, 21946429, 23559951, 20000390, 20000399, 20000400, 20000391, 20000391, 20000396, 20000398, 20000393, 20000392, 20000393, 19859654, 19859736, 19859814, 20042224, 19964021, 20094321, 20098440, 20161530, 20106044, 20106110, 20165389, 20134055, 20134056, 20179335, 20179336, 20179344, 20195938, 20210276, 20224601, 20224602, 20224602, 20224603, 20224603, 20224604, 20224606, 20224607, 20224607, 20224609, 20224610, 20224611, 20224613, 20224602, 20224603, 20224603, 20224604, 20224604, 20224605, 20224606, 20224607, 20224609, 20224609, 20224610, 20224611, 20224603, 20224604, 20224604, 20224605, 20224606, 20224608, 20224608, 20224609, 20224609, 20224611, 20224612, 20224613, 20224613, 20224625, 20224604, 20224605, 20224605, 20224606, 20224607, 20224607, 20224608, 20224608, 20224609, 20224609, 20224610, 20224610, 20224611, 20224611, 20224612, 20224612, 20224613, 20224613, 20224614, 20224614, 20224615, 20224616, 20224617, 20224619, 20224619, 20224620, 20224620, 20224621, 20224624, 20224605, 20224606, 20224606, 20224607, 20224607, 20224608, 20224608, 20224609, 20224609, 20224610, 20224610, 20224611, 20224611, 20224612, 20224612, 20224613, 20224613, 20224614, 20224615, 20224620, 20224620, 20224607, 20224607, 20224608, 20224608, 20224609, 20224610, 20224610, 20224611, 20224611, 20224613, 20224613, 20224614, 20224621, 20224609, 20224609, 20224610, 20224611, 20224614, 20224615, 20224608, 20224609, 20224609, 20224610, 20224611, 20224611, 20224612, 20224612, 20224613, 20224614, 20224614, 20224610, 20224611, 20224612, 20224613, 20224613, 20224614, 20224610, 20224611, 20224611, 20224612, 20224613, 20224614, 20224616, 20224616, 20224611, 20224612, 20224612, 20224613, 20224613, 20224614, 20224614, 20224615, 20224616, 20224618, 20224632, 20224612, 20224613, 20224613, 20224614, 20224616, 20224616, 20224617, 20224618, 20224613, 20224614, 20224614, 20224615, 20224615, 20224616, 20224616, 20224617, 20224617, 20224618, 20224614, 20224615, 20224615, 20224616, 20224616, 20224617, 20224617, 20224618, 20224618, 20224619, 20224620, 20224624, 20224615, 20224616, 20224616, 20224617, 20224617, 20224618, 20224618, 20224619, 20224620, 20224628, 20224616, 20224617, 20224617, 20224618, 20224618, 20224619, 20224619, 20224620, 20224635, 20224635, 20224617, 20224618, 20224618, 20224619, 20224619, 20224620, 20224620, 20224621, 20224626, 20224635, 20224635, 20224636, 20224618, 20224619, 20224619, 20224620, 20224620, 20224621, 20224621, 20224622, 20224626, 20224628, 20224629, 20224630, 20224632, 20224632, 20224635, 20224636, 20224619, 20224620, 20224620, 20224621, 20224621, 20224622, 20224628, 20224629, 20224630, 20224636, 20224620, 20224621, 20224621, 20224622, 20224622, 20224623, 20224623, 20224628, 20224628, 20224629, 20224633, 20224636, 20224636, 20224637, 20224621, 20224622, 20224622, 20224623, 20224623, 20224624, 20224625, 20224626, 20224626, 20224627, 20224628, 20224628, 20224629, 20224630, 20224631, 20224631, 20224636, 20224637, 20224637, 20224638, 20224638, 20224622, 20224623, 20224623, 20224624, 20224624, 20224627, 20224628, 20224628, 20224629, 20224629, 20224630, 20224636, 20224636, 20224637, 20224637, 20224638, 20224638, 20224639, 20224639, 20224623, 20224624, 20224624, 20224625, 20224625, 20224626, 20224627, 20224627, 20224628, 20224628, 20224629, 20224629, 20224630, 20224630, 20224631, 20224632, 20224636, 20224637, 20224638, 20224638, 20224639, 20224639, 20224624, 20224625, 20224625, 20224626, 20224626, 20224627, 20224627, 20224628, 20224628, 20224629, 20224629, 20224630, 20224630, 20224631, 20224631, 20224633, 20224633, 20224634, 20224634, 20224637, 20224638, 20224639, 20224639, 20224640, 20224625, 20224626, 20224626, 20224627, 20224628, 20224628, 20224629, 20224630, 20224630, 20224631, 20224631, 20224632, 20224632, 20224633, 20224635, 20224637, 20224638, 20224639, 20224639, 20224640, 20224640, 20224626, 20224627, 20224627, 20224628, 20224628, 20224629, 20224630, 20224630, 20224631, 20224631, 20224632, 20224632, 20224633, 20224633, 20224634, 20224636, 20224638, 20224639, 20224639, 20224640, 20224640, 20224641, 20224627, 20224628, 20224630, 20224631, 20224632, 20224632, 20224633, 20224634, 20224635, 20224639, 20224640, 20224640, 20224641, 20224641, 20224642, 20224628, 20224629, 20224630, 20224631, 20224631, 20224632, 20224635, 20224637, 20224640, 20224641, 20224642, 20224631, 20224631, 20224632, 20224632, 20224634, 20224635, 20224641, 20224632, 20224633, 20224634, 20224635, 20224641, 20224631, 20224632, 20224632, 20224633, 20224634, 20224634, 20224635, 20224642, 20224643, 20224632, 20224633, 20224633, 20224634, 20224635, 20224637, 20224642, 20224633, 20224634, 20224634, 20224635, 20224642, 20224643, 20224634, 20224635, 20224635, 20224636, 20224636, 20224637, 20224638, 20224641, 20224643, 20224644, 23784179, 20224635, 20224636, 20224636, 20224637, 20224637, 20224638, 20224639, 20224640, 20224641, 20224642, 20224643, 20224644, 20224644, 20224645, 20224645, 20224646, 20224902, 20320806, 20224636, 20224637, 20224637, 20224638, 20224638, 20224641, 20224643, 20224644, 20224645, 20224645, 20224646, 22170656, 23447292, 23784178, 23784180, 20224637, 20224638, 20224638, 20224639, 20224639, 20224640, 20224643, 20224644, 20224645, 20224645, 20224646, 20224646, 22170657, 23784180, 20224638, 20224639, 20224639, 20224640, 20224640, 20224641, 20224642, 20224642, 20224644, 20224645, 20224646, 20224646, 20224647, 23784180, 20224639, 20224640, 20224640, 20224641, 20224641, 20224642, 20224643, 20224644, 20224645, 20224645, 20224646, 20224646, 20224647, 20224647, 21911517, 22170658, 20224640, 20224641, 20224641, 20224642, 20224643, 20224643, 20224645, 20224646, 20224647, 20224647, 20224641, 20224642, 20224643, 20224643, 20224644, 20224646, 20224646, 20224647, 20224647, 20224648, 20224648, 20224642, 20224643, 20224643, 20224646, 20224646, 20224647, 20224648, 20224648, 20224649, 22170652, 20224643, 20224644, 20224645, 20224647, 20224647, 20224648, 20224648, 20224649, 20224649, 20224644, 20224645, 20224646, 20224647, 20224648, 20224648, 20224649, 20224649, 24408362, 20224645, 20224646, 20224647, 20224648, 20224648, 20224649, 20224649, 20224650, 20224646, 20224649, 20224650, 20224648, 20224649, 20224650, 20224650, 20224651, 20224651, 22170663, 20224651, 20224651, 20224652, 20224650, 20224651, 20224652, 20224652, 20224651, 20224652, 20224652, 20224653, 22170656, 20224652, 20224653, 20224653, 23585841, 20224653, 20224654, 20224654, 20224656, 20277079, 20289454, 20289472, 20700725, 21343993, 21477482, 22170660, 22170661, 22170663, 22170663, 22170665, 22170665, 22170666, 22170666, 22170667, 22541611, 23498008, 23784188, 23784188, 20224654, 20224655, 20224655, 20224656, 20224658, 20224910, 20845048, 21290128, 21343993, 21477479, 21477482, 21714290, 21724459, 21831656, 21831656, 21850471, 22018602, 22170657, 22170657, 22170661, 22170663, 22170663, 22170664, 22170664, 22170665, 22170665, 22170666, 22170666, 22541613, 23447304, 23784188, 23784189, 20224655, 20224656, 20224657, 20224913, 20256118, 20320816, 20449066, 20556957, 20652981, 20700726, 21290130, 21308173, 21343994, 21343995, 21423731, 21423732, 21424376, 21424378, 21640673, 21714290, 21850472, 21850472, 21911524, 21911525, 21911525, 22170657, 22170658, 22170658, 22170659, 22170661, 22170662, 22170663, 22170663, 22170664, 22170664, 22170665, 22170665, 22170666, 22170666, 22170667, 22170667, 22170670, 22400889, 23146474, 23146475, 23171014, 23447302, 23784188, 23784189, 23784189, 23784190, 24408367, 20224656, 20224657, 20224657, 20224658, 20224659, 20224659, 20224912, 20244654, 20256119, 20256120, 20256120, 20275758, 20293381, 20293381, 20320816, 20325380, 20449065, 20449067, 20474524, 20556958, 20577624, 20607488, 20700726, 20700728, 20703105, 20712317, 20814406, 20845050, 20978596, 21061488, 21169157, 21169296, 21193324, 21343994, 21400030, 21423731, 21423733, 21714291, 21714291, 21831656, 21831656, 21850472, 21879433, 21911524, 21911524, 21911525, 21911526, 21911526, 21920228, 21976120, 22170658, 22170658, 22170659, 22170659, 22170660, 22170661, 22170661, 22170662, 22170663, 22170663, 22170664, 22170664, 22170665, 22170665, 22170666, 22170666, 22170667, 22170667, 22170668, 22170669, 22201402, 22360193, 22400886, 22400889, 22541612, 22541613, 22541614, 22541614, 22651611, 23447303, 23447304, 23447307, 23447307, 23560104, 23581691, 23784189, 23784189, 23784190, 23784191, 24411347, 28526718, 20224657, 20256122, 20320817, 20449067, 20577623, 20690536, 20700727, 20943987, 21295188, 21319911, 21343995, 21349883, 21367850, 21386074, 21423730, 21423732, 21423732, 21424379, 21477484, 21714291, 21831658, 21850473, 21911524, 21911525, 21911526, 22170658, 22170659, 22170659, 22170660, 22170660, 22170662, 22170663, 22170663, 22170664, 22170665, 22170665, 22170666, 22170667, 22170667, 22541613, 22924676, 23447307, 23585843, 23784190, 23784190, 20320817, 20700727, 22170664, 22170667, 22170667, 20320818, 21290132, 21343997, 21424379, 21831659, 23447307, 20320818, 23585844, 21714294, 22170668, 23784193, 20700730, 20225178, 20225181, 20225183, 20225184, 20225183, 22170933, 21424002, 22170935, 21344267, 22170938, 20264665, 20776535, 20287594, 20287596, 20287597, 20287598, 21321606, 21455207, 22202142, 21455208, 22202143, 20609097, 20326872, 22221778, 20329517, 22223102, 20354271, 23512119, 20354307, 21488564, 20362121, 20362122, 22239407, 22239407, 20416990, 20417004, 20417075, 20417076, 20417159, 20417173, 20673878, 21519990, 21519991, 21576451, 21753706, 21927915, 22007784, 22266918, 22266918, 22266923, 22266925, 23880449, 20545326, 23543563, 20426113, 20426221, 20426330, 22609682, 20673493, 20673491, 20673493, 20673493, 20673494, 20673495, 20673496, 21417745, 21651235, 21514557, 22395091, 22766041, 22074900, 22395088, 22395094, 22395089, 20724418, 20724419, 22420559, 22420561, 20889269, 20889272, 22502978, 21000769, 20930604, 20930611, 20930605, 20930607, 22523650, 22523650, 22753873, 21776722, 20990343, 22783744, 21081320, 21796187, 21112266, 21144539, 21156462, 21156532, 21156599, 22180284, 21176809, 21176810, 21176812, 21176810, 21176812, 21176812, 22646748, 22646749, 22646749, 21321133, 22646748, 22646749, 22646752, 22646743, 22646751, 21181570, 21552945, 21199992, 22658339, 21288468, 21288557, 21288645, 21872981, 21404176, 22760427, 21465456, 21465456, 21465457, 21964401, 21964402, 22334697, 21663341, 22890021, 21732552, 22924622, 21898331, 23007507, 21924319, 23020501, 22113681, 23115190, 22113952, 23115314, 22161998, 22162004, 23139335, 23139344, 22355618, 22355618, 22355621, 23236152, 23236154, 22915962, 23236149, 23236157, 22365755, 22982091, 22391702, 23254188, 22415182, 23265934, 22457254, 23286964, 22463345, 22463346, 22463347, 22463347, 22463348, 22463346, 22463347, 22463348, 22463348, 22596835, 23290014, 23290018, 23030877, 23290019, 24705196, 22951010, 23290017, 23290020, 23290020, 23290019, 23290017, 24903543, 22475124, 22548972, 22511054, 23054731, 23313872, 22547504, 23332095, 22575417, 23346051, 22622819, 22622820, 22622819, 22622819, 22622820, 22622820, 22622821, 22622821, 22622822, 22622832, 23049560, 23369747, 23740700, 24646396, 22623468, 22694068, 23110615, 23110616, 23343904, 23369748, 23369754, 23369754, 23369755, 23369755, 23369756, 24983278, 22624116, 22624116, 22624117, 22624117, 22624118, 22668513, 23370404, 23370405, 23370406, 23050211, 23370397, 22628976, 23372833, 22712905, 22712992, 22713078, 23414881, 22730318, 22730323, 22730324, 22730326, 22730324, 22967128, 23423506, 23423499, 24838684, 24399318, 22735770, 25039766, 22765316, 23441002, 23056694, 23056760, 23056830, 24863397, 23090261, 23344337, 23203938, 23203938, 23203939, 23203939, 23203939, 23203940, 23508250, 25273837, 23362869, 23660315, 23204043, 23321305, 23660307, 23660310, 23660312, 23660314, 23660316, 23890534, 24936955, 23660312, 23204145, 25075592, 23224306, 23670511, 23438671, 23438671, 23438657, 23438658, 23438673, 23438674, 23777677, 23777683, 23457489, 23777676, 23777680, 23777682, 23777683, 23777685, 24148629, 24531692, 25192860, 23476299, 23476301, 23476301, 23476302, 23476302, 23796493, 23796488, 23796490, 23796492, 23796493, 23796495, 23796490, 23796493, 23796495, 23796496, 23796496, 25073133, 23521800, 23819241, 23534215, 23534289, 23534364, 23566383, 23598407, 23598409, 23598408, 23598395, 23598396, 23598409, 23598409, 23598410, 23598410, 23598409, 23598410, 23598411, 23598410, 23598411, 23598410, 23598411, 23598423, 23598423, 23857550, 24228495, 25471072, 23857545, 23857548, 23857548, 23857549, 23857550, 25471074, 23857543, 23857543, 24338495, 25471074, 23857544, 23857546, 23857547, 23857549, 23857549, 23857550, 23857551, 23857552, 23857552, 23857553, 24087773, 24228497, 24530634, 25134190, 25134192, 25471075, 23615811, 23866249, 23727600, 23922146, 23812560, 23964623, 23964624, 24065016, 24090868, 24116660, 24116661, 24116663, 24116666, 24116667, 24116668, 24116669, 24116675, 24116676, 24116661, 24116662, 24116663, 24116666, 24116667, 24116669, 24116669, 24116670, 24116678, 24116663, 24116665, 24116666, 24116666, 24116667, 24116667, 24116668, 24116669, 24116669, 24116670, 24116670, 24116677, 24116680, 24116680, 24116681, 24116684, 24116664, 24116665, 24116667, 24116669, 24116670, 24116670, 24116680, 24116681, 24116666, 24116667, 24116668, 24116668, 24116669, 24116670, 24116668, 24116669, 24116667, 24116671, 24116671, 24116687, 24116668, 24116687, 24116688, 24116670, 24116670, 24116671, 24116672, 24116673, 24116687, 24116688, 24116669, 24116670, 24116671, 24116671, 24116673, 24116674, 24116671, 24116671, 24116672, 24116672, 24116673, 24116673, 24116674, 24116674, 24116689, 24116689, 24116671, 24116672, 24116673, 24116674, 24116674, 24116675, 24116681, 24116690, 24116672, 24116673, 24116673, 24116674, 24116674, 24116675, 24116675, 24116690, 24116690, 24116673, 24116674, 24116674, 24116675, 24116675, 24116676, 24116674, 24116675, 24116675, 24116676, 24116676, 24116677, 24116691, 24116691, 24116692, 24116675, 24116676, 24116676, 24116677, 24116677, 24116678, 24116688, 24116691, 24116692, 24116676, 24116677, 24116677, 24116678, 24116679, 24116685, 24116687, 24116692, 24116692, 24116677, 24116678, 24116678, 24116679, 24116680, 24116684, 24116684, 24116688, 24116690, 24116692, 24116692, 24116693, 24116693, 24116678, 24116679, 24116679, 24116680, 24116681, 24116684, 24116684, 24116685, 24116686, 24116687, 24116688, 24116689, 24116690, 24116691, 24116692, 24116693, 24116693, 24116694, 24116694, 24116679, 24116680, 24116680, 24116681, 24116682, 24116685, 24116686, 24116686, 24116687, 24116687, 24116688, 24116691, 24116691, 24116692, 24116692, 24116693, 24116693, 24116694, 24116694, 24116695, 24116680, 24116681, 24116683, 24116686, 24116687, 24116687, 24116688, 24116690, 24116694, 24116694, 24116695, 24116695, 24116686, 24116689, 24116690, 24116694, 24116694, 24116695, 24116696, 24116687, 24116695, 24116695, 24116696, 24116697, 24116699, 24116696, 24116696, 24116697, 24116698, 24116698, 24116699, 25730206, 24116693, 24116699, 24116700, 24116692, 24116693, 24116700, 25393323, 24116693, 24116694, 24116695, 24116698, 24116701, 24346907, 24116697, 24116701, 24116701, 24116702, 24116701, 24116702, 24116702, 24116702, 25730210, 24116702, 24116703, 25393327, 24116702, 24116703, 24116703, 25730210, 24116701, 25537531, 25730210, 25730211, 24116704, 24116704, 25730210, 24116705, 24116705, 24116705, 24116705, 24116706, 24116706, 24116706, 24116706, 24116707, 24116707, 24116707, 24116708, 24487638, 24116708, 24116709, 24116710, 24116712, 24346914, 24346915, 24346916, 24487638, 24487639, 24487639, 24487640, 25092500, 25092502, 25393330, 25527718, 25531870, 25539233, 25730215, 25730216, 24116709, 24116710, 24116710, 24116711, 24116712, 24177616, 24304401, 24307220, 24346912, 24346913, 24346913, 24346914, 24346914, 24346915, 24346915, 24346916, 24402594, 24487638, 24487639, 24487639, 24487640, 24487640, 24487641, 24521654, 24597636, 24597637, 24597637, 24597640, 24719281, 24746991, 24746994, 24887109, 24965420, 25069430, 25092501, 25092501, 25092502, 25117041, 25117042, 25237624, 25241719, 25241719, 25241723, 25246393, 25350255, 25393329, 25393329, 25393330, 25393330, 25393331, 25393331, 25393332, 25393333, 25393333, 25393336, 25420424, 25431099, 25527718, 25527719, 25531866, 25531868, 25531869, 25531870, 25730214, 25730215, 25730216, 25730216, 25730217, 25730217, 26354394, 24116710, 24116711, 24116712, 24116713, 24307220, 24346913, 24346914, 24346914, 24346915, 24346916, 24346916, 24346931, 24346935, 24402595, 24437828, 24487638, 24487639, 24487639, 24487640, 24487640, 24487641, 24597636, 24597637, 24597637, 24597638, 24965420, 25009250, 25024066, 25069431, 25092501, 25117042, 25237624, 25241722, 25393330, 25393331, 25393331, 25393332, 25393332, 25393333, 25393334, 25393334, 25396051, 25527718, 25531868, 25531870, 25531871, 25596341, 25730216, 25730216, 25730217, 25730217, 26354395, 24116712, 24346913, 24346913, 24346914, 24346915, 24346917, 24437827, 24487639, 24487640, 24487641, 24487641, 24597637, 25069431, 25393331, 25393334, 25531870, 25531871, 25531872, 25730216, 25730217, 25730217, 24346916, 24487640, 24597639, 25393335, 25730218, 24487640, 25092503, 25393334, 25730219, 24487642, 24487642, 25092505, 25393336, 24178168, 25147781, 24212310, 25778023, 24238546, 24548570, 24492114, 25429432, 24495743, 25919738, 24497746, 24497751, 25920742, 25722400, 24577130, 24577137, 24577131, 24577133, 24577147, 24577132, 24577137, 24577132, 24577133, 24577120, 24577135, 24577137, 24577135, 24577136, 24577140, 24577144, 24577145, 24577136, 24577136, 24577138, 24577137, 24577137, 24577138, 24577138, 24577139, 24577139, 24577141, 24577143, 24577147, 24577138, 24577139, 24577139, 24577141, 24577142, 24577140, 24717858, 24717859, 24827855, 25415863, 25960435, 24717858, 24717860, 24827857, 25623552, 25960437, 24577153, 25623551, 25623551, 25960437, 25623550, 25960438, 25960443, 24577172, 25960438, 24827859, 25623552, 25623553, 25960439, 24717863, 25347265, 25898806, 25960439, 25960439, 24827860, 25016417, 25623554, 25960440, 25960440, 24717864, 24577175, 24717866, 25623556, 25623557, 25960442, 24827863, 25623560, 24717870, 25626281, 24577176, 25960448, 25960450, 24717875, 24717880, 25960457, 24688496, 24688555, 26016118, 24688724, 24688892, 24773769, 24758954, 24758961, 26051344, 26051350, 24793080, 26068430, 24858583, 24858568, 24858569, 24858570, 24858584, 24858584, 24858584, 24858570, 24858571, 24858571, 24858585, 24858571, 24858584, 24858585, 24858585, 24858584, 24858586, 24858586, 24858598, 26101160, 24858599, 25764278, 24968582, 24968582, 24968583, 25258055, 25440376, 25454304, 25463446, 25463447, 25463447, 25491375, 25529653, 25556591, 25556592, 25608569, 25612665, 25615464, 25764275, 25764275, 25764276, 25764276, 25764277, 25764277, 25764278, 25764278, 25764279, 25802042, 25802047, 25862214, 25877077, 25898664, 25898664, 25902810, 25902814, 25902815, 25902815, 25967286, 26101158, 26101161, 26101161, 26101162, 26101163, 26101163, 24926622, 25798300, 25078576, 25078577, 25078577, 25078579, 25078565, 25078577, 25078577, 25078578, 25078578, 25078583, 26008659, 25312028, 25550371, 25597982, 25666585, 25666587, 25874269, 25874270, 25874271, 25874271, 25874272, 25874272, 25874273, 25874274, 25907137, 26008658, 26012810, 26012811, 26211156, 26211157, 25874271, 25874273, 26211159, 26211160, 25321866, 25429931, 25377288, 25377291, 26360513, 26360514, 25455694, 26062833, 25462857, 26403297, 25537994, 25597758, 25545481, 26107725, 25624708, 25939651, 26484221, 25657522, 25657523, 25657522, 26163745, 25928163, 26163744, 25814143, 25941224, 26380593, 25901800, 26285881, 25931448, 26293056, 26022222, 26346124, 26348842, 26484661, 26683007, 26683008, 26050010, 26050065, 26050134, 26494437, 26068306, 26068306, 26068307, 26068308, 26068308, 26068306, 26068309, 26068306, 26068307, 26068310, 26068310, 26369136, 26507674, 26706021, 26369135, 26369138, 26706021, 26369134, 26706023, 26369136, 26507675, 26507676, 26706023, 26507677, 26706023, 26706024, 26092849, 26117385, 26117386, 26117387, 26393677, 26393674, 26393676, 26393677, 26532215, 26532215, 26730561, 26124202, 26733989, 26198801, 26226697, 26200722, 26573884, 26254595, 26254597, 26254596, 26254598, 26254599, 26462284, 26462281, 26799167, 26272392, 26462282, 26462285, 26462283, 26290183, 26816959, 26358560, 26358561, 26358561, 26851153, 26851155, 26366742, 26366742, 26366742, 26366745, 26366749, 26366751, 26855239, 26518355, 26855239, 26656893, 26855243, 26372346, 26659695, 26376090, 26661566, 26583811, 26963773, 26654673, 26999215, 26669949, 26669953, 26669953, 26669964, 26669967, 26669951, 26669951, 26669952, 26669953, 26669953, 26669965, 26669967, 26669968, 26669966, 26669968, 26669968, 26669969, 26669970, 26669952, 26669953, 26669954, 26669955, 26669965, 26669966, 26669966, 26669967, 26669967, 26669968, 26669968, 26669969, 26669969, 26669970, 26669970, 26669953, 26669954, 26669956, 26669967, 26669967, 26669968, 26669969, 26669970, 26669954, 26669955, 26669956, 26669967, 26669968, 26669968, 26669969, 26669969, 26669970, 26669955, 26669956, 26669956, 26669968, 26669969, 26669969, 26669970, 26669971, 26669971, 26669972, 26669957, 26669970, 26669971, 26669957, 26669970, 26669971, 26669972, 26669972, 26669958, 26669969, 26669970, 26669970, 26669971, 26669972, 26669972, 26669973, 26669959, 26669972, 26669973, 26669973, 26669974, 26669970, 26669973, 26669979, 27006851, 27006851, 26669982, 26669982, 26808505, 26669983, 26808507, 26984862, 27006851, 26669982, 26669983, 26669984, 27006852, 27006853, 27006853, 26669984, 26669985, 27006853, 26669985, 26804356, 26808507, 27006854, 26669986, 26669986, 26672686, 26672690, 26804356, 26808506, 26808506, 26808507, 26808508, 26814174, 27006853, 27006854, 27006854, 27006855, 27006856, 26669986, 26669987, 27006855, 26669987, 26669988, 26669988, 26672688, 26702836, 26707737, 26804357, 26808506, 26808507, 26808508, 26808509, 26808510, 26808511, 26814175, 26916171, 27006854, 27006854, 27006855, 27006855, 26669988, 26804357, 26804358, 26808507, 26808509, 27006855, 27006855, 27006856, 26808508, 27006855, 27006855, 27006856, 27006856, 27631034, 26743571, 27006858, 26675405, 26675407, 26675408, 26675408, 26675409, 26675410, 27009575, 27009573, 27009574, 26811228, 27009574, 26724183, 27033974, 26735701, 26735702, 26837222, 27039720, 26745498, 26745501, 26745505, 26745507, 26910744, 27044617, 26846274, 27044622, 26771380, 27057560, 26817166, 26882106, 26865841, 27104789, 26895565, 26895566, 27119650, 27119651, 26938741, 26938742, 26938742, 26938743, 26938744, 26938741, 26938743, 26938743, 26938742, 26938743, 26938744, 26938742, 26942893, 27079604, 27141238, 27141239, 27141239, 26942894, 27141239, 26942890, 26942894, 27141240, 27141240, 27141241, 26942893, 26942894, 27141241, 27141242, 27141241, 26947038, 26947027, 26947039, 26947030, 26947041, 26947029, 26947039, 26947041, 26947042, 26947029, 26947043, 26947043, 26947045, 26947029, 26947044, 26947044, 26947045, 26947045, 26947045, 26947046, 26947047, 26947032, 26947043, 26947044, 26947046, 26947046, 26947047, 26947046, 26947047, 26947047, 26947047, 26947048, 26947048, 26947045, 26947048, 26947049, 26947048, 26997773, 27145389, 27145388, 26947058, 27145389, 27145390, 27145391, 26947059, 26947060, 27145389, 27145390, 27145391, 27145390, 27145391, 27145392, 27145391, 27145391, 27145392, 26947062, 27102365, 27145391, 27145392, 27145392, 27145393, 26947063, 27083760, 27145392, 27145392, 27040944, 27145392, 27145393, 27145393, 27145394, 27145393, 27145393, 27145394, 27145394, 26958378, 26958381, 27151058, 27151059, 27151060, 26961772, 27152754, 27048557, 27196170, 27075987, 27075988, 27075989, 27209863, 27209863, 27134847, 27239297, 27162371, 27253054, 27220468, 27220471, 27282102, 27282103, 27282104, 27257682, 27300708, 27299754, 27321744, 27343719, 27343722, 27343721, 27343722, 27343722, 27343722, 27343723, 27343723, 27343724, 27343723, 27343724, 27343724, 27343738, 27343724, 27343725, 27343725, 27343726, 27343726, 27343728, 27343739, 27343740, 27343740, 27343741, 27343725, 27343726, 27343727, 27343726, 27343727, 27343727, 27343740, 27343740, 27343727, 27343728, 27343728, 27343729, 27343729, 27343730, 27343731, 27343740, 27343740, 27343741, 27343742, 27343743, 27343728, 27343729, 27343729, 27343730, 27343730, 27343731, 27343731, 27343740, 27343740, 27343741, 27343741, 27343742, 27343729, 27343730, 27343730, 27343731, 27343731, 27343732, 27343732, 27343733, 27343739, 27343740, 27343741, 27343741, 27343742, 27343742, 27343743, 27343743, 27343730, 27343731, 27343731, 27343732, 27343732, 27343733, 27343741, 27343741, 27343742, 27343742, 27343743, 27343744, 27343731, 27343732, 27343732, 27343733, 27343734, 27343741, 27343742, 27343742, 27343743, 27343743, 27343744, 27343744, 27343746, 27343732, 27343733, 27343733, 27343734, 27343741, 27343742, 27343742, 27343743, 27343743, 27343744, 27343733, 27343734, 27343735, 27343742, 27343743, 27343743, 27343744, 27343744, 27343745, 27343746, 27343734, 27343739, 27343743, 27343743, 27343744, 27343744, 27343745, 27343748, 27343740, 27343743, 27343744, 27343744, 27343745, 27343745, 27343746, 27343745, 27343745, 27343745, 27343746, 27343746, 27343749, 27343750, 27343752, 27343752, 27343753, 27343753, 27343754, 27343754, 27969537, 27343754, 27343755, 27343755, 27343756, 27343756, 27343757, 27967917, 27343755, 27343756, 27343756, 27343757, 27343758, 27343756, 27343757, 27343757, 27343758, 27343759, 27648917, 27678575, 40272220, 27343757, 27343758, 27343758, 27343759, 27343759, 27343760, 27967918, 27967960, 40272220, 27343758, 27343759, 27343759, 27343760, 27343761, 27343761, 27343762, 27969540, 27972172, 27343759, 27343760, 27343760, 27343761, 27343761, 27343762, 27343763, 27473919, 27967919, 27967961, 27967968, 27967970, 27969540, 27970899, 27972173, 27343760, 27343761, 27343761, 27343762, 27343762, 27343763, 27343764, 27967920, 27967962, 27967964, 27969541, 27343761, 27343762, 27343762, 27343763, 27343763, 27343764, 27343764, 27351793, 27678578, 27894652, 27894653, 27918350, 27967920, 27967962, 27967965, 27969541, 28645334, 32086272, 27343762, 27343763, 27343763, 27343764, 27343764, 27343765, 27343765, 27473841, 27819479, 27894653, 27894653, 27967920, 27967921, 27967962, 27967963, 27967971, 27967975, 27969542, 28645350, 27343763, 27343764, 27343764, 27343765, 27343765, 27343766, 27404461, 27473841, 27738396, 27918351, 27967921, 27967963, 27967963, 27967976, 27969542, 27970936, 27972216, 27343764, 27343765, 27343765, 27343766, 27343766, 27678579, 27854405, 27894652, 27894653, 27894654, 27967921, 27967922, 27967963, 27967964, 27967967, 27967972, 27970901, 27343765, 27343766, 27343766, 27343767, 27435992, 27456922, 27473842, 27648922, 27678577, 27678578, 27678579, 27678580, 27886629, 27894653, 27894654, 27894654, 27894655, 27967922, 27967964, 27967965, 27967972, 27967973, 27969543, 27343766, 27343767, 27343767, 27678580, 27894653, 27894654, 27894655, 27894656, 27967923, 27967964, 27967965, 27967974, 27969544, 27343767, 27343768, 27343768, 27436525, 27456921, 27456923, 27648349, 27678580, 27678581, 27678584, 27886629, 27894654, 27894655, 27894655, 27894656, 27926893, 27967923, 27967964, 27967965, 27967965, 27967974, 27969544, 27970903, 27970938, 27970953, 27343768, 27343769, 27343769, 27343770, 27408978, 27456920, 27456923, 27473839, 27482157, 27485687, 27512926, 27648923, 27678581, 27678581, 27714064, 27718939, 27886631, 27894653, 27894655, 27894655, 27894656, 27894656, 27894657, 27967923, 27967924, 27967966, 27967982, 27967982, 27969545, 28645338, 27343770, 27456922, 27484947, 27678581, 27678581, 27678582, 27894655, 27894656, 27967924, 27967965, 27967966, 27967966, 27456922, 27678583, 27967975, 27678583, 27967967, 27967968, 27359837, 27726980, 27465172, 28028632, 27474203, 28033149, 27528231, 27528232, 28060162, 28060204, 27529293, 27741117, 27570091, 27570090, 27570092, 27570095, 27570092, 27570099, 28081092, 28081135, 28081094, 28081098, 28081099, 27603919, 27603931, 27603935, 27604006, 27604012, 27604014, 27604090, 27604090, 27604091, 27604092, 27604092, 28024823, 28098090, 28098091, 28098133, 27620558, 28106325, 27626141, 28109118, 27627622, 28109858, 27682095, 28138713, 27952944, 27952944, 28272518, 27954092, 27954096, 28191798, 28273092, 28273139, 28013407, 28013407, 28013396, 28013409, 28013409, 28013409, 28013410, 28013410, 28013412, 28013413, 28302751, 28302752, 28013425, 28221458, 28229484, 28229485, 28302752, 28302794, 28302806, 28305769, 28302753, 28084390, 28338292, 28094121, 28094122, 28094267, 28113581, 28094414, 28269983, 28133040, 28133041, 28362565, 28329670, 28295254, 28443695, 28365059, 28478632, 28429504, 28429505, 28429507, 28429505, 28429505, 28437530, 28510798, 28510798, 28510798, 28510801, 28445555, 28445557, 28445558, 28445542, 28445543, 28445544, 28445557, 28445543, 28445544, 28445558, 28445559, 28445559, 28445559, 28445559, 28445560, 28445559, 28445560, 28445560, 28445559, 28445561, 28518826, 28518868, 28445574, 28445575, 28518827, 28518869, 28445575, 28518827, 28518872, 28445577, 28465092, 28518827, 28518828, 28518870, 28518829, 28484619, 28538355, 28492949, 28493024, 28493097, 28542591, 28544212, 28510024, 28510098, 28510173, 28551129, 28526298, 28559236, 28592079, 28592080, 28592081, 28592081, 28592082, 28592082, 28592083, 28592084, 28592089, 28592090, 28592091, 28592096, 28592113, 28592116, 28592120, 28592120, 28592121, 28592121, 28592122, 28592123, 28592124, 28592125, 28592155, 28592081, 28592082, 28592082, 28592083, 28592084, 28592091, 28592115, 28592118, 28592120, 28592121, 28592121, 28592122, 28592082, 28592083, 28592090, 28592116, 28592117, 28592122, 28592122, 28592084, 28592092, 28592114, 28592122, 28592122, 28592123, 28592084, 28592093, 28592123, 28592085, 28592086, 28592093, 28592101, 28592105, 28592109, 28592110, 28592120, 28592122, 28592123, 28592123, 28592124, 28592124, 28592087, 28592105, 28592124, 28592125, 28592125, 28592125, 28592100, 28592101, 28592132, 28592123, 28592128, 28592131, 28592132, 28592132, 28592133, 28592135, 28592138, 28592139, 28592143, 28592148, 28592148, 28592153, 28592153, 28592154, 28592156, 28592152, 28592157, 28592156, 28592157, 28592158, 28592161, 28592161, 28592162, 28592162, 28592163, 28592163, 28592163, 28592164, 28592170, 28592171, 28592176, 28592164, 28592165, 28592165, 28592166, 28592166, 28592167, 28592167, 28592168, 28592169, 28592169, 28592170, 28592171, 28592171, 28592172, 28592172, 28592173, 28592174, 28592175, 28592175, 28592176, 28592176, 28592177, 28592179, 28592179, 28592180, 28592180, 28592181, 28592181, 28592182, 28592183, 28592183, 28592184, 28592186, 28592186, 28592188, 28592189, 28592189, 28592190, 28592197, 28592197, 28592239, 28592165, 28592166, 28592166, 28592167, 28592167, 28592170, 28592171, 28592172, 28592172, 28592173, 28592174, 28592174, 28592175, 28592176, 28592177, 28592182, 28592187, 28592198, 28592166, 28592167, 28592167, 28592168, 28592168, 28592169, 28592170, 28592171, 28592171, 28592172, 28592172, 28592173, 28592173, 28592174, 28592175, 28592176, 28592178, 28592179, 28592180, 28592181, 28592182, 28592185, 28592192, 28592198, 28592167, 28592168, 28592168, 28592171, 28592173, 28592174, 28592178, 28592181, 28592168, 28592169, 28592169, 28592173, 28592173, 28592174, 28592174, 28592175, 28592177, 28592177, 28592178, 28592178, 28592179, 28592195, 28592197, 28592199, 28592169, 28592170, 28592170, 28592171, 28592172, 28592173, 28592173, 28592174, 28592174, 28592175, 28592176, 28592176, 28592177, 28592178, 28592178, 28592179, 28592179, 28592182, 28592187, 28592170, 28592172, 28592174, 28592175, 28592175, 28592176, 28592177, 28592179, 28592179, 28592189, 28592200, 28592172, 28592173, 28592175, 28592176, 28592177, 28592178, 28592174, 28592175, 28592176, 28592176, 28592178, 28592179, 28592173, 28592174, 28592177, 28592181, 28592175, 28592176, 28592177, 28592191, 28592176, 28592177, 28592177, 28592178, 28592176, 28592178, 28592178, 28592181, 28592178, 28592178, 28592180, 28592181, 28592185, 28592179, 28592179, 28592180, 28592186, 28592193, 28592194, 28592204, 28592179, 28592180, 28592182, 28592183, 28592184, 28592184, 28592186, 28592189, 28592190, 28592193, 28592180, 28592181, 28592182, 28592182, 28592183, 28592183, 28592184, 28592184, 28592185, 28592186, 28592186, 28592188, 28592190, 28592191, 28592192, 28592193, 28592194, 28592196, 28592197, 28592197, 28592198, 28592198, 28592199, 28592203, 28592205, 28592181, 28592182, 28592182, 28592183, 28592183, 28592184, 28592184, 28592185, 28592185, 28592187, 28592187, 28592188, 28592188, 28592189, 28592189, 28592190, 28592190, 28592191, 28592191, 28592192, 28592192, 28592193, 28592194, 28592194, 28592195, 28592195, 28592197, 28592198, 28592198, 28592199, 28592199, 28592200, 28592202, 28592203, 28592205, 28592206, 28592206, 28592182, 28592185, 28592186, 28592183, 28592184, 28592184, 28592185, 28592185, 28592186, 28592186, 28592188, 28592188, 28592189, 28592189, 28592190, 28592192, 28592193, 28592194, 28592194, 28592195, 28592196, 28592198, 28592199, 28592200, 28592204, 28592204, 28592206, 28592207, 28592185, 28592185, 28592186, 28592186, 28592188, 28592189, 28592191, 28592192, 28592195, 28592196, 28592197, 28592197, 28592198, 28592185, 28592186, 28592186, 28592187, 28592187, 28592188, 28592188, 28592189, 28592190, 28592190, 28592191, 28592191, 28592192, 28592193, 28592194, 28592194, 28592195, 28592196, 28592197, 28592197, 28592199, 28592200, 28592201, 28592202, 28592202, 28592204, 28592206, 28592208, 28592187, 28592188, 28592188, 28592189, 28592190, 28592190, 28592191, 28592191, 28592192, 28592193, 28592194, 28592194, 28592195, 28592196, 28592197, 28592197, 28592198, 28592200, 28592200, 28592202, 28592208, 28592188, 28592189, 28592189, 28592190, 28592190, 28592191, 28592191, 28592192, 28592192, 28592193, 28592194, 28592194, 28592195, 28592196, 28592196, 28592197, 28592198, 28592198, 28592200, 28592201, 28592202, 28592206, 28592207, 28592209, 28592189, 28592190, 28592190, 28592191, 28592191, 28592192, 28592192, 28592193, 28592194, 28592194, 28592195, 28592195, 28592196, 28592196, 28592197, 28592198, 28592198, 28592199, 28592201, 28592202, 28592202, 28592203, 28592204, 28592204, 28592207, 28592209, 28592210, 28592190, 28592191, 28592192, 28592192, 28592193, 28592193, 28592194, 28592195, 28592196, 28592196, 28592197, 28592197, 28592198, 28592199, 28592200, 28592201, 28592201, 28592202, 28592204, 28592208, 28592210, 28592191, 28592192, 28592193, 28592196, 28592198, 28592199, 28592200, 28592192, 28592193, 28592194, 28592197, 28592202, 28592206, 28592193, 28592194, 28592194, 28592195, 28592195, 28592196, 28592197, 28592197, 28592198, 28592199, 28592200, 28592200, 28592201, 28592203, 28592205, 28592212, 28592194, 28592195, 28592195, 28592196, 28592196, 28592199, 28592199, 28592200, 28592203, 28592203, 28592204, 28592209, 28592210, 28592212, 28592212, 28592244, 28593758, 28592195, 28592196, 28592196, 28592197, 28592198, 28592198, 28592199, 28592199, 28592201, 28592202, 28592202, 28592205, 28592206, 28592209, 28592196, 28592197, 28592197, 28592198, 28592199, 28592199, 28592200, 28592200, 28592201, 28592202, 28592202, 28592203, 28592204, 28592205, 28592206, 28592209, 28592210, 28592212, 28592213, 28592197, 28592198, 28592199, 28592199, 28592200, 28592200, 28592201, 28592202, 28592203, 28592203, 28592204, 28592207, 28592211, 28592213, 28592213, 28592214, 28592199, 28592200, 28592201, 28592201, 28592203, 28592203, 28592205, 28592207, 28592212, 28592214, 28592200, 28592200, 28592201, 28592201, 28592202, 28592202, 28592203, 28592203, 28592204, 28592204, 28592205, 28592206, 28592207, 28592210, 28592212, 28592215, 28593760, 28596393, 28592204, 28592204, 28592207, 28592208, 28592214, 28592201, 28592202, 28592202, 28592203, 28592204, 28592204, 28592205, 28592205, 28592206, 28592207, 28592207, 28592208, 28592208, 28592209, 28592210, 28592211, 28592215, 28592216, 28593761, 28592202, 28592203, 28592203, 28592204, 28592204, 28592205, 28592205, 28592206, 28592207, 28592207, 28592208, 28592208, 28592209, 28592214, 28592216, 28593762, 28592203, 28592204, 28592204, 28592205, 28592205, 28592206, 28592206, 28592207, 28592208, 28592208, 28592210, 28592212, 28592217, 28593762, 28592204, 28592205, 28592205, 28592206, 28592206, 28592208, 28592208, 28592209, 28592209, 28592211, 28592215, 28592217, 28592206, 28592206, 28592207, 28592207, 28592208, 28592209, 28592209, 28592210, 28592210, 28592211, 28592212, 28592215, 28592217, 28592218, 28592206, 28592207, 28592208, 28592210, 28592210, 28592218, 28592207, 28592208, 28592208, 28592209, 28592209, 28592210, 28592210, 28592211, 28592211, 28592212, 28592216, 28592216, 28592219, 28592208, 28592209, 28592209, 28592210, 28592210, 28592211, 28592211, 28592212, 28592212, 28592213, 28592213, 28592214, 28592215, 28592215, 28592216, 28592219, 28592219, 28592209, 28592210, 28592211, 28592211, 28592212, 28592212, 28592213, 28592213, 28592214, 28592215, 28592216, 28592217, 28592217, 28592218, 28592218, 28592219, 28592220, 28593765, 28592210, 28592211, 28592211, 28592212, 28592212, 28592213, 28592213, 28592214, 28592216, 28592217, 28592218, 28592220, 28592220, 28592212, 28592214, 28592218, 28592221, 28592212, 28592213, 28592213, 28592214, 28592215, 28592215, 28592216, 28592218, 28592221, 28592221, 28593767, 28592213, 28592214, 28592214, 28592215, 28592215, 28592216, 28592216, 28592219, 28592219, 28592220, 28592221, 28592222, 28592214, 28592215, 28592215, 28592216, 28592216, 28592217, 28592218, 28592219, 28592219, 28592220, 28592220, 28592221, 28592222, 28592222, 28592264, 28593768, 28595126, 28592215, 28592216, 28592216, 28592217, 28592217, 28592218, 28592219, 28592220, 28592221, 28592221, 28592222, 28592223, 28593768, 28592216, 28592217, 28592217, 28592218, 28592218, 28592219, 28592220, 28592221, 28592222, 28592222, 28592223, 28592223, 28592217, 28592218, 28592219, 28592220, 28592221, 28592222, 28592223, 28592224, 28593769, 28592218, 28592219, 28592219, 28592220, 28592221, 28592222, 28592223, 28592223, 28592224, 28592224, 28592219, 28592220, 28592220, 28592221, 28592222, 28592222, 28592223, 28592223, 28592224, 28592225, 28592220, 28592221, 28592222, 28592223, 28592223, 28592224, 28592225, 28592225, 28592223, 28592223, 28592224, 28592225, 28592226, 28593771, 28592224, 28592224, 28592225, 28592226, 28592226, 28592226, 28592227, 28592225, 28592225, 28592227, 28592227, 28593773, 28593818, 28592225, 28592226, 28592226, 28592227, 28592227, 28592228, 28592226, 28592227, 28592227, 28592228, 28592228, 28592227, 28592228, 28592228, 28592229, 28592228, 28592229, 28592229, 28592229, 28592230, 28592230, 28592233, 28592231, 28592233, 28592234, 28592235, 28592237, 28592239, 28592240, 28592241, 28592241, 28592242, 28592244, 28592248, 28592251, 28592261, 28592262, 28592263, 28592263, 28592267, 28592268, 28592269, 28592270, 28592271, 28592271, 28592272, 28592273, 28593776, 28593832, 28595135, 28595170, 28595190, 28596450, 29269569, 29269569, 29269570, 32176264, 32710507, 28592232, 28592233, 28592233, 28592234, 28592234, 28592235, 28592236, 28592236, 28592237, 28592238, 28592239, 28592240, 28592240, 28592241, 28592241, 28592242, 28592242, 28592243, 28592243, 28592244, 28592244, 28592245, 28592245, 28592247, 28592248, 28592249, 28592249, 28592252, 28592252, 28592253, 28592254, 28592255, 28592255, 28592256, 28592257, 28592258, 28592258, 28592259, 28592261, 28592261, 28592263, 28592263, 28592264, 28592264, 28592267, 28592267, 28592268, 28592268, 28592269, 28592270, 28592271, 28592271, 28592272, 28592272, 28592273, 28592273, 29269570, 28592234, 28592237, 28592238, 28592240, 28592243, 28592244, 28592247, 28592255, 28592269, 28592272, 28592272, 28592273, 28592273, 28592274, 28592237, 28592264, 28592267, 28592269, 28592241, 28592243, 28592274, 28592275, 28592236, 28592238, 28592239, 28592242, 28592243, 28592247, 28592247, 28592266, 28592269, 28592273, 28592274, 28592275, 28592275, 28593779, 28592261, 28592270, 28592275, 28592242, 28592276, 28592251, 28592275, 28592276, 28592276, 28592277, 28592241, 28592245, 28592246, 28592273, 28592246, 28592247, 28592249, 28592250, 28592252, 28592254, 28592258, 28592245, 28592278, 28593782, 28592278, 28592247, 28592247, 28592280, 28592270, 28592248, 28592249, 28592253, 28592265, 28592270, 28592273, 28592279, 28592280, 28592280, 28592251, 28592253, 28592254, 28592255, 28592255, 28592261, 28592280, 28592281, 28592253, 28592255, 28592256, 28592256, 28592280, 28592257, 28592273, 28592273, 28592277, 28592281, 28593786, 28592254, 28592255, 28592256, 28592257, 28592273, 28592281, 28592281, 28592282, 28592283, 28592279, 28592284, 28592254, 28592277, 28592279, 28592282, 28592284, 28592284, 28592256, 28592258, 28592280, 28592257, 28592280, 28592283, 28592284, 28592285, 28592257, 28592284, 28593789, 28592260, 28592260, 28592262, 28592264, 28592266, 28592267, 28592271, 28592277, 28592284, 28592284, 28592285, 28592286, 28592286, 34170661, 28592282, 28592284, 28592283, 28592285, 28592261, 28592286, 28592265, 28592271, 28592278, 28592279, 28592283, 28592286, 28592286, 28592287, 28592288, 28592272, 28592289, 28592284, 28592288, 28592290, 28592268, 28592280, 28592276, 28592286, 28592291, 28592287, 28592288, 28592291, 28592284, 28592293, 28592288, 28592288, 28592291, 28592294, 28592292, 28592291, 28592295, 28592296, 28592286, 28592295, 28592297, 28592296, 28592294, 28592296, 28592297, 28592299, 28592299, 28592285, 28592297, 28592290, 28592296, 28592299, 28592299, 28592292, 28592293, 28592293, 28592302, 28592294, 28592303, 28592304, 28592295, 28592296, 28592296, 28592298, 28592301, 28592301, 28592303, 28592304, 28592304, 28592305, 28592299, 28592300, 28592303, 28592305, 28592305, 28592302, 28592303, 28592304, 28592304, 28592304, 28592305, 28592307, 28592307, 28592305, 28592308, 28592305, 28592307, 28592307, 28592308, 28592308, 28592306, 28592308, 28592309, 28593813, 28592305, 28592306, 28592306, 28592307, 28592308, 28592308, 28592309, 28592309, 28592310, 28592306, 28592307, 28592308, 28592308, 28592307, 28592309, 28592310, 28592311, 28592309, 28592309, 28592310, 28592310, 28592311, 28592311, 28592309, 28592310, 28592310, 28592311, 28592310, 28592311, 28592311, 28592312, 28592312, 28593861, 28592311, 28592312, 28592312, 28592313, 28592312, 28592313, 28592313, 28592313, 28592314, 28592314, 28592315, 28592316, 28592331, 28593818, 28593818, 28593835, 28593863, 28593869, 28593873, 28593929, 28595177, 28595212, 28595213, 28595227, 28596451, 28596492, 29269629, 29269630, 31107124, 28592331, 28593819, 28593819, 28593834, 28595321, 28595322, 28595323, 28595323, 28595324, 28595325, 28595326, 28595332, 28595333, 28595334, 28595343, 28595344, 28595347, 28595357, 28595358, 28595361, 28595364, 28595364, 28595365, 28595366, 28595366, 28595367, 28595367, 28595367, 28595368, 28595368, 28595368, 28595369, 28595369, 28595370, 28595369, 28595371, 28595377, 28595377, 28595378, 29271146, 28595387, 28595383, 28595385, 28595386, 28595388, 28595389, 28595392, 28595402, 28595403, 28595406, 28595409, 28595409, 28595410, 28595410, 28595411, 28595411, 28595412, 28595413, 28595413, 28595414, 28595414, 28595415, 28595416, 28595416, 28595417, 28595418, 28595418, 28595419, 28595419, 28595420, 28595420, 28595421, 28595421, 28595422, 28595422, 28595423, 28595424, 28595424, 28595425, 28595426, 28595426, 28595427, 28595427, 28595429, 28595430, 28595431, 28595431, 28595432, 28595432, 28595433, 28595433, 28595434, 28595435, 28595436, 28595436, 28595437, 28595438, 28595438, 28595439, 28595439, 28595440, 28595442, 28595442, 28595413, 28595420, 28595439, 28595443, 28595415, 28595423, 28595438, 28595443, 28595415, 28595416, 28595418, 28595430, 28595444, 28595417, 28595422, 28595423, 28595424, 28595427, 28595431, 28595434, 28595444, 28595419, 28595420, 28595421, 28595422, 28595423, 28595424, 28595431, 28595435, 28595439, 28595439, 28595441, 28595441, 28595442, 28595443, 28595445, 28595439, 28595446, 28595420, 28595423, 28595434, 28595435, 28595440, 28595446, 28595422, 28595423, 28595424, 28595427, 28595429, 28595441, 28595442, 28595443, 28595443, 28595444, 28595446, 28595447, 28595425, 28595426, 28595427, 28595427, 28595428, 28595429, 28595432, 28595435, 28595439, 28595440, 28595440, 28595441, 28595442, 28595442, 28595443, 28595443, 28595444, 28595444, 28595445, 28595447, 28595448, 28595448, 28595426, 28595431, 28595433, 28595443, 28595449, 28595427, 28595429, 28595443, 28595444, 28595445, 28595449, 28595440, 28595441, 28595444, 28595450, 28595428, 28595429, 28595430, 28595438, 28595439, 28595442, 28595444, 28595444, 28595445, 28595446, 28595446, 28595450, 28595450, 28595429, 28595430, 28595432, 28595443, 28595443, 28595444, 28595445, 28595446, 28595449, 28595451, 28595433, 28595443, 28595451, 28595431, 28595434, 28595435, 28595442, 28595444, 28595446, 28595451, 28595452, 28595432, 28595433, 28595435, 28595448, 28595452, 28595438, 28595441, 28595444, 28595444, 28595446, 28595449, 28595453, 28595443, 28595446, 28595448, 28595453, 28595446, 28595447, 28595448, 28595454, 28595454, 28595454, 28595455, 28595438, 28595442, 28595445, 28595446, 28595447, 28595452, 28595453, 28595455, 28595456, 28595447, 28595456, 28595447, 28595452, 28595457, 28595451, 28595458, 28595458, 28595459, 28595459, 28595448, 28595451, 28595453, 28595456, 28595460, 28595460, 28595451, 28595461, 28595461, 28595462, 28596745, 28595453, 28595462, 28595462, 28595457, 28595458, 28595463, 28595459, 28595459, 28595460, 28595464, 28595460, 28595462, 28595464, 28595459, 28595461, 28595465, 28595460, 28595465, 29280057, 28595466, 28595462, 28595466, 28595462, 28595462, 28595463, 28595463, 28595464, 28595464, 28595467, 28595467, 28595463, 28595468, 28595465, 28595468, 28595468, 28595466, 28595469, 28595466, 28595469, 28595469, 28595470, 28595470, 28595470, 28595471, 28595471, 28595472, 28595473, 28595474, 28595474, 28595475, 28595476, 28595477, 28595477, 28595478, 28595479, 28595481, 28595481, 28595482, 28595484, 28595484, 28595485, 28595486, 28595486, 28595488, 28595488, 28595490, 28595491, 28595492, 28595494, 28595498, 28595499, 28595501, 28595504, 28595505, 28595506, 28595507, 28595508, 28595509, 28595511, 28595511, 28595512, 28595512, 28595513, 28595514, 28595514, 28595515, 28595515, 28595516, 28595516, 28595517, 28595517, 28595518, 28596756, 28596791, 28596806, 28598030, 28598071, 29271190, 28595474, 28595475, 28595476, 28595477, 28595479, 28595479, 28595480, 28595480, 28595481, 28595484, 28595485, 28595486, 28595487, 28595490, 28595491, 28595492, 28595494, 28595496, 28595499, 28595500, 28595507, 28595511, 28595512, 28595513, 28595514, 28595514, 28595515, 28595516, 28595516, 28595517, 28595517, 28595518, 28595475, 28595485, 28595497, 28595501, 28595502, 28595512, 28595517, 28595519, 28595516, 28595518, 28595519, 28595496, 28595516, 28595519, 28595517, 28595522, 28595521, 28595522, 28595524, 28595495, 28595525, 28595521, 28595525, 28595523, 28595501, 28595528, 28595522, 28595524, 28595528, 28595528, 28598082, 28595529, 28595530, 28595509, 28595526, 28595528, 28595529, 28595530, 28595531, 28595532, 28595529, 28595508, 28595533, 28595531, 28595534, 28595531, 28595535, 28595536, 28595527, 28595526, 28595534, 28595538, 28595540, 28595541, 28595536, 28595541, 28595543, 28595542, 28595543, 28595544, 28595531, 28595545, 28595548, 28595549, 28595541, 28595546, 28595549, 28595550, 28595551, 28595545, 28595552, 28595548, 28595551, 28595552, 28595553, 28595553, 28595548, 28595553, 28595554, 28595556, 28595554, 28595555, 28595556, 28595554, 28595555, 28595554, 28595556, 28595556, 28595557, 28595554, 28595555, 28595556, 28595557, 28595558, 28596796, 28595557, 28595558, 28595556, 28595557, 28595558, 28595558, 28595559, 28595560, 28595559, 28595559, 28595560, 28595560, 28595559, 28595560, 28595561, 28595560, 28595561, 28595561, 28595562, 28595562, 28595563, 28595567, 28595600, 28595600, 28596798, 28596800, 28596801, 28596802, 28596805, 28596818, 28596823, 28596835, 28596836, 28596841, 28596851, 28596858, 28596858, 28598075, 28598116, 28598130, 28598130, 29271234, 29271235, 29271235, 29271236, 29271240, 29271253, 32712172, 32712173, 40898123, 28596801, 28596805, 28595706, 28595704, 28595706, 28595707, 28595773, 28596907, 28596908, 28598036, 28598070, 28598038, 28598039, 28598040, 28598040, 28598041, 28598041, 28598043, 28598044, 28598044, 28598046, 28598048, 28598055, 28598056, 28598060, 28598062, 28598064, 28598068, 28598070, 28598071, 28598071, 28598072, 28598072, 28598073, 28598073, 28598074, 28598043, 28598052, 28598073, 28598074, 28598074, 28598041, 28598074, 28598075, 28598044, 28598075, 28598075, 28598076, 28598076, 28598047, 28598048, 28598050, 28598052, 28598073, 28598077, 28598077, 28598078, 28598052, 28598078, 28598078, 28598079, 28598080, 28598080, 28598082, 28598083, 28598087, 28598089, 28598085, 28598091, 28598095, 28598096, 28598097, 28598099, 28598103, 28598103, 28598103, 28598104, 28598105, 28598106, 28598107, 28598107, 28598107, 28598107, 28598108, 28598108, 28598111, 28598118, 28598123, 28598125, 28598127, 28598128, 28598129, 28598130, 28598131, 28598145, 28598146, 28598149, 28598149, 28598109, 28598110, 28598110, 28598111, 28598111, 28598112, 28598112, 28598113, 28598114, 28598114, 28598115, 28598116, 28598117, 28598118, 28598118, 28598119, 28598120, 28598120, 28598121, 28598121, 28598122, 28598123, 28598123, 28598124, 28598124, 28598126, 28598126, 28598127, 28598128, 28598128, 28598129, 28598129, 28598130, 28598130, 28598131, 28598131, 28598132, 28598132, 28598133, 28598134, 28598136, 28598137, 28598140, 28598142, 28598143, 28598145, 28598146, 28598147, 28598149, 28598149, 28598150, 28598110, 28598111, 28598111, 28598112, 28598114, 28598117, 28598119, 28598119, 28598121, 28598122, 28598123, 28598124, 28598124, 28598130, 28598131, 28598132, 28598132, 28598134, 28598146, 28598148, 28598149, 28598150, 28598111, 28598119, 28598125, 28598135, 28598150, 28598150, 28598122, 28598125, 28598125, 28598130, 28598151, 28598114, 28598117, 28598125, 28598126, 28598130, 28598137, 28598116, 28598122, 28598125, 28598126, 28598126, 28598133, 28598124, 28598126, 28598131, 28598132, 28598152, 28598146, 28598128, 28598133, 28598149, 28598126, 28598129, 28598130, 28598134, 28598154, 28598154, 28598134, 28598130, 28598139, 28598132, 28598132, 28598154, 28598158, 28598133, 28598138, 28598133, 28598134, 28598159, 28598135, 28598143, 28598134, 28598135, 28598135, 28598135, 28598136, 28598141, 28598161, 28598136, 28598136, 28598141, 28598144, 28598137, 28598139, 28598144, 28598138, 28598143, 28598138, 28598142, 28598143, 28598145, 28598150, 28598158, 28598160, 28598164, 28598139, 28598140, 28598141, 28598141, 28598142, 28598142, 28598143, 28598143, 28598144, 28598144, 28598145, 28598145, 28598146, 28598146, 28598147, 28598147, 28598149, 28598149, 28598150, 28598150, 28598151, 28598151, 28598152, 28598153, 28598153, 28598154, 28598155, 28598156, 28598158, 28598159, 28598160, 28598161, 28598161, 28598162, 28598162, 28598163, 28598164, 28598164, 28598165, 28598140, 28598141, 28598144, 28598145, 28598165, 28598145, 28598165, 28598142, 28598145, 28598145, 28598146, 28598151, 28598160, 28598163, 28598166, 28598145, 28598146, 28598147, 28598149, 28598152, 28598153, 28598164, 28598167, 28598167, 28598146, 28598163, 28598167, 28598148, 28598150, 28598151, 28598154, 28598168, 28598147, 28598148, 28598148, 28598149, 28598150, 28598151, 28598153, 28598154, 28598163, 28598164, 28598165, 28598167, 28598168, 28598148, 28598149, 28598149, 28598150, 28598150, 28598151, 28598151, 28598152, 28598153, 28598154, 28598159, 28598163, 28598164, 28598165, 28598168, 28598169, 28598169, 28598149, 28598150, 28598150, 28598151, 28598151, 28598152, 28598152, 28598154, 28598155, 28598156, 28598156, 28598157, 28598160, 28598165, 28598166, 28598169, 28598169, 28598150, 28598151, 28598151, 28598152, 28598152, 28598155, 28598156, 28598156, 28598166, 28598167, 28598170, 28598170, 32713466, 28598151, 28598152, 28598153, 28598154, 28598155, 28598156, 28598166, 28598167, 28598170, 28598171, 28598153, 28598153, 28598154, 28598155, 28598167, 28598170, 28598171, 28598153, 28598154, 28598156, 28598156, 28598158, 28598163, 28598165, 28598167, 28598171, 28598171, 28598154, 28598155, 28598156, 28598157, 28598157, 28598158, 28598159, 28598159, 28598163, 28598164, 28598167, 28598168, 28598168, 28598171, 28598172, 28598157, 28598157, 28598158, 28598158, 28598159, 28598159, 28598160, 28598162, 28598165, 28598166, 28598167, 28598168, 28598168, 28598170, 28598171, 28598172, 28598172, 28598173, 28598158, 28598159, 28598173, 28598159, 28598163, 28598167, 28598169, 28598173, 28598170, 28598159, 28598168, 28598169, 28598170, 28598172, 28598174, 28598160, 28598161, 28598161, 28598162, 28598162, 28598169, 28598171, 28598172, 28598172, 28598174, 28598174, 28598175, 28598161, 28598162, 28598168, 28598168, 28598171, 28598172, 28598175, 28598175, 28598162, 28598163, 28598163, 28598172, 28598175, 28598176, 28598163, 28598165, 28598171, 28598172, 28598174, 28598176, 28598176, 28598165, 28598166, 28598171, 28598172, 28598173, 28598173, 28598176, 28598177, 28598173, 28598177, 28598177, 28598178, 28598174, 28598178, 28598176, 28598179, 28598175, 28598180, 28598176, 28598179, 28598181, 28598181, 28598178, 28598182, 28598182, 28598181, 28598183, 28598183, 28598177, 28598183, 28598180, 28598184, 28598184, 28598179, 28598184, 28598184, 28598185, 28598185, 28598181, 28598185, 28598183, 28598183, 28598184, 28598184, 28598185, 28598186, 29272565, 28598186, 28598186, 28598187, 28598185, 28598186, 28598187, 28598185, 28598187, 28598222, 28598187, 28598188, 28598188, 28598189, 28598189, 28598190, 28598224, 28599388, 28598190, 28598191, 28598191, 28598192, 28598192, 28598193, 28598194, 28598195, 28598196, 28598196, 28598197, 28598197, 28598198, 28598198, 28598204, 28598205, 28598207, 28598208, 28598210, 28598215, 28598215, 28598218, 28598219, 28598221, 28598222, 28598222, 28598223, 28598223, 28598224, 28598224, 28598225, 28599388, 28599429, 28599432, 28599438, 28599443, 28893661, 29272549, 29272564, 29272566, 29272566, 29272569, 31447746, 32179243, 32713486, 28598191, 28598192, 28598192, 28598193, 28598193, 28598194, 28598195, 28598196, 28598196, 28598197, 28598200, 28598201, 28598203, 28598204, 28598217, 28598220, 28598221, 28598222, 28598222, 28598223, 28598223, 28598224, 28598224, 28598225, 28598225, 28598192, 28598194, 28598195, 28598195, 28598223, 28598226, 28598226, 28598196, 28598198, 28598201, 28598226, 28598227, 29272557, 28598197, 28598199, 28598227, 28598228, 28598197, 28598228, 28598219, 28598229, 28598212, 28598228, 28598229, 28599393, 28598204, 28598230, 28598227, 28598229, 28598207, 28598221, 28598231, 28599394, 28598229, 28598231, 28598231, 28598232, 28598232, 28598233, 28598233, 28598233, 28598234, 28598235, 28598235, 28598236, 28598238, 28598239, 28598240, 28598241, 28598243, 28598245, 28598250, 28598250, 28598251, 28598253, 28598254, 28598255, 28598256, 28598256, 28598257, 28598257, 28598258, 28598258, 28598259, 28599422, 28598259, 28598260, 28598261, 28599423, 28599423, 28599464, 28599474, 28599475, 28599476, 28599476, 28599478, 28754922, 28985833, 29272582, 29272583, 29272583, 29272584, 29272587, 29272590, 29272593, 29272598, 29272598, 29272599, 29272600, 29272601, 29272604, 29281458, 30173848, 30173850, 32179278, 32456566, 32713520, 32713521, 35142721, 40899472, 28599424, 28599424, 28600586, 28600587, 28600588, 28600588, 28600590, 28600598, 28600619, 28600621, 28600622, 28600622, 28600625, 28600626, 28600627, 28600627, 28600628, 28600662, 28600627, 28600628, 28600628, 28600628, 28600629, 28600631, 28600631, 28600639, 28600660, 28600662, 28600663, 28600663, 28600666, 28600666, 28600667, 28600667, 28600667, 28600668, 28600668, 28600703, 28600669, 28600670, 28600670, 28600671, 28600671, 28600672, 28600672, 28600673, 28600674, 28600675, 28600675, 28600676, 28600676, 28600677, 28600677, 28600678, 28600678, 28600679, 28600679, 28600680, 28600680, 28600681, 28600681, 28600682, 28600682, 28600683, 28600683, 28600684, 28600684, 28600686, 28600686, 28600687, 28600688, 28600688, 28600690, 28600691, 28600692, 28600693, 28600695, 28600696, 28600697, 28600700, 28600701, 28600701, 28600702, 28600703, 28600703, 28600672, 28600673, 28600703, 28600704, 28600679, 28600684, 28600680, 28600680, 28600705, 28600675, 28600675, 28600675, 28600678, 28600682, 28600683, 28600683, 28600687, 28600706, 28600680, 28600681, 28600691, 28600694, 28600681, 28600707, 28600681, 28600683, 28600685, 28600707, 28600682, 28600682, 28600700, 28600708, 28600684, 28600685, 28600685, 28600702, 28600702, 28600711, 28600686, 28600688, 28600711, 28600686, 28600687, 28600687, 28600688, 28600688, 28600689, 28600689, 28600690, 28600691, 28600691, 28600694, 28600696, 28600702, 28600703, 28600704, 28600705, 28600709, 28600712, 28600687, 28600690, 28600691, 28600700, 28600704, 28600705, 28600706, 28600712, 28600688, 28600689, 28600689, 28600690, 28600690, 28600691, 28600692, 28600700, 28600701, 28600702, 28600703, 28600704, 28600705, 28600706, 28600706, 28600710, 28600711, 28600713, 28600689, 28600690, 28600691, 28600691, 28600692, 28600693, 28600696, 28600698, 28600702, 28600702, 28600703, 28600705, 28600705, 28600709, 28600711, 28600713, 28600713, 28600690, 28600692, 28600692, 28600698, 28600701, 28600705, 28600706, 28600707, 28600711, 28600714, 28600691, 28600692, 28600694, 28600699, 28600701, 28600703, 28600703, 28600705, 28600706, 28600707, 28600712, 28600714, 28600692, 28600693, 28600702, 28600703, 28600704, 28600707, 28600709, 28600710, 28600713, 28600715, 28600694, 28600694, 28600695, 28600698, 28600700, 28600702, 28600703, 28600704, 28600704, 28600705, 28600706, 28600707, 28600707, 28600713, 28600715, 28600697, 28600704, 28600705, 28600709, 28600716, 28600696, 28600699, 28600703, 28600705, 28600715, 28600716, 28600696, 28600704, 28600708, 28600717, 28600697, 28600700, 28600700, 28600702, 28600703, 28600705, 28600706, 28600710, 28600717, 28600718, 28600706, 28600708, 28600709, 28600718, 28600718, 28600702, 28600711, 28600719, 28600711, 28600707, 28600703, 28600705, 28600709, 28600720, 28600705, 28600706, 28600710, 28600717, 28600719, 28600720, 28600721, 32180500, 28600722, 28600715, 28600722, 28600716, 28600723, 28600723, 28600714, 28600717, 28600725, 28600714, 28600717, 28600725, 29273809, 28600716, 28600717, 28600718, 28600720, 28600726, 28600719, 28600727, 28600719, 28600720, 28600721, 28600727, 28600720, 28600726, 28600728, 28600725, 28600729, 28600721, 28600722, 28600727, 28600727, 28600729, 28600722, 28600723, 28600726, 28600729, 28600730, 28600730, 28600726, 28600729, 28600730, 28600731, 28600731, 28600732, 29273817, 28600733, 28600733, 28600734, 28600734, 28600735, 28600735, 32714758, 28600735, 28600736, 28600736, 28600737, 28600737, 28600738, 28600739, 28600739, 28600740, 28600741, 28600741, 28600742, 28600743, 28600744, 28600744, 28600745, 28600745, 28600746, 28600747, 28600749, 28600751, 28600752, 28600753, 28600755, 28600757, 28600758, 28600760, 28600762, 28600767, 28600770, 28600773, 28600775, 28600775, 28600776, 28600776, 28600777, 28600777, 28600778, 28600778, 28600779, 29273820, 29273821, 29273822, 29273822, 29273823, 29273823, 29273841, 29273843, 29273843, 29273845, 29282698, 30028615, 30175087, 31469836, 32180518, 32259696, 32714760, 40900711, 28600739, 28600740, 28600741, 28600746, 28600748, 28600749, 28600750, 28600752, 28600763, 28600773, 28600777, 28600778, 28600778, 28600779, 28600779, 32695910, 28600780, 28600780, 28756163, 28600745, 28600773, 28600781, 28600781, 28600782, 28600783, 28600784, 28600785, 28600785, 28600786, 28600785, 28600786, 28600764, 28600787, 28600760, 28600776, 28600786, 28600790, 28600790, 28600792, 28600776, 28600793, 28600768, 28600794, 28600796, 28600797, 28600798, 28600799, 28600801, 28600803, 28600804, 28600807, 28600808, 28600810, 28600811, 28600814, 29273859, 28600816, 28600817, 28600817, 28600818, 28600818, 28600819, 32714799, 28600819, 28600820, 28634386, 28636154, 28704207, 28745364, 28756202, 28786793, 28830440, 28894116, 28894975, 28904684, 28977629, 29015781, 29016605, 29273860, 29273861, 29273861, 29273862, 29273862, 29273863, 29273863, 29273864, 29273864, 29273865, 29273865, 29273866, 29273867, 29273867, 29273868, 29273869, 29273869, 29273870, 29273871, 29273873, 29273879, 29273879, 29273881, 29273882, 29273882, 29273883, 29273883, 29273884, 29273884, 29273885, 29273885, 29273886, 29273886, 29273887, 29273891, 29282737, 29282738, 29282739, 29282740, 29338960, 29394356, 29483639, 29489894, 29499346, 30030487, 30175127, 30175128, 30175130, 30175130, 30175132, 31068971, 31332930, 31469876, 32180535, 32180537, 32180546, 32180557, 32180558, 32442611, 32714800, 32714801, 34464370, 35105041, 35144018, 29273863, 29273864, 29273874, 28667969, 29307448, 28671499, 30210472, 28807606, 29377261, 28889924, 29418426, 28911598, 28911599, 29429256, 29429257, 29429258, 29429259, 29429259, 29429262, 29429263, 28972779, 29459869, 29060081, 29060157, 29060228, 29503575, 29187463, 29567210, 29189145, 29189146, 29568033, 29568033, 29208558, 29577738, 29354453, 29650686, 29650691, 29373418, 29660168, 29430755, 29430833, 29688837, 29430909, 29688913, 29432424, 29689683, 29946902, 29946903, 29946904, 29946903, 29946905, 29946919, 29946904, 29946905, 29946906, 29946904, 29946905, 29946905, 29946906, 29946906, 29946907, 29946909, 29946911, 29946918, 29946919, 29946922, 29946924, 29946905, 29946906, 29946906, 29946907, 29946907, 29946909, 29946910, 29946911, 29946911, 29946917, 29946919, 29946920, 29946920, 29946921, 29946922, 29946923, 29946923, 29946924, 29946924, 29946906, 29946907, 29946907, 29946908, 29946910, 29946911, 29946913, 29946914, 29946920, 29946920, 29946921, 29946921, 29946922, 29946922, 29946923, 29946923, 29946924, 29946924, 29946925, 29946928, 29946907, 29946908, 29946908, 29946910, 29946910, 29946912, 29946912, 29946913, 29946918, 29946920, 29946921, 29946922, 29946922, 29946923, 29946923, 29946924, 29946924, 29946925, 29946925, 29946908, 29946909, 29946909, 29946910, 29946911, 29946912, 29946913, 29946914, 29946914, 29946920, 29946920, 29946921, 29946921, 29946922, 29946922, 29946923, 29946923, 29946924, 29946924, 29946925, 29946925, 29946926, 29946927, 29946931, 29946909, 29946911, 29946911, 29946913, 29946914, 29946915, 29946921, 29946922, 29946922, 29946923, 29946924, 29946924, 29946925, 29946925, 29946926, 29946928, 29946911, 29946912, 29946915, 29946915, 29946916, 29946922, 29946923, 29946925, 29946925, 29946926, 29946927, 29946931, 29946914, 29946923, 29946924, 29946928, 29946934, 29946913, 29946915, 29946916, 29946926, 29946915, 29946916, 29946916, 29946917, 29946917, 29946919, 29946923, 29946924, 29946925, 29946926, 29946926, 29946927, 29946927, 29946928, 29946928, 29946929, 29946931, 29946932, 29946932, 29946935, 29946948, 29946948, 29946949, 29946916, 29946916, 29946932, 29946929, 29946918, 29946918, 29946919, 29946926, 29946928, 29946929, 29946932, 29946932, 29946950, 29946919, 29946919, 29946926, 29946928, 29946929, 29946932, 29946933, 29946935, 29946950, 29946920, 29946928, 29946928, 29946929, 29946933, 29946935, 29946936, 29946920, 29946921, 29946921, 29946922, 29946924, 29946925, 29946926, 29946926, 29946927, 29946928, 29946928, 29946929, 29946929, 29946930, 29946930, 29946931, 29946931, 29946936, 29946951, 29946921, 29946924, 29946927, 29946928, 29946929, 29946931, 29946935, 29946952, 29946927, 29946930, 29946932, 29946952, 29946930, 29946931, 29946934, 29946933, 29946955, 29946928, 29946931, 29946955, 29946933, 29946934, 29946936, 30848183, 29946937, 29946938, 29946936, 29946938, 29946934, 29946934, 29946935, 29946936, 29946936, 29946937, 29946937, 29946938, 29946940, 29946940, 29946942, 29946935, 29946936, 29946937, 29955795, 30848185, 33387858, 29946935, 29946936, 29946936, 29946937, 29946937, 29946940, 29946942, 29946943, 29946936, 29946937, 29946937, 29946938, 29946938, 29946939, 29946939, 29946940, 29946943, 30848186, 29946937, 29946938, 29946938, 29946939, 29946939, 29946940, 29946941, 29946942, 29946943, 29946944, 30240280, 30564866, 30848186, 32142934, 33387859, 33387860, 29946938, 29946939, 29946939, 29946940, 29946940, 29946941, 29946942, 29946943, 29946944, 29946945, 29955797, 29955807, 30848187, 32853617, 33387859, 33387860, 29946939, 29946940, 29946940, 29946941, 29946942, 29946942, 29946943, 29946944, 29946944, 29946946, 29946946, 29946960, 29946961, 29955806, 30848187, 30848191, 32126777, 33387860, 33387861, 29946940, 29946941, 29946941, 29946942, 29946942, 29946943, 29946943, 29946944, 29946944, 29946945, 29946946, 29946947, 29946961, 29946961, 29955798, 29955799, 30848188, 31784436, 32142936, 32853618, 32853619, 33387860, 33387861, 29946941, 29946942, 29946942, 29946943, 29946943, 29946944, 29946944, 29946945, 29946946, 29946946, 29946947, 29946947, 29946948, 29946961, 29946962, 29946962, 30012020, 30067413, 30848188, 31618223, 32122665, 32853617, 32853618, 32853619, 33115673, 33387862, 29946942, 29946943, 29946943, 29946944, 29946945, 29946946, 29946946, 29946947, 29946947, 29946962, 29946963, 30012021, 30848189, 30848193, 33387861, 33387862, 29946943, 29946944, 29946944, 29946945, 29946945, 29946946, 29946947, 29946948, 29946948, 29946949, 29946950, 29946955, 29946963, 29946963, 30067418, 30848189, 32122120, 33387863, 29946944, 29946945, 29946945, 29946946, 29946946, 29946947, 29946947, 29946948, 29946963, 29946963, 30848189, 30848190, 32853621, 33387862, 33387863, 38075674, 29946945, 29946946, 29946946, 29946947, 29946947, 29946948, 29946948, 29946949, 29946950, 29946964, 29946964, 30848190, 30848194, 29946946, 29946947, 29946947, 29946948, 29946949, 29946950, 29946956, 29946964, 29946964, 29946965, 30848191, 33387864, 29946947, 29946948, 29946948, 29946949, 29946949, 29946950, 29946950, 29946952, 29946964, 29946965, 29946965, 30565320, 30848191, 31820867, 29946948, 29946949, 29946949, 29946950, 29946950, 29946951, 29946951, 29946953, 29946965, 29946965, 29946966, 29946967, 30848192, 29946949, 29946950, 29946950, 29946951, 29946951, 29946952, 29946965, 29946966, 29946966, 29946950, 29946951, 29946951, 29946952, 29946954, 29946954, 29946966, 29946966, 29946967, 30848193, 29946951, 29946952, 29946952, 29946965, 29946966, 29946967, 29946967, 29946952, 29946965, 29946967, 29946967, 29946968, 33387866, 29946953, 29946954, 29946954, 29946955, 29946956, 29946963, 29946967, 29946967, 29946968, 29946968, 29946954, 29946955, 29946966, 29946968, 29946968, 29946969, 30848195, 33387867, 29946968, 29946969, 29946969, 29946969, 29946970, 29946970, 29946970, 29946971, 33387869, 29946970, 29946971, 29946972, 29946974, 29946975, 29946975, 29946978, 29946981, 33387880, 29946982, 29946982, 29946983, 30067437, 31784456, 33387881, 33387882, 35137451, 29946983, 29946984, 29946984, 29955819, 29955820, 29955820, 29955825, 29955831, 29975327, 30012041, 30067433, 30848208, 30848209, 30848209, 30848211, 30848212, 31110263, 31260546, 31579454, 31618247, 31784457, 31784458, 32416540, 32853636, 32853637, 32853638, 32853639, 32853639, 32853640, 33352290, 33387882, 33387883, 29946984, 29946985, 29955817, 29955819, 29955819, 29955820, 29955820, 29955821, 29955822, 29955822, 29955823, 29955824, 29955829, 29955830, 29958280, 29981429, 30012042, 30031275, 30067436, 30162976, 30202130, 30347865, 30577783, 30593460, 30685013, 30710119, 30848208, 30848209, 30848209, 30848210, 30848210, 30848211, 30848212, 30848212, 30848213, 30848213, 30848214, 31077862, 31486117, 31742053, 32045539, 32102233, 32126799, 32356483, 32356485, 32438151, 32853617, 32853619, 32853620, 32853620, 32853630, 32853633, 32853634, 32853636, 32853637, 32853637, 32853638, 32853639, 32853639, 32853640, 32853640, 32853641, 32853642, 33130928, 33387882, 33387883, 33387883, 29946985, 29955819, 29955820, 29955821, 29955821, 30067438, 30848210, 30848214, 32122142, 32206175, 32853634, 32853638, 33387883, 29955821, 30090639, 30569568, 30848210, 30848211, 30848212, 31486118, 31618247, 32122142, 32853640, 33387883, 29964672, 29964656, 29964674, 29964656, 29964673, 29964674, 29964671, 29964672, 29964672, 29964673, 29964674, 29964675, 29964657, 29964672, 29964672, 29964673, 29964673, 29964674, 29964674, 29964675, 29964675, 29964678, 29964663, 29964673, 29964674, 29964674, 29964675, 29964675, 29964676, 29964677, 29964683, 29964684, 29964684, 29964685, 29964686, 29964687, 29964682, 29964690, 29964691, 29964692, 29964694, 29964694, 29964690, 30857066, 32862493, 30857062, 32124649, 29964689, 30076288, 30857061, 30857062, 30857066, 32862492, 33396735, 33396736, 31046608, 32862491, 32862494, 33396735, 29964694, 30857063, 32135653, 32862493, 32862494, 32862494, 33396736, 30857063, 30857064, 30857066, 32862489, 33370017, 33396736, 33396737, 30857064, 31793309, 33396737, 30857064, 30857065, 33396737, 32862492, 29964701, 30857066, 33396738, 33396739, 33396739, 30857070, 30857073, 30857071, 30857071, 31793317, 32124658, 33396744, 30010131, 32862500, 33396744, 33396745, 32862482, 30857073, 29969589, 31629557, 30003682, 30876564, 30015886, 30882667, 30055556, 30055572, 30055590, 30739319, 30077109, 30077110, 30077112, 30077113, 30077236, 30077236, 32918708, 33452953, 30913281, 30077362, 30077363, 30913404, 32918831, 32918835, 30115575, 30932511, 30187899, 30187905, 30187902, 30187890, 30187907, 30187905, 30187908, 30187911, 30968674, 30187921, 30968676, 30968679, 30968684, 33177276, 33508352, 33508353, 30968681, 30234303, 30578240, 30366468, 30366528, 30366587, 33597689, 30378984, 31064217, 31064219, 30397883, 33613338, 30457303, 32039631, 30533646, 31658455, 30748757, 31111011, 31978896, 30922177, 31335812, 31182857, 31182932, 31182947, 31183004, 31466247, 31183704, 31466575, 31192171, 31470816, 31208607, 31208737, 31208853, 34018822, 31239953, 33500130, 31423055, 31423056, 32853840, 34125924, 31456502, 31456513, 34142648, 31460169, 34144482, 31473266, 31473267, 31611360, 34151030, 31749434, 31749434, 31749438, 31749448, 31749450, 31749434, 31749435, 31749439, 31749439, 31749449, 31749452, 31749453, 31749454, 31749435, 31749436, 31749451, 31749451, 31749452, 31749453, 31749453, 31749454, 31749455, 31749436, 31749437, 31749438, 31749439, 31749440, 31749450, 31749451, 31749451, 31749452, 31749452, 31749453, 31749453, 31749454, 31749454, 31749455, 31749455, 31749456, 31749438, 31749454, 31749455, 31749455, 31749441, 31749440, 31749452, 31749453, 31749454, 31749457, 31749441, 31749457, 31749458, 31749442, 31749453, 31749454, 31749455, 31749458, 31749458, 31749460, 31749454, 31749459, 31749444, 31749455, 31749455, 31749457, 31749458, 31749459, 31749460, 31749457, 31749460, 31749461, 34016935, 31749467, 31749468, 34289123, 31749466, 31749468, 31749468, 31749469, 31749469, 31749470, 31749471, 31979103, 32685698, 32946783, 33023384, 33044199, 33107416, 33754878, 33754881, 33951592, 34289123, 34289124, 31749467, 31749469, 31749469, 31749471, 32519487, 32555492, 32685700, 33023384, 33754862, 33754882, 34289124, 34289125, 31749469, 31749470, 31749470, 33754878, 33754882, 34289124, 34289125, 34672251, 31749469, 31749470, 31749471, 31749472, 32685698, 33754864, 31749470, 31749471, 31749472, 31749472, 33754859, 33754882, 34289125, 34289126, 31749471, 31749472, 31749472, 31749473, 31749473, 32198290, 32643297, 32657869, 33754861, 33754863, 33754865, 33754880, 33754883, 33754884, 33834060, 34289126, 34289127, 31749473, 31749473, 31749474, 32685701, 33754869, 33754873, 33754878, 33754879, 33754880, 33754884, 33754886, 34289126, 34289126, 34289127, 31749473, 31749474, 31785216, 32224440, 32643297, 32643298, 32685699, 32685702, 33044202, 33339395, 33754862, 33754864, 33754865, 33754882, 33754883, 33754884, 33834060, 34289127, 34289128, 31749474, 33004115, 33754885, 34289127, 34289128, 31749475, 31749476, 31755760, 31785209, 31979108, 32387362, 32387363, 32435720, 32519491, 32685703, 32685703, 32685704, 32685705, 33029592, 33044203, 33754862, 33754863, 33754864, 33754864, 33754865, 33754865, 33754867, 33754871, 33754876, 33754881, 33754882, 33754882, 33754883, 33754883, 33754884, 33754884, 33754885, 33754886, 33754886, 34016940, 34016940, 34289128, 34289129, 33257729, 33754866, 33754883, 33754885, 33754885, 33754886, 33834062, 34289128, 34289129, 33339397, 33754885, 32685704, 31762062, 34295429, 31820959, 31820971, 34324877, 32721457, 32128546, 32152082, 32175618, 34502209, 32208753, 33246686, 33984531, 34518773, 32273567, 32273618, 34016969, 32574125, 33098038, 32647183, 32678359, 32699420, 34764107, 32709537, 32999560, 32783247, 32783294, 32783365, 34090627, 33025265, 33025265, 33025264, 33025266, 34392788, 34392787, 34927031, 33121979, 34441142, 33209035, 33249279, 33211934, 34486116, 33289521, 33289522, 33289522, 33289523, 33289523, 33289523, 33289524, 33455732, 34524916, 34524895, 34524915, 34524916, 35059159, 33361527, 35095159, 33537134, 33537135, 33537135, 34648724, 34727899, 35182964, 35182965, 33566279, 34663291, 33621941, 33621941, 33621943, 33621944, 33621945, 33621946, 33621946, 33621948, 33621945, 33621947, 33621946, 33621946, 33621948, 33621948, 33621948, 33621952, 34691114, 35225370, 34691124, 34691126, 34691127, 35225371, 34691127, 33926988, 34043663, 34691108, 35225371, 34691129, 35225371, 35225372, 34691129, 34193975, 34691126, 33694800, 34727553, 34065053, 35446924, 34144111, 34144113, 34952211, 35486454, 34232025, 34232151, 34232276, 35530534, 34257495, 35543144, 34258766, 35543778, 34284623, 34284624, 34284624, 34284625, 35022446, 35284521, 35556709, 35556710, 34297314, 34297314, 34297316, 34297317, 34297317, 35028812, 34769280, 35028814, 35563057, 34298440, 34298511, 34298606, 35563730, 34306627, 34306627, 35033467, 35033468, 35567710, 34309722, 35035016, 34338943, 34338932, 34338943, 34338944, 34338944, 34338944, 35049624, 35583869, 35258989, 34465377, 35112843, 35146033, 35192019, 34765994, 34765998, 34766001, 34766001, 35797393, 35797397, 35797398, 35263153, 34886108, 35323208, 34929333, 34929334, 35344799, 35344822, 35344818, 35241243, 36035020, 35397878, 35397951, 35398028, 35579173, 35760287, 35760266, 35760253, 35760266, 35760269, 35760270, 35760271, 35760272, 35760270, 35760285, 35760287, 35760255, 35760266, 35760269, 35760271, 35760271, 35760272, 35760276, 35760290, 35760291, 35760271, 35760274, 35760274, 35760276, 35760291, 35760270, 35760291, 35760292, 35760278, 35760292, 35760297, 35760278, 35760285, 35760299, 35760301, 35760302, 35760287, 35760287, 35760286, 35969651, 35760284, 35760305, 35760287, 35760290, 35760286, 35760289, 35760290, 35760289, 35760291, 35760291, 35760306, 35760291, 35760292, 35760306, 35760307, 35760308, 35760289, 35760289, 35760291, 35760291, 35760293, 35760307, 35760291, 35760292, 35760293, 35760308, 35760291, 35760292, 35760292, 35760293, 35760293, 35760308, 35760308, 36294536, 35760291, 35760294, 35760294, 35760298, 35760308, 35760308, 35760309, 35760309, 35760310, 36294536, 35760294, 35760294, 35760295, 35760308, 35760309, 35760309, 35760310, 35760293, 35760295, 35760309, 35760310, 35760310, 35760295, 35760295, 35760310, 35760310, 35760311, 35760311, 35760312, 36294538, 35760296, 35760310, 35760311, 35760311, 35760312, 35760296, 35760297, 35760310, 35760311, 35760311, 35760312, 35760312, 35760313, 35760297, 35760298, 35760311, 35760311, 35760312, 35760312, 35760313, 35760311, 35760312, 35760312, 35760313, 35760314, 35760311, 35760313, 35760314, 35760312, 35760315, 35760315, 35760315, 36294550, 36294551, 35760449, 35760450, 35760325, 35760326, 35760326, 35760327, 36294553, 36294554, 42374436, 35760326, 35760327, 35760327, 35760328, 36294553, 36294554, 35760327, 35760328, 35760328, 35769259, 35839488, 35878333, 35986211, 36022364, 36022367, 36122254, 36275704, 36294554, 36294555, 36619031, 36677681, 37375553, 38044123, 35760328, 35760329, 35839485, 36022367, 36022368, 36294554, 36294555, 36677680, 35760329, 35839487, 35839489, 36294555, 36294556, 36294555, 36294556, 36294556, 35760584, 35760585, 36294689, 35778201, 35778274, 35778345, 36303567, 35826750, 36327802, 35918658, 35918658, 35918661, 35918661, 35918662, 35918662, 35918667, 36373726, 36373727, 36373728, 36373728, 36373731, 35996358, 36412578, 36153743, 36491275, 36166645, 36497721, 36179033, 36503913, 36503914, 36212108, 36248263, 36284416, 36284417, 36284419, 36284406, 36284418, 36284420, 36284419, 36284419, 36284421, 36284420, 36556606, 36556607, 36305421, 36313951, 36556606, 36556607, 36556608, 36314881, 36314891, 36315091, 36315091, 36315291, 36315302, 36572048, 36326423, 36577608, 36343483, 36586138, 36484196, 36656497, 36757609, 36793202, 36775357, 36802076, 36791092, 36809942, 36809943, 36828780, 36828781, 36828782, 36828796, 36828797, 36828801, 36828782, 36828783, 36828784, 36828784, 36828785, 36828785, 36828792, 36828793, 36828794, 36828795, 36828795, 36828796, 36828796, 36828797, 36828797, 36828798, 36828798, 36828799, 36828799, 36828800, 36828800, 36828801, 36828801, 36828802, 36828802, 36828803, 36828803, 36828804, 36828806, 36828806, 36828813, 36828795, 36828796, 36828796, 36828797, 36828797, 36828798, 36828798, 36828799, 36828799, 36828800, 36828800, 36828801, 36828801, 36828802, 36828803, 36828804, 36828805, 36828792, 36828799, 36828800, 36828798, 36828797, 36828797, 36828798, 36828799, 36828799, 36828804, 36828815, 36828805, 36828805, 36828813, 36828806, 36828807, 36828807, 36828808, 36828809, 36828810, 36828807, 36828808, 36828808, 36828809, 36828809, 36828810, 36828810, 36828813, 36828808, 36828809, 36828809, 36828810, 36828810, 36828811, 36828809, 36828810, 36828810, 36828811, 36828811, 36828812, 36828813, 36828810, 36828811, 36828811, 36828812, 36828812, 36828811, 36828812, 36828812, 36828813, 36828813, 36828814, 36828815, 36828812, 36828813, 36828813, 36828814, 36828814, 36828817, 36828823, 36828813, 36828814, 36828814, 36828815, 36828815, 36828816, 36828817, 45014748, 36828814, 36828815, 36828815, 36828816, 36828816, 36828817, 36828817, 36828818, 38288940, 36828815, 36828816, 36828816, 36828817, 36828818, 36828818, 36828822, 36945393, 38636442, 39258018, 36828816, 36828817, 36828817, 36828818, 36828818, 36828829, 36828830, 36828817, 36828818, 36828818, 36828819, 36828819, 36828820, 36828820, 36828821, 36828830, 36828833, 37909798, 45014750, 36828818, 36828819, 36828819, 36828820, 36828820, 36828821, 36828821, 36828822, 36828823, 36828824, 36828825, 37211925, 37909798, 38288942, 38578369, 38578370, 38578373, 39258017, 45014751, 36828819, 36828820, 36828820, 36828821, 36828821, 36828822, 36828822, 36828823, 36828824, 36828824, 36828825, 36828825, 36828831, 36828833, 36828834, 36828834, 36828835, 37153321, 37211925, 37211926, 37211926, 37211930, 37909799, 38288941, 38288944, 38578369, 38578370, 38578370, 38578372, 38578374, 39644791, 36828820, 36828821, 36828821, 36828822, 36828822, 36828823, 36828823, 36828824, 36828824, 36828825, 36828830, 36828832, 36828834, 36828835, 37044064, 37097152, 37153329, 37211925, 37211926, 37211926, 37211927, 37211927, 37211928, 37211929, 37211931, 37211933, 37909797, 37909798, 37909799, 38288942, 38288942, 38288943, 38288944, 38578370, 38578373, 38578374, 38578376, 39258013, 45014752, 36828821, 36828822, 36828822, 36828823, 36828823, 36828824, 36828824, 36828825, 36828826, 36828826, 36828827, 36828834, 36828835, 36945396, 37153291, 37153328, 37211926, 37211927, 37211927, 37211928, 37211930, 37754792, 37909799, 37909803, 38288943, 38288944, 38288949, 38578369, 38578373, 39258025, 36828822, 36828823, 36828823, 36828824, 36828824, 36828825, 36828825, 36828826, 36828827, 36828828, 36828828, 36828830, 36828833, 36828835, 37153325, 37153329, 37211926, 37211927, 37211928, 37754792, 37909799, 37909800, 38174323, 38288945, 38578371, 38578371, 38578373, 38578374, 39972515, 45014753, 36828823, 36828824, 36828824, 36828825, 36828825, 36828826, 36828826, 36828829, 36828835, 36828836, 36828836, 36828837, 36828838, 36979251, 37009136, 37097155, 37150617, 37153309, 37153333, 37211925, 37211927, 37211928, 37211928, 37211929, 37211929, 37211930, 37538452, 37909799, 37909800, 37909801, 38288943, 38288945, 38288945, 38578370, 38578371, 38578372, 38578376, 45014753, 36828824, 36828825, 36828825, 36828826, 36828826, 36828827, 36828827, 36828828, 36828828, 36828829, 36828830, 36828832, 36828833, 36828833, 36828835, 36828836, 36828836, 36828837, 36828838, 37153330, 37153333, 37211927, 37211927, 37211928, 37211928, 37211929, 37211929, 37211930, 37211930, 37211933, 37909800, 37909801, 37909801, 38288944, 38288945, 38288946, 38502631, 38578374, 38578375, 42908687, 36828825, 36828826, 36828826, 36828827, 36828827, 36828828, 36828829, 36828832, 36828833, 36828834, 36828834, 36828837, 37211928, 37211928, 37211929, 37211929, 37211930, 37211930, 37211933, 37909800, 37909802, 37909803, 38288945, 38578376, 38578378, 45014754, 36828826, 36828827, 36828827, 36828828, 36828828, 36828829, 36828830, 36828832, 36828832, 36828834, 36828837, 36828838, 36828839, 36999449, 37009138, 37044069, 37153300, 37211928, 37211928, 37211929, 37211930, 37211930, 37211932, 37211932, 37211933, 37211933, 37211934, 37211934, 37909802, 37909805, 38288947, 38288947, 38578373, 36828827, 36828828, 36828828, 36828829, 36828830, 36828830, 36828831, 36828831, 36828832, 36828834, 36828835, 36828835, 36828837, 36828838, 36828839, 36945399, 37153334, 37153335, 37211929, 37211930, 37211930, 37211931, 37211933, 37211934, 37909803, 38288949, 36828828, 36828829, 36828829, 36828830, 36828830, 36828831, 36828831, 36828832, 36828833, 36828834, 36828836, 36828839, 36828839, 36828840, 36917165, 37153331, 37211929, 37211930, 37211934, 37211935, 37211936, 37909803, 38288949, 36828829, 36828830, 36828830, 36828831, 36828831, 36828832, 36828832, 36828833, 36828833, 36828835, 36828835, 36828836, 36828836, 36828839, 36828840, 37211930, 37211931, 37211932, 37211932, 37211933, 37211933, 37211936, 37918787, 38288947, 38578373, 39258022, 36828830, 36828831, 36828831, 36828832, 36828833, 36828833, 36828834, 36828835, 36828836, 36828837, 36828837, 36828838, 36828839, 36828840, 36828842, 37153341, 37211930, 37211931, 37211931, 37211932, 37211932, 37211933, 37211934, 37909804, 38288950, 38578374, 36828831, 36828832, 36828832, 36828833, 36828833, 36828834, 36828834, 36828835, 36828836, 36828836, 36828837, 36828837, 36828838, 36828840, 36828840, 36828842, 37211931, 37211932, 37211932, 37211933, 37211937, 37909805, 38288950, 38578374, 41820632, 36828832, 36828833, 36828833, 36828834, 36828837, 36828837, 36828839, 36828840, 36828842, 37153329, 37211931, 37211932, 37211932, 37211933, 37211933, 37909804, 37909805, 36828833, 36828834, 36828834, 36828835, 36828836, 36828837, 36828838, 36828838, 36828840, 36828841, 36828842, 37211932, 37211933, 37211933, 37211934, 37211935, 37211938, 37804321, 37909802, 38288951, 36828834, 36828835, 36828837, 36828837, 36828838, 36828838, 36828839, 36828842, 37009141, 37009143, 37211936, 37211941, 38288946, 38502672, 36828835, 36828836, 36828837, 36828838, 36828838, 36828839, 36828839, 36828840, 37009143, 37193178, 37211934, 37211936, 36828836, 36828838, 36828838, 36828839, 36828840, 36828841, 36828842, 36828845, 37211934, 37211935, 37211935, 37211936, 36828837, 36828840, 36828840, 36828843, 37211935, 37211937, 37394084, 36828838, 36828840, 36828840, 36828841, 36828846, 37211934, 37211937, 38288952, 36828840, 36828841, 37211936, 37211938, 37211940, 38288954, 36828841, 36828842, 36828845, 37097161, 37211939, 37211940, 36828841, 36828842, 36828842, 36828844, 36828845, 37211936, 37211937, 37211937, 37211939, 37909810, 38288952, 36828842, 36828843, 36828845, 36828846, 37211937, 37211937, 37211938, 37909810, 38288952, 36828843, 36828845, 36828846, 36828846, 36828847, 37044079, 37097162, 37153339, 37211937, 37211937, 37211938, 37211938, 37211939, 37211939, 37211941, 37653328, 38288955, 36828844, 36828845, 36828845, 36828846, 36828846, 36828847, 36828849, 36829163, 36945407, 37211938, 37211938, 37211939, 37211940, 37211941, 37211941, 37909810, 37909811, 38578378, 38578382, 38578386, 38578387, 36828847, 36828849, 37211937, 37211938, 37211939, 37211939, 37211943, 37909812, 38288959, 36828847, 36828848, 36828851, 37009149, 37153317, 37153339, 37153349, 37211939, 37211940, 37211940, 37211941, 36828849, 36828851, 36945409, 37044078, 37211939, 37211940, 37211942, 37211943, 36828849, 36828851, 36828852, 37153324, 37153344, 37211940, 37211941, 37211941, 37211942, 37211942, 37211943, 37211943, 37211945, 37243371, 37909813, 37909814, 38288957, 38578384, 38578388, 45014766, 37097168, 37153347, 37153349, 37211940, 37211941, 37211941, 37211942, 37211944, 37909814, 38578384, 37211941, 37211942, 37211943, 37211945, 37531243, 38288954, 38288955, 36829252, 37211943, 37211945, 36945412, 37153344, 37211944, 37211945, 37909815, 37211943, 37211946, 37909816, 36985709, 37211943, 37211943, 37211944, 38288963, 37211945, 36829518, 36829594, 36829672, 36829682, 37212372, 37910246, 37005518, 37300284, 37061986, 37061986, 37061987, 37061987, 37269896, 37328517, 37328515, 37328517, 37328519, 37328522, 37129715, 37362392, 38439409, 37142577, 37310180, 37170084, 37382567, 37189461, 37189461, 37189462, 37189463, 37333630, 37392253, 37392254, 37392255, 38469270, 37259323, 37259324, 37259324, 37259325, 37427184, 37427186, 37427186, 37365503, 37365497, 37365502, 37365502, 37365504, 37480272, 37480275, 37480280, 37480278, 37480279, 37472422, 38610750, 37477808, 37477818, 37477819, 37477825, 37477830, 37477835, 37477833, 37477837, 37477840, 37477850, 37477847, 37477857, 37477852, 37477854, 37477857, 37477856, 37477859, 37477860, 37477858, 37477855, 37477856, 37477856, 37477864, 37477860, 37477864, 37477861, 37477866, 37477868, 37477868, 37536450, 37536451, 37536452, 37536450, 37536453, 38234326, 37536454, 37536454, 37536454, 38234327, 37536455, 37536459, 37536455, 38234328, 37536455, 37536456, 37536456, 37536458, 37536459, 37536457, 38234327, 37536456, 37536458, 37536463, 38613476, 37536459, 37536462, 38613477, 37557533, 37576290, 37595031, 37595043, 37595044, 37595030, 37595031, 37595045, 37595049, 37595031, 37595032, 37595032, 37595033, 37595033, 37595034, 37595046, 37595047, 37595048, 37595049, 37595032, 37595033, 37595033, 37595034, 37595035, 37595036, 37595037, 37595037, 37595038, 37595043, 37595046, 37595046, 37595047, 37595047, 37595048, 37595049, 37595050, 37595051, 37595052, 37595033, 37595034, 37595034, 37595035, 37595035, 37595036, 37595037, 37595037, 37595038, 37595048, 37595048, 37595049, 37595049, 37595050, 37595050, 37595052, 37595053, 37595034, 37595035, 37595035, 37595036, 37595036, 37595037, 37595037, 37595038, 37595038, 37595046, 37595047, 37595048, 37595049, 37595049, 37595050, 37595050, 37595051, 37595052, 37595035, 37595036, 37595036, 37595037, 37595037, 37595038, 37595038, 37595039, 37595048, 37595048, 37595049, 37595050, 37595050, 37595051, 37595051, 37595053, 37595036, 37595037, 37595037, 37595038, 37595038, 37595039, 37595049, 37595049, 37595050, 37595051, 37595053, 37595053, 37595037, 37595040, 37595042, 37595050, 37595050, 37595052, 37595054, 37595038, 37595039, 37595039, 37595040, 37595040, 37595041, 37595049, 37595049, 37595051, 37595051, 37595052, 37595052, 37595054, 37595055, 37595055, 37595056, 37595039, 37595040, 37595040, 37595050, 37595052, 37595052, 37595053, 37595054, 37595055, 37595056, 37595056, 37595040, 37595041, 37595041, 37595050, 37595051, 37595052, 37595053, 37595053, 37595056, 37595041, 37595042, 37595042, 37595052, 37595053, 37595053, 37595054, 37595055, 37595055, 37595056, 37595057, 37595057, 37595042, 37595043, 37595043, 37595044, 37595044, 37595048, 37595052, 37595052, 37595053, 37595053, 37595054, 37595054, 37595055, 37595055, 37595056, 37595056, 37595057, 37595057, 37595058, 37595043, 37595044, 37595046, 37595051, 37595052, 37595052, 37595053, 37595053, 37595054, 37595054, 37595055, 37595055, 37595056, 37595057, 37595057, 37595058, 37595053, 37595053, 37595054, 37595054, 37595055, 37595055, 37595056, 37595057, 37595057, 37595058, 37595058, 37595059, 37595054, 37595057, 37595047, 37595059, 37595059, 37595060, 37595061, 37595058, 37595064, 38292915, 38672061, 38961487, 38292918, 37595061, 37595062, 37595063, 38292920, 38961493, 37595063, 37595065, 37595066, 38292919, 38292920, 38292920, 38961490, 37595063, 37595064, 37595065, 38292920, 38672064, 38672065, 38961490, 37595063, 37595064, 37595066, 37595067, 37595067, 37595068, 38292920, 38292921, 38557444, 38672066, 38961493, 37595064, 37595065, 37595065, 37595066, 37595066, 37595067, 37595068, 37595068, 38292920, 38292921, 38292921, 38633805, 38672065, 38672066, 38672067, 37595065, 37595066, 37595066, 37595067, 37595068, 37595068, 37595069, 37994688, 38198922, 38292921, 38292921, 38292922, 38292925, 38672067, 38885836, 38961492, 38961492, 37595066, 37595067, 37595067, 37595068, 37595068, 37595069, 37595069, 37595070, 38137914, 38292920, 38292921, 38292921, 38292922, 38292923, 38292925, 38672063, 38672065, 38672066, 38672067, 38672068, 38672068, 38726384, 38961491, 38961493, 38961497, 40355639, 37595067, 37595068, 37595069, 37595069, 37595070, 38137914, 38194157, 38292922, 38292923, 38672065, 38672067, 38672067, 38961492, 38961493, 38961494, 38961497, 37595069, 37595069, 37595070, 37595070, 37595071, 38292919, 38292921, 38292923, 38292923, 38292924, 38292926, 38672065, 38672066, 38672067, 38672069, 38744170, 38961494, 38961494, 38961497, 37595069, 37595070, 37595070, 37595070, 37595071, 37595071, 38292925, 38672064, 38672070, 38961495, 37595071, 37595072, 37595072, 37724497, 38292922, 38292924, 38292925, 38292925, 38331462, 38672066, 38672069, 38672070, 38672070, 38726381, 38885706, 38961494, 38961495, 38961497, 38961498, 39641123, 37595072, 37998764, 38292920, 38292922, 38292922, 38292924, 38292925, 38672067, 38672069, 38672069, 38961496, 37595073, 37595074, 37821951, 37985932, 38014267, 38137917, 38137918, 38292921, 38292922, 38292923, 38292924, 38292925, 38292925, 38292926, 38292926, 38292927, 38292928, 38672066, 38672068, 38672069, 38672069, 38672070, 38672070, 38672071, 38672071, 38672072, 38672072, 38672073, 38885823, 38961494, 38961495, 38961495, 38961496, 38961497, 41095050, 37595075, 37927459, 37927462, 38137918, 38137919, 38194160, 38198930, 38207709, 38292919, 38292921, 38292923, 38292924, 38292925, 38292925, 38292926, 38292926, 38292927, 38292929, 38336815, 38659828, 38672067, 38672068, 38672069, 38672069, 38672070, 38672071, 38672071, 38961495, 38961496, 38961496, 38961497, 38961498, 38092455, 38292924, 38292926, 38961497, 38292927, 37657904, 38169339, 37853957, 39090954, 37959349, 38854215, 38048839, 38048908, 38048983, 38519887, 38233708, 38233814, 38233922, 38991533, 38248092, 39052902, 38259857, 38259859, 38259964, 38259964, 38260068, 38625426, 38625430, 38376804, 38683798, 38394323, 39071697, 38402466, 38839397, 38433476, 38712135, 38477828, 38734311, 38589851, 38790322, 38680775, 38680776, 38680777, 38680778, 38680778, 38680775, 38680778, 38835782, 39214926, 38835781, 38835782, 39504354, 39214929, 38835783, 38835785, 38835786, 38835787, 39504355, 38779821, 39264451, 38793257, 38793359, 39271163, 38793464, 38892127, 38802795, 38802798, 38896794, 39275940, 38820370, 38820463, 38820552, 38905672, 38990770, 38990773, 38990774, 38990789, 38990772, 38990775, 38990788, 38990791, 38990775, 38990776, 38990792, 38990776, 38990794, 38990774, 38990776, 38990791, 38990775, 38990776, 38990777, 38990778, 38990790, 38990791, 38990794, 38990796, 38990776, 38990777, 38990777, 38990778, 38990791, 38990792, 38990792, 38990793, 38990777, 38990778, 38990778, 38990779, 38990780, 38990781, 38990792, 38990792, 38990793, 38990793, 38990794, 38990794, 38990778, 38990779, 38990779, 38990781, 38990781, 38990791, 38990793, 38990793, 38990794, 38990794, 38990795, 38990779, 38990780, 38990780, 38990781, 38990781, 38990782, 38990792, 38990792, 38990793, 38990793, 38990794, 38990794, 38990795, 38990795, 38990796, 38990796, 38990798, 38990780, 38990781, 38990782, 38990794, 38990794, 38990795, 38990795, 38990796, 38990796, 38990781, 38990782, 38990783, 38990795, 38990795, 38990796, 38990796, 38990797, 38990783, 38990795, 38990796, 38990783, 38990796, 38990796, 38990797, 38990799, 38990784, 38990795, 38990797, 38990797, 38990799, 38990800, 38990787, 38990797, 38990797, 38990798, 38990799, 38990800, 38990800, 38990799, 38990800, 38990807, 38990808, 39369936, 39659368, 38990808, 38990808, 39369932, 39369936, 38990808, 38990809, 38990809, 39369940, 39659364, 38990808, 38990809, 38990809, 38990810, 39301049, 39369932, 39369935, 39369937, 39369937, 39369939, 39659364, 39659364, 38990809, 38990810, 38990810, 38990811, 38990811, 38990812, 38990812, 39331678, 39348175, 39369933, 39369934, 39369934, 39369935, 39369936, 39369936, 39369937, 39369937, 39369938, 39369938, 39369939, 39369939, 39369940, 39369940, 39369942, 39625568, 39659363, 39659364, 39659368, 38990810, 38990811, 38990811, 38990812, 38990812, 38990813, 39369934, 39369934, 39369935, 39369935, 39369936, 39369937, 39369937, 39369938, 39369938, 39369939, 39369940, 39369940, 39369941, 39583575, 39625568, 39659363, 39659364, 39659365, 39659366, 39659368, 42367186, 38990811, 38990812, 38990812, 38990813, 38990813, 39034684, 39133564, 39172744, 39255318, 39310913, 39369934, 39369935, 39369935, 39369936, 39369936, 39369937, 39369937, 39369938, 39369938, 39369939, 39369939, 39369940, 39369940, 39369941, 39369942, 39369944, 39583660, 39659363, 39659364, 39659364, 39659365, 39659365, 39659366, 39659366, 39659368, 38990812, 38990813, 38990813, 39255320, 39369935, 39369937, 39369937, 39369938, 39369939, 39369939, 39369940, 39369941, 39369941, 39369943, 39583693, 39659364, 39659365, 38990813, 38990814, 38990814, 39179705, 39348179, 39369936, 39369938, 39369938, 39369939, 39369940, 39369941, 39369941, 39369942, 39369942, 39595641, 39659365, 39659365, 39659366, 38990814, 38990815, 39369937, 39369938, 39369938, 39369939, 39369941, 39369944, 39583662, 39659365, 43989681, 38990816, 39177318, 39369937, 39369937, 39369939, 39369939, 39369940, 39369941, 39369941, 39369942, 39659365, 39659367, 39369936, 39369939, 39369940, 39369940, 39369941, 39369941, 39369942, 39369942, 39369943, 39369943, 39369944, 39369944, 39659369, 39008763, 39378926, 39067874, 39408481, 39078561, 39078635, 39078710, 39413893, 39413894, 39276327, 39398081, 39512701, 39354679, 39354733, 39354800, 39551941, 39363833, 39556451, 39368608, 39558841, 39519838, 39519838, 39519838, 39519841, 39634459, 39634460, 39923884, 39634461, 39634463, 39611302, 39680190, 39631031, 39690058, 39672564, 39672563, 39710818, 39710824, 39705559, 39705561, 39727324, 39727321, 39724643, 39736885, 39749061, 39749069, 39749058, 39749060, 39749061, 39749062, 39749062, 39749063, 39749070, 39749076, 39749060, 39749061, 39749062, 39749063, 39749063, 39749064, 39749074, 39749074, 39749075, 39749078, 39749078, 39749061, 39749062, 39749062, 39749063, 39749063, 39749064, 39749062, 39749064, 39749064, 39749065, 39749079, 39749063, 39749065, 39749066, 39749066, 39749063, 39749064, 39749064, 39749065, 39749065, 39749066, 39749066, 39749067, 39749068, 39749076, 39749079, 39749080, 39749081, 39749082, 39749064, 39749065, 39749066, 39749066, 39749067, 39749068, 39749082, 39749082, 39749083, 39749065, 39749066, 39749066, 39749067, 39749067, 39749068, 39749068, 39749069, 39749069, 39749077, 39749079, 39749082, 39749083, 39749083, 39749084, 39749066, 39749067, 39749067, 39749068, 39749068, 39749069, 39749071, 39749077, 39749082, 39749082, 39749083, 39749083, 39749084, 39749085, 39749067, 39749068, 39749068, 39749069, 39749069, 39749070, 39749070, 39749074, 39749078, 39749081, 39749082, 39749083, 39749083, 39749084, 39749084, 39749085, 39749089, 39749068, 39749069, 39749069, 39749070, 39749070, 39749071, 39749078, 39749079, 39749079, 39749083, 39749084, 39749084, 39749085, 39749086, 39749086, 39749069, 39749070, 39749070, 39749071, 39749071, 39749079, 39749080, 39749083, 39749084, 39749084, 39749085, 39749086, 39749087, 39749070, 39749071, 39749079, 39749083, 39749084, 39749085, 39749085, 39749086, 39749086, 39749071, 39749072, 39749072, 39749079, 39749081, 39749084, 39749084, 39749085, 39749085, 39749086, 39749087, 39749087, 39749072, 39749073, 39749082, 39749083, 39749085, 39749086, 39749087, 39749087, 39749073, 39749074, 39749086, 39749086, 39749087, 39749087, 39749088, 39749088, 39749085, 39749086, 39749087, 39749087, 39749088, 39749089, 39749087, 39749088, 39749089, 39749083, 39749089, 39749089, 40038499, 40038499, 39749093, 39749094, 39749094, 39749095, 40038508, 39749094, 39749095, 39749095, 39749096, 40038503, 39749098, 39749096, 39962833, 39749097, 39749097, 39749097, 40038511, 39749097, 39749100, 39749097, 39749098, 39749098, 39749099, 39749100, 40038507, 40038507, 40038508, 39749099, 39749099, 39803397, 39749099, 39749100, 39749100, 39749101, 39803353, 39962836, 40038507, 40038508, 40038508, 40038509, 40038510, 40038510, 39749100, 39749101, 39749101, 39749102, 39749102, 39759901, 39803397, 39803401, 39916645, 40004713, 40038507, 40038507, 40038508, 40038508, 40038509, 40038509, 40038510, 40038510, 40038511, 40038511, 40038514, 40038515, 40718156, 43841409, 39749101, 39749102, 39749102, 39749103, 39759902, 39803396, 39803398, 39803402, 39803402, 39824941, 39856959, 39916646, 39962721, 40004712, 40004713, 40035221, 40038507, 40038508, 40038508, 40038509, 40038509, 40038510, 40038510, 40038511, 40038511, 40038512, 40038513, 40038513, 40038514, 40038514, 40038515, 40038515, 40038516, 40038517, 40718136, 40718138, 40718153, 40718160, 41052815, 41432651, 39749102, 39749103, 39749104, 39803399, 39803402, 39803403, 40004714, 40038509, 40038510, 40038510, 40038511, 40038511, 40038513, 40038513, 40038515, 40038516, 42746331, 39749103, 39749104, 39749104, 40038509, 40038510, 40038510, 40038511, 40038511, 40038512, 40038513, 40038514, 40038517, 39749104, 39749105, 39803399, 39803400, 39803402, 39803403, 39824574, 40004715, 40038510, 40038511, 40038511, 40038512, 40038514, 40718144, 40718152, 40718159, 43280763, 39803404, 40035223, 40038511, 40038511, 40038512, 40038515, 40038516, 39803404, 40038512, 40038513, 40038515, 40038514, 39770714, 39770716, 40049323, 40049324, 39857617, 39857665, 39857708, 39857710, 39857711, 39857701, 39857702, 39857703, 39857714, 39857703, 39857714, 39857715, 39940087, 40017118, 40059027, 40089533, 40092819, 40092820, 40092821, 40092822, 40092822, 40092823, 40092824, 39893298, 40110623, 39900062, 40038295, 39900803, 39900874, 39900950, 40114448, 39964836, 40070682, 40022464, 40175199, 40084202, 40084204, 40206065, 40885722, 40176416, 40176464, 40176511, 40176508, 40176512, 40176541, 40176542, 40176600, 40176558, 40176604, 40176573, 40176575, 40176625, 40176626, 40252252, 40176642, 40195548, 40252296, 40252297, 40252297, 40252298, 40252298, 40252301, 40931934, 40200526, 40264256, 40214432, 40271180, 40260334, 40260336, 40260339, 40260340, 40294131, 40294132, 40294132, 40294133, 40294133, 40294134, 40294135, 40321351, 40321353, 40321354, 40324640, 40324642, 40324642, 40327915, 40327931, 40327914, 40327915, 40327915, 40327916, 40327916, 40327917, 40327921, 40327916, 40327917, 40327917, 40327917, 40327918, 40327918, 40327919, 40327933, 40327935, 40327918, 40327919, 40327919, 40327920, 40327920, 40327921, 40327921, 40327922, 40327922, 40327923, 40327923, 40327934, 40327935, 40327935, 40327936, 40327938, 40327919, 40327920, 40327920, 40327921, 40327921, 40327922, 40327923, 40327936, 40327936, 40327920, 40327921, 40327921, 40327922, 40327922, 40327923, 40327923, 40327924, 40327924, 40327925, 40327925, 40327935, 40327936, 40327937, 40327937, 40327938, 40327938, 40327939, 40327939, 40327940, 40327921, 40327922, 40327922, 40327923, 40327923, 40327924, 40327924, 40327925, 40327925, 40327926, 40327934, 40327937, 40327937, 40327938, 40327938, 40327939, 40327939, 40327940, 40327922, 40327923, 40327923, 40327924, 40327924, 40327925, 40327925, 40327926, 40327926, 40327934, 40327937, 40327937, 40327938, 40327938, 40327939, 40327923, 40327924, 40327924, 40327925, 40327925, 40327926, 40327926, 40327936, 40327937, 40327937, 40327938, 40327938, 40327939, 40327939, 40327940, 40327940, 40327924, 40327925, 40327925, 40327926, 40327926, 40327928, 40327937, 40327938, 40327939, 40327940, 40327925, 40327926, 40327926, 40327927, 40327927, 40327928, 40327929, 40327937, 40327937, 40327938, 40327938, 40327939, 40327939, 40327940, 40327940, 40327941, 40327941, 40327926, 40327927, 40327927, 40327928, 40327928, 40327938, 40327939, 40327939, 40327940, 40327940, 40327941, 40327942, 40327943, 40327927, 40327928, 40327928, 40327929, 40327929, 40327930, 40327930, 40327938, 40327938, 40327939, 40327939, 40327940, 40327940, 40327941, 40327941, 40327942, 40327942, 40327943, 40327944, 40327928, 40327929, 40327929, 40327930, 40327930, 40327931, 40327937, 40327938, 40327939, 40327939, 40327940, 40327940, 40327941, 40327941, 40327942, 40327942, 40327943, 40327943, 40327944, 40327929, 40327930, 40327930, 40327931, 40327936, 40327938, 40327938, 40327939, 40327939, 40327940, 40327940, 40327941, 40327941, 40327942, 40327942, 40327943, 40327943, 40327944, 40327944, 40327930, 40327931, 40327931, 40327932, 40327936, 40327940, 40327940, 40327941, 40327941, 40327942, 40327942, 40327943, 40327944, 40327945, 40327945, 40327931, 40327932, 40327932, 40327938, 40327939, 40327939, 40327940, 40327940, 40327941, 40327941, 40327942, 40327942, 40327943, 40327943, 40327944, 40327944, 40327945, 40327946, 40327946, 40327948, 40327939, 40327940, 40327941, 40327942, 40327942, 40327943, 40327943, 40327944, 40327944, 40327945, 40327947, 40327933, 40327943, 40327943, 40327945, 40327947, 40327942, 40327943, 40327943, 40327944, 40327945, 40327946, 40327947, 40327945, 40327948, 40327948, 40327949, 40327950, 40327949, 40327949, 40327950, 40327950, 40327951, 40327951, 40327952, 40327950, 40327950, 40327951, 40327951, 46764316, 40327950, 40327951, 40327951, 40327952, 40327952, 40327953, 41085934, 45613395, 40327951, 40327952, 40327952, 40327953, 40327953, 40327954, 40327954, 40327955, 40327952, 40327953, 40327953, 40327954, 40327954, 40327955, 43570188, 40327953, 40327954, 40327954, 40327955, 40327955, 40327956, 40327956, 40327957, 40956960, 41007574, 41007590, 40327954, 40327955, 40327955, 40327956, 40327956, 40327958, 41007562, 41007586, 41085937, 40327955, 40327956, 40327956, 40327957, 40327957, 40327958, 40956964, 40968609, 41007564, 41007566, 41007568, 41007571, 41007573, 41007575, 41007580, 41007586, 41007593, 41085937, 41384701, 41518537, 41722084, 41788195, 46764319, 40327956, 40327957, 40327957, 40327958, 40327958, 40536983, 41007567, 41007570, 41007571, 41007574, 41007581, 41007584, 41007590, 43335121, 43570190, 46764320, 40327957, 40327958, 40327958, 40327959, 40327959, 40327960, 40373060, 40373062, 40866282, 40968610, 40968611, 40968611, 41007564, 41007567, 41007568, 41007576, 41007577, 41007579, 41007582, 41007583, 41007584, 41007587, 41007587, 41007590, 41007592, 41722084, 41722085, 41741692, 43335121, 43335121, 43335122, 43570191, 44329160, 40327958, 40327959, 40327959, 40327960, 40327960, 40327961, 40432907, 40632197, 40956964, 40960377, 40968611, 41007564, 41007565, 41007566, 41007567, 41007569, 41007570, 41007572, 41007573, 41007578, 41007581, 41007585, 41007586, 41007586, 41007591, 41007591, 41176723, 41722085, 41741694, 43335121, 43335122, 43465365, 43570191, 45613396, 45613397, 45613399, 46764321, 40327959, 40327960, 40327960, 40327961, 40432889, 40432890, 40432892, 40432899, 40536981, 40536984, 40883194, 40956966, 40968611, 40968613, 41007565, 41007567, 41007568, 41007569, 41007569, 41007571, 41007571, 41007572, 41007572, 41007574, 41007574, 41007575, 41007577, 41007577, 41007578, 41007579, 41007579, 41007580, 41007581, 41007584, 41007585, 41007586, 41007586, 41007587, 41007588, 41007590, 41007592, 41085939, 41085939, 41085969, 41085970, 41085970, 41176722, 41564906, 41688193, 41722084, 41722085, 41722086, 42461493, 43035759, 43465365, 43570191, 43570202, 43570207, 43570209, 44658255, 45613396, 45613397, 45613397, 45613400, 46764321, 40327960, 40327961, 40327961, 40327962, 40432904, 40610974, 40937120, 40968612, 40968613, 40968613, 40968614, 41007566, 41007566, 41007568, 41007569, 41007569, 41007572, 41007573, 41007576, 41007577, 41007577, 41007578, 41007578, 41007581, 41007581, 41007585, 41007585, 41007587, 41007588, 41007591, 41007593, 41085940, 41085941, 41085947, 41176723, 41518540, 43335123, 43570192, 44658254, 46764322, 40327961, 40327962, 40327962, 40327963, 40327963, 40373067, 40386015, 40402581, 40432890, 40432890, 40432892, 40432897, 40432919, 40536985, 40536986, 40563073, 40683620, 40724566, 40756173, 40886629, 40956966, 40956967, 40968612, 40968613, 41003515, 41007480, 41007566, 41007567, 41007567, 41007568, 41007568, 41007569, 41007569, 41007570, 41007570, 41007571, 41007571, 41007573, 41007574, 41007575, 41007576, 41007577, 41007578, 41007578, 41007579, 41007579, 41007580, 41007582, 41007582, 41007584, 41007585, 41007586, 41007587, 41007588, 41007588, 41007589, 41007589, 41007591, 41007592, 41007593, 41007593, 41007594, 41007594, 41007595, 41007595, 41085939, 41085940, 41085942, 41188368, 41722087, 43335124, 43570209, 44658254, 45613398, 46764322, 40327962, 40327963, 40327964, 40402581, 40432891, 40432912, 40441506, 40536983, 40536986, 40536987, 40610975, 40683620, 40684006, 40703695, 40886628, 40956966, 40968613, 40968613, 41007566, 41007567, 41007568, 41007568, 41007569, 41007570, 41007572, 41007574, 41007575, 41007575, 41007576, 41007578, 41007579, 41007579, 41007580, 41007581, 41007582, 41007583, 41007583, 41007584, 41007587, 41007588, 41007588, 41007589, 41007590, 41007592, 41007594, 41007594, 41007595, 41085940, 41085941, 41342246, 41722085, 41722086, 41722087, 41788199, 43335123, 43335124, 43570192, 45035273, 45613398, 40339852, 40432890, 40432891, 40432921, 40536985, 41007567, 41007567, 41007569, 41007570, 41007572, 41007572, 41007574, 41007579, 41007580, 41007581, 41007583, 41007584, 41007592, 41007594, 41722087, 40865934, 41007568, 41007570, 41007575, 41007580, 41007593, 41007573, 41007597, 42963284, 41007584, 41007571, 40351757, 41019475, 40418173, 40418179, 40418186, 41767197, 43615306, 41013731, 40444081, 40444081, 41065658, 44716321, 40477246, 41082235, 41082240, 41082244, 40537843, 40537834, 40537837, 40537822, 40537835, 40537835, 40537862, 40537851, 40537837, 40537852, 40537845, 40537861, 40537854, 40537864, 40537865, 41112521, 41112523, 41073557, 41112511, 40972917, 40537880, 40537885, 43440076, 41112535, 41112523, 40537894, 40537895, 41061926, 41112537, 41112540, 41846666, 41112533, 41112541, 41112547, 41061942, 41073589, 40555072, 41121148, 40746018, 40746020, 40746009, 40746024, 40746025, 40746025, 40746024, 40746025, 40746024, 40746025, 40746025, 45822434, 41294977, 40746037, 41095667, 41216611, 41216617, 41385763, 43779248, 41216621, 41216606, 41216611, 41931126, 41216623, 43544163, 40798197, 41242720, 40894003, 41290595, 41290597, 42005112, 40936486, 41390228, 41039284, 41039360, 41039434, 41039435, 41363307, 41363306, 41040066, 41442001, 41079446, 42163950, 41121200, 41121295, 41121389, 41404295, 41184427, 41435833, 41403917, 41545551, 41404618, 45196588, 41407995, 45198278, 41438440, 41523857, 41445310, 41445311, 41445312, 41566265, 41566252, 41566260, 41546296, 42331262, 41585983, 41585984, 41585985, 41636588, 41636588, 41636589, 41636589, 41636590, 41636591, 41636601, 41636608, 41636609, 41636610, 41592808, 44961594, 41609278, 41609264, 41609274, 41609275, 41609278, 41609278, 41609279, 41609279, 41609280, 41609280, 41609281, 41609275, 41609279, 41609280, 41609281, 41609281, 41609285, 41609282, 41609283, 41609285, 41609286, 41609363, 41609371, 41609373, 41609376, 42362751, 41648239, 41609295, 41648233, 41648235, 41648236, 41648238, 41648239, 41648249, 41648250, 42328966, 41648244, 41648247, 41648253, 41648237, 41648245, 41648246, 41648260, 41648237, 41648250, 42362754, 41648247, 41648256, 41648257, 41648241, 41648252, 41648258, 41609453, 41609468, 41609474, 41648331, 41609477, 41648331, 43975886, 46254163, 41679082, 41683138, 41687010, 41687096, 41687177, 41687185, 41687181, 41687186, 41687187, 41687175, 41687176, 41687179, 41687181, 41687184, 41687184, 41687187, 41687187, 41687188, 41687188, 41687189, 41687189, 41687190, 41687195, 41687175, 41687184, 41687190, 41687176, 41687183, 41687184, 41687185, 41687187, 41687191, 41687176, 41687185, 41687177, 41687177, 41687178, 41687179, 41687180, 41687181, 41687181, 41687183, 41687183, 41687184, 41687184, 41687186, 41687193, 41687211, 41687216, 41687178, 41687178, 41687179, 41687179, 41687180, 41687180, 41687181, 41687182, 41687182, 41687183, 41687185, 41687185, 41687186, 41687187, 41687187, 41687189, 41687190, 41687190, 41687191, 41687191, 41687192, 41687192, 41687196, 41687197, 41687200, 41687201, 41687202, 41687213, 41687214, 41687217, 41687179, 41687180, 41687180, 41687183, 41687187, 41687188, 41687189, 41687192, 41687199, 41687218, 41687181, 41687182, 41687188, 41687188, 41687192, 41687216, 41687181, 41687182, 41687183, 41687187, 41687187, 41687189, 41687189, 41687190, 41687195, 41687198, 41687217, 41687219, 41687183, 41687184, 41687186, 41687189, 41687189, 41687191, 41687193, 41687203, 41687218, 41687183, 41687184, 41687185, 41687188, 41687189, 41687195, 41687216, 41687220, 41687188, 41687190, 41687190, 41687192, 41687198, 41687200, 41687217, 41687220, 41687189, 41687190, 41687191, 41687195, 41687195, 41687198, 41687200, 41687218, 41687187, 41687190, 41687191, 41687191, 41687192, 41687195, 41687196, 41687198, 41687200, 41687204, 41687219, 41687220, 41687188, 41687191, 41687192, 41687193, 41687195, 41687198, 41687203, 41687219, 41687190, 41687192, 41687192, 41687220, 41687191, 41687192, 41687192, 41687193, 41687196, 41687191, 41687192, 41687195, 41687196, 41687197, 41687219, 41687221, 41687191, 41687192, 41687193, 41687203, 41687219, 41687192, 41687193, 41687194, 41687194, 41687195, 41687201, 41687205, 41687209, 41687193, 41687194, 41687194, 41687195, 41687196, 41687198, 41687201, 41687202, 41687205, 41687195, 41687195, 41687196, 41687199, 41687200, 41687222, 41687223, 41687195, 41687196, 41687196, 41687199, 41687201, 41687201, 41687202, 41687222, 41687224, 41687196, 41687197, 41687197, 41687198, 41687199, 41687200, 41687200, 41687201, 41687202, 41687202, 41687203, 41687204, 41687206, 41687223, 41687224, 41687225, 41687226, 41687197, 41687198, 41687198, 41687199, 41687199, 41687200, 41687200, 41687201, 41687201, 41687202, 41687203, 41687203, 41687204, 41687205, 41687206, 41687206, 41687207, 41687211, 41687212, 41687213, 41687222, 41687223, 41687223, 41687224, 41687225, 41687225, 41687198, 41687199, 41687199, 41687200, 41687200, 41687201, 41687201, 41687203, 41687199, 41687200, 41687201, 41687202, 41687202, 41687203, 41687205, 41687205, 41687211, 41687212, 41687224, 41687200, 41687201, 41687201, 41687202, 41687202, 41687203, 41687204, 41687205, 41687208, 41687208, 41687209, 41687217, 41687226, 41687227, 41687228, 41856343, 41687201, 41687202, 41687202, 41687203, 41687203, 41687204, 41687204, 41687205, 41687206, 41687206, 41687209, 41687214, 41687227, 41687228, 41687202, 41687203, 41687203, 41687204, 41687204, 41687205, 41687206, 41687207, 41687208, 41687208, 41687210, 41687227, 41687229, 41687203, 41687204, 41687205, 41687205, 41687206, 41687206, 41687207, 41687209, 41687209, 41687210, 41687211, 41687211, 41687213, 41687227, 41687227, 41687228, 41687228, 41762273, 42401708, 41687204, 41687205, 41687205, 41687206, 41687206, 41687207, 41687208, 41687208, 41687209, 41687209, 41687211, 41687211, 41687212, 41687213, 41687218, 41687227, 41687227, 42421323, 41687205, 41687206, 41687206, 41687207, 41687207, 41687208, 41687209, 41687209, 41687210, 41687227, 41687228, 41687229, 41687229, 41687230, 41687230, 41687231, 41687206, 41687207, 41687207, 41687208, 41687208, 41687209, 41687209, 41687210, 41687211, 41687211, 41687212, 41687217, 41687229, 41687230, 41687231, 46293022, 41687207, 41687208, 41687208, 41687209, 41687209, 41687210, 41687212, 41687229, 41687230, 41687232, 43715383, 41687208, 41687209, 41687209, 41687210, 41687210, 41687211, 41687211, 41687212, 41687218, 41687219, 41687229, 41687230, 41765564, 41687209, 41687210, 41687210, 41687211, 41687211, 41687213, 41687229, 41687232, 42421328, 41687210, 41687211, 41687211, 41687212, 41687212, 41687213, 41687213, 41687214, 41687214, 41687215, 41687218, 41687229, 41687230, 41687231, 41687232, 41687233, 41687211, 41687212, 41687212, 41687213, 41687213, 41687214, 41687214, 41687216, 41687216, 41687229, 41687230, 41687234, 41687212, 41687213, 41687213, 41687214, 41687214, 41687215, 41687232, 41687233, 41687234, 41687213, 41687214, 41687214, 41687215, 41687215, 41687216, 41687231, 41687233, 41687233, 41687234, 41687235, 41687214, 41687215, 41687215, 41687218, 41687221, 41687221, 41687233, 41687234, 41687235, 41687235, 41687215, 41687216, 41687216, 41687217, 41687219, 41687219, 41687220, 41687232, 41687233, 41687233, 41687234, 41687234, 41687235, 41687235, 41687236, 41687236, 41687216, 41687217, 41687217, 41687218, 41687220, 41687221, 41687233, 41687234, 41687234, 41687235, 41687236, 41687217, 41687218, 41687218, 41687219, 41687219, 41687220, 41687220, 41687221, 41687221, 41687233, 41687233, 41687234, 41687234, 41687235, 41687235, 41687236, 41687236, 41687218, 41687219, 41687219, 41687220, 41687220, 41687221, 41687223, 41687234, 41687234, 41687235, 41687235, 41687236, 41687236, 41687237, 41687238, 41687219, 41687220, 41687220, 41687221, 41687221, 41687224, 41687233, 41687236, 41687236, 41765566, 41687220, 41687221, 41687221, 41687222, 41687222, 41687223, 41687235, 41687235, 41687236, 41687236, 41687237, 41687238, 41687221, 41687222, 41687222, 41687223, 41687223, 41687224, 41687224, 41687235, 41687236, 41687238, 41687222, 41687223, 41687223, 41687224, 41687224, 41687225, 41687225, 41687237, 41687237, 41687238, 41687238, 41687240, 41687240, 41687223, 41687224, 41687224, 41687225, 41687225, 41687226, 41687235, 41687236, 41687236, 41687238, 41687239, 41687240, 41687241, 41687224, 41687225, 41687225, 41687226, 41687235, 41687236, 41687236, 41687237, 41687237, 41687238, 41687238, 41687239, 41687240, 41687241, 41687225, 41687226, 41687226, 41687227, 41687236, 41687237, 41687237, 41687238, 41687238, 41687239, 41687240, 41687240, 41687241, 41687241, 41687242, 41687242, 41687226, 41687227, 41687227, 41687228, 41687228, 41687229, 41687230, 41687237, 41687238, 41687239, 41687239, 41687240, 41687241, 41687241, 41687242, 41687243, 41687227, 41687228, 41687231, 41687237, 41687238, 41687238, 41687239, 41687239, 41687240, 41687240, 41687241, 41687243, 41687228, 41687229, 41687238, 41687239, 41687240, 41687240, 41687241, 41687241, 41687242, 41687243, 41687243, 41687231, 41687235, 41687238, 41687238, 41687239, 41687239, 41687240, 41687240, 41687241, 41687241, 41687243, 41687244, 41687244, 41687231, 41687239, 41687240, 41687240, 41687241, 41687242, 41687243, 41687243, 41687238, 41687241, 41687242, 41687245, 41687244, 41687241, 41687242, 41687242, 41687240, 41687245, 41687245, 41687242, 41687247, 41687247, 43276724, 41687248, 41687249, 41687249, 41687250, 41687251, 41687249, 41687249, 41687250, 41687250, 41687251, 41687252, 41765583, 41765584, 41687249, 41687250, 41687250, 41687251, 41687251, 41687252, 41687252, 41765584, 41765614, 42401729, 44249836, 44249853, 45337907, 41687250, 41687251, 41687251, 41687252, 41687252, 41687253, 41687253, 41765584, 41765585, 42401730, 42401731, 41687251, 41687252, 41687252, 41687253, 41687253, 41687254, 42401731, 42401732, 43715405, 44014768, 41687252, 41687253, 41687253, 41687254, 41687254, 41687256, 41765585, 41765586, 42051036, 42198186, 42401730, 42401730, 42401732, 44014768, 44014769, 41687253, 41687254, 41687254, 41687255, 41687255, 41687256, 41765585, 41765606, 42401729, 42401730, 42401731, 42401733, 42819216, 44014769, 47443968, 41687254, 41687255, 41687255, 41687256, 41687257, 41687260, 41765586, 41765587, 41765588, 41765599, 41856371, 42401731, 42401732, 42401733, 42467845, 44145013, 44249838, 45337900, 45337901, 41687255, 41687256, 41687256, 41687257, 41687257, 41765586, 41765587, 41765594, 41765611, 41765617, 41765620, 41856371, 42198187, 42276721, 42401732, 42401732, 42401733, 42401733, 42401734, 42421343, 42421352, 42421353, 42467845, 42467845, 43141141, 43715407, 43715407, 44014766, 44014770, 44014771, 44145013, 44145013, 44249844, 44249853, 44249856, 45337900, 45337901, 46293047, 47443969, 41687256, 41687257, 41687257, 41687258, 41687258, 41765586, 41765587, 41765587, 41765588, 41765611, 41856367, 42064354, 42401725, 42401733, 42401734, 42421352, 44014771, 46293043, 41687257, 41687258, 41687258, 41687259, 41763828, 41765586, 41765587, 41765587, 41765588, 41765588, 41765589, 41765590, 41765595, 41765599, 41765614, 41765614, 41765616, 41765617, 41765618, 41843027, 41856373, 42021893, 42064354, 42198189, 42324388, 42401731, 42401732, 42401732, 42401733, 42401734, 42401735, 42421348, 42467846, 42985027, 43142363, 43715408, 44014770, 44014771, 44014771, 44014772, 44145018, 45008811, 45337902, 45337903, 45337907, 45714921, 46293046, 47443970, 41687258, 41687259, 41687260, 41765585, 41765587, 41765588, 41765588, 41765589, 41856372, 42021894, 42379602, 42401733, 42401733, 42401735, 42421356, 44014772, 44249839, 44249840, 41687259, 41687260, 41687260, 41765588, 41765588, 41765589, 41765589, 41765590, 41765618, 42021894, 42051040, 42064353, 42401733, 42401734, 42401735, 42401735, 42401736, 42421352, 42421355, 42803220, 43929392, 44014773, 44249842, 44249856, 46293047, 41765588, 41765589, 41765589, 41765590, 41765591, 41765600, 41765609, 41765617, 41765618, 41805210, 41856373, 42268035, 42401734, 42401734, 42401735, 42401735, 42401736, 42421345, 42467848, 42803220, 43430502, 44014772, 44014773, 44145016, 45337905, 41765590, 44249847, 41765590, 41765591, 42401736, 42421356, 42401737, 41837354, 41840643, 41840433, 42478340, 41843930, 41843941, 41843932, 41843918, 41843918, 41843932, 41843934, 41843934, 41843935, 41843935, 41843918, 41843919, 41843920, 41843933, 41843935, 41843919, 41843934, 41843934, 41843935, 41843937, 41843938, 41843941, 41843943, 41843949, 41843921, 41843921, 41843922, 41843927, 41843932, 41843934, 41843935, 41843935, 41843936, 41843936, 41843937, 41843937, 41843938, 41843938, 41843939, 41843939, 41843940, 41843940, 41843941, 41843941, 41843942, 41843943, 41843943, 41843944, 41843945, 41843945, 41843946, 41843947, 41843947, 41843949, 41843949, 41843950, 41843951, 41843951, 41843954, 41843923, 41843937, 41843938, 41843939, 41843939, 41843945, 41843962, 41843963, 41843963, 41843964, 41843941, 41843958, 41843964, 41843937, 41843938, 41843966, 41843947, 41843947, 41843958, 41843970, 41843972, 41843974, 41843975, 41843966, 41843949, 41843950, 42480080, 42499689, 41843963, 42480080, 42480081, 41843951, 41843953, 42480080, 42480080, 44093118, 41843952, 41843953, 41843965, 42499690, 41843952, 41843953, 41843953, 41843954, 42480082, 42546194, 43793755, 44223363, 44328188, 41843953, 41843954, 41843954, 41843955, 41843955, 41843956, 41843956, 41843957, 41843958, 41843962, 41843966, 41843975, 42480083, 42499702, 42546194, 42546194, 41843954, 41843955, 41843956, 41843956, 41843958, 41843960, 41843965, 42480081, 42480083, 43877958, 44328207, 41843955, 41843957, 41843958, 42480083, 42499692, 42499701, 43793757, 44328189, 41843956, 41843957, 41843959, 41843960, 41843962, 41843967, 41843969, 41843970, 41843972, 42084759, 42115217, 42480081, 43793757, 44223358, 41843957, 41843958, 41843958, 41843959, 41843961, 41843965, 41843972, 41843981, 42480083, 42480084, 44223361, 44328206, 41843958, 41843959, 41843961, 41843962, 41843963, 41843964, 41843964, 41843968, 41843970, 41934722, 42499694, 43793758, 44093122, 47522321, 41843960, 41843963, 41843967, 41843969, 41843973, 41843973, 41843984, 42480085, 44223362, 44223363, 45416253, 41843961, 41843961, 41843968, 41843980, 41843984, 42499695, 42499706, 44093123, 41843962, 41843967, 41843970, 41843984, 42499696, 42546198, 41843971, 42100243, 42480086, 42499696, 44093123, 41843972, 42480086, 42499695, 44223368, 41843964, 41843970, 42446304, 42480087, 42480088, 42532717, 44328202, 41843969, 41843987, 44328194, 41843967, 41843969, 41843989, 42480089, 44093137, 41843971, 41843988, 42480088, 42480090, 41843969, 41843972, 41843975, 42480090, 42499709, 43580843, 41843986, 42480088, 42546202, 42480089, 42480090, 42499710, 41843979, 41843990, 42480091, 42499711, 41843977, 41843990, 41843991, 41934729, 43578891, 44223371, 41843992, 41934729, 41843976, 41843992, 41843994, 42480092, 42276547, 41843977, 41843992, 41843994, 41843993, 41843993, 41843994, 41843978, 41843979, 41843994, 41843994, 41843980, 41843994, 41843994, 41843995, 42480093, 44093131, 44093132, 41843994, 41843995, 42100255, 44328215, 41843997, 42480097, 41843985, 41843995, 41843997, 42480095, 42480096, 42480097, 42480099, 42499706, 42499706, 44223373, 41843997, 41843999, 41843997, 41844000, 42142721, 42480098, 42499709, 44093137, 44223379, 42546212, 42919913, 41844002, 41934744, 42480104, 43587050, 42480107, 42480108, 42480106, 42499717, 42480107, 42480109, 42881593, 42480107, 42480109, 42499729, 43219511, 44093147, 41844010, 41934747, 41934750, 42100267, 42480108, 42480109, 42480109, 42480110, 42480110, 42480111, 42499728, 42546223, 42546224, 43578910, 43793784, 44069782, 44093147, 44093147, 42276566, 42480109, 42480110, 42480111, 42480111, 45416279, 42157662, 42461924, 42480110, 42480112, 42499720, 42546223, 44093148, 44093148, 44328234, 41934749, 42499721, 42499731, 43185802, 44328235, 46371425, 41934749, 41934750, 45416281, 41923179, 41974341, 41998810, 42012154, 42025498, 42025486, 42025499, 42025500, 42025501, 42025501, 42025502, 42025503, 42025503, 42025504, 42025499, 42025502, 42025503, 42025504, 42025505, 42025499, 42025505, 42025504, 42025508, 42025508, 42570859, 42590476, 42590479, 42570861, 42570863, 42590484, 42570863, 42636977, 42570864, 42972350, 42025521, 42493519, 42636978, 42570866, 44183904, 42636979, 44314145, 42570866, 42570866, 42570867, 42191028, 42570870, 42048785, 42582503, 42325578, 42787014, 42356538, 42356540, 42356542, 42356543, 42356545, 42736381, 42736380, 42736383, 42736383, 43137867, 42736384, 43475785, 44479663, 42736386, 42386493, 42770968, 42414830, 42414905, 42414912, 42414981, 42414994, 42831716, 44508886, 42441462, 42441462, 42441463, 42441465, 42441466, 42778844, 42575300, 42778844, 44391881, 44391882, 42460775, 42788500, 42471347, 42793797, 42709135, 42709135, 42709136, 42709136, 42709138, 42912681, 44226358, 42912680, 42912680, 42912682, 42932290, 42912680, 42801872, 44702333, 42848825, 42982526, 42866200, 42991211, 42961533, 42961534, 43038880, 43048438, 43048543, 43048650, 43048656, 43048657, 46018605, 43102060, 43102063, 43071956, 43533899, 43079860, 43079932, 43080007, 43117744, 43116201, 43116207, 43116208, 43116209, 43116207, 43116209, 43116210, 43116225, 43116208, 43116209, 43116210, 43116223, 43116223, 43116224, 43116225, 43116225, 43116226, 43116227, 43116227, 43116228, 43116228, 43116209, 43116210, 43116211, 43116224, 43116225, 43116225, 43116227, 43116227, 43116210, 43116211, 43116223, 43116224, 43116226, 43116226, 43116228, 43116229, 43116229, 43116211, 43116212, 43116224, 43116224, 43116225, 43116225, 43116226, 43116226, 43116227, 43116227, 43116228, 43116229, 43116230, 43116231, 43116231, 43116232, 43116232, 43116212, 43116224, 43116225, 43116226, 43116227, 43116236, 43116213, 43116223, 43116224, 43116224, 43116225, 43116225, 43116226, 43116226, 43116227, 43116227, 43116228, 43116228, 43116229, 43116229, 43116231, 43116237, 43116237, 43116238, 43116238, 43116239, 43116239, 43116240, 43116240, 43116241, 43116241, 43116242, 43116240, 43116244, 43116237, 43116249, 43116248, 43116253, 43116238, 43116250, 43135833, 43116237, 43116238, 43116239, 43116240, 43116251, 43116251, 43116252, 43116252, 43116253, 43135843, 44729261, 43116239, 43116240, 43116250, 43116253, 43116254, 43135844, 44964331, 44964343, 43116240, 43116243, 43116250, 43116254, 43116254, 43782244, 44729261, 44729262, 43116244, 43116253, 43217774, 43116242, 43116243, 43116243, 43116250, 43116252, 43116253, 43116255, 43116255, 43116256, 43135836, 43135845, 44429901, 44643883, 44729263, 47007537, 43116242, 43116245, 43116253, 43116254, 43116255, 43116256, 43135835, 43135836, 43135843, 43135847, 44051219, 44429901, 44429903, 44729263, 44729264, 44859502, 44964345, 44964347, 46052395, 43116244, 43116254, 43116255, 43116255, 43116256, 43116256, 43116259, 43135836, 43135836, 44215026, 44300763, 46052396, 48158463, 43116245, 43116246, 43116253, 44729265, 45723305, 47007541, 43116249, 43116254, 43116256, 43116257, 43135837, 43135849, 43182340, 44729265, 46429417, 43116246, 43116254, 43116256, 43116256, 43135838, 44964348, 43182341, 43855635, 44859506, 43116260, 43135850, 44729267, 44964353, 43116256, 43116256, 43116257, 43116257, 43116258, 43135838, 43135839, 48158466, 44729279, 43135839, 43135844, 44964338, 46052400, 43116259, 45723308, 44964339, 43116261, 43116262, 43116265, 43135856, 43821880, 44964342, 43116265, 43116266, 43714313, 44729272, 44729274, 43116264, 43116264, 43116266, 43116266, 43116267, 43116268, 43135846, 43135856, 43135857, 44356992, 44729274, 44729275, 44859517, 44859520, 48158473, 43116266, 43116267, 43135847, 43135857, 43182350, 44729275, 44964344, 47007551, 47007552, 43116265, 43116267, 43116268, 43135858, 43135859, 43182351, 43855646, 44357433, 44729275, 44729276, 46052406, 46052412, 48158474, 43116266, 43116267, 43116267, 43116268, 43116268, 43135847, 43135857, 43135858, 43135859, 43135860, 43135860, 43182351, 43182352, 43213563, 44429913, 44729275, 44729276, 44729276, 44859517, 44964344, 44964345, 44964352, 46052412, 46711145, 47007553, 47007553, 48158475, 43116268, 43116268, 43135847, 43135859, 43182351, 44729276, 44729276, 44859519, 44964360, 43116268, 43116269, 43116269, 43135848, 43135859, 43135860, 44429915, 44643896, 44729277, 44964345, 46052407, 43116269, 43116270, 43135849, 43182352, 43430178, 43699533, 43699534, 43855648, 43856869, 44429916, 44729277, 44729277, 47007553, 43116270, 43135849, 43135850, 43135851, 43135856, 43135859, 43135860, 43135860, 43135861, 43135862, 43182353, 43471779, 43490521, 43517725, 43556051, 43855649, 43856871, 44429914, 44429915, 44729277, 44729278, 44729278, 44964347, 44964350, 45667908, 46052407, 47007555, 48158477, 43135849, 43135852, 43135860, 43135861, 43182353, 43182355, 43217788, 43424229, 43517726, 43699532, 43855647, 44215039, 44521850, 44643896, 44729278, 44729278, 44729279, 44964347, 44964359, 45723319, 46052410, 46052413, 46052414, 44964347, 43135850, 43135851, 43135853, 43155429, 43155442, 43155428, 43155429, 43155443, 43155448, 43155449, 43155429, 43155430, 43155440, 43155445, 43155446, 43155447, 43155447, 43155452, 43155452, 43155453, 43155453, 43155431, 43155437, 43155439, 43155440, 43155441, 43155441, 43155444, 43155445, 43155445, 43155446, 43155447, 43155447, 43155449, 43155450, 43155452, 43155452, 43155453, 43155453, 43155454, 43155454, 43155448, 43155449, 43155453, 43155440, 43155448, 43155450, 43155451, 43155458, 43155442, 43155461, 43155462, 43155462, 43155464, 43155459, 43155463, 43155465, 43155465, 43155465, 43155449, 43155450, 43155460, 43155465, 43155466, 43155466, 43155449, 43155465, 43155466, 43155466, 43155467, 43155450, 43155458, 43155466, 43155467, 43155451, 43155455, 43155466, 43155467, 43155469, 43155452, 43155453, 43155457, 43155461, 43155467, 43155467, 43155468, 43155465, 43155468, 43155469, 43155469, 43155469, 43155470, 43155469, 43155470, 43719128, 43155461, 44748873, 43155460, 43155461, 43155463, 43155471, 44879114, 46072010, 43155461, 43155462, 43155463, 44748873, 44879115, 44983959, 47027148, 43155463, 43155464, 43155469, 43155472, 44748873, 43155470, 44748874, 43155474, 44449513, 44748886, 44879116, 44983946, 46072010, 44449512, 44748875, 44748884, 43155467, 43155474, 43262455, 44879116, 43155471, 43155469, 43876468, 44449513, 43876469, 44983963, 44879116, 46072011, 47027153, 43155471, 43155476, 44748878, 44748879, 43155478, 43155478, 43201956, 43449782, 44879122, 44983949, 48178079, 44748880, 45742922, 43201958, 43237392, 44533720, 46072016, 43155481, 43575655, 44449519, 44748882, 43155482, 43155483, 43201958, 43201959, 43201959, 43302497, 43449785, 44109643, 44449520, 44449521, 44748883, 44748884, 44748884, 44879127, 46072015, 47027158, 43155483, 43155484, 43201960, 43237396, 43537332, 43876476, 44449521, 44748885, 44879121, 44879122, 46072015, 43155484, 43201960, 43201961, 43238565, 43449786, 43537332, 43841491, 43875249, 43876476, 44234646, 44242814, 44449521, 44449522, 44449522, 44464450, 44547392, 44748884, 44748885, 44748885, 44879125, 44983954, 46072016, 46072017, 43201960, 43201961, 43201963, 43719140, 43719141, 44449522, 44748886, 46072016, 44748886, 44748887, 43221482, 44781890, 43248435, 43248450, 43248450, 43248450, 43248451, 43248436, 43248437, 43248437, 43248450, 43248451, 43248451, 43248438, 43248450, 43248451, 43248452, 43248452, 43248453, 43248452, 43248452, 43248453, 43248452, 43248453, 43248453, 43248453, 43248465, 43765630, 43765631, 44795376, 44839711, 45030444, 45030460, 48224574, 43248466, 43496277, 43583823, 43888029, 43921744, 44496012, 44496013, 44795375, 44795376, 44795376, 44925617, 44925618, 45789417, 46118507, 43248467, 43283886, 43556619, 43583824, 43765632, 43765634, 43888035, 43922968, 44496013, 44795372, 44795376, 44795377, 44925617, 44925623, 45030443, 46118508, 46118511, 46495526, 47073650, 47073651, 47073651, 44795376, 44925618, 43310887, 44826602, 43319321, 43319319, 43319320, 43319321, 43319326, 44531447, 43449912, 43657583, 45065880, 44316576, 43321657, 43435554, 43369459, 43948533, 43449523, 44895910, 43549452, 43646776, 43580501, 43580635, 43580768, 44746370, 43732197, 45037247, 43744100, 43744101, 44013456, 44743836, 44743837, 45043199, 45173439, 45278281, 43827320, 43827391, 43827460, 45084886, 43864783, 43864817, 48532739, 44804209, 43919192, 43919191, 43919194, 43919194, 43919195, 43919195, 43919196, 43919196, 43919268, 43919269, 43919270, 43919268, 43919276, 44257112, 44831385, 45130748, 45130749, 45260994, 46421219, 46453883, 45365821, 43919339, 43919344, 43919344, 43919353, 44831456, 45130820, 45365889, 46453951, 45365903, 43951251, 43951374, 43951457, 45061508, 43995841, 43995843, 43995844, 43995844, 43995845, 43995922, 45169070, 44139327, 46492202, 45169071, 43996002, 46492280, 44282808, 44282811, 44282811, 44282810, 44282811, 44282812, 44282814, 44282812, 44282814, 44282813, 45312554, 45312554, 45312553, 45013193, 45312555, 46635687, 46635695, 45013192, 45312556, 47590832, 44829236, 44438928, 44312379, 45562410, 44448324, 45630427, 44527546, 44527668, 44527621, 44527667, 44527668, 44527674, 44527697, 44527742, 45435014, 45435015, 45435015, 45565252, 45565258, 45565258, 44595031, 44595034, 44595035, 44595037, 44595042, 44595043, 44595044, 44595040, 44595042, 44595043, 44595043, 45703734, 45468670, 45598912, 45169307, 45468670, 48777929, 45169308, 47168822, 45468672, 45598912, 47746947, 45598916, 45703742, 45703742, 44597473, 44597475, 44597543, 44597612, 45170591, 45469951, 45469951, 45469952, 45705020, 45705020, 45705023, 46463990, 44866219, 46598302, 44986206, 45664251, 45063825, 45703074, 45173759, 49187229, 45313821, 45313821, 45313822, 45528696, 45528697, 45828058, 45828059, 45828060, 45958302, 45317730, 45960254, 45330117, 45836210, 45330156, 45836227, 45375655, 45559613, 45485298, 45913798, 45597735, 45970017, 45598618, 45598619, 47669303, 48248737, 45743570, 45743574, 45743559, 45743574, 45743574, 45743575, 45743576, 45743577, 45743578, 45743571, 45743575, 45743575, 45743576, 45743577, 45743574, 45743575, 45743576, 45743577, 45743578, 45743578, 45743578, 45743578, 45743580, 45743577, 45743577, 45743581, 45743586, 46173176, 46042936, 45743589, 45851441, 46042938, 46278022, 47366068, 47741779, 49276337, 45743591, 45743664, 45884403, 46042937, 46042937, 46042938, 46173179, 46173180, 46173181, 46173181, 46278007, 46278014, 46278024, 47036979, 49472137, 46042938, 46042938, 46042939, 46173176, 46173178, 46173181, 46278007, 46278007, 47036980, 48321213, 46042938, 46042939, 46042939, 46042949, 46173182, 46042940, 46173181, 47366070, 46042940, 47366070, 46173184, 46042942, 47366073, 48071093, 45743747, 46278090, 45773431, 46057866, 45911980, 45911980, 46127141, 46257381, 46362225, 45927457, 47458016, 45939365, 46271097, 45959306, 46281042, 46025227, 46314041, 46171537, 46171537, 46171540, 46171541, 46171541, 46256918, 46387162, 46387161, 46387164, 46256921, 46204424, 49702564, 46295573, 46449176, 46342282, 46342297, 46342283, 46342299, 46342284, 46342284, 46342285, 46342285, 46342296, 46342299, 46342300, 46342301, 46342302, 46342303, 46342285, 46342286, 46342299, 46342300, 46342300, 46342301, 46342301, 46342302, 46342302, 46342303, 46342304, 46342305, 46342306, 46342306, 46342310, 46342312, 46342286, 46342297, 46342299, 46342300, 46342301, 46342301, 46342302, 46342302, 46342303, 46342304, 46342304, 46342305, 46342306, 46342309, 46342288, 46342288, 46342295, 46342298, 46342300, 46342301, 46342302, 46342302, 46342303, 46342304, 46342304, 46342305, 46342306, 46342311, 46342311, 46342312, 46342312, 46342313, 46342313, 46342314, 46342314, 46342303, 46342321, 46342321, 46342324, 46342324, 46342324, 46342326, 46342312, 46342313, 46342316, 46342324, 46342327, 46342316, 46342317, 46577384, 46342315, 46342325, 46577369, 46577384, 46342317, 46342317, 46577369, 46577370, 47665431, 48042450, 49771499, 46342316, 46342317, 46342317, 46342319, 46342319, 46342320, 46342320, 46342321, 46342326, 46342328, 46342330, 46472540, 46472541, 46472544, 46577368, 46577369, 46577370, 46577372, 46577381, 46577382, 47336342, 47665431, 47665432, 47665436, 47665441, 49771500, 46342317, 46342318, 46342319, 46342319, 46342321, 46342327, 46342327, 46342328, 46342328, 46342329, 46472542, 46472543, 46472544, 46472545, 46577370, 46577371, 46577377, 46577383, 47336340, 47632771, 47665432, 47665432, 46342319, 46342328, 46472541, 46472542, 46472543, 46472544, 46472545, 46577370, 46577371, 46577388, 47665432, 48620578, 48620578, 46342319, 46342322, 46342328, 46342332, 46472539, 46472542, 46472543, 46472544, 46472545, 46472545, 46577371, 46577383, 46577385, 46577386, 47165955, 47665432, 47665434, 48042452, 48620574, 46472542, 46472544, 46472545, 46472546, 46472547, 46577387, 46342329, 46577372, 46342324, 46342329, 46342331, 46342334, 46472545, 46472545, 46472546, 46472546, 46577390, 48620578, 46342325, 46342330, 46342331, 46472545, 46577373, 46577382, 47665436, 46342325, 46342336, 46472542, 46577374, 47665447, 46342331, 46342333, 46472546, 46489636, 46577373, 46577375, 48620582, 49771505, 46577389, 47336346, 48042457, 46577375, 46342335, 46472554, 46342337, 46342338, 46577382, 47665441, 47665441, 47665442, 48620587, 46342338, 46342338, 46342339, 46342340, 46472550, 46472552, 46472554, 46472555, 46472557, 46577380, 46577380, 46577381, 46577385, 46577393, 46577393, 46577394, 46577396, 47336352, 47665442, 47665443, 48041152, 48620585, 48620588, 46577393, 46807367, 47665443, 47665448, 48620586, 46342339, 46472555, 46577381, 46577381, 46577387, 46577398, 46807367, 47665443, 48620587, 48620588, 49771511, 46342342, 46472552, 46472553, 46472553, 46472554, 46472554, 46472555, 46472556, 46472556, 46472557, 46472558, 46577381, 46577382, 46577382, 46577394, 47336352, 47336354, 47665443, 47665443, 47665444, 47665446, 48041153, 48042462, 48620587, 48620587, 48620588, 48620589, 48620589, 46489651, 46577382, 46577382, 47336352, 47665444, 47665448, 47665450, 46472553, 46472554, 46472557, 46577384, 46577399, 47665446, 47665451, 46472559, 46577391, 46472554, 46577384, 46472557, 46577392, 46472559, 46430972, 47709767, 46602775, 46602778, 46602781, 46602777, 46602779, 46602763, 46602778, 46602779, 46602780, 46602781, 46602782, 46602782, 46602766, 46602767, 46602768, 46602768, 46602783, 46602784, 46602784, 46602785, 46602786, 46602786, 46602787, 46602787, 46602768, 46602784, 46602784, 46602785, 46602787, 46602767, 46602768, 46602768, 46602769, 46602784, 46602785, 46602787, 46602768, 46602769, 46602770, 46602771, 46602785, 46602785, 46602786, 46602786, 46602787, 46602788, 46602770, 46602785, 46602787, 46602788, 46602788, 46602789, 46602770, 46602771, 46602784, 46602786, 46602787, 46602787, 46602789, 46602771, 46602772, 46602772, 46602786, 46602787, 46602788, 46602772, 46602773, 46602774, 46602787, 46602787, 46602788, 46602788, 46602790, 46602790, 46602773, 46602787, 46602788, 46602788, 46602789, 46602790, 46602788, 46602789, 46602790, 46602791, 46602790, 46602792, 46602793, 46602792, 46602794, 47795670, 46707611, 46707609, 46707617, 46707623, 46707624, 46707614, 46707621, 47795672, 48750817, 46602800, 46707628, 46707615, 46602803, 46602803, 46602804, 46602804, 46602805, 46602805, 46602806, 46619882, 46640092, 46707532, 46707612, 46707613, 46707613, 46707623, 46707625, 46707626, 46707626, 46707627, 46707628, 46707628, 46707629, 46707629, 46988330, 47466585, 47654363, 47795674, 47795675, 47795681, 48171384, 48750818, 49901743, 46602803, 46602805, 46602806, 46707611, 46707613, 46707627, 46707627, 46707628, 47795676, 48750821, 46602804, 46602805, 46602805, 46602806, 46602806, 46602808, 46707613, 46707614, 46707621, 46707625, 46707626, 46707626, 46707629, 46707631, 46707632, 47466586, 47795675, 47795676, 47795677, 47795678, 48500692, 49901744, 46707614, 46707614, 46707615, 46707625, 46707626, 46707629, 46707630, 47466585, 48750820, 49901744, 46602806, 46602807, 46707614, 46707618, 46707619, 47466585, 47795677, 47795679, 47795683, 46707613, 46707615, 46707615, 46707629, 47676922, 47795677, 47795677, 47795678, 48750824, 46707614, 46707615, 46707616, 46707616, 46707624, 46707628, 46707628, 46707629, 46707631, 46707632, 47466588, 47606806, 47795678, 48171388, 48750823, 48750824, 46707541, 46707616, 46707626, 46707628, 46707632, 48750822, 46707632, 46919705, 46707619, 46602855, 46707645, 46636954, 46636963, 46636994, 46637027, 46724725, 46724737, 46637099, 46637109, 46637111, 47812830, 46677418, 46744938, 46812272, 46812284, 46812354, 46812361, 46812437, 46812437, 46812438, 46812436, 46812437, 46812422, 46812436, 46812437, 46812438, 46812422, 46812423, 46812423, 46812437, 46812423, 46812424, 46812425, 46812426, 46812429, 46812430, 46812435, 46812436, 46812437, 46812438, 46812438, 46812439, 46812439, 46812441, 46812444, 46812455, 46812424, 46812425, 46812425, 46812426, 46812427, 46812432, 46812433, 46812434, 46812434, 46812436, 46812437, 46812437, 46812438, 46812438, 46812439, 46812439, 46812440, 46812440, 46812441, 46812441, 46812442, 46812444, 46812459, 46812425, 46812428, 46812430, 46812434, 46812435, 46812436, 46812439, 46812439, 46812440, 46812440, 46812441, 46812442, 46812448, 46812454, 46812434, 46812437, 46812438, 46812441, 46812441, 46812428, 46812441, 46812455, 46812435, 46812436, 46812441, 46812457, 46812458, 46812438, 46812458, 46812440, 46812440, 46812459, 46812459, 46812431, 46812443, 46812459, 46812460, 46812439, 46812461, 46812460, 46812461, 46812441, 46812443, 46812450, 46812447, 46812462, 46812463, 46812439, 46812445, 46812462, 46812446, 46812463, 46812441, 46812444, 46812446, 46812448, 46812463, 46812466, 46812444, 46812446, 46812448, 46812449, 46812449, 46812464, 46812448, 46812449, 46812449, 46812447, 46812448, 46812449, 46812450, 46812467, 46812448, 46812450, 46812451, 46812466, 46812447, 46812451, 46812451, 46812468, 46812448, 46812449, 46812450, 46812451, 46812468, 46812468, 46812450, 46812451, 46812451, 46812452, 46812453, 46812469, 46812469, 46812450, 46812451, 46812451, 46812453, 46812453, 46812454, 46812469, 46812469, 46812470, 47900499, 46812452, 46812452, 46812453, 46812453, 46812454, 46812457, 46812469, 46812470, 48276209, 46812452, 46812453, 46812453, 46812455, 46812470, 46812470, 47781747, 47900499, 48855645, 46812453, 46812454, 46812454, 46812455, 46812470, 46812471, 47900499, 47900500, 47900501, 48855647, 50006568, 46812454, 46812455, 46812456, 46812457, 46812458, 46812470, 46812471, 46812471, 46812472, 47900501, 47900501, 47900502, 48277519, 48855644, 50006569, 46812455, 46812456, 46812456, 46812457, 46812457, 46812458, 46812460, 46812470, 46812470, 46812471, 46812471, 46812472, 46812472, 47042426, 47093156, 47428008, 47571411, 47900501, 47900501, 47900502, 48855645, 48855646, 48855646, 48855647, 48855647, 50006569, 46812456, 46812457, 46812457, 46812471, 46812471, 46812472, 46812472, 46812473, 47042425, 47571412, 47571413, 47887189, 47900498, 47900501, 47900501, 47900502, 47900502, 47900503, 47900504, 48855645, 46812457, 46812458, 46812461, 46812472, 46812473, 47781750, 47900502, 47900503, 47900508, 48276212, 46812458, 46812459, 46812473, 46812473, 46812474, 47900503, 47900503, 48277521, 48855646, 46812463, 46812464, 46812473, 46812474, 46812474, 46812475, 47900503, 48855647, 46812473, 46812474, 46812475, 47900504, 46812474, 46812476, 48276214, 46812475, 46812475, 46812476, 47781753, 47867846, 47900505, 47900506, 47900509, 48855650, 47093162, 46812479, 47571419, 47900515, 47900519, 47042437, 46812486, 46812487, 47900516, 47900516, 47900517, 47900517, 46812487, 47900517, 47900518, 47900523, 48855660, 48855661, 48855661, 46812488, 46812489, 46812489, 47093173, 47290489, 47571422, 47571426, 47571428, 47900515, 47900517, 47900517, 47900518, 47900518, 47900519, 47900523, 47900523, 47900524, 48277534, 48844037, 48855658, 48855659, 48855661, 48855661, 48855662, 48855662, 48855663, 48855663, 48855664, 50006586, 46812489, 46812490, 47042440, 47042442, 47093172, 47093173, 47571426, 47571427, 47571428, 47571428, 47781764, 47900517, 47900518, 47900518, 47900519, 47900520, 47900521, 47900522, 47900522, 47900524, 47900525, 47900526, 47900526, 47900528, 48276228, 48806190, 48855661, 48855662, 48855663, 48855664, 50006586, 46812490, 47571427, 47571429, 47867858, 47900518, 47900519, 47900519, 47900526, 48276228, 48855662, 48855663, 48855666, 48855666, 50006587, 47042442, 47093180, 47900519, 47900519, 47900520, 47900520, 47900522, 47571431, 47236617, 48112597, 47272407, 47272410, 47272409, 47272410, 47272411, 47272412, 47323141, 48118558, 48130486, 48130486, 49085631, 47801397, 48130487, 48130491, 47373874, 47373875, 47373875, 47373882, 48085602, 48181220, 48181221, 48181226, 48181227, 47775585, 47768502, 48259778, 47933730, 48711507, 47989602, 48456421, 48043574, 48516067, 48177286, 48582922, 48219562, 50710130, 48330374, 48330366, 48330379, 48330379, 48330380, 48330380, 48330380, 48330382, 48330380, 48330380, 48330381, 48330383, 48330381, 48330382, 48659470, 48659473, 49614615, 48330393, 48659476, 49614616, 48357896, 48362082, 48659469, 48659470, 48659470, 48659471, 48659471, 48659473, 48659474, 48659477, 48659478, 49035180, 49283124, 49400663, 49614614, 49614614, 49614615, 49614616, 50765539, 48659472, 49614616, 48659473, 48385425, 49642144, 48393780, 49646312, 48610820, 48799697, 48705935, 49802391, 48751052, 48751053, 48751054, 48751054, 48751055, 48837146, 48869808, 48869813, 49245517, 49245520, 50975875, 48797326, 48892948, 48923237, 48923238, 48923242, 48923243, 48955898, 48955899, 48955902, 48955903, 48955911, 49911047, 48961937, 48975249, 48964703, 48976631, 48988545, 48988560, 48988561, 48988545, 48988546, 48988552, 48988558, 48988562, 48988547, 48988550, 48988552, 48988560, 48988561, 48988564, 48988565, 48988547, 48988548, 48988548, 48988549, 48988550, 48988550, 48988551, 48988552, 48988554, 48988558, 48988562, 48988562, 48988563, 48988563, 48988564, 48988565, 48988565, 48988566, 48988566, 48988567, 48988548, 48988549, 48988549, 48988550, 48988550, 48988551, 48988551, 48988552, 48988552, 48988553, 48988553, 48988554, 48988554, 48988555, 48988555, 48988556, 48988557, 48988561, 48988561, 48988562, 48988562, 48988563, 48988563, 48988564, 48988564, 48988565, 48988565, 48988566, 48988566, 48988549, 48988550, 48988551, 48988551, 48988552, 48988552, 48988553, 48988553, 48988554, 48988554, 48988555, 48988556, 48988556, 48988562, 48988563, 48988563, 48988564, 48988564, 48988565, 48988565, 48988566, 48988566, 48988567, 48988567, 48988568, 48988551, 48988552, 48988552, 48988553, 48988556, 48988556, 48988563, 48988564, 48988565, 48988566, 48988566, 48988567, 48988568, 48988553, 48988564, 48988567, 48988552, 48988553, 48988553, 48988554, 48988554, 48988555, 48988555, 48988556, 48988556, 48988557, 48988561, 48988565, 48988566, 48988572, 48988574, 48988553, 48988554, 48988554, 48988555, 48988556, 48988557, 48988566, 48988567, 48988574, 48988574, 48988575, 48988554, 48988555, 48988555, 48988556, 48988559, 48988565, 48988566, 48988567, 48988568, 48988572, 48988573, 48988555, 48988556, 48988556, 48988557, 48988558, 48988559, 48988559, 48988566, 48988567, 48988567, 48988568, 48988568, 48988569, 48988574, 48988575, 48988556, 48988557, 48988558, 48988558, 48988567, 48988567, 48988569, 48988569, 48988573, 48988574, 48988576, 48988576, 48988558, 48988559, 48988560, 48988561, 48988567, 48988569, 48988575, 48988576, 48988558, 48988559, 48988559, 48988560, 48988561, 48988568, 48988569, 48988569, 48988570, 48988570, 48988573, 48988574, 48988576, 48988577, 48988577, 48988559, 48988560, 48988562, 48988564, 48988568, 48988568, 48988569, 48988570, 48988570, 48988575, 48988577, 48988577, 48988561, 48988561, 48988562, 48988569, 48988570, 48988571, 48988572, 48988573, 48988576, 48988577, 48988578, 48988561, 48988562, 48988564, 48988569, 48988570, 48988571, 48988577, 48988578, 48988562, 48988563, 48988564, 48988566, 48988568, 48988570, 48988570, 48988571, 48988571, 48988572, 48988573, 48988574, 48988577, 48988578, 48988578, 48988579, 48988563, 48988564, 48988565, 48988566, 48988567, 48988569, 48988571, 48988571, 48988572, 48988572, 48988573, 48988577, 48988579, 48988579, 48988580, 48988570, 48988571, 48988572, 48988572, 48988574, 48988575, 48988581, 48988571, 48988576, 48988578, 48988578, 48988580, 48988581, 48988581, 48988580, 48988581, 48988573, 48988574, 48988580, 48988581, 48988583, 48988573, 48988584, 48988575, 48988577, 48988581, 48988582, 49943703, 48988578, 48988583, 51094629, 48988581, 49365580, 49943707, 48988576, 48988577, 48988577, 48988578, 51094630, 48988577, 48988578, 48988578, 48988579, 48988580, 48988584, 48988586, 49364272, 49943705, 51094630, 48988578, 48988579, 48988579, 48988580, 48988580, 48988582, 48988584, 48988585, 48988587, 49364273, 49364274, 49612174, 49943706, 49943707, 49943708, 49943709, 49943709, 51094631, 48988579, 48988580, 48988580, 48988581, 48988581, 48988582, 48988583, 48988585, 48988585, 48988587, 48988587, 48988588, 49364273, 49943706, 49943708, 49943709, 51094631, 48988580, 48988581, 48988581, 48988582, 48988585, 48988586, 48988586, 48988587, 48988587, 48988588, 48988588, 49364274, 49365583, 49603564, 49707998, 49943707, 49943707, 49943708, 49943709, 49943709, 49943710, 50603351, 51094632, 48988581, 48988582, 48988582, 48988583, 48988584, 48988586, 48988587, 48988588, 48988588, 48988589, 49285316, 49364274, 49364275, 49365582, 49365583, 49365584, 49905554, 49943707, 49943708, 49943709, 49943709, 49943710, 49943710, 51094632, 48988582, 48988583, 48988583, 48988584, 48988586, 48988587, 48988588, 48988588, 48988589, 48988590, 49364275, 49364276, 49365583, 49365585, 49457347, 49486674, 49943707, 49943708, 49943708, 49943709, 49943710, 49943711, 49943712, 50722257, 51094633, 48988583, 48988587, 48988587, 48988588, 48988589, 48988589, 48988590, 49365588, 49943707, 49943708, 49943709, 49943710, 49943711, 49943712, 51094633, 48988585, 48988588, 48988588, 48988589, 48988590, 48988590, 48988591, 48988592, 49029508, 49364276, 49365582, 49365585, 49943707, 49943708, 49943709, 49943709, 49943710, 49943710, 49943711, 49943711, 50901271, 49364275, 49364276, 49365585, 49943710, 49943711, 51094634, 48988589, 49365585, 49943710, 49943710, 48988589, 48988590, 48988590, 48988591, 49603568, 49943710, 49943711, 49943712, 49943713, 49943713, 51094635, 48988590, 48988592, 48988591, 48988592, 48988593, 48988593, 49943712, 49943713, 49943714, 48988592, 48988593, 48988593, 48988594, 48988594, 48988595, 49364279, 49364279, 49365589, 49943713, 49943715, 48988593, 48988594, 48988594, 48988595, 48988596, 49220017, 49365590, 49943713, 49943714, 49943714, 49943715, 51094638, 48988594, 48988595, 48988595, 49365589, 49943715, 49943716, 51094639, 48988595, 48988596, 48988596, 49218197, 49364281, 49365590, 49943714, 49943715, 49943715, 49943716, 49943716, 49943717, 49943718, 49944884, 51094639, 48988596, 48988597, 48988598, 49285323, 49364281, 49364281, 49364282, 49364282, 49364283, 49365590, 49365591, 49365592, 49428510, 49457354, 49943714, 49943715, 49943715, 49943716, 49943716, 49943717, 49943717, 49943718, 51094640, 49192252, 49364284, 49365590, 49365591, 49365592, 49693204, 49905562, 49905563, 49943713, 49943714, 49943715, 49943716, 49943716, 49943717, 49943717, 49943718, 49943718, 49773609, 49943716, 49943716, 49943717, 49943718, 49943718, 51094641, 49943716, 49164048, 49943717, 49943718, 49943719, 49070444, 49207013, 49339507, 50119176, 49343580, 49543090, 49395914, 49395931, 49396008, 49396086, 49406794, 49417528, 49922418, 49447810, 50173330, 49451455, 49595717, 49489282, 49489293, 50194066, 49582062, 49582064, 51391379, 49661024, 49739967, 49739968, 49739981, 49739982, 49739982, 49739982, 49739982, 49739983, 49739983, 49739983, 49739984, 49739984, 49739984, 49739984, 49739985, 49739986, 49833054, 50319413, 50319417, 50319418, 50319418, 51470340, 49741291, 50319414, 50319416, 50319416, 50319418, 49741290, 49741293, 50319414, 50319416, 50319417, 50319417, 50319418, 50319418, 50319419, 50319419, 50950312, 51470341, 49833056, 49742598, 49742599, 49742599, 49742600, 49742600, 49742600, 49742601, 49742601, 49742601, 49742602, 49742602, 49742603, 49742602, 49742603, 49742605, 49980583, 50320724, 50320724, 50320725, 50320725, 50320726, 51471649, 50320725, 50320725, 50320726, 50320726, 50320727, 51471650, 50320723, 50320725, 50320726, 50320726, 50320727, 50320727, 50320728, 50320728, 51275852, 51471650, 49868436, 50383641, 49926122, 49926123, 50412483, 50400861, 50412483, 50412486, 49984793, 50441829, 50218561, 50218562, 50558701, 50558704, 50235826, 50235871, 50567358, 51718286, 50306037, 50602442, 50397822, 50648335, 50398595, 50398600, 50648723, 50648724, 50427285, 50427355, 50427414, 50427417, 50427430, 50427432, 50427535, 50427537, 50427627, 50427642, 50663245, 50663247, 50470966, 50684917, 50558635, 50728742, 50799904, 50849377, 50822543, 50822546, 50822545, 50860696, 50860698, 50860702, 50875598, 50875599, 50887219, 50887224, 50898832, 50898844, 50898832, 50898832, 50898833, 50898834, 50898835, 50898847, 50898832, 50898835, 50898833, 50898833, 50898836, 50898834, 50898835, 50898835, 50898836, 50898836, 50898837, 50898837, 50898838, 50898852, 50898852, 50898853, 50898854, 50898857, 50898835, 50898836, 50898836, 50898837, 50898837, 50898838, 50898838, 50898848, 50898851, 50898852, 50898853, 50898853, 50898854, 50898857, 50898836, 50898837, 50898837, 50898838, 50898838, 50898839, 50898839, 50898847, 50898853, 50898853, 50898854, 50898837, 50898838, 50898838, 50898853, 50898854, 50898854, 50898855, 50898838, 50898839, 50898839, 50898840, 50898840, 50898841, 50898853, 50898854, 50898854, 50898855, 50898857, 50898858, 50898839, 50898840, 50898840, 50898841, 50898841, 50898851, 50898851, 50898853, 50898854, 50898854, 50898855, 50898855, 50898840, 50898841, 50898841, 50898843, 50898850, 50898851, 50898853, 50898854, 50898854, 50898855, 50898855, 50898856, 50898841, 50898842, 50898844, 50898852, 50898855, 50898855, 50898856, 50898856, 50898857, 50898858, 50898843, 50898855, 50898856, 50898856, 50898857, 50898857, 50898856, 50898856, 50898857, 50898858, 50898857, 50898858, 50898858, 50898864, 52049771, 50898865, 50898866, 50898865, 50898867, 51856416, 50898868, 50898868, 50898869, 50898870, 50898869, 50898870, 52049776, 50898870, 50898871, 50898871, 50898872, 50898872, 50898873, 50898873, 50898874, 50898876, 50900024, 50913997, 51039993, 51098251, 51154800, 51327477, 51332204, 51386560, 51391897, 51454820, 51529733, 51558496, 51853977, 51853978, 51853978, 51853979, 51853980, 51856412, 51856415, 51856418, 52049777, 50898871, 50898872, 50898872, 50898873, 50898873, 50898874, 50898874, 51007571, 51039994, 51214590, 51327477, 51386561, 51529748, 51530049, 51777941, 51853978, 51853979, 51856413, 51856413, 51957872, 52049777, 50898872, 50898873, 50898873, 50898874, 50898874, 50898875, 50898876, 50898876, 50898877, 50898878, 50900022, 50900024, 51039992, 51299050, 51357650, 51386560, 51386561, 51525979, 51525980, 51525981, 51529749, 51777943, 51853977, 51853978, 51853978, 51853979, 51853979, 51853981, 51853981, 51856414, 51856415, 52049778, 50898873, 50898874, 50898874, 50898875, 50898876, 50898878, 50898881, 50900023, 50900025, 51777945, 51838716, 51853978, 51856415, 51856416, 52049778, 50898875, 50898877, 50900024, 51386562, 51566496, 51856415, 51890221, 52049779, 50898875, 50898877, 51327479, 52049779, 50898876, 51327480, 51558499, 51698387, 51698388, 51698389, 51856417, 52049780, 51298430, 51525979, 51529736, 51698388, 51698389, 52049780, 51327481, 51991324, 52049781, 51853983, 52049781, 51853982, 52049782, 52049782, 52049783, 52049783, 52049784, 52049787, 50901188, 50901189, 50901188, 50901190, 50901190, 50901191, 51678564, 52050943, 51387727, 51699552, 51855147, 52050944, 50929139, 52064919, 51116290, 52158496, 51181125, 51181128, 51181129, 52190911, 52190911, 52190912, 51297642, 51585951, 51410750, 52305727, 51530321, 52365509, 51698039, 52449389, 51699260, 51727687, 51756098, 51756098, 51756099, 51756100, 51756100, 52282601, 52478398, 52271381, 52478399, 52282603, 51765562, 52483135, 51816439, 51845351, 51874249, 51874265, 51874266, 51947425, 52537483, 51884998, 52542878, 52010786, 52605743, 52020589, 52610647, 52153096, 52153098, 52153101, 52153103, 52676897, 52676897, 52676899, 52676900, 52160626, 52160638, 52160647, 52160650, 52680670, 52680676, 52680679, 52680682, 52161299, 52681028, 52218133, 52218157, 52218175, 52709413, 52218232, 52218229, 52218286, 52218308, 52516149, 52516149, 52709513, 52234145, 52234223, 52234301, 52717506, 52455939, 52455944, 52828317, 52828320, 52497910, 52497911, 52497911, 52849302, 52657025, 52657026, 52657030, 52928861, 52928864, 52778624, 52932417, 52786662, 52993680, 52809100, 52809102, 52809102, 52809101, 52809103, 52809102, 52809102, 52809103, 52809102, 52809103, 52809104, 52809105, 52809105, 52809106, 53004901, 53004901, 53004902, 52813970, 52813971, 52813971, 52813971, 52813972, 52813972, 52813973, 52813974, 52813975, 52813977, 52813978, 53007334, 53007335, 53007335, 53007336, 53007336, 53007337, 52881573, 52881649, 52881723, 53041205, 52960807, 52960818, 52960828, 53080758, 53016888, 53108794, 53083783, 53083898, 53084014, 53142356, 53086174, 53143443], "xaxis": "x", "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 4, 1, 0, 0, 5, 86, 76903, 3162, 3971, 3661, 4662, 4246, 2571, 898, 2455, 3, 636, 17, 1270, 1655, 221, 693, 4833, 149, 1176, 215, 1304, 28, 1596, 159, 1847, 244, 3, 2452, 1135, 403, 18686, 59217, 7142, 1, 184, 1402, 1116, 2846, 1469, 2656, 261, 594, 1694, 1280, 1178, 271, 561, 450, 1077, 209, 1254, 1051, 1044, 1152, 668, 633, 4692, 13048, 35323, 1108, 689, 1263, 1105, 300, 866, 438, 3697, 382, 861, 1260, 2666, 1237, 1321, 1393, 4256, 1238, 623, 1206, 1393, 2501, 426, 1507, 3301, 1326, 427, 262, 1494, 1350, 689, 1012, 1979, 1, 1395, 1281, 637, 9, 1177, 1270, 272, 1656, 784, 449, 692, 1036, 1311, 2492, 150, 2213, 44, 1686, 1250, 57, 624, 239, 1255, 1597, 1050, 1349, 1363, 1796, 741, 1043, 243, 4, 1662, 788, 2211, 1392, 75, 865, 669, 634, 4440, 5496, 62, 51300, 1586, 200020, 352862, 14293, 15872, 16936, 540, 938, 390, 130, 864, 575, 1269, 8, 1106, 69, 101, 1354, 944, 970, 7544, 127, 71, 41, 431, 7, 17, 7, 7, 9, 15, 158, 98962, 131785, 88675, 3446, 7327, 198, 4876, 2299, 1764, 3122, 2139, 9231, 84, 102, 32, 30, 63600, 35848, 7322, 1086, 789, 2234, 818, 1677, 39, 145200, 5442, 20130, 22, 18588, 1101, 928, 1728, 33, 2215, 8, 6818, 2133, 7132, 43, 44309, 76437, 577, 4763, 1892, 52335, 1549, 20920, 5697, 12394, 3028, 5603, 1946, 18442, 1321, 14, 1779, 2244, 31591, 236, 17414, 885, 2622, 9854, 5116, 7956, 390, 31, 565, 4147, 362, 4445, 2, 427, 3435, 853, 42148, 1263, 20511, 5383, 8004, 7411, 21958, 3921, 4544, 9727, 98, 391, 886, 578, 428, 1400, 1976, 2780, 131, 2033, 9, 3469, 1914, 23, 854, 199, 3618, 12650, 2622, 6498, 9414, 10349, 41291, 3829, 14419, 29672, 302, 59, 129, 1530, 3619, 21, 380, 723, 1264, 2381, 15337, 5190, 8846, 2327, 15839, 5416, 7776, 6049, 165, 621, 1484, 8581, 20, 9, 2744, 6513, 3922, 23969, 599, 6069, 13305, 5613, 21952, 2920, 23, 3612, 2870, 18097, 3324, 1724, 2451, 21738, 21, 40, 5653, 1142, 2329, 2523, 9197, 6907, 6535, 65017, 105773, 122, 175, 201, 290, 17, 4550, 9899, 16915, 7489, 1285, 6241, 3221, 138768, 756, 64, 255, 26, 8793, 5907, 278825, 64459, 48817, 10431, 296, 31, 23, 136, 5756, 878, 2165, 3640, 2221, 49, 187746, 93850, 7347, 30, 239659, 18106, 163, 384616, 1293, 14, 12, 5, 114, 173, 39, 57, 103712, 60181, 36564, 41114, 74596, 61679, 7205, 18462, 7228, 5323, 1936, 2740, 401, 405, 436, 1659, 166, 4, 998, 7, 72, 17136, 15119, 12842, 27003, 17412, 4837, 3667, 1244, 793, 2164, 38, 960, 580, 10326, 15423, 22527, 14297, 776, 7459, 2923, 1755, 172, 845, 2152, 297, 25, 10346, 20267, 20080, 8096, 1857, 958, 37, 409, 33494, 19879, 12938, 8548, 888, 2239, 693, 369, 701, 33, 85247, 34648, 40576, 7196, 3329, 2376, 1398, 109, 2343, 866, 52, 85, 72, 85462, 80674, 10030, 18604, 6440, 6930, 1351, 2368, 1182, 2433, 624, 188, 941, 1290, 96128, 15820, 13019, 8568, 9994, 2120, 1504, 5697, 410, 324, 213, 233, 62068, 80363, 44213, 39073, 5104, 5286, 4992, 6994, 3191, 242, 78, 2321, 75, 3015, 630, 176, 25, 28, 61852, 17225, 15943, 4803, 474, 3925, 1477, 143, 471, 67, 765, 972, 208, 99890, 51518, 11706, 8582, 10074, 744, 1972, 938, 123, 56, 1312, 236, 45, 126, 110326, 16080, 22472, 13917, 5772, 5561, 2624, 2586, 391, 930, 463, 404, 1638, 172, 141, 77268, 43897, 55303, 23718, 14881, 3699, 4937, 5690, 40, 1963, 437, 1378, 66, 593, 2369, 214, 2313, 859, 117, 38281, 42609, 13569, 10730, 1634, 2227, 694, 579, 3583, 4684, 259, 57092, 40289, 13204, 4407, 3402, 2490, 627, 605, 944, 1960, 2, 46, 121996, 37562, 12366, 7267, 6551, 2294, 1283, 7929, 440, 16, 885, 138, 381, 142462, 35255, 22541, 10773, 1234, 2545, 717, 1841, 85, 118, 120276, 50268, 26477, 10353, 10345, 3522, 4517, 3221, 1292, 2441, 281, 32, 35, 193, 96418, 45773, 4582, 20138, 8056, 134, 3355, 407, 1638, 1099, 29, 51, 61, 157, 122583, 5405, 28470, 10603, 8712, 6075, 72, 2494, 750, 11, 36, 327, 1953, 1109, 194, 785, 46959, 144093, 11327, 5762, 4530, 100, 5157, 1352, 86, 1428, 350, 36, 253, 61400, 4092, 2473, 1275, 2279, 942, 2412, 106, 152, 1083, 360, 182177, 42648, 1015, 25565, 4200, 7407, 1259, 3652, 306, 2280, 30, 269, 1705, 194, 188, 282, 413, 265, 145507, 2344, 36666, 17076, 7300, 3012, 1444, 298, 2307, 5121, 573, 3355, 3218, 770, 2746, 878, 149, 436, 364, 1291, 6704, 150665, 14761, 6353, 4919, 3604, 1521, 4160, 387, 2454, 4663, 3442, 207, 2800, 2462, 1883, 2953, 297, 4525, 1313, 9562, 1503, 632, 943, 3356, 1274, 92996, 19567, 13271, 12854, 10373, 4558, 2075, 1517, 3732, 4438, 16665, 10167, 7219, 13729, 2132, 2669, 8156, 4066, 1280, 5016, 2285, 43671, 11708, 1742, 3517, 2894, 3782, 6886, 5000, 3959, 7433, 9643, 4313, 9837, 5821, 3127, 232, 65, 7768, 3247, 12418, 9180, 843, 5079, 5356, 4172, 4810, 4828, 7343, 6228, 10478, 4047, 3462, 132, 872, 2490, 2118, 2830, 9730, 3353, 1830, 5984, 1393, 7441, 2678, 5807, 2689, 2529, 4038, 1501, 719, 403, 579, 2951, 4779, 1595, 3490, 2044, 1622, 9946, 6187, 3351, 853, 4430, 1585, 1221, 2758, 2493, 6984, 4908, 2856, 6128, 1837, 3006, 1327, 43, 1674, 731, 4416, 2016, 2492, 5077, 14, 297, 2829, 3784, 1197, 941, 2850, 2488, 9085, 5114, 763, 1259, 3347, 3943, 1345, 1522, 13496, 5413, 5794, 2224, 2541, 776, 1290, 3921, 1757, 3112, 1274, 9259, 1198, 4240, 3569, 1052, 1977, 1691, 6470, 10430, 5172, 3141, 3531, 1225, 2857, 364, 24227, 21827, 13673, 13471, 12919, 439, 1025, 2974, 919, 21115, 12726, 6203, 10632, 5404, 7555, 8593, 9310, 39349, 1782, 14857, 18179, 2408, 4495, 14779, 10534, 5207, 38623, 36542, 6859, 7200, 20017, 14323, 1156, 7959, 1952, 235, 137, 52214, 7905, 8334, 24752, 11941, 27952, 28377, 67501, 47583, 15275, 39100, 8567, 68645, 13364, 275400, 204897, 617, 67, 163, 163, 122, 135, 3, 7, 411, 117, 77, 86, 86, 196, 718, 58, 8, 23, 9, 39, 112, 12, 151, 79, 77, 20, 157, 24, 99, 0, 185, 53, 252, 68, 220, 1108, 0, 0, 0, 0, 0, 0, 42960, 16345, 5672, 18829, 1955, 21450, 4483, 11024, 5245, 9298, 6669, 350, 2050, 1454, 396, 3156, 5899, 3156, 4017, 1726, 1467, 752, 3443, 4026, 1002, 943, 946, 228, 400, 847, 548, 306, 2643, 143, 1918, 1771, 343, 2338, 1970, 319, 162, 1347, 401, 203, 1015, 56, 184, 721, 486, 204, 532, 758, 3106, 0, 0, 6426, 993, 8213, 2643, 3178, 2325, 2416, 1323, 1392, 622, 299, 125, 3091, 1786, 730, 1590, 193, 1039, 201, 1416, 691, 325, 687, 623, 206, 455, 210, 335, 1264, 3703, 3728, 2588, 2650, 1824, 390, 1102, 1768, 160, 457, 1272, 261, 347, 432, 690, 13, 98, 52, 1767, 2459, 122, 2691, 282, 540, 18, 23, 176, 2, 569, 8034, 6305, 4410, 4218, 1800, 783, 761, 2409, 571, 145, 660, 551, 818, 31, 172, 6, 386, 3353, 363, 684, 1065, 1131, 512, 698, 891, 189, 5610, 10394, 1891, 3240, 1394, 3100, 2994, 1596, 698, 1564, 1341, 2590, 1049, 532, 682, 76, 774, 1548, 65, 44, 5327, 3600, 3553, 943, 1622, 2179, 225, 16, 1276, 373, 530, 445, 855, 900, 105, 5878, 5075, 4888, 7584, 5564, 1346, 362, 630, 3576, 190, 1460, 727, 498, 948, 2, 4117, 3298, 186, 325, 278, 1500, 1509, 893, 369, 441, 1064, 671, 1048, 6, 1296, 26, 95, 361, 5908, 983, 3748, 3428, 631, 2620, 933, 7654, 77, 780, 691, 992, 625, 264, 135, 102, 90, 1749, 5649, 2919, 2313, 2333, 8476, 942, 810, 913, 336, 270, 1986, 548, 483, 2053, 615, 942, 96, 81, 11, 7986, 855, 2929, 10143, 273, 605, 382, 1289, 536, 762, 184, 728, 1409, 16, 299, 125, 1513, 4319, 1538, 16864, 1074, 190, 356, 468, 517, 277, 336, 7343, 2311, 684, 87, 827, 144, 630, 437, 44, 1619, 10776, 1250, 570, 759, 298, 48, 15, 4512, 686, 799, 347, 164, 124, 629, 472, 121, 144, 133, 85, 36806, 5507, 538, 1396, 1302, 2207, 1488, 1682, 6031, 6073, 3942, 509, 1511, 681, 358, 334, 1519, 2215, 3134, 876, 411, 2420, 1108, 1322, 157, 1008, 14, 74, 378, 118, 235, 0, 8224, 974, 159, 5313, 1795, 1911, 7688, 6749, 4274, 1377, 1135, 272, 556, 1646, 1705, 413, 790, 1429, 685, 695, 553, 134, 76, 557, 1086, 2685, 1200, 1498, 3076, 2148, 396, 621, 456, 3855, 2254, 2421, 802, 379, 349, 831, 305, 798, 368, 80, 687, 617, 2632, 941, 442, 539, 550, 359, 555, 1395, 381, 1016, 158, 391, 1187, 361, 1301, 1085, 845, 3578, 1260, 1233, 54, 893, 1009, 2127, 875, 178, 752, 348, 523, 672, 7, 1796, 1565, 191, 112, 2202, 1196, 781, 844, 905, 742, 9378, 1511, 2275, 2328, 1996, 1178, 212, 3789, 2415, 61, 1587, 3869, 824, 771, 322, 375, 609, 338, 207, 456, 242, 351, 735, 1944, 3927, 1182, 1156, 4473, 1206, 2640, 10113, 1449, 1246, 1783, 537, 191, 1076, 794, 891, 322, 330, 966, 943, 802, 2462, 202, 198, 1532, 1098, 659, 1748, 456, 780, 157, 1047, 1038, 654, 471, 387, 130, 1792, 1071, 1318, 3938, 3247, 2619, 171, 1915, 727, 425, 91, 855, 2328, 229, 443, 1378, 325, 2366, 163, 508, 1951, 560, 594, 726, 2836, 1037, 2043, 444, 1440, 431, 271, 127, 91, 91, 5193, 2089, 1096, 4834, 821, 1182, 139, 318, 214, 133, 555, 682, 547, 2099, 561, 634, 538, 357, 75, 11, 335, 1147, 613, 11064, 310, 4974, 1131, 970, 657, 4435, 1008, 211, 123, 2113, 2316, 1172, 2504, 546, 417, 32, 11981, 335, 3357, 20628, 8027, 4643, 3112, 1066, 2220, 1855, 872, 2189, 455, 15, 781, 859, 945, 1095, 899, 60, 1057, 2048, 12368, 503, 1314, 1199, 1334, 938, 3114, 728, 306, 1742, 781, 824, 676, 157, 2301, 336, 5460, 175, 1545, 664, 213, 588, 293, 303, 253, 2691, 33985, 7599, 3110, 1182, 9, 1768, 7057, 1828, 4425, 1407, 912, 1019, 1221, 345, 451, 565, 1419, 849, 68, 925, 1485, 2175, 513, 1550, 342, 445, 12622, 5622, 1685, 8974, 4670, 488, 1746, 3984, 872, 3875, 322, 2622, 58, 1206, 524, 1363, 1191, 1473, 265, 5644, 3161, 9223, 3355, 1792, 3475, 806, 4946, 1569, 528, 632, 413, 1021, 1055, 2011, 2450, 505, 795, 1777, 1427, 1923, 169, 1214, 5285, 189, 283, 6051, 840, 1030, 3845, 2373, 370, 334, 672, 187, 1827, 1625, 761, 981, 537, 13, 1172, 170, 25, 1519, 2887, 1213, 321, 2624, 98, 547, 568, 726, 668, 8, 627, 1035, 1065, 212, 1581, 348, 209, 174, 65, 4261, 1065, 586, 11058, 2839, 5628, 3025, 801, 511, 1416, 850, 1095, 293, 2134, 1054, 1010, 464, 2228, 1872, 2363, 888, 430, 1735, 707, 4683, 914, 1346, 2019, 936, 1034, 2280, 1645, 1205, 188, 805, 887, 585, 282, 694, 320, 924, 8257, 4028, 7105, 2846, 2991, 1260, 1094, 2295, 3508, 1015, 3055, 2402, 1055, 871, 1568, 923, 839, 1933, 830, 4202, 1870, 522, 392, 3220, 729, 1698, 1549, 2963, 1067, 334, 1478, 1683, 623, 5640, 916, 614, 414, 1872, 601, 1029, 1064, 1068, 694, 1657, 7565, 9740, 4988, 451, 4634, 3851, 1525, 543, 2339, 4196, 4062, 502, 800, 3195, 301, 611, 1099, 724, 9840, 716, 3032, 880, 3309, 2680, 4284, 3095, 2275, 1246, 3572, 4855, 3428, 4031, 8134, 3761, 519, 2786, 904, 1326, 1026, 3290, 643, 849, 486, 505, 5711, 3630, 6521, 1457, 5309, 4764, 4367, 6153, 1055, 728, 6106, 1346, 20792, 8977, 4273, 7972, 2683, 24707, 10562, 17205, 6209, 18993, 30591, 15235, 27892, 17136, 125915, 0, 156, 34, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 1, 0, 0, 0, 0, 0, 0, 0, 1, 13, 2726, 1148, 1832, 727, 163, 158, 101, 61, 9, 5, 5, 90, 85, 69, 91, 20, 4, 203, 268, 29, 84, 93, 243, 3497, 11053, 7232, 1, 368, 491, 130, 182, 465, 752, 367, 37, 520, 524, 452, 803, 1136, 449, 110, 105, 403, 116, 165, 159, 102, 62, 7, 8, 129, 1, 0, 89, 109, 84, 68, 90, 21, 5, 202, 270, 30, 268, 94, 85, 244, 4482, 956, 20601, 2, 16201, 3081, 4484, 5250, 906, 590, 251, 586, 1531, 1363, 186, 143, 1851, 3766, 546, 5468, 115, 314, 201, 108, 1643, 127, 697, 340, 659, 499, 122, 328, 425, 514, 206, 5, 73, 456, 34, 30, 30, 112, 258, 23, 70, 339, 8, 266, 158, 72, 173, 164, 39, 377, 4657, 1920, 967, 3155, 148, 431, 555, 1263, 299, 612, 864, 1177, 1549, 356, 468, 109, 361, 426, 58, 127, 186, 321, 130, 799, 1992, 744, 86, 721, 693, 271, 257, 122, 133, 932, 838, 398, 609, 851, 354, 215, 82, 406, 76, 268, 94, 82, 271, 125, 208, 1995, 1297, 245, 315, 156, 326, 165, 1845, 2135, 80, 260, 178, 114, 211, 274, 145, 127, 60, 57, 102, 970, 546, 126, 636, 183, 443, 90, 432, 190, 50, 194, 19, 142, 209, 782, 466, 2332, 398, 116, 388, 19, 936, 510, 478, 663, 10, 481, 259, 12, 837, 433, 629, 435, 303, 101, 937, 39, 355, 71, 312, 1545, 1553, 23, 430, 143, 157, 80, 108, 399, 1095, 2, 87, 130, 423, 1612, 297, 47, 158, 511, 334, 139, 188, 97, 211, 885, 4784, 151, 1094, 246, 533, 457, 306, 400, 1012, 320, 209, 182, 66, 231, 16, 161, 413, 49, 328, 624, 460, 538, 10, 1035, 183, 4, 4730, 209, 1719, 1029, 177, 364, 70, 195, 207, 1672, 115, 210, 392, 366, 662, 465, 394, 711, 134, 1235, 25, 487, 323, 1444, 1021, 211, 356, 211, 213, 1395, 1036, 298, 83, 116, 306, 184, 200, 10, 202, 357, 5, 109, 81, 9, 1829, 1942, 324, 10, 429, 229, 395, 2, 178, 1064, 1047, 453, 11, 79, 921, 20, 738, 104, 638, 595, 320, 87, 261, 2, 249, 659, 210, 272, 247, 10, 59, 102, 249, 598, 108, 769, 405, 284, 559, 327, 251, 126, 46, 161, 676, 110, 193, 211, 308, 922, 82, 13, 58, 562, 1048, 78, 6, 525, 508, 334, 938, 182, 77, 157, 178, 694, 365, 272, 128, 40, 5, 110, 213, 284, 388, 38, 2, 200, 3, 55, 474, 73, 134, 2, 643, 108, 217, 149, 8, 4, 117, 190, 113, 196, 366, 123, 212, 159, 4, 189, 213, 6, 2, 273, 406, 235, 98, 425, 111, 127, 232, 7, 671, 5, 2, 104, 875, 223, 238, 304, 316, 191, 1013, 41, 259, 110, 167, 362, 747, 62, 89, 319, 776, 473, 114, 256, 205, 3, 208, 1, 8, 181, 315, 188, 461, 179, 214, 333, 127, 411, 276, 74, 81, 361, 211, 935, 119, 69, 133, 560, 15, 195, 64, 38, 539, 350, 799, 172, 271, 718, 12, 178, 387, 134, 290, 85, 129, 237, 472, 48, 61, 0, 561, 639, 55, 328, 11, 459, 4, 516, 272, 86, 365, 996, 194, 292, 250, 248, 313, 560, 1937, 230, 252, 314, 129, 179, 353, 10, 216, 166, 1011, 123, 75, 1544, 376, 530, 97, 44, 337, 337, 125, 51, 390, 683, 554, 1068, 45, 219, 1004, 136, 122, 201, 805, 399, 289, 489, 376, 1433, 436, 303, 126, 1022, 671, 103, 375, 555, 980, 746, 207, 71, 559, 354, 6510, 1685, 572, 705, 102, 681, 191, 1166, 4894, 2714, 835, 563, 255, 937, 175, 1433, 102, 1992, 4703, 210, 1109, 107, 92, 811, 61, 422, 202, 162, 4075, 0, 513, 1386, 320, 385, 819, 327, 1595, 512, 623, 5, 101, 564, 2757, 1291, 374, 2113, 126, 3566, 423, 990, 322, 1479, 124, 9181, 21501, 402, 167, 110, 104, 43, 145, 110, 90, 4, 3, 34, 39, 176, 2, 53, 179, 37, 79, 10, 5, 5, 59, 0, 9, 339, 24, 91, 39, 63, 108, 928, 5137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1541, 676, 122, 485, 415, 344, 127, 148, 443, 243, 476, 104, 71, 629, 236, 300, 279, 416, 340, 295, 36, 69, 319, 19, 198, 88, 176, 95, 1130, 102, 177, 340, 194, 260, 402, 312, 140, 1445, 7892, 0, 138, 310, 82, 217, 56, 104, 370, 158, 496, 43, 233, 172, 316, 76, 108, 121, 0, 104, 78, 299, 103, 144, 272, 44, 143, 143, 62, 90, 126, 167, 0, 128, 149, 266, 175, 152, 137, 58, 91, 50, 321, 93, 63, 91, 142, 103, 44, 3, 70, 151, 2, 136, 86, 415, 174, 130, 297, 235, 38, 92, 250, 210, 232, 278, 320, 63, 187, 290, 28, 122, 235, 230, 69, 288, 103, 395, 85, 34, 393, 57, 150, 88, 365, 917, 11, 39, 270, 4, 68, 84, 319, 55, 103, 20, 60, 68, 94, 199, 236, 43, 87, 148, 83, 514, 31, 2, 368, 187, 269, 94, 228, 1075, 2105, 138, 149, 268, 141, 265, 196, 293, 176, 339, 277, 31, 320, 139, 731, 263, 47, 62, 246, 6032, 5, 8, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 1520, 151, 898, 69, 246, 73, 31, 111, 18, 209, 171, 991, 276, 5865, 8057, 1, 2, 461, 62, 394, 629, 26, 128, 80, 289, 213, 424, 375, 63, 71, 160, 169, 290, 64, 74, 32, 42, 74, 19, 210, 456, 9, 834, 641, 445, 49, 8680, 5869, 686, 1105, 948, 1062, 822, 1408, 860, 79, 410, 29, 189, 665, 411, 43, 63, 49, 315, 21, 190, 56, 92, 250, 49, 612, 328, 12, 402, 135, 217, 76, 562, 1027, 246, 2496, 39, 2402, 4063, 1669, 71, 83, 212, 199, 521, 41, 3, 95, 167, 77, 17, 8, 95, 8, 74, 36, 11, 11, 41, 41, 59, 179, 58, 59, 59, 425, 4906, 2, 578, 138, 1283, 151, 118, 139, 400, 569, 379, 341, 432, 232, 39, 169, 507, 296, 4, 63, 76, 165, 170, 215, 62, 80, 151, 166, 271, 1115, 154, 117, 318, 59, 97, 364, 119, 154, 1, 274, 279, 158, 1, 60, 28, 2, 139, 77, 298, 32, 136, 120, 45, 191, 50, 519, 300, 592, 296, 180, 192, 182, 275, 167, 1, 152, 339, 388, 19, 75, 67, 97, 5, 76, 57, 512, 30, 190, 422, 245, 119, 199, 2, 99, 115, 44, 204, 45, 6, 109, 463, 65, 200, 150, 3, 22, 125, 65, 57, 93, 89, 163, 401, 1, 50, 0, 100, 423, 273, 366, 145, 151, 275, 106, 167, 80, 99, 4, 6, 47, 702, 142, 44, 82, 146, 520, 138, 304, 37, 76, 21, 253, 111, 75, 50, 150, 377, 585, 1, 86, 134, 46, 650, 85, 155, 1141, 13, 98, 97, 24, 186, 829, 149, 1, 210, 132, 2, 262, 124, 60, 190, 2691, 2077, 391, 49, 75, 90, 228, 122, 8, 72, 34, 210, 295, 150, 195, 171, 26, 58, 127, 4, 76, 98, 186, 138, 252, 1, 161, 0, 111, 2466, 637, 349, 570, 961, 58, 670, 146, 2, 185, 149, 164, 113, 581, 253, 246, 129, 68, 107, 918, 3588, 181, 833, 1391, 1914, 131, 907, 26, 106, 509, 182, 2, 1, 102, 258, 95, 55, 293, 19, 122, 111, 103, 47, 4, 101, 229, 357, 355, 150, 1723, 149, 363, 578, 1046, 1395, 63, 124, 338, 83, 55, 343, 60, 378, 181, 183, 20, 147, 248, 1462, 48, 70, 180, 148, 90, 284, 348, 126, 124, 189, 79, 121, 168, 144, 76, 233, 392, 696, 430, 181, 55, 1, 204, 594, 162, 154, 38, 219, 280, 193, 183, 236, 724, 1220, 797, 406, 356, 1, 13, 402, 51, 221, 168, 399, 1, 101, 134, 64, 145, 1354, 262, 459, 108, 138, 37, 379, 426, 239, 1073, 334, 738, 521, 387, 126, 27, 83, 130, 197, 275, 559, 43, 599, 199, 2, 73, 29, 885, 374, 84, 59, 254, 48, 188, 5, 1035, 250, 5, 3, 507, 2466, 186, 125, 522, 89, 595, 302, 682, 25, 52, 54, 256, 147, 630, 96, 185, 1, 118, 103, 656, 187, 255, 300, 52, 75, 367, 47, 220, 68, 167, 259, 149, 35, 94, 4, 166, 78, 342, 779, 38, 580, 84, 2, 67, 483, 18, 198, 59, 121, 165, 152, 170, 194, 27, 142, 0, 120, 51, 333, 42, 221, 378, 98, 541, 247, 321, 1015, 323, 167, 67, 98, 86, 196, 425, 594, 445, 215, 1592, 148, 946, 693, 307, 1844, 5712, 9114, 194, 121, 25, 6, 79, 2, 0, 65, 224, 1, 28, 332, 0, 112, 62, 455, 25, 206, 102, 68, 134, 272, 359, 731, 6116, 0, 0, 0, 0, 0, 0, 0, 725, 82, 124, 47, 158, 56, 683, 24, 128, 115, 289, 209, 173, 384, 208, 237, 661, 555, 4042, 196, 32, 681, 81, 120, 123, 24, 5, 80, 3, 46, 1, 66, 159, 38, 39, 349, 57, 10, 2, 10, 27, 158, 242, 93, 57, 16, 67, 498, 116, 110, 140, 54, 31, 157, 488, 427, 288, 37, 92, 137, 36, 56, 312, 60, 402, 15, 87, 68, 321, 0, 90, 65, 368, 89, 95, 650, 167, 1224, 2185, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21, 6152, 2662, 2733, 453, 5823, 205, 974, 53, 94, 69, 243, 189, 96, 338, 102, 1773, 178, 141, 46, 314, 671, 491, 69, 1553, 12872, 5131, 1, 552, 227, 1427, 252, 119, 144, 152, 38, 2550, 747, 126, 35, 612, 767, 1086, 51, 158, 1080, 87, 158, 159, 88, 466, 44, 1136, 62, 159, 177, 177, 160, 211, 313, 264, 228, 627, 2617, 309, 67, 3924, 802, 206, 88, 185, 315, 792, 253, 768, 159, 54, 96, 263, 158, 70, 120, 245, 188, 97, 84, 292, 65, 176, 227, 89, 573, 306, 185, 178, 286, 348, 90, 4855, 401, 119, 365, 192, 525, 285, 45, 982, 449, 227, 524, 66, 158, 153, 71, 2181, 210, 35159, 34294, 5946, 3892, 1408, 1740, 107, 19, 783, 116, 444, 15, 164, 1791, 1175, 286, 625, 22, 671, 1312, 1236, 265, 923, 182, 3186, 434, 5, 885, 2310, 1738, 257, 244, 1675, 3869, 3185, 4461, 1323, 2180, 433, 616, 586, 28, 329, 306, 4, 411, 1, 33, 152, 145, 1073, 877, 2994, 3870, 916, 1682, 1130, 1701, 1127, 977, 674, 528, 1300, 680, 270, 495, 370, 1534, 90, 568, 190, 245, 150, 637, 3822, 1934, 2466, 1114, 1063, 629, 169, 691, 213, 134, 94, 634, 388, 380, 877, 216, 1173, 687, 576, 863, 437, 889, 511, 289, 923, 8, 119, 3018, 773, 137, 172, 213, 508, 2, 172, 562, 6, 128, 515, 418, 387, 1363, 43, 215, 389, 387, 636, 3, 4, 120, 282, 391, 59, 241, 295, 1479, 135, 144, 1543, 600, 472, 189, 426, 87, 1213, 258, 96, 161, 4, 428, 197, 789, 387, 13, 251, 8, 1214, 403, 293, 557, 9, 318, 250, 368, 104, 459, 138, 1412, 255, 453, 7, 137, 459, 516, 297, 2023, 173, 136, 214, 379, 313, 509, 303, 191, 187, 218, 924, 141, 132, 222, 529, 157, 1020, 404, 547, 287, 756, 460, 626, 23, 599, 469, 514, 160, 145, 585, 368, 1174, 221, 359, 690, 422, 390, 679, 727, 142, 133, 52, 496, 267, 388, 146, 97, 2701, 173, 92, 887, 2, 558, 298, 371, 725, 183, 369, 10, 1499, 1498, 1894, 1093, 2119, 1471, 1990, 1693, 113, 1099, 748, 17, 185, 106, 2, 8, 184, 2, 661, 89, 172, 181, 12, 186, 9, 6, 3, 1528, 778, 1367, 571, 3, 3, 172, 5, 11, 537, 1352, 1633, 995, 5, 802, 290, 1, 1, 1543, 1137, 586, 611, 266, 262, 102, 797, 127, 304, 664, 14, 158, 321, 1, 1290, 2165, 571, 28, 153, 326, 8, 2, 4045, 3058, 2880, 672, 418, 2, 99, 6, 318, 5, 6788, 9355, 319, 444, 1760, 201, 88, 1415, 137, 99, 217, 58, 131, 17457, 977, 2715, 528, 27, 2285, 402, 386, 387, 174, 116, 427, 4, 26, 139, 2, 129, 1243, 19084, 13466, 2809, 2660, 5091, 909, 653, 367, 469, 1181, 3, 96, 484, 3, 1155, 257, 123, 13, 613, 12, 190, 389, 651, 4, 631, 18541, 2151, 1532, 3037, 460, 547, 227, 445, 277, 34, 10, 320, 135, 0, 13359, 8775, 10834, 2915, 1469, 696, 1020, 550, 691, 771, 220, 484, 114, 5, 7, 285, 102, 428, 922, 1, 303, 1, 5553, 5610, 3303, 1612, 272, 851, 1139, 458, 141, 303, 473, 2, 101, 179, 452, 16, 3, 71, 14, 12699, 2939, 339, 1064, 388, 1410, 367, 609, 186, 132, 1, 9665, 8270, 4866, 1662, 361, 9689, 720, 102, 12, 69, 693, 1007, 7, 1030, 576, 1127, 243, 10, 148, 2023, 18, 157, 81, 866, 385, 7858, 1035, 764, 1618, 4689, 272, 3, 947, 792, 389, 234, 188, 424, 925, 26, 73, 670, 4634, 2001, 1328, 6231, 1385, 530, 449, 218, 870, 1120, 594, 180, 763, 317, 157, 774, 1, 2261, 170, 8168, 94, 401, 225, 221, 12, 1298, 451, 371, 100, 372, 172, 357, 4754, 296, 300, 468, 634, 389, 28, 81, 5, 199, 295, 3220, 506, 133, 192, 452, 25, 179, 6711, 2851, 4022, 2916, 1412, 2144, 555, 979, 93, 1818, 958, 1179, 2428, 923, 215, 805, 795, 2, 145, 145, 8135, 376, 190, 1, 193, 247, 326, 2437, 0, 139, 1184, 254, 1486, 191, 368, 1035, 1915, 202, 4, 184, 278, 2100, 142, 2, 565, 685, 563, 540, 477, 368, 168, 97, 390, 1446, 272, 134, 288, 518, 85, 591, 484, 1566, 10, 236, 564, 639, 691, 389, 1026, 818, 418, 523, 790, 207, 562, 669, 1020, 132, 220, 631, 255, 70, 1192, 242, 496, 156, 641, 434, 205, 468, 18, 2100, 4, 220, 291, 184, 175, 810, 388, 348, 363, 835, 469, 1201, 948, 12, 706, 157, 157, 288, 6, 1139, 369, 938, 811, 954, 910, 563, 62, 219, 7, 3640, 666, 125, 750, 357, 261, 979, 1782, 9, 462, 387, 417, 188, 235, 565, 389, 151, 1218, 448, 2676, 1570, 1604, 565, 562, 1121, 5424, 974, 215, 862, 221, 498, 252, 377, 1169, 137, 91, 356, 225, 372, 387, 551, 167, 2278, 105, 447, 77, 298, 1789, 573, 2769, 340, 603, 386, 220, 514, 130, 5782, 191, 430, 178, 478, 1492, 3, 388, 2776, 110, 145, 90, 434, 260, 3, 511, 1217, 629, 390, 1550, 155, 586, 3056, 258, 1276, 214, 144, 1838, 216, 1578, 339, 510, 868, 369, 17, 1216, 516, 602, 761, 1011, 552, 541, 1522, 2058, 213, 929, 2500, 297, 99, 433, 513, 5, 158, 1352, 585, 8240, 3625, 2576, 2001, 1570, 1733, 687, 527, 1233, 8104, 18446, 8, 54, 0, 0, 1746, 193, 324, 192, 428, 170, 1009, 4933, 37, 16, 749, 1328, 516, 259, 562, 94, 2300, 79, 1030, 588, 1648, 2611, 387, 783, 95, 8, 389, 2457, 2767, 379, 615, 1090, 1136, 0, 398, 549, 3830, 864, 954, 2472, 509, 880, 1504, 1982, 2070, 22941, 35716, 380, 90, 90, 133, 48, 65, 0, 33, 461, 69, 147, 2, 175, 127, 144, 198, 325, 233, 748, 866, 549, 3462, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1380, 319, 747, 236, 297, 634, 340, 91, 89, 96, 731, 950, 237, 78, 249, 448, 4622, 226, 606, 79, 396, 255, 479, 1310, 314, 190, 246, 377, 365, 1236, 488, 937, 2074, 1324, 3548, 3541, 5577, 39, 121, 78, 454, 140, 401, 196, 317, 67, 169, 81, 338, 90, 176, 264, 50, 272, 241, 58, 134, 633, 632, 49, 292, 50, 66, 120, 90, 293, 90, 1, 95, 224, 506, 766, 88, 99, 463, 100, 77, 248, 228, 171, 45, 427, 272, 729, 103, 168, 342, 279, 231, 1054, 1253, 332, 1232, 131, 95, 426, 453, 258, 95, 193, 271, 126, 601, 189, 320, 425, 271, 203, 156, 102, 765, 254, 101, 165, 155, 157, 507, 225, 249, 296, 26, 313, 189, 100, 93, 239, 164, 492, 62, 147, 4, 227, 99, 424, 90, 210, 151, 332, 509, 240, 369, 191, 50, 348, 646, 691, 554, 433, 364, 1005, 89, 466, 1625, 1105, 1425, 1594, 832, 1466, 2380, 2885, 6688, 5993, 17297, 43, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 4, 9733, 809, 369, 3484, 330, 140, 68, 6, 8, 72, 17, 22, 299, 440, 1663, 181, 1090, 260, 3189, 8554, 4775, 139, 259, 2753, 280, 160, 154, 421, 199, 446, 265, 326, 337, 2735, 1366, 137, 197, 460, 20, 140, 327, 304, 132, 89, 575, 15, 427, 53, 1175, 3698, 591, 553, 395, 141, 161, 155, 69, 90, 2, 0, 0, 0, 0, 71, 18, 422, 23, 57, 247, 1719, 1142, 726, 229, 623, 2303, 1060, 286, 106, 44, 80, 60, 30, 121, 70, 93, 1016, 131, 268, 119, 65, 61, 861, 1237, 436, 54, 406, 62, 4833, 1507, 4, 23933, 15, 6, 373, 10, 17, 43, 10, 8, 118, 16122, 1605, 876, 2790, 1532, 526, 157, 578, 1009, 102, 70, 225, 197, 85, 1072, 4376, 985, 1227, 397, 846, 1474, 175, 2928, 196, 802, 563, 2542, 418, 239, 1, 390, 194, 395, 425, 737, 466, 39, 184, 1702, 2426, 752, 852, 355, 450, 155, 241, 569, 66, 129, 7, 1359, 119, 601, 2009, 886, 1586, 107, 375, 267, 20, 501, 516, 432, 52, 196, 271, 2, 108, 41, 32, 274, 164, 3345, 23, 647, 315, 918, 318, 827, 319, 1156, 672, 441, 275, 695, 96, 248, 1853, 755, 1055, 754, 470, 104, 811, 242, 188, 254, 307, 278, 58, 492, 350, 107, 295, 892, 501, 519, 465, 247, 184, 183, 160, 237, 122, 375, 142, 5, 316, 16, 182, 544, 1, 103, 580, 324, 249, 3, 553, 83, 532, 93, 477, 17, 319, 223, 339, 8, 138, 428, 142, 2, 262, 124, 75, 36, 268, 28, 158, 155, 228, 502, 198, 7, 201, 396, 262, 355, 591, 221, 320, 1, 125, 202, 101, 156, 347, 811, 520, 71, 226, 673, 203, 198, 62, 237, 25, 238, 206, 157, 867, 348, 276, 207, 1430, 1326, 216, 21, 839, 937, 112, 18, 80, 181, 278, 146, 545, 19, 436, 157, 20, 234, 387, 63, 30, 30, 72, 227, 49, 100, 57, 97, 25, 991, 152, 104, 76, 226, 747, 159, 206, 12, 1848, 178, 320, 151, 325, 26, 138, 309, 104, 181, 133, 200, 85, 97, 199, 964, 284, 366, 249, 70, 168, 184, 653, 1154, 3, 697, 287, 288, 79, 289, 212, 176, 313, 744, 225, 992, 813, 225, 400, 437, 522, 467, 582, 310, 206, 497, 2125, 180, 460, 135, 593, 141, 229, 57, 164, 919, 495, 192, 20, 118, 248, 2, 1041, 238, 380, 189, 101, 1033, 336, 416, 199, 398, 751, 199, 196, 599, 193, 748, 1513, 316, 380, 56, 201, 475, 17, 2, 130, 271, 287, 421, 325, 564, 194, 0, 993, 285, 55, 333, 494, 814, 69, 7, 239, 125, 49, 992, 837, 24, 39, 2, 517, 1, 158, 222, 78, 16, 151, 183, 79, 338, 132, 170, 224, 237, 36, 200, 991, 141, 347, 274, 191, 18, 3, 15, 375, 137, 44, 67, 379, 180, 672, 966, 245, 652, 44, 248, 0, 67, 0, 18, 467, 1629, 353, 290, 67, 284, 84, 446, 287, 783, 281, 179, 2, 143, 18, 266, 231, 14, 269, 338, 222, 183, 384, 260, 1384, 47, 226, 993, 326, 30, 470, 397, 145, 165, 75, 9, 2, 705, 254, 58, 1152, 471, 975, 66, 1357, 6, 4, 156, 1, 4, 261, 466, 240, 527, 687, 35, 378, 179, 84, 1118, 100, 193, 0, 288, 318, 324, 102, 221, 179, 4, 560, 14, 186, 0, 5, 179, 563, 1, 161, 16, 198, 317, 131, 365, 273, 75, 78, 195, 114, 137, 15, 137, 75, 281, 600, 461, 61, 257, 182, 342, 3, 642, 721, 561, 72, 2342, 100, 376, 669, 178, 138, 65, 323, 86, 241, 813, 18, 401, 314, 204, 8, 579, 322, 3356, 2984, 2993, 377, 79, 209, 186, 20, 832, 1747, 623, 1137, 306, 2, 222, 2, 158, 1, 1895, 1526, 1051, 2, 272, 383, 307, 121, 181, 227, 354, 457, 160, 136, 6625, 5055, 113, 67, 352, 585, 841, 72, 263, 122, 145, 22, 189, 26, 468, 13421, 310, 283, 124, 815, 778, 1310, 779, 538, 744, 148, 113, 1, 652, 1023, 546, 10, 274, 131, 1946, 619, 6481, 4530, 3079, 1237, 3661, 2797, 262, 347, 503, 613, 291, 580, 78, 266, 269, 280, 27, 228, 137, 999, 7, 201, 766, 50, 2579, 3415, 1, 108, 385, 466, 87, 3, 311, 302, 283, 154, 25, 316, 381, 17, 282, 268, 132, 139, 88, 114, 242, 291, 1801, 21, 8, 72, 367, 1190, 31, 283, 7, 386, 2, 64, 109, 653, 2406, 2333, 880, 291, 1, 207, 983, 1331, 5, 168, 75, 2051, 3171, 527, 183, 2337, 46, 84, 386, 1604, 317, 18, 644, 250, 153, 222, 238, 2415, 543, 1858, 2777, 820, 597, 495, 252, 504, 545, 278, 291, 282, 159, 4, 283, 400, 2249, 291, 290, 526, 1192, 1091, 308, 176, 482, 178, 889, 4071, 1518, 124, 46, 375, 597, 361, 342, 281, 505, 238, 4226, 387, 673, 544, 478, 176, 182, 912, 837, 424, 2, 425, 265, 320, 501, 392, 547, 2475, 4266, 819, 654, 83, 206, 254, 343, 7, 496, 536, 143, 346, 387, 403, 925, 578, 1254, 342, 995, 647, 859, 492, 786, 537, 400, 477, 343, 318, 106, 820, 47, 50, 70, 177, 169, 373, 375, 596, 561, 101, 74, 991, 209, 1119, 147, 204, 1404, 214, 319, 178, 222, 1252, 2444, 9, 420, 209, 325, 401, 680, 269, 280, 427, 992, 741, 654, 358, 342, 357, 268, 42, 279, 345, 595, 264, 2356, 105, 386, 444, 317, 309, 188, 1290, 112, 152, 136, 0, 617, 3232, 846, 823, 6, 279, 753, 105, 200, 211, 1080, 342, 267, 876, 3042, 237, 651, 282, 307, 850, 13890, 24324, 395, 1421, 997, 3603, 91, 260, 0, 277, 59, 248, 25, 389, 648, 837, 643, 1522, 122, 2548, 0, 0, 0, 0, 0, 0, 0, 0, 3551, 938, 548, 151, 2832, 135, 285, 156, 24, 237, 907, 60, 391, 77, 3, 272, 251, 1561, 2640, 845, 1954, 258, 5256, 0, 687, 199, 234, 1160, 195, 473, 953, 142, 407, 43, 323, 16, 865, 23, 91, 49, 194, 593, 863, 152, 1015, 2244, 34, 69, 197, 406, 39, 86, 190, 17, 466, 730, 159, 792, 2158, 0, 266, 178, 166, 575, 452, 162, 70, 40, 505, 134, 143, 63, 89, 92, 166, 121, 69, 190, 135, 68, 177, 196, 2, 155, 116, 157, 23, 165, 143, 58, 405, 142, 49, 42, 492, 165, 321, 128, 83, 85, 221, 244, 185, 142, 491, 76, 631, 2, 134, 90, 641, 262, 172, 233, 57, 133, 140, 248, 133, 138, 16, 2572, 393, 1070, 269, 1520, 0, 1984, 3231, 128, 3979, 1755, 151, 2447, 824, 10957, 2081, 13, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1733, 299, 70, 91, 309, 31, 176, 315, 41, 17, 10, 281, 2, 6, 86, 6, 104, 22, 129, 4472, 61, 3090, 6402, 66, 681, 54, 248, 717, 259, 45, 72, 92, 37, 45, 41, 191, 32, 178, 82, 42, 42, 155, 42, 16, 20, 0, 185, 99, 3, 2, 0, 1, 0, 0, 258, 63, 21, 5, 199, 67, 21, 50, 83, 39, 489, 2380, 3117, 255, 546, 6738, 1, 2, 5067, 3235, 2500, 1792, 923, 177, 249, 286, 320, 106, 306, 152, 592, 154, 284, 155, 386, 48, 175, 1, 165, 76, 158, 308, 392, 234, 122, 131, 455, 705, 674, 850, 1554, 662, 584, 479, 498, 145, 443, 68, 334, 122, 248, 243, 86, 118, 108, 144, 40, 126, 4, 40, 46, 226, 120, 1312, 4044, 2523, 24, 2, 651, 889, 857, 147, 477, 632, 310, 127, 130, 110, 109, 92, 87, 12, 146, 61, 166, 108, 517, 16, 93, 518, 77, 233, 204, 49, 321, 456, 7, 234, 156, 191, 118, 341, 396, 885, 357, 399, 320, 158, 163, 193, 64, 316, 57, 136, 110, 225, 214, 130, 158, 44, 644, 209, 69, 255, 113, 26, 628, 98, 356, 201, 93, 126, 1, 178, 519, 62, 84, 406, 1, 463, 42, 136, 251, 35, 71, 148, 84, 278, 93, 29, 149, 187, 392, 85, 26, 126, 168, 210, 118, 1, 218, 102, 107, 433, 674, 94, 133, 104, 30, 70, 186, 42, 112, 131, 304, 161, 67, 89, 519, 137, 132, 149, 477, 520, 477, 0, 192, 196, 22, 24, 71, 407, 81, 11, 117, 0, 25, 3, 147, 14, 232, 521, 75, 77, 0, 78, 0, 309, 87, 188, 157, 26, 2, 0, 0, 256, 74, 187, 418, 86, 37, 0, 362, 122, 0, 0, 0, 0, 112, 27, 164, 69, 240, 258, 104, 357, 168, 110, 159, 129, 386, 6, 0, 54, 69, 4, 72, 111, 0, 691, 68, 41, 186, 108, 194, 303, 74, 199, 690, 75, 198, 254, 2, 50, 52, 165, 65, 208, 174, 45, 152, 49, 1483, 630, 380, 98, 60, 282, 58, 164, 318, 1, 133, 194, 253, 256, 1426, 855, 2227, 127, 359, 758, 389, 85, 397, 101, 404, 168, 159, 82, 661, 157, 254, 798, 697, 147, 214, 106, 52, 34, 208, 193, 324, 190, 356, 156, 251, 135, 817, 542, 135, 392, 36, 144, 7, 257, 170, 1126, 651, 1085, 312, 186, 289, 200, 65, 159, 209, 89, 201, 62, 64, 638, 313, 190, 931, 47, 168, 233, 107, 127, 869, 262, 240, 0, 1, 27, 402, 84, 59, 75, 134, 199, 433, 71, 285, 160, 680, 667, 239, 120, 157, 32, 292, 5, 407, 746, 835, 413, 107, 95, 65, 161, 3, 711, 173, 1, 51, 159, 192, 82, 42, 125, 90, 254, 2, 99, 165, 313, 235, 1018, 140, 28, 319, 37, 669, 399, 46, 1, 127, 70, 78, 240, 201, 277, 267, 97, 149, 330, 403, 185, 221, 88, 320, 255, 1, 76, 435, 164, 270, 109, 77, 323, 3, 629, 40, 199, 335, 2, 159, 85, 37, 5, 59, 229, 125, 406, 113, 167, 289, 83, 160, 443, 1, 31, 143, 36, 291, 64, 148, 6, 93, 64, 77, 106, 210, 74, 0, 126, 105, 78, 44, 0, 88, 125, 159, 398, 209, 10, 73, 296, 184, 507, 354, 294, 455, 268, 2, 239, 290, 970, 349, 6, 87, 225, 718, 364, 172, 4, 8284, 21738, 50, 0, 0, 0, 0, 11559, 51, 201, 14, 25, 55, 15, 80, 180, 1, 80, 68, 31, 52, 49, 87, 173, 425, 4908, 0, 0, 0, 0, 1054, 34, 98, 111, 84, 43, 81, 279, 27, 444, 42, 51, 171, 37, 177, 42, 857, 7549, 0, 0, 113, 299, 286, 392, 199, 33, 96, 112, 13, 140, 85, 44, 80, 54, 16, 258, 97, 177, 3, 79, 26, 806, 41, 80, 474, 84, 78, 259, 13, 197, 1630, 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 4, 12, 2047, 377, 183, 223, 286, 181, 310, 2, 2, 94, 27, 353, 6568, 7041, 10, 2, 2, 73, 56, 1341, 626, 2, 285, 94, 74, 3, 47, 67, 229, 158, 132, 195, 63, 74, 183, 135, 1, 2, 1, 1, 0, 1, 97, 29, 57, 152, 210, 2, 9172, 3648, 1118, 129, 2692, 290, 438, 74, 191, 103, 164, 877, 161, 43, 17, 328, 95, 151, 132, 1, 112, 114, 3, 318, 535, 127, 578, 298, 143, 427, 185, 570, 29, 926, 374, 972, 127, 2545, 720, 168, 1136, 522, 124, 779, 548, 148, 160, 570, 59, 38, 285, 34, 87, 304, 1, 250, 119, 722, 68, 54, 407, 330, 71, 423, 148, 134, 368, 81, 32, 105, 245, 1073, 6176, 2, 2, 153, 433, 290, 114, 58, 133, 106, 74, 151, 357, 75, 176, 248, 137, 89, 114, 135, 392, 459, 64, 7, 133, 112, 151, 451, 138, 70, 51, 80, 36, 11, 594, 12, 75, 158, 213, 203, 401, 173, 349, 173, 211, 47, 68, 131, 29, 13, 51, 84, 8, 115, 38, 52, 9, 163, 168, 110, 104, 331, 75, 119, 16, 1, 59, 105, 282, 51, 111, 333, 595, 212, 201, 132, 332, 162, 82, 283, 79, 115, 44, 333, 8, 0, 200, 114, 17, 334, 155, 120, 152, 130, 0, 92, 20, 1, 111, 596, 2, 175, 142, 0, 3, 266, 196, 197, 130, 105, 126, 174, 129, 155, 63, 11, 2, 179, 76, 18, 81, 60, 100, 200, 175, 114, 1, 73, 3, 0, 28, 14, 206, 72, 40, 152, 125, 146, 15, 159, 2, 111, 63, 113, 212, 180, 44, 0, 202, 0, 110, 2, 6, 180, 12, 211, 150, 30, 211, 367, 1, 501, 189, 258, 52, 5, 96, 171, 97, 148, 300, 332, 163, 47, 36, 333, 42, 12, 110, 0, 430, 95, 577, 291, 136, 4, 72, 131, 1, 0, 78, 58, 55, 58, 444, 128, 143, 103, 59, 381, 101, 636, 971, 127, 519, 114, 20, 70, 49, 90, 90, 1128, 546, 111, 1137, 755, 30, 151, 230, 43, 127, 104, 9, 132, 230, 923, 303, 34, 56, 263, 62, 356, 239, 182, 174, 140, 6, 254, 152, 290, 90, 252, 131, 134, 114, 34, 221, 216, 15, 78, 0, 83, 153, 137, 14, 105, 67, 102, 46, 1235, 459, 324, 126, 200, 349, 425, 117, 43, 163, 180, 207, 145, 34, 605, 0, 210, 773, 62, 137, 91, 1509, 115, 322, 12, 382, 47, 57, 13, 1308, 104, 1, 5, 261, 211, 202, 143, 3, 428, 80, 239, 596, 147, 151, 128, 366, 103, 50, 90, 133, 365, 126, 160, 81, 61, 184, 147, 6, 1, 111, 79, 1, 81, 57, 264, 132, 159, 90, 180, 60, 3, 39, 116, 1, 142, 127, 103, 3, 57, 137, 345, 176, 660, 29, 126, 106, 88, 409, 4, 303, 597, 21, 6, 285, 123, 131, 74, 153, 89, 0, 260, 596, 400, 152, 261, 132, 95, 131, 1026, 127, 127, 87, 127, 98, 595, 130, 473, 174, 209, 187, 852, 346, 424, 261, 205, 365, 1343, 1993, 73, 173, 309, 287, 102, 208, 2, 182, 112, 185, 206, 168, 1253, 201, 136, 111, 152, 963, 0, 70, 48, 483, 449, 258, 401, 149, 870, 725, 460, 2, 179, 142, 136, 79, 345, 581, 0, 229, 1179, 0, 1225, 97, 135, 79, 27, 179, 1283, 161, 285, 31, 1, 16, 504, 933, 344, 115, 135, 3, 11, 512, 96, 5131, 8598, 85, 38, 90, 42, 52, 17, 8, 2, 52, 28, 93, 9, 18, 28, 350, 204, 702, 1272, 6167, 0, 0, 531, 77, 78, 72, 88, 99, 79, 200, 56, 272, 187, 217, 437, 1628, 4374, 70, 44, 484, 12, 77, 114, 91, 73, 128, 53, 2, 16, 61, 100, 1, 55, 38, 4, 23, 544, 111, 30, 104, 549, 556, 14, 26, 175, 554, 38, 77, 51, 27, 92, 7, 0, 164, 51, 151, 72, 43, 196, 65, 582, 96, 196, 131, 134, 1156, 4602, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 1, 0, 0, 1, 0, 0, 2, 1, 0, 0, 0, 4, 1, 0, 0, 1, 0, 1, 0, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 4, 0, 4, 0, 1, 0, 2, 0, 0, 1, 0, 3, 4, 0, 0, 0, 0, 0, 0, 1, 0, 2, 4, 2, 0, 1, 0, 2, 0, 3, 0, 3, 0, 4, 0, 1, 0, 2, 0, 0, 1, 0, 1, 0, 2, 1, 2, 4, 2, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 4, 0, 1, 1, 1, 1, 1, 2, 1, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 2, 0, 1, 1, 1, 40, 32, 8, 12, 13, 1, 31, 27, 14, 16, 5, 4, 27, 8, 8, 4, 4, 13, 44, 14, 4, 4, 3, 6, 27, 16, 2, 21, 26, 26, 5, 5, 4, 2, 1, 10, 10, 10, 4, 8, 1, 2, 4, 4, 36, 18, 8, 6, 15, 3, 1, 16, 29, 6, 3, 2, 5, 1, 1, 3, 3, 1, 5, 2, 3, 0, 24, 28, 10, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 34, 18, 17, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 23, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 14, 1, 1, 1, 3, 3, 2, 1, 3, 6, 1, 1, 1, 2, 1, 1, 0, 1, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 10, 2, 3, 1, 3, 4, 2, 4, 24, 1, 3, 2, 1, 13, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 23, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 3, 1, 1, 1, 2, 4, 5, 3, 2, 1, 2, 1, 1, 6, 4, 2, 2, 4, 1, 2, 1, 1, 1, 12, 1, 3, 5, 4, 2, 4, 8, 4, 13, 1, 4, 3, 5, 15, 2, 9, 1, 1, 2, 1, 1, 1, 2, 1, 1, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 2, 1, 0, 0, 0, 1, 0, 2, 4, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 2, 1, 0, 0, 0, 1, 1, 0, 0, 3, 3, 0, 0, 0, 1, 0, 1, 0, 2, 0, 1, 2, 1, 0, 0, 1, 3, 0, 0, 1, 0, 1, 0, 1, 0, 2, 1, 8, 8064, 1870, 228, 329, 253, 19, 175, 163, 617, 273, 5, 14, 54, 263, 2806, 13834, 8428, 231, 3, 152, 476, 759, 3, 1, 1001, 139, 168, 145, 165, 5142, 1262, 124, 170, 141, 135, 196, 90, 1105, 941, 125, 171, 371, 311, 331, 255, 5, 0, 0, 176, 110, 50, 614, 272, 6, 14, 136, 5, 15, 55, 264, 318, 197, 2546, 812, 137, 25155, 8, 5, 26933, 339, 1617, 7958, 15102, 867, 22, 83, 109, 1, 271, 202, 1, 528, 187, 3605, 649, 1491, 631, 4, 52, 8, 339, 587, 27, 25, 111, 32, 306, 279, 973, 845, 212, 4025, 12971, 9, 256, 356, 425, 458, 12, 2027, 1809, 2620, 258, 352, 128, 227, 14, 15, 149, 112, 270, 64, 290, 351, 489, 112, 109, 141, 1658, 668, 14811, 163, 8645, 1376, 795, 680, 241, 2326, 2477, 855, 26, 175, 85, 325, 550, 174, 413, 1, 1098, 431, 418, 170, 127, 735, 14614, 3289, 5546, 457, 2382, 708, 512, 459, 559, 222, 561, 130, 406, 220, 482, 190, 648, 781, 1152, 123, 159, 1178, 190, 117, 302, 394, 629, 525, 390, 3247, 531, 1208, 734, 18, 78, 162, 30, 530, 1054, 31, 283, 478, 49, 422, 13, 6, 11, 191, 1132, 194, 118, 148, 114, 505, 1055, 242, 2118, 358, 111, 32, 151, 2182, 232, 275, 303, 800, 330, 153, 142, 28, 6, 176, 477, 190, 324, 551, 460, 124, 52, 630, 328, 0, 83, 0, 1, 2372, 237, 182, 0, 11, 0, 432, 391, 420, 203, 168, 150, 2, 0, 304, 653, 0, 691, 139, 150, 2, 50, 32, 6749, 16865, 139, 162, 2995, 499, 1189, 694, 1161, 661, 976, 552, 371, 347, 534, 61, 60, 389, 8, 389, 57, 6, 475, 266, 55, 1674, 6577, 247, 781, 2161, 527, 1255, 344, 3, 506, 257, 288, 100, 578, 4, 67, 238, 183, 50, 10, 113, 383, 860, 551, 12038, 3898, 1877, 2071, 2634, 1910, 1188, 89, 513, 850, 369, 122, 704, 594, 317, 0, 503, 519, 234, 694, 399, 141, 63, 126, 614, 424, 2319, 360, 718, 692, 420, 140, 188, 271, 438, 139, 242, 94, 566, 112, 29, 4530, 2117, 738, 1134, 2789, 2602, 1994, 75, 509, 475, 432, 219, 33, 17, 222, 397, 334, 99, 428, 209, 723, 2252, 150, 2203, 1859, 470, 1232, 243, 650, 393, 1128, 917, 944, 141, 272, 65, 23, 9, 222, 102, 429, 29, 57, 453, 1036, 703, 197, 1612, 25, 110, 529, 214, 926, 286, 471, 173, 288, 220, 21, 218, 970, 120, 2075, 2213, 227, 1238, 504, 311, 209, 2, 174, 203, 40, 513, 976, 1787, 280, 243, 263, 575, 1075, 356, 259, 230, 2, 136, 286, 275, 306, 623, 325, 254, 95, 488, 869, 233, 2374, 1133, 1050, 205, 113, 266, 592, 74, 397, 29, 206, 108, 168, 274, 438, 218, 342, 529, 412, 651, 68, 849, 195, 801, 69, 335, 1182, 1354, 428, 1038, 597, 288, 259, 618, 1728, 632, 150, 311, 143, 682, 1212, 387, 35, 120, 2030, 1201, 820, 1361, 1366, 303, 442, 396, 74, 22, 347, 508, 696, 33, 1356, 24, 514, 139, 74, 565, 289, 317, 413, 121, 616, 394, 851, 483, 131, 26, 1326, 50, 1936, 530, 28, 505, 1016, 331, 411, 457, 301, 472, 4, 2218, 213, 254, 413, 77, 533, 597, 10, 562, 1000, 280, 3026, 126, 641, 551, 762, 696, 982, 967, 345, 278, 1778, 190, 931, 220, 147, 51, 355, 156, 214, 2093, 191, 2667, 170, 197, 242, 1472, 211, 635, 339, 330, 5, 256, 251, 514, 2367, 149, 71, 221, 573, 1, 333, 617, 412, 946, 28, 285, 326, 7, 196, 241, 640, 539, 428, 550, 529, 1473, 1, 506, 233, 470, 189, 210, 76, 107, 696, 515, 137, 332, 167, 693, 383, 564, 683, 178, 1903, 520, 3005, 236, 398, 639, 549, 437, 97, 219, 598, 1002, 325, 236, 175, 182, 523, 666, 113, 0, 597, 695, 393, 487, 488, 684, 73, 528, 1451, 1428, 2578, 5, 1621, 2387, 8073, 16, 225, 482, 3674, 39, 238, 2930, 8045, 77, 583, 15980, 111, 34304, 14970, 31, 88, 17, 95, 129, 445, 31426, 97, 142, 280, 152, 176, 183, 54, 106, 379, 478, 56, 451, 1360, 17109, 145, 60, 125, 90, 6, 441, 879, 134, 711, 5, 857, 1, 327, 81, 19, 285, 315, 121, 387, 133, 804, 867, 1118, 1594, 1533, 6254, 0, 371, 595, 15, 497, 489, 167, 161, 699, 420, 108, 2, 187, 208, 436, 155, 90, 483, 272, 424, 895, 809, 1276, 2423, 5705, 369, 142, 76, 514, 61, 14, 11, 344, 151, 124, 84, 3, 487, 96, 166, 5, 160, 276, 165, 531, 176, 141, 281, 145, 327, 164, 70, 167, 195, 133, 164, 144, 87, 56, 107, 194, 1, 153, 195, 89, 431, 188, 6, 4830, 66, 134, 125, 179, 154, 175, 385, 400, 663, 381, 4970, 77, 316, 203, 9438, 0, 197, 128, 80, 133, 18, 271, 71, 374, 182, 280, 543, 242, 181, 150, 124, 261, 964, 132, 190, 94, 816, 1549, 413, 166, 358, 1260, 312, 846, 2232, 699, 2188, 2239, 2606, 2459, 14242, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 36, 474, 1, 56, 3710, 54, 7, 59, 93, 25, 106, 38, 250, 18, 138, 243, 613, 607, 589, 2241, 1644, 790, 207, 18, 411, 366, 149, 68, 37, 321, 436, 1311, 127, 1, 5, 23, 10, 2, 2, 1, 78, 299, 78, 17, 77, 155, 323, 24, 141, 523, 278, 568, 313, 140, 16, 31, 39, 18, 47, 160, 64, 437, 21, 14, 79, 52, 5, 6, 266, 35, 3, 79, 7, 41, 18, 3, 94, 5, 22, 18, 4, 1, 13, 45, 47, 3, 5, 5, 15, 17, 2, 25, 59, 65, 11, 371, 72, 2, 49, 85, 11, 31, 10, 4, 157, 135, 2, 57, 53, 3, 41, 26, 27, 7, 24, 117, 49, 28, 34, 18, 44, 27, 25, 92, 302, 414, 175, 6, 25, 88, 101, 72, 47, 7, 4, 391, 407, 476, 106, 49, 87, 55, 21, 15, 20, 7, 7, 6, 5, 703, 328, 342, 19, 58, 21, 241, 21, 5, 12, 2610, 977, 245, 55, 223, 157, 61, 55, 100, 234, 230, 74, 17, 10, 4, 3, 5, 1, 3, 2233, 384, 67, 36, 472, 369, 254, 322, 252, 210, 58, 987, 171, 14, 28, 16, 5, 6, 12, 9, 4, 5, 4, 6, 838, 120, 319, 473, 365, 135, 475, 139, 744, 40, 896, 155, 6, 31, 19, 5, 3, 8, 13, 8, 3, 122, 140, 323, 96, 134, 140, 201, 172, 286, 162, 6, 10, 8, 9, 12, 3, 1, 62, 20, 68, 102, 111, 76, 5, 117, 202, 40, 44, 93, 42, 49, 607, 251, 412, 181, 146, 109, 547, 28, 4, 7, 1, 424, 115, 298, 620, 94, 700, 85, 8, 468, 191, 274, 41, 436, 54, 11, 884, 452, 372, 238, 48, 4, 786, 314, 942, 141, 19, 3, 1615, 2480, 203, 14, 3291, 28, 9, 11846, 311, 36, 16, 3, 4, 4, 3, 1, 4, 10254, 763, 244, 93, 15, 13, 3, 1, 5, 0, 0, 0, 8736, 720, 117, 20, 2, 21, 0, 8293, 376, 7, 8, 1, 1, 0, 0, 7953, 95, 32, 10, 4, 11, 5, 6, 7, 6067, 181, 20, 15, 12, 6, 2, 6, 6, 5, 15, 2, 1, 0, 0, 4373, 108, 48, 42, 20, 5, 1, 2, 18, 16, 1, 0, 0, 0, 0, 0, 0, 2927, 196, 56, 28, 11, 12, 1, 36, 16, 1, 1, 0, 0, 0, 0, 0, 0, 1976, 188, 62, 31, 14, 6, 7, 7, 32, 40, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1495, 103, 26, 23, 5, 36, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 972, 77, 40, 16, 14, 7, 79, 50, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 530, 107, 31, 22, 5, 5, 49, 62, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 313, 56, 14, 7, 51, 50, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 60, 18, 14, 26, 53, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 54, 8, 19, 44, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 62, 50, 29, 2, 0, 0, 0, 0, 0, 0, 0, 0, 23, 57, 29, 1, 0, 0, 0, 0, 0, 0, 26, 18, 0, 0, 295, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 106, 22, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 3, 0, 0, 0, 1, 1, 2, 2, 1, 3, 2, 11, 17, 3, 1, 5, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 3, 5, 10, 2, 13, 6, 2, 2, 1, 1, 2, 2, 2, 1, 1, 2, 1, 0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 11, 3, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 0, 0, 1, 1, 4, 2, 3, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 2, 0, 0, 1, 0, 3, 4, 3, 1, 0, 1, 1, 2, 4, 4, 1, 2, 5, 6, 11, 1, 8, 1, 13, 4, 7, 1, 3, 3, 57, 10, 2, 2, 3, 19, 42, 3, 1, 2, 5, 4, 4, 2, 5, 6, 2, 2, 3, 1, 1, 4, 1, 1, 1, 1, 2, 2, 1, 2, 2, 2, 4, 0, 0, 5, 0, 0, 18, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 4, 1, 0, 1, 0, 1, 1, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 2, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 2, 3, 4, 6, 5, 6, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 4, 1, 5, 6, 0, 0, 1, 0, 1, 0, 1, 45, 16, 5, 1, 21, 10, 28, 13, 15, 1, 6, 3, 1, 1, 1, 28, 4, 3, 3, 1, 20, 2, 5, 51, 10, 9, 2, 1, 1, 5, 4, 20, 1, 6, 28, 14, 11, 2, 1, 1, 2, 4, 12, 2, 4, 2, 1, 2, 1, 1, 4, 3, 4, 3, 2, 1, 2, 0, 1, 1, 0, 6, 16, 4, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 12, 2, 0, 0, 0, 0, 0, 0, 0, 36, 8, 4, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 3, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 13, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 4, 2, 4, 1, 5, 2, 13, 7, 1, 2, 8, 14, 4, 4, 7, 1, 1, 8, 2, 84, 3, 3, 12, 1, 1, 1, 8, 5, 7, 3, 5, 21, 1, 4, 1, 10, 5, 4, 3, 1, 1, 0, 0, 0, 13, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 11, 1, 8, 1, 22, 0, 4, 0, 11, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 4, 1, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 2, 2, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 1, 0, 0, 1, 7, 1, 1, 3, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 1, 6, 3, 1, 1, 1, 7, 22, 12, 1, 1, 2, 10, 79, 1, 29, 1, 1, 50, 9, 105, 3, 7, 2, 2, 1, 2, 1, 2, 1, 1, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 2, 4, 0, 2, 0, 1, 1, 0, 0, 1, 0, 2, 0, 1, 1, 1, 3, 1, 1, 1, 137, 52, 6, 3, 14, 3, 4, 3, 4, 15, 9, 8, 11, 2, 4, 1, 119, 23, 36, 34, 29, 7, 1, 2, 2, 11, 99, 27, 1, 5, 5, 2, 3, 1, 35, 40, 22, 37, 16, 4, 5, 4, 18, 72, 38, 6, 6, 4, 1, 10, 8, 19, 23, 4, 21, 5, 12, 1, 2, 19, 14, 11, 13, 48, 10, 7, 1, 1, 5, 1, 32, 21, 6, 3, 4, 4, 51, 12, 10, 3, 8, 6, 43, 5, 12, 70, 39, 12, 7, 5, 1, 12, 26, 68, 34, 12, 6, 2, 1, 5, 1, 19, 6, 6, 4, 3, 4, 2, 1, 6, 2, 6, 1, 3, 3, 44, 18, 6, 1, 1, 0, 0, 0, 191, 52, 15, 19, 9, 7, 6, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 106, 18, 41, 22, 10, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 29, 29, 10, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 14, 7, 7, 0, 0, 0, 0, 0, 0, 0, 0, 28, 9, 12, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 2, 2, 1, 2, 7, 3, 8, 1, 1, 4, 1, 1, 1, 1, 1, 1, 1, 2, 2, 3, 7, 1, 1, 0, 1, 1, 1, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 183, 73, 5, 7, 1, 15, 28, 26, 10, 5, 201, 19, 26, 17, 3, 6, 10, 3, 97, 49, 26, 16, 26, 23, 99, 7, 5, 2, 1, 114, 160, 27, 10, 1, 1, 12, 4, 3, 7, 15, 22, 18, 1, 1, 23, 22, 19, 6, 2, 1, 5, 8, 10, 81, 81, 17, 8, 8, 1, 9, 7, 3, 2, 8, 19, 3, 2, 1, 1, 1, 4, 15, 12, 2, 2, 6, 194, 48, 16, 5, 1, 0, 0, 0, 0, 0, 201, 75, 14, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 38, 1, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 3, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 4, 1, 2, 3, 2, 1, 1, 3, 6, 5, 1, 1, 2, 3, 1, 1, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 3, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 4, 6, 0, 0, 1, 4, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 1, 3, 8, 2, 1, 4, 2, 6, 11, 2, 1, 2, 1, 2, 3, 6, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 11, 2, 2, 4, 8, 4, 4, 1, 6, 1, 1, 5, 2, 2, 7, 6, 1, 1, 2, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 2, 0, 0, 0, 7, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 3, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 3, 2, 4, 1, 1, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 1, 0, 66, 177, 2, 1, 1, 121, 1, 709, 112, 318, 9, 404, 122, 78, 111, 223, 9, 9, 79, 613, 401, 410, 403, 335, 450, 1166, 159, 29, 9, 3, 1, 1, 36, 47, 35, 145, 23, 92, 53, 18, 23, 58, 71, 21, 123, 9, 24, 9, 11, 2, 9, 16, 5, 33, 45, 6, 2, 84, 44, 18, 42, 77, 24, 54, 58, 6, 1, 57, 13, 20, 20, 77, 36, 36, 14, 103, 123, 36, 170, 30, 2, 2, 2, 3, 26, 20, 62, 26, 24, 6, 4, 2, 9, 3, 21, 93, 91, 15, 15, 2, 10, 8, 13, 81, 9, 23, 5, 2, 1, 11, 93, 31, 41, 38, 54, 36, 41, 2, 10, 6, 9, 2, 12, 8, 34, 41, 7, 206, 119, 44, 149, 80, 159, 23, 200, 185, 169, 25, 152, 6, 261, 179, 179, 300, 36, 508, 173, 354, 25, 569, 1084, 72, 1, 0, 0, 1568, 26, 12, 0, 0, 4182, 41, 9, 6, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2624, 140, 25, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1620, 90, 3, 1, 2, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 868, 10, 16, 10, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 131, 68, 44, 13, 12, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 15, 3, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 7, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 3, 2, 1, 0, 0, 0, 1, 0, 1, 1, 1, 42, 7, 5, 9, 5, 32, 55, 1, 5, 2, 145, 11, 3, 1, 1, 2, 2, 6, 8, 24, 2, 1, 31, 4, 2, 1, 1, 2, 6, 9, 3, 2, 1, 1, 2, 4, 1, 0, 0, 1, 1, 0, 7, 1, 1, 8, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 4, 30, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 13, 2, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 3, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 0, 1, 2, 0, 0, 0, 2, 2, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 2, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 4, 1, 1, 0, 0, 1, 2, 1, 0, 1, 0, 1, 2, 1, 1, 1, 4, 1, 12, 6, 3, 1, 2, 3, 7, 1, 1, 15, 15, 1, 2, 1, 3, 9, 5, 3, 4, 12, 9, 5, 6, 2, 5, 5, 10, 2, 13, 7, 1, 3, 12, 0, 0, 1, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 8, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 5, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 14, 11, 7, 1, 1, 2, 1, 2, 3, 1, 5, 23, 12, 21, 5, 4, 10, 7, 1, 2, 2, 1, 1, 1, 2, 7, 1, 5, 3, 10, 4, 4, 1, 3, 2, 2, 2, 1, 1, 1, 4, 11, 1, 16, 2, 5, 1, 3, 2, 1, 1, 1, 1, 1, 2, 2, 1, 2, 5, 3, 5, 2, 2, 1, 3, 1, 3, 3, 3, 1, 2, 1, 1, 2, 2, 1, 2, 1, 2, 2, 2, 1, 3, 2, 1, 1, 1, 2, 2, 2, 1, 2, 0, 5, 2, 0, 1, 1, 0, 1, 1, 1, 2, 1, 0, 0, 2, 1, 0, 3, 8, 6, 1, 1, 2, 0, 0, 5, 7, 1, 1, 3, 2, 1, 5, 0, 0, 0, 0, 0, 0, 1, 1, 3, 1, 1, 2, 1, 3, 3, 1, 3, 0, 0, 12, 7, 14, 6, 6, 7, 4, 2, 3, 1, 2, 2, 1, 37, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 2, 2, 3, 3, 2, 6, 5, 0, 0, 0, 0, 6, 1, 1, 2, 3, 1, 3, 0, 0, 0, 0, 0, 0, 0, 6, 2, 3, 2, 3, 2, 6, 1, 0, 0, 0, 0, 1, 4, 0, 0, 0, 0, 0, 1, 3, 3, 1, 2, 1, 1, 1, 0, 0, 0, 0, 2, 3, 1, 2, 1, 1, 0, 0, 0, 0, 0, 2, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 0, 0, 0, 2, 2, 1, 2, 1, 2, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 1, 1, 0, 2, 1, 1, 0, 0, 2, 1, 0, 1, 1, 2, 2, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 1, 3, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 2, 1, 1, 1, 1, 3, 2, 28, 6, 4, 5, 2, 2, 5, 1, 1, 89, 92, 27, 21, 2, 2, 2, 1, 1, 26, 8, 1, 2, 1, 1, 109, 47, 20, 3, 5, 1, 7, 8, 2, 20, 5, 3, 8, 2, 1, 1, 1, 230, 54, 7, 11, 1, 4, 2, 2, 3, 10, 5, 8, 60, 4, 11, 1, 1, 1, 1, 192, 8, 37, 23, 16, 10, 1, 5, 8, 15, 41, 41, 65, 36, 8, 4, 6, 1, 1, 1, 35, 29, 44, 41, 8, 2, 2, 4, 24, 71, 106, 22, 52, 10, 10, 1, 1, 5, 3, 1, 3, 21, 10, 2, 8, 8, 2, 9, 2, 9, 7, 3, 11, 39, 14, 21, 6, 8, 2, 2, 1, 20, 13, 9, 17, 29, 4, 6, 4, 1, 1, 6, 13, 36, 22, 14, 7, 7, 2, 6, 18, 5, 7, 1, 15, 9, 3, 2, 1, 2, 4, 1, 1, 1, 5, 2, 5, 2, 21, 32, 5, 8, 3, 2, 2, 0, 0, 0, 62, 71, 25, 2, 2, 1, 2, 0, 145, 43, 25, 5, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 141, 23, 22, 3, 3, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 157, 31, 16, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 122, 48, 6, 11, 4, 3, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 2, 6, 9, 2, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 7, 9, 3, 4, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 1, 2, 1, 5, 1, 0, 0, 0, 0, 0, 1, 2, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 1, 1, 1, 1, 4, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 1, 1, 3, 2, 5, 1, 2, 2, 3, 1, 2, 2, 1, 4, 4, 7, 4, 1, 1, 2, 2, 3, 5, 3, 2, 2, 1, 4, 1, 14, 1, 3, 4, 2, 3, 4, 3, 1, 13, 4, 1, 1, 1, 2, 5, 6, 2, 6, 6, 2, 10, 4, 2, 3, 2, 17, 7, 19, 30, 45, 55, 7, 2, 5, 12, 8, 20, 1, 2, 2, 2, 2, 2, 0, 1, 3, 1, 1, 0, 0, 1, 2, 0, 6, 1, 1, 0, 0, 0, 0, 8, 1, 3, 0, 0, 0, 0, 3, 2, 6, 0, 0, 0, 0, 0, 0, 6, 4, 6, 1, 0, 0, 0, 0, 0, 0, 21, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 15, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 0, 1, 2, 0, 0, 0, 1, 0, 40, 19, 13, 4, 2, 2, 1, 2, 1, 1, 2, 2, 1, 71, 27, 5, 5, 1, 3, 1, 1, 2, 2, 1, 2, 148, 2, 5, 2, 1, 6, 3, 3, 8, 1, 4, 1, 3, 1, 167, 23, 6, 16, 1, 7, 25, 18, 46, 6, 32, 33, 37, 24, 25, 65, 20, 31, 13, 4, 16, 1, 2, 3, 6, 2, 4, 1, 1, 31, 1, 2, 2, 10, 34, 12, 4, 27, 24, 23, 10, 10, 6, 16, 7, 1, 11, 1, 1, 2, 5, 1, 4, 7, 2, 2, 24, 6, 14, 14, 10, 1, 4, 2, 1, 2, 2, 4, 3, 4, 2, 10, 7, 1, 3, 12, 3, 3, 5, 2, 3, 4, 2, 3, 2, 1, 5, 3, 1, 1, 11, 3, 2, 1, 19, 12, 20, 8, 2, 15, 4, 3, 5, 4, 1, 5, 31, 32, 1, 2, 3, 6, 3, 24, 5, 12, 14, 8, 5, 1, 3, 4, 8, 33, 63, 20, 14, 11, 12, 11, 19, 9, 6, 2, 2, 44, 35, 44, 26, 12, 11, 1, 10, 4, 2, 59, 32, 70, 20, 57, 9, 7, 9, 2, 2, 70, 55, 70, 56, 7, 16, 11, 3, 5, 6, 1, 1, 57, 94, 76, 11, 14, 5, 4, 1, 10, 5, 7, 2, 4, 5, 1, 1, 108, 127, 39, 22, 29, 20, 3, 3, 4, 1, 241, 86, 92, 13, 37, 8, 7, 6, 10, 3, 2, 1, 6, 2, 382, 330, 61, 51, 5, 1, 1, 20, 6, 32, 18, 4, 3, 6, 4, 2, 5, 23, 3, 1, 3, 410, 125, 53, 28, 21, 12, 5, 24, 10, 13, 2, 6, 10, 2, 30, 2, 1, 1, 2, 352, 288, 156, 44, 22, 8, 9, 15, 8, 48, 79, 11, 48, 43, 11, 4, 11, 9, 75, 25, 1, 1, 294, 74, 35, 38, 5, 6, 7, 16, 21, 40, 56, 31, 15, 16, 5, 11, 14, 6, 9, 8, 53, 19, 3, 3, 228, 65, 42, 3, 26, 20, 113, 85, 29, 63, 29, 2, 23, 11, 8, 5, 15, 111, 9, 18, 2, 62, 25, 16, 10, 89, 14, 59, 68, 44, 27, 32, 10, 13, 9, 9, 27, 14, 14, 53, 29, 5, 12, 49, 14, 31, 31, 16, 18, 10, 10, 14, 11, 63, 4, 3, 2, 1, 27, 17, 30, 18, 51, 8, 4, 8, 36, 5, 1, 18, 4, 5, 10, 9, 3, 19, 8, 4, 8, 7, 8, 54, 8, 37, 28, 13, 3, 2, 15, 1, 19, 43, 17, 15, 8, 5, 8, 36, 18, 33, 13, 3, 3, 225, 44, 71, 16, 17, 6, 2, 4, 3, 25, 0, 183, 164, 70, 53, 22, 8, 15, 3, 5, 4, 10, 56, 18, 5, 1, 1, 0, 0, 175, 37, 28, 38, 31, 3, 7, 22, 10, 8, 1, 0, 0, 0, 0, 178, 153, 28, 21, 28, 25, 4, 8, 48, 41, 1, 4, 0, 0, 135, 45, 30, 12, 9, 5, 5, 4, 9, 98, 13, 11, 2, 0, 102, 47, 39, 49, 9, 8, 6, 12, 1, 13, 45, 31, 2, 2, 0, 0, 56, 36, 29, 12, 29, 5, 6, 66, 13, 13, 81, 18, 13, 7, 2, 9, 3, 45, 18, 5, 2, 54, 21, 22, 5, 12, 32, 26, 12, 1, 0, 18, 34, 12, 24, 5, 75, 16, 10, 1, 21, 11, 6, 13, 12, 6, 5, 5, 0, 30, 11, 8, 4, 11, 28, 12, 2, 30, 46, 9, 4, 36, 46, 7, 1, 1, 0, 8, 3, 3, 4, 26, 7, 4, 16, 92, 28, 7, 0, 93, 21, 1, 0, 727, 137, 30, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 586, 81, 9, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 357, 18, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 63, 2, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 128, 2, 0, 0, 128, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 3, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 4, 0, 1, 1, 1, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 3, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 3, 1, 1, 1, 2, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 0, 1, 0, 2, 1, 3, 2, 1, 4, 3, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 2, 1, 0, 1, 0, 2, 2, 8, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 1, 1, 2, 1, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 2, 1, 1, 2, 1, 3, 1, 1, 3, 3, 1, 24, 3, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 0, 2, 0, 1, 1, 2, 2, 2, 1, 1, 1, 1, 5, 1, 1, 1, 1, 2, 1, 1, 1, 2, 2, 1, 9, 1, 7, 1, 2, 2, 3, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 4, 1, 1, 3, 1, 2, 3, 1, 5, 1, 1, 1, 1, 2, 2, 9, 2, 3, 2, 1, 2, 1, 2, 1, 2, 3, 4, 2, 2, 1, 3, 1, 3, 3, 1, 1, 2, 7, 5, 1, 3, 1, 3, 1, 10, 3, 8, 13, 8, 7, 6, 1, 2, 16, 12, 13, 17, 7, 3, 18, 9, 20, 9, 6, 3, 2, 4, 1, 32, 38, 19, 23, 3, 1, 3, 3, 2, 61, 27, 20, 4, 6, 2, 5, 5, 8, 154, 84, 5, 1, 3, 3, 5, 3, 2, 5, 45, 35, 6, 193, 32, 20, 2, 1, 3, 2, 25, 6, 8, 5, 3, 5, 4, 4, 71, 83, 6, 1, 80, 19, 3, 1, 2, 4, 5, 3, 14, 8, 5, 6, 3, 4, 4, 7, 203, 168, 3, 1, 6, 9, 2, 13, 7, 3, 11, 6, 55, 56, 12, 1, 5, 3, 13, 5, 16, 24, 1, 7, 7, 11, 1, 2, 1, 6, 2, 3, 1, 3, 2, 0, 2, 3, 1, 4, 2, 4, 0, 12, 4, 14, 3, 13, 0, 10, 10, 2, 1, 6, 8, 10, 10, 0, 7, 2, 0, 4, 13, 8, 0, 12, 0, 0, 0, 13, 4, 0, 4, 2, 11, 5, 1, 2, 2, 3, 3, 3, 27, 5, 0, 308, 16, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 123, 18, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 2, 1, 1, 4, 1, 1, 1, 1, 1, 1, 2, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 2, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 2, 1, 9, 3, 10, 4, 3, 1, 50, 1, 1, 3, 17, 2, 27, 4, 1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 12, 1, 2, 1, 1, 7, 13, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 1, 1, 0, 0, 0, 2, 0, 0, 2, 0, 1, 0, 12, 0, 0, 0, 0, 0, 1, 2, 1, 0, 4, 1, 1, 3, 3, 2, 1, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 5, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 2, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 3, 1, 1, 2, 2, 2, 2, 1, 2, 3, 2, 1, 1, 1, 2, 1, 3, 1, 2, 1, 1, 1, 1, 4, 1, 2, 4, 2, 13, 1, 1, 1, 3, 3, 2, 2, 1, 4, 3, 1, 2, 2, 1, 2, 1, 3, 6, 1, 1, 2, 4, 5, 1, 3, 8, 3, 1, 1, 5, 2, 9, 6, 3, 2, 6, 1, 4, 2, 4, 11, 3, 2, 14, 14, 2, 4, 1, 2, 4, 4, 3, 1, 0, 0, 1, 4, 0, 1, 0, 0, 0, 2, 1, 4, 0, 0, 0, 3, 7, 0, 1, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 7, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 3, 2, 5, 2, 1, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 3, 3, 1, 1, 1, 1, 2, 3, 1, 1, 1, 2, 1, 11, 5, 1, 1, 1, 4, 4, 20, 1, 3, 1, 1, 3, 2, 4, 1, 2, 2, 1, 1, 0, 0, 0, 3, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 0, 1, 0, 1, 3, 2, 1, 2, 39, 67, 1, 1, 157, 3, 1, 1, 1389, 2365, 207, 19, 3, 2, 6, 1, 1, 1, 1670, 7, 8, 5834, 287, 106, 18, 9, 6104, 1015, 80, 30, 47, 20, 15, 23, 149, 26, 1, 5, 6091, 483, 112, 110, 80, 68, 21, 8, 45, 118, 65, 32, 4543, 1018, 437, 129, 112, 88, 27, 14, 8, 77, 258, 1043, 126, 129, 5, 5, 1957, 920, 406, 233, 23, 17, 169, 278, 1076, 198, 171, 10, 1127, 360, 315, 98, 27, 49, 134, 918, 217, 28, 6, 8, 1, 510, 354, 110, 22, 14, 167, 338, 850, 294, 110, 338, 74, 29, 71, 177, 667, 92, 95, 6, 3, 126, 33, 37, 131, 905, 168, 100, 1, 22, 50, 37, 351, 81, 35, 6, 63, 7, 15, 28, 30, 32, 21, 20, 116, 487, 1397, 24, 59, 0, 5997, 942, 42, 14, 11, 1, 0, 6128, 217, 20, 4, 1, 5831, 260, 76, 30, 3, 0, 0, 0, 3804, 692, 76, 17, 5, 1, 0, 0, 0, 3097, 244, 34, 12, 1, 1, 1, 0, 0, 2477, 260, 57, 6, 7, 2, 4, 0, 0, 0, 0, 0, 0, 0, 0, 1729, 229, 21, 24, 18, 3, 1, 0, 0, 0, 0, 1312, 49, 30, 16, 2, 8, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 415, 192, 136, 23, 22, 22, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 155, 118, 15, 15, 11, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 164, 18, 30, 15, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 72, 46, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 29, 26, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 63, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 0, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 2, 1, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 2, 1, 0, 0, 0, 1, 1, 1, 1, 1, 4, 12, 1, 2, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 1, 1, 4, 2, 3, 7, 3, 3, 5, 2, 12, 16, 2, 7, 0, 0, 1, 1, 0, 0, 4, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 2, 4, 2, 0, 0, 1, 2, 1, 0, 1, 0, 14, 21304, 1192, 2231, 852, 8966, 340, 113, 16, 3, 2039, 33, 1342, 352, 331, 1557, 19783, 1163, 1037, 28, 11, 9, 1, 5496, 1869, 521, 2932, 333, 857, 403, 154, 621, 392, 7468, 353, 1256, 2797, 8, 503, 173, 1549, 426, 1639, 147, 774, 130, 2516, 167, 522, 468, 387, 1125, 229, 219, 129, 215, 206, 219, 220, 329, 2239, 11302, 328, 164, 791, 336, 341, 564, 114, 792, 14, 2, 1, 91, 473, 220, 2317, 466, 122, 6, 34, 130, 551, 207, 220, 867, 440, 900, 402, 502, 354, 501, 172, 848, 1794, 4851, 142, 52440, 6746, 2, 56162, 9, 1, 1, 2, 51233, 37368, 1242, 7707, 6694, 1308, 5, 420, 247, 344, 4, 1145, 1301, 3931, 5388, 409, 7, 1293, 1012, 1241, 437, 6, 2, 2, 5, 267, 2, 14, 661, 7, 1, 17, 3, 84, 1, 4, 4, 1, 10, 722, 1, 31293, 1165, 2616, 6870, 874, 453, 345, 1545, 2855, 1337, 726, 317, 261, 200, 453, 3, 40, 36, 2547, 18471, 16879, 7626, 718, 1957, 1508, 1965, 586, 265, 918, 4952, 4274, 1854, 217, 199, 410, 211, 547, 278, 755, 469, 6, 1391, 1588, 1822, 187, 309, 364, 18, 521, 160, 11715, 5351, 641, 447, 773, 3812, 3728, 1350, 451, 733, 9, 666, 4, 496, 180, 190, 5045, 825, 1754, 1353, 945, 1032, 1408, 1560, 10328, 9816, 1323, 1759, 1328, 2276, 681, 1830, 4, 498, 334, 3921, 211, 1171, 8779, 4134, 991, 624, 9, 605, 41, 52, 642, 1443, 829, 1631, 1575, 1, 749, 1132, 520, 624, 421, 692, 643, 926, 197, 231, 642, 210, 719, 1039, 927, 341, 946, 5, 1966, 1322, 575, 310, 2686, 597, 643, 750, 309, 1997, 1094, 754, 269, 2, 433, 1, 4325, 6419, 3, 297, 185, 2, 3, 211, 3, 1050, 29408, 4599, 1105, 472, 2721, 1048, 387, 1245, 1239, 110, 1045, 64, 35, 5, 101, 3, 506, 9, 404, 6, 3, 7, 346, 7, 12, 2799, 11419, 3169, 396, 16090, 6212, 7951, 3691, 3695, 471, 954, 2860, 1990, 5, 8, 282, 479, 262, 581, 517, 1163, 1619, 201, 4, 342, 1380, 7, 5, 157, 377, 7, 2, 1, 84, 2, 467, 1, 1847, 7, 949, 4310, 1976, 3509, 2972, 622, 539, 1953, 3497, 980, 5, 2367, 2, 5, 465, 10, 4, 3, 347, 345, 383, 4, 655, 404, 627, 1, 1107, 4901, 1286, 2024, 717, 564, 3, 730, 523, 2, 472, 625, 579, 1977, 870, 8889, 4132, 1718, 2448, 2268, 2854, 395, 1978, 784, 252, 622, 2, 348, 48, 8, 2, 298, 369, 611, 452, 657, 274, 2, 751, 2, 307, 5289, 9338, 1958, 938, 734, 1238, 451, 1601, 349, 1071, 8, 862, 2510, 4, 545, 246, 956, 335, 653, 2, 705, 6308, 1372, 592, 183, 2099, 2065, 188, 1297, 562, 931, 429, 9, 6, 558, 118, 6, 1375, 4, 782, 626, 464, 322, 766, 618, 8887, 534, 2390, 2709, 1549, 13, 2389, 368, 1211, 199, 1654, 585, 1127, 518, 1210, 1258, 594, 5, 115, 10, 363, 2, 3, 238, 522, 770, 668, 3, 5244, 752, 618, 1989, 1203, 757, 3519, 2697, 13, 1563, 87, 3, 2757, 258, 9, 1300, 4, 3, 212, 13, 348, 2364, 436, 939, 246, 4, 5, 2188, 184, 205, 347, 718, 111, 611, 273, 6138, 3019, 971, 1134, 1538, 1927, 814, 377, 2911, 2457, 71, 846, 5, 375, 296, 1254, 1551, 608, 672, 9, 360, 989, 455, 986, 5, 686, 310, 857, 577, 0, 0, 1659, 554, 4, 894, 288, 9, 460, 1977, 8, 187, 653, 7, 964, 346, 3621, 849, 2608, 6185, 1714, 1726, 667, 8, 509, 862, 415, 1089, 7, 32, 593, 779, 33, 196, 501, 262, 607, 6, 486, 1714, 1537, 3, 421, 1172, 1019, 350, 560, 631, 1583, 1074, 270, 607, 7, 683, 160, 3, 263, 196, 171, 972, 3, 1566, 1157, 1654, 1139, 1297, 2, 434, 1426, 608, 671, 590, 268, 13, 278, 618, 14, 0, 0, 428, 6, 929, 37, 471, 956, 1195, 3294, 2548, 1861, 1569, 333, 1037, 439, 658, 406, 3, 963, 238, 2, 799, 606, 302, 0, 1495, 1044, 3913, 342, 811, 362, 949, 4, 446, 406, 419, 11, 354, 576, 186, 0, 1658, 595, 2959, 575, 555, 2122, 764, 1685, 418, 795, 285, 550, 286, 0, 1951, 1777, 841, 4118, 1964, 446, 908, 1661, 925, 209, 911, 1383, 597, 4165, 606, 1804, 258, 539, 1529, 7, 1078, 669, 391, 1264, 1690, 311, 1689, 979, 933, 339, 1136, 1, 3495, 983, 237, 522, 92, 1413, 1367, 1369, 1199, 1186, 218, 1777, 274, 3830, 3188, 834, 1162, 1796, 5377, 3134, 243, 1347, 5, 1585, 434, 37, 464, 358, 1426, 1030, 2573, 1400, 2956, 1695, 1614, 586, 5, 258, 1145, 1, 70, 947, 1540, 17, 426, 2099, 235, 0, 934, 1018, 5345, 1232, 1359, 725, 794, 3, 1747, 819, 1353, 719, 495, 1358, 933, 626, 257, 1699, 612, 2542, 343, 743, 502, 7, 445, 911, 269, 0, 6558, 1727, 2253, 421, 6, 1283, 268, 2114, 3140, 991, 3, 2953, 10192, 4018, 884, 730, 830, 781, 1240, 314, 347, 1851, 654, 273, 2101, 3617, 1, 0, 0, 8318, 6695, 1062, 1748, 377, 7, 400, 2596, 584, 652, 418, 1538, 0, 4669, 4789, 1919, 320, 424, 626, 534, 2559, 191, 1585, 1103, 2125, 3637, 4199, 1273, 6, 5574, 1353, 1856, 2804, 0, 3267, 1550, 769, 2415, 758, 1260, 570, 4, 345, 2041, 871, 2401, 433, 1190, 473, 4472, 2164, 1585, 1869, 991, 586, 416, 772, 870, 392, 6, 433, 1861, 851, 2, 318, 3226, 610, 0, 1230, 1970, 996, 2437, 1259, 1961, 1685, 1519, 1188, 313, 448, 0, 0, 3523, 617, 1107, 429, 1841, 2200, 4667, 1872, 2652, 14134, 15387, 342, 666, 7309, 8493, 1252, 754, 6190, 4178, 4453, 55614, 1, 59520, 622, 3, 38, 83, 2, 88, 1, 115, 0, 2, 0, 183, 1, 0, 6, 1, 1, 18, 173, 1, 651, 19, 141, 1105, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9388, 1514, 1282, 2267, 95, 507, 417, 204, 1811, 209, 609, 1383, 754, 917, 1265, 1229, 616, 1149, 313, 577, 463, 1231, 101, 1230, 673, 364, 325, 433, 184, 980, 447, 121, 242, 127, 337, 327, 164, 1188, 223, 199, 342, 1444, 365, 957, 213, 353, 76, 2236, 202, 1305, 2295, 4181, 1875, 1282, 2824, 2907, 0, 1244, 1329, 214, 831, 380, 204, 588, 90, 494, 672, 1002, 787, 790, 728, 531, 469, 260, 250, 563, 106, 451, 167, 385, 98, 447, 458, 453, 225, 455, 224, 168, 394, 553, 77, 179, 0, 384, 4, 96, 369, 136, 33, 97, 141, 276, 3, 785, 203, 532, 546, 224, 772, 784, 638, 222, 269, 129, 215, 83, 0, 210, 368, 302, 305, 214, 196, 308, 576, 367, 198, 324, 379, 170, 616, 191, 195, 370, 459, 301, 190, 202, 87, 452, 307, 211, 215, 493, 160, 462, 233, 410, 222, 0, 257, 290, 533, 773, 167, 309, 107, 210, 116, 439, 177, 309, 169, 269, 437, 379, 151, 203, 308, 312, 451, 230, 782, 174, 170, 462, 256, 0, 289, 223, 450, 228, 393, 272, 196, 299, 461, 615, 125, 474, 224, 0, 100, 454, 369, 532, 308, 458, 210, 333, 589, 373, 444, 618, 301, 302, 1096, 214, 222, 674, 159, 1, 451, 363, 268, 324, 209, 450, 182, 227, 324, 107, 185, 979, 189, 128, 394, 171, 91, 549, 120, 243, 128, 332, 215, 338, 368, 197, 326, 269, 165, 310, 270, 1259, 224, 198, 19, 6, 197, 214, 341, 197, 5, 121, 93, 166, 209, 464, 869, 306, 1048, 945, 523, 364, 370, 555, 41, 518, 120, 324, 111, 323, 92, 168, 259, 212, 165, 978, 648, 391, 184, 409, 268, 75, 3, 0, 544, 340, 247, 220, 2946, 406, 449, 170, 615, 269, 231, 866, 931, 208, 876, 268, 201, 517, 1702, 206, 1453, 214, 301, 211, 453, 512, 223, 2723, 957, 1199, 1306, 754, 0, 5451, 7843, 5442, 3264, 4907, 5581, 3546, 12289, 9643, 33477, 55, 1, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 148, 79, 215, 42, 13, 87, 2, 125, 2, 135, 42, 49, 4, 22, 70, 53, 33, 259, 113, 1922, 6474, 46, 110, 81, 29, 199, 18, 26, 14, 16, 75, 0, 15, 73, 0, 0, 1, 14, 34, 93, 41, 48, 5, 25, 68, 55, 49, 323, 17, 100, 2121, 176, 579, 752, 431, 1707, 10, 419, 781, 2152, 36, 554, 287, 161, 456, 746, 47, 409, 234, 137, 84, 365, 69, 444, 29, 196, 87, 88, 5, 88, 29, 1, 15, 65, 43, 130, 17, 63, 119, 51, 51, 48, 43, 17, 38, 181, 554, 6642, 66, 60, 18, 36, 183, 66, 73, 335, 84, 103, 294, 71, 211, 63, 20, 125, 85, 3, 19, 46, 162, 290, 20, 61, 39, 127, 3, 42, 165, 57, 31, 18, 85, 46, 156, 882, 11, 64, 59, 27, 61, 67, 100, 107, 374, 93, 44, 116, 96, 18, 74, 125, 16, 38, 145, 307, 68, 76, 117, 181, 235, 253, 53, 203, 98, 14, 141, 121, 34, 62, 70, 66, 74, 75, 82, 11, 560, 37, 107, 142, 149, 39, 280, 74, 95, 10, 104, 4, 7, 31, 69, 66, 98, 45, 15, 1, 26, 40, 20, 68, 46, 38, 61, 21, 121, 242, 104, 157, 77, 68, 26, 95, 24, 121, 83, 328, 126, 105, 48, 78, 118, 4, 40, 2, 174, 113, 186, 80, 4, 53, 86, 459, 117, 2, 34, 83, 2, 67, 103, 149, 4, 5, 173, 102, 156, 254, 127, 192, 59, 10, 90, 173, 54, 2, 77, 137, 20, 323, 89, 3, 28, 54, 332, 10, 86, 89, 116, 113, 24, 4, 120, 72, 50, 129, 25, 87, 62, 73, 68, 0, 53, 207, 64, 53, 30, 333, 119, 33, 97, 181, 68, 40, 241, 13, 77, 106, 139, 93, 0, 155, 52, 566, 157, 99, 12, 253, 15, 31, 302, 95, 11, 1280, 85, 65, 365, 49, 364, 2, 751, 37, 309, 228, 41, 237, 58, 1311, 4072, 172, 36, 41, 45, 0, 18, 53, 52, 19, 29, 47, 36, 24, 38, 30, 117, 49, 81, 31, 68, 17, 34, 33, 32, 18, 20, 19, 90, 4, 54, 28, 44, 22, 57, 70, 176, 79, 141, 89, 120, 226, 765, 1701, 17, 1008, 0, 0, 0, 0, 0, 0, 80, 90, 21, 39, 14, 29, 40, 10, 48, 20, 146, 57, 63, 44, 47, 45, 27, 58, 38, 83, 78, 42, 27, 176, 25, 59, 52, 264, 148, 870, 897, 282, 51, 34, 49, 13, 20, 23, 45, 11, 50, 124, 40, 22, 25, 22, 41, 19, 15, 52, 79, 41, 11, 20, 49, 30, 46, 19, 35, 33, 143, 22, 0, 73, 18, 31, 46, 62, 34, 34, 48, 79, 40, 43, 30, 46, 42, 32, 89, 33, 18, 21, 28, 33, 139, 34, 18, 16, 39, 14, 82, 21, 19, 18, 19, 18, 14, 20, 33, 32, 7, 77, 3, 36, 12, 39, 26, 25, 41, 17, 62, 41, 76, 59, 21, 17, 38, 3, 36, 73, 31, 62, 56, 162, 255, 82, 0, 22, 130, 15, 74, 38, 182, 150, 40, 266, 199, 55, 57, 159, 376, 33, 2263, 641, 525, 6043, 573, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 5, 2, 1, 0, 0, 10, 1, 9, 806, 205, 326, 16, 15, 4968, 106, 37, 26, 687, 66, 58, 55, 4, 40, 32, 52, 230, 31, 42, 52, 290, 5306, 4196, 94, 88, 262, 271, 102, 108, 30, 70, 284, 107, 50, 17, 16, 238, 81, 79, 324, 78, 190, 2564, 1923, 129, 111, 107, 120, 27, 80, 567, 595, 87, 64, 59, 1, 54, 1, 5, 39, 31, 58, 79, 53, 232, 32, 43, 51, 4, 660, 229, 11153, 2, 14, 185, 25, 4, 6, 4, 4, 11, 24, 2, 2, 309, 6971, 761, 510, 1004, 301, 384, 220, 349, 794, 108, 175, 106, 265, 31, 131, 157, 150, 215, 360, 414, 81, 109, 1283, 12059, 152, 2, 197, 90, 683, 1031, 440, 160, 67, 4, 113, 108, 26, 113, 2, 127, 118, 3, 113, 41, 164, 1121, 18, 95, 415, 2839, 16, 222, 89, 93, 349, 185, 240, 51, 551, 207, 231, 379, 674, 1964, 73, 30, 111, 103, 117, 681, 68, 138, 488, 67, 73, 330, 146, 224, 157, 1, 51, 215, 265, 144, 110, 94, 225, 554, 1, 125, 85, 117, 103, 248, 102, 3, 129, 111, 70, 115, 74, 221, 57, 66, 229, 186, 194, 84, 1, 126, 483, 109, 272, 107, 241, 137, 130, 32, 184, 74, 140, 198, 391, 151, 118, 127, 71, 20, 130, 361, 2, 208, 187, 572, 12, 68, 82, 128, 104, 532, 91, 2178, 142, 72, 112, 44, 30, 187, 249, 1003, 142, 176, 1320, 187, 459, 1971, 1820, 1821, 1363, 459, 201, 851, 709, 940, 72, 109, 211, 539, 382, 123, 533, 124, 139, 105, 132, 134, 156, 21, 60, 1295, 149, 222, 52, 112, 12, 676, 2144, 5, 199, 21, 135, 436, 372, 198, 141, 26, 85, 1, 21, 25, 129, 129, 47, 111, 190, 289, 97, 466, 175, 53, 99, 30, 83, 100, 1, 9, 34, 268, 0, 234, 408, 502, 227, 528, 143, 188, 5, 335, 52, 203, 63, 72, 270, 161, 617, 549, 262, 78, 407, 217, 60, 68, 103, 40, 5, 243, 227, 115, 783, 4, 280, 89, 16, 491, 526, 155, 136, 95, 53, 395, 81, 191, 3, 360, 105, 40, 487, 881, 12, 92, 204, 278, 104, 724, 217, 322, 72, 507, 34, 0, 55, 35, 273, 255, 120, 420, 215, 345, 600, 8, 54, 107, 3, 640, 175, 150, 48, 531, 85, 79, 143, 381, 113, 2, 304, 127, 58, 541, 285, 88, 864, 60, 157, 142, 112, 70, 83, 73, 93, 3, 1, 421, 212, 325, 60, 119, 166, 227, 64, 134, 10, 102, 206, 231, 356, 3, 75, 96, 748, 4, 135, 71, 171, 12, 77, 195, 525, 7, 116, 161, 526, 2, 167, 119, 352, 402, 3, 134, 269, 85, 2, 477, 90, 12, 155, 594, 629, 283, 43, 82, 147, 359, 20, 318, 351, 12, 58, 265, 925, 383, 357, 63, 26, 144, 407, 16, 629, 576, 21, 57, 102, 62, 197, 37, 141, 781, 453, 111, 270, 2, 137, 20, 104, 81, 342, 39, 2, 112, 133, 181, 155, 82, 81, 148, 42, 11, 220, 545, 705, 203, 4, 59, 235, 58, 277, 51, 230, 242, 1117, 558, 239, 226, 1495, 7105, 0, 36, 506, 23, 103, 168, 2009, 253, 593, 1, 169, 599, 557, 384, 6311, 37, 1, 0, 10183, 527, 83, 626, 26, 42, 187, 40, 95, 30, 133, 69, 41, 168, 114, 33, 10, 13, 45, 34, 26, 82, 34, 94, 17, 91, 48, 45, 225, 378, 5205, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 448, 35, 491, 206, 121, 67, 74, 98, 294, 124, 38, 132, 6, 56, 44, 78, 3, 19, 64, 96, 140, 249, 86, 367, 5944, 52, 179, 93, 64, 58, 513, 165, 61, 197, 54, 36, 749, 0, 89, 83, 54, 120, 66, 219, 92, 65, 112, 63, 207, 0, 88, 38, 38, 58, 63, 230, 285, 0, 31, 82, 30, 222, 68, 40, 25, 139, 140, 37, 133, 62, 5, 173, 32, 9, 125, 44, 352, 25, 43, 81, 33, 77, 92, 55, 77, 271, 185, 408, 381, 0, 820, 26, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1042, 14, 45, 76, 2, 121, 14, 63, 78, 95, 76, 169, 1800, 7179, 3, 59, 370, 647, 15, 46, 29, 50, 0, 126, 15, 63, 79, 80, 20, 79, 60, 123, 66, 2582, 6, 685, 181, 423, 156, 272, 250, 53, 72, 146, 111, 17, 37, 82, 268, 1998, 485, 2298, 1442, 479, 384, 320, 820, 88, 456, 230, 34, 307, 178, 89, 306, 123, 128, 25, 13, 150, 94, 134, 29, 24, 79, 22, 74, 251, 63, 5, 241, 7504, 178, 115, 90, 312, 136, 51, 241, 137, 51, 157, 13, 4, 118, 2, 2, 27, 179, 117, 80, 87, 66, 21, 54, 14, 42, 5, 116, 32, 158, 119, 11, 20, 112, 18, 119, 37, 2, 85, 2, 117, 152, 123, 593, 171, 2, 134, 23, 172, 104, 111, 4, 81, 49, 47, 20, 62, 121, 120, 340, 248, 159, 3, 75, 117, 53, 30, 269, 520, 447, 294, 72, 41, 74, 77, 24, 43, 2, 195, 134, 81, 84, 28, 1, 27, 1638, 348, 150, 10, 64, 45, 56, 125, 73, 4, 6, 305, 160, 42, 47, 9, 130, 754, 249, 119, 11, 13, 49, 2, 238, 21, 31, 576, 1, 244, 205, 22, 16, 2, 54, 36, 310, 44, 43, 371, 2, 1, 3, 150, 2, 3, 39, 73, 73, 84, 44, 20, 35, 188, 3, 36, 136, 128, 2, 3, 8, 126, 329, 37, 532, 113, 89, 105, 8, 67, 11, 58, 2, 45, 61, 466, 73, 64, 74, 161, 5, 74, 206, 12, 78, 6, 12, 52, 11, 1, 18, 116, 65, 223, 179, 180, 14, 78, 112, 82, 179, 36, 75, 219, 27, 32, 240, 181, 21, 178, 259, 0, 175, 12, 175, 72, 24, 108, 2, 81, 223, 130, 2, 303, 0, 3, 88, 4, 133, 585, 53, 7, 206, 104, 2, 367, 194, 117, 174, 66, 7, 3, 314, 66, 106, 701, 116, 205, 2, 58, 828, 225, 115, 58, 54, 614, 267, 191, 0, 114, 72, 46, 246, 75, 613, 0, 106, 285, 6, 346, 553, 3116, 222, 96, 60, 9, 145, 69, 98, 29, 106, 90, 81, 44, 55, 18, 27, 42, 96, 52, 12, 38, 14, 30, 2, 36, 18, 2, 61, 56, 99, 206, 166, 212, 317, 5160, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 30, 86, 79, 42, 16, 32, 8, 26, 29, 44, 55, 314, 74, 41, 2127, 0, 247, 174, 0, 59, 78, 7, 23, 121, 67, 155, 28, 103, 89, 24, 55, 32, 50, 56, 15, 31, 17, 7, 26, 55, 65, 95, 94, 54, 31, 11, 39, 15, 61, 54, 16, 1, 77, 33, 60, 0, 59, 84, 148, 200, 469, 400, 0, 351, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 13, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 2, 0, 1, 1, 0, 0, 1, 0, 2, 0, 0, 1, 0, 2, 0, 0, 1, 0, 2, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 2, 4, 3, 1, 1, 1, 1, 1, 2, 2, 1, 18, 16, 11, 1, 2, 2, 1, 1, 1, 1, 2, 4, 1, 2, 1, 2, 1, 2, 1, 26, 12, 2, 1, 2, 3, 1, 1, 4, 5, 1, 5, 1, 2, 1, 3, 1, 4, 3, 1, 70, 10, 4, 1, 11, 5, 5, 14, 1, 1, 7, 13, 11, 4, 8, 2, 5, 2, 1, 27, 12, 5, 8, 24, 2, 1, 11, 2, 1, 3, 10, 6, 9, 29, 23, 17, 36, 9, 4, 5, 2, 3, 1, 10, 1, 12, 4, 3, 1, 2, 5, 2, 6, 19, 15, 11, 1, 1, 1, 6, 3, 2, 8, 2, 2, 7, 11, 2, 1, 2, 2, 4, 2, 2, 1, 1, 8, 2, 10, 3, 3, 7, 9, 13, 17, 3, 6, 6, 13, 9, 4, 6, 9, 4, 2, 1, 2, 1, 1, 1, 2, 4, 1, 2, 1, 1, 2, 4, 9, 4, 6, 2, 1, 2, 3, 1, 6, 5, 5, 6, 5, 2, 2, 3, 1, 1, 6, 6, 2, 4, 1, 4, 8, 4, 2, 3, 4, 6, 2, 5, 3, 3, 3, 6, 3, 15, 12, 23, 3, 2, 3, 13, 3, 20, 9, 3, 2, 1, 2, 13, 7, 5, 3, 3, 3, 4, 4, 1, 4, 1, 1, 2, 5, 5, 0, 4, 4, 2, 3, 7, 10, 14, 8, 6, 1, 2, 3, 2, 0, 1, 8, 2, 3, 0, 0, 0, 5, 15, 5, 2, 11, 1, 0, 0, 2, 9, 15, 5, 7, 1, 1, 1, 0, 0, 22, 9, 12, 21, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 7, 39, 17, 14, 8, 5, 3, 4, 2, 3, 0, 0, 0, 0, 0, 0, 27, 10, 5, 7, 1, 0, 1, 1, 1, 1, 0, 3, 1, 0, 0, 0, 0, 0, 0, 53, 40, 32, 3, 1, 2, 8, 1, 3, 0, 1, 0, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 25, 55, 5, 3, 2, 3, 2, 1, 0, 0, 0, 0, 3, 4, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 41, 41, 16, 4, 2, 2, 2, 1, 0, 5, 4, 0, 0, 0, 0, 0, 97, 31, 12, 17, 1, 3, 8, 0, 6, 2, 1, 3, 5, 1, 0, 0, 0, 0, 126, 27, 27, 8, 11, 3, 2, 1, 7, 6, 0, 0, 0, 0, 0, 0, 138, 32, 22, 8, 6, 5, 0, 5, 4, 5, 3, 0, 0, 188, 20, 6, 1, 7, 4, 2, 5, 7, 4, 0, 0, 211, 94, 2, 1, 7, 10, 3, 3, 20, 4, 9, 0, 0, 0, 261, 26, 12, 1, 15, 5, 1, 7, 5, 14, 10, 1, 0, 259, 105, 33, 57, 12, 1, 5, 37, 26, 197, 55, 54, 15, 4, 2, 14, 5, 18, 0, 189, 111, 37, 3, 5, 28, 21, 280, 1, 7, 50, 15, 0, 255, 18, 34, 8, 3, 3, 10, 29, 270, 52, 8, 18, 5, 138, 184, 28, 0, 0, 5, 19, 15, 54, 5, 5, 5, 7, 0, 5, 5, 2, 1, 1, 2, 2, 6, 0, 9, 175, 41, 0, 0, 0, 0, 0, 631, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 3, 1, 1, 2, 2, 3, 2, 1, 1, 1, 11, 1, 3, 4, 1, 1, 3, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 2, 1, 2, 1, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 2, 0, 1, 1, 1, 1, 1, 2, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 0, 6, 12, 7, 6, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 2, 1, 2, 3, 1, 1, 1, 6, 2, 1, 2, 1, 4, 1, 1, 1, 1, 8, 3, 2, 12, 2, 48, 17, 5, 3, 7, 34, 14, 26, 8, 10, 2, 3, 2, 1, 1, 1, 2, 5, 4, 4, 2, 1, 1, 2, 3, 3, 2, 3, 8, 1, 1, 2, 5, 3, 5, 5, 8, 5, 16, 1, 3, 4, 1, 0, 1, 1, 0, 1, 6, 2, 6, 4, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 0, 3, 2, 1, 2, 0, 0, 5, 1, 2, 1, 0, 0, 0, 0, 8, 2, 2, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 3, 0, 4, 0, 0, 0, 1, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 1, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 3, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 1, 4, 3, 1, 1, 3, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1, 2, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 0, 0, 0, 1, 0, 1, 2, 3, 1, 3, 1, 0, 0, 0, 4, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 2, 4, 2, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 0, 2, 1, 2, 1, 1, 1, 1, 3, 1, 1, 1, 1, 2, 3, 1, 1, 2, 2, 1, 1, 2, 2, 3, 1, 2, 1, 1, 1, 2, 1, 3, 1, 1, 0, 1, 1, 3, 3, 3, 2, 1, 3, 1, 0, 2, 1, 2, 4, 1, 4, 5, 1, 1, 2, 1, 3, 4, 5, 2, 10, 3, 4, 2, 0, 3, 5, 3, 4, 1, 6, 1, 6, 2, 16, 10, 3, 1, 5, 1, 9, 4, 40, 23, 5, 12, 4, 4, 11, 1, 1, 3, 2, 1, 3, 1, 2, 0, 0, 0, 0, 3, 17, 4, 2, 0, 0, 0, 4, 3, 1, 1, 0, 0, 20, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 2, 1, 0, 2, 0, 1, 1, 1, 2, 3, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 1, 3, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 218, 2022, 1, 1, 1, 240, 4706, 25, 5, 69, 300, 38, 10, 90, 2123, 1122, 856, 1188, 2827, 1259, 1396, 225, 55, 32, 41, 34, 15, 10, 5, 1, 1, 4, 7, 1, 3, 1, 364, 151, 292, 187, 1857, 1164, 597, 154, 50, 18, 24, 19, 12, 17, 4, 2, 3, 2, 25, 6, 71, 14, 18, 134, 71, 67, 4, 3, 39, 9, 3, 12, 13, 5, 44, 13, 11, 368, 573, 274, 785, 190, 203, 57, 4, 365, 283, 635, 313, 144, 23, 672, 897, 372, 120, 16, 8, 8, 1968, 253, 291, 80, 9, 6031, 2409, 297, 21, 5, 9, 6, 8828, 445, 10, 14, 3, 7, 2, 12557, 166, 67, 32, 23, 9, 1, 0, 11088, 538, 154, 54, 15, 6, 1, 3, 0, 9642, 438, 106, 39, 7, 1, 5, 0, 0, 0, 9014, 238, 23, 12, 7, 1, 1, 8087, 119, 23, 10, 2, 14, 6, 1, 2, 1, 0, 0, 6016, 95, 28, 22, 8, 4, 6, 3, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4408, 108, 29, 18, 11, 6, 4, 1, 2, 1, 1, 1, 1, 2, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2995, 105, 46, 19, 2, 4, 8, 6, 2, 4, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2139, 156, 9, 14, 9, 1, 0, 4, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1613, 74, 14, 4, 4, 0, 5, 1, 1, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1019, 167, 32, 10, 3, 13, 4, 2, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 598, 105, 25, 4, 15, 10, 4, 1, 12, 3, 7, 1, 1, 1, 3, 4, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 414, 77, 39, 10, 18, 11, 3, 2, 4, 1, 5, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 271, 74, 29, 6, 4, 4, 1, 1, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 142, 77, 24, 15, 5, 1, 1, 5, 1, 1, 3, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 124, 25, 23, 7, 8, 3, 1, 1, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 82, 24, 15, 5, 4, 4, 1, 4, 2, 6, 1, 6, 4, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 52, 22, 13, 10, 4, 1, 2, 6, 1, 4, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 25, 2, 12, 2, 2, 2, 3, 1, 3, 3, 5, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 4, 3, 6, 4, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 14, 13, 6, 6, 1, 3, 2, 3, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 1, 2, 3, 1, 4, 1, 2, 0, 0, 0, 0, 0, 0, 3, 2, 4, 6, 6, 2, 2, 1, 0, 0, 0, 0, 3, 2, 1, 4, 2, 1, 2, 1, 0, 0, 0, 0, 5, 2, 1, 1, 0, 0, 0, 1, 8, 1, 3, 1, 0, 0, 0, 2, 1, 0, 0, 0, 0, 3, 2, 1, 0, 0, 0, 4, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 6, 11, 1, 1, 0, 0, 0, 0, 0, 9, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 2, 3, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 4, 0, 0, 1, 0, 2, 1, 1, 2, 0, 0, 0, 0, 0, 0, 12, 0, 0, 1, 0, 1, 0, 1, 1, 3, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 4, 2, 2, 2, 1, 2, 2, 1, 1, 1, 18, 11, 3, 7, 5, 1, 2, 1, 1, 3, 2, 2, 4, 4, 2, 3, 2, 1, 1, 43, 10, 9, 4, 26, 3, 5, 5, 1, 1, 6, 7, 1, 6, 4, 1, 1, 24, 34, 4, 32, 7, 4, 2, 6, 1, 2, 1, 2, 17, 9, 9, 7, 4, 1, 19, 5, 26, 1, 1, 2, 3, 6, 2, 7, 2, 7, 14, 4, 1, 3, 30, 60, 7, 10, 7, 4, 2, 5, 6, 1, 2, 9, 49, 1, 1, 2, 4, 4, 5, 127, 61, 37, 98, 22, 7, 3, 3, 5, 10, 7, 13, 3, 2, 4, 1, 93, 49, 34, 3, 7, 6, 5, 2, 10, 2, 1, 107, 80, 7, 6, 5, 4, 5, 2, 9, 153, 42, 17, 5, 2, 12, 15, 6, 3, 17, 7, 1, 109, 62, 18, 1, 3, 3, 10, 16, 45, 56, 64, 24, 15, 6, 3, 9, 42, 20, 1, 34, 12, 16, 4, 9, 6, 4, 29, 14, 8, 19, 14, 10, 21, 30, 8, 4, 3, 44, 15, 24, 5, 7, 18, 11, 11, 2, 3, 11, 9, 13, 2, 2, 5, 1, 31, 2, 0, 0, 0, 0, 4, 5, 2, 0, 0, 1, 1, 9, 0, 0, 0, 0, 11, 3, 12, 0, 0, 0, 0, 4, 5, 10, 5, 6, 9, 0, 0, 0, 0, 0, 18, 23, 22, 3, 25, 37, 3, 4, 0, 0, 0, 0, 0, 0, 0, 9, 39, 13, 2, 16, 13, 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 5, 21, 3, 34, 12, 12, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 50, 24, 42, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 22, 32, 14, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 21, 23, 41, 58, 12, 0, 0, 0, 0, 147, 34, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 289, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 0, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 3, 1, 2, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 2, 3, 1, 4, 2, 1, 1, 4, 1, 4, 1, 1, 1, 1, 1, 11, 14, 2, 2, 1, 2, 2, 4, 6, 5, 2, 3, 26, 4, 1, 1, 2, 2, 5, 3, 8, 4, 1, 27, 18, 8, 3, 3, 5, 5, 2, 6, 20, 43, 40, 50, 11, 2, 1, 1, 20, 5, 2, 2, 7, 23, 16, 2, 1, 2, 8, 1, 10, 28, 8, 4, 4, 5, 8, 2, 10, 3, 6, 5, 1, 14, 6, 6, 3, 2, 2, 2, 13, 11, 2, 2, 6, 3, 2, 3, 1, 4, 0, 0, 5, 1, 0, 0, 1, 1, 1, 0, 0, 13, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 19, 10, 9, 4, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 11, 12, 5, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 6, 2, 2, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 2, 4, 2, 0, 0, 8, 0, 0, 2, 6, 3, 0, 1, 0, 1, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 3, 3, 1, 1, 2, 2, 2, 1, 6, 1, 5, 4, 2, 1, 1, 2, 2, 2, 2, 2, 2, 2, 8, 6, 5, 3, 1, 3, 4, 4, 1, 13, 3, 3, 2, 2, 4, 1, 1, 1, 2, 2, 2, 6, 1, 2, 20, 4, 7, 10, 6, 3, 3, 3, 2, 1, 5, 12, 1, 1, 25, 19, 6, 10, 2, 1, 1, 2, 2, 2, 7, 16, 24, 13, 4, 2, 1, 35, 7, 10, 3, 8, 2, 2, 3, 2, 11, 8, 16, 3, 1, 1, 29, 12, 8, 3, 5, 4, 4, 6, 21, 30, 27, 5, 1, 32, 1, 3, 4, 8, 48, 20, 2, 1, 15, 9, 2, 3, 4, 18, 4, 10, 33, 40, 4, 2, 4, 6, 11, 4, 12, 11, 3, 3, 2, 6, 4, 9, 24, 2, 6, 1, 10, 3, 12, 7, 2, 2, 6, 1, 2, 4, 2, 3, 0, 0, 3, 2, 3, 1, 0, 3, 1, 3, 1, 0, 1, 6, 0, 8, 1, 3, 0, 1, 1, 14, 2, 6, 12, 1, 0, 0, 0, 13, 4, 0, 23, 28, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 64, 20, 7, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 16, 13, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 2, 2, 4, 1, 3, 1, 3, 1, 10, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 3, 1, 0, 0, 0, 2, 8, 2, 1, 1, 1, 19, 5, 10, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 2, 1, 9, 1, 1, 5, 2, 1, 94, 8, 29, 3, 1, 1, 111, 164, 38, 8, 6, 5, 7, 7, 10, 2, 4, 4, 1, 2, 1, 1, 135, 30, 7, 5, 4, 2, 4, 3, 1, 456, 152, 55, 18, 57, 25, 47, 25, 17, 3, 5, 3, 9, 2, 11, 8, 4, 1, 2, 1, 404, 104, 73, 50, 55, 56, 26, 24, 1, 1, 2, 4, 11, 5, 4, 1, 2, 1, 181, 126, 126, 64, 103, 74, 8, 3, 6, 3, 2, 5, 12, 12, 7, 126, 109, 45, 76, 17, 2, 7, 5, 9, 15, 6, 3, 8, 11, 4, 1, 145, 81, 72, 80, 17, 3, 8, 8, 8, 2, 234, 134, 107, 21, 13, 30, 1, 7, 3, 17, 2, 11, 20, 14, 1, 2, 2, 278, 139, 104, 3, 36, 14, 14, 16, 9, 2, 4, 1, 1, 494, 182, 88, 56, 19, 2, 10, 13, 32, 2, 16, 10, 27, 28, 18, 9, 2, 6, 1, 536, 175, 64, 34, 8, 5, 20, 15, 46, 37, 62, 52, 50, 74, 12, 20, 3, 4, 1, 274, 182, 71, 6, 24, 11, 9, 16, 17, 81, 74, 68, 155, 86, 14, 16, 9, 7, 2, 154, 58, 10, 5, 9, 93, 41, 65, 67, 71, 61, 15, 3, 1, 4, 51, 15, 58, 12, 46, 7, 36, 31, 27, 11, 57, 88, 105, 20, 35, 7, 11, 1, 2, 1, 13, 5, 8, 98, 38, 45, 23, 5, 23, 12, 1, 7, 6, 33, 1, 2, 18, 28, 14, 26, 2, 8, 8, 23, 22, 19, 11, 2, 10, 6, 12, 20, 16, 8, 6, 41, 27, 6, 14, 0, 141, 47, 5, 2, 16, 13, 0, 0, 237, 42, 80, 24, 12, 9, 9, 5, 252, 214, 107, 20, 31, 8, 0, 279, 169, 54, 52, 9, 7, 3, 3, 0, 0, 0, 681, 146, 88, 25, 24, 1, 0, 0, 0, 667, 299, 87, 44, 6, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 648, 106, 25, 8, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 628, 218, 16, 16, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 481, 34, 41, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 188, 133, 23, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 93, 20, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 13, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 3, 0, 0, 0, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 3, 2, 2, 1, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3, 0, 0, 0, 1, 0, 2, 4, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 3, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 1, 1, 8, 2, 4, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 2, 1, 2, 1, 2, 2, 3, 1, 2, 1, 3, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 7, 3, 1, 1, 1, 1, 1, 1, 2, 1, 2, 2, 1, 1, 2, 1, 2, 5, 3, 1, 2, 3, 1, 1, 1, 3, 1, 3, 6, 5, 1, 3, 3, 2, 3, 3, 3, 3, 1, 1, 1, 2, 2, 4, 2, 2, 2, 3, 2, 2, 4, 1, 1, 1, 1, 2, 6, 2, 3, 2, 1, 3, 5, 3, 1, 1, 1, 3, 1, 1, 1, 2, 1, 1, 2, 2, 8, 1, 1, 2, 3, 1, 1, 5, 1, 4, 1, 3, 1, 1, 1, 2, 2, 1, 3, 1, 2, 3, 1, 5, 2, 2, 2, 2, 2, 1, 2, 1, 7, 6, 2, 1, 4, 1, 1, 3, 1, 1, 2, 5, 3, 2, 2, 1, 1, 3, 2, 1, 1, 1, 1, 3, 1, 4, 1, 4, 1, 1, 3, 1, 1, 1, 3, 4, 2, 1, 1, 2, 3, 4, 3, 2, 1, 1, 2, 3, 1, 9, 8, 5, 2, 1, 2, 2, 10, 9, 2, 4, 2, 1, 1, 9, 3, 2, 2, 2, 2, 3, 1, 1, 84, 3, 7, 7, 11, 2, 4, 6, 4, 1, 2, 3, 8, 3, 1, 2, 4, 38, 15, 27, 9, 30, 18, 18, 13, 12, 5, 2, 2, 4, 18, 2, 2, 6, 1, 2, 3, 4, 1, 3, 6, 4, 1, 3, 14, 14, 3, 7, 16, 3, 7, 5, 4, 10, 5, 1, 6, 2, 3, 1, 3, 1, 5, 14, 11, 14, 16, 1, 7, 2, 1, 3, 5, 1, 5, 1, 1, 0, 10, 10, 5, 5, 6, 6, 2, 5, 0, 2, 2, 1, 3, 1, 9, 15, 1, 35, 15, 1, 2, 2, 5, 5, 4, 1, 2, 23, 18, 9, 8, 5, 5, 1, 2, 2, 1, 0, 3, 2, 1, 3, 1, 1, 0, 0, 30, 29, 21, 9, 7, 8, 4, 8, 4, 4, 4, 3, 2, 3, 3, 2, 3, 0, 35, 26, 24, 17, 12, 6, 1, 0, 2, 3, 2, 5, 3, 3, 1, 1, 45, 56, 12, 3, 1, 23, 7, 5, 6, 11, 1, 1, 6, 1, 2, 0, 38, 23, 32, 35, 18, 11, 2, 1, 1, 1, 0, 54, 35, 43, 7, 16, 16, 2, 6, 0, 4, 1, 5, 0, 48, 49, 43, 15, 1, 10, 2, 1, 0, 56, 27, 18, 38, 6, 4, 17, 16, 3, 2, 2, 1, 6, 1, 1, 2, 72, 87, 33, 26, 12, 1, 2, 1, 9, 1, 2, 3, 82, 102, 20, 17, 24, 1, 3, 3, 1, 86, 105, 56, 42, 6, 10, 7, 3, 1, 1, 1, 231, 67, 41, 1, 1, 1, 1, 3, 2, 3, 242, 150, 59, 11, 1, 3, 1, 6, 1, 3, 4, 3, 13, 1, 3, 1, 378, 83, 4, 12, 1, 3, 3, 9, 2, 2, 3, 460, 113, 109, 51, 13, 25, 5, 3, 6, 2, 26, 7, 3, 9, 7, 22, 1, 352, 200, 95, 11, 27, 4, 2, 16, 3, 14, 11, 2, 1, 1, 1, 257, 185, 49, 25, 11, 5, 4, 4, 6, 0, 310, 176, 45, 22, 23, 16, 36, 31, 2, 3, 1, 1, 381, 157, 72, 33, 34, 9, 18, 10, 15, 2, 489, 112, 28, 28, 4, 20, 7, 20, 4, 1, 5, 2, 1, 450, 114, 115, 33, 40, 13, 38, 18, 11, 11, 3, 2, 3, 333, 207, 31, 28, 20, 18, 5, 36, 3, 27, 37, 4, 5, 2, 223, 163, 1, 34, 23, 22, 16, 33, 44, 11, 27, 2, 1, 1, 1, 1, 253, 99, 67, 82, 30, 16, 3, 16, 52, 45, 26, 9, 1, 2, 1, 1, 45, 158, 17, 27, 23, 60, 101, 42, 53, 5, 1, 2, 42, 39, 12, 111, 21, 13, 2, 2, 4, 1, 2, 4, 11, 38, 20, 59, 72, 30, 113, 19, 3, 2, 3, 1, 27, 47, 21, 24, 12, 11, 5, 4, 4, 14, 15, 1, 1, 17, 4, 28, 6, 4, 2, 16, 10, 3, 0, 27, 22, 7, 5, 1, 39, 19, 42, 34, 3, 2, 0, 0, 35, 15, 128, 12, 1, 2, 1, 0, 0, 0, 0, 0, 0, 136, 325, 33, 5, 5, 4, 2, 0, 0, 0, 0, 359, 48, 16, 13, 13, 4, 0, 0, 0, 0, 1012, 91, 14, 7, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1022, 82, 15, 18, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 854, 63, 17, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 699, 40, 3, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 489, 5, 6, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 132, 24, 25, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 36, 18, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 13, 1, 1, 1, 14, 1, 1, 1, 2, 2, 2, 1, 1, 7, 1, 3, 3, 3, 4, 12, 7, 28, 39, 9, 9, 20, 7, 14, 7, 5, 3, 1, 2, 4, 4, 2, 2, 1, 2, 3, 2, 1, 3, 3, 1, 1, 1, 2, 2, 3, 3, 2, 2, 2, 1, 1, 1, 2, 2, 1, 1, 4, 3, 1, 2, 2, 2, 2, 1, 1, 1, 1, 2, 3, 0, 0, 0, 0, 0, 2, 6, 0, 0, 0, 3, 1, 0, 0, 13, 2, 2, 1, 0, 0, 0, 0, 0, 17, 6, 6, 2, 2, 2, 2, 2, 1, 0, 0, 2, 0, 0, 0, 0, 1, 11, 2, 2, 1, 3, 0, 0, 0, 0, 0, 6, 1, 1, 0, 0, 0, 0, 0, 11, 4, 1, 1, 2, 0, 2, 1, 2, 0, 0, 0, 0, 0, 2, 3, 4, 1, 1, 0, 2, 1, 0, 0, 0, 0, 2, 2, 1, 1, 1, 1, 2, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 1, 2, 0, 0, 0, 0, 1, 1, 0, 2, 1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 2, 1, 0, 0, 0, 1, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 2, 1, 1, 0, 0, 1, 3, 2, 1, 1, 1, 1, 3, 3, 2, 1, 7, 1, 3, 0, 0, 0, 1, 2, 0, 0, 1, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 3, 1, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 4, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 2, 0, 2, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 1, 1, 1, 2, 2, 3, 1, 2, 4, 13, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 3, 2, 6, 1, 2, 4, 1, 2, 5, 11, 1, 2, 4, 1, 1, 1, 2, 2, 37, 4, 1, 1, 1, 8, 6, 3, 2, 2, 1, 1, 1, 3, 1, 1, 4, 1, 3, 1, 2, 1, 2, 5, 6, 8, 23, 11, 10, 3, 14, 23, 20, 13, 6, 4, 7, 2, 7, 18, 9, 14, 37, 8, 15, 3, 18, 12, 3, 1, 2, 1, 2, 2, 2, 4, 0, 3, 2, 3, 3, 3, 1, 1, 2, 1, 0, 0, 3, 1, 4, 2, 1, 0, 0, 0, 1, 1, 2, 1, 3, 0, 0, 0, 2, 1, 0, 0, 1, 1, 2, 1, 5, 1, 2, 2, 0, 0, 0, 0, 0, 0, 4, 2, 2, 2, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 3, 2, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 3, 2, 5, 0, 0, 0, 2, 1, 1, 2, 0, 0, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 5, 4, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 6, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 5, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 2, 4, 3, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 2, 1, 6, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 8, 10, 7, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 3, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 2, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 1, 2, 2, 1, 1, 3, 8, 9, 1, 1, 1, 4, 2, 11, 3, 4, 2, 2, 1, 4, 1, 1, 2, 1, 0, 2, 0, 1, 1, 1, 2, 0, 0, 2, 2, 1, 0, 0, 0, 0, 1, 3, 1, 3, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 2, 2, 1, 1, 15, 17, 1, 2, 2, 7, 3, 1, 1, 4, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 5, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 2, 1, 0, 0, 1, 1, 1, 1, 1, 1, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 4, 19, 1, 1, 2, 17, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 3, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 1, 18, 9, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 3, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 9, 9, 4, 1, 1, 1, 2, 10, 7, 1, 1, 1, 1, 3, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 2, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 14, 8, 2, 7, 5, 9, 4, 3, 1, 2, 4, 1, 2, 1, 1, 1, 21, 5, 6, 4, 39, 20, 6, 11, 1, 2, 1, 1, 2, 2, 2, 2, 2, 1, 2, 17, 13, 2, 3, 4, 11, 7, 2, 1, 8, 20, 4, 10, 30, 4, 3, 3, 1, 3, 1, 1, 1, 1, 2, 5, 2, 2, 2, 1, 3, 0, 1, 1, 0, 0, 1, 2, 0, 0, 0, 0, 0, 6, 1, 3, 1, 1, 2, 1, 1, 5, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 4, 1, 1, 1, 1, 1, 1, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 4, 1, 1, 0, 0, 0, 0, 0, 0, 1, 3, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 0, 0, 0, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 2, 2, 1, 1, 2, 2, 2, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 3, 1, 3, 2, 4, 1, 1, 1, 1, 2, 1, 6, 1, 3, 1, 6, 2, 4, 3, 1, 1, 1, 1, 5, 4, 3, 9, 2, 1, 1, 4, 2, 1, 16, 1, 2, 3, 1, 1, 30, 4, 5, 1, 5, 1, 1, 7, 4, 5, 1, 1, 4, 7, 1, 1, 2, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 9, 1, 4, 1, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 2, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 5, 6, 10, 0, 0, 6, 5, 4, 0, 6, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 4, 2, 1, 1, 1, 1, 1, 1, 1, 2, 3, 6, 2, 1, 3, 1, 5, 2, 1, 1, 2, 1, 1, 1, 1, 1, 2, 2, 3, 7, 15, 14, 6, 2, 1, 2, 1, 4, 1, 4, 1, 3, 1, 1, 1, 1, 6, 8, 7, 1, 2, 1, 1, 3, 2, 2, 2, 2, 1, 2, 1, 2, 2, 1, 1, 1, 1, 2, 5, 2, 2, 2, 1, 2, 2, 1, 1, 1, 1, 1, 1, 4, 2, 2, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 3, 2, 2, 3, 4, 1, 1, 1, 2, 1, 4, 3, 2, 2, 1, 1, 2, 1, 2, 2, 5, 1, 3, 2, 1, 1, 9, 2, 1, 5, 1, 2, 3, 2, 1, 4, 1, 0, 5, 3, 2, 2, 1, 1, 0, 2, 8, 7, 1, 1, 5, 3, 5, 0, 2, 4, 3, 1, 9, 1, 0, 0, 0, 2, 2, 5, 9, 8, 2, 0, 0, 0, 0, 0, 22, 12, 0, 5, 1, 1, 5, 10, 1, 0, 0, 0, 0, 0, 0, 15, 13, 3, 2, 4, 1, 1, 1, 3, 3, 11, 9, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 30, 7, 2, 4, 1, 11, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 29, 8, 3, 41, 3, 0, 0, 0, 0, 0, 8, 2, 44, 2, 2, 0, 0, 0, 0, 1, 2, 22, 3, 2, 1, 0, 0, 1, 3, 1, 0, 4, 1, 0, 2, 4, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 7, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 49, 5, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 5, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 10, 1, 1, 4, 1, 1, 2, 4, 22, 1, 1, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 4, 0, 1, 0, 1, 0, 1, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 3, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 9, 1, 1, 1, 2, 2, 1, 19, 5, 1, 2, 2, 1, 2, 1, 1, 1, 2, 1, 1, 2, 4, 1, 1, 1, 1, 1, 46, 10, 4, 10, 7, 3, 5, 4, 2, 7, 1, 5, 3, 2, 4, 1, 2, 2, 2, 6, 11, 13, 18, 21, 15, 7, 5, 1, 2, 6, 4, 1, 3, 6, 2, 1, 9, 3, 1, 1, 2, 2, 5, 6, 18, 18, 16, 14, 8, 4, 4, 3, 1, 1, 5, 1, 1, 1, 6, 3, 3, 2, 3, 6, 2, 1, 1, 2, 4, 1, 9, 1, 6, 3, 1, 2, 2, 2, 2, 4, 1, 2, 3, 1, 3, 6, 2, 5, 3, 9, 2, 2, 6, 1, 2, 1, 3, 4, 2, 4, 1, 3, 4, 2, 2, 3, 2, 5, 4, 3, 7, 7, 3, 4, 2, 3, 6, 3, 3, 2, 1, 1, 6, 10, 2, 5, 2, 4, 3, 2, 1, 6, 2, 1, 2, 4, 5, 3, 5, 3, 2, 2, 6, 8, 4, 6, 2, 13, 5, 3, 5, 5, 4, 3, 2, 2, 1, 7, 5, 2, 4, 5, 2, 4, 3, 4, 4, 1, 1, 7, 17, 2, 15, 3, 3, 2, 3, 1, 3, 2, 3, 6, 3, 2, 7, 3, 1, 3, 6, 5, 1, 1, 5, 9, 12, 10, 2, 2, 2, 2, 3, 1, 3, 2, 6, 4, 4, 3, 6, 4, 12, 6, 4, 3, 3, 6, 2, 3, 1, 5, 6, 7, 3, 2, 3, 1, 6, 4, 3, 2, 1, 1, 1, 4, 5, 8, 4, 2, 1, 1, 4, 1, 5, 2, 4, 7, 0, 1, 4, 0, 3, 0, 0, 2, 1, 2, 4, 0, 4, 9, 9, 3, 1, 4, 3, 0, 0, 0, 10, 1, 3, 3, 1, 1, 7, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 15, 5, 2, 7, 1, 3, 6, 14, 7, 1, 1, 0, 0, 0, 0, 0, 21, 8, 11, 7, 10, 6, 5, 1, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 13, 1, 2, 1, 4, 7, 3, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 3, 1, 1, 4, 4, 3, 3, 9, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 4, 3, 2, 3, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 7, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 2, 2, 4, 0, 0, 0, 0, 0, 0, 0, 3, 2, 5, 9, 5, 3, 0, 0, 0, 12, 2, 11, 16, 1, 2, 0, 0, 0, 0, 0, 5, 10, 8, 2, 1, 0, 0, 0, 0, 0, 0, 0, 4, 7, 1, 0, 0, 0, 0, 24, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 0, 2, 0, 1, 0, 1, 0, 1, 0, 2, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 6, 2, 9, 1, 7, 7, 1, 1, 2, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 1, 6, 2, 9, 1, 4, 10, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 3, 0, 0, 0, 0, 4, 0, 2, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 4, 1, 5, 0, 0, 1, 5, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 4, 3, 1, 1, 1, 2, 1, 1, 2, 1, 29, 26, 5, 12, 6, 7, 2, 1, 6, 1, 2, 1, 1, 57, 19, 52, 22, 21, 3, 5, 6, 2, 16, 6, 1, 1, 1, 33, 92, 39, 17, 4, 4, 1, 5, 22, 1, 1, 53, 32, 8, 8, 1, 2, 1, 185, 98, 26, 9, 9, 3, 7, 114, 5, 3, 1, 1, 236, 35, 9, 15, 3, 6, 4, 6, 12, 141, 10, 5, 108, 48, 39, 7, 14, 2, 3, 2, 15, 367, 7, 4, 29, 3, 2, 3, 27, 162, 6, 3, 6, 1, 12, 20, 99, 5, 2, 1, 4, 82, 4, 2, 21, 8, 3, 4, 0, 12, 6, 5, 5, 0, 2, 9, 1, 1, 69, 3, 0, 228, 142, 24, 12, 1, 6, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 104, 3, 2, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20, 19, 7, 6, 3, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 4, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 2, 46, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 1, 0, 2, 2, 1, 0, 4, 2, 1, 2, 0, 0, 0, 1, 2, 1, 0, 1, 1, 0, 0, 2, 3, 1, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 4, 1, 2, 1, 1, 4, 3, 1, 1, 4, 2, 0, 0, 0, 1, 2, 1, 2, 2, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0], "yaxis": "y"}], "layout": {"height": 300, "legend": {"tracegroupgap": 0}, "shapes": [{"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 34263, "x1": 34263, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 35120, "x1": 35120, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 38160, "x1": 38160, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 42847, "x1": 42847, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 50589, "x1": 50589, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 71972, "x1": 71972, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 97616, "x1": 97616, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 8564155, "x1": 8564155, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28592157, "x1": 28592157, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28595448, "x1": 28595448, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28598056, "x1": 28598056, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28598061, "x1": 28598061, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28598165, "x1": 28598165, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 28600700, "x1": 28600700, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}], "template": {"data": {"bar": [{"error_x": {"color": "rgb(36,36,36)"}, "error_y": {"color": "rgb(36,36,36)"}, "marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "baxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmapgl"}], "histogram": [{"marker": {"line": {"color": "white", "width": 0.6}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "rgb(237,237,237)"}, "line": {"color": "white"}}, "header": {"fill": {"color": "rgb(217,217,217)"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "colorscale": {"diverging": [[0.0, "rgb(103,0,31)"], [0.1, "rgb(178,24,43)"], [0.2, "rgb(214,96,77)"], [0.3, "rgb(244,165,130)"], [0.4, "rgb(253,219,199)"], [0.5, "rgb(247,247,247)"], [0.6, "rgb(209,229,240)"], [0.7, "rgb(146,197,222)"], [0.8, "rgb(67,147,195)"], [0.9, "rgb(33,102,172)"], [1.0, "rgb(5,48,97)"]], "sequential": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "sequentialminus": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]]}, "colorway": ["#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF"], "font": {"color": "rgb(36,36,36)"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "white", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "white", "polar": {"angularaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "radialaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "scene": {"xaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "zaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}, "shapedefaults": {"fillcolor": "black", "line": {"width": 0}, "opacity": 0.3}, "ternary": {"aaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "baxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "caxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}}, "title": {"text": "3R"}, "width": 750, "xaxis": {"anchor": "y", "domain": [0.0, 1.0], "title": {"text": "midpoint"}}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0], "title": {"text": "depth"}}}}, "text/html": ["<div>                            <div id=\"99e7e911-6899-4216-8a64-6ce78ba8c4ee\" class=\"plotly-graph-div\" style=\"height:300px; width:750px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"99e7e911-6899-4216-8a64-6ce78ba8c4ee\")) {                    Plotly.newPlot(                        \"99e7e911-6899-4216-8a64-6ce78ba8c4ee\",                        [{\"hovertemplate\":\"midpoint=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"\",\"marker\":{\"color\":\"lightsalmon\",\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"showlegend\":false,\"x\":[7233,7236,7236,16860,16878,17031,17031,17032,17069,17069,17487,21348,25299,4840419,13671862,14299019,14300293,14483,14485,14487,24281,24282,33796,33832,33968,33986,34063,34063,34064,34065,34065,34066,34066,34067,34068,34071,34071,34074,34075,34076,34078,34079,34080,34083,34084,34084,34085,34085,34086,34086,34088,34093,34094,34094,34095,34095,34096,34100,34100,34101,34101,34139,34065,34066,34066,34067,34068,34068,34071,34071,34072,34076,34078,34079,34080,34084,34085,34087,34088,34090,34095,34096,34099,34100,34100,34101,34101,34102,34067,34101,34102,34102,34098,34102,34102,34103,34073,34102,34103,34069,34071,34078,34103,34104,34090,34096,34099,34104,34074,34104,34105,34105,34091,34107,34108,34098,34101,34108,34108,34111,34111,34112,34112,34113,34115,34115,34116,34116,34117,34120,34120,34105,34120,34121,34121,34122,34122,34122,34123,34123,34123,34124,34124,34125,34127,34127,34130,34130,34131,34131,34131,34132,34132,34132,34132,34133,34133,34133,34135,34136,34136,34137,34137,34137,34138,34138,34139,34140,34140,34141,34141,34142,34142,34143,34143,34144,34145,34145,34146,34146,34147,34148,34149,34150,34150,34152,34152,34153,34153,34156,34159,34160,34162,34168,34172,34177,34140,34141,34141,34142,34142,34144,34144,34145,34146,34148,34150,34151,34152,34153,34158,34177,34141,34142,34143,34145,34146,34149,34151,34151,34153,34142,34143,34143,34145,34145,34146,34146,34147,34148,34148,34149,34149,34151,34152,34154,34143,34144,34144,34145,34145,34146,34146,34147,34147,34148,34148,34149,34149,34150,34150,34151,34151,34152,34152,34155,34144,34145,34146,34146,34147,34148,34149,34149,34150,34150,34152,34153,34179,34145,34146,34146,34147,34147,34148,34149,34149,34150,34151,34152,34153,34153,34180,34147,34148,34149,34154,34148,34149,34150,34150,34151,34154,34148,34149,34150,34151,34152,34149,34150,34150,34151,34151,34152,34153,34154,34155,34155,34158,34165,34182,34151,34152,34152,34153,34155,34156,34151,34152,34152,34153,34153,34154,34155,34156,34156,34159,34153,34153,34154,34158,34159,34153,34154,34154,34155,34155,34157,34157,34154,34155,34156,34157,34158,34155,34156,34156,34157,34158,34158,34160,34161,34156,34158,34158,34159,34157,34158,34158,34159,34159,34161,34162,34170,34173,34186,34159,34160,34160,34160,34162,34160,34161,34161,34163,34164,34164,34167,34162,34163,34163,34164,34164,34165,34166,34167,34168,34177,34164,34164,34165,34164,34165,34165,34165,34166,34166,34170,34166,34167,34169,34167,34168,34169,34170,34171,34171,34172,34173,34191,34168,34169,34169,34170,34170,34171,34171,34172,34172,34173,34173,34174,34174,34175,34176,34176,34177,34178,34186,34191,34191,34169,34170,34170,34171,34171,34172,34172,34173,34173,34174,34174,34176,34177,34170,34171,34171,34172,34172,34173,34173,34174,34174,34175,34176,34180,34190,34171,34172,34172,34173,34173,34174,34174,34175,34172,34173,34173,34174,34174,34175,34175,34176,34178,34179,34173,34174,34174,34175,34175,34176,34176,34177,34177,34178,34178,34179,34194,34174,34175,34175,34176,34176,34177,34177,34178,34178,34179,34179,34181,34181,34182,34175,34176,34176,34177,34177,34178,34178,34179,34179,34180,34180,34182,34176,34177,34177,34178,34178,34179,34179,34180,34180,34181,34182,34182,34183,34183,34184,34193,34194,34195,34177,34178,34178,34179,34179,34180,34180,34181,34181,34183,34184,34187,34196,34178,34179,34179,34180,34180,34181,34181,34182,34183,34184,34184,34193,34194,34196,34179,34180,34180,34181,34181,34182,34182,34183,34183,34184,34184,34185,34186,34190,34197,34180,34181,34181,34182,34182,34183,34183,34184,34184,34185,34185,34186,34187,34188,34192,34193,34194,34196,34197,34181,34182,34182,34183,34183,34184,34184,34185,34185,34186,34187,34182,34183,34183,34184,34184,34185,34185,34187,34187,34188,34194,34198,34183,34184,34184,34185,34185,34186,34186,34187,34187,34188,34190,34196,34199,34184,34185,34185,34186,34186,34187,34187,34188,34197,34199,34185,34186,34186,34187,34187,34188,34188,34189,34190,34192,34193,34196,34198,34200,34186,34187,34187,34188,34188,34189,34189,34190,34191,34194,34195,34197,34198,34200,34187,34188,34188,34189,34189,34190,34191,34193,34194,34196,34196,34197,34198,34198,34199,34201,34188,34189,34189,34190,34191,34192,34192,34194,34198,34199,34200,34201,34201,34189,34190,34190,34191,34191,34192,34193,34193,34198,34201,34202,34190,34191,34191,34192,34192,34193,34193,34194,34194,34196,34197,34198,34199,34200,34200,34201,34202,34202,34191,34192,34192,34193,34193,34194,34195,34195,34196,34196,34197,34198,34198,34199,34199,34200,34201,34201,34202,34203,34192,34193,34193,34194,34194,34195,34195,34196,34197,34197,34198,34198,34199,34199,34200,34201,34201,34202,34203,34203,34193,34194,34194,34196,34199,34200,34194,34195,34195,34196,34196,34197,34197,34198,34198,34199,34199,34200,34200,34201,34201,34202,34202,34203,34203,34204,34204,34195,34196,34196,34197,34197,34198,34198,34199,34199,34200,34200,34201,34201,34202,34203,34203,34204,34204,34205,34196,34197,34197,34198,34198,34199,34199,34200,34200,34201,34201,34202,34203,34203,34204,34204,34205,34205,34197,34198,34198,34199,34199,34200,34200,34201,34201,34202,34202,34203,34204,34205,34205,34206,34198,34199,34200,34200,34201,34201,34202,34203,34204,34204,34205,34206,34206,34199,34200,34200,34201,34202,34202,34203,34204,34205,34206,34207,34201,34202,34203,34203,34204,34205,34205,34201,34202,34202,34203,34203,34204,34204,34205,34206,34207,34208,34202,34203,34203,34204,34205,34206,34206,34207,34208,34208,34203,34204,34204,34205,34205,34206,34207,34207,34208,34209,34204,34205,34205,34206,34207,34207,34208,34209,34205,34206,34206,34207,34208,34208,34209,34209,34210,34206,34207,34208,34208,34209,34209,34210,34210,34207,34208,34208,34209,34209,34210,34210,34211,34208,34209,34209,34210,34210,34211,34211,34209,34210,34211,34211,34212,34210,34211,34211,34212,34212,34211,34212,34212,34213,34212,34213,34213,34213,34214,34214,34215,34216,34216,34217,34217,34218,34219,34219,34220,34220,34221,34222,34223,34224,34224,34225,34226,34227,34229,34231,34232,34233,34233,34234,34235,34236,34237,34238,34239,34241,34241,34250,34250,34251,34251,34252,34252,34595,34637,36129,36156,38456,38485,34216,34217,34217,34218,34218,34219,34219,34220,34220,34221,34221,34222,34223,34223,34224,34224,34225,34225,34226,34226,34227,34228,34229,34230,34230,34231,34231,34232,34233,34233,34234,34235,34236,34237,34238,34238,34239,34239,34240,34240,34241,34243,34244,34246,34247,34249,34249,34250,34251,34251,34252,34252,34253,34595,34637,34217,34218,34218,34219,34219,34220,34220,34221,34223,34224,34224,34225,34225,34226,34226,34227,34228,34230,34231,34235,34237,34239,34240,34241,34243,34245,34248,34252,34218,34219,34219,34220,34220,34221,34221,34222,34224,34226,34227,34230,34231,34232,34234,34236,34237,34253,34254,34219,34220,34221,34221,34224,34224,34226,34235,34241,34254,34220,34221,34221,34222,34223,34223,34224,34224,34225,34226,34226,34227,34228,34237,34237,34242,34248,34255,34221,34222,34222,34223,34225,34228,34230,34241,34253,34222,34223,34224,34224,34225,34225,34226,34228,34228,34229,34230,34232,34233,34233,34234,34237,34239,34241,34253,34256,34223,34224,34224,34225,34225,34226,34227,34227,34228,34233,34233,34236,34239,34240,34242,34224,34225,34225,34226,34227,34227,34228,34228,34229,34232,34234,34237,34239,34240,34251,34225,34226,34226,34227,34227,34228,34229,34230,34230,34231,34234,34234,34235,34236,34244,34246,34255,34257,34226,34227,34227,34228,34228,34229,34229,34230,34233,34234,34238,34240,34241,34243,34245,34251,34258,34227,34228,34228,34229,34229,34230,34232,34235,34244,34248,34258,34228,34229,34229,34231,34231,34232,34233,34236,34245,34229,34230,34230,34231,34232,34232,34233,34234,34235,34236,34236,34238,34239,34242,34245,34258,34230,34231,34231,34232,34233,34235,34236,34238,34240,34246,34247,34232,34233,34233,34240,34243,34247,34250,34260,34260,34232,34233,34233,34237,34244,34248,34254,34261,34233,34234,34234,34236,34241,34243,34244,34245,34247,34260,34261,34261,34234,34235,34235,34236,34236,34237,34237,34238,34238,34239,34240,34241,34242,34242,34243,34243,34244,34244,34245,34246,34247,34247,34248,34249,34249,34250,34251,34251,34259,34261,34262,34604,34235,34236,34236,34237,34238,34238,34239,34239,34241,34241,34242,34242,34243,34244,34245,34248,34249,34250,34252,34253,34254,34258,34262,34237,34237,34238,34239,34239,34240,34241,34243,34243,34244,34246,34247,34248,34250,34250,34252,34252,34257,34259,34261,34263,34238,34239,34240,34240,34242,34244,34249,34257,34240,34247,34249,34250,34251,34259,34261,34264,34247,34264,34241,34241,34242,34244,34245,34245,34247,34248,34249,34250,34251,34252,34258,34264,34265,34248,34249,34265,34242,34243,34243,34244,34247,34248,34251,34243,34244,34245,34245,34246,34247,34248,34249,34249,34250,34251,34252,34253,34253,34255,34256,34256,34260,34260,34261,34264,34266,34244,34245,34245,34246,34247,34247,34248,34249,34250,34251,34251,34252,34253,34254,34254,34261,34263,34264,34265,34265,34267,34248,34250,34254,34267,34246,34248,34248,34250,34251,34252,34253,34254,34255,34257,34264,34267,34268,34248,34249,34249,34250,34251,34252,34253,34255,34257,34267,34268,34249,34249,34254,34260,34263,34269,34252,34257,34258,34250,34251,34252,34252,34253,34254,34255,34256,34256,34260,34267,34268,34269,34270,34252,34253,34254,34256,34257,34257,34264,34269,34270,34270,34252,34253,34253,34254,34255,34258,34262,34269,34270,34271,34253,34257,34259,34255,34256,34257,34258,34259,34260,34261,34263,34270,34271,34255,34256,34258,34259,34259,34270,34272,34257,34257,34258,34258,34259,34260,34260,34262,34262,34264,34265,34267,34269,34269,34271,34272,34273,34257,34260,34273,34258,34259,34259,34260,34260,34261,34261,34262,34263,34265,34267,34268,34269,34271,34273,34274,34260,34272,34260,34261,34262,34262,34264,34264,34270,34274,34275,34261,34262,34262,34263,34263,34264,34264,34265,34265,34267,34268,34268,34269,34270,34271,34271,34272,34273,34273,34274,34275,34275,34262,34264,34267,34272,34275,34263,34264,34265,34266,34266,34267,34268,34269,34270,34270,34271,34271,34272,34273,34273,34274,34274,34275,34275,34276,34276,34264,34265,34266,34266,34268,34268,34269,34269,34270,34270,34271,34271,34272,34272,34274,34275,34275,34276,34277,34265,34266,34267,34268,34268,34269,34269,34271,34271,34273,34273,34274,34274,34275,34275,34276,34276,34277,34277,34266,34267,34278,34267,34268,34268,34269,34269,34270,34272,34274,34275,34277,34278,34278,34268,34269,34272,34273,34274,34274,34276,34278,34279,34269,34270,34270,34271,34272,34273,34273,34274,34274,34275,34275,34276,34276,34277,34277,34278,34278,34279,34279,34270,34271,34271,34273,34273,34274,34274,34276,34277,34278,34280,34272,34273,34275,34279,34272,34274,34276,34276,34277,34280,34273,34274,34275,34275,34276,34276,34277,34278,34278,34279,34279,34280,34281,34281,34276,34277,34277,34279,34276,34276,34277,34277,34278,34279,34279,34280,34280,34281,34281,34282,34282,34283,34277,34278,34278,34279,34279,34280,34280,34281,34282,34282,34283,34283,34278,34279,34279,34280,34281,34281,34282,34282,34283,34283,34284,34279,34280,34281,34282,34282,34283,34284,34284,34280,34281,34281,34282,34282,34283,34283,34284,34284,34285,34281,34282,34282,34283,34283,34284,34284,34285,34285,34282,34283,34283,34284,34284,34285,34286,34283,34284,34284,34285,34286,34286,34284,34285,34285,34286,34286,34287,34285,34286,34286,34287,34287,34286,34287,34287,34288,34287,34288,34288,34288,34289,34289,34738,34290,34291,34291,34630,34632,34632,34674,34681,34685,34690,36166,36194,36196,36217,36220,38493,38522,65914,10129458,18431536,26617487,34291,34292,34632,34633,34633,34633,34633,34634,34676,34973,34974,34975,34976,34976,34977,34977,34978,34979,34979,34985,34986,34986,34988,34993,34994,34996,35001,35003,35008,35010,35013,35014,35014,35015,35016,35016,35017,35050,34976,34977,34987,35014,35016,35017,35017,34977,35017,35017,35018,35017,35018,35018,34991,35018,35018,35019,35019,35020,35020,35021,34996,35028,35028,35028,36548,35030,35030,35033,35036,35037,35043,35045,35049,35051,35054,35055,35056,35057,35057,35057,35058,35058,35092,35059,35060,35060,35061,35061,35062,35063,35063,35064,35064,35065,35065,35066,35066,35067,35067,35068,35068,35069,35069,35070,35070,35071,35071,35072,35073,35073,35074,35074,35075,35076,35076,35077,35078,35078,35079,35080,35082,35082,35083,35084,35085,35085,35086,35088,35089,35090,35090,35091,35092,35092,35060,35061,35061,35062,35062,35063,35064,35065,35066,35066,35067,35068,35069,35070,35071,35075,35077,35084,35085,35090,35091,35092,35093,35062,35064,35066,35068,35071,35071,35077,35090,35093,35062,35063,35064,35066,35067,35068,35069,35069,35071,35073,35075,35084,35087,35094,35063,35064,35065,35065,35066,35066,35067,35067,35068,35068,35069,35071,35072,35072,35075,35075,35076,35077,35081,35084,35093,35094,35094,35065,35066,35067,35069,35070,35095,35067,35067,35069,35071,35073,35083,35096,35068,35069,35070,35071,35077,35082,35096,35068,35070,35071,35072,35084,35090,35096,35097,35069,35071,35071,35072,35075,35075,35076,35077,35097,35071,35072,35073,35075,35090,35091,35098,35072,35072,35098,35073,35074,35076,35078,35085,35073,35074,35075,35075,35081,35082,35084,35084,35086,35092,35093,35099,35075,35076,35077,35078,35078,35079,35080,35081,35082,35082,35083,35084,35085,35087,35089,35092,35093,35094,35095,35095,35100,35075,35100,35076,35077,35078,35078,35079,35079,35080,35080,35081,35081,35082,35082,35083,35084,35085,35086,35086,35087,35088,35088,35089,35089,35090,35090,35091,35092,35093,35094,35095,35095,35096,35097,35101,35079,35094,35095,35101,35079,35094,35095,35102,35085,35102,35085,35085,35093,35081,35082,35082,35083,35084,35085,35085,35086,35087,35088,35089,35090,35090,35091,35091,35092,35093,35094,35094,35096,35096,35097,35100,35101,35102,35103,35103,35082,35089,35090,35096,35097,35103,35104,35083,35084,35085,35086,35086,35090,35091,35091,35093,35093,35094,35097,35097,35098,35099,35104,35085,35090,35090,35091,35091,35092,35093,35093,35094,35095,35097,35098,35103,35104,35105,35087,35086,35087,35087,35090,35091,35091,35093,35093,35094,35095,35096,35098,35106,35088,35089,35089,35091,35091,35092,35093,35093,35094,35094,35095,35097,35099,35102,35106,35092,35093,35106,35107,35090,35091,35091,35092,35092,35093,35094,35094,35095,35096,35100,35100,35105,35107,35107,35093,35094,35095,35099,35100,35101,35107,35108,35092,35093,35093,35094,35095,35095,35096,35099,35100,35102,35107,35108,35108,35095,35101,35093,35096,35098,35101,35109,35095,35095,35097,35109,35110,35096,35097,35098,35101,35103,35110,35110,35097,35098,35100,35103,35104,35109,35110,35111,35098,35098,35099,35100,35102,35102,35104,35104,35111,35111,35098,35099,35100,35101,35102,35104,35106,35109,35110,35111,35112,38897,35099,35100,35101,35101,35102,35103,35105,35105,35110,35111,35112,35112,35100,35101,35101,35102,35103,35105,35105,35106,35113,35103,35103,35104,35105,35106,35106,35110,35113,35103,35104,35106,35108,35114,35105,35107,35107,35108,35109,35111,35104,35105,35106,35107,35109,35106,35108,35108,35109,35113,35115,35108,35115,35116,35107,35109,35110,35111,35114,35116,35110,35111,35114,35115,35117,35110,35114,35117,35110,35117,35111,35112,35113,35113,35114,35115,35116,35118,35118,35113,35113,35114,35114,35115,35116,35116,35117,35118,35119,35114,35114,35115,35116,35117,35117,35118,35118,35119,35120,36606,35116,35116,35117,35118,35120,35120,35121,35118,35119,35120,35121,35121,35122,35122,35122,35123,35123,35123,35123,35124,35124,35124,35125,35125,35126,35127,35127,35128,35128,35129,35130,35132,35132,35133,35135,35136,35136,35137,35137,35138,35138,35139,35139,35142,35143,35144,35149,35156,35157,35158,35161,35164,35165,35166,35167,35167,35168,36584,36612,36616,36626,36633,36638,36642,36676,38911,38940,66417,35127,35128,35128,35129,35129,35130,35131,35131,35132,35132,35133,35133,35134,35136,35137,35137,35138,35139,35139,35140,35143,35145,35147,35149,35152,35154,35157,35158,35158,35163,35163,35164,35164,35165,35166,35166,35167,35168,35168,36615,35133,35137,35138,35140,35148,35149,35157,35168,35169,35135,35139,35141,35169,35169,35132,35170,36614,35141,35142,35160,35165,35133,35147,35171,35137,35140,35142,35143,35171,35172,38944,35172,35159,35166,35173,35140,35142,35145,35168,35174,35144,35158,35174,35174,35166,35175,35159,35175,35147,35147,35177,35148,35148,35149,35171,35177,35178,35162,35168,35150,35150,35179,35150,35179,35170,35177,35180,35152,35176,35178,35180,35152,35163,35171,35180,35181,35159,35170,35171,35172,35172,35179,35181,35181,35184,35185,35175,35186,35187,35175,35188,35189,35189,35190,35191,35192,35193,35193,35184,35194,35195,35196,35187,35187,35188,35198,35189,35199,35190,35199,35197,35199,35200,35200,35200,35201,35201,35202,35203,35204,35204,35205,35205,35206,35207,35207,35207,35207,35208,35208,35209,35209,35210,35211,35211,36626,36626,36654,36677,36680,36681,38953,38982,39001,39003,39006,42884,53591,26617947,36627,36627,36628,38042,38043,38044,38044,38045,38046,38047,38049,38065,38066,38067,38068,38069,38069,38070,38070,38112,38118,38045,38045,38070,38071,38071,38071,38047,38048,38070,38071,38072,38049,38072,38072,38073,38072,38073,38074,38077,38092,38093,38094,38093,38095,38096,38096,38096,38096,38097,38097,38098,38099,38099,38100,38100,38101,38101,38102,38102,38103,38103,38104,38105,38106,38106,38107,38107,38108,38109,38109,38110,38110,38111,38112,38113,38114,38115,38115,38116,38117,38117,38118,38118,38119,38119,38120,38120,38121,38121,38122,38122,38123,38123,38124,38124,38125,38125,38126,38126,38127,38128,38128,38129,38130,38132,38136,38138,38138,38139,38140,38141,38141,38143,38145,38145,38146,38146,38100,38101,38102,38102,38105,38107,38112,38116,38118,38119,38119,38120,38120,38121,38121,38122,38125,38146,38146,38100,38120,38122,38124,38127,38110,38115,38121,38122,38122,38104,38110,38121,38122,38123,38103,38105,38115,38116,38121,38122,38122,38131,38148,38118,38119,38121,38122,38123,38123,38124,38124,38126,38149,38119,38120,38122,38122,38123,38124,38127,38131,38149,38123,38123,38124,38125,38125,38134,38135,38146,38127,38127,38124,38151,38126,38127,38120,38127,38153,38116,38126,38127,38129,38134,38130,38125,38136,38129,38131,38131,38156,38125,38126,38157,38125,38136,38133,38136,38132,38134,38132,38135,38160,38143,38130,38133,38135,38136,38131,38133,38135,38137,38139,38162,38138,38143,38163,38136,38137,38138,38141,38142,38155,38138,38139,38138,38144,38147,38164,38138,38165,38139,38138,38139,38139,38140,38141,38141,38144,38149,38140,38140,38141,38141,38142,38144,38146,38148,38149,38140,38141,38141,38142,38142,38144,38145,38147,38167,38141,38142,38142,38143,38143,38144,38145,38145,38146,38146,38147,38147,38148,38149,38153,38155,38159,38160,38161,38164,38165,38166,38166,38167,38167,38142,38143,38145,38146,38148,38143,38144,38145,38146,38146,38147,38147,38148,38149,38149,38150,38150,38152,38157,38162,38163,38163,38164,38167,38168,38144,38145,38146,38146,38147,38147,38148,38148,38149,38149,38150,38152,38152,38153,38154,38156,38157,38158,38159,38161,38162,38163,38164,38165,38166,38167,38167,38168,38168,38169,38146,38146,38147,38147,38148,38148,38149,38149,38150,38151,38157,38160,38164,38165,38166,38168,38168,38169,38169,38147,38148,38148,38148,38170,38148,38149,38151,38152,38155,38159,38166,38167,38168,38169,38170,38171,38149,38150,38150,38151,38151,38152,38153,38154,38163,38164,38165,38169,38170,38171,38171,38150,38151,38151,38152,38152,38153,38154,38155,38156,38157,38157,38160,38161,38164,38169,38170,38171,38172,38151,38152,38153,38160,38161,38166,38169,38172,38172,38153,38153,38154,38154,38155,38156,38162,38167,38170,38172,38173,38153,38154,38155,38157,38172,38173,38173,38154,38155,38157,38157,38159,38167,38171,38174,38156,38162,38164,38174,38174,38158,38170,38172,38171,38172,38175,38175,38159,38169,38173,38175,38175,38176,38176,38160,38169,38176,38176,38177,38168,38177,38177,38178,38177,38178,38173,38178,38179,38167,38169,38179,38180,38181,38181,38174,38179,38181,38182,38174,38182,38179,38183,38183,38183,38184,38184,38185,38179,38183,38185,38185,38186,38186,38186,38203,38182,38186,38187,38187,38185,38186,38187,38188,38183,38188,38189,38189,38189,38190,38189,38190,38188,38189,38190,38191,38191,38191,38191,38192,38192,38192,38193,38193,38194,38195,38195,38196,38196,38197,38200,38201,38205,38205,38210,38211,38211,38212,38213,38214,38215,38215,38218,38218,38219,38219,38220,38220,38221,38221,40445,40474,40497,40499,44376,44396,2392842,38195,38196,38196,38201,38206,38209,38212,38212,38215,38216,38216,38218,38219,38219,38220,38220,38221,38221,38222,38206,38220,38222,38213,38222,38222,38223,38223,38217,38227,38228,38228,38230,38223,38228,38229,38233,38233,38228,38237,38238,38238,38232,38233,38234,38235,38236,38237,38239,38239,38241,38241,38236,38240,38242,38242,38243,38243,38240,38242,38242,38244,38245,38245,38244,38245,38246,38245,38245,38246,44401,38245,38246,38247,38246,38247,38247,38247,38248,38248,40472,38249,38252,40472,40473,40502,40522,40524,40526,40528,40530,40533,44403,44423,67893,13690986,40473,40476,42696,42697,42698,42698,42699,42699,42700,42700,42703,42704,42709,42711,42715,42716,42717,42719,42720,42721,42721,42722,42723,42723,42724,42724,42725,42725,42726,42767,42699,42699,42700,42701,42712,42720,42720,42722,42726,42726,42699,42700,42700,42702,42726,42727,42700,42701,42701,42703,42709,42720,42721,42726,42727,42727,42701,42720,42727,42727,42728,42703,42710,42720,42722,42722,42727,42727,42728,42728,42728,42729,42723,42726,42729,42729,42730,42730,42732,42732,42731,42736,42737,42735,42736,42743,42736,42745,42745,42746,42741,42746,42741,42742,42748,42744,42744,42745,42746,42747,42748,42749,42745,42750,42750,42750,42750,42751,42751,42752,42752,42752,42753,42752,42753,42753,42753,42754,42754,42755,42756,42756,42757,42757,42758,42758,42759,42759,42760,42762,42762,42763,42764,42764,42765,42765,42766,42766,42767,42767,42768,42769,42770,42770,42771,42772,42772,42773,42773,42774,42774,42775,42775,42776,42777,42777,42778,42778,42779,42779,42780,42780,42781,42782,42782,42783,42787,42787,42796,42801,42756,42757,42757,42758,42759,42759,42760,42760,42762,42764,42765,42766,42767,42768,42770,42770,42771,42772,42773,42774,42774,42775,42775,42776,42776,42777,42778,42778,42779,42779,42780,42801,42802,42757,42758,42758,42760,42764,42767,42771,42773,42774,42775,42776,42776,42777,42778,42780,42802,42759,42759,42761,42761,42762,42763,42768,42770,42771,42774,42775,42776,42776,42777,42777,42779,42768,42769,42770,42772,42772,42773,42774,42776,42777,42778,42779,42761,42761,42763,42769,42771,42772,42776,42776,42777,42777,42778,42780,42771,42772,42775,42779,42780,42763,42769,42776,42779,42781,42764,42768,42771,42773,42774,42776,42777,42779,42779,42780,42778,42779,42779,42780,42781,42767,42769,42772,42774,42775,42775,42772,42781,42774,42782,42783,42777,42778,42779,42780,42781,42784,42785,42790,42779,42782,42783,42785,42779,42781,42785,42788,42778,42788,42781,42783,42787,42788,42779,42780,42781,42786,42786,42787,42782,42782,42785,42787,42788,42789,42795,42813,42782,42788,42783,42788,42789,42783,42785,42788,42789,42793,42784,42788,42788,42789,42790,42792,42786,42787,42787,42788,42789,42789,42790,42790,42791,42791,42792,42792,42793,42793,42794,42795,42797,42816,42788,42791,42791,42792,42794,42795,42789,42792,42794,42789,42792,42792,42793,42794,42795,42813,42818,42790,42791,42792,42792,42793,42793,42794,42795,42796,42799,42813,42792,42792,42793,42794,42795,42800,42819,42792,42794,42794,42795,42796,42797,42797,42814,42794,42794,42795,42796,42796,42798,42801,42814,42794,42795,42795,42796,42797,42797,42798,42798,42801,42804,42795,42796,42796,42797,42797,42798,42798,42799,42799,42803,42803,42812,42816,42796,42797,42798,42798,42799,42799,42800,42800,42801,42802,42805,42808,42811,42816,42816,42818,42822,42797,42798,42798,42799,42799,42800,42800,42801,42801,42802,42803,42803,42804,42805,42808,42808,42812,42814,42815,42817,42817,42822,42798,42799,42800,42802,42799,42800,42800,42801,42801,42802,42803,42804,42804,42809,42813,42818,42823,70168,42800,42801,42801,42802,42802,42803,42804,42805,42805,42807,42808,42808,42810,42810,42811,42812,42812,42813,42818,42821,42823,42824,42801,42802,42802,42803,42803,42804,42805,42805,42806,42807,42808,42810,42811,42812,42814,42815,42818,42819,42824,42802,42803,42803,42804,42804,42805,42806,42811,42812,42819,42825,42803,42804,42804,42805,42805,42806,42806,42807,42807,42808,42808,42809,42809,42810,42811,42812,42813,42814,42814,42815,42816,42817,42818,42820,42825,42804,42805,42805,42806,42806,42807,42807,42808,42808,42809,42810,42812,42814,42820,42823,42825,42826,42805,42806,42806,42807,42807,42808,42809,42809,42810,42811,42812,42813,42814,42817,42820,42821,42826,42806,42807,42807,42808,42808,42809,42809,42810,42811,42813,42813,42825,42826,42827,42807,42808,42808,42810,42811,42812,42813,42817,42821,42822,42822,42827,42808,42809,42810,42811,42814,42824,42828,42809,42810,42810,42811,42811,42812,42812,42813,42813,42814,42815,42815,42816,42817,42817,42818,42818,42819,42820,42821,42823,42824,42824,42825,42826,42827,42828,42828,46683,42810,42811,42811,42812,42812,42813,42813,42815,42815,42817,42818,42822,42823,42824,42825,42827,42829,42811,42812,42812,42813,42814,42814,42815,42815,42819,42822,42822,42824,42825,42829,42812,42813,42814,42815,42815,42816,42816,42818,42822,42824,42829,42830,42813,42814,42814,42815,42816,42817,42819,42820,42820,42821,42825,42830,42830,42814,42815,42815,42817,42817,42818,42819,42820,42821,42822,42823,42824,42825,42827,42828,42830,42831,42815,42816,42817,42818,42819,42820,42821,42821,42825,42826,42829,42831,42816,42818,42820,42820,42822,42826,42832,42818,42819,42819,42820,42821,42821,42822,42827,42829,42829,42831,42832,42827,42832,42819,42820,42828,42820,42821,42822,42822,42823,42826,42826,42828,42828,42830,42831,42831,42832,42833,42834,42821,42822,42823,42823,42824,42824,42825,42825,42826,42826,42829,42834,42825,42826,42828,42829,42824,42825,42826,42827,42827,42829,42829,42830,42830,42832,42834,42835,42836,42826,42827,42828,42831,42836,42826,42827,42831,42833,42837,42827,42828,42828,42829,42830,42831,42831,42832,42833,42834,42835,42836,42837,42831,42832,42834,42836,42838,42831,42833,42835,42838,42831,42833,42839,42834,42839,42834,42840,42835,42840,42835,42840,42841,42836,42836,42839,42841,42836,42838,42837,42838,42838,42839,42839,42840,42840,42841,42841,42842,42842,42870,42871,46697,46717,42838,42839,42839,42840,42841,42842,42842,42843,42871,42872,42839,42840,42840,42841,42841,42843,42843,42841,42842,42843,42843,42844,42841,42842,42842,42843,42843,42844,42844,42842,42843,42844,42845,46700,42844,42845,42845,42844,42845,42846,42845,42846,42846,42846,42847,42847,42848,42849,42850,42850,42851,42854,42854,42857,42861,42863,42866,42868,42869,42872,42873,42873,42874,42874,42875,42875,42876,42876,42877,46702,46703,46723,46728,46753,46762,57384,57410,57415,70191,70193,70213,70276,70278,42849,42850,42850,42851,42851,42852,42855,42855,42856,42859,42860,42861,42861,42862,42862,42863,42863,42864,42867,42867,42868,42869,42870,42870,42871,42871,42872,42873,42873,42874,42874,42875,42875,42876,42876,42877,42877,42851,42856,42864,42866,42876,42877,42877,42878,42862,42864,42878,42865,42873,42878,42879,42865,42879,42876,42879,42880,42856,42881,42883,42862,42873,42883,42882,42883,42880,42884,42886,42883,42873,42875,42881,42889,42889,42889,42890,42890,42877,42889,42890,42891,42879,42881,42882,42883,42888,42889,42889,42890,42890,42891,42891,42892,42889,42892,42884,42893,42885,42886,42894,42894,42895,42893,42895,42896,42893,42894,42896,42897,42889,42896,42896,42892,42893,42897,42898,42896,42897,42898,42898,42899,42896,42900,42896,42899,42900,42898,42899,42900,42900,42901,42901,42898,42899,42899,42900,42901,42902,42899,42900,42901,42901,42902,42902,42901,42901,42902,42902,42903,42901,42902,42903,42903,42902,42903,42903,42904,42903,42904,42904,42904,42905,42905,42906,42907,42909,43023,43026,46731,46732,46752,46754,46782,46789,57413,57438,57439,57467,70222,70242,4303437,4861872,46732,46752,46733,46735,43215,43218,46924,46924,50557,50558,50559,50559,50560,50560,50561,50563,50568,50569,50570,50571,50572,50573,50573,50574,50575,50576,50576,50577,50577,50578,50559,50560,50560,50561,50562,50563,50572,50574,50574,50576,50576,50577,50578,50578,50561,50561,50575,50578,50579,50561,50579,50562,50566,50575,50576,50578,50578,50579,50579,50580,50580,50580,50579,50580,50582,50579,50584,50579,61249,50585,50589,50619,50590,50587,50587,50588,50588,50589,50589,50590,50592,50593,50593,50594,50603,50605,50623,50624,50624,50628,50628,50630,50631,50653,50594,50603,50594,50595,50595,50594,50595,50595,50596,50595,50596,50596,50596,50597,50653,50597,50599,50602,50606,50607,50618,50628,50634,50639,50653,50598,50599,50599,50600,50600,50601,50602,50602,50603,50604,50604,50605,50605,50606,50606,50607,50607,50608,50608,50609,50609,50610,50610,50611,50611,50612,50612,50613,50613,50614,50615,50615,50616,50616,50617,50617,50618,50618,50619,50620,50620,50621,50621,50622,50622,50623,50623,50624,50624,50625,50625,50626,50626,50627,50628,50628,50629,50629,50630,50631,50632,50632,50633,50634,50635,50635,50637,50639,50643,50647,50652,50653,50653,50654,50599,50600,50600,50601,50603,50604,50605,50606,50606,50607,50608,50609,50609,50611,50611,50612,50613,50617,50620,50620,50621,50624,50626,50626,50627,50628,50628,50629,50635,50653,50654,50603,50605,50611,50612,50621,50624,50629,50607,50614,50615,50619,50622,50623,50602,50605,50609,50613,50614,50614,50615,50620,50621,50623,50626,50627,50628,50630,50609,50610,50613,50616,50618,50620,50622,50623,50627,50630,50606,50610,50624,50626,50631,50611,50609,50615,50624,50625,50635,50609,50614,50625,50632,50632,50637,50616,50629,50631,50611,50613,50612,50613,50615,50617,50660,50614,50626,50635,50639,50615,50620,50624,50625,50629,50636,50615,50626,50631,50644,50616,50617,50617,50618,50619,50620,50621,50622,50626,50627,50628,50629,50629,50633,50634,50635,50635,50636,50637,50640,50641,50641,50644,50646,50647,50648,50662,50663,50666,50620,50626,50629,50630,50635,50637,50638,50662,50663,50619,50620,50622,50631,50631,50634,50635,50638,50638,50663,50621,50623,50634,50637,50638,50621,50625,50633,50643,50664,50622,50628,50630,50631,50631,50632,50632,50637,50638,50639,50644,50637,50625,50625,50626,50627,50628,50630,50631,50632,50632,50633,50636,50638,50639,50640,50641,50648,50666,50670,50625,50633,50641,50664,50666,50625,50629,50634,50639,50641,50645,50653,50626,50629,50632,50633,50635,50639,50642,50634,50634,50635,50635,50636,50637,50637,50640,50641,50642,50643,50644,50661,50632,50634,50635,50637,50639,50641,50642,50633,50643,50644,50669,50651,50632,50636,50636,50649,50633,50636,50638,50641,50650,50670,50634,50635,50645,50648,50636,50638,50638,50639,50643,50650,50640,50641,50645,50646,50647,50647,50651,50652,50639,50640,50640,50645,50647,50648,50652,50655,50673,50640,50640,50641,50644,50647,50657,50641,50641,50642,50644,50645,50646,50646,50648,50649,50652,50655,61280,50675,50641,50642,50642,50643,50645,50645,50647,50647,50648,50649,50650,50652,50653,50654,50656,50663,50675,50679,50642,50643,50643,50645,50645,50646,50647,50648,50649,50649,50650,50650,50653,50654,50654,50656,50657,50675,50644,50644,50645,50646,50646,50648,50648,50650,50651,50654,50657,50644,50645,50646,50646,50647,50647,50648,50649,50649,50650,50650,50651,50651,50655,50656,50660,50680,50646,50647,50647,50648,50649,50651,50652,50655,50658,61334,50647,50648,50649,50650,50651,50652,50652,50654,50655,50661,50677,50650,50652,50652,50653,50656,50656,50649,50650,50651,50653,50653,50678,50649,50650,50651,50651,50652,50653,50653,50654,50651,50652,50652,50654,50656,50657,50661,50661,50679,50652,50653,50654,50654,50655,50661,50668,50653,50654,50655,50655,50656,50660,50662,50664,50681,50685,50654,50655,50656,50656,50657,50657,50659,50660,50661,50681,50656,50656,50657,50660,50661,50672,50676,50681,50682,50656,50657,50657,50660,50682,50657,50658,50660,50661,50661,50662,50662,50663,50664,50665,50669,50673,50674,50677,50683,50658,50659,50660,50661,50661,50662,50662,50663,50664,50665,50670,50675,50676,50683,50683,50659,50660,50660,50661,50661,50662,50662,50663,50663,50665,50665,50666,50666,50667,50668,50669,50670,50670,50671,50672,50673,50674,50674,50675,50676,50677,50678,50680,50680,50682,50683,50684,50684,50662,50663,50666,50662,50664,50676,50685,50664,50665,50665,50667,50671,50685,50664,50665,50686,50664,50665,50665,50666,50667,50668,50668,50669,50673,50686,50665,50666,50666,50668,50669,50670,50674,50678,50687,50666,50667,50668,50669,50669,50670,50671,50674,50674,50675,50687,50687,50667,50668,50669,50669,50670,50671,50671,50672,50672,50674,50674,50675,50680,50685,50687,50688,50669,50670,50670,50671,50671,50672,50672,50673,50675,50677,50677,50680,50682,50684,50687,50688,50688,50689,50671,50680,50671,50672,50673,50676,50687,50689,50690,50672,50674,50674,50675,50675,50676,50677,50677,50678,50688,50688,50690,50673,50674,50675,50675,50676,50676,50677,50677,50679,50679,50680,50681,50682,50686,50688,50689,50690,50691,50676,50691,50675,50678,50687,50689,50692,50676,50677,50680,50683,50683,50687,50690,50692,50692,50677,50679,50679,50686,50692,50693,50680,50681,50682,50682,50685,50689,50693,50693,50694,50680,50680,50681,50682,50694,50685,50694,50695,50682,50683,50691,50695,50682,50683,50686,50686,50687,50688,50693,50695,50695,50696,50690,50695,50696,50696,50696,50688,50692,50697,50691,50697,50697,50692,50697,50698,50696,50697,50699,50693,50697,50699,50699,50691,50693,50700,50697,50698,50700,50700,50701,50701,50701,74116,50702,50702,50703,50703,50704,50701,50704,50704,50704,50705,50705,50706,50705,50706,50706,50706,50707,50707,50707,50708,50708,50709,50710,50711,50712,50713,50714,50715,50719,50719,50721,50722,50725,50726,50726,50727,50727,50728,50728,50729,61314,61315,61340,61343,74143,74206,74208,74209,50710,50711,50712,50712,50713,50714,50715,50720,50720,50721,50722,50722,50723,50724,50725,50725,50726,50727,50727,50728,50728,50729,50729,61315,50714,50714,50726,50727,50728,50729,50730,50713,50714,50724,50726,50730,50714,50715,50729,50730,50730,50731,50716,50730,50716,50717,50718,50721,50723,50725,50725,50726,50728,50730,50730,50731,50731,50732,50733,61319,50718,50723,50725,50729,50731,50731,50732,50732,50733,50720,50726,50732,50734,50730,50727,50730,50731,50735,50731,50737,50738,50737,50739,50737,50738,50739,50738,50740,50735,50737,50738,50739,50739,50740,50736,50737,50739,50741,50739,50741,50742,50741,50743,50741,50743,50744,50742,50744,50742,50742,50743,50744,50745,50743,50743,50744,50745,50744,50744,50745,50746,50744,50745,50745,50746,50746,61332,50745,50746,50746,50747,50746,50747,50747,50747,50748,50748,50749,50750,61334,61335,61360,61362,61384,61387,61388,61389,61390,61393,74143,74163,2399120,2399120,2447330,4307359,4865792,61335,61336,71920,71921,71922,71923,71923,71925,71926,71927,71927,71929,71930,71931,71931,71932,71933,71935,71942,71943,71944,71944,71945,71945,71946,71946,71944,71945,71946,71946,71947,71936,71947,71948,71946,71948,71949,71950,71950,71950,71952,71951,71952,71952,71953,71955,71940,71942,71956,71955,71956,71944,71957,84760,71958,71987,84825,71959,71959,71960,71967,71967,71968,71969,71968,71969,71970,71969,71970,71970,71970,71971,71971,72014,72021,71972,71973,71973,71974,71974,71975,71976,71976,71977,71977,71978,71980,71980,71981,71983,71983,71984,71984,71985,71986,71988,71989,71989,71990,71991,71991,71992,71993,71994,71994,71995,71995,71996,71997,71997,71998,71998,71999,71999,72000,72001,72001,72002,72002,72003,72004,72005,72005,72006,72006,72007,72011,72015,72020,72020,72021,72021,72022,72022,72023,71973,71974,71974,71975,71976,71978,71990,71991,71993,71994,71994,71995,71996,71997,71998,71998,72022,72022,71974,71975,71979,71984,71986,71990,71992,71995,71996,71997,71998,71999,72000,72001,72022,72022,72023,71975,71976,71979,71985,71992,71993,71995,71996,71997,71999,72002,72003,72006,72020,72022,72023,72023,71976,71978,71980,71993,71993,71994,71994,71997,71998,71999,72000,72000,72001,72004,72023,72024,71978,71988,71994,71995,71996,71998,71998,71999,72000,72006,72012,72023,72024,71981,72024,71982,72000,72025,72025,72026,71997,72000,72026,71994,72000,72026,72027,72001,72002,72006,72010,72027,72028,71999,72028,72005,72030,71991,72004,72030,72005,72010,71994,72005,72006,72009,71995,72000,72008,72016,72033,72034,71998,71999,72006,72009,72009,72030,72035,72019,72037,72010,72012,72038,72009,72011,72021,72017,72021,72039,84792,72014,72009,72011,72014,72016,72018,72023,72024,72010,72013,72013,72014,72016,72016,84774,72014,72015,72019,72023,72024,72030,72041,72015,72021,72014,72015,72016,72016,72017,72018,72019,72020,72041,72041,72042,84775,72016,72017,72023,72042,72021,72017,72018,72020,72022,72024,72026,72031,72043,72017,72018,72018,72021,72021,72022,72023,72025,72019,72020,72020,72021,72022,72027,72042,72044,72019,72020,72021,72022,72022,72023,72023,72024,72025,72028,72040,72045,72045,72020,72021,72021,72022,72022,72023,72023,72024,72024,72025,72026,72031,72032,72042,72045,72045,72046,72021,72022,72023,72023,72024,72025,72025,72026,72026,72029,72029,72042,72043,72046,72046,72047,72023,72024,72024,72025,72027,72037,72045,72047,72047,72024,72025,72025,72027,72029,72030,72031,72038,72040,72040,72041,72042,72046,72047,72047,72048,72025,72026,72026,72028,72029,72041,72041,72048,72048,72026,72027,72028,72028,72030,72031,72033,72041,72045,72046,72048,72049,72027,72028,72028,72029,72029,72031,72034,72039,72040,72041,72047,72048,72049,72049,72029,72030,72032,72038,72046,72049,72050,72050,72031,72033,72049,72050,72050,72031,72032,72032,72033,72034,72046,72049,72050,72050,72051,72032,72033,72034,72050,72051,72051,72052,72034,72036,72044,72049,72051,72051,72052,72040,72043,72052,72042,72048,72052,72053,72049,72050,72053,72036,72053,72053,72054,72039,72047,72051,72053,72054,72054,72049,72054,72055,72055,72055,72046,72055,72056,72055,72056,72053,72056,72058,72059,72060,72054,72060,72060,72061,72061,72062,72059,72061,72062,72062,72063,72063,72064,72057,72059,72059,84880,72058,72064,72064,72065,84798,72063,72065,72065,72065,72063,72066,72066,72066,72066,72067,72067,72065,72067,72068,72068,72067,72068,72068,72068,72069,72069,72069,72070,72069,72070,72096,72070,72071,72097,84804,84824,84887,1598862,72072,72073,72073,72080,72080,72086,72086,72087,72087,72088,72088,72091,72094,72095,72095,72096,72096,72097,72097,84805,84825,84888,1332141,72073,72074,72076,72079,72082,72082,72086,72087,72091,72091,72092,72094,72095,72096,72096,72097,72097,72098,84890,4318117,72081,72092,72098,72098,72099,72099,72101,72104,72105,72106,72107,72107,72109,72111,72112,72110,72112,72113,72113,72114,72116,72116,72117,72119,72120,72121,72121,72121,72121,72122,72122,72123,72158,72158,84829,84830,84830,84831,84832,84845,84850,84915,84916,2341608,2409807,2409807,4318046,9421991,26636403,84831,72261,72259,84931,84934,97536,97537,97538,97539,97539,97540,97540,97541,97542,97547,97549,97556,97556,97557,97557,97558,97560,97561,97569,97542,97557,97558,97558,97540,97558,97559,97542,97550,97559,97559,97560,97560,97560,97560,97561,97561,97561,97562,97558,97559,97561,97569,97633,97573,97576,97576,97576,97576,97577,97632,97577,97578,97579,97580,97580,97581,97581,97582,97583,97583,97584,97585,97588,97588,97589,97589,97590,97590,97591,97592,97593,97593,97594,97595,97595,97596,97597,97597,97598,97598,97599,97599,97600,97601,97601,97602,97603,97603,97604,97604,97605,97606,97606,97608,97608,97609,97609,97610,97611,97612,97612,97613,97613,97614,97615,97616,97618,97619,97620,97620,97621,97621,97622,97622,97623,97624,97624,97625,97627,97629,97632,97633,97633,97634,97635,97581,97582,97585,97588,97590,97596,97596,97598,97600,97601,97602,97604,97609,97610,97612,97616,97618,97620,97634,97598,97600,97602,97603,97605,97605,97620,97635,97606,97621,97583,97584,97588,97599,97600,97601,97601,97602,97603,97604,97606,97610,97616,97623,97636,97599,97601,97604,97604,97605,97608,97624,97633,97636,97586,97589,97607,97623,97625,97637,97605,97595,97607,97611,97614,97604,97594,97612,97640,97593,97601,97608,97609,97641,97597,97616,97613,97615,97616,97622,97644,97601,97615,97634,97620,97627,97640,97613,97614,97644,97628,97634,97625,97634,97648,97625,97635,97619,97650,97614,97621,97627,97617,97621,97623,97651,97615,97621,97617,97616,97617,97620,97624,97627,97628,97630,97631,97638,97640,97652,97620,97621,97625,97619,97619,97622,97626,97629,97646,97653,97653,97619,97621,97624,97629,97630,97636,97654,97622,97623,97624,97625,97642,97654,97623,97623,97627,97630,97632,97633,97634,97641,97642,97655,97630,97637,97624,97625,97626,97627,97628,97631,97631,97633,97640,97651,97655,97656,97656,97627,97629,97630,97632,97641,97647,97653,97657,2422558,97627,97628,97629,97630,97632,97633,97633,97635,97636,97636,97642,97646,97647,97657,97657,97643,97629,97630,97631,97632,97632,97633,97634,97634,97635,97638,97640,97646,97647,97648,97651,97659,97631,97632,97634,97634,97639,97645,97659,97635,97636,97646,97649,97633,97634,97635,97636,97637,97638,97639,97639,97640,97646,97647,97648,97652,97658,97661,97634,97636,97636,97637,97645,97647,97650,97661,97636,97637,97637,97639,97640,97648,97650,97652,97653,97661,97662,97638,97644,97638,97639,97639,97642,97644,97648,97649,97650,97651,97651,97653,97655,97656,97660,97663,4330803,97639,97640,97641,97643,97645,97650,97651,97651,97652,97653,97653,97654,97661,97664,97640,97644,97646,97647,97649,97652,97655,97656,97664,97642,97644,97646,97647,97648,97650,97651,97652,97653,97655,97664,97665,97650,97644,97645,97645,97647,97652,97653,97657,97665,97666,97654,97659,97666,97646,97651,97654,97658,97659,97667,97648,97656,97657,97665,97667,97647,97649,97655,97655,97656,97658,97659,97668,97654,97656,97668,97654,97655,97662,97669,97653,97659,97667,97670,97670,97657,97657,97659,97671,2422572,97654,97656,97671,97661,97663,97661,97673,97658,97659,97660,97661,97664,97665,97666,97666,97669,97674,97661,97662,97663,97664,97665,97666,97667,97670,97670,97674,97675,97668,97671,97675,97663,97665,97669,97670,97676,97664,97666,97669,97676,97676,97665,97666,97668,97675,97677,2470788,97669,97674,97677,97667,97669,97673,97677,97678,97678,97678,97698,97670,97679,97671,97673,97675,97679,97687,97679,97680,97687,97680,97680,97681,97674,97678,97681,97681,97682,97682,97683,97683,97683,97684,97684,97684,97685,97686,97706,97686,97687,97688,97688,97689,97690,97691,97692,97694,97695,97696,97696,97699,97703,97703,97704,97704,97705,97706,97707,97707,97708,97708,97709,2422590,2422590,97690,97691,97692,97693,97695,97697,97702,97705,97706,97707,97707,97708,97708,97709,97709,97707,97707,97709,97710,97711,97711,97712,97713,97714,97713,97703,97715,97705,97716,97706,97706,97707,97717,97717,97707,97708,97708,97718,97708,97709,97717,97718,97719,97719,97719,97721,97723,97722,97723,97724,4330844,97724,97725,97726,97724,97725,97726,97726,97727,97726,97727,97727,97727,97728,97728,97729,102954,133043,327571,363614,437975,499835,500542,500542,500543,502379,688565,703777,738024,744652,753053,971794,975699,995893,1259947,1344969,1482151,1611595,1628261,1642241,1759623,1759629,1880099,1880101,1958421,1960686,2128384,2128388,2128392,2128394,2177915,2392091,2422609,2422610,2422610,2422611,2422611,2422612,2422612,2422613,2422613,2470815,2470816,2470817,2470817,2470818,2470819,2470819,2470821,2470822,2470826,2691745,2691752,2891935,2908556,3053311,3470739,3473955,3473955,3473956,3473956,3473957,3473957,3473958,3473958,3473959,4047877,4114084,4330848,4330849,4330880,4330881,4330882,4330899,4330900,4330904,4330945,4889283,8341886,2128392,4330849,108190,2427849,168374,4366180,557424,557424,557425,557426,730395,4560702,557439,2652465,2173292,629515,629516,2688510,2733861,1532479,778282,778298,2762918,778375,778447,2468786,901952,2530509,903367,903367,903368,903368,903369,2825435,2825435,2825437,4733674,3294761,3876783,907039,907216,907392,4735736,1279414,4921697,1309840,3028673,1378391,1378476,1378565,1616155,1391590,2824854,1408389,2249897,3077947,1845875,5763364,1853682,1853682,3300592,3300593,5208831,3300593,3300595,5208832,1894069,3026568,2422196,2422272,2422347,3584935,2435444,3591475,2592225,5578104,2866644,2866783,2866924,4858591,3091410,3625241,3125472,3125568,3125667,3642367,3936585,3158803,5861487,3186767,3672918,3421530,3421534,3421603,3421604,3421678,3421679,5992830,5992831,3662484,3662484,6113232,5256342,3789156,4268330,3819129,4283317,3823667,6193830,4159064,4159065,4159071,4159075,4159068,4159070,4159071,4159072,4159073,4159074,4159074,4453286,4453288,4453288,4922613,4453289,4453291,6361529,4453290,4453291,5504638,4453291,4922617,4453293,4258114,4258115,5662466,4502809,4611104,6587573,4686503,4717022,4747490,4747491,4747505,4747491,4747492,4747492,4747493,4747493,4747494,4747506,4747506,4747507,4747507,4747508,4747508,4747492,4747493,4747493,4747494,4747505,4747506,4747507,4747507,4747508,4747508,4747509,4747493,4747494,4747494,4747495,4747507,4747507,4747508,4747508,4747509,4747494,4747496,4747496,4747507,4747508,4747508,4747509,4747509,4747510,4747495,4747496,4747497,4747508,4747508,4747509,4747509,4747510,4747510,4747511,4747508,4747509,4747510,4747511,4747509,4747510,4747512,4747513,4747509,4747510,4747513,4747510,4747512,4747520,6655744,4747521,4747522,4747522,4747523,4747523,4747525,4757902,4795711,4795713,5016641,5798854,6655745,6655841,4747522,4747523,4747523,4747524,4747525,4795713,4795714,4795716,5016641,5137490,5216831,5798853,5798853,5798854,5798855,5798855,5798856,5798856,6655745,6655841,7214180,4747523,4747524,4747524,4795715,4795717,5016649,5216832,5795636,5798853,5798854,5798854,5798855,5845237,6164747,6513407,6655745,6655746,6655842,7214179,4747524,4747525,4747526,4747527,4795715,4795717,5016642,5026407,5026409,5130237,5795636,5798854,5798854,5798855,5798855,5798856,5798857,5845237,6515973,6610647,6655746,4747525,4747526,4747527,4747527,4795716,4795718,4795718,4887429,5016643,5216833,5378208,5430286,5798853,5798854,5798855,5798855,5798856,5798856,5798857,5798857,5819147,5819147,5907165,6438983,6655747,6655778,6655843,4747527,4795715,4795716,4795717,4795718,4795719,5798855,5798855,5798856,5798857,5998848,6655747,6655781,6655807,6655843,4795717,6655748,5016644,5798857,5907167,6655748,5111804,5798859,6655749,5798858,6655749,4768295,5714565,4838205,6701189,4843918,4843919,4843918,4843920,4843920,4843906,4843921,4843921,4843908,4843922,4843922,4843923,4843909,4843923,4843924,4843923,4843925,4843923,4843924,4843925,4843924,4843925,4843926,4843927,4843934,6703951,4843936,5843843,6703952,4843938,5064849,5131499,5482724,5847061,5847061,5847062,6703953,5847062,5064858,5847063,5847064,6703954,6704050,6703957,5027346,5938772,5285768,5285785,5285788,5285793,5285796,5285845,5285813,5285855,5285854,5285858,5285865,5285930,5285907,5285934,5285938,5285940,6068051,5486052,5300750,6068075,6068077,6068078,6924941,6924968,5305306,5305308,6077753,6934645,5315546,6082873,5419073,6991527,5476092,6163146,5513022,5513098,5513170,7038603,5527499,5527570,5527640,7045824,5686152,6268173,6268174,6268175,6268175,6288466,6908301,7125066,5719450,5719825,5720202,7142120,6008907,6008905,7286443,6429556,6113055,6113129,6113204,7338591,6121524,6485860,6660835,6775811,6843763,6843764,6843763,6843764,7703872,6846982,7703873,7703874,6850184,6850196,6850200,6850198,6850200,6850184,6850185,6850186,6850187,6850196,6850197,6850199,6850199,6850200,6850200,6850201,6850201,6850186,6850199,6850200,6850200,6850201,6850201,6850202,6850186,6850187,6850187,6850198,6850198,6850201,6850201,6850202,6850202,6850199,6850200,6850201,6850202,6850202,6850203,6850188,6850199,6850202,6850203,6850203,6850203,6850204,6850204,6850190,6850202,6850204,6850204,6850203,6850204,6850205,6850206,7707089,7707089,6850215,6870490,7707090,7707090,6850216,7707091,7424119,7707091,6850216,6850217,6958510,7707092,7707123,6850217,7707092,6850217,6850218,7707092,7707093,6850218,7707040,7707093,7707093,6958512,7490329,7564755,7707093,7707094,7707094,7707095,6890784,6890772,6890786,6890786,7658226,7727383,7727384,6942965,6942967,7753474,7753476,7066818,7066818,7815399,7815400,7815496,7250183,7764743,7581983,8072981,7998037,8281009,8130451,8130452,8130453,8347216,8347217,8279303,8279304,8421642,8421643,8284433,8424207,8425665,8494919,8473783,8518882,8563915,8563942,8563968,8563969,8563970,8563970,8563971,8563973,8563979,8563981,8563990,8563991,8563993,8563995,8563996,8563997,8563998,8563999,8563999,8564000,8564000,8564001,8564001,8564002,8564002,8564003,8564019,8563970,8563971,8563972,8563999,8563999,8564000,8564000,8564002,8563971,8563972,8563997,8563999,8564000,8564000,8564001,8564003,8564000,8564001,8564002,8564004,8564003,8564010,8564012,8564033,8564012,8564021,8564021,8564021,8564023,8564026,8564023,8564026,8564027,8564027,8564027,8564028,8564029,8564029,8564029,8564030,8564032,8564030,8564031,8564033,8564031,8564032,8564032,8564033,8564033,8564034,8564034,8564036,8564038,8564043,8564045,8564048,8564049,8564049,8564050,8564050,8564051,8564051,8564053,8564053,8564054,8564054,8564055,8564056,8564056,8564057,8564059,8564060,8564075,8564075,8564076,8564032,8564033,8564033,8564034,8564035,8564037,8564038,8564038,8564043,8564046,8564051,8564051,8564052,8564053,8564055,8564055,8564056,8564056,8564058,8564069,8564075,8564076,8564076,8564077,8564034,8564034,8564052,8564055,8564077,8564034,8564035,8564035,8564036,8564036,8564037,8564037,8564038,8564039,8564039,8564040,8564040,8564041,8564041,8564042,8564043,8564044,8564045,8564045,8564047,8564048,8564048,8564049,8564051,8564052,8564052,8564053,8564053,8564054,8564054,8564055,8564056,8564056,8564057,8564058,8564058,8564059,8564060,8564060,8564061,8564062,8564068,8564071,8564077,8564078,8564078,8564079,8564037,8564038,8564038,8564041,8564043,8564046,8564048,8564050,8564053,8564054,8564054,8564056,8564057,8564059,8564062,8564078,8564038,8564040,8564040,8564049,8564054,8564054,8564055,8564058,8564058,8564080,8564044,8564054,8564055,8564080,8564055,8564055,8564056,8564057,8564059,8564056,8564057,8564058,8564082,8564055,8564057,8564058,8564082,8564056,8564057,8564058,8564058,8564058,8564061,8564081,8564061,8564059,8564068,8564060,8564061,8564062,8564087,8564088,8564057,8564062,8564063,8564087,8564073,8564064,8564065,8564065,8564066,8564068,8564070,8564073,8564065,8564066,8564067,8564068,8564071,8564071,8564072,8564071,8564072,8564069,8564073,8564069,8564070,8564070,8564071,8564072,8564079,8564070,8564071,8564071,8564072,8564072,8564073,8564073,8564074,8564074,8564075,8564075,8564076,8564077,8564077,8564078,8564078,8564079,8564079,8564082,8564088,8564090,8564092,8564093,8564094,8564094,8564095,8564071,8564072,8564072,8564073,8564073,8564074,8564075,8564075,8564076,8564076,8564077,8564078,8564079,8564079,8564080,8564081,8564090,8564093,8564094,8564095,8564095,8564072,8564073,8564073,8564074,8564074,8564075,8564075,8564076,8564076,8564077,8564077,8564078,8564078,8564079,8564079,8564080,8564080,8564081,8564082,8564083,8564086,8564089,8564090,8564093,8564094,8564094,8564095,8564095,8564096,8564096,8564097,8564074,8564074,8564078,8564078,8564096,8564074,8564075,8564076,8564076,8564077,8564078,8564081,8564075,8564076,8564076,8564077,8564077,8564078,8564078,8564079,8564080,8564080,8564081,8564081,8564082,8564083,8564086,8564089,8564089,8564090,8564096,8564096,8564097,8564097,8564098,8564076,8564077,8564077,8564078,8564078,8564079,8564080,8564080,8564081,8564081,8564083,8564089,8564091,8564092,8564096,8564096,8564097,8564098,8564098,8564099,8564077,8564078,8564078,8564079,8564079,8564080,8564080,8564081,8564081,8564082,8564085,8564089,8564092,8564095,8564096,8564097,8564097,8564098,8564099,8564078,8564079,8564079,8564080,8564081,8564082,8564083,8564083,8564094,8564097,8564097,8564099,8564079,8564080,8564080,8564081,8564082,8564082,8564083,8564083,8564084,8564085,8564089,8564091,8564092,8564093,8564095,8564097,8564097,8564098,8564098,8564099,8564099,8564100,8564080,8564081,8564081,8564082,8564083,8564083,8564084,8564084,8564085,8564086,8564088,8564091,8564092,8564093,8564094,8564094,8564096,8564097,8564097,8564098,8564098,8564099,8564099,8564100,8564100,8564101,8564081,8564082,8564082,8564083,8564083,8564084,8564085,8564086,8564094,8564097,8564098,8564098,8564099,8564100,8564100,8564101,8564101,8564083,8564083,8564084,8564084,8564085,8564085,8564089,8564094,8564096,8564099,8564099,8564100,8564100,8564101,8564102,8564085,8564087,8564093,8564096,8564098,8564099,8564100,8564101,8564101,8564085,8564086,8564098,8564099,8564101,8564102,8564103,8564085,8564086,8564087,8564092,8564094,8564096,8564100,8564100,8564101,8564101,8564102,8564102,8564103,8564086,8564087,8564087,8564089,8564094,8564096,8564097,8564100,8564102,8564103,8564104,8564087,8564089,8564092,8564092,8564098,8564099,8564101,8564101,8564102,8564103,8564103,8564104,8564088,8564089,8564090,8564091,8564097,8564102,8564102,8564103,8564103,8564104,8564105,8564091,8564093,8564094,8564095,8564098,8564099,8564100,8564101,8564102,8564102,8564103,8564104,8564105,8564105,8564095,8564105,8564101,8564099,8564104,8564105,8564106,8564107,8564097,8564101,8564105,8564106,8564107,8564102,8564106,8564108,8564103,8564103,8564109,8564109,8564109,8564110,8564108,8564110,8564110,8564105,8564109,8564111,8564110,8564110,8564113,8564112,8564112,8564113,8564111,8564111,8564112,8564112,8564113,8564113,8564114,8564110,8564112,8564113,8564113,8564114,8564110,8564110,8564112,8564114,8564114,8564115,8564116,8564113,8564115,8564116,8564136,8564114,8564116,8564114,8564115,8564116,8564116,8564117,8564115,8564115,8564116,8564117,8564118,8564116,8564117,8564118,8564119,8564117,8564118,8564118,8564119,8564119,8564118,8564119,8564119,8564120,8564119,8564120,8564120,8564121,8564121,8564135,8564140,8564150,8564150,8564151,8564121,8564126,8564133,8564134,8564137,8564141,8564146,8564147,8564149,8564149,8564150,8564150,8564151,8564151,8564122,8564123,8564123,8564125,8564126,8564130,8564131,8564135,8564136,8564137,8564138,8564141,8564143,8564144,8564145,8564145,8564146,8564147,8564147,8564148,8564149,8564149,8564150,8564150,8564151,8564151,8564152,9122480,8564123,8564124,8564125,8564126,8564127,8564127,8564131,8564133,8564136,8564137,8564137,8564138,8564142,8564147,8564147,8564148,8564149,8564149,8564150,8564150,8564151,8564151,8564152,8564152,8564150,8564153,8564152,8564153,8564153,8564127,8564135,8564145,8564151,8564155,8564153,8564156,8564156,8564156,8564156,8564160,8564159,8564151,8564157,8564160,8564162,8564163,8564159,8564149,8564154,8564163,8564164,8564165,8564151,8564155,8564164,8564164,8564165,8564166,8564156,8564166,8564167,8564157,8564164,8564165,8564167,8564167,8564166,8564161,8564162,8564165,8564167,8564168,8564169,8564169,8564170,8564170,8564171,8564171,8564162,8564167,8564171,8564172,8564172,9122501,8564173,8564174,8564175,8564174,8564175,8564173,8564175,8564176,8564173,8564176,8564177,8564175,8564177,8564176,8564178,8564176,8564178,8564176,8564177,8564178,8564178,8564177,8564178,8564179,8564179,8564178,8564179,8564179,8564180,8564179,8564180,8564180,8564180,8564181,8564181,8564182,8564183,8613218,8614464,8798538,8833246,8955662,9009693,9009693,9032984,9032984,9040138,9040138,9040139,9095399,9122509,9122509,9122510,9122510,9122514,9122517,9122518,9122520,9122521,9345763,9366029,10703176,13668021,17953954,17953956,18578131,18581110,8564199,8603564,9122509,9122510,9122517,10703176,11455150,9122511,9122525,8642957,8642959,9161903,9161905,8662278,8662384,8662491,9171676,8664758,9172804,9032908,9356879,9102333,9391596,9347154,9514001,9455219,9455220,9568035,9501798,9501797,9501900,9501902,9502003,9502004,9509052,9591425,9516105,9516107,9516107,9516107,9516108,9516110,9598478,9598479,9598478,9598479,9598480,9626632,9653742,9680836,9680837,9680842,9680837,9680838,9680839,9680839,9680840,9680841,9680841,9680842,9680842,9680843,9680843,9680844,9680844,9680845,9680845,9680846,9680846,9680847,9680847,9680848,9680848,9680849,9680850,9680850,9680851,9680851,9680852,9680852,9680853,9680853,9680854,9680854,9680855,9680856,9680857,9680858,9680860,9680839,9680840,9680840,9680842,9680843,9680844,9680844,9680845,9680845,9680846,9680846,9680847,9680847,9680848,9680848,9680849,9680849,9680850,9680851,9680852,9680853,9680853,9680854,9680856,9680846,9680847,9680848,9680842,9680844,9680846,9680857,9680848,9680846,9680848,9680849,9680850,9680848,9680848,9680856,9680849,9680850,9680851,9680854,9680856,9680857,9680860,9680849,9680850,9680851,9680852,9680848,9680849,9680850,9680850,9680851,9680851,9680852,9680849,9680850,9680850,9680851,9680852,9680852,9680855,9680851,9680851,9680852,9680852,9680853,9680853,9680855,9680856,9680857,9680861,9680851,9680852,9680852,9680853,9680853,9680854,9680858,9680859,9680860,9680852,9680853,9680853,9680854,9680854,9680855,9680857,9680859,9680860,9680860,9680861,9680864,9680853,9680854,9680854,9680855,9680855,9680857,9680857,9680859,9680859,9680860,9680861,9680862,9680862,9680863,9680854,9680855,9680855,9680856,9680857,9680858,9680861,9680861,9680862,9680863,9680855,9680856,9680856,9680857,9680858,9680858,9680859,9680859,9680860,9680860,9680861,9680862,9680863,9680864,9680864,9680865,9680868,9680870,9680871,9680856,9680857,9680857,9680858,9680858,9680859,9680859,9680860,9680860,9680861,9680861,9680862,9680862,9680863,9680864,9680864,9680865,9680865,9680866,9680867,9680867,9680868,9680868,9680871,9680857,9680858,9680858,9680859,9680859,9680860,9680860,9680861,9680861,9680862,9680862,9680863,9680863,9680864,9680865,9680865,9680866,9680866,9680867,9680867,9680868,9680858,9680859,9680859,9680860,9680860,9680861,9680862,9680862,9680863,9680863,9680865,9680865,9680866,9680866,9680868,9680868,9680873,9680860,9680860,9680861,9680862,9680863,9680864,9680867,9680860,9680861,9680861,9680862,9680863,9680864,9680864,9680861,9680862,9680862,9680863,9680863,9680864,9680864,9680865,9680865,9680868,9680874,9680862,9680863,9680863,9680864,9680864,9680865,9680865,9680868,9680863,9680864,9680864,9680865,9680865,9680866,9680868,9680864,9680865,9680865,9680866,9680866,9680867,9680865,9680866,9680866,9680867,9680867,9680868,9680866,9680867,9680867,9680868,9680867,9680868,9680869,9680868,9680869,9680869,9680870,9680870,9680871,9680872,9680873,9680874,9680877,9680869,9680870,9680870,9680871,9680871,9680872,9680872,9680873,9680873,12013493,14295875,14295876,9680870,9680871,9680871,9680872,9680872,9680873,31440777,9680871,9680872,9680872,9680873,9680873,9680874,12295412,18512297,9680872,9680873,9680873,9680874,9680874,9680875,9680875,9680878,9680879,9680873,9680874,9680874,9680875,9680875,9680876,9680876,9680877,9680878,9680879,9680880,9680880,9680881,11261521,12013496,9680874,9680875,9680875,9680876,9680876,9680877,9680877,9680878,9680880,9680880,9680881,9757428,9994485,11551741,12013496,13133459,31440779,9680875,9680876,9680876,9680877,9680877,9680878,9680880,9680880,9680881,9680881,9680882,10882389,11551740,12013496,12295414,12368245,13133459,9680876,9680877,9680877,9680878,9680878,9680879,9680879,9680880,9680881,9680881,9764388,10254451,10602665,10687893,11261522,11551743,12013496,12013497,12295416,12993070,13133460,9680877,9680878,9680878,9680879,9680880,9680881,9680882,10254451,11261523,11261523,11455442,11551743,12013497,12295415,12368246,12368247,12993067,13133459,13133460,9680878,9680879,9680879,9680880,9680880,9680881,9680882,9680882,9680883,9680883,9757429,9757429,9994487,10687892,10687893,10687894,11261523,11551745,12295415,12295416,12295418,12526112,13012677,13133460,13133461,9680879,9680880,9680880,9680881,9680881,9680882,9680882,9680883,9680883,9680884,9994488,10687894,10687894,11261524,11261524,11551744,11961964,12013498,12368250,13012678,9680880,9680881,9680881,9680882,9680883,9680883,9680884,9680884,9680885,9757429,9994488,9994489,10687893,10687893,10687894,11261524,11261525,11551745,12368247,9680881,9680882,9680882,9680883,9680883,9680884,9994489,10687893,10687895,10882392,11261525,11261526,11551745,12013499,12013500,12295417,12295417,12368248,12368248,13133462,9680882,9680883,9680883,9680884,9680884,9680885,9757432,9994489,10254454,10687895,10687896,10687898,10861138,10956561,11261526,11551745,11735840,12295417,12368249,9680883,9680884,9680885,9680885,10687897,10742196,10861143,11261526,11261527,11551746,11551747,12295418,9680884,9680885,9680885,9680886,9994490,10687895,10687897,11261527,11922068,12295422,9680885,9680886,10687900,11551746,9680886,9680887,9757434,9994489,10254456,10370373,10687896,10687897,10687897,10687898,10687898,10687900,11261527,11261527,11261528,11261528,11551750,12013502,12013503,12013503,12295419,12360603,12526115,13133464,9680887,9680888,9680888,9680889,9680890,9685284,9685285,9757311,9757430,9757432,9757434,9757434,9757435,9764390,9994489,9994490,9994491,9994492,9994493,9994493,10223662,10254456,10254457,10366561,10658321,10687897,10687897,10687898,10687898,10687899,10687899,10687900,10687902,10722387,10774053,10861144,10861145,10882395,11231419,11261528,11261528,11261529,11261529,11265136,11265139,11313593,11323230,11551747,11551747,11551748,11551748,11551749,11551749,11551750,11795308,12013500,12013502,12013502,12013503,12013503,12013504,12275990,12295420,12295420,12295421,12295421,12295423,12360599,12368251,12368251,12368252,12993073,13012683,13133465,14952745,9680888,9680889,9680889,9680890,9680891,9685283,9757433,9757435,9757435,9757437,9924386,9994490,9994492,9994493,10254457,10658321,10658322,10658324,10678381,10679195,10687897,10687898,10687898,10687899,10687899,10687901,10687901,11261528,11261529,11261529,11261530,11265139,11528733,11551746,11551748,11551748,11551749,11816742,12013502,12013503,12013503,12013504,12013505,12295420,12295421,12368251,13060479,13133466,9680891,9757435,9757435,9757436,9775395,9994493,9994493,10658322,10687898,10687898,10687899,10687899,10882396,11261529,11261529,11261530,11551747,11551749,11942715,12295421,12295422,12368252,13133465,13133466,9757436,10687899,9994494,11261531,12013504,10385827,11286813,10687901,9785429,10170265,9689693,9689694,9689696,9689697,10692308,11265939,11556159,9761722,9833744,9833868,9833869,9833871,9833990,9833991,9833992,9833993,9833992,9833994,9833983,9833995,9833995,9833985,9833994,9833997,9833998,12444809,10764459,11628306,9834009,10071052,10071052,10186305,10331017,10764457,10764458,10764458,10764459,10764461,10937706,11338088,11338089,11628307,11628309,11628309,11628310,12090063,12090063,12371981,10071053,9847908,9847913,10741839,12378939,9869916,10782422,9889991,9890034,9890109,11366170,10127361,10911143,10167892,10167897,11795262,11104654,10308104,10308095,10308105,10308108,10308111,10308096,10308108,10308112,10308098,10308109,10308110,10308110,10308111,10308111,10308112,10308112,10308113,10308113,10308114,10308115,10308115,10308111,10308113,10308116,10308111,10308113,10308115,10568071,11001513,10308123,11082848,11842349,10308123,10971941,11001516,12327120,10308125,11001515,11575146,11865367,12609038,10308126,10308126,10523305,10568075,11001517,11001517,11001520,11575147,11575151,12609039,11001516,11865367,10308129,10916291,11001517,11001517,11001518,11001518,11415206,11575148,11575149,11575150,11865370,12327122,12609039,12609041,10503749,10971941,10991998,11001518,11001521,11575148,11865368,11865369,10916292,11842353,10350056,11575149,11865370,11001521,12609042,11001521,11001521,11575151,12327125,10391991,11043455,10538614,11690397,10659651,11750917,10699382,11197152,10738495,11187133,10766452,11804318,10828038,10828039,10828041,10828042,10828038,12869003,10828051,11231906,11261479,11261480,11434727,12125329,12869002,12941833,11261480,11261481,11835111,12941834,12587086,11261484,11052249,12237436,11059932,11060007,11060077,11954765,11090777,11392851,11524464,11524465,11524466,11524534,11524533,11524536,11524603,11524604,11524605,12183392,12473612,11635769,11635769,11635770,11635756,11635770,11635771,11635772,11635772,11635773,11665345,11635784,11665346,11665347,12238976,12242589,11665346,11665347,11665348,12238978,12529197,11675895,11675898,11685415,12549265,11677514,11677576,11677628,11677640,11677652,11677662,11686288,11694907,11694922,11694907,11694908,11694908,11694912,11694922,11694922,11694923,11694908,11694923,11694923,11694924,11694909,11694910,11694910,11694913,11694922,11694923,11694924,11694924,11694910,11694912,11694923,11694924,11694925,11694925,11694926,11694911,11694925,11694925,11694926,11694926,11694925,11694925,11694926,11694927,11694927,11694927,11694928,11694929,11694929,11694932,11694934,11694917,11694930,11694928,11694932,11694928,11694931,11694938,11694938,12059288,12268553,11694938,12268553,13020530,11694939,11694940,11694941,11694943,11963600,11984917,12046740,12268554,12268554,12268555,12268555,12268556,12272164,12293836,12558773,12558774,12558774,12558775,13020528,13020529,13302445,13302446,13302446,13375277,13794076,11694940,11694941,11694941,11694942,11836373,11850738,11868170,11868172,11889423,11906558,12046740,12268554,12268555,12268556,12272164,12558775,12558775,12558777,12558777,13020529,13020529,13020530,13302443,13302446,13302447,13302447,13302449,13375278,13375280,14140491,11694941,11963593,12268555,12268555,12558776,12568628,13302447,13375278,12268555,12293838,12558776,12558776,12568628,13302448,13375278,12268556,12558776,13302449,11868174,12067054,12268556,12268557,12558777,12268557,12293839,12268558,12293840,13302452,12268562,11763919,11764013,11764139,12303185,11803521,13074825,11857623,11970787,11867235,12644932,11977825,11977845,12105044,12006558,12714594,12041408,12041410,12041413,12041414,12732015,13193772,12062664,12441797,12441798,13193772,13475689,15406642,12083913,12083915,12083915,12083917,12083919,12084034,12083926,12463048,12463048,12463048,12463049,12463050,13215024,12084155,13215140,12118193,12278686,12232243,12232251,12232253,12232254,12232262,12232281,12232281,12232316,12537235,12537250,12827470,12827471,12274941,12558578,12398555,12398556,12620369,13318523,12423654,12923138,12439167,12439204,12439182,12439219,12640706,12930928,12522305,13434222,12781962,14543621,12842184,12842169,12842170,12842170,12842171,12842183,12842184,12842184,12842185,12842185,12842186,12842186,12842187,12842187,12842188,12842189,12842170,12842171,12842171,12842172,12842183,12842183,12842184,12842184,12842185,12842185,12842186,12842186,12842187,12842187,12842171,12842183,12842184,12842184,12842185,12842185,12842186,12842186,12842187,12842188,12842190,12842173,12842183,12842184,12842185,12842186,12842187,12842187,12842188,12842189,12842189,12842185,12842186,12842186,12842188,12842189,12842192,12842197,13876076,12842198,12842200,13132403,12842198,12842198,12842199,12842200,12842200,12842201,12845794,12949307,13109387,13132401,13132403,13132403,13132405,13132406,13311476,13594158,13594159,13876075,13876075,13876076,13876079,12842199,13132404,13876075,12842199,12842200,12949334,13036102,13132404,13132406,13594159,13876079,14714121,12842200,12842201,12842201,12842202,12842202,12842203,12842204,12867466,12867467,12903886,13060902,13132403,13132404,13132404,13132405,13132406,13132406,13132407,13594159,13594160,13795680,13876076,13876076,13876077,13876080,13948907,14573730,14714121,14714122,12842201,12842202,12842203,12842205,12867467,12903885,12948302,13109389,13132403,13132404,13132405,13132405,13132406,13132406,13132407,13132407,13291901,13594158,13594159,13594159,13594160,13876077,13876077,13876078,13876079,13876080,12842202,12842205,12845794,12845795,12845795,12845796,13132404,13132405,13132405,13132406,13132407,13132408,13132409,13142258,13540338,13594160,13594160,13594161,13594161,13876077,13876078,13876078,13948909,16533403,12842203,12867468,13132404,13132406,13132407,13542626,13594160,13594161,13876078,13948909,12842204,12842205,12845799,12867469,12903888,13132405,13132406,13132407,13132407,13594161,13594161,13876078,13876079,13948909,13109391,13132406,13132407,13594161,13876080,13132406,13594162,13876080,13132409,13876080,13948912,13132407,13132408,12936090,13523377,13594165,12849402,12849402,12849402,12849403,12849404,12849404,12849405,12849405,12849409,12849410,13136013,12871076,13506325,13952517,12907496,13136014,13597768,13136016,13597772,12892748,12892749,12929168,13157687,13619440,13619441,13619442,13901358,13966538,12946315,13646224,12965581,12965587,12965587,12965588,13655856,13194106,13194106,13655860,13325271,13655860,13655860,13029986,13611380,13054413,13238518,13056433,13701283,13056485,13239555,13230023,13230023,13788078,13326325,13279615,13523826,13376589,13376590,13376591,13376591,13376592,13861359,14143278,13861361,14143279,13861362,14143278,13422608,13422620,13422621,13422622,13422607,13422608,13422622,13422623,13422607,13422608,13422611,13422623,13422608,13422609,13422621,13422623,13422623,13422624,13422609,13422611,13422623,13422624,13422624,13422610,13422611,13422611,13422612,13422612,13422624,13422624,13422625,13422612,13422625,13422625,13422612,13422613,13422624,13422625,13422625,13422626,13422613,13422626,13422626,13422628,13422614,13422626,13422627,13422626,13422627,13422627,13422628,13422628,14166294,14166294,14166296,13422639,13716233,13884378,13884378,14166297,14166297,14239126,13422639,13687618,13884376,13884378,13884378,13884379,13884379,14166296,14166296,14166297,15004341,13432477,13432523,13442304,13601697,13713965,13813592,13832839,13865593,13884377,13884378,13884378,13884379,13884379,13884380,13884380,14123883,14146866,14166295,14166296,14166296,14166297,14166297,14166298,14166298,14166299,14166300,14231476,14239127,14239128,14606181,14883558,15004341,15004342,14166298,13442360,13442361,13442390,13442435,13442425,13442436,14176199,13442509,13894291,13442509,13894335,13894335,13894336,14176253,14176253,13462038,13510898,13559752,13756207,13684955,14015543,13741677,13741805,13741932,14044063,13768038,14024598,13780790,13780827,14063472,14345391,13790808,14016934,13909743,14409855,13952610,13952611,14431288,14149371,14005303,14175718,14009841,14532736,14163252,14163265,15374658,14254698,14192778,14269457,14204611,14204567,14204618,14275355,14204914,14204919,14204926,14205222,14205235,14275708,14630456,14557632,14238490,14238491,14574229,14574232,14243044,14243061,14243066,14243074,14243076,14243141,14576515,14243080,14294600,14294600,14243222,14576594,14281157,14595560,14308555,14308682,14308809,14327470,14346115,14346117,14346132,14346117,14346131,14346132,14346117,14346118,14346118,14346119,14346132,14346133,14346118,14346119,14346119,14346120,14346132,14346133,14346134,14346134,14346119,14346121,14346134,14346134,14346134,14346135,14346135,14346135,14346136,14346136,14346138,14346136,14346137,14346136,14346137,14346138,14346148,14555305,14628051,14628051,14346149,14628051,14628051,14628052,14628054,14700882,14346150,14346151,14346151,14362993,14555306,14585637,14628049,14628051,14628052,14628052,14628053,14628053,14628054,14628054,14628055,14693231,14700881,14700882,14700883,14700883,14700884,14700886,14858746,15325586,15325704,15345313,15466096,15466097,15884306,25587466,14628052,14700883,17285378,14628051,14628052,14628055,14628056,15466097,14628055,14700884,14628056,14379849,15482953,14749172,15061128,14764485,14764529,14764561,14910105,14764633,14797295,14825140,14825142,14867554,14867555,14829956,14869963,14871105,14890535,14909950,14909950,14909951,14909952,14909967,14909952,14909967,14909953,14909954,14909954,14909955,14909955,14909956,14909956,14909957,14909968,14909968,14909969,14909969,14909970,14909970,14909971,14909972,14909954,14909955,14909955,14909956,14909956,14909957,14909957,14909958,14909965,14909968,14909969,14909969,14909970,14909970,14909971,14909971,14909972,14909972,14909955,14909956,14909956,14909957,14909957,14909958,14909959,14909968,14909969,14909969,14909970,14909970,14909971,14909971,14909973,14909956,14909957,14909957,14909958,14909969,14909970,14909970,14909971,14909972,14909972,14909957,14909958,14909958,14909970,14909970,14909971,14909971,14909972,14909972,14909973,14909974,14909958,14909959,14909959,14909960,14909970,14909970,14909971,14909971,14909972,14909972,14909973,14909974,14909959,14909960,14909971,14909971,14909972,14909972,14909973,14909974,14909974,14909960,14909971,14909972,14909972,14909973,14909974,14909974,14909975,14909975,14909976,14909972,14909973,14909973,14909974,14909974,14909975,14909976,14909976,14909973,14909975,14909974,14909981,14909982,14909983,14909983,14909984,14909986,14909986,14909987,14982799,14982799,15748012,14909984,14909985,14909985,14909986,14909986,14909987,14909987,14909988,14975147,14975148,14975150,14982799,14982800,14982800,14982801,14982803,15607621,15648249,15648275,15748013,15748014,16910432,14909985,14909986,14909986,14909987,14909987,14909988,14909988,14975153,14982800,14982800,14982801,14982801,14982802,15140666,15404760,15627231,15661493,15675031,15748013,15748014,14909986,14909987,14909987,14909988,14909988,14909989,14975149,14975153,14982800,14982801,14982801,14982802,14982803,15140665,15140667,15607623,15748014,15748014,15748015,16840922,14909987,14909988,14909988,14909989,14975149,14975154,14982801,14982801,14982802,15661494,15748014,15748015,14909988,14909989,14909989,14909990,14909990,14909991,14975149,14975150,14982800,14982801,14982802,14982802,14982803,15137546,15648261,15748015,15748016,16840924,14909989,14909990,14975150,14975152,14975152,14975155,14982802,14982802,14982803,15607555,15607623,15607625,15648269,15748015,15748016,14909990,14909991,14946835,14975151,14975152,14975155,14982802,14982803,14982803,14982805,15607624,15748016,15748017,15748021,14909991,14975151,14975152,14975154,14975155,14975156,14982803,14982803,14982804,14982805,14982805,15401607,15607628,15627235,15648092,15661477,15748016,15748017,16180173,14975152,14975156,14982802,14982803,14982804,14982804,14982806,14982804,14982804,14983693,15019660,15040311,15040327,15040312,15040316,15040326,15040326,15040327,15040327,15040328,15040329,15040330,15040328,15040330,15040329,15040331,15040330,15040331,15040332,15040335,15040331,15040332,15040333,15040334,15040335,15040335,15047978,15040342,15040343,15040344,15047978,15047979,15047979,15040343,15040345,15040345,15047979,15047979,15047980,15047980,15713428,15047980,15047981,15047982,15692411,15047981,15047981,15047982,15182831,16924464,15047983,15713355,15047982,15047982,15047983,15055614,15055614,15055614,15055615,15055616,15055616,15055617,15055618,15055630,15055631,15055631,15055632,15055632,15055616,15055617,15055617,15055618,15055618,15055619,15055620,15055630,15055631,15055631,15055632,15055632,15055617,15055618,15055618,15055619,15055619,15055621,15055621,15055631,15055632,15055632,15055633,15055634,15055635,15055619,15055620,15055621,15055631,15055632,15055632,15055633,15055633,15055634,15055619,15055632,15055633,15055633,15055634,15055637,15055620,15055621,15055622,15055633,15055633,15055634,15055634,15055635,15055635,15055633,15055634,15055635,15055635,15055634,15055634,15055635,15055635,15055637,15055637,15055636,15055636,15055635,15055636,15055636,15055645,15055645,15055646,15055647,15055647,15055648,15055648,15213494,15734304,15820844,15820845,16239054,15055647,15055648,15055648,15055649,15055649,15055651,15213497,15213497,15213500,15214360,15417115,15422685,15448398,15474431,15545457,15643594,15680452,15680453,15680454,15680455,15700063,15721004,15721078,15721096,15721105,15734324,15734324,15734327,15820844,15820845,15055648,15055649,15055649,15055650,15055650,15055651,15055652,15213371,15213496,15213497,15213497,15213498,15254965,15254966,15258894,15422685,15474432,15580850,15680450,15680453,15680453,15680454,15680454,15680457,15700062,15700063,15721075,15721079,15721081,15820845,15820845,15820846,15820850,16239055,16913754,15055649,15055650,15055651,15055651,15055652,15103526,15213498,15213499,15254967,15422685,15422686,15422687,15474432,15474437,15680451,15680452,15680453,15680453,15680455,15680457,15700063,15700063,15700064,15700065,15721072,15721080,15721082,15734306,15734308,15734325,15820845,15820846,15820849,16913754,16932114,17415897,21199686,15055650,15055651,15055651,15055654,15124345,15213372,15213375,15213497,15213498,15213498,15213499,15214361,15254965,15254967,15342952,15417120,15422686,15474437,15680453,15680454,15680456,15680458,15680459,15700063,15721006,15721079,15721081,15721093,15721103,15721110,15734306,15751429,15820846,15820846,15820847,16239056,15213498,15213503,15680456,15700064,15700065,15820846,15820847,15151114,15213499,15213499,15680456,15680459,15700064,15820847,15820848,15213497,15213498,15254967,15680456,15680460,15700066,15820848,15680460,15248295,15680459,15820848,15820849,15213502,15820850,15721086,15151427,15868747,15193056,15283073,15246588,15308973,15325338,15955702,15365116,15854802,15371103,15371104,15371112,15371232,15371236,15371229,15371237,15371357,15371345,15371358,15371360,15371349,15371359,15371360,15371346,15371361,15371362,15371360,15371360,15371361,15371362,15371362,15371363,15371361,15371361,15371362,15371363,15371363,15371364,15371363,15371364,15371366,15371369,15371371,15371369,15371374,15838321,15857926,15878943,15978709,15412828,15857926,15978708,15978709,15838318,15857926,15978709,15978710,15580550,15857928,15978709,15978710,16396920,15580550,15606264,15838318,15857927,15857929,15878971,15878973,15978710,15978711,17141129,15857928,17071617,15857931,15978714,15373085,15373088,15373090,15373091,16397780,15879831,16397784,15879734,15440951,15615344,15454294,15454295,15454295,15454296,15454297,15879782,15879784,15879788,15899392,15899393,16020175,16020176,15920404,15462155,15924266,15630266,16008236,15778609,15778613,16061557,16182339,15789740,15789738,15789738,15789739,15789739,15789741,15789740,16067115,16067116,16187898,16187901,16187899,16047505,16047510,16088032,16187898,16187899,16047510,16067118,15841162,15841163,16073217,16213610,15893229,15893230,15893229,15893236,15893236,15893237,18058930,16239644,17332551,17350924,16118863,16239645,16239646,15899554,15899624,15899692,16242876,16035288,16170283,16106065,16346060,16231558,16408810,16305032,16305157,16305131,16305206,16305269,16305272,16305272,16305261,16305273,16305260,16305273,16305274,16305275,16305274,16305274,16305275,16305275,16305276,16305274,16305274,16305277,16305277,16305278,16305278,16305279,16305279,16305280,16305280,16305281,16305281,16305282,16305280,16305281,16324881,16305288,16345741,16345923,16445665,16445666,16305290,16324883,16324884,16345886,16345932,16359126,16365747,16372616,16445666,16445667,16542613,16863876,17608085,16305292,16324883,16324884,16324884,16345742,16345826,16345925,16359127,16445666,16445667,16445669,17538576,18264946,16324884,16324884,16324885,16445668,16863878,16863879,17538576,16445669,16344489,16344490,16344478,16344479,16344488,16344489,16344489,16344490,16344492,16344492,16344493,16344494,16344494,16344495,16344490,16344493,16344493,16344489,16344494,16344494,16344495,16344497,16344494,16344494,16344496,16344500,16344504,16344505,16378750,16465271,16465271,16465272,17576555,16465271,16465272,16365495,16465273,16365432,16365522,16465272,16465273,16969509,16465274,16344509,16365494,16465274,16465275,17558182,16365502,16465275,16465276,16465276,17576558,16344509,16365409,16365509,16365530,16465275,16465276,16465276,16465279,16365498,16365544,16378756,16465276,16465277,16465277,16883487,16355191,16378757,16465277,16465278,16465278,16465279,16365893,16894189,16386269,16386385,16386425,16486193,16486194,16386437,17579156,17597517,16386535,16386535,16386537,16386538,16386549,16386549,16386544,16386546,16386555,16386538,16386552,16386557,16386561,16386516,16386554,16386555,16386563,16486278,18081327,18305557,16386534,16386558,16386560,16386560,16386564,16386564,16386571,16386563,16386565,16386578,16386574,16386554,16386577,16386580,16386560,16386573,16386578,16386582,16386586,16386584,16386588,16386586,16386586,16386584,16386590,16386594,16386597,16486315,16486316,16486318,16486316,16904526,16486316,16486317,16486319,16486320,16904530,16486320,16486321,16486321,16399803,16486322,16386604,16486323,16386605,16486323,16386606,16486323,16904534,16386607,16486325,16486327,16774683,16486324,17579233,16486326,16486326,16399809,16486327,16486328,16486328,17597596,16486328,16486329,16412975,16412976,16412978,16413017,16413018,16412978,16412996,16412997,16412997,16412995,16412996,16413000,16499518,16413019,16413020,16413025,16413020,16413026,16413027,16413027,16413040,16413028,16413023,16413029,16413030,16917750,16499540,16499541,16499541,16917751,16499546,16499546,16499547,16499551,16499557,16499557,16499558,16426220,16506139,16439952,16440020,16440085,16440087,16440089,16513069,16513072,16447251,16516668,16586042,16586043,16586057,16586059,16586059,16586043,16586060,16586044,16586045,16586045,16586046,16586046,16586047,16586047,16586048,16586048,16586049,16586049,16586055,16586056,16586056,16586057,16586057,16586058,16586058,16586059,16586059,16586060,16586060,16586061,16586061,16586062,16586045,16586046,16586046,16586047,16586047,16586048,16586056,16586057,16586057,16586058,16586058,16586059,16586059,16586060,16586046,16586047,16586047,16586048,16586049,16586049,16586050,16586058,16586060,16586060,16586061,16586048,16586049,16586057,16586058,16586058,16586059,16586060,16586060,16586061,16586063,16586061,16586049,16586050,16586050,16586051,16586058,16586059,16586059,16586060,16586060,16586061,16586061,16586062,16586063,16586064,16586065,16586066,16586059,16586059,16586061,16586061,16586062,16586062,16586063,16586064,16586059,16586059,16586060,16586060,16586061,16586062,16586062,16586064,16586052,16586059,16586061,16586062,16586062,16586063,16586064,16586065,16586067,16586055,16586060,16586061,16586061,16586062,16586063,16586063,16586064,16586068,16586061,16586064,16586064,16586065,16586063,16586068,16586069,16586069,16586071,16586068,16586069,16586069,16586070,16586070,16586071,16586071,16586069,16586070,16586070,16586071,16586071,16586072,16586070,16586071,16586071,16586072,16586072,16586071,16586072,16586072,16586073,16586072,16586073,16586073,16586074,16609027,17748477,16586073,16586074,16586074,17004268,21964898,16586074,16586075,16586075,16586076,16586077,16586078,17004268,17678966,17678966,17678967,17697328,18181111,18405339,21964901,16586075,16586076,16586076,16586077,16586078,16586078,16586079,16874418,17004269,17004271,17018213,17678966,17697327,17697328,17697343,17748479,18165041,18405348,18405350,23266491,16586076,16586077,16586077,16586078,16586078,16586079,16586079,17004269,17251851,17258604,17398698,17678966,17678968,17697327,17748479,17748479,17748480,18181111,18405349,18405350,20351379,16586077,16586078,16586078,16586079,16586080,16586080,17004270,17004271,17148052,17158138,17678966,17678967,17678968,17697328,17697344,17748479,17748479,17748480,17748480,17748481,18126401,18405339,18405340,18405347,18405349,20351374,20351375,21964901,16586078,16586079,16586079,16586080,16586080,16586081,16758746,16941971,17004270,17004272,17004273,17018217,17458023,17508353,17678966,17678967,17678967,17678968,17697325,17697328,17697328,17697329,17697329,17697336,17697339,17697343,17697344,17697345,17697346,17748479,17748479,17748480,17748480,17748481,17748481,18115738,18181110,18181111,18405339,18405341,18405341,18405349,18405349,18405352,21964901,34893381,16586079,16586080,16586080,16586081,16586081,16586083,16586083,17004271,17006330,17678967,17678969,17678969,17697329,17697341,17697345,17748479,17748480,17748480,17748482,17864260,18405350,16586080,16586081,16586081,16586082,16874420,17004271,17004273,17148054,17678968,17678970,17697329,17697330,17748480,17748481,17748482,18405340,18405341,16586081,16586082,16874421,17004272,17004273,17090298,17121344,17572106,17678968,17678969,17678970,17697327,17697330,17697330,17697331,17697345,17697346,17748479,17748481,17748481,17748482,17748482,18181114,18405341,20399190,16586082,16586083,16646182,17004272,17004272,17004274,17090298,17678969,17678971,17748481,17748482,18181113,18181114,16586083,16586084,17004273,17678968,17678969,17678970,17678970,17678971,17678971,17697331,17697340,17697346,17697347,17748480,17748482,17748482,17748483,17748484,18405355,17004273,17678970,17697331,17697332,17697347,17748484,16874423,17004274,16874424,17004275,16631995,17027236,16706298,17739085,16779946,17101209,16931431,17176955,17162774,17162774,17162775,17292625,17967323,17292625,17297878,17360178,17422462,17422463,17422464,17422464,17422465,17422474,17422474,17422475,17422475,17422476,17422476,17422477,17422477,17422478,17422478,17422479,17422480,17422483,17422476,17422477,17422466,17422477,17422477,17422478,17422479,17422479,17422480,17422481,17422481,17422482,17422476,17422478,17422480,17422480,17422482,17422484,17422487,17422489,17422489,17422490,17816903,18115532,17422488,17422490,17508501,17422488,17422489,17422490,17422490,18097173,18097174,18115546,18115547,18166684,18599314,18823554,18823556,17422489,17422490,17422490,17422491,17422491,17422492,17422493,17422493,17576342,17692181,17816904,17816905,18097171,18097172,18097173,18097174,18097174,18115534,18115535,18166684,18166684,18166685,18166685,18549405,18823545,18823552,17422491,17448258,18115535,17422492,17508503,18097175,18166686,18166686,18599317,20769585,17422492,18097174,18115535,18115551,17422493,17422494,17422494,17422495,17422496,17422501,17436423,17436424,17508504,17670047,17714962,17783006,17816907,17876230,17969047,18097173,18097174,18097174,18097175,18097175,18097176,18097176,18097177,18115535,18115536,18115536,18115537,18115537,18115538,18115546,18115547,18115548,18115551,18115552,18115552,18166686,18166686,18166687,18166687,18166688,18166688,18166689,18166691,18166691,18166692,18329080,18599317,18599318,18599319,18599320,18599320,18823549,18823555,18823555,18823558,18823559,20510444,20769585,21140531,22383108,17422495,17422495,17422496,17783007,17926561,18097175,18097176,18097176,18097177,18097177,18115536,18115536,18115538,18115552,18115553,18115553,18166687,18166688,18166688,18823549,18823560,17422496,17422498,18097176,18097177,18115537,18115538,18166689,18166689,18166690,18823558,17422497,17576348,18115538,18166688,18166689,18097177,18115536,18115538,18115554,18115554,18166690,18097179,18166691,18097179,18115544,17426593,18168742,17450369,17450370,17450371,17450371,18111122,18180633,18111121,18129482,18129484,17474102,17474185,17474268,18123101,17594526,17594527,17594527,17599141,18183196,18909569,18183197,18252710,18201560,17603759,18206177,17656620,18232606,17710041,18240957,18259317,17730209,17730210,18269400,18269414,18269416,17917624,17917637,18344752,18414265,17931192,18351555,17961884,18366876,18007442,18408031,18143533,18143535,18527214,18476065,18211332,18211333,18211334,18211335,18509962,18561114,18509964,18509964,19217975,18329979,18329980,19277303,18569286,18430698,18430777,18430848,18430850,18619762,18619747,18515632,18515695,18515765,18643829,18558142,18734517,18771856,18771868,18771870,18771870,18771871,18771856,18771857,18771871,18771871,18771872,18771873,18771857,18771858,18771858,18771870,18771871,18771872,18771872,18771873,18771858,18771859,18771872,18771873,18771859,18771873,18771873,18771874,18771874,18771875,18771860,18771872,18771873,18771873,18771874,18771874,18771875,18771875,18771876,18771874,18771876,18790232,18841383,18771887,18841384,22720920,18771886,18790232,18790233,18790234,18790247,18841384,18841385,19274016,18771887,18771888,18771888,18790233,18790234,18790234,18790246,18790246,18790249,18841383,18841383,18841384,18841384,18841385,18841386,18841387,19498255,18771888,18771889,18771889,18790233,18790234,18790235,18790248,18790249,18790249,18841384,18841384,18841385,18841386,18841386,18841387,19274017,19498254,19498255,18771889,18771890,18790234,18790234,18790235,18841385,18841386,19498245,18790231,18790232,18790234,18790235,18790235,18790236,18790242,18790248,18790250,18790253,18841385,18841387,19274018,19274018,23681985,18771891,18790231,18790233,18790235,18790236,18790236,18790237,18790251,18790251,18790252,18841386,18841387,18841388,23681985,18790236,18790237,18808575,18808589,18808592,18808603,18808577,18808578,18808591,18808590,18808592,18808578,18808594,18808610,18808579,18808580,18808580,18808581,18808582,18808589,18808591,18808591,18808592,18808593,18808593,18808594,18808594,18808595,18808595,18808596,18808596,18808597,18808597,18808598,18808598,18808600,18808601,18808603,18808610,18808580,18808590,18808594,18808595,18808595,18808596,18808596,18808597,18808598,18808599,18808600,18808581,18808582,18808585,18808591,18808594,18808595,18808595,18808596,18808596,18808597,18808598,18808599,18808601,18808603,18808603,18808607,18808608,18808582,18808592,18808593,18808594,18808595,18808596,18808597,18808599,18808600,18808602,18808603,18808605,18808607,18808608,18808608,18808609,18808610,18808596,18808597,18808598,18808600,18808601,18808607,18808607,18808610,18808597,18808602,18808618,18808603,18808605,18808609,18808621,18808621,18808606,18808607,18808615,18808620,18808607,18808622,18859743,18808607,18808619,18859742,18808608,18808623,18859743,18808606,18808607,18808608,18808620,18808624,19292372,18808608,18808613,18808625,18859744,18808608,18808609,18808611,18808612,18808625,18808625,18859744,18859745,18808609,18808610,18808612,18808612,18808613,18808619,18808621,18808625,18859745,18859746,18859746,18859747,19292378,19516611,18808610,18808611,18808612,18808612,18808613,18808614,18808614,18808615,18808626,18808627,18808627,18859745,18859746,18808611,18808612,18808612,18808613,18808613,18808614,18808614,18808615,18808616,18808618,18808620,18808623,18808624,18808626,18808627,18808627,18859742,18859745,18859745,18859746,18859747,18859747,19516617,18808612,18808613,18808613,18808615,18808615,18808616,18808619,18808623,18808627,18808628,18859745,18859746,18859747,18859750,18808613,18808616,18808624,18808626,18808627,18808628,18808628,18859745,18859746,18859747,18859747,18859748,18859748,19184676,18808615,18808615,18808617,18808618,18808623,18808625,18808628,18808629,18859747,18859747,18859749,18859751,18808616,18808628,18859748,18859748,19292381,19516609,19516618,18808616,18808617,18808624,18808625,18808627,18808629,18808629,18808630,18859748,18859749,18859750,19516608,18808618,18808618,18808620,18808622,18808628,18808631,18859748,18859749,18859749,18859751,21462640,18808618,18808626,18808630,18808630,18808631,18808631,18808632,18859749,18859752,18808620,18808624,18808631,18808633,18859749,18859750,18859750,18808620,18808630,18808631,18808625,18808631,18808632,18859750,18859754,19292384,18808632,18859753,18808624,18859751,18859752,18859751,18859752,18859754,18808634,18859755,19292386,18859756,18808633,18808635,18859755,18808635,18808636,18808637,18859756,19516616,18808632,18808633,18859757,18808634,18808636,18808637,18808638,18808640,18859757,18859758,18859759,19292390,18808639,18859758,18859758,18859759,18859759,18859760,18808639,18859759,18859760,21203515,18808642,18859759,18859760,18859761,18808641,18859760,18859761,19292393,18808641,18808642,18808643,18808643,18808644,18859761,18859761,18859762,18859762,18859763,18859763,18859764,18859768,18906966,19292394,19292395,19516622,19516622,19516627,19516628,19516629,19516634,18808643,18859761,18859762,18859764,18859765,19292395,18859757,18859761,18859762,18859762,18859763,18859763,18859764,19516622,19516632,19516633,19516633,21462661,18859762,18859762,18859763,18859763,18859764,18859762,18859764,19292396,18859764,18910877,18910878,18910879,18910879,18910880,18910881,18910881,18910879,18910880,18910880,18910880,18910881,18910881,18910882,18910882,18910894,18910895,18910896,18910896,18910881,18910882,18910882,18910883,18910883,18910884,18910884,18910886,18910896,18910896,18910897,18910897,18910898,18910898,18910899,18910882,18910883,18910883,18910884,18910884,18910886,18910896,18910896,18910897,18910897,18910898,18910898,18910899,18910899,18910900,18910900,18910901,18910883,18910884,18910884,18910885,18910886,18910886,18910893,18910894,18910895,18910896,18910897,18910897,18910898,18910898,18910899,18910899,18910900,18910901,18910903,18910884,18910885,18910885,18910886,18910886,18910887,18910887,18910896,18910896,18910897,18910897,18910898,18910898,18910899,18910899,18910900,18910900,18910901,18910902,18910904,18910885,18910886,18910886,18910887,18910887,18910888,18910897,18910897,18910898,18910898,18910899,18910899,18910900,18910900,18910901,18910901,18910902,18910886,18910887,18910888,18910889,18910898,18910898,18910899,18910899,18910900,18910900,18910901,18910905,18910887,18910888,18910888,18910898,18910899,18910899,18910900,18910900,18910901,18910901,18910902,18910905,18910888,18910889,18910899,18910899,18910900,18910900,18910901,18910902,18910903,18910904,18910890,18910899,18910900,18910901,18910901,18910902,18910902,18910904,18910901,18910901,18910902,18910902,18910904,18910902,18910902,18910903,18910905,18910906,18910902,18910904,18910909,18910909,18910909,18910910,18910910,18910910,18910912,18910910,18910911,18910911,18910912,18910912,18910913,18910913,19343528,19567755,19567756,18910911,18910912,18910912,18910913,18910913,18910914,18910915,19567764,18910912,18910913,18910913,18910914,18910914,19073287,19343528,19343529,19343529,19567756,19567757,19567758,19567765,19567766,21513793,23127318,18910913,18910914,18910914,18910915,18910915,18910916,18910916,18910918,18910918,18910920,19185493,19235830,19343528,19343529,19343529,19343530,19343530,19567757,19567757,19567758,19567758,19567760,19567764,19567767,19567768,19567769,21254655,18910914,18910915,18910915,18910916,18910916,18910917,18910917,18910918,18910920,19110635,19185492,19343529,19343529,19343530,19343530,19343531,19567757,19567758,19567759,19567767,19567769,19567770,23753118,18910915,18910916,18910916,18910917,18910917,18910918,18910918,18910919,19132307,19235829,19335027,19343528,19343529,19343529,19343530,19343530,19343531,19343531,19567758,19567758,19567759,19567759,19567765,19567766,19567767,19567767,19567768,19567768,19567769,19567770,19567771,21057422,18910916,18910917,18910917,18910918,18910918,18910920,18910922,19026678,19056464,19073292,19132305,19235827,19235832,19246727,19343529,19343529,19343530,19343530,19343531,19343531,19343532,19567759,19567759,19567760,19567760,19567762,19567764,19567765,19567766,19567770,21513797,21884742,18910917,18910918,18910918,18910919,18910920,18910920,18910922,18910925,18910925,19026675,19073292,19110635,19132307,19132307,19132308,19185496,19235829,19235831,19235832,19343529,19343529,19343530,19343530,19343531,19343531,19343532,19343532,19385278,19437460,19567759,19567759,19567760,19567761,19567763,19567764,19567765,19567766,19567767,19567768,19567769,19567769,19567770,19567771,22790438,18910918,18910919,18910919,18910920,19234948,19288821,19343529,19343530,19343531,19343532,19343532,19343533,19567761,19567761,19567765,19567768,18910919,18910920,18910921,18910921,18910927,19026680,19132309,19185494,19185495,19343529,19343530,19343532,19343532,19343533,19343533,19567760,19567761,19567768,21513797,23127321,18910920,18910921,18910927,19070926,19073293,19235834,19343532,19343533,19343533,19343534,19567762,19567768,19567768,19567771,21513796,19185497,19343532,19343532,19343534,19567762,19567762,19567764,19567771,19567772,21513797,18910922,19132311,19343533,19343533,19567761,19567762,18910923,19288824,19343535,19508482,19567762,19567764,19567770,18910927,19235834,19343534,19343534,19343535,19343535,19567764,19567771,19567772,19567773,19567774,19567772,19343537,19185500,19343537,19235840,19225129,19567768,19567769,19567769,19005300,19614966,19142436,19142454,19142457,19142457,19142461,19142471,19683537,19683539,19459310,19459312,19202024,19489091,19230949,19727785,19235676,19235681,19235682,19235682,19235683,19505919,19730149,19730158,19730158,19505921,19505922,19310371,19310373,19543268,19767496,19353711,19353713,19353713,19353714,19353715,19564936,19564937,19564938,19564938,19789166,19460085,19460086,19460087,19460088,19618123,19510423,19510424,19618123,19618124,19842352,19842356,19842361,19539337,19881976,19558991,19667575,19560754,19560755,19560761,19560760,19560760,19560761,19560763,19560763,19560764,19560764,19668458,19892686,19668458,19668461,19892696,19668460,19892689,19892699,19892699,19668461,19668461,19668462,19668462,19668463,19582567,19622558,19645413,19935024,19662549,19662589,19662677,19719449,19666736,19666737,19945679,19945681,19945684,19676330,19676416,19676501,19950567,19744019,23543877,19759212,19991944,19776142,19776158,19776142,19776144,19776144,19776145,19776156,19776159,19776143,19776144,19776157,19776143,19776144,19776144,19776145,19776158,19776158,19776159,19776160,19776161,19776144,19776145,19776145,19776146,19776147,19776156,19776157,19776158,19776158,19776159,19776159,19776160,19776160,19776161,19776161,19776145,19776146,19776146,19776156,19776160,19776160,19776161,19776161,19776162,19776163,19776146,19776147,19776148,19776150,19776159,19776160,19776160,19776161,19776161,19776162,19776162,19776163,19776147,19776158,19776159,19776159,19776160,19776160,19776161,19776161,19776162,19776162,19776163,19776160,19776161,19776162,19776162,19776163,19776163,19776164,19776160,19776163,19776165,19776165,19776172,20000386,19776171,19776173,19776175,19776177,20000386,20000398,19776172,19776174,20000389,19776174,19776175,19776175,20000387,20000388,20000389,20000396,19776175,19776176,19776176,20000387,20000388,20000389,20000399,19776176,19776176,19776177,20000388,20000388,20000389,20000393,20000397,20000397,19776176,19776177,19776177,19776180,19955110,20000389,20000390,20000390,20000398,20000399,19776177,19776178,19776180,20000389,20000389,20000390,20000390,20000391,20000398,20000399,20000401,19776178,19776179,19776179,19937301,19955111,20000389,20000390,20000390,20000391,20000391,20000392,20000393,20000394,20000395,20000396,20000397,20000398,20000398,20000399,20000400,20000400,20000401,20000404,20096577,21946426,19776180,19776181,19955111,19986053,20000390,20000390,20000391,20000391,20000392,20000393,20000394,20000394,20000395,20000395,20000396,20000397,20000397,20000398,20000399,20000399,20000400,20000400,20000401,20000401,20000402,20000403,20000403,21946429,23559951,20000390,20000399,20000400,20000391,20000391,20000396,20000398,20000393,20000392,20000393,19859654,19859736,19859814,20042224,19964021,20094321,20098440,20161530,20106044,20106110,20165389,20134055,20134056,20179335,20179336,20179344,20195938,20210276,20224601,20224602,20224602,20224603,20224603,20224604,20224606,20224607,20224607,20224609,20224610,20224611,20224613,20224602,20224603,20224603,20224604,20224604,20224605,20224606,20224607,20224609,20224609,20224610,20224611,20224603,20224604,20224604,20224605,20224606,20224608,20224608,20224609,20224609,20224611,20224612,20224613,20224613,20224625,20224604,20224605,20224605,20224606,20224607,20224607,20224608,20224608,20224609,20224609,20224610,20224610,20224611,20224611,20224612,20224612,20224613,20224613,20224614,20224614,20224615,20224616,20224617,20224619,20224619,20224620,20224620,20224621,20224624,20224605,20224606,20224606,20224607,20224607,20224608,20224608,20224609,20224609,20224610,20224610,20224611,20224611,20224612,20224612,20224613,20224613,20224614,20224615,20224620,20224620,20224607,20224607,20224608,20224608,20224609,20224610,20224610,20224611,20224611,20224613,20224613,20224614,20224621,20224609,20224609,20224610,20224611,20224614,20224615,20224608,20224609,20224609,20224610,20224611,20224611,20224612,20224612,20224613,20224614,20224614,20224610,20224611,20224612,20224613,20224613,20224614,20224610,20224611,20224611,20224612,20224613,20224614,20224616,20224616,20224611,20224612,20224612,20224613,20224613,20224614,20224614,20224615,20224616,20224618,20224632,20224612,20224613,20224613,20224614,20224616,20224616,20224617,20224618,20224613,20224614,20224614,20224615,20224615,20224616,20224616,20224617,20224617,20224618,20224614,20224615,20224615,20224616,20224616,20224617,20224617,20224618,20224618,20224619,20224620,20224624,20224615,20224616,20224616,20224617,20224617,20224618,20224618,20224619,20224620,20224628,20224616,20224617,20224617,20224618,20224618,20224619,20224619,20224620,20224635,20224635,20224617,20224618,20224618,20224619,20224619,20224620,20224620,20224621,20224626,20224635,20224635,20224636,20224618,20224619,20224619,20224620,20224620,20224621,20224621,20224622,20224626,20224628,20224629,20224630,20224632,20224632,20224635,20224636,20224619,20224620,20224620,20224621,20224621,20224622,20224628,20224629,20224630,20224636,20224620,20224621,20224621,20224622,20224622,20224623,20224623,20224628,20224628,20224629,20224633,20224636,20224636,20224637,20224621,20224622,20224622,20224623,20224623,20224624,20224625,20224626,20224626,20224627,20224628,20224628,20224629,20224630,20224631,20224631,20224636,20224637,20224637,20224638,20224638,20224622,20224623,20224623,20224624,20224624,20224627,20224628,20224628,20224629,20224629,20224630,20224636,20224636,20224637,20224637,20224638,20224638,20224639,20224639,20224623,20224624,20224624,20224625,20224625,20224626,20224627,20224627,20224628,20224628,20224629,20224629,20224630,20224630,20224631,20224632,20224636,20224637,20224638,20224638,20224639,20224639,20224624,20224625,20224625,20224626,20224626,20224627,20224627,20224628,20224628,20224629,20224629,20224630,20224630,20224631,20224631,20224633,20224633,20224634,20224634,20224637,20224638,20224639,20224639,20224640,20224625,20224626,20224626,20224627,20224628,20224628,20224629,20224630,20224630,20224631,20224631,20224632,20224632,20224633,20224635,20224637,20224638,20224639,20224639,20224640,20224640,20224626,20224627,20224627,20224628,20224628,20224629,20224630,20224630,20224631,20224631,20224632,20224632,20224633,20224633,20224634,20224636,20224638,20224639,20224639,20224640,20224640,20224641,20224627,20224628,20224630,20224631,20224632,20224632,20224633,20224634,20224635,20224639,20224640,20224640,20224641,20224641,20224642,20224628,20224629,20224630,20224631,20224631,20224632,20224635,20224637,20224640,20224641,20224642,20224631,20224631,20224632,20224632,20224634,20224635,20224641,20224632,20224633,20224634,20224635,20224641,20224631,20224632,20224632,20224633,20224634,20224634,20224635,20224642,20224643,20224632,20224633,20224633,20224634,20224635,20224637,20224642,20224633,20224634,20224634,20224635,20224642,20224643,20224634,20224635,20224635,20224636,20224636,20224637,20224638,20224641,20224643,20224644,23784179,20224635,20224636,20224636,20224637,20224637,20224638,20224639,20224640,20224641,20224642,20224643,20224644,20224644,20224645,20224645,20224646,20224902,20320806,20224636,20224637,20224637,20224638,20224638,20224641,20224643,20224644,20224645,20224645,20224646,22170656,23447292,23784178,23784180,20224637,20224638,20224638,20224639,20224639,20224640,20224643,20224644,20224645,20224645,20224646,20224646,22170657,23784180,20224638,20224639,20224639,20224640,20224640,20224641,20224642,20224642,20224644,20224645,20224646,20224646,20224647,23784180,20224639,20224640,20224640,20224641,20224641,20224642,20224643,20224644,20224645,20224645,20224646,20224646,20224647,20224647,21911517,22170658,20224640,20224641,20224641,20224642,20224643,20224643,20224645,20224646,20224647,20224647,20224641,20224642,20224643,20224643,20224644,20224646,20224646,20224647,20224647,20224648,20224648,20224642,20224643,20224643,20224646,20224646,20224647,20224648,20224648,20224649,22170652,20224643,20224644,20224645,20224647,20224647,20224648,20224648,20224649,20224649,20224644,20224645,20224646,20224647,20224648,20224648,20224649,20224649,24408362,20224645,20224646,20224647,20224648,20224648,20224649,20224649,20224650,20224646,20224649,20224650,20224648,20224649,20224650,20224650,20224651,20224651,22170663,20224651,20224651,20224652,20224650,20224651,20224652,20224652,20224651,20224652,20224652,20224653,22170656,20224652,20224653,20224653,23585841,20224653,20224654,20224654,20224656,20277079,20289454,20289472,20700725,21343993,21477482,22170660,22170661,22170663,22170663,22170665,22170665,22170666,22170666,22170667,22541611,23498008,23784188,23784188,20224654,20224655,20224655,20224656,20224658,20224910,20845048,21290128,21343993,21477479,21477482,21714290,21724459,21831656,21831656,21850471,22018602,22170657,22170657,22170661,22170663,22170663,22170664,22170664,22170665,22170665,22170666,22170666,22541613,23447304,23784188,23784189,20224655,20224656,20224657,20224913,20256118,20320816,20449066,20556957,20652981,20700726,21290130,21308173,21343994,21343995,21423731,21423732,21424376,21424378,21640673,21714290,21850472,21850472,21911524,21911525,21911525,22170657,22170658,22170658,22170659,22170661,22170662,22170663,22170663,22170664,22170664,22170665,22170665,22170666,22170666,22170667,22170667,22170670,22400889,23146474,23146475,23171014,23447302,23784188,23784189,23784189,23784190,24408367,20224656,20224657,20224657,20224658,20224659,20224659,20224912,20244654,20256119,20256120,20256120,20275758,20293381,20293381,20320816,20325380,20449065,20449067,20474524,20556958,20577624,20607488,20700726,20700728,20703105,20712317,20814406,20845050,20978596,21061488,21169157,21169296,21193324,21343994,21400030,21423731,21423733,21714291,21714291,21831656,21831656,21850472,21879433,21911524,21911524,21911525,21911526,21911526,21920228,21976120,22170658,22170658,22170659,22170659,22170660,22170661,22170661,22170662,22170663,22170663,22170664,22170664,22170665,22170665,22170666,22170666,22170667,22170667,22170668,22170669,22201402,22360193,22400886,22400889,22541612,22541613,22541614,22541614,22651611,23447303,23447304,23447307,23447307,23560104,23581691,23784189,23784189,23784190,23784191,24411347,28526718,20224657,20256122,20320817,20449067,20577623,20690536,20700727,20943987,21295188,21319911,21343995,21349883,21367850,21386074,21423730,21423732,21423732,21424379,21477484,21714291,21831658,21850473,21911524,21911525,21911526,22170658,22170659,22170659,22170660,22170660,22170662,22170663,22170663,22170664,22170665,22170665,22170666,22170667,22170667,22541613,22924676,23447307,23585843,23784190,23784190,20320817,20700727,22170664,22170667,22170667,20320818,21290132,21343997,21424379,21831659,23447307,20320818,23585844,21714294,22170668,23784193,20700730,20225178,20225181,20225183,20225184,20225183,22170933,21424002,22170935,21344267,22170938,20264665,20776535,20287594,20287596,20287597,20287598,21321606,21455207,22202142,21455208,22202143,20609097,20326872,22221778,20329517,22223102,20354271,23512119,20354307,21488564,20362121,20362122,22239407,22239407,20416990,20417004,20417075,20417076,20417159,20417173,20673878,21519990,21519991,21576451,21753706,21927915,22007784,22266918,22266918,22266923,22266925,23880449,20545326,23543563,20426113,20426221,20426330,22609682,20673493,20673491,20673493,20673493,20673494,20673495,20673496,21417745,21651235,21514557,22395091,22766041,22074900,22395088,22395094,22395089,20724418,20724419,22420559,22420561,20889269,20889272,22502978,21000769,20930604,20930611,20930605,20930607,22523650,22523650,22753873,21776722,20990343,22783744,21081320,21796187,21112266,21144539,21156462,21156532,21156599,22180284,21176809,21176810,21176812,21176810,21176812,21176812,22646748,22646749,22646749,21321133,22646748,22646749,22646752,22646743,22646751,21181570,21552945,21199992,22658339,21288468,21288557,21288645,21872981,21404176,22760427,21465456,21465456,21465457,21964401,21964402,22334697,21663341,22890021,21732552,22924622,21898331,23007507,21924319,23020501,22113681,23115190,22113952,23115314,22161998,22162004,23139335,23139344,22355618,22355618,22355621,23236152,23236154,22915962,23236149,23236157,22365755,22982091,22391702,23254188,22415182,23265934,22457254,23286964,22463345,22463346,22463347,22463347,22463348,22463346,22463347,22463348,22463348,22596835,23290014,23290018,23030877,23290019,24705196,22951010,23290017,23290020,23290020,23290019,23290017,24903543,22475124,22548972,22511054,23054731,23313872,22547504,23332095,22575417,23346051,22622819,22622820,22622819,22622819,22622820,22622820,22622821,22622821,22622822,22622832,23049560,23369747,23740700,24646396,22623468,22694068,23110615,23110616,23343904,23369748,23369754,23369754,23369755,23369755,23369756,24983278,22624116,22624116,22624117,22624117,22624118,22668513,23370404,23370405,23370406,23050211,23370397,22628976,23372833,22712905,22712992,22713078,23414881,22730318,22730323,22730324,22730326,22730324,22967128,23423506,23423499,24838684,24399318,22735770,25039766,22765316,23441002,23056694,23056760,23056830,24863397,23090261,23344337,23203938,23203938,23203939,23203939,23203939,23203940,23508250,25273837,23362869,23660315,23204043,23321305,23660307,23660310,23660312,23660314,23660316,23890534,24936955,23660312,23204145,25075592,23224306,23670511,23438671,23438671,23438657,23438658,23438673,23438674,23777677,23777683,23457489,23777676,23777680,23777682,23777683,23777685,24148629,24531692,25192860,23476299,23476301,23476301,23476302,23476302,23796493,23796488,23796490,23796492,23796493,23796495,23796490,23796493,23796495,23796496,23796496,25073133,23521800,23819241,23534215,23534289,23534364,23566383,23598407,23598409,23598408,23598395,23598396,23598409,23598409,23598410,23598410,23598409,23598410,23598411,23598410,23598411,23598410,23598411,23598423,23598423,23857550,24228495,25471072,23857545,23857548,23857548,23857549,23857550,25471074,23857543,23857543,24338495,25471074,23857544,23857546,23857547,23857549,23857549,23857550,23857551,23857552,23857552,23857553,24087773,24228497,24530634,25134190,25134192,25471075,23615811,23866249,23727600,23922146,23812560,23964623,23964624,24065016,24090868,24116660,24116661,24116663,24116666,24116667,24116668,24116669,24116675,24116676,24116661,24116662,24116663,24116666,24116667,24116669,24116669,24116670,24116678,24116663,24116665,24116666,24116666,24116667,24116667,24116668,24116669,24116669,24116670,24116670,24116677,24116680,24116680,24116681,24116684,24116664,24116665,24116667,24116669,24116670,24116670,24116680,24116681,24116666,24116667,24116668,24116668,24116669,24116670,24116668,24116669,24116667,24116671,24116671,24116687,24116668,24116687,24116688,24116670,24116670,24116671,24116672,24116673,24116687,24116688,24116669,24116670,24116671,24116671,24116673,24116674,24116671,24116671,24116672,24116672,24116673,24116673,24116674,24116674,24116689,24116689,24116671,24116672,24116673,24116674,24116674,24116675,24116681,24116690,24116672,24116673,24116673,24116674,24116674,24116675,24116675,24116690,24116690,24116673,24116674,24116674,24116675,24116675,24116676,24116674,24116675,24116675,24116676,24116676,24116677,24116691,24116691,24116692,24116675,24116676,24116676,24116677,24116677,24116678,24116688,24116691,24116692,24116676,24116677,24116677,24116678,24116679,24116685,24116687,24116692,24116692,24116677,24116678,24116678,24116679,24116680,24116684,24116684,24116688,24116690,24116692,24116692,24116693,24116693,24116678,24116679,24116679,24116680,24116681,24116684,24116684,24116685,24116686,24116687,24116688,24116689,24116690,24116691,24116692,24116693,24116693,24116694,24116694,24116679,24116680,24116680,24116681,24116682,24116685,24116686,24116686,24116687,24116687,24116688,24116691,24116691,24116692,24116692,24116693,24116693,24116694,24116694,24116695,24116680,24116681,24116683,24116686,24116687,24116687,24116688,24116690,24116694,24116694,24116695,24116695,24116686,24116689,24116690,24116694,24116694,24116695,24116696,24116687,24116695,24116695,24116696,24116697,24116699,24116696,24116696,24116697,24116698,24116698,24116699,25730206,24116693,24116699,24116700,24116692,24116693,24116700,25393323,24116693,24116694,24116695,24116698,24116701,24346907,24116697,24116701,24116701,24116702,24116701,24116702,24116702,24116702,25730210,24116702,24116703,25393327,24116702,24116703,24116703,25730210,24116701,25537531,25730210,25730211,24116704,24116704,25730210,24116705,24116705,24116705,24116705,24116706,24116706,24116706,24116706,24116707,24116707,24116707,24116708,24487638,24116708,24116709,24116710,24116712,24346914,24346915,24346916,24487638,24487639,24487639,24487640,25092500,25092502,25393330,25527718,25531870,25539233,25730215,25730216,24116709,24116710,24116710,24116711,24116712,24177616,24304401,24307220,24346912,24346913,24346913,24346914,24346914,24346915,24346915,24346916,24402594,24487638,24487639,24487639,24487640,24487640,24487641,24521654,24597636,24597637,24597637,24597640,24719281,24746991,24746994,24887109,24965420,25069430,25092501,25092501,25092502,25117041,25117042,25237624,25241719,25241719,25241723,25246393,25350255,25393329,25393329,25393330,25393330,25393331,25393331,25393332,25393333,25393333,25393336,25420424,25431099,25527718,25527719,25531866,25531868,25531869,25531870,25730214,25730215,25730216,25730216,25730217,25730217,26354394,24116710,24116711,24116712,24116713,24307220,24346913,24346914,24346914,24346915,24346916,24346916,24346931,24346935,24402595,24437828,24487638,24487639,24487639,24487640,24487640,24487641,24597636,24597637,24597637,24597638,24965420,25009250,25024066,25069431,25092501,25117042,25237624,25241722,25393330,25393331,25393331,25393332,25393332,25393333,25393334,25393334,25396051,25527718,25531868,25531870,25531871,25596341,25730216,25730216,25730217,25730217,26354395,24116712,24346913,24346913,24346914,24346915,24346917,24437827,24487639,24487640,24487641,24487641,24597637,25069431,25393331,25393334,25531870,25531871,25531872,25730216,25730217,25730217,24346916,24487640,24597639,25393335,25730218,24487640,25092503,25393334,25730219,24487642,24487642,25092505,25393336,24178168,25147781,24212310,25778023,24238546,24548570,24492114,25429432,24495743,25919738,24497746,24497751,25920742,25722400,24577130,24577137,24577131,24577133,24577147,24577132,24577137,24577132,24577133,24577120,24577135,24577137,24577135,24577136,24577140,24577144,24577145,24577136,24577136,24577138,24577137,24577137,24577138,24577138,24577139,24577139,24577141,24577143,24577147,24577138,24577139,24577139,24577141,24577142,24577140,24717858,24717859,24827855,25415863,25960435,24717858,24717860,24827857,25623552,25960437,24577153,25623551,25623551,25960437,25623550,25960438,25960443,24577172,25960438,24827859,25623552,25623553,25960439,24717863,25347265,25898806,25960439,25960439,24827860,25016417,25623554,25960440,25960440,24717864,24577175,24717866,25623556,25623557,25960442,24827863,25623560,24717870,25626281,24577176,25960448,25960450,24717875,24717880,25960457,24688496,24688555,26016118,24688724,24688892,24773769,24758954,24758961,26051344,26051350,24793080,26068430,24858583,24858568,24858569,24858570,24858584,24858584,24858584,24858570,24858571,24858571,24858585,24858571,24858584,24858585,24858585,24858584,24858586,24858586,24858598,26101160,24858599,25764278,24968582,24968582,24968583,25258055,25440376,25454304,25463446,25463447,25463447,25491375,25529653,25556591,25556592,25608569,25612665,25615464,25764275,25764275,25764276,25764276,25764277,25764277,25764278,25764278,25764279,25802042,25802047,25862214,25877077,25898664,25898664,25902810,25902814,25902815,25902815,25967286,26101158,26101161,26101161,26101162,26101163,26101163,24926622,25798300,25078576,25078577,25078577,25078579,25078565,25078577,25078577,25078578,25078578,25078583,26008659,25312028,25550371,25597982,25666585,25666587,25874269,25874270,25874271,25874271,25874272,25874272,25874273,25874274,25907137,26008658,26012810,26012811,26211156,26211157,25874271,25874273,26211159,26211160,25321866,25429931,25377288,25377291,26360513,26360514,25455694,26062833,25462857,26403297,25537994,25597758,25545481,26107725,25624708,25939651,26484221,25657522,25657523,25657522,26163745,25928163,26163744,25814143,25941224,26380593,25901800,26285881,25931448,26293056,26022222,26346124,26348842,26484661,26683007,26683008,26050010,26050065,26050134,26494437,26068306,26068306,26068307,26068308,26068308,26068306,26068309,26068306,26068307,26068310,26068310,26369136,26507674,26706021,26369135,26369138,26706021,26369134,26706023,26369136,26507675,26507676,26706023,26507677,26706023,26706024,26092849,26117385,26117386,26117387,26393677,26393674,26393676,26393677,26532215,26532215,26730561,26124202,26733989,26198801,26226697,26200722,26573884,26254595,26254597,26254596,26254598,26254599,26462284,26462281,26799167,26272392,26462282,26462285,26462283,26290183,26816959,26358560,26358561,26358561,26851153,26851155,26366742,26366742,26366742,26366745,26366749,26366751,26855239,26518355,26855239,26656893,26855243,26372346,26659695,26376090,26661566,26583811,26963773,26654673,26999215,26669949,26669953,26669953,26669964,26669967,26669951,26669951,26669952,26669953,26669953,26669965,26669967,26669968,26669966,26669968,26669968,26669969,26669970,26669952,26669953,26669954,26669955,26669965,26669966,26669966,26669967,26669967,26669968,26669968,26669969,26669969,26669970,26669970,26669953,26669954,26669956,26669967,26669967,26669968,26669969,26669970,26669954,26669955,26669956,26669967,26669968,26669968,26669969,26669969,26669970,26669955,26669956,26669956,26669968,26669969,26669969,26669970,26669971,26669971,26669972,26669957,26669970,26669971,26669957,26669970,26669971,26669972,26669972,26669958,26669969,26669970,26669970,26669971,26669972,26669972,26669973,26669959,26669972,26669973,26669973,26669974,26669970,26669973,26669979,27006851,27006851,26669982,26669982,26808505,26669983,26808507,26984862,27006851,26669982,26669983,26669984,27006852,27006853,27006853,26669984,26669985,27006853,26669985,26804356,26808507,27006854,26669986,26669986,26672686,26672690,26804356,26808506,26808506,26808507,26808508,26814174,27006853,27006854,27006854,27006855,27006856,26669986,26669987,27006855,26669987,26669988,26669988,26672688,26702836,26707737,26804357,26808506,26808507,26808508,26808509,26808510,26808511,26814175,26916171,27006854,27006854,27006855,27006855,26669988,26804357,26804358,26808507,26808509,27006855,27006855,27006856,26808508,27006855,27006855,27006856,27006856,27631034,26743571,27006858,26675405,26675407,26675408,26675408,26675409,26675410,27009575,27009573,27009574,26811228,27009574,26724183,27033974,26735701,26735702,26837222,27039720,26745498,26745501,26745505,26745507,26910744,27044617,26846274,27044622,26771380,27057560,26817166,26882106,26865841,27104789,26895565,26895566,27119650,27119651,26938741,26938742,26938742,26938743,26938744,26938741,26938743,26938743,26938742,26938743,26938744,26938742,26942893,27079604,27141238,27141239,27141239,26942894,27141239,26942890,26942894,27141240,27141240,27141241,26942893,26942894,27141241,27141242,27141241,26947038,26947027,26947039,26947030,26947041,26947029,26947039,26947041,26947042,26947029,26947043,26947043,26947045,26947029,26947044,26947044,26947045,26947045,26947045,26947046,26947047,26947032,26947043,26947044,26947046,26947046,26947047,26947046,26947047,26947047,26947047,26947048,26947048,26947045,26947048,26947049,26947048,26997773,27145389,27145388,26947058,27145389,27145390,27145391,26947059,26947060,27145389,27145390,27145391,27145390,27145391,27145392,27145391,27145391,27145392,26947062,27102365,27145391,27145392,27145392,27145393,26947063,27083760,27145392,27145392,27040944,27145392,27145393,27145393,27145394,27145393,27145393,27145394,27145394,26958378,26958381,27151058,27151059,27151060,26961772,27152754,27048557,27196170,27075987,27075988,27075989,27209863,27209863,27134847,27239297,27162371,27253054,27220468,27220471,27282102,27282103,27282104,27257682,27300708,27299754,27321744,27343719,27343722,27343721,27343722,27343722,27343722,27343723,27343723,27343724,27343723,27343724,27343724,27343738,27343724,27343725,27343725,27343726,27343726,27343728,27343739,27343740,27343740,27343741,27343725,27343726,27343727,27343726,27343727,27343727,27343740,27343740,27343727,27343728,27343728,27343729,27343729,27343730,27343731,27343740,27343740,27343741,27343742,27343743,27343728,27343729,27343729,27343730,27343730,27343731,27343731,27343740,27343740,27343741,27343741,27343742,27343729,27343730,27343730,27343731,27343731,27343732,27343732,27343733,27343739,27343740,27343741,27343741,27343742,27343742,27343743,27343743,27343730,27343731,27343731,27343732,27343732,27343733,27343741,27343741,27343742,27343742,27343743,27343744,27343731,27343732,27343732,27343733,27343734,27343741,27343742,27343742,27343743,27343743,27343744,27343744,27343746,27343732,27343733,27343733,27343734,27343741,27343742,27343742,27343743,27343743,27343744,27343733,27343734,27343735,27343742,27343743,27343743,27343744,27343744,27343745,27343746,27343734,27343739,27343743,27343743,27343744,27343744,27343745,27343748,27343740,27343743,27343744,27343744,27343745,27343745,27343746,27343745,27343745,27343745,27343746,27343746,27343749,27343750,27343752,27343752,27343753,27343753,27343754,27343754,27969537,27343754,27343755,27343755,27343756,27343756,27343757,27967917,27343755,27343756,27343756,27343757,27343758,27343756,27343757,27343757,27343758,27343759,27648917,27678575,40272220,27343757,27343758,27343758,27343759,27343759,27343760,27967918,27967960,40272220,27343758,27343759,27343759,27343760,27343761,27343761,27343762,27969540,27972172,27343759,27343760,27343760,27343761,27343761,27343762,27343763,27473919,27967919,27967961,27967968,27967970,27969540,27970899,27972173,27343760,27343761,27343761,27343762,27343762,27343763,27343764,27967920,27967962,27967964,27969541,27343761,27343762,27343762,27343763,27343763,27343764,27343764,27351793,27678578,27894652,27894653,27918350,27967920,27967962,27967965,27969541,28645334,32086272,27343762,27343763,27343763,27343764,27343764,27343765,27343765,27473841,27819479,27894653,27894653,27967920,27967921,27967962,27967963,27967971,27967975,27969542,28645350,27343763,27343764,27343764,27343765,27343765,27343766,27404461,27473841,27738396,27918351,27967921,27967963,27967963,27967976,27969542,27970936,27972216,27343764,27343765,27343765,27343766,27343766,27678579,27854405,27894652,27894653,27894654,27967921,27967922,27967963,27967964,27967967,27967972,27970901,27343765,27343766,27343766,27343767,27435992,27456922,27473842,27648922,27678577,27678578,27678579,27678580,27886629,27894653,27894654,27894654,27894655,27967922,27967964,27967965,27967972,27967973,27969543,27343766,27343767,27343767,27678580,27894653,27894654,27894655,27894656,27967923,27967964,27967965,27967974,27969544,27343767,27343768,27343768,27436525,27456921,27456923,27648349,27678580,27678581,27678584,27886629,27894654,27894655,27894655,27894656,27926893,27967923,27967964,27967965,27967965,27967974,27969544,27970903,27970938,27970953,27343768,27343769,27343769,27343770,27408978,27456920,27456923,27473839,27482157,27485687,27512926,27648923,27678581,27678581,27714064,27718939,27886631,27894653,27894655,27894655,27894656,27894656,27894657,27967923,27967924,27967966,27967982,27967982,27969545,28645338,27343770,27456922,27484947,27678581,27678581,27678582,27894655,27894656,27967924,27967965,27967966,27967966,27456922,27678583,27967975,27678583,27967967,27967968,27359837,27726980,27465172,28028632,27474203,28033149,27528231,27528232,28060162,28060204,27529293,27741117,27570091,27570090,27570092,27570095,27570092,27570099,28081092,28081135,28081094,28081098,28081099,27603919,27603931,27603935,27604006,27604012,27604014,27604090,27604090,27604091,27604092,27604092,28024823,28098090,28098091,28098133,27620558,28106325,27626141,28109118,27627622,28109858,27682095,28138713,27952944,27952944,28272518,27954092,27954096,28191798,28273092,28273139,28013407,28013407,28013396,28013409,28013409,28013409,28013410,28013410,28013412,28013413,28302751,28302752,28013425,28221458,28229484,28229485,28302752,28302794,28302806,28305769,28302753,28084390,28338292,28094121,28094122,28094267,28113581,28094414,28269983,28133040,28133041,28362565,28329670,28295254,28443695,28365059,28478632,28429504,28429505,28429507,28429505,28429505,28437530,28510798,28510798,28510798,28510801,28445555,28445557,28445558,28445542,28445543,28445544,28445557,28445543,28445544,28445558,28445559,28445559,28445559,28445559,28445560,28445559,28445560,28445560,28445559,28445561,28518826,28518868,28445574,28445575,28518827,28518869,28445575,28518827,28518872,28445577,28465092,28518827,28518828,28518870,28518829,28484619,28538355,28492949,28493024,28493097,28542591,28544212,28510024,28510098,28510173,28551129,28526298,28559236,28592079,28592080,28592081,28592081,28592082,28592082,28592083,28592084,28592089,28592090,28592091,28592096,28592113,28592116,28592120,28592120,28592121,28592121,28592122,28592123,28592124,28592125,28592155,28592081,28592082,28592082,28592083,28592084,28592091,28592115,28592118,28592120,28592121,28592121,28592122,28592082,28592083,28592090,28592116,28592117,28592122,28592122,28592084,28592092,28592114,28592122,28592122,28592123,28592084,28592093,28592123,28592085,28592086,28592093,28592101,28592105,28592109,28592110,28592120,28592122,28592123,28592123,28592124,28592124,28592087,28592105,28592124,28592125,28592125,28592125,28592100,28592101,28592132,28592123,28592128,28592131,28592132,28592132,28592133,28592135,28592138,28592139,28592143,28592148,28592148,28592153,28592153,28592154,28592156,28592152,28592157,28592156,28592157,28592158,28592161,28592161,28592162,28592162,28592163,28592163,28592163,28592164,28592170,28592171,28592176,28592164,28592165,28592165,28592166,28592166,28592167,28592167,28592168,28592169,28592169,28592170,28592171,28592171,28592172,28592172,28592173,28592174,28592175,28592175,28592176,28592176,28592177,28592179,28592179,28592180,28592180,28592181,28592181,28592182,28592183,28592183,28592184,28592186,28592186,28592188,28592189,28592189,28592190,28592197,28592197,28592239,28592165,28592166,28592166,28592167,28592167,28592170,28592171,28592172,28592172,28592173,28592174,28592174,28592175,28592176,28592177,28592182,28592187,28592198,28592166,28592167,28592167,28592168,28592168,28592169,28592170,28592171,28592171,28592172,28592172,28592173,28592173,28592174,28592175,28592176,28592178,28592179,28592180,28592181,28592182,28592185,28592192,28592198,28592167,28592168,28592168,28592171,28592173,28592174,28592178,28592181,28592168,28592169,28592169,28592173,28592173,28592174,28592174,28592175,28592177,28592177,28592178,28592178,28592179,28592195,28592197,28592199,28592169,28592170,28592170,28592171,28592172,28592173,28592173,28592174,28592174,28592175,28592176,28592176,28592177,28592178,28592178,28592179,28592179,28592182,28592187,28592170,28592172,28592174,28592175,28592175,28592176,28592177,28592179,28592179,28592189,28592200,28592172,28592173,28592175,28592176,28592177,28592178,28592174,28592175,28592176,28592176,28592178,28592179,28592173,28592174,28592177,28592181,28592175,28592176,28592177,28592191,28592176,28592177,28592177,28592178,28592176,28592178,28592178,28592181,28592178,28592178,28592180,28592181,28592185,28592179,28592179,28592180,28592186,28592193,28592194,28592204,28592179,28592180,28592182,28592183,28592184,28592184,28592186,28592189,28592190,28592193,28592180,28592181,28592182,28592182,28592183,28592183,28592184,28592184,28592185,28592186,28592186,28592188,28592190,28592191,28592192,28592193,28592194,28592196,28592197,28592197,28592198,28592198,28592199,28592203,28592205,28592181,28592182,28592182,28592183,28592183,28592184,28592184,28592185,28592185,28592187,28592187,28592188,28592188,28592189,28592189,28592190,28592190,28592191,28592191,28592192,28592192,28592193,28592194,28592194,28592195,28592195,28592197,28592198,28592198,28592199,28592199,28592200,28592202,28592203,28592205,28592206,28592206,28592182,28592185,28592186,28592183,28592184,28592184,28592185,28592185,28592186,28592186,28592188,28592188,28592189,28592189,28592190,28592192,28592193,28592194,28592194,28592195,28592196,28592198,28592199,28592200,28592204,28592204,28592206,28592207,28592185,28592185,28592186,28592186,28592188,28592189,28592191,28592192,28592195,28592196,28592197,28592197,28592198,28592185,28592186,28592186,28592187,28592187,28592188,28592188,28592189,28592190,28592190,28592191,28592191,28592192,28592193,28592194,28592194,28592195,28592196,28592197,28592197,28592199,28592200,28592201,28592202,28592202,28592204,28592206,28592208,28592187,28592188,28592188,28592189,28592190,28592190,28592191,28592191,28592192,28592193,28592194,28592194,28592195,28592196,28592197,28592197,28592198,28592200,28592200,28592202,28592208,28592188,28592189,28592189,28592190,28592190,28592191,28592191,28592192,28592192,28592193,28592194,28592194,28592195,28592196,28592196,28592197,28592198,28592198,28592200,28592201,28592202,28592206,28592207,28592209,28592189,28592190,28592190,28592191,28592191,28592192,28592192,28592193,28592194,28592194,28592195,28592195,28592196,28592196,28592197,28592198,28592198,28592199,28592201,28592202,28592202,28592203,28592204,28592204,28592207,28592209,28592210,28592190,28592191,28592192,28592192,28592193,28592193,28592194,28592195,28592196,28592196,28592197,28592197,28592198,28592199,28592200,28592201,28592201,28592202,28592204,28592208,28592210,28592191,28592192,28592193,28592196,28592198,28592199,28592200,28592192,28592193,28592194,28592197,28592202,28592206,28592193,28592194,28592194,28592195,28592195,28592196,28592197,28592197,28592198,28592199,28592200,28592200,28592201,28592203,28592205,28592212,28592194,28592195,28592195,28592196,28592196,28592199,28592199,28592200,28592203,28592203,28592204,28592209,28592210,28592212,28592212,28592244,28593758,28592195,28592196,28592196,28592197,28592198,28592198,28592199,28592199,28592201,28592202,28592202,28592205,28592206,28592209,28592196,28592197,28592197,28592198,28592199,28592199,28592200,28592200,28592201,28592202,28592202,28592203,28592204,28592205,28592206,28592209,28592210,28592212,28592213,28592197,28592198,28592199,28592199,28592200,28592200,28592201,28592202,28592203,28592203,28592204,28592207,28592211,28592213,28592213,28592214,28592199,28592200,28592201,28592201,28592203,28592203,28592205,28592207,28592212,28592214,28592200,28592200,28592201,28592201,28592202,28592202,28592203,28592203,28592204,28592204,28592205,28592206,28592207,28592210,28592212,28592215,28593760,28596393,28592204,28592204,28592207,28592208,28592214,28592201,28592202,28592202,28592203,28592204,28592204,28592205,28592205,28592206,28592207,28592207,28592208,28592208,28592209,28592210,28592211,28592215,28592216,28593761,28592202,28592203,28592203,28592204,28592204,28592205,28592205,28592206,28592207,28592207,28592208,28592208,28592209,28592214,28592216,28593762,28592203,28592204,28592204,28592205,28592205,28592206,28592206,28592207,28592208,28592208,28592210,28592212,28592217,28593762,28592204,28592205,28592205,28592206,28592206,28592208,28592208,28592209,28592209,28592211,28592215,28592217,28592206,28592206,28592207,28592207,28592208,28592209,28592209,28592210,28592210,28592211,28592212,28592215,28592217,28592218,28592206,28592207,28592208,28592210,28592210,28592218,28592207,28592208,28592208,28592209,28592209,28592210,28592210,28592211,28592211,28592212,28592216,28592216,28592219,28592208,28592209,28592209,28592210,28592210,28592211,28592211,28592212,28592212,28592213,28592213,28592214,28592215,28592215,28592216,28592219,28592219,28592209,28592210,28592211,28592211,28592212,28592212,28592213,28592213,28592214,28592215,28592216,28592217,28592217,28592218,28592218,28592219,28592220,28593765,28592210,28592211,28592211,28592212,28592212,28592213,28592213,28592214,28592216,28592217,28592218,28592220,28592220,28592212,28592214,28592218,28592221,28592212,28592213,28592213,28592214,28592215,28592215,28592216,28592218,28592221,28592221,28593767,28592213,28592214,28592214,28592215,28592215,28592216,28592216,28592219,28592219,28592220,28592221,28592222,28592214,28592215,28592215,28592216,28592216,28592217,28592218,28592219,28592219,28592220,28592220,28592221,28592222,28592222,28592264,28593768,28595126,28592215,28592216,28592216,28592217,28592217,28592218,28592219,28592220,28592221,28592221,28592222,28592223,28593768,28592216,28592217,28592217,28592218,28592218,28592219,28592220,28592221,28592222,28592222,28592223,28592223,28592217,28592218,28592219,28592220,28592221,28592222,28592223,28592224,28593769,28592218,28592219,28592219,28592220,28592221,28592222,28592223,28592223,28592224,28592224,28592219,28592220,28592220,28592221,28592222,28592222,28592223,28592223,28592224,28592225,28592220,28592221,28592222,28592223,28592223,28592224,28592225,28592225,28592223,28592223,28592224,28592225,28592226,28593771,28592224,28592224,28592225,28592226,28592226,28592226,28592227,28592225,28592225,28592227,28592227,28593773,28593818,28592225,28592226,28592226,28592227,28592227,28592228,28592226,28592227,28592227,28592228,28592228,28592227,28592228,28592228,28592229,28592228,28592229,28592229,28592229,28592230,28592230,28592233,28592231,28592233,28592234,28592235,28592237,28592239,28592240,28592241,28592241,28592242,28592244,28592248,28592251,28592261,28592262,28592263,28592263,28592267,28592268,28592269,28592270,28592271,28592271,28592272,28592273,28593776,28593832,28595135,28595170,28595190,28596450,29269569,29269569,29269570,32176264,32710507,28592232,28592233,28592233,28592234,28592234,28592235,28592236,28592236,28592237,28592238,28592239,28592240,28592240,28592241,28592241,28592242,28592242,28592243,28592243,28592244,28592244,28592245,28592245,28592247,28592248,28592249,28592249,28592252,28592252,28592253,28592254,28592255,28592255,28592256,28592257,28592258,28592258,28592259,28592261,28592261,28592263,28592263,28592264,28592264,28592267,28592267,28592268,28592268,28592269,28592270,28592271,28592271,28592272,28592272,28592273,28592273,29269570,28592234,28592237,28592238,28592240,28592243,28592244,28592247,28592255,28592269,28592272,28592272,28592273,28592273,28592274,28592237,28592264,28592267,28592269,28592241,28592243,28592274,28592275,28592236,28592238,28592239,28592242,28592243,28592247,28592247,28592266,28592269,28592273,28592274,28592275,28592275,28593779,28592261,28592270,28592275,28592242,28592276,28592251,28592275,28592276,28592276,28592277,28592241,28592245,28592246,28592273,28592246,28592247,28592249,28592250,28592252,28592254,28592258,28592245,28592278,28593782,28592278,28592247,28592247,28592280,28592270,28592248,28592249,28592253,28592265,28592270,28592273,28592279,28592280,28592280,28592251,28592253,28592254,28592255,28592255,28592261,28592280,28592281,28592253,28592255,28592256,28592256,28592280,28592257,28592273,28592273,28592277,28592281,28593786,28592254,28592255,28592256,28592257,28592273,28592281,28592281,28592282,28592283,28592279,28592284,28592254,28592277,28592279,28592282,28592284,28592284,28592256,28592258,28592280,28592257,28592280,28592283,28592284,28592285,28592257,28592284,28593789,28592260,28592260,28592262,28592264,28592266,28592267,28592271,28592277,28592284,28592284,28592285,28592286,28592286,34170661,28592282,28592284,28592283,28592285,28592261,28592286,28592265,28592271,28592278,28592279,28592283,28592286,28592286,28592287,28592288,28592272,28592289,28592284,28592288,28592290,28592268,28592280,28592276,28592286,28592291,28592287,28592288,28592291,28592284,28592293,28592288,28592288,28592291,28592294,28592292,28592291,28592295,28592296,28592286,28592295,28592297,28592296,28592294,28592296,28592297,28592299,28592299,28592285,28592297,28592290,28592296,28592299,28592299,28592292,28592293,28592293,28592302,28592294,28592303,28592304,28592295,28592296,28592296,28592298,28592301,28592301,28592303,28592304,28592304,28592305,28592299,28592300,28592303,28592305,28592305,28592302,28592303,28592304,28592304,28592304,28592305,28592307,28592307,28592305,28592308,28592305,28592307,28592307,28592308,28592308,28592306,28592308,28592309,28593813,28592305,28592306,28592306,28592307,28592308,28592308,28592309,28592309,28592310,28592306,28592307,28592308,28592308,28592307,28592309,28592310,28592311,28592309,28592309,28592310,28592310,28592311,28592311,28592309,28592310,28592310,28592311,28592310,28592311,28592311,28592312,28592312,28593861,28592311,28592312,28592312,28592313,28592312,28592313,28592313,28592313,28592314,28592314,28592315,28592316,28592331,28593818,28593818,28593835,28593863,28593869,28593873,28593929,28595177,28595212,28595213,28595227,28596451,28596492,29269629,29269630,31107124,28592331,28593819,28593819,28593834,28595321,28595322,28595323,28595323,28595324,28595325,28595326,28595332,28595333,28595334,28595343,28595344,28595347,28595357,28595358,28595361,28595364,28595364,28595365,28595366,28595366,28595367,28595367,28595367,28595368,28595368,28595368,28595369,28595369,28595370,28595369,28595371,28595377,28595377,28595378,29271146,28595387,28595383,28595385,28595386,28595388,28595389,28595392,28595402,28595403,28595406,28595409,28595409,28595410,28595410,28595411,28595411,28595412,28595413,28595413,28595414,28595414,28595415,28595416,28595416,28595417,28595418,28595418,28595419,28595419,28595420,28595420,28595421,28595421,28595422,28595422,28595423,28595424,28595424,28595425,28595426,28595426,28595427,28595427,28595429,28595430,28595431,28595431,28595432,28595432,28595433,28595433,28595434,28595435,28595436,28595436,28595437,28595438,28595438,28595439,28595439,28595440,28595442,28595442,28595413,28595420,28595439,28595443,28595415,28595423,28595438,28595443,28595415,28595416,28595418,28595430,28595444,28595417,28595422,28595423,28595424,28595427,28595431,28595434,28595444,28595419,28595420,28595421,28595422,28595423,28595424,28595431,28595435,28595439,28595439,28595441,28595441,28595442,28595443,28595445,28595439,28595446,28595420,28595423,28595434,28595435,28595440,28595446,28595422,28595423,28595424,28595427,28595429,28595441,28595442,28595443,28595443,28595444,28595446,28595447,28595425,28595426,28595427,28595427,28595428,28595429,28595432,28595435,28595439,28595440,28595440,28595441,28595442,28595442,28595443,28595443,28595444,28595444,28595445,28595447,28595448,28595448,28595426,28595431,28595433,28595443,28595449,28595427,28595429,28595443,28595444,28595445,28595449,28595440,28595441,28595444,28595450,28595428,28595429,28595430,28595438,28595439,28595442,28595444,28595444,28595445,28595446,28595446,28595450,28595450,28595429,28595430,28595432,28595443,28595443,28595444,28595445,28595446,28595449,28595451,28595433,28595443,28595451,28595431,28595434,28595435,28595442,28595444,28595446,28595451,28595452,28595432,28595433,28595435,28595448,28595452,28595438,28595441,28595444,28595444,28595446,28595449,28595453,28595443,28595446,28595448,28595453,28595446,28595447,28595448,28595454,28595454,28595454,28595455,28595438,28595442,28595445,28595446,28595447,28595452,28595453,28595455,28595456,28595447,28595456,28595447,28595452,28595457,28595451,28595458,28595458,28595459,28595459,28595448,28595451,28595453,28595456,28595460,28595460,28595451,28595461,28595461,28595462,28596745,28595453,28595462,28595462,28595457,28595458,28595463,28595459,28595459,28595460,28595464,28595460,28595462,28595464,28595459,28595461,28595465,28595460,28595465,29280057,28595466,28595462,28595466,28595462,28595462,28595463,28595463,28595464,28595464,28595467,28595467,28595463,28595468,28595465,28595468,28595468,28595466,28595469,28595466,28595469,28595469,28595470,28595470,28595470,28595471,28595471,28595472,28595473,28595474,28595474,28595475,28595476,28595477,28595477,28595478,28595479,28595481,28595481,28595482,28595484,28595484,28595485,28595486,28595486,28595488,28595488,28595490,28595491,28595492,28595494,28595498,28595499,28595501,28595504,28595505,28595506,28595507,28595508,28595509,28595511,28595511,28595512,28595512,28595513,28595514,28595514,28595515,28595515,28595516,28595516,28595517,28595517,28595518,28596756,28596791,28596806,28598030,28598071,29271190,28595474,28595475,28595476,28595477,28595479,28595479,28595480,28595480,28595481,28595484,28595485,28595486,28595487,28595490,28595491,28595492,28595494,28595496,28595499,28595500,28595507,28595511,28595512,28595513,28595514,28595514,28595515,28595516,28595516,28595517,28595517,28595518,28595475,28595485,28595497,28595501,28595502,28595512,28595517,28595519,28595516,28595518,28595519,28595496,28595516,28595519,28595517,28595522,28595521,28595522,28595524,28595495,28595525,28595521,28595525,28595523,28595501,28595528,28595522,28595524,28595528,28595528,28598082,28595529,28595530,28595509,28595526,28595528,28595529,28595530,28595531,28595532,28595529,28595508,28595533,28595531,28595534,28595531,28595535,28595536,28595527,28595526,28595534,28595538,28595540,28595541,28595536,28595541,28595543,28595542,28595543,28595544,28595531,28595545,28595548,28595549,28595541,28595546,28595549,28595550,28595551,28595545,28595552,28595548,28595551,28595552,28595553,28595553,28595548,28595553,28595554,28595556,28595554,28595555,28595556,28595554,28595555,28595554,28595556,28595556,28595557,28595554,28595555,28595556,28595557,28595558,28596796,28595557,28595558,28595556,28595557,28595558,28595558,28595559,28595560,28595559,28595559,28595560,28595560,28595559,28595560,28595561,28595560,28595561,28595561,28595562,28595562,28595563,28595567,28595600,28595600,28596798,28596800,28596801,28596802,28596805,28596818,28596823,28596835,28596836,28596841,28596851,28596858,28596858,28598075,28598116,28598130,28598130,29271234,29271235,29271235,29271236,29271240,29271253,32712172,32712173,40898123,28596801,28596805,28595706,28595704,28595706,28595707,28595773,28596907,28596908,28598036,28598070,28598038,28598039,28598040,28598040,28598041,28598041,28598043,28598044,28598044,28598046,28598048,28598055,28598056,28598060,28598062,28598064,28598068,28598070,28598071,28598071,28598072,28598072,28598073,28598073,28598074,28598043,28598052,28598073,28598074,28598074,28598041,28598074,28598075,28598044,28598075,28598075,28598076,28598076,28598047,28598048,28598050,28598052,28598073,28598077,28598077,28598078,28598052,28598078,28598078,28598079,28598080,28598080,28598082,28598083,28598087,28598089,28598085,28598091,28598095,28598096,28598097,28598099,28598103,28598103,28598103,28598104,28598105,28598106,28598107,28598107,28598107,28598107,28598108,28598108,28598111,28598118,28598123,28598125,28598127,28598128,28598129,28598130,28598131,28598145,28598146,28598149,28598149,28598109,28598110,28598110,28598111,28598111,28598112,28598112,28598113,28598114,28598114,28598115,28598116,28598117,28598118,28598118,28598119,28598120,28598120,28598121,28598121,28598122,28598123,28598123,28598124,28598124,28598126,28598126,28598127,28598128,28598128,28598129,28598129,28598130,28598130,28598131,28598131,28598132,28598132,28598133,28598134,28598136,28598137,28598140,28598142,28598143,28598145,28598146,28598147,28598149,28598149,28598150,28598110,28598111,28598111,28598112,28598114,28598117,28598119,28598119,28598121,28598122,28598123,28598124,28598124,28598130,28598131,28598132,28598132,28598134,28598146,28598148,28598149,28598150,28598111,28598119,28598125,28598135,28598150,28598150,28598122,28598125,28598125,28598130,28598151,28598114,28598117,28598125,28598126,28598130,28598137,28598116,28598122,28598125,28598126,28598126,28598133,28598124,28598126,28598131,28598132,28598152,28598146,28598128,28598133,28598149,28598126,28598129,28598130,28598134,28598154,28598154,28598134,28598130,28598139,28598132,28598132,28598154,28598158,28598133,28598138,28598133,28598134,28598159,28598135,28598143,28598134,28598135,28598135,28598135,28598136,28598141,28598161,28598136,28598136,28598141,28598144,28598137,28598139,28598144,28598138,28598143,28598138,28598142,28598143,28598145,28598150,28598158,28598160,28598164,28598139,28598140,28598141,28598141,28598142,28598142,28598143,28598143,28598144,28598144,28598145,28598145,28598146,28598146,28598147,28598147,28598149,28598149,28598150,28598150,28598151,28598151,28598152,28598153,28598153,28598154,28598155,28598156,28598158,28598159,28598160,28598161,28598161,28598162,28598162,28598163,28598164,28598164,28598165,28598140,28598141,28598144,28598145,28598165,28598145,28598165,28598142,28598145,28598145,28598146,28598151,28598160,28598163,28598166,28598145,28598146,28598147,28598149,28598152,28598153,28598164,28598167,28598167,28598146,28598163,28598167,28598148,28598150,28598151,28598154,28598168,28598147,28598148,28598148,28598149,28598150,28598151,28598153,28598154,28598163,28598164,28598165,28598167,28598168,28598148,28598149,28598149,28598150,28598150,28598151,28598151,28598152,28598153,28598154,28598159,28598163,28598164,28598165,28598168,28598169,28598169,28598149,28598150,28598150,28598151,28598151,28598152,28598152,28598154,28598155,28598156,28598156,28598157,28598160,28598165,28598166,28598169,28598169,28598150,28598151,28598151,28598152,28598152,28598155,28598156,28598156,28598166,28598167,28598170,28598170,32713466,28598151,28598152,28598153,28598154,28598155,28598156,28598166,28598167,28598170,28598171,28598153,28598153,28598154,28598155,28598167,28598170,28598171,28598153,28598154,28598156,28598156,28598158,28598163,28598165,28598167,28598171,28598171,28598154,28598155,28598156,28598157,28598157,28598158,28598159,28598159,28598163,28598164,28598167,28598168,28598168,28598171,28598172,28598157,28598157,28598158,28598158,28598159,28598159,28598160,28598162,28598165,28598166,28598167,28598168,28598168,28598170,28598171,28598172,28598172,28598173,28598158,28598159,28598173,28598159,28598163,28598167,28598169,28598173,28598170,28598159,28598168,28598169,28598170,28598172,28598174,28598160,28598161,28598161,28598162,28598162,28598169,28598171,28598172,28598172,28598174,28598174,28598175,28598161,28598162,28598168,28598168,28598171,28598172,28598175,28598175,28598162,28598163,28598163,28598172,28598175,28598176,28598163,28598165,28598171,28598172,28598174,28598176,28598176,28598165,28598166,28598171,28598172,28598173,28598173,28598176,28598177,28598173,28598177,28598177,28598178,28598174,28598178,28598176,28598179,28598175,28598180,28598176,28598179,28598181,28598181,28598178,28598182,28598182,28598181,28598183,28598183,28598177,28598183,28598180,28598184,28598184,28598179,28598184,28598184,28598185,28598185,28598181,28598185,28598183,28598183,28598184,28598184,28598185,28598186,29272565,28598186,28598186,28598187,28598185,28598186,28598187,28598185,28598187,28598222,28598187,28598188,28598188,28598189,28598189,28598190,28598224,28599388,28598190,28598191,28598191,28598192,28598192,28598193,28598194,28598195,28598196,28598196,28598197,28598197,28598198,28598198,28598204,28598205,28598207,28598208,28598210,28598215,28598215,28598218,28598219,28598221,28598222,28598222,28598223,28598223,28598224,28598224,28598225,28599388,28599429,28599432,28599438,28599443,28893661,29272549,29272564,29272566,29272566,29272569,31447746,32179243,32713486,28598191,28598192,28598192,28598193,28598193,28598194,28598195,28598196,28598196,28598197,28598200,28598201,28598203,28598204,28598217,28598220,28598221,28598222,28598222,28598223,28598223,28598224,28598224,28598225,28598225,28598192,28598194,28598195,28598195,28598223,28598226,28598226,28598196,28598198,28598201,28598226,28598227,29272557,28598197,28598199,28598227,28598228,28598197,28598228,28598219,28598229,28598212,28598228,28598229,28599393,28598204,28598230,28598227,28598229,28598207,28598221,28598231,28599394,28598229,28598231,28598231,28598232,28598232,28598233,28598233,28598233,28598234,28598235,28598235,28598236,28598238,28598239,28598240,28598241,28598243,28598245,28598250,28598250,28598251,28598253,28598254,28598255,28598256,28598256,28598257,28598257,28598258,28598258,28598259,28599422,28598259,28598260,28598261,28599423,28599423,28599464,28599474,28599475,28599476,28599476,28599478,28754922,28985833,29272582,29272583,29272583,29272584,29272587,29272590,29272593,29272598,29272598,29272599,29272600,29272601,29272604,29281458,30173848,30173850,32179278,32456566,32713520,32713521,35142721,40899472,28599424,28599424,28600586,28600587,28600588,28600588,28600590,28600598,28600619,28600621,28600622,28600622,28600625,28600626,28600627,28600627,28600628,28600662,28600627,28600628,28600628,28600628,28600629,28600631,28600631,28600639,28600660,28600662,28600663,28600663,28600666,28600666,28600667,28600667,28600667,28600668,28600668,28600703,28600669,28600670,28600670,28600671,28600671,28600672,28600672,28600673,28600674,28600675,28600675,28600676,28600676,28600677,28600677,28600678,28600678,28600679,28600679,28600680,28600680,28600681,28600681,28600682,28600682,28600683,28600683,28600684,28600684,28600686,28600686,28600687,28600688,28600688,28600690,28600691,28600692,28600693,28600695,28600696,28600697,28600700,28600701,28600701,28600702,28600703,28600703,28600672,28600673,28600703,28600704,28600679,28600684,28600680,28600680,28600705,28600675,28600675,28600675,28600678,28600682,28600683,28600683,28600687,28600706,28600680,28600681,28600691,28600694,28600681,28600707,28600681,28600683,28600685,28600707,28600682,28600682,28600700,28600708,28600684,28600685,28600685,28600702,28600702,28600711,28600686,28600688,28600711,28600686,28600687,28600687,28600688,28600688,28600689,28600689,28600690,28600691,28600691,28600694,28600696,28600702,28600703,28600704,28600705,28600709,28600712,28600687,28600690,28600691,28600700,28600704,28600705,28600706,28600712,28600688,28600689,28600689,28600690,28600690,28600691,28600692,28600700,28600701,28600702,28600703,28600704,28600705,28600706,28600706,28600710,28600711,28600713,28600689,28600690,28600691,28600691,28600692,28600693,28600696,28600698,28600702,28600702,28600703,28600705,28600705,28600709,28600711,28600713,28600713,28600690,28600692,28600692,28600698,28600701,28600705,28600706,28600707,28600711,28600714,28600691,28600692,28600694,28600699,28600701,28600703,28600703,28600705,28600706,28600707,28600712,28600714,28600692,28600693,28600702,28600703,28600704,28600707,28600709,28600710,28600713,28600715,28600694,28600694,28600695,28600698,28600700,28600702,28600703,28600704,28600704,28600705,28600706,28600707,28600707,28600713,28600715,28600697,28600704,28600705,28600709,28600716,28600696,28600699,28600703,28600705,28600715,28600716,28600696,28600704,28600708,28600717,28600697,28600700,28600700,28600702,28600703,28600705,28600706,28600710,28600717,28600718,28600706,28600708,28600709,28600718,28600718,28600702,28600711,28600719,28600711,28600707,28600703,28600705,28600709,28600720,28600705,28600706,28600710,28600717,28600719,28600720,28600721,32180500,28600722,28600715,28600722,28600716,28600723,28600723,28600714,28600717,28600725,28600714,28600717,28600725,29273809,28600716,28600717,28600718,28600720,28600726,28600719,28600727,28600719,28600720,28600721,28600727,28600720,28600726,28600728,28600725,28600729,28600721,28600722,28600727,28600727,28600729,28600722,28600723,28600726,28600729,28600730,28600730,28600726,28600729,28600730,28600731,28600731,28600732,29273817,28600733,28600733,28600734,28600734,28600735,28600735,32714758,28600735,28600736,28600736,28600737,28600737,28600738,28600739,28600739,28600740,28600741,28600741,28600742,28600743,28600744,28600744,28600745,28600745,28600746,28600747,28600749,28600751,28600752,28600753,28600755,28600757,28600758,28600760,28600762,28600767,28600770,28600773,28600775,28600775,28600776,28600776,28600777,28600777,28600778,28600778,28600779,29273820,29273821,29273822,29273822,29273823,29273823,29273841,29273843,29273843,29273845,29282698,30028615,30175087,31469836,32180518,32259696,32714760,40900711,28600739,28600740,28600741,28600746,28600748,28600749,28600750,28600752,28600763,28600773,28600777,28600778,28600778,28600779,28600779,32695910,28600780,28600780,28756163,28600745,28600773,28600781,28600781,28600782,28600783,28600784,28600785,28600785,28600786,28600785,28600786,28600764,28600787,28600760,28600776,28600786,28600790,28600790,28600792,28600776,28600793,28600768,28600794,28600796,28600797,28600798,28600799,28600801,28600803,28600804,28600807,28600808,28600810,28600811,28600814,29273859,28600816,28600817,28600817,28600818,28600818,28600819,32714799,28600819,28600820,28634386,28636154,28704207,28745364,28756202,28786793,28830440,28894116,28894975,28904684,28977629,29015781,29016605,29273860,29273861,29273861,29273862,29273862,29273863,29273863,29273864,29273864,29273865,29273865,29273866,29273867,29273867,29273868,29273869,29273869,29273870,29273871,29273873,29273879,29273879,29273881,29273882,29273882,29273883,29273883,29273884,29273884,29273885,29273885,29273886,29273886,29273887,29273891,29282737,29282738,29282739,29282740,29338960,29394356,29483639,29489894,29499346,30030487,30175127,30175128,30175130,30175130,30175132,31068971,31332930,31469876,32180535,32180537,32180546,32180557,32180558,32442611,32714800,32714801,34464370,35105041,35144018,29273863,29273864,29273874,28667969,29307448,28671499,30210472,28807606,29377261,28889924,29418426,28911598,28911599,29429256,29429257,29429258,29429259,29429259,29429262,29429263,28972779,29459869,29060081,29060157,29060228,29503575,29187463,29567210,29189145,29189146,29568033,29568033,29208558,29577738,29354453,29650686,29650691,29373418,29660168,29430755,29430833,29688837,29430909,29688913,29432424,29689683,29946902,29946903,29946904,29946903,29946905,29946919,29946904,29946905,29946906,29946904,29946905,29946905,29946906,29946906,29946907,29946909,29946911,29946918,29946919,29946922,29946924,29946905,29946906,29946906,29946907,29946907,29946909,29946910,29946911,29946911,29946917,29946919,29946920,29946920,29946921,29946922,29946923,29946923,29946924,29946924,29946906,29946907,29946907,29946908,29946910,29946911,29946913,29946914,29946920,29946920,29946921,29946921,29946922,29946922,29946923,29946923,29946924,29946924,29946925,29946928,29946907,29946908,29946908,29946910,29946910,29946912,29946912,29946913,29946918,29946920,29946921,29946922,29946922,29946923,29946923,29946924,29946924,29946925,29946925,29946908,29946909,29946909,29946910,29946911,29946912,29946913,29946914,29946914,29946920,29946920,29946921,29946921,29946922,29946922,29946923,29946923,29946924,29946924,29946925,29946925,29946926,29946927,29946931,29946909,29946911,29946911,29946913,29946914,29946915,29946921,29946922,29946922,29946923,29946924,29946924,29946925,29946925,29946926,29946928,29946911,29946912,29946915,29946915,29946916,29946922,29946923,29946925,29946925,29946926,29946927,29946931,29946914,29946923,29946924,29946928,29946934,29946913,29946915,29946916,29946926,29946915,29946916,29946916,29946917,29946917,29946919,29946923,29946924,29946925,29946926,29946926,29946927,29946927,29946928,29946928,29946929,29946931,29946932,29946932,29946935,29946948,29946948,29946949,29946916,29946916,29946932,29946929,29946918,29946918,29946919,29946926,29946928,29946929,29946932,29946932,29946950,29946919,29946919,29946926,29946928,29946929,29946932,29946933,29946935,29946950,29946920,29946928,29946928,29946929,29946933,29946935,29946936,29946920,29946921,29946921,29946922,29946924,29946925,29946926,29946926,29946927,29946928,29946928,29946929,29946929,29946930,29946930,29946931,29946931,29946936,29946951,29946921,29946924,29946927,29946928,29946929,29946931,29946935,29946952,29946927,29946930,29946932,29946952,29946930,29946931,29946934,29946933,29946955,29946928,29946931,29946955,29946933,29946934,29946936,30848183,29946937,29946938,29946936,29946938,29946934,29946934,29946935,29946936,29946936,29946937,29946937,29946938,29946940,29946940,29946942,29946935,29946936,29946937,29955795,30848185,33387858,29946935,29946936,29946936,29946937,29946937,29946940,29946942,29946943,29946936,29946937,29946937,29946938,29946938,29946939,29946939,29946940,29946943,30848186,29946937,29946938,29946938,29946939,29946939,29946940,29946941,29946942,29946943,29946944,30240280,30564866,30848186,32142934,33387859,33387860,29946938,29946939,29946939,29946940,29946940,29946941,29946942,29946943,29946944,29946945,29955797,29955807,30848187,32853617,33387859,33387860,29946939,29946940,29946940,29946941,29946942,29946942,29946943,29946944,29946944,29946946,29946946,29946960,29946961,29955806,30848187,30848191,32126777,33387860,33387861,29946940,29946941,29946941,29946942,29946942,29946943,29946943,29946944,29946944,29946945,29946946,29946947,29946961,29946961,29955798,29955799,30848188,31784436,32142936,32853618,32853619,33387860,33387861,29946941,29946942,29946942,29946943,29946943,29946944,29946944,29946945,29946946,29946946,29946947,29946947,29946948,29946961,29946962,29946962,30012020,30067413,30848188,31618223,32122665,32853617,32853618,32853619,33115673,33387862,29946942,29946943,29946943,29946944,29946945,29946946,29946946,29946947,29946947,29946962,29946963,30012021,30848189,30848193,33387861,33387862,29946943,29946944,29946944,29946945,29946945,29946946,29946947,29946948,29946948,29946949,29946950,29946955,29946963,29946963,30067418,30848189,32122120,33387863,29946944,29946945,29946945,29946946,29946946,29946947,29946947,29946948,29946963,29946963,30848189,30848190,32853621,33387862,33387863,38075674,29946945,29946946,29946946,29946947,29946947,29946948,29946948,29946949,29946950,29946964,29946964,30848190,30848194,29946946,29946947,29946947,29946948,29946949,29946950,29946956,29946964,29946964,29946965,30848191,33387864,29946947,29946948,29946948,29946949,29946949,29946950,29946950,29946952,29946964,29946965,29946965,30565320,30848191,31820867,29946948,29946949,29946949,29946950,29946950,29946951,29946951,29946953,29946965,29946965,29946966,29946967,30848192,29946949,29946950,29946950,29946951,29946951,29946952,29946965,29946966,29946966,29946950,29946951,29946951,29946952,29946954,29946954,29946966,29946966,29946967,30848193,29946951,29946952,29946952,29946965,29946966,29946967,29946967,29946952,29946965,29946967,29946967,29946968,33387866,29946953,29946954,29946954,29946955,29946956,29946963,29946967,29946967,29946968,29946968,29946954,29946955,29946966,29946968,29946968,29946969,30848195,33387867,29946968,29946969,29946969,29946969,29946970,29946970,29946970,29946971,33387869,29946970,29946971,29946972,29946974,29946975,29946975,29946978,29946981,33387880,29946982,29946982,29946983,30067437,31784456,33387881,33387882,35137451,29946983,29946984,29946984,29955819,29955820,29955820,29955825,29955831,29975327,30012041,30067433,30848208,30848209,30848209,30848211,30848212,31110263,31260546,31579454,31618247,31784457,31784458,32416540,32853636,32853637,32853638,32853639,32853639,32853640,33352290,33387882,33387883,29946984,29946985,29955817,29955819,29955819,29955820,29955820,29955821,29955822,29955822,29955823,29955824,29955829,29955830,29958280,29981429,30012042,30031275,30067436,30162976,30202130,30347865,30577783,30593460,30685013,30710119,30848208,30848209,30848209,30848210,30848210,30848211,30848212,30848212,30848213,30848213,30848214,31077862,31486117,31742053,32045539,32102233,32126799,32356483,32356485,32438151,32853617,32853619,32853620,32853620,32853630,32853633,32853634,32853636,32853637,32853637,32853638,32853639,32853639,32853640,32853640,32853641,32853642,33130928,33387882,33387883,33387883,29946985,29955819,29955820,29955821,29955821,30067438,30848210,30848214,32122142,32206175,32853634,32853638,33387883,29955821,30090639,30569568,30848210,30848211,30848212,31486118,31618247,32122142,32853640,33387883,29964672,29964656,29964674,29964656,29964673,29964674,29964671,29964672,29964672,29964673,29964674,29964675,29964657,29964672,29964672,29964673,29964673,29964674,29964674,29964675,29964675,29964678,29964663,29964673,29964674,29964674,29964675,29964675,29964676,29964677,29964683,29964684,29964684,29964685,29964686,29964687,29964682,29964690,29964691,29964692,29964694,29964694,29964690,30857066,32862493,30857062,32124649,29964689,30076288,30857061,30857062,30857066,32862492,33396735,33396736,31046608,32862491,32862494,33396735,29964694,30857063,32135653,32862493,32862494,32862494,33396736,30857063,30857064,30857066,32862489,33370017,33396736,33396737,30857064,31793309,33396737,30857064,30857065,33396737,32862492,29964701,30857066,33396738,33396739,33396739,30857070,30857073,30857071,30857071,31793317,32124658,33396744,30010131,32862500,33396744,33396745,32862482,30857073,29969589,31629557,30003682,30876564,30015886,30882667,30055556,30055572,30055590,30739319,30077109,30077110,30077112,30077113,30077236,30077236,32918708,33452953,30913281,30077362,30077363,30913404,32918831,32918835,30115575,30932511,30187899,30187905,30187902,30187890,30187907,30187905,30187908,30187911,30968674,30187921,30968676,30968679,30968684,33177276,33508352,33508353,30968681,30234303,30578240,30366468,30366528,30366587,33597689,30378984,31064217,31064219,30397883,33613338,30457303,32039631,30533646,31658455,30748757,31111011,31978896,30922177,31335812,31182857,31182932,31182947,31183004,31466247,31183704,31466575,31192171,31470816,31208607,31208737,31208853,34018822,31239953,33500130,31423055,31423056,32853840,34125924,31456502,31456513,34142648,31460169,34144482,31473266,31473267,31611360,34151030,31749434,31749434,31749438,31749448,31749450,31749434,31749435,31749439,31749439,31749449,31749452,31749453,31749454,31749435,31749436,31749451,31749451,31749452,31749453,31749453,31749454,31749455,31749436,31749437,31749438,31749439,31749440,31749450,31749451,31749451,31749452,31749452,31749453,31749453,31749454,31749454,31749455,31749455,31749456,31749438,31749454,31749455,31749455,31749441,31749440,31749452,31749453,31749454,31749457,31749441,31749457,31749458,31749442,31749453,31749454,31749455,31749458,31749458,31749460,31749454,31749459,31749444,31749455,31749455,31749457,31749458,31749459,31749460,31749457,31749460,31749461,34016935,31749467,31749468,34289123,31749466,31749468,31749468,31749469,31749469,31749470,31749471,31979103,32685698,32946783,33023384,33044199,33107416,33754878,33754881,33951592,34289123,34289124,31749467,31749469,31749469,31749471,32519487,32555492,32685700,33023384,33754862,33754882,34289124,34289125,31749469,31749470,31749470,33754878,33754882,34289124,34289125,34672251,31749469,31749470,31749471,31749472,32685698,33754864,31749470,31749471,31749472,31749472,33754859,33754882,34289125,34289126,31749471,31749472,31749472,31749473,31749473,32198290,32643297,32657869,33754861,33754863,33754865,33754880,33754883,33754884,33834060,34289126,34289127,31749473,31749473,31749474,32685701,33754869,33754873,33754878,33754879,33754880,33754884,33754886,34289126,34289126,34289127,31749473,31749474,31785216,32224440,32643297,32643298,32685699,32685702,33044202,33339395,33754862,33754864,33754865,33754882,33754883,33754884,33834060,34289127,34289128,31749474,33004115,33754885,34289127,34289128,31749475,31749476,31755760,31785209,31979108,32387362,32387363,32435720,32519491,32685703,32685703,32685704,32685705,33029592,33044203,33754862,33754863,33754864,33754864,33754865,33754865,33754867,33754871,33754876,33754881,33754882,33754882,33754883,33754883,33754884,33754884,33754885,33754886,33754886,34016940,34016940,34289128,34289129,33257729,33754866,33754883,33754885,33754885,33754886,33834062,34289128,34289129,33339397,33754885,32685704,31762062,34295429,31820959,31820971,34324877,32721457,32128546,32152082,32175618,34502209,32208753,33246686,33984531,34518773,32273567,32273618,34016969,32574125,33098038,32647183,32678359,32699420,34764107,32709537,32999560,32783247,32783294,32783365,34090627,33025265,33025265,33025264,33025266,34392788,34392787,34927031,33121979,34441142,33209035,33249279,33211934,34486116,33289521,33289522,33289522,33289523,33289523,33289523,33289524,33455732,34524916,34524895,34524915,34524916,35059159,33361527,35095159,33537134,33537135,33537135,34648724,34727899,35182964,35182965,33566279,34663291,33621941,33621941,33621943,33621944,33621945,33621946,33621946,33621948,33621945,33621947,33621946,33621946,33621948,33621948,33621948,33621952,34691114,35225370,34691124,34691126,34691127,35225371,34691127,33926988,34043663,34691108,35225371,34691129,35225371,35225372,34691129,34193975,34691126,33694800,34727553,34065053,35446924,34144111,34144113,34952211,35486454,34232025,34232151,34232276,35530534,34257495,35543144,34258766,35543778,34284623,34284624,34284624,34284625,35022446,35284521,35556709,35556710,34297314,34297314,34297316,34297317,34297317,35028812,34769280,35028814,35563057,34298440,34298511,34298606,35563730,34306627,34306627,35033467,35033468,35567710,34309722,35035016,34338943,34338932,34338943,34338944,34338944,34338944,35049624,35583869,35258989,34465377,35112843,35146033,35192019,34765994,34765998,34766001,34766001,35797393,35797397,35797398,35263153,34886108,35323208,34929333,34929334,35344799,35344822,35344818,35241243,36035020,35397878,35397951,35398028,35579173,35760287,35760266,35760253,35760266,35760269,35760270,35760271,35760272,35760270,35760285,35760287,35760255,35760266,35760269,35760271,35760271,35760272,35760276,35760290,35760291,35760271,35760274,35760274,35760276,35760291,35760270,35760291,35760292,35760278,35760292,35760297,35760278,35760285,35760299,35760301,35760302,35760287,35760287,35760286,35969651,35760284,35760305,35760287,35760290,35760286,35760289,35760290,35760289,35760291,35760291,35760306,35760291,35760292,35760306,35760307,35760308,35760289,35760289,35760291,35760291,35760293,35760307,35760291,35760292,35760293,35760308,35760291,35760292,35760292,35760293,35760293,35760308,35760308,36294536,35760291,35760294,35760294,35760298,35760308,35760308,35760309,35760309,35760310,36294536,35760294,35760294,35760295,35760308,35760309,35760309,35760310,35760293,35760295,35760309,35760310,35760310,35760295,35760295,35760310,35760310,35760311,35760311,35760312,36294538,35760296,35760310,35760311,35760311,35760312,35760296,35760297,35760310,35760311,35760311,35760312,35760312,35760313,35760297,35760298,35760311,35760311,35760312,35760312,35760313,35760311,35760312,35760312,35760313,35760314,35760311,35760313,35760314,35760312,35760315,35760315,35760315,36294550,36294551,35760449,35760450,35760325,35760326,35760326,35760327,36294553,36294554,42374436,35760326,35760327,35760327,35760328,36294553,36294554,35760327,35760328,35760328,35769259,35839488,35878333,35986211,36022364,36022367,36122254,36275704,36294554,36294555,36619031,36677681,37375553,38044123,35760328,35760329,35839485,36022367,36022368,36294554,36294555,36677680,35760329,35839487,35839489,36294555,36294556,36294555,36294556,36294556,35760584,35760585,36294689,35778201,35778274,35778345,36303567,35826750,36327802,35918658,35918658,35918661,35918661,35918662,35918662,35918667,36373726,36373727,36373728,36373728,36373731,35996358,36412578,36153743,36491275,36166645,36497721,36179033,36503913,36503914,36212108,36248263,36284416,36284417,36284419,36284406,36284418,36284420,36284419,36284419,36284421,36284420,36556606,36556607,36305421,36313951,36556606,36556607,36556608,36314881,36314891,36315091,36315091,36315291,36315302,36572048,36326423,36577608,36343483,36586138,36484196,36656497,36757609,36793202,36775357,36802076,36791092,36809942,36809943,36828780,36828781,36828782,36828796,36828797,36828801,36828782,36828783,36828784,36828784,36828785,36828785,36828792,36828793,36828794,36828795,36828795,36828796,36828796,36828797,36828797,36828798,36828798,36828799,36828799,36828800,36828800,36828801,36828801,36828802,36828802,36828803,36828803,36828804,36828806,36828806,36828813,36828795,36828796,36828796,36828797,36828797,36828798,36828798,36828799,36828799,36828800,36828800,36828801,36828801,36828802,36828803,36828804,36828805,36828792,36828799,36828800,36828798,36828797,36828797,36828798,36828799,36828799,36828804,36828815,36828805,36828805,36828813,36828806,36828807,36828807,36828808,36828809,36828810,36828807,36828808,36828808,36828809,36828809,36828810,36828810,36828813,36828808,36828809,36828809,36828810,36828810,36828811,36828809,36828810,36828810,36828811,36828811,36828812,36828813,36828810,36828811,36828811,36828812,36828812,36828811,36828812,36828812,36828813,36828813,36828814,36828815,36828812,36828813,36828813,36828814,36828814,36828817,36828823,36828813,36828814,36828814,36828815,36828815,36828816,36828817,45014748,36828814,36828815,36828815,36828816,36828816,36828817,36828817,36828818,38288940,36828815,36828816,36828816,36828817,36828818,36828818,36828822,36945393,38636442,39258018,36828816,36828817,36828817,36828818,36828818,36828829,36828830,36828817,36828818,36828818,36828819,36828819,36828820,36828820,36828821,36828830,36828833,37909798,45014750,36828818,36828819,36828819,36828820,36828820,36828821,36828821,36828822,36828823,36828824,36828825,37211925,37909798,38288942,38578369,38578370,38578373,39258017,45014751,36828819,36828820,36828820,36828821,36828821,36828822,36828822,36828823,36828824,36828824,36828825,36828825,36828831,36828833,36828834,36828834,36828835,37153321,37211925,37211926,37211926,37211930,37909799,38288941,38288944,38578369,38578370,38578370,38578372,38578374,39644791,36828820,36828821,36828821,36828822,36828822,36828823,36828823,36828824,36828824,36828825,36828830,36828832,36828834,36828835,37044064,37097152,37153329,37211925,37211926,37211926,37211927,37211927,37211928,37211929,37211931,37211933,37909797,37909798,37909799,38288942,38288942,38288943,38288944,38578370,38578373,38578374,38578376,39258013,45014752,36828821,36828822,36828822,36828823,36828823,36828824,36828824,36828825,36828826,36828826,36828827,36828834,36828835,36945396,37153291,37153328,37211926,37211927,37211927,37211928,37211930,37754792,37909799,37909803,38288943,38288944,38288949,38578369,38578373,39258025,36828822,36828823,36828823,36828824,36828824,36828825,36828825,36828826,36828827,36828828,36828828,36828830,36828833,36828835,37153325,37153329,37211926,37211927,37211928,37754792,37909799,37909800,38174323,38288945,38578371,38578371,38578373,38578374,39972515,45014753,36828823,36828824,36828824,36828825,36828825,36828826,36828826,36828829,36828835,36828836,36828836,36828837,36828838,36979251,37009136,37097155,37150617,37153309,37153333,37211925,37211927,37211928,37211928,37211929,37211929,37211930,37538452,37909799,37909800,37909801,38288943,38288945,38288945,38578370,38578371,38578372,38578376,45014753,36828824,36828825,36828825,36828826,36828826,36828827,36828827,36828828,36828828,36828829,36828830,36828832,36828833,36828833,36828835,36828836,36828836,36828837,36828838,37153330,37153333,37211927,37211927,37211928,37211928,37211929,37211929,37211930,37211930,37211933,37909800,37909801,37909801,38288944,38288945,38288946,38502631,38578374,38578375,42908687,36828825,36828826,36828826,36828827,36828827,36828828,36828829,36828832,36828833,36828834,36828834,36828837,37211928,37211928,37211929,37211929,37211930,37211930,37211933,37909800,37909802,37909803,38288945,38578376,38578378,45014754,36828826,36828827,36828827,36828828,36828828,36828829,36828830,36828832,36828832,36828834,36828837,36828838,36828839,36999449,37009138,37044069,37153300,37211928,37211928,37211929,37211930,37211930,37211932,37211932,37211933,37211933,37211934,37211934,37909802,37909805,38288947,38288947,38578373,36828827,36828828,36828828,36828829,36828830,36828830,36828831,36828831,36828832,36828834,36828835,36828835,36828837,36828838,36828839,36945399,37153334,37153335,37211929,37211930,37211930,37211931,37211933,37211934,37909803,38288949,36828828,36828829,36828829,36828830,36828830,36828831,36828831,36828832,36828833,36828834,36828836,36828839,36828839,36828840,36917165,37153331,37211929,37211930,37211934,37211935,37211936,37909803,38288949,36828829,36828830,36828830,36828831,36828831,36828832,36828832,36828833,36828833,36828835,36828835,36828836,36828836,36828839,36828840,37211930,37211931,37211932,37211932,37211933,37211933,37211936,37918787,38288947,38578373,39258022,36828830,36828831,36828831,36828832,36828833,36828833,36828834,36828835,36828836,36828837,36828837,36828838,36828839,36828840,36828842,37153341,37211930,37211931,37211931,37211932,37211932,37211933,37211934,37909804,38288950,38578374,36828831,36828832,36828832,36828833,36828833,36828834,36828834,36828835,36828836,36828836,36828837,36828837,36828838,36828840,36828840,36828842,37211931,37211932,37211932,37211933,37211937,37909805,38288950,38578374,41820632,36828832,36828833,36828833,36828834,36828837,36828837,36828839,36828840,36828842,37153329,37211931,37211932,37211932,37211933,37211933,37909804,37909805,36828833,36828834,36828834,36828835,36828836,36828837,36828838,36828838,36828840,36828841,36828842,37211932,37211933,37211933,37211934,37211935,37211938,37804321,37909802,38288951,36828834,36828835,36828837,36828837,36828838,36828838,36828839,36828842,37009141,37009143,37211936,37211941,38288946,38502672,36828835,36828836,36828837,36828838,36828838,36828839,36828839,36828840,37009143,37193178,37211934,37211936,36828836,36828838,36828838,36828839,36828840,36828841,36828842,36828845,37211934,37211935,37211935,37211936,36828837,36828840,36828840,36828843,37211935,37211937,37394084,36828838,36828840,36828840,36828841,36828846,37211934,37211937,38288952,36828840,36828841,37211936,37211938,37211940,38288954,36828841,36828842,36828845,37097161,37211939,37211940,36828841,36828842,36828842,36828844,36828845,37211936,37211937,37211937,37211939,37909810,38288952,36828842,36828843,36828845,36828846,37211937,37211937,37211938,37909810,38288952,36828843,36828845,36828846,36828846,36828847,37044079,37097162,37153339,37211937,37211937,37211938,37211938,37211939,37211939,37211941,37653328,38288955,36828844,36828845,36828845,36828846,36828846,36828847,36828849,36829163,36945407,37211938,37211938,37211939,37211940,37211941,37211941,37909810,37909811,38578378,38578382,38578386,38578387,36828847,36828849,37211937,37211938,37211939,37211939,37211943,37909812,38288959,36828847,36828848,36828851,37009149,37153317,37153339,37153349,37211939,37211940,37211940,37211941,36828849,36828851,36945409,37044078,37211939,37211940,37211942,37211943,36828849,36828851,36828852,37153324,37153344,37211940,37211941,37211941,37211942,37211942,37211943,37211943,37211945,37243371,37909813,37909814,38288957,38578384,38578388,45014766,37097168,37153347,37153349,37211940,37211941,37211941,37211942,37211944,37909814,38578384,37211941,37211942,37211943,37211945,37531243,38288954,38288955,36829252,37211943,37211945,36945412,37153344,37211944,37211945,37909815,37211943,37211946,37909816,36985709,37211943,37211943,37211944,38288963,37211945,36829518,36829594,36829672,36829682,37212372,37910246,37005518,37300284,37061986,37061986,37061987,37061987,37269896,37328517,37328515,37328517,37328519,37328522,37129715,37362392,38439409,37142577,37310180,37170084,37382567,37189461,37189461,37189462,37189463,37333630,37392253,37392254,37392255,38469270,37259323,37259324,37259324,37259325,37427184,37427186,37427186,37365503,37365497,37365502,37365502,37365504,37480272,37480275,37480280,37480278,37480279,37472422,38610750,37477808,37477818,37477819,37477825,37477830,37477835,37477833,37477837,37477840,37477850,37477847,37477857,37477852,37477854,37477857,37477856,37477859,37477860,37477858,37477855,37477856,37477856,37477864,37477860,37477864,37477861,37477866,37477868,37477868,37536450,37536451,37536452,37536450,37536453,38234326,37536454,37536454,37536454,38234327,37536455,37536459,37536455,38234328,37536455,37536456,37536456,37536458,37536459,37536457,38234327,37536456,37536458,37536463,38613476,37536459,37536462,38613477,37557533,37576290,37595031,37595043,37595044,37595030,37595031,37595045,37595049,37595031,37595032,37595032,37595033,37595033,37595034,37595046,37595047,37595048,37595049,37595032,37595033,37595033,37595034,37595035,37595036,37595037,37595037,37595038,37595043,37595046,37595046,37595047,37595047,37595048,37595049,37595050,37595051,37595052,37595033,37595034,37595034,37595035,37595035,37595036,37595037,37595037,37595038,37595048,37595048,37595049,37595049,37595050,37595050,37595052,37595053,37595034,37595035,37595035,37595036,37595036,37595037,37595037,37595038,37595038,37595046,37595047,37595048,37595049,37595049,37595050,37595050,37595051,37595052,37595035,37595036,37595036,37595037,37595037,37595038,37595038,37595039,37595048,37595048,37595049,37595050,37595050,37595051,37595051,37595053,37595036,37595037,37595037,37595038,37595038,37595039,37595049,37595049,37595050,37595051,37595053,37595053,37595037,37595040,37595042,37595050,37595050,37595052,37595054,37595038,37595039,37595039,37595040,37595040,37595041,37595049,37595049,37595051,37595051,37595052,37595052,37595054,37595055,37595055,37595056,37595039,37595040,37595040,37595050,37595052,37595052,37595053,37595054,37595055,37595056,37595056,37595040,37595041,37595041,37595050,37595051,37595052,37595053,37595053,37595056,37595041,37595042,37595042,37595052,37595053,37595053,37595054,37595055,37595055,37595056,37595057,37595057,37595042,37595043,37595043,37595044,37595044,37595048,37595052,37595052,37595053,37595053,37595054,37595054,37595055,37595055,37595056,37595056,37595057,37595057,37595058,37595043,37595044,37595046,37595051,37595052,37595052,37595053,37595053,37595054,37595054,37595055,37595055,37595056,37595057,37595057,37595058,37595053,37595053,37595054,37595054,37595055,37595055,37595056,37595057,37595057,37595058,37595058,37595059,37595054,37595057,37595047,37595059,37595059,37595060,37595061,37595058,37595064,38292915,38672061,38961487,38292918,37595061,37595062,37595063,38292920,38961493,37595063,37595065,37595066,38292919,38292920,38292920,38961490,37595063,37595064,37595065,38292920,38672064,38672065,38961490,37595063,37595064,37595066,37595067,37595067,37595068,38292920,38292921,38557444,38672066,38961493,37595064,37595065,37595065,37595066,37595066,37595067,37595068,37595068,38292920,38292921,38292921,38633805,38672065,38672066,38672067,37595065,37595066,37595066,37595067,37595068,37595068,37595069,37994688,38198922,38292921,38292921,38292922,38292925,38672067,38885836,38961492,38961492,37595066,37595067,37595067,37595068,37595068,37595069,37595069,37595070,38137914,38292920,38292921,38292921,38292922,38292923,38292925,38672063,38672065,38672066,38672067,38672068,38672068,38726384,38961491,38961493,38961497,40355639,37595067,37595068,37595069,37595069,37595070,38137914,38194157,38292922,38292923,38672065,38672067,38672067,38961492,38961493,38961494,38961497,37595069,37595069,37595070,37595070,37595071,38292919,38292921,38292923,38292923,38292924,38292926,38672065,38672066,38672067,38672069,38744170,38961494,38961494,38961497,37595069,37595070,37595070,37595070,37595071,37595071,38292925,38672064,38672070,38961495,37595071,37595072,37595072,37724497,38292922,38292924,38292925,38292925,38331462,38672066,38672069,38672070,38672070,38726381,38885706,38961494,38961495,38961497,38961498,39641123,37595072,37998764,38292920,38292922,38292922,38292924,38292925,38672067,38672069,38672069,38961496,37595073,37595074,37821951,37985932,38014267,38137917,38137918,38292921,38292922,38292923,38292924,38292925,38292925,38292926,38292926,38292927,38292928,38672066,38672068,38672069,38672069,38672070,38672070,38672071,38672071,38672072,38672072,38672073,38885823,38961494,38961495,38961495,38961496,38961497,41095050,37595075,37927459,37927462,38137918,38137919,38194160,38198930,38207709,38292919,38292921,38292923,38292924,38292925,38292925,38292926,38292926,38292927,38292929,38336815,38659828,38672067,38672068,38672069,38672069,38672070,38672071,38672071,38961495,38961496,38961496,38961497,38961498,38092455,38292924,38292926,38961497,38292927,37657904,38169339,37853957,39090954,37959349,38854215,38048839,38048908,38048983,38519887,38233708,38233814,38233922,38991533,38248092,39052902,38259857,38259859,38259964,38259964,38260068,38625426,38625430,38376804,38683798,38394323,39071697,38402466,38839397,38433476,38712135,38477828,38734311,38589851,38790322,38680775,38680776,38680777,38680778,38680778,38680775,38680778,38835782,39214926,38835781,38835782,39504354,39214929,38835783,38835785,38835786,38835787,39504355,38779821,39264451,38793257,38793359,39271163,38793464,38892127,38802795,38802798,38896794,39275940,38820370,38820463,38820552,38905672,38990770,38990773,38990774,38990789,38990772,38990775,38990788,38990791,38990775,38990776,38990792,38990776,38990794,38990774,38990776,38990791,38990775,38990776,38990777,38990778,38990790,38990791,38990794,38990796,38990776,38990777,38990777,38990778,38990791,38990792,38990792,38990793,38990777,38990778,38990778,38990779,38990780,38990781,38990792,38990792,38990793,38990793,38990794,38990794,38990778,38990779,38990779,38990781,38990781,38990791,38990793,38990793,38990794,38990794,38990795,38990779,38990780,38990780,38990781,38990781,38990782,38990792,38990792,38990793,38990793,38990794,38990794,38990795,38990795,38990796,38990796,38990798,38990780,38990781,38990782,38990794,38990794,38990795,38990795,38990796,38990796,38990781,38990782,38990783,38990795,38990795,38990796,38990796,38990797,38990783,38990795,38990796,38990783,38990796,38990796,38990797,38990799,38990784,38990795,38990797,38990797,38990799,38990800,38990787,38990797,38990797,38990798,38990799,38990800,38990800,38990799,38990800,38990807,38990808,39369936,39659368,38990808,38990808,39369932,39369936,38990808,38990809,38990809,39369940,39659364,38990808,38990809,38990809,38990810,39301049,39369932,39369935,39369937,39369937,39369939,39659364,39659364,38990809,38990810,38990810,38990811,38990811,38990812,38990812,39331678,39348175,39369933,39369934,39369934,39369935,39369936,39369936,39369937,39369937,39369938,39369938,39369939,39369939,39369940,39369940,39369942,39625568,39659363,39659364,39659368,38990810,38990811,38990811,38990812,38990812,38990813,39369934,39369934,39369935,39369935,39369936,39369937,39369937,39369938,39369938,39369939,39369940,39369940,39369941,39583575,39625568,39659363,39659364,39659365,39659366,39659368,42367186,38990811,38990812,38990812,38990813,38990813,39034684,39133564,39172744,39255318,39310913,39369934,39369935,39369935,39369936,39369936,39369937,39369937,39369938,39369938,39369939,39369939,39369940,39369940,39369941,39369942,39369944,39583660,39659363,39659364,39659364,39659365,39659365,39659366,39659366,39659368,38990812,38990813,38990813,39255320,39369935,39369937,39369937,39369938,39369939,39369939,39369940,39369941,39369941,39369943,39583693,39659364,39659365,38990813,38990814,38990814,39179705,39348179,39369936,39369938,39369938,39369939,39369940,39369941,39369941,39369942,39369942,39595641,39659365,39659365,39659366,38990814,38990815,39369937,39369938,39369938,39369939,39369941,39369944,39583662,39659365,43989681,38990816,39177318,39369937,39369937,39369939,39369939,39369940,39369941,39369941,39369942,39659365,39659367,39369936,39369939,39369940,39369940,39369941,39369941,39369942,39369942,39369943,39369943,39369944,39369944,39659369,39008763,39378926,39067874,39408481,39078561,39078635,39078710,39413893,39413894,39276327,39398081,39512701,39354679,39354733,39354800,39551941,39363833,39556451,39368608,39558841,39519838,39519838,39519838,39519841,39634459,39634460,39923884,39634461,39634463,39611302,39680190,39631031,39690058,39672564,39672563,39710818,39710824,39705559,39705561,39727324,39727321,39724643,39736885,39749061,39749069,39749058,39749060,39749061,39749062,39749062,39749063,39749070,39749076,39749060,39749061,39749062,39749063,39749063,39749064,39749074,39749074,39749075,39749078,39749078,39749061,39749062,39749062,39749063,39749063,39749064,39749062,39749064,39749064,39749065,39749079,39749063,39749065,39749066,39749066,39749063,39749064,39749064,39749065,39749065,39749066,39749066,39749067,39749068,39749076,39749079,39749080,39749081,39749082,39749064,39749065,39749066,39749066,39749067,39749068,39749082,39749082,39749083,39749065,39749066,39749066,39749067,39749067,39749068,39749068,39749069,39749069,39749077,39749079,39749082,39749083,39749083,39749084,39749066,39749067,39749067,39749068,39749068,39749069,39749071,39749077,39749082,39749082,39749083,39749083,39749084,39749085,39749067,39749068,39749068,39749069,39749069,39749070,39749070,39749074,39749078,39749081,39749082,39749083,39749083,39749084,39749084,39749085,39749089,39749068,39749069,39749069,39749070,39749070,39749071,39749078,39749079,39749079,39749083,39749084,39749084,39749085,39749086,39749086,39749069,39749070,39749070,39749071,39749071,39749079,39749080,39749083,39749084,39749084,39749085,39749086,39749087,39749070,39749071,39749079,39749083,39749084,39749085,39749085,39749086,39749086,39749071,39749072,39749072,39749079,39749081,39749084,39749084,39749085,39749085,39749086,39749087,39749087,39749072,39749073,39749082,39749083,39749085,39749086,39749087,39749087,39749073,39749074,39749086,39749086,39749087,39749087,39749088,39749088,39749085,39749086,39749087,39749087,39749088,39749089,39749087,39749088,39749089,39749083,39749089,39749089,40038499,40038499,39749093,39749094,39749094,39749095,40038508,39749094,39749095,39749095,39749096,40038503,39749098,39749096,39962833,39749097,39749097,39749097,40038511,39749097,39749100,39749097,39749098,39749098,39749099,39749100,40038507,40038507,40038508,39749099,39749099,39803397,39749099,39749100,39749100,39749101,39803353,39962836,40038507,40038508,40038508,40038509,40038510,40038510,39749100,39749101,39749101,39749102,39749102,39759901,39803397,39803401,39916645,40004713,40038507,40038507,40038508,40038508,40038509,40038509,40038510,40038510,40038511,40038511,40038514,40038515,40718156,43841409,39749101,39749102,39749102,39749103,39759902,39803396,39803398,39803402,39803402,39824941,39856959,39916646,39962721,40004712,40004713,40035221,40038507,40038508,40038508,40038509,40038509,40038510,40038510,40038511,40038511,40038512,40038513,40038513,40038514,40038514,40038515,40038515,40038516,40038517,40718136,40718138,40718153,40718160,41052815,41432651,39749102,39749103,39749104,39803399,39803402,39803403,40004714,40038509,40038510,40038510,40038511,40038511,40038513,40038513,40038515,40038516,42746331,39749103,39749104,39749104,40038509,40038510,40038510,40038511,40038511,40038512,40038513,40038514,40038517,39749104,39749105,39803399,39803400,39803402,39803403,39824574,40004715,40038510,40038511,40038511,40038512,40038514,40718144,40718152,40718159,43280763,39803404,40035223,40038511,40038511,40038512,40038515,40038516,39803404,40038512,40038513,40038515,40038514,39770714,39770716,40049323,40049324,39857617,39857665,39857708,39857710,39857711,39857701,39857702,39857703,39857714,39857703,39857714,39857715,39940087,40017118,40059027,40089533,40092819,40092820,40092821,40092822,40092822,40092823,40092824,39893298,40110623,39900062,40038295,39900803,39900874,39900950,40114448,39964836,40070682,40022464,40175199,40084202,40084204,40206065,40885722,40176416,40176464,40176511,40176508,40176512,40176541,40176542,40176600,40176558,40176604,40176573,40176575,40176625,40176626,40252252,40176642,40195548,40252296,40252297,40252297,40252298,40252298,40252301,40931934,40200526,40264256,40214432,40271180,40260334,40260336,40260339,40260340,40294131,40294132,40294132,40294133,40294133,40294134,40294135,40321351,40321353,40321354,40324640,40324642,40324642,40327915,40327931,40327914,40327915,40327915,40327916,40327916,40327917,40327921,40327916,40327917,40327917,40327917,40327918,40327918,40327919,40327933,40327935,40327918,40327919,40327919,40327920,40327920,40327921,40327921,40327922,40327922,40327923,40327923,40327934,40327935,40327935,40327936,40327938,40327919,40327920,40327920,40327921,40327921,40327922,40327923,40327936,40327936,40327920,40327921,40327921,40327922,40327922,40327923,40327923,40327924,40327924,40327925,40327925,40327935,40327936,40327937,40327937,40327938,40327938,40327939,40327939,40327940,40327921,40327922,40327922,40327923,40327923,40327924,40327924,40327925,40327925,40327926,40327934,40327937,40327937,40327938,40327938,40327939,40327939,40327940,40327922,40327923,40327923,40327924,40327924,40327925,40327925,40327926,40327926,40327934,40327937,40327937,40327938,40327938,40327939,40327923,40327924,40327924,40327925,40327925,40327926,40327926,40327936,40327937,40327937,40327938,40327938,40327939,40327939,40327940,40327940,40327924,40327925,40327925,40327926,40327926,40327928,40327937,40327938,40327939,40327940,40327925,40327926,40327926,40327927,40327927,40327928,40327929,40327937,40327937,40327938,40327938,40327939,40327939,40327940,40327940,40327941,40327941,40327926,40327927,40327927,40327928,40327928,40327938,40327939,40327939,40327940,40327940,40327941,40327942,40327943,40327927,40327928,40327928,40327929,40327929,40327930,40327930,40327938,40327938,40327939,40327939,40327940,40327940,40327941,40327941,40327942,40327942,40327943,40327944,40327928,40327929,40327929,40327930,40327930,40327931,40327937,40327938,40327939,40327939,40327940,40327940,40327941,40327941,40327942,40327942,40327943,40327943,40327944,40327929,40327930,40327930,40327931,40327936,40327938,40327938,40327939,40327939,40327940,40327940,40327941,40327941,40327942,40327942,40327943,40327943,40327944,40327944,40327930,40327931,40327931,40327932,40327936,40327940,40327940,40327941,40327941,40327942,40327942,40327943,40327944,40327945,40327945,40327931,40327932,40327932,40327938,40327939,40327939,40327940,40327940,40327941,40327941,40327942,40327942,40327943,40327943,40327944,40327944,40327945,40327946,40327946,40327948,40327939,40327940,40327941,40327942,40327942,40327943,40327943,40327944,40327944,40327945,40327947,40327933,40327943,40327943,40327945,40327947,40327942,40327943,40327943,40327944,40327945,40327946,40327947,40327945,40327948,40327948,40327949,40327950,40327949,40327949,40327950,40327950,40327951,40327951,40327952,40327950,40327950,40327951,40327951,46764316,40327950,40327951,40327951,40327952,40327952,40327953,41085934,45613395,40327951,40327952,40327952,40327953,40327953,40327954,40327954,40327955,40327952,40327953,40327953,40327954,40327954,40327955,43570188,40327953,40327954,40327954,40327955,40327955,40327956,40327956,40327957,40956960,41007574,41007590,40327954,40327955,40327955,40327956,40327956,40327958,41007562,41007586,41085937,40327955,40327956,40327956,40327957,40327957,40327958,40956964,40968609,41007564,41007566,41007568,41007571,41007573,41007575,41007580,41007586,41007593,41085937,41384701,41518537,41722084,41788195,46764319,40327956,40327957,40327957,40327958,40327958,40536983,41007567,41007570,41007571,41007574,41007581,41007584,41007590,43335121,43570190,46764320,40327957,40327958,40327958,40327959,40327959,40327960,40373060,40373062,40866282,40968610,40968611,40968611,41007564,41007567,41007568,41007576,41007577,41007579,41007582,41007583,41007584,41007587,41007587,41007590,41007592,41722084,41722085,41741692,43335121,43335121,43335122,43570191,44329160,40327958,40327959,40327959,40327960,40327960,40327961,40432907,40632197,40956964,40960377,40968611,41007564,41007565,41007566,41007567,41007569,41007570,41007572,41007573,41007578,41007581,41007585,41007586,41007586,41007591,41007591,41176723,41722085,41741694,43335121,43335122,43465365,43570191,45613396,45613397,45613399,46764321,40327959,40327960,40327960,40327961,40432889,40432890,40432892,40432899,40536981,40536984,40883194,40956966,40968611,40968613,41007565,41007567,41007568,41007569,41007569,41007571,41007571,41007572,41007572,41007574,41007574,41007575,41007577,41007577,41007578,41007579,41007579,41007580,41007581,41007584,41007585,41007586,41007586,41007587,41007588,41007590,41007592,41085939,41085939,41085969,41085970,41085970,41176722,41564906,41688193,41722084,41722085,41722086,42461493,43035759,43465365,43570191,43570202,43570207,43570209,44658255,45613396,45613397,45613397,45613400,46764321,40327960,40327961,40327961,40327962,40432904,40610974,40937120,40968612,40968613,40968613,40968614,41007566,41007566,41007568,41007569,41007569,41007572,41007573,41007576,41007577,41007577,41007578,41007578,41007581,41007581,41007585,41007585,41007587,41007588,41007591,41007593,41085940,41085941,41085947,41176723,41518540,43335123,43570192,44658254,46764322,40327961,40327962,40327962,40327963,40327963,40373067,40386015,40402581,40432890,40432890,40432892,40432897,40432919,40536985,40536986,40563073,40683620,40724566,40756173,40886629,40956966,40956967,40968612,40968613,41003515,41007480,41007566,41007567,41007567,41007568,41007568,41007569,41007569,41007570,41007570,41007571,41007571,41007573,41007574,41007575,41007576,41007577,41007578,41007578,41007579,41007579,41007580,41007582,41007582,41007584,41007585,41007586,41007587,41007588,41007588,41007589,41007589,41007591,41007592,41007593,41007593,41007594,41007594,41007595,41007595,41085939,41085940,41085942,41188368,41722087,43335124,43570209,44658254,45613398,46764322,40327962,40327963,40327964,40402581,40432891,40432912,40441506,40536983,40536986,40536987,40610975,40683620,40684006,40703695,40886628,40956966,40968613,40968613,41007566,41007567,41007568,41007568,41007569,41007570,41007572,41007574,41007575,41007575,41007576,41007578,41007579,41007579,41007580,41007581,41007582,41007583,41007583,41007584,41007587,41007588,41007588,41007589,41007590,41007592,41007594,41007594,41007595,41085940,41085941,41342246,41722085,41722086,41722087,41788199,43335123,43335124,43570192,45035273,45613398,40339852,40432890,40432891,40432921,40536985,41007567,41007567,41007569,41007570,41007572,41007572,41007574,41007579,41007580,41007581,41007583,41007584,41007592,41007594,41722087,40865934,41007568,41007570,41007575,41007580,41007593,41007573,41007597,42963284,41007584,41007571,40351757,41019475,40418173,40418179,40418186,41767197,43615306,41013731,40444081,40444081,41065658,44716321,40477246,41082235,41082240,41082244,40537843,40537834,40537837,40537822,40537835,40537835,40537862,40537851,40537837,40537852,40537845,40537861,40537854,40537864,40537865,41112521,41112523,41073557,41112511,40972917,40537880,40537885,43440076,41112535,41112523,40537894,40537895,41061926,41112537,41112540,41846666,41112533,41112541,41112547,41061942,41073589,40555072,41121148,40746018,40746020,40746009,40746024,40746025,40746025,40746024,40746025,40746024,40746025,40746025,45822434,41294977,40746037,41095667,41216611,41216617,41385763,43779248,41216621,41216606,41216611,41931126,41216623,43544163,40798197,41242720,40894003,41290595,41290597,42005112,40936486,41390228,41039284,41039360,41039434,41039435,41363307,41363306,41040066,41442001,41079446,42163950,41121200,41121295,41121389,41404295,41184427,41435833,41403917,41545551,41404618,45196588,41407995,45198278,41438440,41523857,41445310,41445311,41445312,41566265,41566252,41566260,41546296,42331262,41585983,41585984,41585985,41636588,41636588,41636589,41636589,41636590,41636591,41636601,41636608,41636609,41636610,41592808,44961594,41609278,41609264,41609274,41609275,41609278,41609278,41609279,41609279,41609280,41609280,41609281,41609275,41609279,41609280,41609281,41609281,41609285,41609282,41609283,41609285,41609286,41609363,41609371,41609373,41609376,42362751,41648239,41609295,41648233,41648235,41648236,41648238,41648239,41648249,41648250,42328966,41648244,41648247,41648253,41648237,41648245,41648246,41648260,41648237,41648250,42362754,41648247,41648256,41648257,41648241,41648252,41648258,41609453,41609468,41609474,41648331,41609477,41648331,43975886,46254163,41679082,41683138,41687010,41687096,41687177,41687185,41687181,41687186,41687187,41687175,41687176,41687179,41687181,41687184,41687184,41687187,41687187,41687188,41687188,41687189,41687189,41687190,41687195,41687175,41687184,41687190,41687176,41687183,41687184,41687185,41687187,41687191,41687176,41687185,41687177,41687177,41687178,41687179,41687180,41687181,41687181,41687183,41687183,41687184,41687184,41687186,41687193,41687211,41687216,41687178,41687178,41687179,41687179,41687180,41687180,41687181,41687182,41687182,41687183,41687185,41687185,41687186,41687187,41687187,41687189,41687190,41687190,41687191,41687191,41687192,41687192,41687196,41687197,41687200,41687201,41687202,41687213,41687214,41687217,41687179,41687180,41687180,41687183,41687187,41687188,41687189,41687192,41687199,41687218,41687181,41687182,41687188,41687188,41687192,41687216,41687181,41687182,41687183,41687187,41687187,41687189,41687189,41687190,41687195,41687198,41687217,41687219,41687183,41687184,41687186,41687189,41687189,41687191,41687193,41687203,41687218,41687183,41687184,41687185,41687188,41687189,41687195,41687216,41687220,41687188,41687190,41687190,41687192,41687198,41687200,41687217,41687220,41687189,41687190,41687191,41687195,41687195,41687198,41687200,41687218,41687187,41687190,41687191,41687191,41687192,41687195,41687196,41687198,41687200,41687204,41687219,41687220,41687188,41687191,41687192,41687193,41687195,41687198,41687203,41687219,41687190,41687192,41687192,41687220,41687191,41687192,41687192,41687193,41687196,41687191,41687192,41687195,41687196,41687197,41687219,41687221,41687191,41687192,41687193,41687203,41687219,41687192,41687193,41687194,41687194,41687195,41687201,41687205,41687209,41687193,41687194,41687194,41687195,41687196,41687198,41687201,41687202,41687205,41687195,41687195,41687196,41687199,41687200,41687222,41687223,41687195,41687196,41687196,41687199,41687201,41687201,41687202,41687222,41687224,41687196,41687197,41687197,41687198,41687199,41687200,41687200,41687201,41687202,41687202,41687203,41687204,41687206,41687223,41687224,41687225,41687226,41687197,41687198,41687198,41687199,41687199,41687200,41687200,41687201,41687201,41687202,41687203,41687203,41687204,41687205,41687206,41687206,41687207,41687211,41687212,41687213,41687222,41687223,41687223,41687224,41687225,41687225,41687198,41687199,41687199,41687200,41687200,41687201,41687201,41687203,41687199,41687200,41687201,41687202,41687202,41687203,41687205,41687205,41687211,41687212,41687224,41687200,41687201,41687201,41687202,41687202,41687203,41687204,41687205,41687208,41687208,41687209,41687217,41687226,41687227,41687228,41856343,41687201,41687202,41687202,41687203,41687203,41687204,41687204,41687205,41687206,41687206,41687209,41687214,41687227,41687228,41687202,41687203,41687203,41687204,41687204,41687205,41687206,41687207,41687208,41687208,41687210,41687227,41687229,41687203,41687204,41687205,41687205,41687206,41687206,41687207,41687209,41687209,41687210,41687211,41687211,41687213,41687227,41687227,41687228,41687228,41762273,42401708,41687204,41687205,41687205,41687206,41687206,41687207,41687208,41687208,41687209,41687209,41687211,41687211,41687212,41687213,41687218,41687227,41687227,42421323,41687205,41687206,41687206,41687207,41687207,41687208,41687209,41687209,41687210,41687227,41687228,41687229,41687229,41687230,41687230,41687231,41687206,41687207,41687207,41687208,41687208,41687209,41687209,41687210,41687211,41687211,41687212,41687217,41687229,41687230,41687231,46293022,41687207,41687208,41687208,41687209,41687209,41687210,41687212,41687229,41687230,41687232,43715383,41687208,41687209,41687209,41687210,41687210,41687211,41687211,41687212,41687218,41687219,41687229,41687230,41765564,41687209,41687210,41687210,41687211,41687211,41687213,41687229,41687232,42421328,41687210,41687211,41687211,41687212,41687212,41687213,41687213,41687214,41687214,41687215,41687218,41687229,41687230,41687231,41687232,41687233,41687211,41687212,41687212,41687213,41687213,41687214,41687214,41687216,41687216,41687229,41687230,41687234,41687212,41687213,41687213,41687214,41687214,41687215,41687232,41687233,41687234,41687213,41687214,41687214,41687215,41687215,41687216,41687231,41687233,41687233,41687234,41687235,41687214,41687215,41687215,41687218,41687221,41687221,41687233,41687234,41687235,41687235,41687215,41687216,41687216,41687217,41687219,41687219,41687220,41687232,41687233,41687233,41687234,41687234,41687235,41687235,41687236,41687236,41687216,41687217,41687217,41687218,41687220,41687221,41687233,41687234,41687234,41687235,41687236,41687217,41687218,41687218,41687219,41687219,41687220,41687220,41687221,41687221,41687233,41687233,41687234,41687234,41687235,41687235,41687236,41687236,41687218,41687219,41687219,41687220,41687220,41687221,41687223,41687234,41687234,41687235,41687235,41687236,41687236,41687237,41687238,41687219,41687220,41687220,41687221,41687221,41687224,41687233,41687236,41687236,41765566,41687220,41687221,41687221,41687222,41687222,41687223,41687235,41687235,41687236,41687236,41687237,41687238,41687221,41687222,41687222,41687223,41687223,41687224,41687224,41687235,41687236,41687238,41687222,41687223,41687223,41687224,41687224,41687225,41687225,41687237,41687237,41687238,41687238,41687240,41687240,41687223,41687224,41687224,41687225,41687225,41687226,41687235,41687236,41687236,41687238,41687239,41687240,41687241,41687224,41687225,41687225,41687226,41687235,41687236,41687236,41687237,41687237,41687238,41687238,41687239,41687240,41687241,41687225,41687226,41687226,41687227,41687236,41687237,41687237,41687238,41687238,41687239,41687240,41687240,41687241,41687241,41687242,41687242,41687226,41687227,41687227,41687228,41687228,41687229,41687230,41687237,41687238,41687239,41687239,41687240,41687241,41687241,41687242,41687243,41687227,41687228,41687231,41687237,41687238,41687238,41687239,41687239,41687240,41687240,41687241,41687243,41687228,41687229,41687238,41687239,41687240,41687240,41687241,41687241,41687242,41687243,41687243,41687231,41687235,41687238,41687238,41687239,41687239,41687240,41687240,41687241,41687241,41687243,41687244,41687244,41687231,41687239,41687240,41687240,41687241,41687242,41687243,41687243,41687238,41687241,41687242,41687245,41687244,41687241,41687242,41687242,41687240,41687245,41687245,41687242,41687247,41687247,43276724,41687248,41687249,41687249,41687250,41687251,41687249,41687249,41687250,41687250,41687251,41687252,41765583,41765584,41687249,41687250,41687250,41687251,41687251,41687252,41687252,41765584,41765614,42401729,44249836,44249853,45337907,41687250,41687251,41687251,41687252,41687252,41687253,41687253,41765584,41765585,42401730,42401731,41687251,41687252,41687252,41687253,41687253,41687254,42401731,42401732,43715405,44014768,41687252,41687253,41687253,41687254,41687254,41687256,41765585,41765586,42051036,42198186,42401730,42401730,42401732,44014768,44014769,41687253,41687254,41687254,41687255,41687255,41687256,41765585,41765606,42401729,42401730,42401731,42401733,42819216,44014769,47443968,41687254,41687255,41687255,41687256,41687257,41687260,41765586,41765587,41765588,41765599,41856371,42401731,42401732,42401733,42467845,44145013,44249838,45337900,45337901,41687255,41687256,41687256,41687257,41687257,41765586,41765587,41765594,41765611,41765617,41765620,41856371,42198187,42276721,42401732,42401732,42401733,42401733,42401734,42421343,42421352,42421353,42467845,42467845,43141141,43715407,43715407,44014766,44014770,44014771,44145013,44145013,44249844,44249853,44249856,45337900,45337901,46293047,47443969,41687256,41687257,41687257,41687258,41687258,41765586,41765587,41765587,41765588,41765611,41856367,42064354,42401725,42401733,42401734,42421352,44014771,46293043,41687257,41687258,41687258,41687259,41763828,41765586,41765587,41765587,41765588,41765588,41765589,41765590,41765595,41765599,41765614,41765614,41765616,41765617,41765618,41843027,41856373,42021893,42064354,42198189,42324388,42401731,42401732,42401732,42401733,42401734,42401735,42421348,42467846,42985027,43142363,43715408,44014770,44014771,44014771,44014772,44145018,45008811,45337902,45337903,45337907,45714921,46293046,47443970,41687258,41687259,41687260,41765585,41765587,41765588,41765588,41765589,41856372,42021894,42379602,42401733,42401733,42401735,42421356,44014772,44249839,44249840,41687259,41687260,41687260,41765588,41765588,41765589,41765589,41765590,41765618,42021894,42051040,42064353,42401733,42401734,42401735,42401735,42401736,42421352,42421355,42803220,43929392,44014773,44249842,44249856,46293047,41765588,41765589,41765589,41765590,41765591,41765600,41765609,41765617,41765618,41805210,41856373,42268035,42401734,42401734,42401735,42401735,42401736,42421345,42467848,42803220,43430502,44014772,44014773,44145016,45337905,41765590,44249847,41765590,41765591,42401736,42421356,42401737,41837354,41840643,41840433,42478340,41843930,41843941,41843932,41843918,41843918,41843932,41843934,41843934,41843935,41843935,41843918,41843919,41843920,41843933,41843935,41843919,41843934,41843934,41843935,41843937,41843938,41843941,41843943,41843949,41843921,41843921,41843922,41843927,41843932,41843934,41843935,41843935,41843936,41843936,41843937,41843937,41843938,41843938,41843939,41843939,41843940,41843940,41843941,41843941,41843942,41843943,41843943,41843944,41843945,41843945,41843946,41843947,41843947,41843949,41843949,41843950,41843951,41843951,41843954,41843923,41843937,41843938,41843939,41843939,41843945,41843962,41843963,41843963,41843964,41843941,41843958,41843964,41843937,41843938,41843966,41843947,41843947,41843958,41843970,41843972,41843974,41843975,41843966,41843949,41843950,42480080,42499689,41843963,42480080,42480081,41843951,41843953,42480080,42480080,44093118,41843952,41843953,41843965,42499690,41843952,41843953,41843953,41843954,42480082,42546194,43793755,44223363,44328188,41843953,41843954,41843954,41843955,41843955,41843956,41843956,41843957,41843958,41843962,41843966,41843975,42480083,42499702,42546194,42546194,41843954,41843955,41843956,41843956,41843958,41843960,41843965,42480081,42480083,43877958,44328207,41843955,41843957,41843958,42480083,42499692,42499701,43793757,44328189,41843956,41843957,41843959,41843960,41843962,41843967,41843969,41843970,41843972,42084759,42115217,42480081,43793757,44223358,41843957,41843958,41843958,41843959,41843961,41843965,41843972,41843981,42480083,42480084,44223361,44328206,41843958,41843959,41843961,41843962,41843963,41843964,41843964,41843968,41843970,41934722,42499694,43793758,44093122,47522321,41843960,41843963,41843967,41843969,41843973,41843973,41843984,42480085,44223362,44223363,45416253,41843961,41843961,41843968,41843980,41843984,42499695,42499706,44093123,41843962,41843967,41843970,41843984,42499696,42546198,41843971,42100243,42480086,42499696,44093123,41843972,42480086,42499695,44223368,41843964,41843970,42446304,42480087,42480088,42532717,44328202,41843969,41843987,44328194,41843967,41843969,41843989,42480089,44093137,41843971,41843988,42480088,42480090,41843969,41843972,41843975,42480090,42499709,43580843,41843986,42480088,42546202,42480089,42480090,42499710,41843979,41843990,42480091,42499711,41843977,41843990,41843991,41934729,43578891,44223371,41843992,41934729,41843976,41843992,41843994,42480092,42276547,41843977,41843992,41843994,41843993,41843993,41843994,41843978,41843979,41843994,41843994,41843980,41843994,41843994,41843995,42480093,44093131,44093132,41843994,41843995,42100255,44328215,41843997,42480097,41843985,41843995,41843997,42480095,42480096,42480097,42480099,42499706,42499706,44223373,41843997,41843999,41843997,41844000,42142721,42480098,42499709,44093137,44223379,42546212,42919913,41844002,41934744,42480104,43587050,42480107,42480108,42480106,42499717,42480107,42480109,42881593,42480107,42480109,42499729,43219511,44093147,41844010,41934747,41934750,42100267,42480108,42480109,42480109,42480110,42480110,42480111,42499728,42546223,42546224,43578910,43793784,44069782,44093147,44093147,42276566,42480109,42480110,42480111,42480111,45416279,42157662,42461924,42480110,42480112,42499720,42546223,44093148,44093148,44328234,41934749,42499721,42499731,43185802,44328235,46371425,41934749,41934750,45416281,41923179,41974341,41998810,42012154,42025498,42025486,42025499,42025500,42025501,42025501,42025502,42025503,42025503,42025504,42025499,42025502,42025503,42025504,42025505,42025499,42025505,42025504,42025508,42025508,42570859,42590476,42590479,42570861,42570863,42590484,42570863,42636977,42570864,42972350,42025521,42493519,42636978,42570866,44183904,42636979,44314145,42570866,42570866,42570867,42191028,42570870,42048785,42582503,42325578,42787014,42356538,42356540,42356542,42356543,42356545,42736381,42736380,42736383,42736383,43137867,42736384,43475785,44479663,42736386,42386493,42770968,42414830,42414905,42414912,42414981,42414994,42831716,44508886,42441462,42441462,42441463,42441465,42441466,42778844,42575300,42778844,44391881,44391882,42460775,42788500,42471347,42793797,42709135,42709135,42709136,42709136,42709138,42912681,44226358,42912680,42912680,42912682,42932290,42912680,42801872,44702333,42848825,42982526,42866200,42991211,42961533,42961534,43038880,43048438,43048543,43048650,43048656,43048657,46018605,43102060,43102063,43071956,43533899,43079860,43079932,43080007,43117744,43116201,43116207,43116208,43116209,43116207,43116209,43116210,43116225,43116208,43116209,43116210,43116223,43116223,43116224,43116225,43116225,43116226,43116227,43116227,43116228,43116228,43116209,43116210,43116211,43116224,43116225,43116225,43116227,43116227,43116210,43116211,43116223,43116224,43116226,43116226,43116228,43116229,43116229,43116211,43116212,43116224,43116224,43116225,43116225,43116226,43116226,43116227,43116227,43116228,43116229,43116230,43116231,43116231,43116232,43116232,43116212,43116224,43116225,43116226,43116227,43116236,43116213,43116223,43116224,43116224,43116225,43116225,43116226,43116226,43116227,43116227,43116228,43116228,43116229,43116229,43116231,43116237,43116237,43116238,43116238,43116239,43116239,43116240,43116240,43116241,43116241,43116242,43116240,43116244,43116237,43116249,43116248,43116253,43116238,43116250,43135833,43116237,43116238,43116239,43116240,43116251,43116251,43116252,43116252,43116253,43135843,44729261,43116239,43116240,43116250,43116253,43116254,43135844,44964331,44964343,43116240,43116243,43116250,43116254,43116254,43782244,44729261,44729262,43116244,43116253,43217774,43116242,43116243,43116243,43116250,43116252,43116253,43116255,43116255,43116256,43135836,43135845,44429901,44643883,44729263,47007537,43116242,43116245,43116253,43116254,43116255,43116256,43135835,43135836,43135843,43135847,44051219,44429901,44429903,44729263,44729264,44859502,44964345,44964347,46052395,43116244,43116254,43116255,43116255,43116256,43116256,43116259,43135836,43135836,44215026,44300763,46052396,48158463,43116245,43116246,43116253,44729265,45723305,47007541,43116249,43116254,43116256,43116257,43135837,43135849,43182340,44729265,46429417,43116246,43116254,43116256,43116256,43135838,44964348,43182341,43855635,44859506,43116260,43135850,44729267,44964353,43116256,43116256,43116257,43116257,43116258,43135838,43135839,48158466,44729279,43135839,43135844,44964338,46052400,43116259,45723308,44964339,43116261,43116262,43116265,43135856,43821880,44964342,43116265,43116266,43714313,44729272,44729274,43116264,43116264,43116266,43116266,43116267,43116268,43135846,43135856,43135857,44356992,44729274,44729275,44859517,44859520,48158473,43116266,43116267,43135847,43135857,43182350,44729275,44964344,47007551,47007552,43116265,43116267,43116268,43135858,43135859,43182351,43855646,44357433,44729275,44729276,46052406,46052412,48158474,43116266,43116267,43116267,43116268,43116268,43135847,43135857,43135858,43135859,43135860,43135860,43182351,43182352,43213563,44429913,44729275,44729276,44729276,44859517,44964344,44964345,44964352,46052412,46711145,47007553,47007553,48158475,43116268,43116268,43135847,43135859,43182351,44729276,44729276,44859519,44964360,43116268,43116269,43116269,43135848,43135859,43135860,44429915,44643896,44729277,44964345,46052407,43116269,43116270,43135849,43182352,43430178,43699533,43699534,43855648,43856869,44429916,44729277,44729277,47007553,43116270,43135849,43135850,43135851,43135856,43135859,43135860,43135860,43135861,43135862,43182353,43471779,43490521,43517725,43556051,43855649,43856871,44429914,44429915,44729277,44729278,44729278,44964347,44964350,45667908,46052407,47007555,48158477,43135849,43135852,43135860,43135861,43182353,43182355,43217788,43424229,43517726,43699532,43855647,44215039,44521850,44643896,44729278,44729278,44729279,44964347,44964359,45723319,46052410,46052413,46052414,44964347,43135850,43135851,43135853,43155429,43155442,43155428,43155429,43155443,43155448,43155449,43155429,43155430,43155440,43155445,43155446,43155447,43155447,43155452,43155452,43155453,43155453,43155431,43155437,43155439,43155440,43155441,43155441,43155444,43155445,43155445,43155446,43155447,43155447,43155449,43155450,43155452,43155452,43155453,43155453,43155454,43155454,43155448,43155449,43155453,43155440,43155448,43155450,43155451,43155458,43155442,43155461,43155462,43155462,43155464,43155459,43155463,43155465,43155465,43155465,43155449,43155450,43155460,43155465,43155466,43155466,43155449,43155465,43155466,43155466,43155467,43155450,43155458,43155466,43155467,43155451,43155455,43155466,43155467,43155469,43155452,43155453,43155457,43155461,43155467,43155467,43155468,43155465,43155468,43155469,43155469,43155469,43155470,43155469,43155470,43719128,43155461,44748873,43155460,43155461,43155463,43155471,44879114,46072010,43155461,43155462,43155463,44748873,44879115,44983959,47027148,43155463,43155464,43155469,43155472,44748873,43155470,44748874,43155474,44449513,44748886,44879116,44983946,46072010,44449512,44748875,44748884,43155467,43155474,43262455,44879116,43155471,43155469,43876468,44449513,43876469,44983963,44879116,46072011,47027153,43155471,43155476,44748878,44748879,43155478,43155478,43201956,43449782,44879122,44983949,48178079,44748880,45742922,43201958,43237392,44533720,46072016,43155481,43575655,44449519,44748882,43155482,43155483,43201958,43201959,43201959,43302497,43449785,44109643,44449520,44449521,44748883,44748884,44748884,44879127,46072015,47027158,43155483,43155484,43201960,43237396,43537332,43876476,44449521,44748885,44879121,44879122,46072015,43155484,43201960,43201961,43238565,43449786,43537332,43841491,43875249,43876476,44234646,44242814,44449521,44449522,44449522,44464450,44547392,44748884,44748885,44748885,44879125,44983954,46072016,46072017,43201960,43201961,43201963,43719140,43719141,44449522,44748886,46072016,44748886,44748887,43221482,44781890,43248435,43248450,43248450,43248450,43248451,43248436,43248437,43248437,43248450,43248451,43248451,43248438,43248450,43248451,43248452,43248452,43248453,43248452,43248452,43248453,43248452,43248453,43248453,43248453,43248465,43765630,43765631,44795376,44839711,45030444,45030460,48224574,43248466,43496277,43583823,43888029,43921744,44496012,44496013,44795375,44795376,44795376,44925617,44925618,45789417,46118507,43248467,43283886,43556619,43583824,43765632,43765634,43888035,43922968,44496013,44795372,44795376,44795377,44925617,44925623,45030443,46118508,46118511,46495526,47073650,47073651,47073651,44795376,44925618,43310887,44826602,43319321,43319319,43319320,43319321,43319326,44531447,43449912,43657583,45065880,44316576,43321657,43435554,43369459,43948533,43449523,44895910,43549452,43646776,43580501,43580635,43580768,44746370,43732197,45037247,43744100,43744101,44013456,44743836,44743837,45043199,45173439,45278281,43827320,43827391,43827460,45084886,43864783,43864817,48532739,44804209,43919192,43919191,43919194,43919194,43919195,43919195,43919196,43919196,43919268,43919269,43919270,43919268,43919276,44257112,44831385,45130748,45130749,45260994,46421219,46453883,45365821,43919339,43919344,43919344,43919353,44831456,45130820,45365889,46453951,45365903,43951251,43951374,43951457,45061508,43995841,43995843,43995844,43995844,43995845,43995922,45169070,44139327,46492202,45169071,43996002,46492280,44282808,44282811,44282811,44282810,44282811,44282812,44282814,44282812,44282814,44282813,45312554,45312554,45312553,45013193,45312555,46635687,46635695,45013192,45312556,47590832,44829236,44438928,44312379,45562410,44448324,45630427,44527546,44527668,44527621,44527667,44527668,44527674,44527697,44527742,45435014,45435015,45435015,45565252,45565258,45565258,44595031,44595034,44595035,44595037,44595042,44595043,44595044,44595040,44595042,44595043,44595043,45703734,45468670,45598912,45169307,45468670,48777929,45169308,47168822,45468672,45598912,47746947,45598916,45703742,45703742,44597473,44597475,44597543,44597612,45170591,45469951,45469951,45469952,45705020,45705020,45705023,46463990,44866219,46598302,44986206,45664251,45063825,45703074,45173759,49187229,45313821,45313821,45313822,45528696,45528697,45828058,45828059,45828060,45958302,45317730,45960254,45330117,45836210,45330156,45836227,45375655,45559613,45485298,45913798,45597735,45970017,45598618,45598619,47669303,48248737,45743570,45743574,45743559,45743574,45743574,45743575,45743576,45743577,45743578,45743571,45743575,45743575,45743576,45743577,45743574,45743575,45743576,45743577,45743578,45743578,45743578,45743578,45743580,45743577,45743577,45743581,45743586,46173176,46042936,45743589,45851441,46042938,46278022,47366068,47741779,49276337,45743591,45743664,45884403,46042937,46042937,46042938,46173179,46173180,46173181,46173181,46278007,46278014,46278024,47036979,49472137,46042938,46042938,46042939,46173176,46173178,46173181,46278007,46278007,47036980,48321213,46042938,46042939,46042939,46042949,46173182,46042940,46173181,47366070,46042940,47366070,46173184,46042942,47366073,48071093,45743747,46278090,45773431,46057866,45911980,45911980,46127141,46257381,46362225,45927457,47458016,45939365,46271097,45959306,46281042,46025227,46314041,46171537,46171537,46171540,46171541,46171541,46256918,46387162,46387161,46387164,46256921,46204424,49702564,46295573,46449176,46342282,46342297,46342283,46342299,46342284,46342284,46342285,46342285,46342296,46342299,46342300,46342301,46342302,46342303,46342285,46342286,46342299,46342300,46342300,46342301,46342301,46342302,46342302,46342303,46342304,46342305,46342306,46342306,46342310,46342312,46342286,46342297,46342299,46342300,46342301,46342301,46342302,46342302,46342303,46342304,46342304,46342305,46342306,46342309,46342288,46342288,46342295,46342298,46342300,46342301,46342302,46342302,46342303,46342304,46342304,46342305,46342306,46342311,46342311,46342312,46342312,46342313,46342313,46342314,46342314,46342303,46342321,46342321,46342324,46342324,46342324,46342326,46342312,46342313,46342316,46342324,46342327,46342316,46342317,46577384,46342315,46342325,46577369,46577384,46342317,46342317,46577369,46577370,47665431,48042450,49771499,46342316,46342317,46342317,46342319,46342319,46342320,46342320,46342321,46342326,46342328,46342330,46472540,46472541,46472544,46577368,46577369,46577370,46577372,46577381,46577382,47336342,47665431,47665432,47665436,47665441,49771500,46342317,46342318,46342319,46342319,46342321,46342327,46342327,46342328,46342328,46342329,46472542,46472543,46472544,46472545,46577370,46577371,46577377,46577383,47336340,47632771,47665432,47665432,46342319,46342328,46472541,46472542,46472543,46472544,46472545,46577370,46577371,46577388,47665432,48620578,48620578,46342319,46342322,46342328,46342332,46472539,46472542,46472543,46472544,46472545,46472545,46577371,46577383,46577385,46577386,47165955,47665432,47665434,48042452,48620574,46472542,46472544,46472545,46472546,46472547,46577387,46342329,46577372,46342324,46342329,46342331,46342334,46472545,46472545,46472546,46472546,46577390,48620578,46342325,46342330,46342331,46472545,46577373,46577382,47665436,46342325,46342336,46472542,46577374,47665447,46342331,46342333,46472546,46489636,46577373,46577375,48620582,49771505,46577389,47336346,48042457,46577375,46342335,46472554,46342337,46342338,46577382,47665441,47665441,47665442,48620587,46342338,46342338,46342339,46342340,46472550,46472552,46472554,46472555,46472557,46577380,46577380,46577381,46577385,46577393,46577393,46577394,46577396,47336352,47665442,47665443,48041152,48620585,48620588,46577393,46807367,47665443,47665448,48620586,46342339,46472555,46577381,46577381,46577387,46577398,46807367,47665443,48620587,48620588,49771511,46342342,46472552,46472553,46472553,46472554,46472554,46472555,46472556,46472556,46472557,46472558,46577381,46577382,46577382,46577394,47336352,47336354,47665443,47665443,47665444,47665446,48041153,48042462,48620587,48620587,48620588,48620589,48620589,46489651,46577382,46577382,47336352,47665444,47665448,47665450,46472553,46472554,46472557,46577384,46577399,47665446,47665451,46472559,46577391,46472554,46577384,46472557,46577392,46472559,46430972,47709767,46602775,46602778,46602781,46602777,46602779,46602763,46602778,46602779,46602780,46602781,46602782,46602782,46602766,46602767,46602768,46602768,46602783,46602784,46602784,46602785,46602786,46602786,46602787,46602787,46602768,46602784,46602784,46602785,46602787,46602767,46602768,46602768,46602769,46602784,46602785,46602787,46602768,46602769,46602770,46602771,46602785,46602785,46602786,46602786,46602787,46602788,46602770,46602785,46602787,46602788,46602788,46602789,46602770,46602771,46602784,46602786,46602787,46602787,46602789,46602771,46602772,46602772,46602786,46602787,46602788,46602772,46602773,46602774,46602787,46602787,46602788,46602788,46602790,46602790,46602773,46602787,46602788,46602788,46602789,46602790,46602788,46602789,46602790,46602791,46602790,46602792,46602793,46602792,46602794,47795670,46707611,46707609,46707617,46707623,46707624,46707614,46707621,47795672,48750817,46602800,46707628,46707615,46602803,46602803,46602804,46602804,46602805,46602805,46602806,46619882,46640092,46707532,46707612,46707613,46707613,46707623,46707625,46707626,46707626,46707627,46707628,46707628,46707629,46707629,46988330,47466585,47654363,47795674,47795675,47795681,48171384,48750818,49901743,46602803,46602805,46602806,46707611,46707613,46707627,46707627,46707628,47795676,48750821,46602804,46602805,46602805,46602806,46602806,46602808,46707613,46707614,46707621,46707625,46707626,46707626,46707629,46707631,46707632,47466586,47795675,47795676,47795677,47795678,48500692,49901744,46707614,46707614,46707615,46707625,46707626,46707629,46707630,47466585,48750820,49901744,46602806,46602807,46707614,46707618,46707619,47466585,47795677,47795679,47795683,46707613,46707615,46707615,46707629,47676922,47795677,47795677,47795678,48750824,46707614,46707615,46707616,46707616,46707624,46707628,46707628,46707629,46707631,46707632,47466588,47606806,47795678,48171388,48750823,48750824,46707541,46707616,46707626,46707628,46707632,48750822,46707632,46919705,46707619,46602855,46707645,46636954,46636963,46636994,46637027,46724725,46724737,46637099,46637109,46637111,47812830,46677418,46744938,46812272,46812284,46812354,46812361,46812437,46812437,46812438,46812436,46812437,46812422,46812436,46812437,46812438,46812422,46812423,46812423,46812437,46812423,46812424,46812425,46812426,46812429,46812430,46812435,46812436,46812437,46812438,46812438,46812439,46812439,46812441,46812444,46812455,46812424,46812425,46812425,46812426,46812427,46812432,46812433,46812434,46812434,46812436,46812437,46812437,46812438,46812438,46812439,46812439,46812440,46812440,46812441,46812441,46812442,46812444,46812459,46812425,46812428,46812430,46812434,46812435,46812436,46812439,46812439,46812440,46812440,46812441,46812442,46812448,46812454,46812434,46812437,46812438,46812441,46812441,46812428,46812441,46812455,46812435,46812436,46812441,46812457,46812458,46812438,46812458,46812440,46812440,46812459,46812459,46812431,46812443,46812459,46812460,46812439,46812461,46812460,46812461,46812441,46812443,46812450,46812447,46812462,46812463,46812439,46812445,46812462,46812446,46812463,46812441,46812444,46812446,46812448,46812463,46812466,46812444,46812446,46812448,46812449,46812449,46812464,46812448,46812449,46812449,46812447,46812448,46812449,46812450,46812467,46812448,46812450,46812451,46812466,46812447,46812451,46812451,46812468,46812448,46812449,46812450,46812451,46812468,46812468,46812450,46812451,46812451,46812452,46812453,46812469,46812469,46812450,46812451,46812451,46812453,46812453,46812454,46812469,46812469,46812470,47900499,46812452,46812452,46812453,46812453,46812454,46812457,46812469,46812470,48276209,46812452,46812453,46812453,46812455,46812470,46812470,47781747,47900499,48855645,46812453,46812454,46812454,46812455,46812470,46812471,47900499,47900500,47900501,48855647,50006568,46812454,46812455,46812456,46812457,46812458,46812470,46812471,46812471,46812472,47900501,47900501,47900502,48277519,48855644,50006569,46812455,46812456,46812456,46812457,46812457,46812458,46812460,46812470,46812470,46812471,46812471,46812472,46812472,47042426,47093156,47428008,47571411,47900501,47900501,47900502,48855645,48855646,48855646,48855647,48855647,50006569,46812456,46812457,46812457,46812471,46812471,46812472,46812472,46812473,47042425,47571412,47571413,47887189,47900498,47900501,47900501,47900502,47900502,47900503,47900504,48855645,46812457,46812458,46812461,46812472,46812473,47781750,47900502,47900503,47900508,48276212,46812458,46812459,46812473,46812473,46812474,47900503,47900503,48277521,48855646,46812463,46812464,46812473,46812474,46812474,46812475,47900503,48855647,46812473,46812474,46812475,47900504,46812474,46812476,48276214,46812475,46812475,46812476,47781753,47867846,47900505,47900506,47900509,48855650,47093162,46812479,47571419,47900515,47900519,47042437,46812486,46812487,47900516,47900516,47900517,47900517,46812487,47900517,47900518,47900523,48855660,48855661,48855661,46812488,46812489,46812489,47093173,47290489,47571422,47571426,47571428,47900515,47900517,47900517,47900518,47900518,47900519,47900523,47900523,47900524,48277534,48844037,48855658,48855659,48855661,48855661,48855662,48855662,48855663,48855663,48855664,50006586,46812489,46812490,47042440,47042442,47093172,47093173,47571426,47571427,47571428,47571428,47781764,47900517,47900518,47900518,47900519,47900520,47900521,47900522,47900522,47900524,47900525,47900526,47900526,47900528,48276228,48806190,48855661,48855662,48855663,48855664,50006586,46812490,47571427,47571429,47867858,47900518,47900519,47900519,47900526,48276228,48855662,48855663,48855666,48855666,50006587,47042442,47093180,47900519,47900519,47900520,47900520,47900522,47571431,47236617,48112597,47272407,47272410,47272409,47272410,47272411,47272412,47323141,48118558,48130486,48130486,49085631,47801397,48130487,48130491,47373874,47373875,47373875,47373882,48085602,48181220,48181221,48181226,48181227,47775585,47768502,48259778,47933730,48711507,47989602,48456421,48043574,48516067,48177286,48582922,48219562,50710130,48330374,48330366,48330379,48330379,48330380,48330380,48330380,48330382,48330380,48330380,48330381,48330383,48330381,48330382,48659470,48659473,49614615,48330393,48659476,49614616,48357896,48362082,48659469,48659470,48659470,48659471,48659471,48659473,48659474,48659477,48659478,49035180,49283124,49400663,49614614,49614614,49614615,49614616,50765539,48659472,49614616,48659473,48385425,49642144,48393780,49646312,48610820,48799697,48705935,49802391,48751052,48751053,48751054,48751054,48751055,48837146,48869808,48869813,49245517,49245520,50975875,48797326,48892948,48923237,48923238,48923242,48923243,48955898,48955899,48955902,48955903,48955911,49911047,48961937,48975249,48964703,48976631,48988545,48988560,48988561,48988545,48988546,48988552,48988558,48988562,48988547,48988550,48988552,48988560,48988561,48988564,48988565,48988547,48988548,48988548,48988549,48988550,48988550,48988551,48988552,48988554,48988558,48988562,48988562,48988563,48988563,48988564,48988565,48988565,48988566,48988566,48988567,48988548,48988549,48988549,48988550,48988550,48988551,48988551,48988552,48988552,48988553,48988553,48988554,48988554,48988555,48988555,48988556,48988557,48988561,48988561,48988562,48988562,48988563,48988563,48988564,48988564,48988565,48988565,48988566,48988566,48988549,48988550,48988551,48988551,48988552,48988552,48988553,48988553,48988554,48988554,48988555,48988556,48988556,48988562,48988563,48988563,48988564,48988564,48988565,48988565,48988566,48988566,48988567,48988567,48988568,48988551,48988552,48988552,48988553,48988556,48988556,48988563,48988564,48988565,48988566,48988566,48988567,48988568,48988553,48988564,48988567,48988552,48988553,48988553,48988554,48988554,48988555,48988555,48988556,48988556,48988557,48988561,48988565,48988566,48988572,48988574,48988553,48988554,48988554,48988555,48988556,48988557,48988566,48988567,48988574,48988574,48988575,48988554,48988555,48988555,48988556,48988559,48988565,48988566,48988567,48988568,48988572,48988573,48988555,48988556,48988556,48988557,48988558,48988559,48988559,48988566,48988567,48988567,48988568,48988568,48988569,48988574,48988575,48988556,48988557,48988558,48988558,48988567,48988567,48988569,48988569,48988573,48988574,48988576,48988576,48988558,48988559,48988560,48988561,48988567,48988569,48988575,48988576,48988558,48988559,48988559,48988560,48988561,48988568,48988569,48988569,48988570,48988570,48988573,48988574,48988576,48988577,48988577,48988559,48988560,48988562,48988564,48988568,48988568,48988569,48988570,48988570,48988575,48988577,48988577,48988561,48988561,48988562,48988569,48988570,48988571,48988572,48988573,48988576,48988577,48988578,48988561,48988562,48988564,48988569,48988570,48988571,48988577,48988578,48988562,48988563,48988564,48988566,48988568,48988570,48988570,48988571,48988571,48988572,48988573,48988574,48988577,48988578,48988578,48988579,48988563,48988564,48988565,48988566,48988567,48988569,48988571,48988571,48988572,48988572,48988573,48988577,48988579,48988579,48988580,48988570,48988571,48988572,48988572,48988574,48988575,48988581,48988571,48988576,48988578,48988578,48988580,48988581,48988581,48988580,48988581,48988573,48988574,48988580,48988581,48988583,48988573,48988584,48988575,48988577,48988581,48988582,49943703,48988578,48988583,51094629,48988581,49365580,49943707,48988576,48988577,48988577,48988578,51094630,48988577,48988578,48988578,48988579,48988580,48988584,48988586,49364272,49943705,51094630,48988578,48988579,48988579,48988580,48988580,48988582,48988584,48988585,48988587,49364273,49364274,49612174,49943706,49943707,49943708,49943709,49943709,51094631,48988579,48988580,48988580,48988581,48988581,48988582,48988583,48988585,48988585,48988587,48988587,48988588,49364273,49943706,49943708,49943709,51094631,48988580,48988581,48988581,48988582,48988585,48988586,48988586,48988587,48988587,48988588,48988588,49364274,49365583,49603564,49707998,49943707,49943707,49943708,49943709,49943709,49943710,50603351,51094632,48988581,48988582,48988582,48988583,48988584,48988586,48988587,48988588,48988588,48988589,49285316,49364274,49364275,49365582,49365583,49365584,49905554,49943707,49943708,49943709,49943709,49943710,49943710,51094632,48988582,48988583,48988583,48988584,48988586,48988587,48988588,48988588,48988589,48988590,49364275,49364276,49365583,49365585,49457347,49486674,49943707,49943708,49943708,49943709,49943710,49943711,49943712,50722257,51094633,48988583,48988587,48988587,48988588,48988589,48988589,48988590,49365588,49943707,49943708,49943709,49943710,49943711,49943712,51094633,48988585,48988588,48988588,48988589,48988590,48988590,48988591,48988592,49029508,49364276,49365582,49365585,49943707,49943708,49943709,49943709,49943710,49943710,49943711,49943711,50901271,49364275,49364276,49365585,49943710,49943711,51094634,48988589,49365585,49943710,49943710,48988589,48988590,48988590,48988591,49603568,49943710,49943711,49943712,49943713,49943713,51094635,48988590,48988592,48988591,48988592,48988593,48988593,49943712,49943713,49943714,48988592,48988593,48988593,48988594,48988594,48988595,49364279,49364279,49365589,49943713,49943715,48988593,48988594,48988594,48988595,48988596,49220017,49365590,49943713,49943714,49943714,49943715,51094638,48988594,48988595,48988595,49365589,49943715,49943716,51094639,48988595,48988596,48988596,49218197,49364281,49365590,49943714,49943715,49943715,49943716,49943716,49943717,49943718,49944884,51094639,48988596,48988597,48988598,49285323,49364281,49364281,49364282,49364282,49364283,49365590,49365591,49365592,49428510,49457354,49943714,49943715,49943715,49943716,49943716,49943717,49943717,49943718,51094640,49192252,49364284,49365590,49365591,49365592,49693204,49905562,49905563,49943713,49943714,49943715,49943716,49943716,49943717,49943717,49943718,49943718,49773609,49943716,49943716,49943717,49943718,49943718,51094641,49943716,49164048,49943717,49943718,49943719,49070444,49207013,49339507,50119176,49343580,49543090,49395914,49395931,49396008,49396086,49406794,49417528,49922418,49447810,50173330,49451455,49595717,49489282,49489293,50194066,49582062,49582064,51391379,49661024,49739967,49739968,49739981,49739982,49739982,49739982,49739982,49739983,49739983,49739983,49739984,49739984,49739984,49739984,49739985,49739986,49833054,50319413,50319417,50319418,50319418,51470340,49741291,50319414,50319416,50319416,50319418,49741290,49741293,50319414,50319416,50319417,50319417,50319418,50319418,50319419,50319419,50950312,51470341,49833056,49742598,49742599,49742599,49742600,49742600,49742600,49742601,49742601,49742601,49742602,49742602,49742603,49742602,49742603,49742605,49980583,50320724,50320724,50320725,50320725,50320726,51471649,50320725,50320725,50320726,50320726,50320727,51471650,50320723,50320725,50320726,50320726,50320727,50320727,50320728,50320728,51275852,51471650,49868436,50383641,49926122,49926123,50412483,50400861,50412483,50412486,49984793,50441829,50218561,50218562,50558701,50558704,50235826,50235871,50567358,51718286,50306037,50602442,50397822,50648335,50398595,50398600,50648723,50648724,50427285,50427355,50427414,50427417,50427430,50427432,50427535,50427537,50427627,50427642,50663245,50663247,50470966,50684917,50558635,50728742,50799904,50849377,50822543,50822546,50822545,50860696,50860698,50860702,50875598,50875599,50887219,50887224,50898832,50898844,50898832,50898832,50898833,50898834,50898835,50898847,50898832,50898835,50898833,50898833,50898836,50898834,50898835,50898835,50898836,50898836,50898837,50898837,50898838,50898852,50898852,50898853,50898854,50898857,50898835,50898836,50898836,50898837,50898837,50898838,50898838,50898848,50898851,50898852,50898853,50898853,50898854,50898857,50898836,50898837,50898837,50898838,50898838,50898839,50898839,50898847,50898853,50898853,50898854,50898837,50898838,50898838,50898853,50898854,50898854,50898855,50898838,50898839,50898839,50898840,50898840,50898841,50898853,50898854,50898854,50898855,50898857,50898858,50898839,50898840,50898840,50898841,50898841,50898851,50898851,50898853,50898854,50898854,50898855,50898855,50898840,50898841,50898841,50898843,50898850,50898851,50898853,50898854,50898854,50898855,50898855,50898856,50898841,50898842,50898844,50898852,50898855,50898855,50898856,50898856,50898857,50898858,50898843,50898855,50898856,50898856,50898857,50898857,50898856,50898856,50898857,50898858,50898857,50898858,50898858,50898864,52049771,50898865,50898866,50898865,50898867,51856416,50898868,50898868,50898869,50898870,50898869,50898870,52049776,50898870,50898871,50898871,50898872,50898872,50898873,50898873,50898874,50898876,50900024,50913997,51039993,51098251,51154800,51327477,51332204,51386560,51391897,51454820,51529733,51558496,51853977,51853978,51853978,51853979,51853980,51856412,51856415,51856418,52049777,50898871,50898872,50898872,50898873,50898873,50898874,50898874,51007571,51039994,51214590,51327477,51386561,51529748,51530049,51777941,51853978,51853979,51856413,51856413,51957872,52049777,50898872,50898873,50898873,50898874,50898874,50898875,50898876,50898876,50898877,50898878,50900022,50900024,51039992,51299050,51357650,51386560,51386561,51525979,51525980,51525981,51529749,51777943,51853977,51853978,51853978,51853979,51853979,51853981,51853981,51856414,51856415,52049778,50898873,50898874,50898874,50898875,50898876,50898878,50898881,50900023,50900025,51777945,51838716,51853978,51856415,51856416,52049778,50898875,50898877,50900024,51386562,51566496,51856415,51890221,52049779,50898875,50898877,51327479,52049779,50898876,51327480,51558499,51698387,51698388,51698389,51856417,52049780,51298430,51525979,51529736,51698388,51698389,52049780,51327481,51991324,52049781,51853983,52049781,51853982,52049782,52049782,52049783,52049783,52049784,52049787,50901188,50901189,50901188,50901190,50901190,50901191,51678564,52050943,51387727,51699552,51855147,52050944,50929139,52064919,51116290,52158496,51181125,51181128,51181129,52190911,52190911,52190912,51297642,51585951,51410750,52305727,51530321,52365509,51698039,52449389,51699260,51727687,51756098,51756098,51756099,51756100,51756100,52282601,52478398,52271381,52478399,52282603,51765562,52483135,51816439,51845351,51874249,51874265,51874266,51947425,52537483,51884998,52542878,52010786,52605743,52020589,52610647,52153096,52153098,52153101,52153103,52676897,52676897,52676899,52676900,52160626,52160638,52160647,52160650,52680670,52680676,52680679,52680682,52161299,52681028,52218133,52218157,52218175,52709413,52218232,52218229,52218286,52218308,52516149,52516149,52709513,52234145,52234223,52234301,52717506,52455939,52455944,52828317,52828320,52497910,52497911,52497911,52849302,52657025,52657026,52657030,52928861,52928864,52778624,52932417,52786662,52993680,52809100,52809102,52809102,52809101,52809103,52809102,52809102,52809103,52809102,52809103,52809104,52809105,52809105,52809106,53004901,53004901,53004902,52813970,52813971,52813971,52813971,52813972,52813972,52813973,52813974,52813975,52813977,52813978,53007334,53007335,53007335,53007336,53007336,53007337,52881573,52881649,52881723,53041205,52960807,52960818,52960828,53080758,53016888,53108794,53083783,53083898,53084014,53142356,53086174,53143443],\"xaxis\":\"x\",\"y\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,4,1,0,0,5,86,76903,3162,3971,3661,4662,4246,2571,898,2455,3,636,17,1270,1655,221,693,4833,149,1176,215,1304,28,1596,159,1847,244,3,2452,1135,403,18686,59217,7142,1,184,1402,1116,2846,1469,2656,261,594,1694,1280,1178,271,561,450,1077,209,1254,1051,1044,1152,668,633,4692,13048,35323,1108,689,1263,1105,300,866,438,3697,382,861,1260,2666,1237,1321,1393,4256,1238,623,1206,1393,2501,426,1507,3301,1326,427,262,1494,1350,689,1012,1979,1,1395,1281,637,9,1177,1270,272,1656,784,449,692,1036,1311,2492,150,2213,44,1686,1250,57,624,239,1255,1597,1050,1349,1363,1796,741,1043,243,4,1662,788,2211,1392,75,865,669,634,4440,5496,62,51300,1586,200020,352862,14293,15872,16936,540,938,390,130,864,575,1269,8,1106,69,101,1354,944,970,7544,127,71,41,431,7,17,7,7,9,15,158,98962,131785,88675,3446,7327,198,4876,2299,1764,3122,2139,9231,84,102,32,30,63600,35848,7322,1086,789,2234,818,1677,39,145200,5442,20130,22,18588,1101,928,1728,33,2215,8,6818,2133,7132,43,44309,76437,577,4763,1892,52335,1549,20920,5697,12394,3028,5603,1946,18442,1321,14,1779,2244,31591,236,17414,885,2622,9854,5116,7956,390,31,565,4147,362,4445,2,427,3435,853,42148,1263,20511,5383,8004,7411,21958,3921,4544,9727,98,391,886,578,428,1400,1976,2780,131,2033,9,3469,1914,23,854,199,3618,12650,2622,6498,9414,10349,41291,3829,14419,29672,302,59,129,1530,3619,21,380,723,1264,2381,15337,5190,8846,2327,15839,5416,7776,6049,165,621,1484,8581,20,9,2744,6513,3922,23969,599,6069,13305,5613,21952,2920,23,3612,2870,18097,3324,1724,2451,21738,21,40,5653,1142,2329,2523,9197,6907,6535,65017,105773,122,175,201,290,17,4550,9899,16915,7489,1285,6241,3221,138768,756,64,255,26,8793,5907,278825,64459,48817,10431,296,31,23,136,5756,878,2165,3640,2221,49,187746,93850,7347,30,239659,18106,163,384616,1293,14,12,5,114,173,39,57,103712,60181,36564,41114,74596,61679,7205,18462,7228,5323,1936,2740,401,405,436,1659,166,4,998,7,72,17136,15119,12842,27003,17412,4837,3667,1244,793,2164,38,960,580,10326,15423,22527,14297,776,7459,2923,1755,172,845,2152,297,25,10346,20267,20080,8096,1857,958,37,409,33494,19879,12938,8548,888,2239,693,369,701,33,85247,34648,40576,7196,3329,2376,1398,109,2343,866,52,85,72,85462,80674,10030,18604,6440,6930,1351,2368,1182,2433,624,188,941,1290,96128,15820,13019,8568,9994,2120,1504,5697,410,324,213,233,62068,80363,44213,39073,5104,5286,4992,6994,3191,242,78,2321,75,3015,630,176,25,28,61852,17225,15943,4803,474,3925,1477,143,471,67,765,972,208,99890,51518,11706,8582,10074,744,1972,938,123,56,1312,236,45,126,110326,16080,22472,13917,5772,5561,2624,2586,391,930,463,404,1638,172,141,77268,43897,55303,23718,14881,3699,4937,5690,40,1963,437,1378,66,593,2369,214,2313,859,117,38281,42609,13569,10730,1634,2227,694,579,3583,4684,259,57092,40289,13204,4407,3402,2490,627,605,944,1960,2,46,121996,37562,12366,7267,6551,2294,1283,7929,440,16,885,138,381,142462,35255,22541,10773,1234,2545,717,1841,85,118,120276,50268,26477,10353,10345,3522,4517,3221,1292,2441,281,32,35,193,96418,45773,4582,20138,8056,134,3355,407,1638,1099,29,51,61,157,122583,5405,28470,10603,8712,6075,72,2494,750,11,36,327,1953,1109,194,785,46959,144093,11327,5762,4530,100,5157,1352,86,1428,350,36,253,61400,4092,2473,1275,2279,942,2412,106,152,1083,360,182177,42648,1015,25565,4200,7407,1259,3652,306,2280,30,269,1705,194,188,282,413,265,145507,2344,36666,17076,7300,3012,1444,298,2307,5121,573,3355,3218,770,2746,878,149,436,364,1291,6704,150665,14761,6353,4919,3604,1521,4160,387,2454,4663,3442,207,2800,2462,1883,2953,297,4525,1313,9562,1503,632,943,3356,1274,92996,19567,13271,12854,10373,4558,2075,1517,3732,4438,16665,10167,7219,13729,2132,2669,8156,4066,1280,5016,2285,43671,11708,1742,3517,2894,3782,6886,5000,3959,7433,9643,4313,9837,5821,3127,232,65,7768,3247,12418,9180,843,5079,5356,4172,4810,4828,7343,6228,10478,4047,3462,132,872,2490,2118,2830,9730,3353,1830,5984,1393,7441,2678,5807,2689,2529,4038,1501,719,403,579,2951,4779,1595,3490,2044,1622,9946,6187,3351,853,4430,1585,1221,2758,2493,6984,4908,2856,6128,1837,3006,1327,43,1674,731,4416,2016,2492,5077,14,297,2829,3784,1197,941,2850,2488,9085,5114,763,1259,3347,3943,1345,1522,13496,5413,5794,2224,2541,776,1290,3921,1757,3112,1274,9259,1198,4240,3569,1052,1977,1691,6470,10430,5172,3141,3531,1225,2857,364,24227,21827,13673,13471,12919,439,1025,2974,919,21115,12726,6203,10632,5404,7555,8593,9310,39349,1782,14857,18179,2408,4495,14779,10534,5207,38623,36542,6859,7200,20017,14323,1156,7959,1952,235,137,52214,7905,8334,24752,11941,27952,28377,67501,47583,15275,39100,8567,68645,13364,275400,204897,617,67,163,163,122,135,3,7,411,117,77,86,86,196,718,58,8,23,9,39,112,12,151,79,77,20,157,24,99,0,185,53,252,68,220,1108,0,0,0,0,0,0,42960,16345,5672,18829,1955,21450,4483,11024,5245,9298,6669,350,2050,1454,396,3156,5899,3156,4017,1726,1467,752,3443,4026,1002,943,946,228,400,847,548,306,2643,143,1918,1771,343,2338,1970,319,162,1347,401,203,1015,56,184,721,486,204,532,758,3106,0,0,6426,993,8213,2643,3178,2325,2416,1323,1392,622,299,125,3091,1786,730,1590,193,1039,201,1416,691,325,687,623,206,455,210,335,1264,3703,3728,2588,2650,1824,390,1102,1768,160,457,1272,261,347,432,690,13,98,52,1767,2459,122,2691,282,540,18,23,176,2,569,8034,6305,4410,4218,1800,783,761,2409,571,145,660,551,818,31,172,6,386,3353,363,684,1065,1131,512,698,891,189,5610,10394,1891,3240,1394,3100,2994,1596,698,1564,1341,2590,1049,532,682,76,774,1548,65,44,5327,3600,3553,943,1622,2179,225,16,1276,373,530,445,855,900,105,5878,5075,4888,7584,5564,1346,362,630,3576,190,1460,727,498,948,2,4117,3298,186,325,278,1500,1509,893,369,441,1064,671,1048,6,1296,26,95,361,5908,983,3748,3428,631,2620,933,7654,77,780,691,992,625,264,135,102,90,1749,5649,2919,2313,2333,8476,942,810,913,336,270,1986,548,483,2053,615,942,96,81,11,7986,855,2929,10143,273,605,382,1289,536,762,184,728,1409,16,299,125,1513,4319,1538,16864,1074,190,356,468,517,277,336,7343,2311,684,87,827,144,630,437,44,1619,10776,1250,570,759,298,48,15,4512,686,799,347,164,124,629,472,121,144,133,85,36806,5507,538,1396,1302,2207,1488,1682,6031,6073,3942,509,1511,681,358,334,1519,2215,3134,876,411,2420,1108,1322,157,1008,14,74,378,118,235,0,8224,974,159,5313,1795,1911,7688,6749,4274,1377,1135,272,556,1646,1705,413,790,1429,685,695,553,134,76,557,1086,2685,1200,1498,3076,2148,396,621,456,3855,2254,2421,802,379,349,831,305,798,368,80,687,617,2632,941,442,539,550,359,555,1395,381,1016,158,391,1187,361,1301,1085,845,3578,1260,1233,54,893,1009,2127,875,178,752,348,523,672,7,1796,1565,191,112,2202,1196,781,844,905,742,9378,1511,2275,2328,1996,1178,212,3789,2415,61,1587,3869,824,771,322,375,609,338,207,456,242,351,735,1944,3927,1182,1156,4473,1206,2640,10113,1449,1246,1783,537,191,1076,794,891,322,330,966,943,802,2462,202,198,1532,1098,659,1748,456,780,157,1047,1038,654,471,387,130,1792,1071,1318,3938,3247,2619,171,1915,727,425,91,855,2328,229,443,1378,325,2366,163,508,1951,560,594,726,2836,1037,2043,444,1440,431,271,127,91,91,5193,2089,1096,4834,821,1182,139,318,214,133,555,682,547,2099,561,634,538,357,75,11,335,1147,613,11064,310,4974,1131,970,657,4435,1008,211,123,2113,2316,1172,2504,546,417,32,11981,335,3357,20628,8027,4643,3112,1066,2220,1855,872,2189,455,15,781,859,945,1095,899,60,1057,2048,12368,503,1314,1199,1334,938,3114,728,306,1742,781,824,676,157,2301,336,5460,175,1545,664,213,588,293,303,253,2691,33985,7599,3110,1182,9,1768,7057,1828,4425,1407,912,1019,1221,345,451,565,1419,849,68,925,1485,2175,513,1550,342,445,12622,5622,1685,8974,4670,488,1746,3984,872,3875,322,2622,58,1206,524,1363,1191,1473,265,5644,3161,9223,3355,1792,3475,806,4946,1569,528,632,413,1021,1055,2011,2450,505,795,1777,1427,1923,169,1214,5285,189,283,6051,840,1030,3845,2373,370,334,672,187,1827,1625,761,981,537,13,1172,170,25,1519,2887,1213,321,2624,98,547,568,726,668,8,627,1035,1065,212,1581,348,209,174,65,4261,1065,586,11058,2839,5628,3025,801,511,1416,850,1095,293,2134,1054,1010,464,2228,1872,2363,888,430,1735,707,4683,914,1346,2019,936,1034,2280,1645,1205,188,805,887,585,282,694,320,924,8257,4028,7105,2846,2991,1260,1094,2295,3508,1015,3055,2402,1055,871,1568,923,839,1933,830,4202,1870,522,392,3220,729,1698,1549,2963,1067,334,1478,1683,623,5640,916,614,414,1872,601,1029,1064,1068,694,1657,7565,9740,4988,451,4634,3851,1525,543,2339,4196,4062,502,800,3195,301,611,1099,724,9840,716,3032,880,3309,2680,4284,3095,2275,1246,3572,4855,3428,4031,8134,3761,519,2786,904,1326,1026,3290,643,849,486,505,5711,3630,6521,1457,5309,4764,4367,6153,1055,728,6106,1346,20792,8977,4273,7972,2683,24707,10562,17205,6209,18993,30591,15235,27892,17136,125915,0,156,34,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,1,0,0,0,0,0,0,0,1,13,2726,1148,1832,727,163,158,101,61,9,5,5,90,85,69,91,20,4,203,268,29,84,93,243,3497,11053,7232,1,368,491,130,182,465,752,367,37,520,524,452,803,1136,449,110,105,403,116,165,159,102,62,7,8,129,1,0,89,109,84,68,90,21,5,202,270,30,268,94,85,244,4482,956,20601,2,16201,3081,4484,5250,906,590,251,586,1531,1363,186,143,1851,3766,546,5468,115,314,201,108,1643,127,697,340,659,499,122,328,425,514,206,5,73,456,34,30,30,112,258,23,70,339,8,266,158,72,173,164,39,377,4657,1920,967,3155,148,431,555,1263,299,612,864,1177,1549,356,468,109,361,426,58,127,186,321,130,799,1992,744,86,721,693,271,257,122,133,932,838,398,609,851,354,215,82,406,76,268,94,82,271,125,208,1995,1297,245,315,156,326,165,1845,2135,80,260,178,114,211,274,145,127,60,57,102,970,546,126,636,183,443,90,432,190,50,194,19,142,209,782,466,2332,398,116,388,19,936,510,478,663,10,481,259,12,837,433,629,435,303,101,937,39,355,71,312,1545,1553,23,430,143,157,80,108,399,1095,2,87,130,423,1612,297,47,158,511,334,139,188,97,211,885,4784,151,1094,246,533,457,306,400,1012,320,209,182,66,231,16,161,413,49,328,624,460,538,10,1035,183,4,4730,209,1719,1029,177,364,70,195,207,1672,115,210,392,366,662,465,394,711,134,1235,25,487,323,1444,1021,211,356,211,213,1395,1036,298,83,116,306,184,200,10,202,357,5,109,81,9,1829,1942,324,10,429,229,395,2,178,1064,1047,453,11,79,921,20,738,104,638,595,320,87,261,2,249,659,210,272,247,10,59,102,249,598,108,769,405,284,559,327,251,126,46,161,676,110,193,211,308,922,82,13,58,562,1048,78,6,525,508,334,938,182,77,157,178,694,365,272,128,40,5,110,213,284,388,38,2,200,3,55,474,73,134,2,643,108,217,149,8,4,117,190,113,196,366,123,212,159,4,189,213,6,2,273,406,235,98,425,111,127,232,7,671,5,2,104,875,223,238,304,316,191,1013,41,259,110,167,362,747,62,89,319,776,473,114,256,205,3,208,1,8,181,315,188,461,179,214,333,127,411,276,74,81,361,211,935,119,69,133,560,15,195,64,38,539,350,799,172,271,718,12,178,387,134,290,85,129,237,472,48,61,0,561,639,55,328,11,459,4,516,272,86,365,996,194,292,250,248,313,560,1937,230,252,314,129,179,353,10,216,166,1011,123,75,1544,376,530,97,44,337,337,125,51,390,683,554,1068,45,219,1004,136,122,201,805,399,289,489,376,1433,436,303,126,1022,671,103,375,555,980,746,207,71,559,354,6510,1685,572,705,102,681,191,1166,4894,2714,835,563,255,937,175,1433,102,1992,4703,210,1109,107,92,811,61,422,202,162,4075,0,513,1386,320,385,819,327,1595,512,623,5,101,564,2757,1291,374,2113,126,3566,423,990,322,1479,124,9181,21501,402,167,110,104,43,145,110,90,4,3,34,39,176,2,53,179,37,79,10,5,5,59,0,9,339,24,91,39,63,108,928,5137,0,0,0,0,0,0,0,0,0,0,0,1541,676,122,485,415,344,127,148,443,243,476,104,71,629,236,300,279,416,340,295,36,69,319,19,198,88,176,95,1130,102,177,340,194,260,402,312,140,1445,7892,0,138,310,82,217,56,104,370,158,496,43,233,172,316,76,108,121,0,104,78,299,103,144,272,44,143,143,62,90,126,167,0,128,149,266,175,152,137,58,91,50,321,93,63,91,142,103,44,3,70,151,2,136,86,415,174,130,297,235,38,92,250,210,232,278,320,63,187,290,28,122,235,230,69,288,103,395,85,34,393,57,150,88,365,917,11,39,270,4,68,84,319,55,103,20,60,68,94,199,236,43,87,148,83,514,31,2,368,187,269,94,228,1075,2105,138,149,268,141,265,196,293,176,339,277,31,320,139,731,263,47,62,246,6032,5,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,1520,151,898,69,246,73,31,111,18,209,171,991,276,5865,8057,1,2,461,62,394,629,26,128,80,289,213,424,375,63,71,160,169,290,64,74,32,42,74,19,210,456,9,834,641,445,49,8680,5869,686,1105,948,1062,822,1408,860,79,410,29,189,665,411,43,63,49,315,21,190,56,92,250,49,612,328,12,402,135,217,76,562,1027,246,2496,39,2402,4063,1669,71,83,212,199,521,41,3,95,167,77,17,8,95,8,74,36,11,11,41,41,59,179,58,59,59,425,4906,2,578,138,1283,151,118,139,400,569,379,341,432,232,39,169,507,296,4,63,76,165,170,215,62,80,151,166,271,1115,154,117,318,59,97,364,119,154,1,274,279,158,1,60,28,2,139,77,298,32,136,120,45,191,50,519,300,592,296,180,192,182,275,167,1,152,339,388,19,75,67,97,5,76,57,512,30,190,422,245,119,199,2,99,115,44,204,45,6,109,463,65,200,150,3,22,125,65,57,93,89,163,401,1,50,0,100,423,273,366,145,151,275,106,167,80,99,4,6,47,702,142,44,82,146,520,138,304,37,76,21,253,111,75,50,150,377,585,1,86,134,46,650,85,155,1141,13,98,97,24,186,829,149,1,210,132,2,262,124,60,190,2691,2077,391,49,75,90,228,122,8,72,34,210,295,150,195,171,26,58,127,4,76,98,186,138,252,1,161,0,111,2466,637,349,570,961,58,670,146,2,185,149,164,113,581,253,246,129,68,107,918,3588,181,833,1391,1914,131,907,26,106,509,182,2,1,102,258,95,55,293,19,122,111,103,47,4,101,229,357,355,150,1723,149,363,578,1046,1395,63,124,338,83,55,343,60,378,181,183,20,147,248,1462,48,70,180,148,90,284,348,126,124,189,79,121,168,144,76,233,392,696,430,181,55,1,204,594,162,154,38,219,280,193,183,236,724,1220,797,406,356,1,13,402,51,221,168,399,1,101,134,64,145,1354,262,459,108,138,37,379,426,239,1073,334,738,521,387,126,27,83,130,197,275,559,43,599,199,2,73,29,885,374,84,59,254,48,188,5,1035,250,5,3,507,2466,186,125,522,89,595,302,682,25,52,54,256,147,630,96,185,1,118,103,656,187,255,300,52,75,367,47,220,68,167,259,149,35,94,4,166,78,342,779,38,580,84,2,67,483,18,198,59,121,165,152,170,194,27,142,0,120,51,333,42,221,378,98,541,247,321,1015,323,167,67,98,86,196,425,594,445,215,1592,148,946,693,307,1844,5712,9114,194,121,25,6,79,2,0,65,224,1,28,332,0,112,62,455,25,206,102,68,134,272,359,731,6116,0,0,0,0,0,0,0,725,82,124,47,158,56,683,24,128,115,289,209,173,384,208,237,661,555,4042,196,32,681,81,120,123,24,5,80,3,46,1,66,159,38,39,349,57,10,2,10,27,158,242,93,57,16,67,498,116,110,140,54,31,157,488,427,288,37,92,137,36,56,312,60,402,15,87,68,321,0,90,65,368,89,95,650,167,1224,2185,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,6152,2662,2733,453,5823,205,974,53,94,69,243,189,96,338,102,1773,178,141,46,314,671,491,69,1553,12872,5131,1,552,227,1427,252,119,144,152,38,2550,747,126,35,612,767,1086,51,158,1080,87,158,159,88,466,44,1136,62,159,177,177,160,211,313,264,228,627,2617,309,67,3924,802,206,88,185,315,792,253,768,159,54,96,263,158,70,120,245,188,97,84,292,65,176,227,89,573,306,185,178,286,348,90,4855,401,119,365,192,525,285,45,982,449,227,524,66,158,153,71,2181,210,35159,34294,5946,3892,1408,1740,107,19,783,116,444,15,164,1791,1175,286,625,22,671,1312,1236,265,923,182,3186,434,5,885,2310,1738,257,244,1675,3869,3185,4461,1323,2180,433,616,586,28,329,306,4,411,1,33,152,145,1073,877,2994,3870,916,1682,1130,1701,1127,977,674,528,1300,680,270,495,370,1534,90,568,190,245,150,637,3822,1934,2466,1114,1063,629,169,691,213,134,94,634,388,380,877,216,1173,687,576,863,437,889,511,289,923,8,119,3018,773,137,172,213,508,2,172,562,6,128,515,418,387,1363,43,215,389,387,636,3,4,120,282,391,59,241,295,1479,135,144,1543,600,472,189,426,87,1213,258,96,161,4,428,197,789,387,13,251,8,1214,403,293,557,9,318,250,368,104,459,138,1412,255,453,7,137,459,516,297,2023,173,136,214,379,313,509,303,191,187,218,924,141,132,222,529,157,1020,404,547,287,756,460,626,23,599,469,514,160,145,585,368,1174,221,359,690,422,390,679,727,142,133,52,496,267,388,146,97,2701,173,92,887,2,558,298,371,725,183,369,10,1499,1498,1894,1093,2119,1471,1990,1693,113,1099,748,17,185,106,2,8,184,2,661,89,172,181,12,186,9,6,3,1528,778,1367,571,3,3,172,5,11,537,1352,1633,995,5,802,290,1,1,1543,1137,586,611,266,262,102,797,127,304,664,14,158,321,1,1290,2165,571,28,153,326,8,2,4045,3058,2880,672,418,2,99,6,318,5,6788,9355,319,444,1760,201,88,1415,137,99,217,58,131,17457,977,2715,528,27,2285,402,386,387,174,116,427,4,26,139,2,129,1243,19084,13466,2809,2660,5091,909,653,367,469,1181,3,96,484,3,1155,257,123,13,613,12,190,389,651,4,631,18541,2151,1532,3037,460,547,227,445,277,34,10,320,135,0,13359,8775,10834,2915,1469,696,1020,550,691,771,220,484,114,5,7,285,102,428,922,1,303,1,5553,5610,3303,1612,272,851,1139,458,141,303,473,2,101,179,452,16,3,71,14,12699,2939,339,1064,388,1410,367,609,186,132,1,9665,8270,4866,1662,361,9689,720,102,12,69,693,1007,7,1030,576,1127,243,10,148,2023,18,157,81,866,385,7858,1035,764,1618,4689,272,3,947,792,389,234,188,424,925,26,73,670,4634,2001,1328,6231,1385,530,449,218,870,1120,594,180,763,317,157,774,1,2261,170,8168,94,401,225,221,12,1298,451,371,100,372,172,357,4754,296,300,468,634,389,28,81,5,199,295,3220,506,133,192,452,25,179,6711,2851,4022,2916,1412,2144,555,979,93,1818,958,1179,2428,923,215,805,795,2,145,145,8135,376,190,1,193,247,326,2437,0,139,1184,254,1486,191,368,1035,1915,202,4,184,278,2100,142,2,565,685,563,540,477,368,168,97,390,1446,272,134,288,518,85,591,484,1566,10,236,564,639,691,389,1026,818,418,523,790,207,562,669,1020,132,220,631,255,70,1192,242,496,156,641,434,205,468,18,2100,4,220,291,184,175,810,388,348,363,835,469,1201,948,12,706,157,157,288,6,1139,369,938,811,954,910,563,62,219,7,3640,666,125,750,357,261,979,1782,9,462,387,417,188,235,565,389,151,1218,448,2676,1570,1604,565,562,1121,5424,974,215,862,221,498,252,377,1169,137,91,356,225,372,387,551,167,2278,105,447,77,298,1789,573,2769,340,603,386,220,514,130,5782,191,430,178,478,1492,3,388,2776,110,145,90,434,260,3,511,1217,629,390,1550,155,586,3056,258,1276,214,144,1838,216,1578,339,510,868,369,17,1216,516,602,761,1011,552,541,1522,2058,213,929,2500,297,99,433,513,5,158,1352,585,8240,3625,2576,2001,1570,1733,687,527,1233,8104,18446,8,54,0,0,1746,193,324,192,428,170,1009,4933,37,16,749,1328,516,259,562,94,2300,79,1030,588,1648,2611,387,783,95,8,389,2457,2767,379,615,1090,1136,0,398,549,3830,864,954,2472,509,880,1504,1982,2070,22941,35716,380,90,90,133,48,65,0,33,461,69,147,2,175,127,144,198,325,233,748,866,549,3462,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1380,319,747,236,297,634,340,91,89,96,731,950,237,78,249,448,4622,226,606,79,396,255,479,1310,314,190,246,377,365,1236,488,937,2074,1324,3548,3541,5577,39,121,78,454,140,401,196,317,67,169,81,338,90,176,264,50,272,241,58,134,633,632,49,292,50,66,120,90,293,90,1,95,224,506,766,88,99,463,100,77,248,228,171,45,427,272,729,103,168,342,279,231,1054,1253,332,1232,131,95,426,453,258,95,193,271,126,601,189,320,425,271,203,156,102,765,254,101,165,155,157,507,225,249,296,26,313,189,100,93,239,164,492,62,147,4,227,99,424,90,210,151,332,509,240,369,191,50,348,646,691,554,433,364,1005,89,466,1625,1105,1425,1594,832,1466,2380,2885,6688,5993,17297,43,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,4,9733,809,369,3484,330,140,68,6,8,72,17,22,299,440,1663,181,1090,260,3189,8554,4775,139,259,2753,280,160,154,421,199,446,265,326,337,2735,1366,137,197,460,20,140,327,304,132,89,575,15,427,53,1175,3698,591,553,395,141,161,155,69,90,2,0,0,0,0,71,18,422,23,57,247,1719,1142,726,229,623,2303,1060,286,106,44,80,60,30,121,70,93,1016,131,268,119,65,61,861,1237,436,54,406,62,4833,1507,4,23933,15,6,373,10,17,43,10,8,118,16122,1605,876,2790,1532,526,157,578,1009,102,70,225,197,85,1072,4376,985,1227,397,846,1474,175,2928,196,802,563,2542,418,239,1,390,194,395,425,737,466,39,184,1702,2426,752,852,355,450,155,241,569,66,129,7,1359,119,601,2009,886,1586,107,375,267,20,501,516,432,52,196,271,2,108,41,32,274,164,3345,23,647,315,918,318,827,319,1156,672,441,275,695,96,248,1853,755,1055,754,470,104,811,242,188,254,307,278,58,492,350,107,295,892,501,519,465,247,184,183,160,237,122,375,142,5,316,16,182,544,1,103,580,324,249,3,553,83,532,93,477,17,319,223,339,8,138,428,142,2,262,124,75,36,268,28,158,155,228,502,198,7,201,396,262,355,591,221,320,1,125,202,101,156,347,811,520,71,226,673,203,198,62,237,25,238,206,157,867,348,276,207,1430,1326,216,21,839,937,112,18,80,181,278,146,545,19,436,157,20,234,387,63,30,30,72,227,49,100,57,97,25,991,152,104,76,226,747,159,206,12,1848,178,320,151,325,26,138,309,104,181,133,200,85,97,199,964,284,366,249,70,168,184,653,1154,3,697,287,288,79,289,212,176,313,744,225,992,813,225,400,437,522,467,582,310,206,497,2125,180,460,135,593,141,229,57,164,919,495,192,20,118,248,2,1041,238,380,189,101,1033,336,416,199,398,751,199,196,599,193,748,1513,316,380,56,201,475,17,2,130,271,287,421,325,564,194,0,993,285,55,333,494,814,69,7,239,125,49,992,837,24,39,2,517,1,158,222,78,16,151,183,79,338,132,170,224,237,36,200,991,141,347,274,191,18,3,15,375,137,44,67,379,180,672,966,245,652,44,248,0,67,0,18,467,1629,353,290,67,284,84,446,287,783,281,179,2,143,18,266,231,14,269,338,222,183,384,260,1384,47,226,993,326,30,470,397,145,165,75,9,2,705,254,58,1152,471,975,66,1357,6,4,156,1,4,261,466,240,527,687,35,378,179,84,1118,100,193,0,288,318,324,102,221,179,4,560,14,186,0,5,179,563,1,161,16,198,317,131,365,273,75,78,195,114,137,15,137,75,281,600,461,61,257,182,342,3,642,721,561,72,2342,100,376,669,178,138,65,323,86,241,813,18,401,314,204,8,579,322,3356,2984,2993,377,79,209,186,20,832,1747,623,1137,306,2,222,2,158,1,1895,1526,1051,2,272,383,307,121,181,227,354,457,160,136,6625,5055,113,67,352,585,841,72,263,122,145,22,189,26,468,13421,310,283,124,815,778,1310,779,538,744,148,113,1,652,1023,546,10,274,131,1946,619,6481,4530,3079,1237,3661,2797,262,347,503,613,291,580,78,266,269,280,27,228,137,999,7,201,766,50,2579,3415,1,108,385,466,87,3,311,302,283,154,25,316,381,17,282,268,132,139,88,114,242,291,1801,21,8,72,367,1190,31,283,7,386,2,64,109,653,2406,2333,880,291,1,207,983,1331,5,168,75,2051,3171,527,183,2337,46,84,386,1604,317,18,644,250,153,222,238,2415,543,1858,2777,820,597,495,252,504,545,278,291,282,159,4,283,400,2249,291,290,526,1192,1091,308,176,482,178,889,4071,1518,124,46,375,597,361,342,281,505,238,4226,387,673,544,478,176,182,912,837,424,2,425,265,320,501,392,547,2475,4266,819,654,83,206,254,343,7,496,536,143,346,387,403,925,578,1254,342,995,647,859,492,786,537,400,477,343,318,106,820,47,50,70,177,169,373,375,596,561,101,74,991,209,1119,147,204,1404,214,319,178,222,1252,2444,9,420,209,325,401,680,269,280,427,992,741,654,358,342,357,268,42,279,345,595,264,2356,105,386,444,317,309,188,1290,112,152,136,0,617,3232,846,823,6,279,753,105,200,211,1080,342,267,876,3042,237,651,282,307,850,13890,24324,395,1421,997,3603,91,260,0,277,59,248,25,389,648,837,643,1522,122,2548,0,0,0,0,0,0,0,0,3551,938,548,151,2832,135,285,156,24,237,907,60,391,77,3,272,251,1561,2640,845,1954,258,5256,0,687,199,234,1160,195,473,953,142,407,43,323,16,865,23,91,49,194,593,863,152,1015,2244,34,69,197,406,39,86,190,17,466,730,159,792,2158,0,266,178,166,575,452,162,70,40,505,134,143,63,89,92,166,121,69,190,135,68,177,196,2,155,116,157,23,165,143,58,405,142,49,42,492,165,321,128,83,85,221,244,185,142,491,76,631,2,134,90,641,262,172,233,57,133,140,248,133,138,16,2572,393,1070,269,1520,0,1984,3231,128,3979,1755,151,2447,824,10957,2081,13,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,1733,299,70,91,309,31,176,315,41,17,10,281,2,6,86,6,104,22,129,4472,61,3090,6402,66,681,54,248,717,259,45,72,92,37,45,41,191,32,178,82,42,42,155,42,16,20,0,185,99,3,2,0,1,0,0,258,63,21,5,199,67,21,50,83,39,489,2380,3117,255,546,6738,1,2,5067,3235,2500,1792,923,177,249,286,320,106,306,152,592,154,284,155,386,48,175,1,165,76,158,308,392,234,122,131,455,705,674,850,1554,662,584,479,498,145,443,68,334,122,248,243,86,118,108,144,40,126,4,40,46,226,120,1312,4044,2523,24,2,651,889,857,147,477,632,310,127,130,110,109,92,87,12,146,61,166,108,517,16,93,518,77,233,204,49,321,456,7,234,156,191,118,341,396,885,357,399,320,158,163,193,64,316,57,136,110,225,214,130,158,44,644,209,69,255,113,26,628,98,356,201,93,126,1,178,519,62,84,406,1,463,42,136,251,35,71,148,84,278,93,29,149,187,392,85,26,126,168,210,118,1,218,102,107,433,674,94,133,104,30,70,186,42,112,131,304,161,67,89,519,137,132,149,477,520,477,0,192,196,22,24,71,407,81,11,117,0,25,3,147,14,232,521,75,77,0,78,0,309,87,188,157,26,2,0,0,256,74,187,418,86,37,0,362,122,0,0,0,0,112,27,164,69,240,258,104,357,168,110,159,129,386,6,0,54,69,4,72,111,0,691,68,41,186,108,194,303,74,199,690,75,198,254,2,50,52,165,65,208,174,45,152,49,1483,630,380,98,60,282,58,164,318,1,133,194,253,256,1426,855,2227,127,359,758,389,85,397,101,404,168,159,82,661,157,254,798,697,147,214,106,52,34,208,193,324,190,356,156,251,135,817,542,135,392,36,144,7,257,170,1126,651,1085,312,186,289,200,65,159,209,89,201,62,64,638,313,190,931,47,168,233,107,127,869,262,240,0,1,27,402,84,59,75,134,199,433,71,285,160,680,667,239,120,157,32,292,5,407,746,835,413,107,95,65,161,3,711,173,1,51,159,192,82,42,125,90,254,2,99,165,313,235,1018,140,28,319,37,669,399,46,1,127,70,78,240,201,277,267,97,149,330,403,185,221,88,320,255,1,76,435,164,270,109,77,323,3,629,40,199,335,2,159,85,37,5,59,229,125,406,113,167,289,83,160,443,1,31,143,36,291,64,148,6,93,64,77,106,210,74,0,126,105,78,44,0,88,125,159,398,209,10,73,296,184,507,354,294,455,268,2,239,290,970,349,6,87,225,718,364,172,4,8284,21738,50,0,0,0,0,11559,51,201,14,25,55,15,80,180,1,80,68,31,52,49,87,173,425,4908,0,0,0,0,1054,34,98,111,84,43,81,279,27,444,42,51,171,37,177,42,857,7549,0,0,113,299,286,392,199,33,96,112,13,140,85,44,80,54,16,258,97,177,3,79,26,806,41,80,474,84,78,259,13,197,1630,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,4,12,2047,377,183,223,286,181,310,2,2,94,27,353,6568,7041,10,2,2,73,56,1341,626,2,285,94,74,3,47,67,229,158,132,195,63,74,183,135,1,2,1,1,0,1,97,29,57,152,210,2,9172,3648,1118,129,2692,290,438,74,191,103,164,877,161,43,17,328,95,151,132,1,112,114,3,318,535,127,578,298,143,427,185,570,29,926,374,972,127,2545,720,168,1136,522,124,779,548,148,160,570,59,38,285,34,87,304,1,250,119,722,68,54,407,330,71,423,148,134,368,81,32,105,245,1073,6176,2,2,153,433,290,114,58,133,106,74,151,357,75,176,248,137,89,114,135,392,459,64,7,133,112,151,451,138,70,51,80,36,11,594,12,75,158,213,203,401,173,349,173,211,47,68,131,29,13,51,84,8,115,38,52,9,163,168,110,104,331,75,119,16,1,59,105,282,51,111,333,595,212,201,132,332,162,82,283,79,115,44,333,8,0,200,114,17,334,155,120,152,130,0,92,20,1,111,596,2,175,142,0,3,266,196,197,130,105,126,174,129,155,63,11,2,179,76,18,81,60,100,200,175,114,1,73,3,0,28,14,206,72,40,152,125,146,15,159,2,111,63,113,212,180,44,0,202,0,110,2,6,180,12,211,150,30,211,367,1,501,189,258,52,5,96,171,97,148,300,332,163,47,36,333,42,12,110,0,430,95,577,291,136,4,72,131,1,0,78,58,55,58,444,128,143,103,59,381,101,636,971,127,519,114,20,70,49,90,90,1128,546,111,1137,755,30,151,230,43,127,104,9,132,230,923,303,34,56,263,62,356,239,182,174,140,6,254,152,290,90,252,131,134,114,34,221,216,15,78,0,83,153,137,14,105,67,102,46,1235,459,324,126,200,349,425,117,43,163,180,207,145,34,605,0,210,773,62,137,91,1509,115,322,12,382,47,57,13,1308,104,1,5,261,211,202,143,3,428,80,239,596,147,151,128,366,103,50,90,133,365,126,160,81,61,184,147,6,1,111,79,1,81,57,264,132,159,90,180,60,3,39,116,1,142,127,103,3,57,137,345,176,660,29,126,106,88,409,4,303,597,21,6,285,123,131,74,153,89,0,260,596,400,152,261,132,95,131,1026,127,127,87,127,98,595,130,473,174,209,187,852,346,424,261,205,365,1343,1993,73,173,309,287,102,208,2,182,112,185,206,168,1253,201,136,111,152,963,0,70,48,483,449,258,401,149,870,725,460,2,179,142,136,79,345,581,0,229,1179,0,1225,97,135,79,27,179,1283,161,285,31,1,16,504,933,344,115,135,3,11,512,96,5131,8598,85,38,90,42,52,17,8,2,52,28,93,9,18,28,350,204,702,1272,6167,0,0,531,77,78,72,88,99,79,200,56,272,187,217,437,1628,4374,70,44,484,12,77,114,91,73,128,53,2,16,61,100,1,55,38,4,23,544,111,30,104,549,556,14,26,175,554,38,77,51,27,92,7,0,164,51,151,72,43,196,65,582,96,196,131,134,1156,4602,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,2,1,0,0,1,0,0,2,1,0,0,0,4,1,0,0,1,0,1,0,1,3,1,1,1,0,0,0,0,0,0,1,0,1,0,1,0,1,0,4,0,4,0,1,0,2,0,0,1,0,3,4,0,0,0,0,0,0,1,0,2,4,2,0,1,0,2,0,3,0,3,0,4,0,1,0,2,0,0,1,0,1,0,2,1,2,4,2,1,0,0,1,1,0,0,1,0,1,0,4,0,1,1,1,1,1,2,1,5,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,2,0,1,1,1,40,32,8,12,13,1,31,27,14,16,5,4,27,8,8,4,4,13,44,14,4,4,3,6,27,16,2,21,26,26,5,5,4,2,1,10,10,10,4,8,1,2,4,4,36,18,8,6,15,3,1,16,29,6,3,2,5,1,1,3,3,1,5,2,3,0,24,28,10,6,1,1,0,0,0,0,0,0,0,34,18,17,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,23,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,1,1,1,1,1,2,14,1,1,1,3,3,2,1,3,6,1,1,1,2,1,1,0,1,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,10,2,3,1,3,4,2,4,24,1,3,2,1,13,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,1,0,1,0,1,2,1,0,23,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,2,1,0,1,0,1,0,1,1,1,1,0,0,0,0,1,1,1,1,2,1,3,1,1,1,2,4,5,3,2,1,2,1,1,6,4,2,2,4,1,2,1,1,1,12,1,3,5,4,2,4,8,4,13,1,4,3,5,15,2,9,1,1,2,1,1,1,2,1,1,0,0,2,0,0,0,1,0,0,0,2,1,0,0,0,1,0,2,4,0,0,2,0,0,0,0,0,0,0,0,0,0,3,1,2,1,0,0,0,1,1,0,0,3,3,0,0,0,1,0,1,0,2,0,1,2,1,0,0,1,3,0,0,1,0,1,0,1,0,2,1,8,8064,1870,228,329,253,19,175,163,617,273,5,14,54,263,2806,13834,8428,231,3,152,476,759,3,1,1001,139,168,145,165,5142,1262,124,170,141,135,196,90,1105,941,125,171,371,311,331,255,5,0,0,176,110,50,614,272,6,14,136,5,15,55,264,318,197,2546,812,137,25155,8,5,26933,339,1617,7958,15102,867,22,83,109,1,271,202,1,528,187,3605,649,1491,631,4,52,8,339,587,27,25,111,32,306,279,973,845,212,4025,12971,9,256,356,425,458,12,2027,1809,2620,258,352,128,227,14,15,149,112,270,64,290,351,489,112,109,141,1658,668,14811,163,8645,1376,795,680,241,2326,2477,855,26,175,85,325,550,174,413,1,1098,431,418,170,127,735,14614,3289,5546,457,2382,708,512,459,559,222,561,130,406,220,482,190,648,781,1152,123,159,1178,190,117,302,394,629,525,390,3247,531,1208,734,18,78,162,30,530,1054,31,283,478,49,422,13,6,11,191,1132,194,118,148,114,505,1055,242,2118,358,111,32,151,2182,232,275,303,800,330,153,142,28,6,176,477,190,324,551,460,124,52,630,328,0,83,0,1,2372,237,182,0,11,0,432,391,420,203,168,150,2,0,304,653,0,691,139,150,2,50,32,6749,16865,139,162,2995,499,1189,694,1161,661,976,552,371,347,534,61,60,389,8,389,57,6,475,266,55,1674,6577,247,781,2161,527,1255,344,3,506,257,288,100,578,4,67,238,183,50,10,113,383,860,551,12038,3898,1877,2071,2634,1910,1188,89,513,850,369,122,704,594,317,0,503,519,234,694,399,141,63,126,614,424,2319,360,718,692,420,140,188,271,438,139,242,94,566,112,29,4530,2117,738,1134,2789,2602,1994,75,509,475,432,219,33,17,222,397,334,99,428,209,723,2252,150,2203,1859,470,1232,243,650,393,1128,917,944,141,272,65,23,9,222,102,429,29,57,453,1036,703,197,1612,25,110,529,214,926,286,471,173,288,220,21,218,970,120,2075,2213,227,1238,504,311,209,2,174,203,40,513,976,1787,280,243,263,575,1075,356,259,230,2,136,286,275,306,623,325,254,95,488,869,233,2374,1133,1050,205,113,266,592,74,397,29,206,108,168,274,438,218,342,529,412,651,68,849,195,801,69,335,1182,1354,428,1038,597,288,259,618,1728,632,150,311,143,682,1212,387,35,120,2030,1201,820,1361,1366,303,442,396,74,22,347,508,696,33,1356,24,514,139,74,565,289,317,413,121,616,394,851,483,131,26,1326,50,1936,530,28,505,1016,331,411,457,301,472,4,2218,213,254,413,77,533,597,10,562,1000,280,3026,126,641,551,762,696,982,967,345,278,1778,190,931,220,147,51,355,156,214,2093,191,2667,170,197,242,1472,211,635,339,330,5,256,251,514,2367,149,71,221,573,1,333,617,412,946,28,285,326,7,196,241,640,539,428,550,529,1473,1,506,233,470,189,210,76,107,696,515,137,332,167,693,383,564,683,178,1903,520,3005,236,398,639,549,437,97,219,598,1002,325,236,175,182,523,666,113,0,597,695,393,487,488,684,73,528,1451,1428,2578,5,1621,2387,8073,16,225,482,3674,39,238,2930,8045,77,583,15980,111,34304,14970,31,88,17,95,129,445,31426,97,142,280,152,176,183,54,106,379,478,56,451,1360,17109,145,60,125,90,6,441,879,134,711,5,857,1,327,81,19,285,315,121,387,133,804,867,1118,1594,1533,6254,0,371,595,15,497,489,167,161,699,420,108,2,187,208,436,155,90,483,272,424,895,809,1276,2423,5705,369,142,76,514,61,14,11,344,151,124,84,3,487,96,166,5,160,276,165,531,176,141,281,145,327,164,70,167,195,133,164,144,87,56,107,194,1,153,195,89,431,188,6,4830,66,134,125,179,154,175,385,400,663,381,4970,77,316,203,9438,0,197,128,80,133,18,271,71,374,182,280,543,242,181,150,124,261,964,132,190,94,816,1549,413,166,358,1260,312,846,2232,699,2188,2239,2606,2459,14242,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,1,0,2,0,1,0,1,1,0,1,1,0,0,1,1,0,0,1,1,1,1,1,1,0,0,0,0,0,1,0,36,474,1,56,3710,54,7,59,93,25,106,38,250,18,138,243,613,607,589,2241,1644,790,207,18,411,366,149,68,37,321,436,1311,127,1,5,23,10,2,2,1,78,299,78,17,77,155,323,24,141,523,278,568,313,140,16,31,39,18,47,160,64,437,21,14,79,52,5,6,266,35,3,79,7,41,18,3,94,5,22,18,4,1,13,45,47,3,5,5,15,17,2,25,59,65,11,371,72,2,49,85,11,31,10,4,157,135,2,57,53,3,41,26,27,7,24,117,49,28,34,18,44,27,25,92,302,414,175,6,25,88,101,72,47,7,4,391,407,476,106,49,87,55,21,15,20,7,7,6,5,703,328,342,19,58,21,241,21,5,12,2610,977,245,55,223,157,61,55,100,234,230,74,17,10,4,3,5,1,3,2233,384,67,36,472,369,254,322,252,210,58,987,171,14,28,16,5,6,12,9,4,5,4,6,838,120,319,473,365,135,475,139,744,40,896,155,6,31,19,5,3,8,13,8,3,122,140,323,96,134,140,201,172,286,162,6,10,8,9,12,3,1,62,20,68,102,111,76,5,117,202,40,44,93,42,49,607,251,412,181,146,109,547,28,4,7,1,424,115,298,620,94,700,85,8,468,191,274,41,436,54,11,884,452,372,238,48,4,786,314,942,141,19,3,1615,2480,203,14,3291,28,9,11846,311,36,16,3,4,4,3,1,4,10254,763,244,93,15,13,3,1,5,0,0,0,8736,720,117,20,2,21,0,8293,376,7,8,1,1,0,0,7953,95,32,10,4,11,5,6,7,6067,181,20,15,12,6,2,6,6,5,15,2,1,0,0,4373,108,48,42,20,5,1,2,18,16,1,0,0,0,0,0,0,2927,196,56,28,11,12,1,36,16,1,1,0,0,0,0,0,0,1976,188,62,31,14,6,7,7,32,40,0,0,0,0,0,0,0,0,0,0,0,1495,103,26,23,5,36,16,0,0,0,0,0,0,0,0,0,0,0,0,972,77,40,16,14,7,79,50,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,530,107,31,22,5,5,49,62,3,1,0,0,0,0,0,0,0,0,0,0,313,56,14,7,51,50,5,1,1,0,0,0,0,0,0,0,0,0,0,196,60,18,14,26,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,54,8,19,44,5,0,0,0,0,0,0,0,0,0,0,0,0,0,62,50,29,2,0,0,0,0,0,0,0,0,23,57,29,1,0,0,0,0,0,0,26,18,0,0,295,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,22,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,3,0,0,0,1,1,2,2,1,3,2,11,17,3,1,5,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,2,1,0,1,0,1,1,0,0,1,1,1,1,1,1,1,1,1,3,3,5,10,2,13,6,2,2,1,1,2,2,2,1,1,2,1,0,0,1,0,0,1,0,0,0,1,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,11,3,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,1,1,0,0,0,1,1,1,0,0,1,1,4,2,3,1,1,1,1,0,1,0,0,0,0,0,0,0,0,0,5,2,0,0,1,0,3,4,3,1,0,1,1,2,4,4,1,2,5,6,11,1,8,1,13,4,7,1,3,3,57,10,2,2,3,19,42,3,1,2,5,4,4,2,5,6,2,2,3,1,1,4,1,1,1,1,2,2,1,2,2,2,4,0,0,5,0,0,18,4,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,4,1,0,1,0,1,1,2,6,0,0,0,0,0,0,0,0,1,3,2,1,1,0,1,0,0,0,0,0,0,1,0,1,0,2,1,2,3,4,6,5,6,0,0,0,0,1,0,1,1,0,0,1,0,4,1,5,6,0,0,1,0,1,0,1,45,16,5,1,21,10,28,13,15,1,6,3,1,1,1,28,4,3,3,1,20,2,5,51,10,9,2,1,1,5,4,20,1,6,28,14,11,2,1,1,2,4,12,2,4,2,1,2,1,1,4,3,4,3,2,1,2,0,1,1,0,6,16,4,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,2,0,0,0,0,0,0,0,36,8,4,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,3,1,1,2,1,1,0,0,0,0,0,0,0,0,0,1,13,0,0,0,0,0,0,0,1,0,1,1,2,3,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,1,2,1,1,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,1,4,2,4,1,5,2,13,7,1,2,8,14,4,4,7,1,1,8,2,84,3,3,12,1,1,1,8,5,7,3,5,21,1,4,1,10,5,4,3,1,1,0,0,0,13,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,11,1,8,1,22,0,4,0,11,0,0,0,0,0,1,0,2,0,1,0,1,0,1,0,1,0,4,1,0,0,1,0,1,0,1,2,0,0,1,0,1,0,1,1,0,0,1,0,1,2,2,0,0,0,0,2,1,0,0,0,1,1,0,0,1,7,1,1,3,0,0,1,0,0,1,0,1,0,1,0,1,0,1,1,2,1,1,1,6,3,1,1,1,7,22,12,1,1,2,10,79,1,29,1,1,50,9,105,3,7,2,2,1,2,1,2,1,1,1,0,0,0,6,0,0,0,0,0,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,2,4,0,2,0,1,1,0,0,1,0,2,0,1,1,1,3,1,1,1,137,52,6,3,14,3,4,3,4,15,9,8,11,2,4,1,119,23,36,34,29,7,1,2,2,11,99,27,1,5,5,2,3,1,35,40,22,37,16,4,5,4,18,72,38,6,6,4,1,10,8,19,23,4,21,5,12,1,2,19,14,11,13,48,10,7,1,1,5,1,32,21,6,3,4,4,51,12,10,3,8,6,43,5,12,70,39,12,7,5,1,12,26,68,34,12,6,2,1,5,1,19,6,6,4,3,4,2,1,6,2,6,1,3,3,44,18,6,1,1,0,0,0,191,52,15,19,9,7,6,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,18,41,22,10,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,37,29,29,10,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,14,7,7,0,0,0,0,0,0,0,0,28,9,12,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,28,15,0,0,0,0,0,0,0,0,0,0,0,0,0,14,5,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,2,2,1,2,7,3,8,1,1,4,1,1,1,1,1,1,1,2,2,3,7,1,1,0,1,1,1,0,0,0,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,183,73,5,7,1,15,28,26,10,5,201,19,26,17,3,6,10,3,97,49,26,16,26,23,99,7,5,2,1,114,160,27,10,1,1,12,4,3,7,15,22,18,1,1,23,22,19,6,2,1,5,8,10,81,81,17,8,8,1,9,7,3,2,8,19,3,2,1,1,1,4,15,12,2,2,6,194,48,16,5,1,0,0,0,0,0,201,75,14,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,38,1,3,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,3,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,0,1,0,1,0,2,1,1,0,0,0,0,1,1,1,1,1,1,4,1,2,3,2,1,1,3,6,5,1,1,2,3,1,1,1,1,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,0,3,1,1,2,1,0,0,0,0,0,0,0,0,1,0,1,0,4,6,0,0,1,4,1,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,2,1,1,1,1,0,0,0,0,0,0,0,1,2,1,0,1,0,1,0,1,0,1,0,1,0,1,1,2,1,1,1,3,8,2,1,4,2,6,11,2,1,2,1,2,3,6,1,1,1,1,1,1,1,1,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,11,2,2,4,8,4,4,1,6,1,1,5,2,2,7,6,1,1,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,2,0,0,0,7,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,1,1,1,2,1,1,1,1,1,1,2,1,2,1,1,1,1,3,1,1,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,1,1,1,1,0,0,0,0,0,0,0,1,3,2,4,1,1,1,1,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,0,0,1,0,66,177,2,1,1,121,1,709,112,318,9,404,122,78,111,223,9,9,79,613,401,410,403,335,450,1166,159,29,9,3,1,1,36,47,35,145,23,92,53,18,23,58,71,21,123,9,24,9,11,2,9,16,5,33,45,6,2,84,44,18,42,77,24,54,58,6,1,57,13,20,20,77,36,36,14,103,123,36,170,30,2,2,2,3,26,20,62,26,24,6,4,2,9,3,21,93,91,15,15,2,10,8,13,81,9,23,5,2,1,11,93,31,41,38,54,36,41,2,10,6,9,2,12,8,34,41,7,206,119,44,149,80,159,23,200,185,169,25,152,6,261,179,179,300,36,508,173,354,25,569,1084,72,1,0,0,1568,26,12,0,0,4182,41,9,6,2,1,0,0,0,0,0,0,0,0,2624,140,25,3,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1620,90,3,1,2,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,868,10,16,10,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,68,44,13,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,15,3,5,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,7,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,15,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,3,2,1,0,0,0,1,0,1,1,1,42,7,5,9,5,32,55,1,5,2,145,11,3,1,1,2,2,6,8,24,2,1,31,4,2,1,1,2,6,9,3,2,1,1,2,4,1,0,0,1,1,0,7,1,1,8,0,0,0,0,0,0,0,0,2,2,4,30,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,0,0,0,0,0,0,3,0,0,0,13,2,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,2,0,0,0,0,0,5,0,5,0,3,2,1,0,0,0,0,0,0,1,0,1,0,2,0,0,1,2,0,0,0,2,2,0,0,2,0,1,0,1,0,1,1,0,0,1,1,1,2,0,0,0,0,0,1,1,0,0,2,4,1,1,0,0,1,2,1,0,1,0,1,2,1,1,1,4,1,12,6,3,1,2,3,7,1,1,15,15,1,2,1,3,9,5,3,4,12,9,5,6,2,5,5,10,2,13,7,1,3,12,0,0,1,0,0,5,0,0,0,0,0,0,0,8,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,2,1,1,1,1,1,1,1,1,14,11,7,1,1,2,1,2,3,1,5,23,12,21,5,4,10,7,1,2,2,1,1,1,2,7,1,5,3,10,4,4,1,3,2,2,2,1,1,1,4,11,1,16,2,5,1,3,2,1,1,1,1,1,2,2,1,2,5,3,5,2,2,1,3,1,3,3,3,1,2,1,1,2,2,1,2,1,2,2,2,1,3,2,1,1,1,2,2,2,1,2,0,5,2,0,1,1,0,1,1,1,2,1,0,0,2,1,0,3,8,6,1,1,2,0,0,5,7,1,1,3,2,1,5,0,0,0,0,0,0,1,1,3,1,1,2,1,3,3,1,3,0,0,12,7,14,6,6,7,4,2,3,1,2,2,1,37,2,2,0,0,0,0,0,0,0,0,3,2,2,2,3,3,2,6,5,0,0,0,0,6,1,1,2,3,1,3,0,0,0,0,0,0,0,6,2,3,2,3,2,6,1,0,0,0,0,1,4,0,0,0,0,0,1,3,3,1,2,1,1,1,0,0,0,0,2,3,1,2,1,1,0,0,0,0,0,2,1,1,1,1,1,1,0,0,1,1,1,1,0,0,0,2,2,1,2,1,2,0,0,0,2,0,1,0,0,0,0,0,2,0,0,0,1,1,0,2,1,1,0,0,2,1,0,1,1,2,2,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,3,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,1,1,1,1,3,2,28,6,4,5,2,2,5,1,1,89,92,27,21,2,2,2,1,1,26,8,1,2,1,1,109,47,20,3,5,1,7,8,2,20,5,3,8,2,1,1,1,230,54,7,11,1,4,2,2,3,10,5,8,60,4,11,1,1,1,1,192,8,37,23,16,10,1,5,8,15,41,41,65,36,8,4,6,1,1,1,35,29,44,41,8,2,2,4,24,71,106,22,52,10,10,1,1,5,3,1,3,21,10,2,8,8,2,9,2,9,7,3,11,39,14,21,6,8,2,2,1,20,13,9,17,29,4,6,4,1,1,6,13,36,22,14,7,7,2,6,18,5,7,1,15,9,3,2,1,2,4,1,1,1,5,2,5,2,21,32,5,8,3,2,2,0,0,0,62,71,25,2,2,1,2,0,145,43,25,5,3,0,0,0,0,0,0,0,0,0,0,0,152,141,23,22,3,3,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,157,31,16,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,48,6,11,4,3,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,2,6,9,2,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,7,9,3,4,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,1,1,0,0,0,0,1,0,1,0,1,1,2,1,1,0,0,0,0,0,0,2,2,0,0,1,2,1,5,1,0,0,0,0,0,1,2,4,1,0,0,0,0,0,0,0,0,1,0,1,0,2,1,1,1,1,1,4,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,2,1,0,0,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,2,1,1,3,2,5,1,2,2,3,1,2,2,1,4,4,7,4,1,1,2,2,3,5,3,2,2,1,4,1,14,1,3,4,2,3,4,3,1,13,4,1,1,1,2,5,6,2,6,6,2,10,4,2,3,2,17,7,19,30,45,55,7,2,5,12,8,20,1,2,2,2,2,2,0,1,3,1,1,0,0,1,2,0,6,1,1,0,0,0,0,8,1,3,0,0,0,0,3,2,6,0,0,0,0,0,0,6,4,6,1,0,0,0,0,0,0,21,9,1,0,0,0,0,0,0,0,0,15,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,2,0,1,2,0,0,0,1,0,40,19,13,4,2,2,1,2,1,1,2,2,1,71,27,5,5,1,3,1,1,2,2,1,2,148,2,5,2,1,6,3,3,8,1,4,1,3,1,167,23,6,16,1,7,25,18,46,6,32,33,37,24,25,65,20,31,13,4,16,1,2,3,6,2,4,1,1,31,1,2,2,10,34,12,4,27,24,23,10,10,6,16,7,1,11,1,1,2,5,1,4,7,2,2,24,6,14,14,10,1,4,2,1,2,2,4,3,4,2,10,7,1,3,12,3,3,5,2,3,4,2,3,2,1,5,3,1,1,11,3,2,1,19,12,20,8,2,15,4,3,5,4,1,5,31,32,1,2,3,6,3,24,5,12,14,8,5,1,3,4,8,33,63,20,14,11,12,11,19,9,6,2,2,44,35,44,26,12,11,1,10,4,2,59,32,70,20,57,9,7,9,2,2,70,55,70,56,7,16,11,3,5,6,1,1,57,94,76,11,14,5,4,1,10,5,7,2,4,5,1,1,108,127,39,22,29,20,3,3,4,1,241,86,92,13,37,8,7,6,10,3,2,1,6,2,382,330,61,51,5,1,1,20,6,32,18,4,3,6,4,2,5,23,3,1,3,410,125,53,28,21,12,5,24,10,13,2,6,10,2,30,2,1,1,2,352,288,156,44,22,8,9,15,8,48,79,11,48,43,11,4,11,9,75,25,1,1,294,74,35,38,5,6,7,16,21,40,56,31,15,16,5,11,14,6,9,8,53,19,3,3,228,65,42,3,26,20,113,85,29,63,29,2,23,11,8,5,15,111,9,18,2,62,25,16,10,89,14,59,68,44,27,32,10,13,9,9,27,14,14,53,29,5,12,49,14,31,31,16,18,10,10,14,11,63,4,3,2,1,27,17,30,18,51,8,4,8,36,5,1,18,4,5,10,9,3,19,8,4,8,7,8,54,8,37,28,13,3,2,15,1,19,43,17,15,8,5,8,36,18,33,13,3,3,225,44,71,16,17,6,2,4,3,25,0,183,164,70,53,22,8,15,3,5,4,10,56,18,5,1,1,0,0,175,37,28,38,31,3,7,22,10,8,1,0,0,0,0,178,153,28,21,28,25,4,8,48,41,1,4,0,0,135,45,30,12,9,5,5,4,9,98,13,11,2,0,102,47,39,49,9,8,6,12,1,13,45,31,2,2,0,0,56,36,29,12,29,5,6,66,13,13,81,18,13,7,2,9,3,45,18,5,2,54,21,22,5,12,32,26,12,1,0,18,34,12,24,5,75,16,10,1,21,11,6,13,12,6,5,5,0,30,11,8,4,11,28,12,2,30,46,9,4,36,46,7,1,1,0,8,3,3,4,26,7,4,16,92,28,7,0,93,21,1,0,727,137,30,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,586,81,9,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,357,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,2,2,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,1,0,3,1,1,1,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,0,0,128,2,0,0,128,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,1,2,2,1,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,0,1,0,1,0,1,0,1,2,1,0,3,1,1,2,1,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,2,0,4,0,1,1,1,0,0,0,2,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,3,0,0,0,0,0,1,0,1,0,1,0,1,0,3,1,1,1,2,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,1,0,1,0,2,1,3,2,1,4,3,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,1,1,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,1,1,0,0,0,0,0,2,0,1,0,1,2,1,0,1,0,2,2,8,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,1,1,2,1,10,0,0,0,0,0,0,0,0,0,0,0,1,6,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,2,1,1,2,1,3,1,1,3,3,1,24,3,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,0,0,2,0,1,1,2,2,2,1,1,1,1,5,1,1,1,1,2,1,1,1,2,2,1,9,1,7,1,2,2,3,2,1,1,2,1,1,1,1,1,1,1,1,1,1,2,1,4,1,1,3,1,2,3,1,5,1,1,1,1,2,2,9,2,3,2,1,2,1,2,1,2,3,4,2,2,1,3,1,3,3,1,1,2,7,5,1,3,1,3,1,10,3,8,13,8,7,6,1,2,16,12,13,17,7,3,18,9,20,9,6,3,2,4,1,32,38,19,23,3,1,3,3,2,61,27,20,4,6,2,5,5,8,154,84,5,1,3,3,5,3,2,5,45,35,6,193,32,20,2,1,3,2,25,6,8,5,3,5,4,4,71,83,6,1,80,19,3,1,2,4,5,3,14,8,5,6,3,4,4,7,203,168,3,1,6,9,2,13,7,3,11,6,55,56,12,1,5,3,13,5,16,24,1,7,7,11,1,2,1,6,2,3,1,3,2,0,2,3,1,4,2,4,0,12,4,14,3,13,0,10,10,2,1,6,8,10,10,0,7,2,0,4,13,8,0,12,0,0,0,13,4,0,4,2,11,5,1,2,2,3,3,3,27,5,0,308,16,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,18,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,1,1,2,1,1,4,1,1,1,1,1,1,2,2,3,1,1,1,1,1,1,1,1,1,1,1,3,2,3,2,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,1,0,1,1,0,0,1,0,1,1,2,1,9,3,10,4,3,1,50,1,1,3,17,2,27,4,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,12,1,2,1,1,7,13,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,1,0,1,0,2,0,0,1,1,1,0,0,0,2,0,0,2,0,1,0,12,0,0,0,0,0,1,2,1,0,4,1,1,3,3,2,1,4,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,5,0,0,0,0,0,0,0,2,0,1,0,1,0,2,2,1,1,1,0,0,0,0,0,0,0,1,0,2,1,1,0,0,1,1,1,1,1,1,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,3,1,1,2,2,2,2,1,2,3,2,1,1,1,2,1,3,1,2,1,1,1,1,4,1,2,4,2,13,1,1,1,3,3,2,2,1,4,3,1,2,2,1,2,1,3,6,1,1,2,4,5,1,3,8,3,1,1,5,2,9,6,3,2,6,1,4,2,4,11,3,2,14,14,2,4,1,2,4,4,3,1,0,0,1,4,0,1,0,0,0,2,1,4,0,0,0,3,7,0,1,0,0,0,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,7,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,1,0,1,1,0,0,1,1,2,1,0,0,0,0,1,0,1,0,1,0,1,1,0,0,3,2,5,2,1,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,3,3,1,1,1,1,2,3,1,1,1,2,1,11,5,1,1,1,4,4,20,1,3,1,1,3,2,4,1,2,2,1,1,0,0,0,3,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,1,0,1,0,1,1,1,0,0,1,0,1,0,1,2,0,0,0,1,0,1,0,1,3,2,1,2,39,67,1,1,157,3,1,1,1389,2365,207,19,3,2,6,1,1,1,1670,7,8,5834,287,106,18,9,6104,1015,80,30,47,20,15,23,149,26,1,5,6091,483,112,110,80,68,21,8,45,118,65,32,4543,1018,437,129,112,88,27,14,8,77,258,1043,126,129,5,5,1957,920,406,233,23,17,169,278,1076,198,171,10,1127,360,315,98,27,49,134,918,217,28,6,8,1,510,354,110,22,14,167,338,850,294,110,338,74,29,71,177,667,92,95,6,3,126,33,37,131,905,168,100,1,22,50,37,351,81,35,6,63,7,15,28,30,32,21,20,116,487,1397,24,59,0,5997,942,42,14,11,1,0,6128,217,20,4,1,5831,260,76,30,3,0,0,0,3804,692,76,17,5,1,0,0,0,3097,244,34,12,1,1,1,0,0,2477,260,57,6,7,2,4,0,0,0,0,0,0,0,0,1729,229,21,24,18,3,1,0,0,0,0,1312,49,30,16,2,8,5,0,0,0,0,0,0,0,0,0,0,0,415,192,136,23,22,22,5,0,0,0,0,0,0,0,0,0,0,0,0,155,118,15,15,11,3,0,0,0,0,0,0,0,0,0,0,0,164,18,30,15,1,0,0,0,0,0,0,0,0,0,0,0,0,78,72,46,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,26,5,0,0,0,0,0,0,0,0,0,0,63,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,2,0,1,1,1,1,2,1,0,0,0,0,0,1,2,1,0,0,0,1,1,1,1,1,0,0,0,0,1,0,1,0,1,0,1,0,1,1,0,2,1,0,0,0,1,1,1,1,1,4,12,1,2,1,0,0,1,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,1,0,0,1,0,1,0,1,1,1,1,1,0,0,0,0,0,1,2,1,1,1,1,1,1,4,2,3,7,3,3,5,2,12,16,2,7,0,0,1,1,0,0,4,0,0,1,0,0,0,0,0,1,0,2,4,2,0,0,1,2,1,0,1,0,14,21304,1192,2231,852,8966,340,113,16,3,2039,33,1342,352,331,1557,19783,1163,1037,28,11,9,1,5496,1869,521,2932,333,857,403,154,621,392,7468,353,1256,2797,8,503,173,1549,426,1639,147,774,130,2516,167,522,468,387,1125,229,219,129,215,206,219,220,329,2239,11302,328,164,791,336,341,564,114,792,14,2,1,91,473,220,2317,466,122,6,34,130,551,207,220,867,440,900,402,502,354,501,172,848,1794,4851,142,52440,6746,2,56162,9,1,1,2,51233,37368,1242,7707,6694,1308,5,420,247,344,4,1145,1301,3931,5388,409,7,1293,1012,1241,437,6,2,2,5,267,2,14,661,7,1,17,3,84,1,4,4,1,10,722,1,31293,1165,2616,6870,874,453,345,1545,2855,1337,726,317,261,200,453,3,40,36,2547,18471,16879,7626,718,1957,1508,1965,586,265,918,4952,4274,1854,217,199,410,211,547,278,755,469,6,1391,1588,1822,187,309,364,18,521,160,11715,5351,641,447,773,3812,3728,1350,451,733,9,666,4,496,180,190,5045,825,1754,1353,945,1032,1408,1560,10328,9816,1323,1759,1328,2276,681,1830,4,498,334,3921,211,1171,8779,4134,991,624,9,605,41,52,642,1443,829,1631,1575,1,749,1132,520,624,421,692,643,926,197,231,642,210,719,1039,927,341,946,5,1966,1322,575,310,2686,597,643,750,309,1997,1094,754,269,2,433,1,4325,6419,3,297,185,2,3,211,3,1050,29408,4599,1105,472,2721,1048,387,1245,1239,110,1045,64,35,5,101,3,506,9,404,6,3,7,346,7,12,2799,11419,3169,396,16090,6212,7951,3691,3695,471,954,2860,1990,5,8,282,479,262,581,517,1163,1619,201,4,342,1380,7,5,157,377,7,2,1,84,2,467,1,1847,7,949,4310,1976,3509,2972,622,539,1953,3497,980,5,2367,2,5,465,10,4,3,347,345,383,4,655,404,627,1,1107,4901,1286,2024,717,564,3,730,523,2,472,625,579,1977,870,8889,4132,1718,2448,2268,2854,395,1978,784,252,622,2,348,48,8,2,298,369,611,452,657,274,2,751,2,307,5289,9338,1958,938,734,1238,451,1601,349,1071,8,862,2510,4,545,246,956,335,653,2,705,6308,1372,592,183,2099,2065,188,1297,562,931,429,9,6,558,118,6,1375,4,782,626,464,322,766,618,8887,534,2390,2709,1549,13,2389,368,1211,199,1654,585,1127,518,1210,1258,594,5,115,10,363,2,3,238,522,770,668,3,5244,752,618,1989,1203,757,3519,2697,13,1563,87,3,2757,258,9,1300,4,3,212,13,348,2364,436,939,246,4,5,2188,184,205,347,718,111,611,273,6138,3019,971,1134,1538,1927,814,377,2911,2457,71,846,5,375,296,1254,1551,608,672,9,360,989,455,986,5,686,310,857,577,0,0,1659,554,4,894,288,9,460,1977,8,187,653,7,964,346,3621,849,2608,6185,1714,1726,667,8,509,862,415,1089,7,32,593,779,33,196,501,262,607,6,486,1714,1537,3,421,1172,1019,350,560,631,1583,1074,270,607,7,683,160,3,263,196,171,972,3,1566,1157,1654,1139,1297,2,434,1426,608,671,590,268,13,278,618,14,0,0,428,6,929,37,471,956,1195,3294,2548,1861,1569,333,1037,439,658,406,3,963,238,2,799,606,302,0,1495,1044,3913,342,811,362,949,4,446,406,419,11,354,576,186,0,1658,595,2959,575,555,2122,764,1685,418,795,285,550,286,0,1951,1777,841,4118,1964,446,908,1661,925,209,911,1383,597,4165,606,1804,258,539,1529,7,1078,669,391,1264,1690,311,1689,979,933,339,1136,1,3495,983,237,522,92,1413,1367,1369,1199,1186,218,1777,274,3830,3188,834,1162,1796,5377,3134,243,1347,5,1585,434,37,464,358,1426,1030,2573,1400,2956,1695,1614,586,5,258,1145,1,70,947,1540,17,426,2099,235,0,934,1018,5345,1232,1359,725,794,3,1747,819,1353,719,495,1358,933,626,257,1699,612,2542,343,743,502,7,445,911,269,0,6558,1727,2253,421,6,1283,268,2114,3140,991,3,2953,10192,4018,884,730,830,781,1240,314,347,1851,654,273,2101,3617,1,0,0,8318,6695,1062,1748,377,7,400,2596,584,652,418,1538,0,4669,4789,1919,320,424,626,534,2559,191,1585,1103,2125,3637,4199,1273,6,5574,1353,1856,2804,0,3267,1550,769,2415,758,1260,570,4,345,2041,871,2401,433,1190,473,4472,2164,1585,1869,991,586,416,772,870,392,6,433,1861,851,2,318,3226,610,0,1230,1970,996,2437,1259,1961,1685,1519,1188,313,448,0,0,3523,617,1107,429,1841,2200,4667,1872,2652,14134,15387,342,666,7309,8493,1252,754,6190,4178,4453,55614,1,59520,622,3,38,83,2,88,1,115,0,2,0,183,1,0,6,1,1,18,173,1,651,19,141,1105,0,0,0,0,0,0,0,0,0,0,0,9388,1514,1282,2267,95,507,417,204,1811,209,609,1383,754,917,1265,1229,616,1149,313,577,463,1231,101,1230,673,364,325,433,184,980,447,121,242,127,337,327,164,1188,223,199,342,1444,365,957,213,353,76,2236,202,1305,2295,4181,1875,1282,2824,2907,0,1244,1329,214,831,380,204,588,90,494,672,1002,787,790,728,531,469,260,250,563,106,451,167,385,98,447,458,453,225,455,224,168,394,553,77,179,0,384,4,96,369,136,33,97,141,276,3,785,203,532,546,224,772,784,638,222,269,129,215,83,0,210,368,302,305,214,196,308,576,367,198,324,379,170,616,191,195,370,459,301,190,202,87,452,307,211,215,493,160,462,233,410,222,0,257,290,533,773,167,309,107,210,116,439,177,309,169,269,437,379,151,203,308,312,451,230,782,174,170,462,256,0,289,223,450,228,393,272,196,299,461,615,125,474,224,0,100,454,369,532,308,458,210,333,589,373,444,618,301,302,1096,214,222,674,159,1,451,363,268,324,209,450,182,227,324,107,185,979,189,128,394,171,91,549,120,243,128,332,215,338,368,197,326,269,165,310,270,1259,224,198,19,6,197,214,341,197,5,121,93,166,209,464,869,306,1048,945,523,364,370,555,41,518,120,324,111,323,92,168,259,212,165,978,648,391,184,409,268,75,3,0,544,340,247,220,2946,406,449,170,615,269,231,866,931,208,876,268,201,517,1702,206,1453,214,301,211,453,512,223,2723,957,1199,1306,754,0,5451,7843,5442,3264,4907,5581,3546,12289,9643,33477,55,1,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,148,79,215,42,13,87,2,125,2,135,42,49,4,22,70,53,33,259,113,1922,6474,46,110,81,29,199,18,26,14,16,75,0,15,73,0,0,1,14,34,93,41,48,5,25,68,55,49,323,17,100,2121,176,579,752,431,1707,10,419,781,2152,36,554,287,161,456,746,47,409,234,137,84,365,69,444,29,196,87,88,5,88,29,1,15,65,43,130,17,63,119,51,51,48,43,17,38,181,554,6642,66,60,18,36,183,66,73,335,84,103,294,71,211,63,20,125,85,3,19,46,162,290,20,61,39,127,3,42,165,57,31,18,85,46,156,882,11,64,59,27,61,67,100,107,374,93,44,116,96,18,74,125,16,38,145,307,68,76,117,181,235,253,53,203,98,14,141,121,34,62,70,66,74,75,82,11,560,37,107,142,149,39,280,74,95,10,104,4,7,31,69,66,98,45,15,1,26,40,20,68,46,38,61,21,121,242,104,157,77,68,26,95,24,121,83,328,126,105,48,78,118,4,40,2,174,113,186,80,4,53,86,459,117,2,34,83,2,67,103,149,4,5,173,102,156,254,127,192,59,10,90,173,54,2,77,137,20,323,89,3,28,54,332,10,86,89,116,113,24,4,120,72,50,129,25,87,62,73,68,0,53,207,64,53,30,333,119,33,97,181,68,40,241,13,77,106,139,93,0,155,52,566,157,99,12,253,15,31,302,95,11,1280,85,65,365,49,364,2,751,37,309,228,41,237,58,1311,4072,172,36,41,45,0,18,53,52,19,29,47,36,24,38,30,117,49,81,31,68,17,34,33,32,18,20,19,90,4,54,28,44,22,57,70,176,79,141,89,120,226,765,1701,17,1008,0,0,0,0,0,0,80,90,21,39,14,29,40,10,48,20,146,57,63,44,47,45,27,58,38,83,78,42,27,176,25,59,52,264,148,870,897,282,51,34,49,13,20,23,45,11,50,124,40,22,25,22,41,19,15,52,79,41,11,20,49,30,46,19,35,33,143,22,0,73,18,31,46,62,34,34,48,79,40,43,30,46,42,32,89,33,18,21,28,33,139,34,18,16,39,14,82,21,19,18,19,18,14,20,33,32,7,77,3,36,12,39,26,25,41,17,62,41,76,59,21,17,38,3,36,73,31,62,56,162,255,82,0,22,130,15,74,38,182,150,40,266,199,55,57,159,376,33,2263,641,525,6043,573,1,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,5,2,1,0,0,10,1,9,806,205,326,16,15,4968,106,37,26,687,66,58,55,4,40,32,52,230,31,42,52,290,5306,4196,94,88,262,271,102,108,30,70,284,107,50,17,16,238,81,79,324,78,190,2564,1923,129,111,107,120,27,80,567,595,87,64,59,1,54,1,5,39,31,58,79,53,232,32,43,51,4,660,229,11153,2,14,185,25,4,6,4,4,11,24,2,2,309,6971,761,510,1004,301,384,220,349,794,108,175,106,265,31,131,157,150,215,360,414,81,109,1283,12059,152,2,197,90,683,1031,440,160,67,4,113,108,26,113,2,127,118,3,113,41,164,1121,18,95,415,2839,16,222,89,93,349,185,240,51,551,207,231,379,674,1964,73,30,111,103,117,681,68,138,488,67,73,330,146,224,157,1,51,215,265,144,110,94,225,554,1,125,85,117,103,248,102,3,129,111,70,115,74,221,57,66,229,186,194,84,1,126,483,109,272,107,241,137,130,32,184,74,140,198,391,151,118,127,71,20,130,361,2,208,187,572,12,68,82,128,104,532,91,2178,142,72,112,44,30,187,249,1003,142,176,1320,187,459,1971,1820,1821,1363,459,201,851,709,940,72,109,211,539,382,123,533,124,139,105,132,134,156,21,60,1295,149,222,52,112,12,676,2144,5,199,21,135,436,372,198,141,26,85,1,21,25,129,129,47,111,190,289,97,466,175,53,99,30,83,100,1,9,34,268,0,234,408,502,227,528,143,188,5,335,52,203,63,72,270,161,617,549,262,78,407,217,60,68,103,40,5,243,227,115,783,4,280,89,16,491,526,155,136,95,53,395,81,191,3,360,105,40,487,881,12,92,204,278,104,724,217,322,72,507,34,0,55,35,273,255,120,420,215,345,600,8,54,107,3,640,175,150,48,531,85,79,143,381,113,2,304,127,58,541,285,88,864,60,157,142,112,70,83,73,93,3,1,421,212,325,60,119,166,227,64,134,10,102,206,231,356,3,75,96,748,4,135,71,171,12,77,195,525,7,116,161,526,2,167,119,352,402,3,134,269,85,2,477,90,12,155,594,629,283,43,82,147,359,20,318,351,12,58,265,925,383,357,63,26,144,407,16,629,576,21,57,102,62,197,37,141,781,453,111,270,2,137,20,104,81,342,39,2,112,133,181,155,82,81,148,42,11,220,545,705,203,4,59,235,58,277,51,230,242,1117,558,239,226,1495,7105,0,36,506,23,103,168,2009,253,593,1,169,599,557,384,6311,37,1,0,10183,527,83,626,26,42,187,40,95,30,133,69,41,168,114,33,10,13,45,34,26,82,34,94,17,91,48,45,225,378,5205,0,0,0,0,0,0,0,0,0,0,0,0,0,0,448,35,491,206,121,67,74,98,294,124,38,132,6,56,44,78,3,19,64,96,140,249,86,367,5944,52,179,93,64,58,513,165,61,197,54,36,749,0,89,83,54,120,66,219,92,65,112,63,207,0,88,38,38,58,63,230,285,0,31,82,30,222,68,40,25,139,140,37,133,62,5,173,32,9,125,44,352,25,43,81,33,77,92,55,77,271,185,408,381,0,820,26,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1042,14,45,76,2,121,14,63,78,95,76,169,1800,7179,3,59,370,647,15,46,29,50,0,126,15,63,79,80,20,79,60,123,66,2582,6,685,181,423,156,272,250,53,72,146,111,17,37,82,268,1998,485,2298,1442,479,384,320,820,88,456,230,34,307,178,89,306,123,128,25,13,150,94,134,29,24,79,22,74,251,63,5,241,7504,178,115,90,312,136,51,241,137,51,157,13,4,118,2,2,27,179,117,80,87,66,21,54,14,42,5,116,32,158,119,11,20,112,18,119,37,2,85,2,117,152,123,593,171,2,134,23,172,104,111,4,81,49,47,20,62,121,120,340,248,159,3,75,117,53,30,269,520,447,294,72,41,74,77,24,43,2,195,134,81,84,28,1,27,1638,348,150,10,64,45,56,125,73,4,6,305,160,42,47,9,130,754,249,119,11,13,49,2,238,21,31,576,1,244,205,22,16,2,54,36,310,44,43,371,2,1,3,150,2,3,39,73,73,84,44,20,35,188,3,36,136,128,2,3,8,126,329,37,532,113,89,105,8,67,11,58,2,45,61,466,73,64,74,161,5,74,206,12,78,6,12,52,11,1,18,116,65,223,179,180,14,78,112,82,179,36,75,219,27,32,240,181,21,178,259,0,175,12,175,72,24,108,2,81,223,130,2,303,0,3,88,4,133,585,53,7,206,104,2,367,194,117,174,66,7,3,314,66,106,701,116,205,2,58,828,225,115,58,54,614,267,191,0,114,72,46,246,75,613,0,106,285,6,346,553,3116,222,96,60,9,145,69,98,29,106,90,81,44,55,18,27,42,96,52,12,38,14,30,2,36,18,2,61,56,99,206,166,212,317,5160,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,86,79,42,16,32,8,26,29,44,55,314,74,41,2127,0,247,174,0,59,78,7,23,121,67,155,28,103,89,24,55,32,50,56,15,31,17,7,26,55,65,95,94,54,31,11,39,15,61,54,16,1,77,33,60,0,59,84,148,200,469,400,0,351,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,13,1,0,0,0,0,0,0,0,1,0,1,2,1,0,2,0,1,1,0,0,1,0,2,0,0,1,0,2,0,0,1,0,2,0,1,1,1,1,1,1,1,1,1,3,2,4,3,1,1,1,1,1,2,2,1,18,16,11,1,2,2,1,1,1,1,2,4,1,2,1,2,1,2,1,26,12,2,1,2,3,1,1,4,5,1,5,1,2,1,3,1,4,3,1,70,10,4,1,11,5,5,14,1,1,7,13,11,4,8,2,5,2,1,27,12,5,8,24,2,1,11,2,1,3,10,6,9,29,23,17,36,9,4,5,2,3,1,10,1,12,4,3,1,2,5,2,6,19,15,11,1,1,1,6,3,2,8,2,2,7,11,2,1,2,2,4,2,2,1,1,8,2,10,3,3,7,9,13,17,3,6,6,13,9,4,6,9,4,2,1,2,1,1,1,2,4,1,2,1,1,2,4,9,4,6,2,1,2,3,1,6,5,5,6,5,2,2,3,1,1,6,6,2,4,1,4,8,4,2,3,4,6,2,5,3,3,3,6,3,15,12,23,3,2,3,13,3,20,9,3,2,1,2,13,7,5,3,3,3,4,4,1,4,1,1,2,5,5,0,4,4,2,3,7,10,14,8,6,1,2,3,2,0,1,8,2,3,0,0,0,5,15,5,2,11,1,0,0,2,9,15,5,7,1,1,1,0,0,22,9,12,21,1,1,1,1,0,1,0,0,0,0,0,0,7,39,17,14,8,5,3,4,2,3,0,0,0,0,0,0,27,10,5,7,1,0,1,1,1,1,0,3,1,0,0,0,0,0,0,53,40,32,3,1,2,8,1,3,0,1,0,1,4,0,0,0,0,0,0,0,0,0,25,55,5,3,2,3,2,1,0,0,0,0,3,4,3,2,0,0,0,0,0,0,0,0,0,0,41,41,16,4,2,2,2,1,0,5,4,0,0,0,0,0,97,31,12,17,1,3,8,0,6,2,1,3,5,1,0,0,0,0,126,27,27,8,11,3,2,1,7,6,0,0,0,0,0,0,138,32,22,8,6,5,0,5,4,5,3,0,0,188,20,6,1,7,4,2,5,7,4,0,0,211,94,2,1,7,10,3,3,20,4,9,0,0,0,261,26,12,1,15,5,1,7,5,14,10,1,0,259,105,33,57,12,1,5,37,26,197,55,54,15,4,2,14,5,18,0,189,111,37,3,5,28,21,280,1,7,50,15,0,255,18,34,8,3,3,10,29,270,52,8,18,5,138,184,28,0,0,5,19,15,54,5,5,5,7,0,5,5,2,1,1,2,2,6,0,9,175,41,0,0,0,0,0,631,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,3,1,1,1,3,1,1,2,2,3,2,1,1,1,11,1,3,4,1,1,3,1,1,1,1,1,1,2,1,1,2,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,2,1,0,2,1,2,1,0,0,0,0,0,1,2,0,0,0,2,0,1,1,1,1,1,2,2,1,0,1,0,0,0,0,0,0,0,1,0,1,0,1,0,2,0,0,1,0,1,0,1,0,2,0,0,1,0,6,12,7,6,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,2,1,0,1,0,1,1,0,0,1,1,1,1,1,1,2,1,2,3,1,1,1,6,2,1,2,1,4,1,1,1,1,8,3,2,12,2,48,17,5,3,7,34,14,26,8,10,2,3,2,1,1,1,2,5,4,4,2,1,1,2,3,3,2,3,8,1,1,2,5,3,5,5,8,5,16,1,3,4,1,0,1,1,0,1,6,2,6,4,3,1,0,0,0,0,0,0,0,0,0,0,0,2,1,3,2,0,0,0,0,0,0,0,0,3,1,1,0,0,0,0,0,3,2,1,2,0,0,5,1,2,1,0,0,0,0,8,2,2,6,1,0,0,0,0,0,0,0,0,0,0,0,0,1,5,1,0,0,0,0,0,0,0,0,0,0,0,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,3,0,4,0,0,0,1,2,0,1,0,1,0,1,0,1,0,1,2,1,0,1,1,1,1,0,0,0,1,0,1,0,1,0,1,1,2,1,1,1,1,0,0,0,0,0,0,1,0,1,1,3,0,0,0,0,1,0,1,1,2,1,1,4,3,1,1,3,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,1,0,1,0,1,1,1,1,0,0,0,0,1,1,1,1,2,0,0,0,0,1,0,1,0,1,2,0,0,0,1,0,1,2,3,1,3,1,0,0,0,4,0,0,0,1,1,1,1,0,0,0,0,1,0,2,1,0,0,0,1,0,2,4,2,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,2,2,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,2,0,2,1,2,1,1,1,1,3,1,1,1,1,2,3,1,1,2,2,1,1,2,2,3,1,2,1,1,1,2,1,3,1,1,0,1,1,3,3,3,2,1,3,1,0,2,1,2,4,1,4,5,1,1,2,1,3,4,5,2,10,3,4,2,0,3,5,3,4,1,6,1,6,2,16,10,3,1,5,1,9,4,40,23,5,12,4,4,11,1,1,3,2,1,3,1,2,0,0,0,0,3,17,4,2,0,0,0,4,3,1,1,0,0,20,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,0,1,2,1,0,2,0,1,1,1,2,3,1,1,0,0,0,0,0,1,0,1,0,1,0,2,0,0,1,0,1,1,1,1,1,1,1,5,1,1,0,0,0,0,0,0,0,3,1,0,0,1,3,0,1,0,1,0,1,0,1,0,1,0,2,0,0,1,218,2022,1,1,1,240,4706,25,5,69,300,38,10,90,2123,1122,856,1188,2827,1259,1396,225,55,32,41,34,15,10,5,1,1,4,7,1,3,1,364,151,292,187,1857,1164,597,154,50,18,24,19,12,17,4,2,3,2,25,6,71,14,18,134,71,67,4,3,39,9,3,12,13,5,44,13,11,368,573,274,785,190,203,57,4,365,283,635,313,144,23,672,897,372,120,16,8,8,1968,253,291,80,9,6031,2409,297,21,5,9,6,8828,445,10,14,3,7,2,12557,166,67,32,23,9,1,0,11088,538,154,54,15,6,1,3,0,9642,438,106,39,7,1,5,0,0,0,9014,238,23,12,7,1,1,8087,119,23,10,2,14,6,1,2,1,0,0,6016,95,28,22,8,4,6,3,1,2,2,0,0,0,0,0,0,0,0,4408,108,29,18,11,6,4,1,2,1,1,1,1,2,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2995,105,46,19,2,4,8,6,2,4,4,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2139,156,9,14,9,1,0,4,3,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1613,74,14,4,4,0,5,1,1,1,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1019,167,32,10,3,13,4,2,1,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,598,105,25,4,15,10,4,1,12,3,7,1,1,1,3,4,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,414,77,39,10,18,11,3,2,4,1,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,271,74,29,6,4,4,1,1,1,1,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,142,77,24,15,5,1,1,5,1,1,3,2,1,2,1,0,0,0,0,0,0,0,0,0,0,0,124,25,23,7,8,3,1,1,3,1,1,1,1,1,0,0,0,0,0,0,0,0,0,82,24,15,5,4,4,1,4,2,6,1,6,4,3,1,0,0,0,0,0,0,0,0,0,0,0,52,22,13,10,4,1,2,6,1,4,1,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,16,25,2,12,2,2,2,3,1,3,3,5,3,2,1,1,0,0,0,0,0,0,0,0,0,16,4,3,6,4,1,2,2,1,0,0,0,0,0,0,0,0,14,13,6,6,1,3,2,3,1,1,2,0,0,0,0,0,0,0,0,0,8,1,2,3,1,4,1,2,0,0,0,0,0,0,3,2,4,6,6,2,2,1,0,0,0,0,3,2,1,4,2,1,2,1,0,0,0,0,5,2,1,1,0,0,0,1,8,1,3,1,0,0,0,2,1,0,0,0,0,3,2,1,0,0,0,4,3,2,1,1,0,0,0,0,0,0,6,11,1,1,0,0,0,0,0,9,3,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,3,2,2,3,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,4,0,0,1,0,2,1,1,2,0,0,0,0,0,0,12,0,0,1,0,1,0,1,1,3,1,0,0,0,0,0,1,1,1,1,0,0,0,1,1,1,1,1,0,0,0,0,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,1,1,4,2,2,2,1,2,2,1,1,1,18,11,3,7,5,1,2,1,1,3,2,2,4,4,2,3,2,1,1,43,10,9,4,26,3,5,5,1,1,6,7,1,6,4,1,1,24,34,4,32,7,4,2,6,1,2,1,2,17,9,9,7,4,1,19,5,26,1,1,2,3,6,2,7,2,7,14,4,1,3,30,60,7,10,7,4,2,5,6,1,2,9,49,1,1,2,4,4,5,127,61,37,98,22,7,3,3,5,10,7,13,3,2,4,1,93,49,34,3,7,6,5,2,10,2,1,107,80,7,6,5,4,5,2,9,153,42,17,5,2,12,15,6,3,17,7,1,109,62,18,1,3,3,10,16,45,56,64,24,15,6,3,9,42,20,1,34,12,16,4,9,6,4,29,14,8,19,14,10,21,30,8,4,3,44,15,24,5,7,18,11,11,2,3,11,9,13,2,2,5,1,31,2,0,0,0,0,4,5,2,0,0,1,1,9,0,0,0,0,11,3,12,0,0,0,0,4,5,10,5,6,9,0,0,0,0,0,18,23,22,3,25,37,3,4,0,0,0,0,0,0,0,9,39,13,2,16,13,17,0,0,0,0,0,0,0,0,0,0,33,5,21,3,34,12,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,50,24,42,10,0,0,0,0,0,0,0,0,0,0,0,15,22,32,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,21,23,41,58,12,0,0,0,0,147,34,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,289,0,0,0,0,0,0,0,0,0,0,78,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,2,0,0,1,0,1,0,2,0,1,0,1,0,1,0,3,1,2,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,1,0,1,1,0,0,1,0,1,0,1,2,1,1,1,1,1,1,2,1,1,1,1,2,1,1,1,2,3,1,4,2,1,1,4,1,4,1,1,1,1,1,11,14,2,2,1,2,2,4,6,5,2,3,26,4,1,1,2,2,5,3,8,4,1,27,18,8,3,3,5,5,2,6,20,43,40,50,11,2,1,1,20,5,2,2,7,23,16,2,1,2,8,1,10,28,8,4,4,5,8,2,10,3,6,5,1,14,6,6,3,2,2,2,13,11,2,2,6,3,2,3,1,4,0,0,5,1,0,0,1,1,1,0,0,13,2,1,1,0,0,0,0,0,0,0,0,19,10,9,4,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,11,12,5,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,6,2,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,2,4,2,0,0,8,0,0,2,6,3,0,1,0,1,0,2,1,1,1,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,0,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,3,2,1,1,1,1,1,2,1,1,1,1,1,2,3,3,1,1,2,2,2,1,6,1,5,4,2,1,1,2,2,2,2,2,2,2,8,6,5,3,1,3,4,4,1,13,3,3,2,2,4,1,1,1,2,2,2,6,1,2,20,4,7,10,6,3,3,3,2,1,5,12,1,1,25,19,6,10,2,1,1,2,2,2,7,16,24,13,4,2,1,35,7,10,3,8,2,2,3,2,11,8,16,3,1,1,29,12,8,3,5,4,4,6,21,30,27,5,1,32,1,3,4,8,48,20,2,1,15,9,2,3,4,18,4,10,33,40,4,2,4,6,11,4,12,11,3,3,2,6,4,9,24,2,6,1,10,3,12,7,2,2,6,1,2,4,2,3,0,0,3,2,3,1,0,3,1,3,1,0,1,6,0,8,1,3,0,1,1,14,2,6,12,1,0,0,0,13,4,0,23,28,1,1,0,0,0,0,0,0,0,0,64,20,7,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,16,13,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,1,1,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,2,2,4,1,3,1,3,1,10,9,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,1,0,1,0,1,0,1,1,0,0,3,1,0,0,0,2,8,2,1,1,1,19,5,10,0,2,0,0,0,0,0,0,0,0,1,0,1,0,1,5,1,1,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,1,1,2,1,9,1,1,5,2,1,94,8,29,3,1,1,111,164,38,8,6,5,7,7,10,2,4,4,1,2,1,1,135,30,7,5,4,2,4,3,1,456,152,55,18,57,25,47,25,17,3,5,3,9,2,11,8,4,1,2,1,404,104,73,50,55,56,26,24,1,1,2,4,11,5,4,1,2,1,181,126,126,64,103,74,8,3,6,3,2,5,12,12,7,126,109,45,76,17,2,7,5,9,15,6,3,8,11,4,1,145,81,72,80,17,3,8,8,8,2,234,134,107,21,13,30,1,7,3,17,2,11,20,14,1,2,2,278,139,104,3,36,14,14,16,9,2,4,1,1,494,182,88,56,19,2,10,13,32,2,16,10,27,28,18,9,2,6,1,536,175,64,34,8,5,20,15,46,37,62,52,50,74,12,20,3,4,1,274,182,71,6,24,11,9,16,17,81,74,68,155,86,14,16,9,7,2,154,58,10,5,9,93,41,65,67,71,61,15,3,1,4,51,15,58,12,46,7,36,31,27,11,57,88,105,20,35,7,11,1,2,1,13,5,8,98,38,45,23,5,23,12,1,7,6,33,1,2,18,28,14,26,2,8,8,23,22,19,11,2,10,6,12,20,16,8,6,41,27,6,14,0,141,47,5,2,16,13,0,0,237,42,80,24,12,9,9,5,252,214,107,20,31,8,0,279,169,54,52,9,7,3,3,0,0,0,681,146,88,25,24,1,0,0,0,667,299,87,44,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,648,106,25,8,12,0,0,0,0,0,0,0,0,0,0,0,628,218,16,16,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,481,34,41,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,133,23,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,93,20,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,13,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,1,0,0,3,0,0,0,1,1,1,1,1,2,1,1,2,1,1,1,1,1,1,0,0,0,0,0,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,3,2,2,1,1,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,3,0,0,0,1,0,2,4,1,1,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,0,0,1,0,1,3,6,0,0,0,0,0,0,0,0,0,0,1,0,1,1,2,1,1,1,8,2,4,1,2,1,2,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,1,0,0,0,1,0,1,0,1,1,1,1,1,2,1,2,1,2,2,3,1,2,1,3,1,1,1,1,2,1,1,1,1,1,1,1,1,1,7,3,1,1,1,1,1,1,2,1,2,2,1,1,2,1,2,5,3,1,2,3,1,1,1,3,1,3,6,5,1,3,3,2,3,3,3,3,1,1,1,2,2,4,2,2,2,3,2,2,4,1,1,1,1,2,6,2,3,2,1,3,5,3,1,1,1,3,1,1,1,2,1,1,2,2,8,1,1,2,3,1,1,5,1,4,1,3,1,1,1,2,2,1,3,1,2,3,1,5,2,2,2,2,2,1,2,1,7,6,2,1,4,1,1,3,1,1,2,5,3,2,2,1,1,3,2,1,1,1,1,3,1,4,1,4,1,1,3,1,1,1,3,4,2,1,1,2,3,4,3,2,1,1,2,3,1,9,8,5,2,1,2,2,10,9,2,4,2,1,1,9,3,2,2,2,2,3,1,1,84,3,7,7,11,2,4,6,4,1,2,3,8,3,1,2,4,38,15,27,9,30,18,18,13,12,5,2,2,4,18,2,2,6,1,2,3,4,1,3,6,4,1,3,14,14,3,7,16,3,7,5,4,10,5,1,6,2,3,1,3,1,5,14,11,14,16,1,7,2,1,3,5,1,5,1,1,0,10,10,5,5,6,6,2,5,0,2,2,1,3,1,9,15,1,35,15,1,2,2,5,5,4,1,2,23,18,9,8,5,5,1,2,2,1,0,3,2,1,3,1,1,0,0,30,29,21,9,7,8,4,8,4,4,4,3,2,3,3,2,3,0,35,26,24,17,12,6,1,0,2,3,2,5,3,3,1,1,45,56,12,3,1,23,7,5,6,11,1,1,6,1,2,0,38,23,32,35,18,11,2,1,1,1,0,54,35,43,7,16,16,2,6,0,4,1,5,0,48,49,43,15,1,10,2,1,0,56,27,18,38,6,4,17,16,3,2,2,1,6,1,1,2,72,87,33,26,12,1,2,1,9,1,2,3,82,102,20,17,24,1,3,3,1,86,105,56,42,6,10,7,3,1,1,1,231,67,41,1,1,1,1,3,2,3,242,150,59,11,1,3,1,6,1,3,4,3,13,1,3,1,378,83,4,12,1,3,3,9,2,2,3,460,113,109,51,13,25,5,3,6,2,26,7,3,9,7,22,1,352,200,95,11,27,4,2,16,3,14,11,2,1,1,1,257,185,49,25,11,5,4,4,6,0,310,176,45,22,23,16,36,31,2,3,1,1,381,157,72,33,34,9,18,10,15,2,489,112,28,28,4,20,7,20,4,1,5,2,1,450,114,115,33,40,13,38,18,11,11,3,2,3,333,207,31,28,20,18,5,36,3,27,37,4,5,2,223,163,1,34,23,22,16,33,44,11,27,2,1,1,1,1,253,99,67,82,30,16,3,16,52,45,26,9,1,2,1,1,45,158,17,27,23,60,101,42,53,5,1,2,42,39,12,111,21,13,2,2,4,1,2,4,11,38,20,59,72,30,113,19,3,2,3,1,27,47,21,24,12,11,5,4,4,14,15,1,1,17,4,28,6,4,2,16,10,3,0,27,22,7,5,1,39,19,42,34,3,2,0,0,35,15,128,12,1,2,1,0,0,0,0,0,0,136,325,33,5,5,4,2,0,0,0,0,359,48,16,13,13,4,0,0,0,0,1012,91,14,7,8,1,0,0,0,0,0,0,0,0,0,1022,82,15,18,3,2,0,0,0,0,0,0,0,0,0,854,63,17,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,699,40,3,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,489,5,6,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,132,24,25,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,1,2,1,1,1,1,1,2,13,1,1,1,14,1,1,1,2,2,2,1,1,7,1,3,3,3,4,12,7,28,39,9,9,20,7,14,7,5,3,1,2,4,4,2,2,1,2,3,2,1,3,3,1,1,1,2,2,3,3,2,2,2,1,1,1,2,2,1,1,4,3,1,2,2,2,2,1,1,1,1,2,3,0,0,0,0,0,2,6,0,0,0,3,1,0,0,13,2,2,1,0,0,0,0,0,17,6,6,2,2,2,2,2,1,0,0,2,0,0,0,0,1,11,2,2,1,3,0,0,0,0,0,6,1,1,0,0,0,0,0,11,4,1,1,2,0,2,1,2,0,0,0,0,0,2,3,4,1,1,0,2,1,0,0,0,0,2,2,1,1,1,1,2,0,1,0,0,0,0,0,1,1,0,1,0,1,2,0,0,0,0,1,1,0,2,1,0,0,0,1,1,1,1,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,2,2,1,0,0,0,1,0,0,1,0,1,0,0,0,1,0,0,0,0,0,1,1,0,0,1,1,1,0,0,0,1,0,2,1,1,0,0,1,3,2,1,1,1,1,3,3,2,1,7,1,3,0,0,0,1,2,0,0,1,0,2,1,1,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,1,1,1,1,1,2,1,1,1,3,1,1,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,4,2,1,0,0,0,0,0,0,0,0,0,1,0,2,0,0,1,1,0,0,1,1,1,1,1,0,0,0,0,0,1,0,2,0,2,3,2,1,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,1,0,1,1,1,0,0,0,1,0,1,2,1,0,1,1,1,1,2,2,3,1,2,4,13,1,2,1,1,1,1,1,1,1,1,3,2,6,1,2,4,1,2,5,11,1,2,4,1,1,1,2,2,37,4,1,1,1,8,6,3,2,2,1,1,1,3,1,1,4,1,3,1,2,1,2,5,6,8,23,11,10,3,14,23,20,13,6,4,7,2,7,18,9,14,37,8,15,3,18,12,3,1,2,1,2,2,2,4,0,3,2,3,3,3,1,1,2,1,0,0,3,1,4,2,1,0,0,0,1,1,2,1,3,0,0,0,2,1,0,0,1,1,2,1,5,1,2,2,0,0,0,0,0,0,4,2,2,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,2,1,2,1,1,0,0,0,0,0,0,3,2,5,0,0,0,2,1,1,2,0,0,0,0,0,1,1,2,1,0,0,0,0,0,1,0,0,0,2,1,1,1,1,0,0,0,0,0,0,0,0,1,0,0,1,1,1,0,0,0,1,1,0,0,0,5,4,1,1,1,1,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,6,4,1,0,0,0,0,0,0,0,0,0,0,2,4,5,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,0,0,0,0,0,0,0,2,4,3,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,1,6,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,8,10,7,2,1,1,1,1,1,1,1,2,1,2,1,1,1,1,2,3,1,1,1,2,1,1,2,1,1,1,1,2,1,2,1,2,1,1,1,1,2,1,1,2,2,1,1,3,8,9,1,1,1,4,2,11,3,4,2,2,1,4,1,1,2,1,0,2,0,1,1,1,2,0,0,2,2,1,0,0,0,0,1,3,1,3,0,1,0,1,0,0,0,0,0,0,0,0,1,1,0,0,2,1,0,0,0,0,0,0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,2,2,1,1,15,17,1,2,2,7,3,1,1,4,2,2,1,1,1,1,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,1,1,1,1,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,5,0,0,0,0,0,0,1,2,1,0,2,1,0,0,1,1,1,1,1,1,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,0,0,0,0,0,1,0,1,0,1,1,1,1,1,0,0,0,0,0,1,0,1,2,1,1,3,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,1,4,19,1,1,2,17,0,0,0,0,0,0,1,1,1,1,1,1,1,1,3,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,1,18,9,0,0,0,0,0,0,0,0,1,0,2,0,1,0,1,0,1,3,2,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,9,9,4,1,1,1,2,10,7,1,1,1,1,3,1,2,1,1,1,1,1,1,1,1,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,1,0,0,0,1,0,2,0,1,0,1,0,1,1,1,1,1,0,0,0,0,0,1,0,1,0,1,1,1,1,1,2,1,1,1,2,1,1,1,1,14,8,2,7,5,9,4,3,1,2,4,1,2,1,1,1,21,5,6,4,39,20,6,11,1,2,1,1,2,2,2,2,2,1,2,17,13,2,3,4,11,7,2,1,8,20,4,10,30,4,3,3,1,3,1,1,1,1,2,5,2,2,2,1,3,0,1,1,0,0,1,2,0,0,0,0,0,6,1,3,1,1,2,1,1,5,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,4,1,1,1,1,1,1,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,4,1,1,0,0,0,0,0,0,1,3,1,0,0,0,0,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,0,0,0,1,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,2,1,1,1,2,1,1,1,2,2,1,1,2,2,2,1,1,2,1,1,2,1,2,1,1,3,1,3,2,4,1,1,1,1,2,1,6,1,3,1,6,2,4,3,1,1,1,1,5,4,3,9,2,1,1,4,2,1,16,1,2,3,1,1,30,4,5,1,5,1,1,7,4,5,1,1,4,7,1,1,2,2,2,1,1,0,0,0,0,0,0,0,0,0,0,2,0,0,9,1,4,1,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,2,1,2,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,5,6,10,0,0,6,5,4,0,6,0,1,1,0,0,1,1,1,1,1,3,1,1,1,1,1,1,1,4,2,1,1,1,1,1,1,1,2,3,6,2,1,3,1,5,2,1,1,2,1,1,1,1,1,2,2,3,7,15,14,6,2,1,2,1,4,1,4,1,3,1,1,1,1,6,8,7,1,2,1,1,3,2,2,2,2,1,2,1,2,2,1,1,1,1,2,5,2,2,2,1,2,2,1,1,1,1,1,1,4,2,2,1,1,1,1,1,1,1,2,2,1,1,1,1,3,2,2,3,4,1,1,1,2,1,4,3,2,2,1,1,2,1,2,2,5,1,3,2,1,1,9,2,1,5,1,2,3,2,1,4,1,0,5,3,2,2,1,1,0,2,8,7,1,1,5,3,5,0,2,4,3,1,9,1,0,0,0,2,2,5,9,8,2,0,0,0,0,0,22,12,0,5,1,1,5,10,1,0,0,0,0,0,0,15,13,3,2,4,1,1,1,3,3,11,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,30,7,2,4,1,11,5,1,0,0,0,0,0,0,0,0,0,0,0,0,29,8,3,41,3,0,0,0,0,0,8,2,44,2,2,0,0,0,0,1,2,22,3,2,1,0,0,1,3,1,0,4,1,0,2,4,3,0,0,0,0,0,0,0,1,0,0,0,0,1,7,0,0,0,0,4,0,0,0,0,0,0,49,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,3,1,1,0,0,0,0,0,0,0,0,1,1,5,1,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,10,1,1,4,1,1,2,4,22,1,1,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,0,1,0,1,0,1,1,1,3,1,0,0,0,0,0,0,1,0,1,1,1,3,0,0,0,0,0,0,1,0,1,0,1,1,1,1,2,1,1,1,9,1,1,1,2,2,1,19,5,1,2,2,1,2,1,1,1,2,1,1,2,4,1,1,1,1,1,46,10,4,10,7,3,5,4,2,7,1,5,3,2,4,1,2,2,2,6,11,13,18,21,15,7,5,1,2,6,4,1,3,6,2,1,9,3,1,1,2,2,5,6,18,18,16,14,8,4,4,3,1,1,5,1,1,1,6,3,3,2,3,6,2,1,1,2,4,1,9,1,6,3,1,2,2,2,2,4,1,2,3,1,3,6,2,5,3,9,2,2,6,1,2,1,3,4,2,4,1,3,4,2,2,3,2,5,4,3,7,7,3,4,2,3,6,3,3,2,1,1,6,10,2,5,2,4,3,2,1,6,2,1,2,4,5,3,5,3,2,2,6,8,4,6,2,13,5,3,5,5,4,3,2,2,1,7,5,2,4,5,2,4,3,4,4,1,1,7,17,2,15,3,3,2,3,1,3,2,3,6,3,2,7,3,1,3,6,5,1,1,5,9,12,10,2,2,2,2,3,1,3,2,6,4,4,3,6,4,12,6,4,3,3,6,2,3,1,5,6,7,3,2,3,1,6,4,3,2,1,1,1,4,5,8,4,2,1,1,4,1,5,2,4,7,0,1,4,0,3,0,0,2,1,2,4,0,4,9,9,3,1,4,3,0,0,0,10,1,3,3,1,1,7,3,3,0,0,0,0,0,0,0,0,0,24,15,5,2,7,1,3,6,14,7,1,1,0,0,0,0,0,21,8,11,7,10,6,5,1,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,15,13,1,2,1,4,7,3,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,1,1,4,4,3,3,9,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,4,3,2,3,4,1,0,0,0,0,0,0,0,0,1,1,1,7,1,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,2,2,4,0,0,0,0,0,0,0,3,2,5,9,5,3,0,0,0,12,2,11,16,1,2,0,0,0,0,0,5,10,8,2,1,0,0,0,0,0,0,0,4,7,1,0,0,0,0,24,2,1,0,0,0,0,0,0,0,0,0,0,0,0,7,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,2,0,2,0,1,0,1,0,1,0,2,1,0,1,1,0,0,1,1,1,1,1,6,2,9,1,7,7,1,1,2,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,1,6,2,9,1,4,10,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,3,0,0,0,0,4,0,2,1,0,0,1,1,0,0,1,0,1,0,1,1,0,0,1,0,1,4,1,5,0,0,1,5,0,0,2,0,1,0,1,0,1,1,1,0,0,0,1,1,0,0,1,1,1,4,3,1,1,1,2,1,1,2,1,29,26,5,12,6,7,2,1,6,1,2,1,1,57,19,52,22,21,3,5,6,2,16,6,1,1,1,33,92,39,17,4,4,1,5,22,1,1,53,32,8,8,1,2,1,185,98,26,9,9,3,7,114,5,3,1,1,236,35,9,15,3,6,4,6,12,141,10,5,108,48,39,7,14,2,3,2,15,367,7,4,29,3,2,3,27,162,6,3,6,1,12,20,99,5,2,1,4,82,4,2,21,8,3,4,0,12,6,5,5,0,2,9,1,1,69,3,0,228,142,24,12,1,6,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,3,2,5,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,19,7,6,3,1,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,3,1,1,1,1,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,1,1,0,0,0,0,0,0,1,0,1,0,1,1,1,0,0,0,4,0,2,0,1,0,1,0,1,0,1,2,2,1,1,0,0,0,0,0,1,0,1,0,2,2,46,0,0,1,0,1,0,1,0,1,1,1,1,0,0,0,0,1,1,2,1,0,0,0,0,1,0,2,2,1,0,4,2,1,2,0,0,0,1,2,1,0,1,1,0,0,2,3,1,0,1,1,1,0,0,1,0,1,0,1,1,1,4,1,2,1,1,4,3,1,1,4,2,0,0,0,1,2,1,2,2,2,2,1,1,1,1,0,0,0,0,0,0,1,2,1,0,1,2,1,0,1,0,1,0,1,0,1,0],\"yaxis\":\"y\",\"type\":\"scattergl\"}],                        {\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"midpoint\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"depth\"}},\"legend\":{\"tracegroupgap\":0},\"title\":{\"text\":\"3R\"},\"height\":300,\"width\":750,\"shapes\":[{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":34263,\"x1\":34263,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":35120,\"x1\":35120,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":38160,\"x1\":38160,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":42847,\"x1\":42847,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":50589,\"x1\":50589,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":71972,\"x1\":71972,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":97616,\"x1\":97616,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":8564155,\"x1\":8564155,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28592157,\"x1\":28592157,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28595448,\"x1\":28595448,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28598056,\"x1\":28598056,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28598061,\"x1\":28598061,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28598165,\"x1\":28598165,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":28600700,\"x1\":28600700,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"}]},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('99e7e911-6899-4216-8a64-6ce78ba8c4ee');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}, {"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"hovertemplate": "midpoint=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "", "marker": {"color": "lightsalmon", "symbol": "circle"}, "mode": "markers", "name": "", "showlegend": false, "type": "scattergl", "x": [9293, 9395, 37332, 71130, 71131, 71132, 71132, 71133, 71133, 71134, 71134, 190919, 205512, 205962, 205963, 205964, 220562, 251045, 251047, 251048, 251203, 353027, 353028, 353029, 376927, 376928, 376928, 376929, 376932, 376939, 376942, 376956, 376957, 376957, 376958, 376958, 376959, 376959, 376960, 377037, 377038, 665500, 3476182, 3476267, 4712811, 7624851, 7625657, 8474300, 10007352, 12114878, 12196554, 18631, 18706, 18781, 18782, 18808, 18825, 80544, 80545, 80546, 74677, 108478, 142262, 142262, 142263, 142264, 142264, 142265, 142265, 142266, 142266, 142278, 142279, 142280, 142280, 142264, 142265, 142265, 142266, 142279, 142279, 142280, 142280, 142281, 142265, 142266, 142266, 142267, 142269, 142269, 142279, 142280, 142280, 142281, 142281, 142266, 142267, 142267, 142268, 142268, 142280, 142280, 142281, 142281, 142282, 142283, 142267, 142268, 142268, 142269, 142269, 142270, 142280, 142281, 142281, 142282, 142268, 142269, 142281, 142282, 142282, 142283, 142269, 142270, 142281, 142282, 142282, 142283, 142282, 142283, 142283, 142282, 142283, 142283, 142284, 142283, 142284, 142284, 142284, 142285, 142294, 142295, 142295, 142295, 142296, 142296, 277111, 277111, 433342, 448075, 448076, 448103, 448105, 448106, 142296, 142297, 142297, 143404, 262067, 262068, 262068, 276659, 276659, 277111, 277112, 277113, 281418, 281419, 290596, 322195, 322196, 322351, 355809, 424175, 448075, 448076, 448076, 448077, 448078, 448084, 448086, 448105, 448105, 448106, 448107, 142297, 142298, 142298, 142299, 142299, 142300, 142302, 181955, 205729, 235053, 248711, 262067, 262068, 262068, 262069, 262071, 276661, 277109, 277109, 277111, 277111, 277112, 277112, 277114, 281419, 301568, 301569, 322193, 322193, 322194, 322194, 322195, 322195, 322196, 322196, 322197, 322199, 322351, 322352, 322352, 364018, 392707, 394996, 424176, 424177, 430290, 448069, 448075, 448076, 448076, 448077, 448077, 448078, 448078, 448079, 448081, 448084, 448087, 448089, 448090, 448091, 448092, 448092, 448095, 448104, 448105, 448106, 448106, 448107, 448107, 142298, 142299, 142303, 143405, 208592, 248712, 262068, 262068, 262069, 262070, 262070, 276660, 276661, 277111, 277112, 277113, 281419, 281420, 281421, 322194, 322196, 322197, 322198, 322352, 322353, 424176, 430290, 448076, 448077, 448077, 448079, 448080, 448105, 448106, 448106, 448107, 448107, 448108, 208593, 248712, 262066, 262068, 276662, 277113, 277113, 322197, 322352, 424178, 448077, 448088, 448089, 448090, 448108, 448108, 322198, 322353, 391708, 448078, 448108, 262071, 448109, 277114, 448110, 262070, 277115, 322201, 277117, 144524, 144587, 144600, 144675, 144730, 278307, 144871, 323520, 221629, 316786, 269178, 325516, 274899, 274899, 274900, 328375, 388503, 328375, 327820, 369427, 355138, 355139, 428623, 368495, 387846, 381849, 381838, 381839, 381839, 381851, 381851, 381852, 381853, 381853, 381854, 381854, 381855, 381856, 381857, 381858, 381858, 381839, 381853, 381853, 381854, 381855, 381840, 381853, 381854, 381855, 381855, 381852, 381853, 381855, 381855, 381856, 381857, 381858, 381863, 396895, 442135, 543959, 401203, 381866, 381869, 381870, 396897, 396897, 441981, 543961, 567892, 396897, 396898, 441982, 442135, 442137, 514782, 543961, 567861, 567861, 567864, 567891, 381870, 396897, 396898, 396898, 441982, 543962, 381872, 396447, 442138, 475595, 543962, 381872, 396448, 396899, 396899, 441979, 442138, 567864, 567891, 396899, 396900, 441984, 441984, 396900, 441984, 567863, 567894, 396902, 396902, 567866, 543968, 411037, 411034, 411038, 411037, 411037, 411039, 411040, 411040, 411041, 411041, 411042, 411042, 411042, 411486, 411488, 529373, 411056, 411490, 411490, 411492, 411491, 456574, 456575, 456730, 582458, 582483, 582487, 411492, 582484, 411492, 456577, 411493, 411493, 411494, 582489, 411938, 411940, 411926, 411941, 411941, 411942, 411927, 411928, 411929, 411941, 411942, 411942, 411929, 411930, 411942, 411943, 411944, 411944, 411945, 411957, 582908, 411957, 436399, 457027, 457181, 416249, 416250, 436400, 457025, 457026, 457027, 457027, 457028, 457182, 457182, 457183, 482757, 529827, 559006, 559007, 559008, 565121, 568173, 582906, 582907, 582907, 582908, 582909, 582909, 582910, 582911, 582915, 582918, 582918, 582920, 582921, 582933, 582935, 582936, 582936, 582937, 582938, 420554, 420554, 420555, 420555, 420556, 420556, 420556, 420557, 420556, 461486, 461487, 563311, 461332, 461487, 572479, 587241, 461332, 420571, 461333, 461333, 461488, 587228, 587244, 440706, 461333, 461334, 461489, 563313, 587214, 587229, 587243, 587244, 438914, 470513, 441140, 597536, 460858, 460859, 460857, 460858, 481483, 607394, 583463, 607364, 607372, 481641, 481486, 502090, 502107, 502105, 502108, 502093, 502108, 502093, 502105, 502107, 502107, 502109, 502094, 502108, 502109, 502094, 502110, 502095, 502096, 502107, 502109, 502109, 502110, 502110, 502109, 502109, 502111, 502111, 502111, 502112, 502113, 502114, 502116, 502121, 502122, 628016, 502124, 628001, 502124, 627988, 627990, 502125, 604089, 502125, 502265, 502266, 502266, 527841, 535723, 604090, 604091, 627989, 627990, 627990, 627991, 627998, 628005, 628008, 628017, 628018, 628019, 628021, 628021, 502127, 502266, 502266, 571620, 574912, 604090, 610204, 610206, 627990, 627991, 627991, 627993, 627994, 627995, 627996, 627997, 627999, 628019, 628020, 628021, 628022, 604091, 628020, 527842, 535724, 604092, 627992, 628021, 628022, 627993, 604093, 627993, 502404, 502406, 502407, 502407, 502416, 502419, 502419, 502420, 502420, 502421, 502421, 502422, 502422, 502418, 502418, 502420, 502421, 502422, 502422, 502422, 502422, 502423, 502422, 502424, 502523, 502525, 502433, 502433, 502528, 502434, 628144, 628175, 502435, 502527, 604244, 628175, 502435, 502526, 502436, 502525, 502527, 575066, 604245, 604246, 604248, 610359, 620667, 628145, 628145, 628146, 628146, 628147, 628147, 628148, 628149, 628149, 628150, 628151, 628153, 628157, 628158, 628158, 628160, 628173, 628173, 628174, 628174, 628175, 628175, 628176, 628176, 628177, 502529, 502530, 502531, 604246, 628146, 628146, 628147, 628148, 628158, 628174, 628175, 628177, 628177, 12384492, 535879, 604246, 628147, 628149, 628176, 628176, 628178, 502624, 502631, 502632, 502631, 502633, 502634, 502635, 502635, 604345, 628261, 535983, 604350, 628250, 628279, 628280, 628282, 553568, 553568, 653717, 653719, 653749, 569335, 569336, 569336, 569337, 569337, 661633, 661603, 604691, 637703, 661632, 661610, 585766, 669825, 640041, 673055, 641125, 641126, 679708, 697499, 643154, 643193, 674625, 647711, 647711, 647712, 647713, 647711, 676890, 700790, 700791, 676891, 700819, 700821, 676892, 706068, 706056, 706056, 706057, 706057, 706069, 706069, 706070, 706070, 706071, 706073, 706069, 706073, 706069, 706070, 706071, 706072, 706059, 706071, 706071, 706071, 706071, 706073, 706071, 706082, 729973, 706083, 729971, 729974, 729982, 729998, 706084, 706085, 729970, 729971, 729975, 729982, 729987, 730001, 706085, 715237, 729963, 729969, 729970, 729970, 729971, 729973, 729974, 729975, 729981, 729985, 729988, 729998, 729999, 729999, 730000, 730001, 730001, 706088, 729970, 729971, 729971, 729972, 729973, 729980, 729999, 730000, 730001, 730002, 729971, 730002, 730002, 729984, 730001, 729974, 718296, 718297, 718297, 718296, 718297, 718297, 736113, 736094, 736111, 736085, 736098, 736114, 724402, 724403, 724403, 739164, 739167, 739143, 739166, 738914, 746422, 753851, 753860, 753858, 753864, 753866, 753854, 753855, 753855, 753857, 753867, 753869, 753869, 753855, 753856, 753856, 753857, 753858, 753858, 753860, 753862, 753864, 753868, 753869, 753870, 753870, 753871, 753871, 753872, 753873, 753874, 753856, 753857, 753857, 753858, 753858, 753861, 753862, 753864, 753865, 753866, 753869, 753870, 753871, 753871, 753872, 753872, 753873, 753873, 753874, 753875, 753857, 753858, 753859, 753862, 753864, 753866, 753870, 753870, 753872, 753872, 753874, 753875, 753877, 753878, 753858, 753859, 753859, 753860, 753861, 753864, 753865, 753866, 753867, 753872, 753873, 753877, 753881, 753885, 753859, 753860, 753863, 753870, 753885, 753886, 753860, 753861, 753862, 753862, 753863, 753863, 753864, 753864, 753865, 753865, 753866, 753866, 753867, 753867, 753868, 753868, 753869, 753871, 753871, 753872, 753873, 753873, 753874, 753876, 753884, 753888, 753889, 753863, 753866, 753867, 753867, 753870, 753873, 753875, 753876, 753876, 753886, 753886, 753887, 753887, 753889, 753865, 753871, 753871, 753872, 753874, 753885, 753887, 753887, 753888, 753889, 753885, 753867, 753868, 753874, 753877, 753888, 753866, 753866, 753869, 753874, 753874, 753875, 753878, 753879, 753886, 753887, 753888, 753888, 753889, 753868, 753876, 753887, 753888, 753889, 753889, 753890, 753868, 753874, 753877, 753878, 753883, 753889, 753890, 753868, 753869, 753870, 753870, 753871, 753872, 753890, 753891, 753869, 753870, 753876, 753880, 753870, 753871, 753871, 753874, 753874, 753871, 753872, 753873, 753876, 753879, 753882, 753889, 753892, 753892, 753872, 753873, 753877, 753880, 753892, 753895, 753873, 753874, 753874, 753880, 753890, 753892, 753893, 753895, 753874, 753875, 753875, 753876, 753879, 753880, 753881, 753892, 753894, 753875, 753876, 753877, 753878, 753891, 753893, 753876, 753877, 753877, 753878, 753882, 753883, 753877, 753878, 753878, 753879, 753881, 753882, 753895, 753878, 753879, 753879, 753881, 753881, 753887, 753893, 753894, 753896, 753879, 753880, 753882, 753895, 753896, 753896, 753897, 753880, 753881, 753881, 753882, 753884, 753896, 753896, 753897, 753898, 753881, 753882, 753882, 753883, 753883, 753884, 753884, 753885, 753886, 753894, 753895, 753896, 753897, 753899, 753882, 753883, 753883, 753884, 753884, 753897, 753897, 753883, 753884, 753884, 753885, 753885, 753887, 753897, 753898, 753898, 753884, 753885, 753886, 753887, 753898, 753898, 753899, 753899, 753885, 753886, 753886, 753888, 753888, 753896, 753898, 753898, 753899, 753899, 753901, 753901, 753886, 753887, 753887, 753888, 753897, 753898, 753899, 753900, 753901, 753902, 753887, 753888, 753888, 753889, 753890, 753897, 753898, 753899, 753900, 753902, 753888, 753889, 753889, 753890, 753890, 753898, 753899, 753900, 753901, 753901, 753902, 753903, 753889, 753890, 753890, 753894, 753900, 753901, 753902, 753902, 753903, 753903, 753890, 753899, 753900, 753901, 753902, 753903, 753891, 753892, 753892, 753893, 753894, 753894, 753895, 753897, 753899, 753900, 753901, 753901, 753902, 753902, 753903, 753904, 753904, 753892, 753894, 753900, 753902, 753902, 753903, 753904, 753905, 753893, 753894, 753894, 753895, 753895, 753901, 753902, 753904, 753905, 753894, 753895, 753897, 753901, 753902, 753903, 753903, 753904, 753895, 753898, 753902, 753897, 753898, 753900, 753902, 753902, 753904, 753897, 753899, 753902, 753906, 753898, 753899, 753903, 753904, 753904, 753899, 753904, 753905, 753907, 753900, 753903, 753904, 753907, 753905, 753905, 753909, 753910, 753907, 753908, 753908, 753909, 753910, 753910, 753911, 753911, 753912, 753913, 753909, 753910, 753910, 753911, 753911, 753913, 753913, 753910, 753911, 753911, 753912, 753912, 753913, 753913, 753914, 753911, 753912, 753912, 753913, 753914, 753914, 753912, 753913, 753913, 753914, 753914, 753915, 753913, 753914, 753914, 753915, 753915, 753914, 753915, 753915, 753916, 753915, 753916, 753916, 753916, 753917, 753917, 753918, 753918, 753919, 753919, 753920, 753927, 753928, 753930, 753931, 753931, 753932, 753920, 753921, 753921, 753922, 753923, 753933, 753921, 753922, 753922, 753923, 753929, 753932, 753922, 753923, 753923, 753924, 753926, 753929, 753929, 753930, 753930, 753932, 753923, 753924, 753924, 753925, 753925, 753926, 753929, 753930, 753930, 753931, 753932, 753924, 753925, 753925, 753926, 753926, 753927, 753928, 753929, 753929, 753930, 753930, 753931, 753934, 753925, 753926, 753926, 753927, 753927, 753928, 753929, 753929, 753930, 753930, 753931, 753931, 753932, 753926, 753927, 753927, 753928, 753929, 753929, 753930, 753930, 753931, 753931, 753932, 753932, 753927, 753928, 753928, 753929, 753930, 753930, 753931, 753931, 753932, 753932, 753933, 753928, 753929, 753929, 753930, 753930, 753931, 753931, 753932, 753932, 753933, 753930, 753931, 753931, 753932, 753932, 753933, 753933, 753930, 753931, 753931, 753932, 753932, 753933, 753933, 753934, 753934, 753932, 753933, 753933, 753934, 753933, 753934, 753935, 753933, 753934, 753934, 753935, 753935, 753934, 753935, 753935, 753936, 753936, 753937, 753935, 753936, 753936, 753936, 753937, 753937, 753938, 753940, 753937, 753938, 753938, 753938, 753939, 753939, 753940, 753941, 754009, 753939, 753940, 753940, 753941, 753940, 753941, 753941, 753942, 753942, 753943, 753943, 753943, 753944, 753944, 753945, 753944, 753945, 753945, 754011, 753945, 753946, 753946, 753947, 754012, 754012, 754013, 754014, 753946, 753948, 753947, 753948, 753948, 753949, 753950, 754010, 754011, 754012, 754013, 754014, 753948, 753949, 753949, 753950, 753951, 753970, 754013, 753949, 753950, 753950, 753951, 753951, 753953, 753954, 753957, 753960, 753962, 753963, 753963, 753964, 753964, 754011, 754012, 754013, 753950, 753951, 753951, 753952, 753952, 753953, 753954, 753955, 753955, 753956, 753957, 753958, 753959, 753959, 753960, 753963, 753963, 753964, 753964, 753965, 753965, 753966, 753967, 753968, 753987, 754010, 754011, 754011, 754014, 753951, 753952, 753952, 753953, 753954, 753954, 753956, 753958, 753958, 753960, 753961, 753961, 753962, 753962, 753963, 753964, 753964, 753965, 753965, 753967, 753968, 754008, 754011, 754012, 754013, 753952, 753953, 753953, 753954, 753954, 753955, 753955, 753956, 753956, 753957, 753957, 753958, 753958, 753959, 753959, 753960, 753961, 753961, 753962, 753962, 753963, 753963, 753964, 753964, 753965, 753965, 753966, 753966, 753967, 753967, 753968, 753969, 753970, 753970, 753971, 753972, 754008, 754010, 754010, 754011, 754011, 754012, 754012, 754013, 754014, 753953, 753954, 753954, 753955, 753955, 753956, 753956, 753957, 753957, 753958, 753958, 753959, 753959, 753960, 753961, 753962, 753962, 753963, 753963, 753964, 753964, 753965, 753965, 753966, 753966, 753967, 753968, 753968, 753969, 753970, 753970, 753971, 753972, 753978, 754011, 754011, 754012, 754013, 753954, 753955, 753955, 753956, 753956, 753957, 753957, 753958, 753958, 753959, 753959, 753960, 753960, 753961, 753962, 753962, 753963, 753964, 753964, 753965, 753965, 753966, 753966, 753967, 753967, 753968, 753968, 753971, 753973, 754011, 754011, 754012, 754013, 754013, 753955, 753956, 753957, 753957, 753958, 753958, 753959, 753960, 753960, 753961, 753961, 753962, 753962, 753963, 753963, 753964, 753965, 753965, 753966, 753966, 753967, 753967, 753970, 754014, 754015, 753956, 753957, 753957, 753958, 753958, 753959, 753959, 753961, 753961, 753962, 753962, 753964, 753965, 753965, 753966, 753966, 753967, 753967, 753968, 753969, 753957, 753958, 753959, 753959, 753960, 753962, 753966, 753966, 753967, 753968, 753969, 753972, 754014, 754016, 753958, 753959, 753961, 753962, 753965, 753965, 753966, 753967, 753967, 753968, 753968, 753969, 753969, 753985, 754013, 754014, 753959, 753961, 753961, 753962, 753963, 753963, 753964, 753966, 753967, 753967, 753968, 753971, 753976, 753960, 753961, 753962, 753962, 753963, 753963, 753964, 753964, 753965, 753966, 753967, 753967, 753968, 753969, 753970, 753971, 753973, 753975, 753977, 753961, 753962, 753962, 753963, 753963, 753964, 753965, 753965, 753966, 753968, 753969, 753969, 753970, 754015, 753962, 753963, 753964, 753965, 753967, 753968, 753970, 753971, 753964, 753964, 753965, 753966, 753967, 753969, 753970, 753971, 753971, 753973, 753976, 753979, 753964, 753965, 753965, 753966, 753967, 753967, 753968, 753969, 753970, 753970, 753971, 753971, 753965, 753966, 753966, 753967, 753967, 753968, 753968, 753970, 753971, 753971, 753972, 753972, 753973, 753974, 753966, 753967, 753967, 753968, 753968, 753969, 753969, 753971, 753971, 753972, 753972, 753973, 753974, 753975, 753980, 754017, 754019, 753967, 753968, 753968, 753969, 753970, 753971, 753971, 753972, 753973, 753980, 754018, 753968, 753969, 753970, 753971, 753971, 753973, 753973, 753974, 753975, 754020, 753969, 753970, 753970, 753971, 753971, 753972, 753972, 753973, 753973, 753974, 753974, 753975, 753978, 753982, 754017, 753970, 753971, 753971, 753972, 753972, 753973, 753974, 753974, 753975, 753971, 753972, 753972, 753973, 753973, 753974, 753974, 753975, 753975, 753976, 753979, 753983, 754021, 754022, 753972, 753973, 753973, 753974, 753975, 753975, 753976, 753976, 753977, 753977, 753979, 753981, 754022, 753973, 753974, 753974, 753975, 753975, 753976, 753976, 753979, 753983, 753984, 754023, 753974, 753975, 753975, 753976, 753977, 753977, 753978, 753978, 753979, 753980, 753980, 754022, 754022, 754023, 754023, 753975, 753976, 753976, 753977, 753977, 753978, 753979, 753979, 753980, 753981, 753982, 753982, 753985, 753986, 753991, 754023, 754024, 753976, 753977, 753977, 753978, 753978, 753979, 753980, 753982, 753984, 753985, 753991, 754023, 754024, 754024, 753977, 753978, 753978, 753979, 753979, 753980, 753980, 753981, 753984, 753985, 754022, 754024, 754024, 754025, 753978, 753979, 753979, 753980, 753980, 753981, 753981, 753982, 753982, 753983, 753984, 753986, 753987, 753993, 754018, 754021, 754022, 754023, 754024, 754025, 754025, 753979, 753980, 753980, 753981, 753981, 753982, 753982, 753983, 753983, 753984, 753984, 753985, 753986, 753987, 753991, 753993, 754020, 754022, 754024, 754025, 754025, 754026, 754027, 753980, 753981, 753981, 753982, 753982, 753983, 753983, 753984, 753984, 753985, 753985, 753986, 753987, 753987, 753988, 753988, 753991, 754024, 754024, 754025, 754025, 754026, 754026, 753981, 753982, 753982, 753983, 753983, 753984, 753984, 753985, 753986, 753988, 753989, 753992, 753992, 753994, 753995, 754024, 754025, 754025, 754026, 754027, 754027, 753982, 753983, 753983, 753984, 753984, 753985, 753985, 753986, 753986, 753987, 753987, 753988, 753989, 753989, 753994, 753996, 754025, 754026, 754027, 754027, 753983, 753984, 753984, 753985, 753985, 753986, 753986, 753988, 753988, 753989, 753989, 753990, 753990, 753992, 753993, 753994, 753995, 754024, 754025, 754026, 754026, 754027, 754027, 754028, 753984, 753985, 753985, 753986, 753986, 753987, 753987, 753988, 753989, 753989, 753990, 753994, 753998, 754004, 754026, 754027, 754028, 754028, 754030, 753985, 753986, 753986, 753987, 753987, 753988, 753988, 753989, 753990, 753990, 753991, 754026, 754027, 754027, 754028, 754028, 754029, 754030, 753986, 753987, 753987, 753988, 753988, 753989, 753990, 753990, 753991, 753991, 753992, 753995, 753997, 754027, 754028, 754028, 754029, 754029, 753987, 753988, 753988, 753989, 753989, 753990, 753991, 753991, 753992, 753995, 753997, 753998, 754027, 754027, 754028, 754028, 754029, 754029, 754030, 754030, 754032, 753989, 753989, 753990, 753991, 753991, 753992, 753996, 753997, 754000, 754006, 754028, 754029, 754030, 754030, 754031, 754031, 753989, 753990, 753991, 753991, 753992, 753992, 753994, 753998, 754026, 754027, 754028, 754028, 754029, 754029, 754030, 754030, 754031, 754032, 753990, 753991, 753992, 753992, 753993, 753993, 753996, 753998, 753998, 754023, 754029, 754029, 754030, 754031, 754031, 754032, 754033, 754033, 753991, 753992, 753992, 753993, 753993, 753994, 753994, 753999, 754027, 754030, 754031, 754031, 754032, 754032, 753992, 753993, 753994, 753997, 753999, 754002, 754027, 754030, 754031, 754032, 754032, 754033, 753993, 753994, 753994, 753996, 753999, 754000, 754028, 754031, 754031, 754032, 754032, 754033, 754034, 753994, 753995, 753995, 753998, 754000, 754002, 754030, 754030, 754031, 754031, 754032, 754033, 753995, 753996, 753996, 753999, 753999, 754001, 754002, 754004, 754025, 754028, 754030, 754030, 754031, 754032, 754032, 754033, 754033, 754034, 753996, 753997, 753999, 754000, 754001, 754001, 754002, 754032, 754033, 754033, 754034, 754034, 753997, 754000, 754000, 754002, 754033, 754034, 754035, 754036, 754002, 754007, 754033, 754034, 754034, 754035, 754034, 754003, 754035, 754036, 754030, 754037, 754037, 754035, 754036, 754036, 754037, 754005, 754035, 754036, 754036, 754037, 754037, 754038, 754038, 754035, 754006, 754019, 754037, 754037, 754039, 754015, 754035, 754036, 754037, 754038, 754038, 754039, 754039, 754040, 754042, 754022, 754038, 754040, 754021, 754039, 754040, 754040, 754040, 754022, 754041, 754036, 754041, 754042, 754042, 754046, 754047, 754049, 754052, 754053, 754053, 754053, 754063, 754064, 754065, 754064, 754066, 754065, 754066, 754067, 754065, 754068, 754064, 754068, 754068, 754066, 754068, 754069, 754066, 754068, 754069, 754069, 754070, 754067, 754068, 754069, 754071, 754068, 754069, 754069, 754070, 754070, 754071, 754069, 754070, 754070, 754071, 754071, 754070, 754071, 754071, 754072, 754071, 754072, 754072, 754073, 754074, 754072, 754073, 754073, 754075, 754073, 754074, 754074, 754075, 754075, 754076, 754074, 754075, 754075, 754076, 754075, 754076, 754076, 754077, 754077, 754076, 754077, 754077, 754078, 754077, 754078, 754078, 754078, 754079, 754079, 754079, 754080, 754089, 754092, 754095, 754080, 754081, 754088, 754092, 754093, 754093, 754095, 754097, 754081, 754082, 754088, 754089, 754090, 754090, 754091, 754091, 754092, 754092, 754093, 754094, 754094, 754095, 754095, 754082, 754083, 754087, 754087, 754088, 754089, 754089, 754090, 754090, 754091, 754091, 754094, 754095, 754083, 754085, 754086, 754087, 754088, 754088, 754089, 754089, 754090, 754090, 754091, 754091, 754092, 754092, 754093, 754094, 754098, 754085, 754087, 754087, 754088, 754088, 754089, 754089, 754090, 754090, 754091, 754091, 754092, 754092, 754093, 754092, 754092, 754093, 754093, 754094, 754095, 754094, 754095, 754095, 754093, 754095, 754095, 754095, 754096, 754096, 754095, 754096, 754096, 754097, 754096, 754097, 754097, 754098, 754100, 754097, 754098, 754098, 754099, 754098, 754099, 754099, 754100, 754100, 754099, 754100, 754100, 754102, 754100, 754101, 754101, 754102, 754101, 754102, 754102, 754102, 754103, 754103, 754106, 754111, 1042550, 754103, 754104, 754104, 754106, 754104, 754105, 754105, 754105, 754106, 754106, 754107, 3031856, 754106, 754107, 754108, 2021185, 754107, 754108, 754108, 754109, 2394349, 8002711, 754108, 754109, 754109, 754110, 754111, 754112, 1324498, 754109, 754110, 754110, 754111, 1324498, 754110, 754111, 754112, 754115, 2124841, 754111, 754112, 754112, 754113, 1042555, 1320137, 2021922, 754112, 754113, 754113, 754114, 754115, 754115, 754119, 754120, 1042556, 1324500, 2394350, 2767370, 754113, 754114, 754114, 754115, 754124, 1303634, 3415196, 754114, 754115, 754115, 754116, 754116, 754117, 754117, 754120, 754122, 754132, 754135, 1042556, 1324501, 754115, 754116, 754116, 754117, 754117, 754118, 754118, 754119, 754119, 754120, 754121, 754121, 754122, 754123, 754125, 754126, 754128, 754128, 754136, 957055, 990838, 1042557, 1317718, 1324501, 1549362, 1985572, 1985573, 5232736, 8001859, 754116, 754117, 754117, 754118, 754118, 754119, 754120, 754120, 754121, 754122, 754122, 754124, 754125, 754127, 754127, 754128, 990839, 1042557, 1295449, 1317718, 1317720, 754117, 754118, 754118, 754119, 754119, 754120, 754120, 754121, 754121, 754123, 754124, 754126, 754131, 948033, 957056, 1042558, 1084591, 1086293, 1197631, 1320138, 1324502, 2230886, 2394349, 8001860, 754118, 754119, 754119, 754120, 754120, 754121, 754121, 754122, 754123, 754124, 754124, 754126, 754127, 754128, 754129, 754131, 754137, 990839, 990840, 1042558, 1190441, 1317721, 1320138, 1320139, 1320140, 1324503, 2394354, 754119, 754120, 754120, 754121, 754121, 754122, 754122, 754123, 754123, 754124, 754124, 754125, 754125, 754126, 754126, 754127, 754127, 754129, 754132, 754135, 754136, 793043, 824123, 901639, 957055, 957057, 1042558, 1042558, 1042559, 1042576, 1320139, 1465950, 1613865, 1985573, 754120, 754121, 754121, 754122, 754122, 754123, 754123, 754124, 754124, 754125, 754125, 754126, 754127, 754127, 754128, 754128, 754129, 754129, 754130, 754131, 973864, 990840, 1042559, 1042559, 1042560, 1197628, 1324504, 2021914, 754121, 754122, 754122, 754123, 754123, 754124, 754124, 754125, 754125, 754126, 754127, 754128, 754128, 754129, 754129, 754130, 754130, 754131, 754134, 754136, 957057, 990841, 1042559, 1042559, 1042560, 1042560, 1119522, 1317722, 1320140, 1324504, 1324505, 754122, 754123, 754123, 754124, 754124, 754125, 754125, 754126, 754126, 754127, 754128, 754128, 754129, 754129, 754130, 754130, 754131, 754132, 754139, 990841, 1042559, 1042560, 1042561, 1324505, 754123, 754124, 754124, 754125, 754125, 754126, 754126, 754127, 754128, 754129, 754130, 754130, 754131, 754132, 754132, 754133, 754138, 857671, 860213, 973864, 990842, 990842, 990843, 1197629, 1197629, 1324505, 754124, 754125, 754125, 754126, 754126, 754127, 754127, 754128, 754128, 754129, 754130, 754131, 754131, 754132, 754132, 754133, 754136, 754140, 754141, 957060, 990842, 1042561, 1042562, 1197633, 1205241, 1320141, 1324506, 754125, 754126, 754126, 754127, 754127, 754128, 754128, 754129, 754129, 754130, 754131, 754131, 754132, 754132, 754133, 754140, 754141, 831908, 858656, 861125, 963572, 973865, 990843, 990843, 1042563, 1042581, 1324506, 1555487, 754126, 754127, 754127, 754128, 754128, 754129, 754130, 754130, 754131, 754131, 754133, 754133, 754135, 754140, 754140, 858656, 957060, 1042562, 1042563, 1320142, 754127, 754128, 754128, 754129, 754129, 754130, 754130, 754131, 754133, 754133, 754135, 754136, 754137, 754140, 754141, 754141, 826522, 858657, 990844, 990846, 1042563, 1317724, 1324507, 1479922, 754128, 754129, 754129, 754130, 754130, 754131, 754132, 754132, 754133, 754133, 754134, 754135, 754136, 754141, 754142, 754143, 759282, 858657, 957060, 990844, 990845, 1042562, 1042564, 1070171, 1119526, 1197632, 1317725, 1320145, 1324508, 754129, 754130, 754130, 754131, 754131, 754132, 754133, 754134, 754135, 754136, 754142, 754142, 754143, 858659, 957062, 973869, 990845, 1190448, 1320143, 754130, 754131, 754131, 754132, 754132, 754133, 754133, 754135, 754135, 754136, 754137, 754138, 754139, 754142, 754143, 754143, 820303, 857674, 990845, 990846, 1324509, 754131, 754132, 754132, 754133, 754133, 754134, 754135, 754135, 754136, 754140, 754143, 754143, 754144, 793049, 863496, 940522, 957063, 990846, 990846, 1042565, 1135581, 1177033, 1599774, 754132, 754133, 754133, 754134, 754134, 754135, 754135, 754136, 754136, 754137, 754139, 754142, 754143, 754143, 754144, 754146, 793048, 917860, 957063, 973869, 990846, 990847, 1197635, 1317727, 754133, 754134, 754134, 754135, 754135, 754136, 754137, 754137, 754138, 754143, 754144, 754144, 754145, 839573, 957065, 1042565, 1042566, 1324510, 754134, 754135, 754135, 754136, 754136, 754137, 754137, 754138, 754140, 754144, 754144, 754145, 861129, 897345, 957064, 1324511, 754135, 754136, 754136, 754137, 754137, 754138, 754138, 754140, 754141, 754143, 754145, 754145, 754146, 754146, 926926, 948042, 990848, 1042567, 1197635, 1317728, 1320146, 1320148, 1324511, 1613873, 1985581, 754136, 754137, 754137, 754138, 754138, 754139, 754140, 754140, 754141, 754145, 754146, 990848, 1042568, 1197635, 1324512, 754137, 754138, 754138, 754139, 754139, 754141, 754144, 754146, 754146, 754147, 926925, 957066, 973873, 990849, 990849, 1042568, 1197636, 1324512, 754138, 754139, 754139, 754140, 754140, 754141, 754141, 754144, 754146, 754147, 754147, 858662, 858664, 948044, 957065, 990849, 1042569, 1084602, 1190452, 1320149, 1324513, 754139, 754140, 754140, 754141, 754141, 754142, 754142, 754144, 754144, 754146, 754146, 754147, 754147, 754148, 861124, 926927, 957065, 957066, 973875, 990850, 1042568, 1042569, 1197637, 1320149, 1324513, 754140, 754141, 754141, 754142, 754142, 754143, 754144, 754145, 754146, 754147, 754147, 754148, 754148, 857680, 858663, 926927, 957062, 957065, 957067, 957068, 990850, 990851, 1042568, 1190451, 754141, 754142, 754142, 754143, 754143, 754144, 754145, 754146, 754148, 754148, 754149, 918156, 926927, 926929, 957069, 973875, 990851, 1042569, 1042570, 1324514, 754142, 754143, 754143, 754144, 754146, 754148, 754148, 754149, 990851, 1320149, 1320150, 1324515, 754143, 754144, 754149, 754149, 754150, 831917, 857682, 858665, 990852, 1324515, 754144, 754145, 754145, 754146, 754149, 754149, 754150, 754150, 1042572, 1320151, 1324516, 754145, 754148, 754148, 754149, 754149, 754150, 754150, 1042572, 1320151, 1320155, 1324516, 1613879, 754146, 754147, 754148, 754150, 754150, 754151, 990853, 1320152, 1324517, 754150, 754151, 754152, 754150, 754151, 754152, 990854, 1042573, 1197645, 754150, 754153, 973879, 990855, 1324518, 754152, 754154, 754152, 754153, 754154, 820313, 857685, 957073, 990856, 990856, 4443447, 754153, 754153, 754154, 1197643, 2394370, 754155, 990857, 990857, 1042576, 754154, 754155, 754155, 924680, 957074, 957075, 963589, 990857, 1042577, 1119538, 1190330, 1190460, 1197646, 1324521, 754155, 754156, 820315, 828162, 858670, 861140, 926936, 957075, 990858, 990858, 1042577, 1320159, 1324521, 754156, 754157, 860230, 957075, 973884, 990858, 990859, 1042577, 1042578, 754157, 754158, 754158, 766825, 766826, 783300, 793063, 793063, 793064, 820316, 826534, 826536, 826538, 857688, 857688, 858672, 858673, 858673, 861141, 912158, 924681, 948053, 957073, 957074, 957076, 957076, 957077, 973881, 973882, 973883, 973885, 990859, 990859, 990860, 1042576, 1042576, 1042577, 1042577, 1042578, 1042578, 1042579, 1190461, 1197646, 1317739, 1320157, 1320158, 766828, 858674, 863511, 948054, 955845, 957073, 957074, 957076, 963591, 990859, 990860, 1003530, 1034880, 1042578, 1042579, 1479936, 990860, 1042579, 957074, 973886, 764446, 764525, 764604, 1329751, 779509, 779510, 779510, 930938, 844607, 1055260, 812456, 1071733, 831980, 831979, 831980, 831982, 831984, 831985, 831986, 897590, 1029776, 995995, 1081497, 1081499, 1081499, 1081500, 1029781, 886488, 924843, 990851, 1023247, 894140, 1033588, 898927, 898929, 898932, 898933, 898934, 1392550, 997075, 1114972, 999333, 1063255, 930083, 902240, 908541, 909705, 909706, 1051665, 1402304, 914781, 1054201, 925027, 1042518, 961234, 961232, 961234, 961234, 961235, 961237, 961235, 961238, 961236, 961237, 1060620, 1077428, 1060622, 1146124, 1423705, 964682, 1146125, 1428070, 962223, 1428072, 963201, 963204, 963198, 963199, 963202, 963202, 963204, 963203, 963203, 963207, 963205, 963206, 963206, 963208, 1302172, 1061604, 1095386, 1294991, 963218, 1095389, 1061606, 1095389, 1095390, 1061607, 1061608, 1072248, 1061608, 1078415, 1061608, 1061609, 1095392, 1095393, 1147113, 966318, 966319, 1030769, 1096947, 968131, 968133, 968137, 968139, 968140, 968141, 968282, 1149576, 1064073, 1427156, 1097858, 1193313, 968425, 1149735, 972877, 972880, 1066444, 1100228, 1040568, 1467734, 1049174, 1104589, 1070171, 1200591, 1081612, 1090675, 1082181, 1082272, 1082369, 1121187, 1121190, 1095216, 1095217, 1095218, 1095218, 1141109, 1144420, 1161396, 1213114, 1213115, 1099726, 1099726, 1099729, 1099727, 1099730, 1099729, 1099730, 1129865, 1497313, 1490530, 1129865, 1163651, 1215371, 1129866, 1163652, 1129870, 1126925, 1384038, 1141959, 1141960, 1141960, 1142041, 1142042, 1142042, 1142043, 1142124, 1142125, 1184848, 1184850, 1236566, 1236566, 1518511, 1157548, 1244282, 1160003, 1160003, 1160004, 1160005, 1159992, 1160006, 1160004, 1160006, 1159994, 1160004, 1160007, 1160004, 1160007, 1160008, 1159995, 1159996, 1160008, 1160009, 1160009, 1160009, 1193788, 1520670, 1193789, 1245506, 1193790, 1527453, 1160022, 1176812, 1176814, 1176814, 1176815, 1176816, 1176817, 1193791, 1193792, 1193794, 1237812, 1245511, 1245529, 1253835, 1295649, 1393263, 1393264, 1393394, 1400579, 1527455, 1743560, 2433841, 1193792, 1193792, 1173034, 1173035, 1173036, 1173036, 1183328, 1183331, 1200305, 1295758, 1181286, 1181362, 1181437, 1256222, 1186989, 1187000, 1190309, 1193605, 1193621, 1193621, 1193622, 1193620, 1193622, 1193609, 1193621, 1193622, 1193622, 1193623, 1193621, 1193622, 1193623, 1193623, 1193624, 1193624, 1193625, 1193625, 1262316, 1346824, 1193635, 1262317, 1210598, 1210598, 1262317, 1262318, 1515209, 1544262, 1210599, 1210599, 1262317, 1262317, 1262318, 1262318, 1339280, 1539899, 1227561, 1227562, 1227562, 1227563, 1227564, 1227574, 1227575, 1227575, 1227576, 1227576, 1227577, 1227577, 1227578, 1227562, 1227575, 1227575, 1227576, 1227576, 1227577, 1227577, 1227578, 1227575, 1227576, 1227577, 1227577, 1227578, 1227576, 1227578, 1227577, 1227580, 1227579, 1227581, 1227579, 1227589, 1227589, 1227590, 1279293, 1434361, 1227590, 1227590, 1279293, 1427178, 1556873, 1561238, 1227590, 1227591, 1240243, 1279291, 1279295, 1339086, 1427178, 1227591, 1227592, 1227592, 1227593, 1279294, 1279294, 1279295, 1279295, 1356257, 1427048, 1427179, 1434363, 1434363, 1554456, 1554457, 1556874, 1556875, 1561239, 1836503, 2222309, 1227592, 1227593, 1279294, 1279294, 1279295, 1279295, 1279296, 1279296, 1279311, 1279313, 1279314, 1287618, 1323030, 1323031, 1356257, 1356258, 1427041, 1427179, 1434363, 1434364, 1434366, 1532187, 1540807, 1554456, 1554458, 1554459, 1556874, 1556875, 1556876, 1556877, 1561240, 2149492, 2631087, 1227596, 1279295, 1279295, 1279296, 1279296, 1279297, 1279314, 1279315, 1307010, 1356258, 1427180, 1434364, 1554458, 1556875, 1556876, 1556877, 1556879, 1279296, 1554457, 1279296, 1339090, 1356259, 1556876, 1556877, 1556877, 1279298, 1556879, 1252917, 1252918, 1291966, 1291968, 1315614, 1478381, 1598477, 1330995, 1330996, 1330997, 1330996, 1330997, 1330998, 1330997, 1330998, 1330998, 1331014, 1331014, 1331015, 1331017, 1330998, 1330999, 1331010, 1331013, 1331013, 1331014, 1331014, 1331015, 1331015, 1331016, 1331017, 1330999, 1331014, 1331015, 1331016, 1331016, 1331017, 1331017, 1331030, 1331000, 1331010, 1331014, 1331014, 1331015, 1331015, 1331016, 1331016, 1331017, 1331017, 1331018, 1331018, 1331019, 1331019, 1331020, 1331020, 1331021, 1331021, 1331022, 1331023, 1331025, 1331026, 1331026, 1331030, 1331031, 1331034, 1331013, 1331013, 1331014, 1331014, 1331015, 1331015, 1331016, 1331016, 1331017, 1331017, 1331018, 1331018, 1331019, 1331019, 1331020, 1331020, 1331021, 1331021, 1331022, 1331023, 1331031, 1331025, 1606172, 1331027, 1331028, 1331030, 1331028, 1331031, 1331029, 1331029, 1331030, 1331030, 1331031, 1331033, 1478897, 1331029, 1331030, 1331030, 1331031, 1331032, 1331032, 1608595, 2274029, 1331030, 1331031, 1331031, 1331032, 1331032, 1331033, 1331034, 1331034, 1331035, 1331036, 1331036, 1331038, 1331046, 1358729, 1486082, 1486083, 1612959, 1331031, 1331032, 1331032, 1331033, 1331033, 1331034, 1331034, 1331035, 1331035, 1331036, 1331049, 1478900, 1486083, 1486088, 1583907, 1608594, 1608594, 1608595, 1608596, 5097181, 1331032, 1331033, 1331033, 1331034, 1331034, 1331035, 1331036, 1478899, 1493693, 1608595, 1608597, 1612960, 1843941, 1331033, 1331034, 1331034, 1331035, 1331035, 1331036, 1331036, 1331037, 1331039, 1331039, 1331050, 1390809, 1407978, 1478899, 1606179, 1608595, 1608596, 1612960, 1331034, 1331035, 1331035, 1331036, 1331036, 1331037, 1331037, 1331038, 1331039, 1331042, 1486084, 1608596, 1608599, 1612961, 2310307, 2682811, 1331035, 1331036, 1331036, 1331037, 1331037, 1331038, 1331038, 1331043, 1331048, 1331050, 1331051, 1331051, 1608596, 1608597, 1608597, 1612961, 1902323, 1331036, 1331037, 1331037, 1331038, 1331038, 1331039, 1331039, 1331040, 1331040, 1331041, 1331041, 1331051, 1331052, 1404970, 1478903, 1583909, 1608596, 1608597, 1612962, 1331037, 1331038, 1331038, 1331039, 1331039, 1331040, 1331040, 1331041, 1331041, 1331044, 1331052, 1486086, 2274036, 1331038, 1331039, 1331039, 1331040, 1331040, 1331041, 1331041, 1331042, 1331043, 1331044, 1331049, 1331050, 1374754, 1407981, 1407981, 1583910, 1608597, 1608598, 1608599, 1608600, 1612963, 1862851, 1888227, 1331039, 1331040, 1331040, 1331041, 1331041, 1331044, 1331050, 1331051, 1331052, 1339344, 1478902, 1612963, 1331040, 1331041, 1331041, 1331042, 1331042, 1331043, 1331044, 1331044, 1331045, 1331046, 1331051, 1331053, 1374754, 1374755, 1478903, 1486087, 1486088, 1490547, 1528852, 1608598, 1331041, 1331042, 1331042, 1331043, 1331043, 1331044, 1331044, 1331045, 1331046, 1331047, 1331052, 1478904, 1608597, 1608600, 1608600, 1608601, 1867813, 2177040, 1331042, 1331043, 1331043, 1331044, 1331044, 1331046, 1331047, 1331048, 1331049, 1331049, 1331050, 1331052, 1331054, 1358625, 1407983, 1486088, 1487827, 1608599, 1608602, 1331043, 1331044, 1331044, 1331045, 1331046, 1331047, 1331048, 1331048, 1331051, 1331055, 1358735, 1486089, 1608600, 1608601, 1331044, 1331045, 1331045, 1331046, 1331046, 1331047, 1331048, 1331049, 1331051, 1331052, 1331053, 1486089, 1608600, 1608601, 1608601, 1608603, 1862853, 2274037, 1331045, 1331046, 1331046, 1331047, 1331047, 1331048, 1331048, 1331049, 1331051, 1331052, 1407984, 1407984, 1478904, 1478906, 1583914, 1608601, 1608602, 1612966, 1331046, 1331047, 1331047, 1331048, 1331048, 1331049, 1331051, 1331052, 1331052, 1331053, 1331054, 1374756, 1478773, 1486090, 1862854, 1331047, 1331048, 1331048, 1331049, 1331049, 1331050, 1331051, 1331053, 1331055, 1478776, 1608602, 1608604, 1612967, 1331048, 1331049, 1331049, 1331050, 1331050, 1331051, 1331053, 1331054, 1331055, 1384265, 1583915, 1331049, 1331050, 1331051, 1331051, 1331052, 1331054, 1331056, 1331056, 1373057, 1407987, 1478908, 1608603, 1608604, 1612968, 1331050, 1331051, 1331051, 1331052, 1331052, 1331054, 1331055, 1331056, 1331056, 1612969, 2274039, 1331051, 1331052, 1331052, 1331053, 1331054, 1331055, 1331057, 1358631, 1358633, 1478908, 1596891, 1605205, 1608606, 1612969, 1331052, 1331053, 1331053, 1331054, 1331054, 1331055, 1331056, 1331056, 1331057, 1612970, 2274041, 2682820, 1331054, 1331054, 1331055, 1331056, 1331057, 1331058, 1407988, 1478910, 1608605, 1608606, 1331054, 1331056, 1331056, 1331057, 1374764, 1583918, 1612971, 1331056, 1331056, 1331057, 1331057, 1331058, 1374760, 1478911, 1331057, 1331057, 1331058, 1331059, 1331057, 1331058, 1331059, 1331059, 1339355, 1331058, 1331059, 1331060, 1331060, 1339357, 1407991, 1486097, 1606189, 1608609, 2274045, 1331059, 1331060, 1331061, 1331063, 1390823, 1407991, 1606190, 1608608, 1331060, 1331061, 1331061, 1331063, 1478913, 1606257, 1608608, 1829082, 1331061, 1331062, 1331064, 1407993, 1486098, 1486099, 1486153, 1612974, 1331062, 1331064, 1339355, 1358743, 1374764, 1407991, 1407993, 1407993, 1478914, 1478915, 1486098, 1486099, 1486100, 1493708, 1606191, 1608609, 1608610, 1608610, 1608613, 1612975, 1768388, 1768389, 2274043, 1331064, 1331065, 1339355, 1358745, 1358745, 1360890, 1374766, 1390825, 1407993, 1478916, 1486099, 1486099, 1583923, 1608610, 1608610, 1608611, 1608611, 1612975, 1486099, 1608612, 1612976, 1331067, 1612977, 1381171, 1407995, 1407995, 1478786, 1486102, 1583925, 1608612, 1608612, 1608614, 1612977, 2177053, 1478919, 1486102, 1583925, 1608615, 1612978, 2682825, 1347661, 1347663, 1347661, 1347662, 1347670, 1347671, 1616915, 1416299, 1487222, 1616918, 1616919, 1616921, 1621288, 1386219, 1386223, 1386225, 1386226, 1386329, 1386332, 1386333, 1386439, 1386440, 1386440, 1386441, 1386441, 1386439, 1386442, 1636304, 1506610, 1411969, 1506480, 1506610, 1513794, 1633888, 1636303, 1636309, 10757309, 1390732, 1515941, 1415077, 1650622, 1650624, 1650625, 1418481, 1418477, 1418480, 1418482, 1418482, 1418481, 1418482, 1418485, 1418481, 1418482, 1418483, 1418485, 1418564, 1537423, 1652325, 1451709, 1522630, 1529815, 1529815, 1529816, 1649909, 1652328, 1946056, 1529816, 1529817, 1529818, 1418649, 1652409, 1431287, 1431288, 1536217, 1634040, 1663094, 1437497, 1437501, 1539323, 1666203, 1450597, 1450598, 1450598, 1450599, 1538688, 1467767, 1467767, 1668384, 1672749, 1478919, 1682547, 1484934, 1484923, 1484924, 1484936, 1484938, 1484938, 1484939, 1484941, 1484924, 1484925, 1484935, 1484936, 1484939, 1484939, 1484940, 1484940, 1484941, 1484940, 1484941, 1685553, 1685554, 1484950, 1555858, 1563043, 1660864, 1683137, 1685553, 1689918, 1979280, 1607274, 1685554, 1555858, 1563044, 1563045, 1484954, 1570654, 1685557, 1689921, 1484957, 1555730, 1563045, 1563045, 1660775, 1660869, 1685556, 1685557, 1484960, 1563045, 1689922, 1563046, 1683141, 1555732, 1555863, 1555735, 1500026, 1578195, 1517070, 1861412, 1599952, 1747428, 1626501, 1626511, 1626514, 1626515, 1626515, 1626516, 1626644, 1626648, 1626647, 1626647, 1626650, 1626651, 1626649, 1626650, 1626650, 1626651, 1626652, 1626779, 1626780, 1626765, 1626768, 1626781, 1626766, 1626781, 1626782, 1626782, 1626782, 1626783, 1626782, 1626783, 1626784, 1626783, 1626784, 1626784, 1626786, 1626786, 1626786, 1626786, 1626786, 1626787, 1633965, 1756479, 1626799, 1633966, 1633966, 1633967, 1633969, 1641574, 1731790, 1754060, 1756477, 1756478, 1756478, 1756479, 1756480, 1760842, 1916255, 2036106, 1633966, 1633968, 1756477, 1916256, 2421913, 2421914, 1633966, 1756479, 1641134, 1641135, 1641135, 1641136, 1641136, 1641137, 1641148, 1641149, 1641150, 1641150, 1641151, 1641151, 1641152, 1641152, 1641136, 1641145, 1641148, 1641150, 1641151, 1641151, 1641152, 1641152, 1641154, 1641149, 1641149, 1641151, 1641152, 1641152, 1641150, 1641151, 1641152, 1641153, 1641153, 1641139, 1641140, 1641152, 1641154, 1641150, 1641152, 1641155, 1641152, 1641153, 1641153, 1641160, 1641154, 1641160, 1641163, 1641163, 1641203, 1641163, 1641164, 1641165, 1641166, 1641203, 1641204, 1641165, 1641204, 1641165, 1641205, 1763661, 1763662, 2429100, 1641166, 1641167, 1641205, 1641205, 1648759, 1738974, 1747593, 1751948, 1761243, 1761244, 1763660, 1763661, 1763662, 1763662, 1763663, 1763663, 1763664, 1763664, 1768027, 1992888, 2429098, 1641167, 1681242, 1761244, 1763662, 1763662, 1763663, 1763663, 1763665, 1768027, 2057389, 1641207, 1761244, 1763663, 1763664, 1763665, 1763665, 1768028, 1738976, 1761245, 1763663, 1763663, 1763664, 1763665, 1763666, 1768028, 1641207, 1763665, 1768029, 1763665, 2837882, 1641254, 1641254, 1641255, 1641256, 1648808, 1739024, 1739025, 1761292, 1761293, 1763709, 1763710, 1763711, 1763711, 1763713, 1768076, 1992937, 1739024, 1763711, 1768077, 1644625, 1765397, 1650065, 1765700, 1656362, 1656363, 1656364, 1656353, 1656366, 1656368, 1656374, 1656657, 1656657, 1656658, 1656381, 1656661, 1771268, 1771269, 1775633, 1775635, 1656949, 1656951, 1656951, 1656953, 1656960, 1771559, 1771560, 1771560, 1771561, 2000786, 1721329, 1803752, 1726677, 1806423, 1729611, 1807892, 1836610, 1844891, 1836792, 1836795, 1836797, 1836797, 1836798, 1836800, 1836799, 1836797, 1859066, 1865848, 1861484, 1861485, 1861485, 1861487, 1861487, 1865850, 1859067, 1861485, 1861486, 1861488, 1865850, 1861487, 1865853, 1853170, 1853172, 2780420, 1869672, 1854033, 1854034, 1870102, 1870103, 1862742, 1862743, 1874455, 1874456, 1879372, 1882774, 1881322, 1881330, 1881331, 1881331, 1881332, 1881333, 1881334, 1881323, 1881331, 1881332, 1881332, 1881333, 1881331, 1881332, 1881333, 1881333, 1881334, 1881334, 1881334, 1881335, 1881337, 1881344, 1881398, 1881400, 1881399, 1881401, 1881402, 1881343, 1881399, 1881401, 1881401, 1881402, 1881403, 1881400, 1881400, 1881402, 1881402, 1881404, 1881401, 1881402, 1881403, 1881404, 1881404, 1883755, 1888117, 1881405, 1881465, 1881466, 1881466, 1881470, 1881470, 1881472, 1881473, 1883816, 1883817, 1883818, 1883818, 1883819, 1883819, 1883820, 1883822, 1888181, 1888182, 1883818, 1883819, 1883819, 1883820, 1883821, 1883821, 1888184, 2029627, 1883819, 1883820, 1883820, 1883821, 1883822, 1886156, 1886169, 1886155, 1886156, 1886157, 1886158, 1886158, 1886159, 1886159, 1886160, 1886172, 1886172, 1886173, 1886173, 1886174, 1886174, 1886175, 1886175, 1886176, 1886158, 1886159, 1886159, 1886160, 1886160, 1886161, 1886171, 1886172, 1886173, 1886173, 1886174, 1886174, 1886175, 1886176, 1886159, 1886160, 1886160, 1886161, 1886161, 1886163, 1886163, 1886172, 1886173, 1886174, 1886174, 1886175, 1886175, 1886176, 1886176, 1886177, 1886160, 1886161, 1886161, 1886162, 1886173, 1886174, 1886175, 1886175, 1886176, 1886176, 1886177, 1886177, 1886161, 1886162, 1886162, 1886174, 1886176, 1886176, 1886177, 1886177, 1886178, 1886162, 1886163, 1886163, 1886175, 1886176, 1886176, 1886177, 1886177, 1886178, 1886178, 1886163, 1886165, 1886175, 1886176, 1886176, 1886177, 1886178, 1886178, 1886179, 1886180, 1886175, 1886176, 1886177, 1886178, 1886178, 1886179, 1886179, 1886176, 1886181, 1886181, 1886179, 1886178, 1886178, 1886179, 1886180, 1886181, 1886188, 1886187, 1886188, 1890537, 1886187, 1886188, 1886189, 1886188, 1886189, 1886189, 1886190, 1886190, 1886191, 1890538, 2551607, 1886189, 1886190, 1886190, 1886191, 1886191, 1886192, 1890538, 2121519, 2121520, 2551610, 1886190, 1886191, 1886191, 1886192, 1886194, 1890539, 2045952, 2145388, 2551611, 1886191, 1886192, 1886192, 1886193, 1890539, 2145388, 2179901, 2179902, 2551613, 1886192, 1886193, 1886193, 1886194, 1886195, 1890540, 1890540, 2045953, 2106791, 2106792, 2115401, 2121522, 2179903, 2551608, 2551609, 2551612, 2551614, 2796924, 1886193, 1886194, 1886195, 1890540, 1890541, 2045953, 2045954, 2045955, 2179902, 1886194, 1886196, 1890541, 2106649, 2121522, 2145390, 2179903, 2179905, 2551610, 2551611, 2551611, 2551612, 2796925, 1890541, 1890542, 2045954, 2121523, 2551611, 2551613, 2551615, 1890542, 2551617, 1890542, 1890543, 2045956, 2045956, 1890543, 1894887, 1894888, 1894889, 1894889, 1894890, 1894890, 1894897, 1894898, 1894898, 1894899, 1894899, 1894900, 1894898, 1894898, 1894899, 1894900, 1894898, 1894899, 1894900, 1894899, 1894899, 1894900, 1894907, 1894908, 1894908, 1894909, 1894909, 1894911, 1894913, 1894977, 1894977, 1894978, 1894978, 1894908, 1894909, 1894909, 1894978, 1894978, 1894979, 1894979, 1894980, 1894909, 1894910, 1894912, 1894979, 1894979, 1894980, 1894910, 1894979, 1894979, 1894980, 1894980, 1894981, 1894981, 1894911, 1894979, 1894979, 1894980, 1894980, 1894981, 1894981, 1894982, 2555969, 1894980, 1894981, 1894981, 1894982, 1894981, 1894982, 1894984, 1895048, 1895048, 1895048, 1895049, 1895050, 1895060, 1895049, 1895050, 1895050, 1895051, 1895059, 1895060, 1895050, 1895051, 1895051, 1895059, 1895060, 1895060, 1895061, 1895051, 1895052, 1895054, 1895060, 1895060, 1895061, 1895061, 1895052, 1895061, 1895061, 1895062, 1895061, 1895062, 1895062, 1895064, 1895069, 1895070, 1895070, 1895071, 2111227, 2125961, 2556048, 3431922, 1895071, 2050392, 2050393, 2050524, 2101191, 2111088, 2119840, 2125961, 2125961, 2184342, 2184344, 2556049, 2556050, 2556051, 2964830, 1895076, 1925294, 1954709, 1954710, 1954713, 1954715, 1974555, 2036423, 2036424, 2036426, 2050393, 2050393, 2050394, 2050394, 2050395, 2056736, 2091275, 2091275, 2091277, 2101191, 2111085, 2111085, 2111088, 2111090, 2111230, 2111231, 2111232, 2111232, 2111234, 2119839, 2119840, 2119841, 2125960, 2125960, 2125961, 2125961, 2125962, 2133583, 2144867, 2149829, 2170244, 2170244, 2170245, 2170245, 2170247, 2170248, 2184341, 2184342, 2184342, 2184343, 2184343, 2184344, 2184345, 2206993, 2278278, 2344460, 2381614, 2402523, 2424130, 2459051, 2459052, 2459053, 2476779, 2483230, 2483231, 2530035, 2556048, 2556049, 2556050, 2556050, 2556051, 2556051, 2556052, 2556052, 2556053, 2556053, 2556054, 2556054, 2556055, 2592385, 2592400, 2595404, 2801364, 2801365, 2829627, 2958944, 2964827, 2964829, 2964834, 5803212, 2050400, 1955526, 1955631, 1955735, 2080730, 2014362, 2014363, 2014367, 2014369, 2110046, 2170741, 2243995, 2076150, 2054087, 2129925, 2137931, 2222626, 2177778, 2177790, 2177791, 2177793, 2177793, 2191760, 2522979, 2191760, 2522981, 3106194, 3106195, 2205714, 2205715, 2205723, 2205724, 2205724, 2205725, 2205725, 2205726, 2205726, 2205727, 2205728, 2205715, 2205716, 2205724, 2205724, 2205725, 2205725, 2205726, 2205726, 2205727, 2205727, 2205724, 2205725, 2205725, 2205726, 2205726, 2205727, 2205727, 2205728, 2205728, 2205725, 2205726, 2205727, 2205729, 2205728, 2205729, 2205730, 2205730, 2205733, 2205734, 2205735, 2205857, 2205857, 2205858, 2205734, 2205735, 2205735, 2205737, 2205857, 2205857, 2205858, 2205858, 2205860, 2205735, 2205736, 2205737, 2205857, 2205858, 2205858, 2205859, 2205860, 2205736, 2205737, 2205738, 2205856, 2205857, 2205858, 2205858, 2205859, 2205859, 2205860, 2205860, 2205861, 2205862, 2711382, 2205737, 2205738, 2205738, 2205856, 2205857, 2205857, 2205858, 2205858, 2205859, 2205859, 2205860, 2205861, 2205861, 2205862, 2205859, 2205859, 2205860, 2205861, 2205861, 2205863, 2339675, 2205857, 2205859, 2205859, 2205860, 2205861, 2205861, 2205859, 2205859, 2205860, 2205861, 2205862, 2205863, 2205863, 2205859, 2205861, 2281296, 2205862, 2205861, 2205988, 2205989, 2205990, 2205991, 2205979, 2205991, 2205991, 2205979, 2205980, 2205991, 2205992, 2205980, 2205981, 2205981, 2205991, 2205991, 2205992, 2205992, 2205981, 2205991, 2205992, 2205993, 2205993, 2205982, 2205983, 2205983, 2205984, 2205991, 2205992, 2205992, 2205993, 2205993, 2205992, 2205993, 2205994, 2205984, 2205993, 2205994, 2205994, 2205985, 2205994, 2205994, 2205995, 2205993, 2205995, 2205995, 2205999, 2205997, 2205998, 2206002, 2281426, 2206003, 2206003, 2266550, 2266553, 2711516, 2206004, 2256250, 2266554, 2275306, 2281426, 2325709, 2339807, 2339808, 2339809, 2956829, 2206004, 2266554, 2266555, 2266697, 2266699, 2281427, 2281428, 2300333, 2339808, 2339809, 2339809, 2685501, 2711514, 2711517, 2256249, 2266552, 2266555, 2266557, 2266697, 2266697, 2266698, 2266700, 2266700, 2275307, 2275307, 2281426, 2281427, 2281428, 2281428, 2289049, 2305295, 2325708, 2325709, 2325711, 2325712, 2339808, 2339808, 2339809, 2339810, 2339812, 2421491, 2537080, 2538721, 2638697, 2685502, 2711516, 2711516, 2711517, 2711517, 2711518, 2711518, 2711522, 2971952, 3120296, 2711517, 2711517, 2233785, 2256659, 2281430, 2325715, 2711519, 2325714, 2325715, 2218420, 2287646, 2261573, 2261683, 2261793, 2294454, 2287492, 2287491, 2287494, 2322177, 2322179, 2752266, 2306509, 2306512, 2316814, 2761779, 2307326, 2307326, 2317365, 2317366, 2332096, 2390477, 2332096, 2327110, 2327102, 2327111, 2327111, 2327112, 2327112, 2327113, 2327113, 2327114, 2327115, 2327115, 2327116, 2327117, 2327117, 2327119, 2327118, 2327117, 2327119, 2327255, 2327257, 2327124, 2327125, 2327125, 2327126, 2327256, 2327256, 2327257, 2327259, 2327260, 2327262, 2327126, 2327127, 2327257, 2327258, 2327259, 2327259, 2327260, 2327260, 2327261, 2327259, 2327261, 2327261, 2327128, 2327129, 2327257, 2327258, 2327259, 2327260, 2327260, 2327262, 2327259, 2327262, 2327129, 2327260, 2327261, 2327261, 2327262, 2327262, 2327263, 2327259, 2327261, 2327261, 2327263, 2327264, 2327263, 2327399, 2327393, 2327401, 2327401, 2327390, 2327392, 2327400, 2327401, 2327403, 2327400, 2327401, 2327402, 2327404, 2327403, 2327392, 2327393, 2327394, 2327395, 2327402, 2327403, 2327403, 2327405, 2327394, 2327395, 2327396, 2327402, 2327404, 2327405, 2327395, 2327403, 2327404, 2327405, 2327406, 2327396, 2327405, 2327406, 2327396, 2327397, 2327407, 2327398, 2327404, 2327405, 2327406, 2327407, 2327408, 2327406, 2327408, 2327406, 2327408, 2327410, 2342131, 2365998, 2327415, 2386414, 2400513, 2327413, 2342131, 2386416, 2327416, 2336012, 2342132, 2342132, 2386414, 2400513, 2699401, 2772221, 2327416, 2336012, 2342132, 2342133, 2366000, 2386417, 2400513, 2482194, 2494449, 2597784, 2691561, 2692950, 2699402, 2772221, 2772221, 2772224, 2772225, 2342134, 2327418, 2336013, 2336014, 2342132, 2342133, 2342133, 2342134, 2342134, 2342135, 2342135, 2349756, 2366002, 2366003, 2386417, 2386417, 2386418, 2400515, 2400515, 2400517, 2400520, 2675227, 2699403, 2699404, 2746208, 2772223, 2772223, 2772224, 2772224, 2772225, 2772226, 2772227, 2342133, 2342134, 2361041, 2342144, 2344608, 2344617, 2344619, 2344619, 2344618, 2344619, 2344619, 2344621, 2344621, 2344610, 2344619, 2344620, 2344620, 2344621, 2344620, 2344699, 2344700, 2344630, 2344631, 2344699, 2344700, 2344700, 2344701, 2344701, 2344702, 2344700, 2344700, 2344701, 2344702, 2344700, 2344701, 2344703, 2344701, 2344701, 2344702, 2344701, 2344701, 2344702, 2344780, 2344771, 2344780, 2344782, 2344781, 2344781, 2344782, 2344783, 2344783, 2344782, 2344784, 2344784, 2344785, 2344792, 2350820, 2350820, 2350821, 2395104, 2395104, 2409201, 2409201, 2683915, 2754895, 2780909, 2780910, 2780911, 2780912, 3026223, 2350822, 2780909, 2350823, 2374690, 2708091, 2780910, 2780912, 3026225, 3189688, 3562711, 2350823, 3189690, 2356848, 2356848, 2356862, 2356863, 2356867, 2356873, 2356850, 2356864, 2356864, 2356865, 2356865, 2356866, 2356866, 2356867, 2356869, 2356850, 2356851, 2356862, 2356863, 2356865, 2356865, 2356866, 2356867, 2356867, 2356868, 2356869, 2356874, 2356874, 2356851, 2356866, 2356866, 2356867, 2356868, 2356868, 2356871, 2356852, 2356863, 2356865, 2356866, 2356867, 2356867, 2356868, 2356868, 2356869, 2356869, 2356870, 2356871, 2356872, 2356874, 2356875, 2356867, 2356869, 2356886, 2356880, 2401147, 2356879, 2786953, 2786953, 2356880, 2401142, 2533802, 2786955, 2401153, 2415246, 2437897, 2760939, 2786955, 2356881, 2356882, 2356883, 2364487, 2375772, 2401150, 2401150, 2496927, 2761014, 2786954, 2356883, 2356884, 2356885, 2356886, 2401151, 2415246, 2415247, 2415247, 2415252, 2437898, 2515902, 2612519, 2714135, 2714136, 2786955, 2786955, 2786956, 2786956, 2786957, 2786958, 2356884, 2356884, 2356885, 2356886, 2356888, 2380734, 2415247, 2415248, 2689961, 2714136, 2714136, 2760941, 2786955, 2786956, 2786958, 2786959, 2822570, 3032269, 2356887, 2356891, 2415247, 2415248, 2415249, 2415249, 2415250, 2496934, 2714136, 2714137, 2786955, 2786956, 2786956, 2786957, 2786958, 2786960, 2356885, 2356886, 2356887, 2380735, 2401151, 2415248, 2415249, 2786955, 2786956, 2786957, 2786957, 2786960, 2356896, 2401153, 2415249, 2415249, 2509185, 2612520, 2786956, 2786957, 2786958, 2415250, 2415252, 2612520, 2786957, 2786958, 3021052, 2786958, 2401152, 2415250, 2415251, 2415253, 2786958, 2786958, 2786959, 3195737, 2401154, 2474525, 2509187, 2415252, 2786959, 2786960, 2786962, 2786961, 2401157, 2786962, 2786964, 2380742, 2786965, 2375784, 2786968, 2372107, 2372108, 2372108, 2372109, 2721757, 2768635, 2422868, 2721757, 2394675, 2394675, 2394676, 2394676, 2434149, 2779843, 2805857, 2805858, 2805861, 2399637, 2434150, 2733039, 2805858, 2404598, 2404598, 2404599, 2404600, 2404599, 2520797, 2425014, 2425015, 2439111, 2439113, 2533047, 2810820, 2810822, 2810824, 2439111, 2439112, 2556242, 2636383, 2636384, 2738001, 2810819, 2810820, 2810821, 2810823, 2445423, 2445426, 2445431, 2445432, 2445431, 2445432, 2445432, 2445433, 2445433, 2445432, 2445433, 2445433, 2445433, 2445434, 2445434, 2445434, 2445420, 2445435, 2445435, 2445435, 2445435, 2445436, 2445436, 2656797, 2459526, 2445559, 2831237, 2459529, 2459530, 2459531, 2482181, 2518804, 2541211, 2728315, 2768214, 2805223, 2831238, 2831239, 2831241, 2459529, 2459531, 2459531, 2459533, 2459533, 2734244, 2758419, 2768214, 2831239, 2831240, 2831242, 2459530, 2459531, 2459532, 2758414, 2831237, 2831238, 2831239, 2831239, 2831240, 2831240, 2831243, 3221950, 2831239, 2445683, 2459652, 2473626, 2473612, 2473612, 2473626, 2473627, 2473627, 2473628, 2473628, 2473629, 2473612, 2473613, 2473613, 2473614, 2473627, 2473627, 2473628, 2473629, 2473614, 2473615, 2473628, 2473628, 2473629, 2473629, 2473630, 2473628, 2473629, 2473629, 2473630, 2473615, 2473628, 2473629, 2473630, 2473630, 2473633, 2473617, 2473629, 2473630, 2473631, 2473631, 2473630, 2473630, 2473632, 2473633, 2473630, 2473633, 2473634, 2473633, 2473634, 2473635, 2473643, 2551678, 2845334, 2845335, 2845336, 2473643, 2473644, 2473644, 2473646, 2555313, 2567563, 2670899, 2748340, 2772512, 2772516, 2830991, 2845335, 2845335, 2845336, 2845336, 2845337, 2845337, 2845338, 2845338, 2845339, 2845340, 2845341, 3090650, 3090652, 3236045, 3254115, 3254115, 2473644, 2473645, 2567564, 2691809, 2705039, 2748341, 2772517, 2845334, 2845335, 2845335, 2845336, 2845336, 2845338, 2845338, 2473645, 2614949, 2670899, 2748340, 2819322, 2845334, 2845336, 2845336, 2845337, 2845338, 2845338, 2845341, 3090650, 3090651, 3254116, 2496280, 2748342, 2772517, 2845336, 2845337, 2845340, 2845340, 2845341, 2772518, 2772518, 2845337, 2845337, 2845338, 2845338, 2845339, 2845337, 2819324, 2761995, 2845340, 2845340, 2615470, 2518923, 2518924, 2519045, 2519046, 2519046, 2519168, 2519169, 2736586, 2795284, 2842089, 2868105, 2592174, 2592174, 2731812, 2904608, 2629730, 2923386, 2636989, 2636990, 2636992, 2636999, 2636999, 2927018, 2854197, 2927016, 2927018, 2927020, 2927021, 2661496, 2661497, 2661497, 2661498, 2661499, 2913329, 2939275, 2939269, 2939269, 2939270, 2939270, 2939271, 2939273, 2674936, 2873170, 2707882, 2707906, 2707930, 2962483, 2710745, 2963897, 2756265, 2986653, 2757303, 2987173, 2793859, 2793932, 2794004, 3005520, 2868163, 2868167, 2868167, 2868168, 2868168, 2868168, 2868168, 2868169, 2868169, 2868243, 2969785, 3042603, 2969785, 3042605, 3042606, 3042604, 3042605, 3042606, 3042608, 3042605, 2868323, 3042681, 2871446, 2871447, 2871547, 2871548, 2871647, 2944096, 3044343, 2910037, 2966569, 3063564, 2936447, 3076747, 2953203, 3085122, 2954009, 3085524, 3011194, 3114115, 3016550, 3116795, 3023046, 3023047, 3023049, 3023051, 3023050, 3023050, 3023051, 3047226, 3120046, 3047226, 3120044, 3120045, 3120045, 3120046, 3120046, 3120048, 3050355, 3133699, 3055752, 3136412, 3058498, 3058501, 3137769, 3137772, 3071394, 3071394, 3071389, 3071401, 3071402, 3071402, 3071404, 3071401, 3071402, 3071402, 3071403, 3071404, 3071404, 3144217, 3144218, 3071414, 3144221, 3144224, 3071414, 3144220, 3144223, 3071415, 3118207, 3118281, 3144221, 3144221, 3144222, 3144222, 3144223, 3144223, 3144224, 3144225, 3144226, 3553002, 3144221, 3144222, 3144223, 3144226, 3144222, 3144223, 3090995, 3154019, 3154020, 3165008, 3165011, 3165083, 3165083, 3165084, 3165084, 3165085, 3165085, 3165159, 3165160, 3165160, 3165161, 3165161, 3165162, 3165163, 3191099, 3191099, 3191100, 3191100, 3191101, 3191101, 3191102, 3191103, 3191105, 3191107, 3191101, 3191101, 3188352, 3202696, 3217025, 3217026, 3217028, 3217025, 3217026, 3217027, 3217028, 3217026, 3217027, 3217027, 3217028, 3217027, 3217028, 3217028, 3217029, 3217029, 3217030, 3217030, 3217031, 3217031, 3217032, 3217046, 3217028, 3217029, 3217029, 3217030, 3217030, 3217031, 3217031, 3217032, 3217032, 3217033, 3217035, 3217029, 3217030, 3217030, 3217031, 3217031, 3217032, 3217032, 3217033, 3217033, 3217035, 3217046, 3217047, 3217048, 3217030, 3217031, 3217031, 3217032, 3217032, 3217033, 3217033, 3217034, 3217034, 3217036, 3217046, 3217047, 3217047, 3217048, 3217048, 3217031, 3217032, 3217032, 3217033, 3217033, 3217034, 3217034, 3217035, 3217037, 3217047, 3217047, 3217048, 3217048, 3217032, 3217033, 3217033, 3217034, 3217034, 3217035, 3217035, 3217036, 3217037, 3217047, 3217048, 3217048, 3217049, 3217049, 3217033, 3217034, 3217034, 3217035, 3217035, 3217037, 3217044, 3217048, 3217048, 3217049, 3217049, 3217050, 3217034, 3217035, 3217035, 3217036, 3217037, 3217038, 3217046, 3217048, 3217048, 3217049, 3217049, 3217050, 3217050, 3217051, 3217051, 3217035, 3217036, 3217036, 3217037, 3217037, 3217038, 3217038, 3217039, 3217039, 3217047, 3217049, 3217049, 3217050, 3217050, 3217051, 3217051, 3217036, 3217037, 3217037, 3217038, 3217038, 3217039, 3217039, 3217040, 3217040, 3217041, 3217049, 3217050, 3217050, 3217051, 3217051, 3217037, 3217038, 3217038, 3217039, 3217039, 3217040, 3217040, 3217041, 3217043, 3217044, 3217047, 3217048, 3217049, 3217049, 3217050, 3217050, 3217051, 3217051, 3217052, 3217052, 3217038, 3217039, 3217040, 3217041, 3217042, 3217043, 3217047, 3217049, 3217050, 3217050, 3217051, 3217051, 3217052, 3217052, 3217053, 3217039, 3217040, 3217041, 3217049, 3217050, 3217051, 3217051, 3217052, 3217052, 3217054, 3217041, 3217041, 3217042, 3217046, 3217050, 3217051, 3217052, 3217052, 3217053, 3217042, 3217050, 3217051, 3217052, 3217052, 3217053, 3217053, 3217054, 3217052, 3217052, 3217053, 3217053, 3217054, 3217044, 3217052, 3217053, 3217053, 3217054, 3217054, 3217055, 3217044, 3217052, 3217054, 3217054, 3217055, 3217055, 3217054, 3217054, 3217055, 3217055, 3217053, 3217057, 3217058, 3217056, 3217058, 3217060, 3217060, 3217061, 3217061, 3217061, 3217062, 3217063, 3217196, 3217196, 3217062, 3217063, 3217064, 3217062, 3217063, 3217063, 3217064, 3217197, 3217063, 3217064, 3217064, 3217065, 3217197, 3612695, 3217064, 3217065, 3217065, 3217066, 3253321, 3356318, 3462360, 3462361, 3462362, 3625825, 3625826, 3625829, 3217065, 3217066, 3217066, 3217067, 3217067, 3217198, 3253319, 3253352, 3256403, 3256408, 3276467, 3286701, 3286835, 3300608, 3462360, 3462361, 3462361, 3462362, 3545889, 3545889, 3545891, 3625823, 3625824, 3625826, 3217066, 3217067, 3217067, 3217068, 3217197, 3217198, 3217199, 3252661, 3252665, 3252665, 3252670, 3256371, 3286836, 3327910, 3356319, 3428678, 3456614, 3456614, 3462361, 3462361, 3462362, 3462362, 3462363, 3462363, 3497435, 3545890, 3625824, 3625825, 3625826, 3625826, 3625827, 3625828, 3625831, 3942143, 3217067, 3217068, 3217068, 3217141, 3217197, 3217198, 3217198, 3217199, 3217199, 3217200, 3217201, 3217201, 3217596, 3233895, 3252661, 3252665, 3252666, 3252667, 3252668, 3252672, 3253321, 3253322, 3253322, 3253323, 3253326, 3253327, 3253329, 3253332, 3253344, 3253378, 3253379, 3253383, 3253385, 3253388, 3253388, 3253398, 3256371, 3256371, 3256380, 3256381, 3256390, 3256390, 3256404, 3256408, 3256409, 3256457, 3286699, 3286702, 3286833, 3300610, 3301357, 3356316, 3356319, 3387358, 3397181, 3456614, 3456615, 3460878, 3462361, 3462362, 3462362, 3462363, 3462363, 3462364, 3477483, 3497438, 3545890, 3545893, 3592367, 3625824, 3625825, 3625825, 3625826, 3625826, 3625827, 3625828, 3625828, 3625829, 3625830, 4646672, 3217068, 3217069, 3217142, 3217199, 3217200, 3217200, 3217201, 3233893, 3233894, 3240935, 3252665, 3252666, 3252669, 3252672, 3252673, 3253322, 3253323, 3253324, 3253324, 3253325, 3253327, 3253328, 3253333, 3253334, 3253335, 3253340, 3253350, 3253355, 3253380, 3253391, 3256376, 3256409, 3256410, 3256419, 3256443, 3256447, 3256874, 3286702, 3286838, 3315401, 3356319, 3356320, 3387358, 3456617, 3462362, 3462362, 3462363, 3462363, 3462364, 3490625, 3497440, 3545890, 3582728, 3625825, 3625825, 3625826, 3625826, 3625827, 3625828, 3217069, 3217071, 3217199, 3217200, 3217200, 3217201, 3217201, 3252670, 3252673, 3253322, 3253323, 3253328, 3253340, 3256383, 3256392, 3256409, 3256409, 3256447, 3256475, 3258651, 3462362, 3462363, 3462363, 3462364, 3462365, 3545891, 3625826, 3217201, 3217201, 3253385, 3253389, 3256421, 3286839, 3462363, 3462363, 3545892, 3625829, 3462365, 3217225, 3462445, 3217338, 3217339, 3217340, 3217340, 3217331, 3217339, 3217340, 3217341, 3217331, 3217333, 3217340, 3217332, 3217334, 3217341, 3217341, 3217342, 3217342, 3217342, 3217344, 3217345, 3217343, 3217345, 3217346, 3217344, 3462503, 3387499, 3625967, 3217351, 3217352, 3234032, 3462503, 3546031, 3217351, 3253466, 3462503, 3592509, 3217354, 3252808, 3253464, 3253465, 3253466, 3253475, 3256523, 3256537, 3256551, 3286842, 3286974, 3286976, 3286979, 3356462, 3462504, 3462504, 3462505, 3462506, 3497579, 3582870, 3607899, 3625967, 3625968, 3625969, 3625970, 3625971, 3252807, 3256513, 3462506, 3625968, 3625970, 3252816, 3462506, 3625972, 3218138, 3256913, 3250730, 3250731, 3250734, 3250738, 3269511, 3479201, 3270223, 3479204, 3264818, 3486244, 3288256, 3288271, 3288272, 3288276, 3288277, 3288280, 3288270, 3288282, 3288283, 3288285, 3288265, 3288268, 3288283, 3288287, 3288285, 3288285, 3288287, 3288289, 3288283, 3288292, 3288289, 3288292, 3288292, 3288284, 3288293, 3288294, 3288294, 3288295, 3288290, 3661435, 3288296, 3497974, 3288301, 3288937, 3497976, 3497977, 3288303, 3292025, 3288304, 3289006, 3292069, 3288306, 3661442, 3497981, 3291341, 3661443, 3288943, 3288946, 3288954, 3497981, 3288947, 3292064, 3497982, 3497983, 3294272, 3548595, 3289589, 3289580, 3289591, 3289596, 3289596, 3289608, 3289626, 3289588, 3289593, 3289596, 3289601, 3289607, 3289594, 3289597, 3289598, 3289599, 3289597, 3289604, 3289597, 3289600, 3289609, 3289598, 3289606, 3289601, 3289602, 3289613, 3289616, 3289610, 3289611, 3289614, 3289592, 3289611, 3289610, 3289620, 3289609, 3289614, 3289621, 3289621, 3289622, 3289638, 3289623, 3289621, 3289654, 3289669, 3662097, 3289629, 3289631, 3498636, 3498635, 3498636, 3289632, 3498635, 3289636, 3498636, 3292646, 3498636, 3498637, 3644034, 3294923, 3498639, 3289632, 3662101, 3289636, 3289668, 3289635, 3289632, 3498642, 3662106, 3292653, 3289675, 3662109, 3289666, 3662109, 3498648, 3292695, 3289646, 3289669, 3289665, 3289683, 3662114, 3289663, 3292707, 3498651, 3292675, 3479659, 3498650, 3662118, 3582182, 3292671, 3323128, 3289666, 3498652, 3446080, 3498656, 3289671, 3289684, 3498666, 3498669, 3498669, 3292718, 3289716, 3498673, 3289706, 3289719, 3289724, 3289719, 3289704, 3289719, 3289722, 3289718, 3289718, 3289724, 3289724, 3289717, 3289718, 3289724, 3289719, 3289723, 3289734, 3289728, 3289731, 3498690, 3498688, 3289730, 3289740, 3289732, 3289733, 3289746, 3289750, 3289747, 3289753, 3289745, 3498696, 3289755, 3292743, 3294982, 3478568, 3498697, 3662165, 3498698, 3662160, 3498700, 3498702, 3498701, 3498702, 3292711, 3296830, 3498702, 3498705, 3662168, 3392662, 3292716, 3498710, 3292726, 3292804, 3662177, 3662178, 3294390, 3501029, 3295693, 3295684, 3295689, 3295691, 3295693, 3295697, 3295698, 3295702, 3295697, 3295694, 3295704, 3295705, 3295698, 3295712, 3295717, 3295713, 3295714, 3295715, 3295713, 3295728, 3295724, 3501682, 3501684, 3295728, 3295731, 3295750, 3295733, 3501689, 3501688, 3501688, 3295737, 3295739, 3501689, 3585218, 3501690, 3501692, 3295740, 3501696, 3481565, 3495948, 3295797, 3501698, 3295774, 3501698, 3295765, 3501700, 3295764, 3665165, 3295765, 3295765, 3295766, 3295770, 3295768, 3295769, 3295770, 3295804, 3295772, 3395662, 3295773, 3295769, 3501706, 3295786, 3295789, 3295790, 3360230, 3436538, 3482727, 3501718, 3501718, 3501719, 3536793, 3665180, 3665183, 3326195, 3501718, 3295805, 3647115, 3501721, 3665183, 3501722, 3574654, 3501722, 3298011, 3501723, 3295798, 3501724, 3501728, 3295824, 3501732, 3501732, 3297465, 3295840, 3295841, 3295849, 3295856, 3295847, 3295854, 3395710, 3295868, 3426753, 3501757, 3501759, 3665222, 3501764, 3298047, 3501764, 3295898, 3501771, 3501772, 3501785, 3296691, 3502179, 3299136, 3438224, 3300238, 3300244, 3300243, 3300251, 3300249, 3300250, 3667418, 3503958, 3503959, 3451388, 3503961, 3667426, 3303923, 3505795, 3335878, 3335896, 3335916, 3685254, 3356340, 3356341, 3356342, 3356346, 3356347, 3356479, 3356480, 3356480, 3356482, 3356483, 3356603, 3356614, 3356616, 3356617, 3356619, 3356619, 3356620, 3422747, 3532142, 3532143, 3532143, 3581042, 3695608, 3532143, 3426101, 3532144, 3532144, 3384163, 3384164, 3470912, 3545916, 3385660, 3527670, 3413753, 3560713, 3424693, 3566181, 3438765, 3573216, 3488877, 3512383, 3495582, 3495583, 3495584, 3495584, 3495585, 3495586, 3601626, 3685155, 3601626, 3601627, 3601627, 3601628, 3601629, 3765090, 4339793, 3535889, 3550525, 3557661, 3557662, 3632665, 3632666, 3796128, 3565160, 3664677, 3577305, 3577308, 3577309, 3577348, 3642488, 3642489, 3577393, 3642533, 3602523, 3602524, 3655096, 3655097, 3640302, 3837447, 3667413, 3667414, 3687542, 3687542, 3669679, 3669686, 3669685, 3846253, 3669824, 3688677, 3669961, 3688813, 3685233, 3696453, 3696177, 3696178, 3696178, 3696178, 3696179, 3696180, 3701924, 3865387, 3701925, 3865388, 3865388, 3704699, 3706183, 3707655, 3707657, 3707656, 3707657, 3707657, 3707658, 3707658, 3707659, 3707659, 3707660, 3707671, 3707671, 3707672, 3707672, 3707673, 3707673, 3707674, 3707657, 3707658, 3707658, 3707659, 3707671, 3707672, 3707672, 3707673, 3707673, 3707674, 3707658, 3707659, 3707659, 3707660, 3707661, 3707672, 3707672, 3707673, 3707673, 3707674, 3707659, 3707660, 3707660, 3707672, 3707672, 3707673, 3707673, 3707674, 3707674, 3707675, 3707660, 3707661, 3707673, 3707673, 3707674, 3707674, 3707675, 3707675, 3707661, 3707662, 3707673, 3707673, 3707674, 3707674, 3707675, 3707675, 3707676, 3707676, 3707674, 3707674, 3707675, 3707675, 3707676, 3707674, 3707675, 3707675, 3707676, 3707676, 3707686, 3707686, 3707686, 3707687, 3707687, 3707688, 3707688, 3707689, 3723897, 3742748, 3790067, 3791199, 3791200, 3791200, 3791201, 3791202, 3825878, 3871133, 3871134, 3871134, 3871135, 3871135, 3871136, 3871136, 3871137, 3707687, 3707688, 3707688, 3707689, 3707690, 3723373, 3735935, 3791200, 3791201, 3791202, 3828036, 3837676, 3837677, 3845358, 3853064, 3853066, 3858005, 3859355, 3871134, 3871134, 3871135, 3871135, 3871136, 3871136, 3871137, 3871137, 3871138, 3707688, 3707689, 3707689, 3707690, 3723898, 3742748, 3791201, 3791202, 3791203, 3791203, 3828038, 3837677, 3853071, 3865251, 3871134, 3871134, 3871135, 3871135, 3871136, 3871136, 3871137, 3871137, 3707689, 3707690, 3707690, 3707691, 3723266, 3723899, 3735936, 3742745, 3742747, 3742748, 3742750, 3758281, 3791201, 3791201, 3791203, 3791204, 3837677, 3853066, 3853071, 3871135, 3871136, 3871136, 3871137, 3871137, 3871138, 3871138, 3871139, 3707690, 3707691, 3707693, 3720193, 3722794, 3723267, 3735936, 3742748, 3742748, 3742749, 3742749, 3742750, 3761820, 3791201, 3791202, 3791202, 3791203, 3791203, 3791204, 3791204, 3825917, 3828040, 3837678, 3853069, 3858008, 3869447, 3871135, 3871136, 3871136, 3871137, 3871137, 3871138, 3871138, 3871139, 3871140, 3707691, 3742748, 3742748, 3742749, 3791201, 3791202, 3791202, 3791203, 3791203, 3791204, 3828040, 3828040, 3837678, 3853066, 3853067, 3853073, 3865253, 3871136, 3871136, 3871137, 3871137, 3871138, 3871138, 3871139, 3871139, 3871141, 3837679, 3853070, 3871137, 3871138, 3871138, 3871139, 3791204, 3871137, 3871138, 3853075, 3732710, 3883653, 3737910, 3806318, 3806320, 3868188, 3738853, 3738901, 3738964, 3738949, 3886770, 3739072, 3739075, 3806899, 3853375, 3740121, 3807423, 3869291, 3887357, 3887359, 3764195, 3764196, 3819461, 3899394, 3899395, 3899397, 3899397, 3771007, 3784902, 3886268, 3899395, 3777818, 3777820, 3777820, 3777808, 3777821, 3777821, 3777821, 3777821, 3777822, 3777824, 3777822, 3777823, 3777823, 3777823, 3777824, 3826274, 3826274, 3826276, 3893080, 3826272, 3826275, 3863112, 3872752, 3883070, 3904520, 3906209, 3906209, 3906210, 3906211, 3906211, 3906213, 3906211, 3805468, 3805538, 3805606, 3805609, 3908318, 3808372, 3808886, 3808891, 3921740, 3898604, 3811133, 3904792, 3815965, 3845348, 3853532, 3944062, 3872463, 3953530, 3874711, 3874727, 3874714, 3874728, 3874729, 3874731, 3874715, 3874726, 3874729, 3874729, 3874731, 3874730, 3874731, 3874731, 3874731, 3874732, 3874733, 3874721, 3874733, 3874733, 3874734, 3874737, 3874741, 3954662, 3954669, 3874746, 3936592, 3954663, 3874747, 3911567, 3936598, 3948780, 3954663, 3954663, 3954664, 3954665, 3874747, 3954664, 3921206, 3936600, 3948781, 3954664, 3954666, 3911569, 3911569, 3921207, 3936109, 3936595, 3936597, 3936598, 3936600, 3936600, 3941538, 3941539, 3948781, 3954665, 3954665, 3954666, 3954666, 3954667, 3954667, 3954668, 3954668, 3954670, 3944083, 3989341, 3944162, 3989381, 3948402, 3948403, 3948404, 3948405, 3948405, 3991500, 3958043, 3958043, 3973430, 3978373, 3991500, 3991501, 3991502, 3991503, 3991504, 3967666, 3967669, 3967681, 3967681, 3967682, 3967682, 3967682, 3967683, 3967684, 3967683, 3967696, 4001139, 4001140, 4001140, 4001141, 3983074, 4001139, 4001141, 4001142, 4001139, 4001140, 4001142, 3988013, 3983041, 4008817, 3988315, 3988316, 4011454, 4011455, 3997482, 3997973, 3998454, 3998455, 3998456, 3998457, 3998458, 3998461, 3998458, 3998459, 3998462, 3998464, 3998448, 3998465, 3998467, 3998468, 3998464, 3998465, 3998466, 3998467, 3998453, 3998467, 3998468, 3998468, 3998455, 3998466, 3998469, 3998467, 4016528, 4016526, 4016528, 4016528, 4016528, 4016530, 4016529, 3998478, 3998689, 3998690, 3998690, 4016531, 4016532, 4016533, 3999995, 4016532, 4016534, 4003405, 4016533, 4016535, 4016536, 4016536, 4016535, 4016535, 3998901, 3998902, 3998911, 3998912, 3998912, 3998921, 4016752, 4029504, 4522686, 4001517, 4001653, 4001788, 4018190, 4008337, 4008338, 4008338, 4008332, 4008342, 4008352, 4021466, 4021466, 4021467, 4021467, 4021468, 4021471, 4021467, 4021468, 4011037, 4011039, 4022818, 4022821, 4022830, 4022830, 4022828, 4022829, 4022831, 4022831, 4028711, 4028713, 4028713, 4028714, 4028714, 4028714, 4031219, 4031220, 4032908, 4032911, 4034580, 4034581, 4034582, 4034583, 4034583, 4034584, 4034586, 4034582, 4034583, 4034583, 4034584, 4034584, 4034585, 4034585, 4034586, 4034587, 4034598, 4034599, 4034606, 4034583, 4034584, 4034584, 4034585, 4034585, 4034586, 4034586, 4034587, 4034588, 4034584, 4034585, 4034585, 4034586, 4034586, 4034587, 4034588, 4034588, 4034585, 4034586, 4034586, 4034587, 4034587, 4034588, 4034601, 4034604, 4034586, 4034587, 4034587, 4034588, 4034588, 4034589, 4034590, 4034600, 4034601, 4034602, 4034604, 4034605, 4034587, 4034588, 4034588, 4034589, 4034589, 4034590, 4034590, 4034602, 4034603, 4034605, 4034588, 4034589, 4034589, 4034590, 4034590, 4034591, 4034598, 4034603, 4034604, 4034604, 4034607, 4034589, 4034590, 4034590, 4034591, 4034591, 4034592, 4034592, 4034599, 4034601, 4034602, 4034602, 4034603, 4034604, 4034604, 4034605, 4034608, 4034590, 4034591, 4034591, 4034592, 4034592, 4034593, 4034598, 4034599, 4034603, 4034603, 4034604, 4034604, 4034605, 4034609, 4034591, 4034592, 4034592, 4034593, 4034593, 4034594, 4034594, 4034595, 4034599, 4034600, 4034600, 4034602, 4034603, 4034603, 4034604, 4034604, 4034605, 4034605, 4034606, 4034592, 4034593, 4034593, 4034594, 4034594, 4034596, 4034600, 4034601, 4034603, 4034604, 4034604, 4034605, 4034605, 4034606, 4034607, 4034607, 4034608, 4034609, 4034593, 4034594, 4034594, 4034595, 4034595, 4034596, 4034596, 4034598, 4034600, 4034601, 4034601, 4034602, 4034603, 4034603, 4034604, 4034605, 4034605, 4034606, 4034606, 4034607, 4034607, 4034608, 4034608, 4034609, 4034609, 4034610, 4034594, 4034595, 4034595, 4034596, 4034596, 4034597, 4034599, 4034601, 4034601, 4034602, 4034602, 4034604, 4034604, 4034605, 4034605, 4034606, 4034606, 4034607, 4034607, 4034608, 4034609, 4034595, 4034596, 4034596, 4034597, 4034598, 4034598, 4034599, 4034599, 4034600, 4034601, 4034602, 4034602, 4034603, 4034604, 4034604, 4034605, 4034605, 4034606, 4034606, 4034607, 4034607, 4034596, 4034597, 4034597, 4034598, 4034598, 4034599, 4034599, 4034602, 4034603, 4034603, 4034604, 4034604, 4034605, 4034605, 4034606, 4034606, 4034607, 4034607, 4034608, 4034608, 4034609, 4034609, 4034610, 4034611, 4034611, 4034612, 4034597, 4034598, 4034598, 4034599, 4034600, 4034600, 4034603, 4034603, 4034604, 4034604, 4034605, 4034606, 4034606, 4034607, 4034607, 4034608, 4034609, 4034611, 4034598, 4034599, 4034599, 4034601, 4034603, 4034604, 4034604, 4034606, 4034607, 4034608, 4034608, 4034599, 4034600, 4034601, 4034601, 4034602, 4034604, 4034604, 4034605, 4034606, 4034607, 4034607, 4034608, 4034608, 4034609, 4034609, 4034600, 4034602, 4034604, 4034605, 4034608, 4034610, 4034602, 4034602, 4034605, 4034606, 4034607, 4034608, 4034609, 4034609, 4034610, 4034605, 4034608, 4034609, 4034606, 4034606, 4034608, 4034610, 4034604, 4034608, 4034609, 4034610, 4034610, 4034611, 4034611, 4034612, 4034606, 4034610, 4034611, 4034611, 4034612, 4034608, 4034610, 4034611, 4034613, 4034613, 4034614, 4034608, 4034609, 4034610, 4034610, 4034611, 4034611, 4034612, 4034612, 4034613, 4034613, 4034614, 4034614, 4034616, 4034610, 4034611, 4034611, 4034612, 4034612, 4034613, 4034613, 4034614, 4034614, 4034615, 4034616, 4034611, 4034612, 4034612, 4034613, 4034614, 4034614, 4034615, 4034612, 4034613, 4034613, 4034614, 4034615, 4034616, 4034613, 4034614, 4034614, 4034615, 4034615, 4034616, 4034616, 4034619, 4034619, 4034615, 4034615, 4034616, 4034616, 4034617, 4034618, 4034615, 4034616, 4034616, 4034617, 4034617, 4034618, 6613563, 4034616, 4034617, 4034617, 4034618, 4034619, 4350919, 4034617, 4034618, 4034618, 4034619, 4034619, 4034620, 4034620, 4034621, 4034621, 4034622, 4407623, 4478496, 4034618, 4034619, 4034619, 4034620, 4034620, 4034621, 4034619, 4034620, 4034620, 4034621, 4034622, 4034622, 4034623, 4034625, 4034630, 4540535, 5798712, 4034620, 4034621, 4034621, 4034622, 4034622, 4034623, 4034624, 4034625, 4034625, 4034627, 4039261, 4047350, 4412349, 4611285, 5055449, 5798981, 4034621, 4034622, 4034622, 4034623, 4034623, 4034624, 4034625, 4034625, 4034626, 4034628, 4047353, 4047354, 4429153, 4478496, 4789889, 7515991, 4034622, 4034623, 4034623, 4034624, 4034624, 4034625, 4034626, 4034629, 4034630, 4039265, 4047354, 4151188, 4407625, 4611287, 5030509, 9642968, 4034623, 4034624, 4034624, 4034625, 4034625, 4034626, 4034626, 4034627, 4034627, 4034629, 4034632, 4047354, 4047354, 4047355, 4137752, 4350920, 4407626, 4407627, 4412350, 4418540, 4432737, 5798979, 4034624, 4034625, 4034625, 4034626, 4034626, 4034627, 4034627, 4034628, 4034629, 4034631, 4047355, 4047355, 4126460, 4137754, 4350920, 4350926, 4407626, 4407627, 4478498, 4611288, 4782462, 4946218, 5493381, 5493528, 5798981, 5798981, 4034625, 4034626, 4034626, 4034627, 4034627, 4034628, 4034629, 4034631, 4034633, 4039267, 4047355, 4047356, 4126458, 4137753, 4151190, 4195574, 4350922, 4350925, 4407626, 4407627, 4478498, 4508750, 4611288, 4611288, 4789890, 4789891, 4034626, 4034627, 4034627, 4034628, 4034628, 4034629, 4034630, 4034630, 4034632, 4034633, 4034633, 4039265, 4039266, 4039267, 4047355, 4047356, 4047356, 4350905, 4350906, 4377669, 4407624, 4407627, 4611289, 4680565, 4782463, 4789890, 4789893, 4929815, 5003814, 5077275, 5493430, 4034627, 4034628, 4034628, 4034629, 4034629, 4034633, 4034633, 4034634, 4034637, 4039265, 4039267, 4039268, 4047355, 4047356, 4047356, 4047357, 4057160, 4126461, 4126463, 4151191, 4180214, 4195575, 4350920, 4350923, 4407628, 4407628, 4478500, 4611289, 4738620, 4789893, 4929815, 5178391, 5798981, 9642971, 4034628, 4034629, 4034629, 4034630, 4034630, 4034631, 4034632, 4034633, 4034634, 4034634, 4034635, 4047355, 4047356, 4047357, 4047357, 4151192, 4349916, 4350909, 4350925, 4407628, 4407629, 4627132, 4683487, 4789893, 4929816, 5798982, 4034629, 4034630, 4034630, 4034631, 4034632, 4034632, 4034633, 4034634, 4034635, 4042592, 4047352, 4047354, 4047355, 4047355, 4047356, 4047357, 4047358, 4137755, 4247287, 4350924, 4407629, 4540539, 4782465, 4789893, 4034630, 4034631, 4034631, 4034632, 4034632, 4034633, 4034634, 4034634, 4034635, 4034635, 4034636, 4034636, 4039269, 4047356, 4047357, 4047357, 4047358, 4047358, 4126463, 4350923, 4350925, 4407629, 4407630, 4540539, 4789893, 5493450, 9642116, 4034631, 4034632, 4034632, 4034633, 4034633, 4034634, 4034634, 4034635, 4034635, 4034636, 4034637, 4039269, 4039270, 4047356, 4047357, 4047357, 4047358, 4047358, 4047359, 4137756, 4350907, 4407630, 4407630, 4407631, 4540540, 4789894, 4789895, 4789895, 4034632, 4034633, 4034633, 4034634, 4034634, 4034635, 4034635, 4034636, 4034636, 4034637, 4034637, 4034638, 4034638, 4034639, 4034640, 4039269, 4039270, 4039270, 4047354, 4047354, 4047355, 4047356, 4047356, 4047357, 4047357, 4047358, 4047359, 4047359, 4109174, 4126462, 4126463, 4126465, 4126465, 4126466, 4151193, 4177968, 4247286, 4247288, 4287006, 4349918, 4350253, 4350255, 4350909, 4350910, 4350911, 4350925, 4350926, 4350929, 4407628, 4407630, 4407631, 4407632, 4412355, 4429158, 4478502, 4478502, 4540536, 4540540, 4540542, 4611291, 4627134, 4680567, 4782465, 4782466, 4789894, 4946220, 9642117, 4034633, 4034634, 4034636, 4034637, 4034638, 4039271, 4047359, 4137757, 4142401, 4350928, 4407631, 4407631, 4034634, 4034635, 4034635, 4034636, 4034636, 4034637, 4034638, 4034639, 4034640, 4034742, 4039271, 4047359, 4047360, 4099003, 4350910, 4407631, 4478503, 4034635, 4034636, 4034636, 4034637, 4034637, 4034638, 4034640, 4034641, 4034741, 4034742, 4039270, 4039272, 4047359, 4047359, 4047360, 4047361, 4047361, 4126464, 4137759, 4177958, 4344308, 4350911, 4350917, 4350928, 4350929, 4351968, 4361135, 4407632, 4407632, 4611293, 4946224, 4034637, 4034637, 4034639, 4034642, 4047358, 4047361, 4047361, 4252758, 4349920, 4407632, 4034638, 4039272, 4039273, 4047357, 4047358, 4047361, 4047362, 4151196, 4407633, 4478504, 4034639, 4034639, 4034641, 4034642, 4047360, 4047361, 4047362, 4047362, 4100808, 4102787, 4126465, 4137759, 4407633, 4680571, 4034639, 4039273, 4047362, 4047362, 4047363, 4252760, 4350912, 4350928, 4394262, 4407634, 4540544, 4789897, 4034640, 4034642, 4034644, 4039273, 4039274, 4039275, 4047359, 4047360, 4047363, 4047363, 4063218, 4151197, 4151198, 4252031, 4309857, 4349922, 4350912, 4350927, 4407634, 4429161, 4429164, 4611294, 4034641, 4034642, 4034644, 4034745, 4039274, 4039274, 4039275, 4042598, 4047362, 4047362, 4047363, 4047363, 4047364, 4047364, 4126466, 4126467, 4137516, 4137761, 4247293, 4341944, 4349923, 4350914, 4350931, 4371917, 4407635, 4478506, 4478507, 4782470, 4789899, 9642171, 4034642, 4039275, 4047362, 4047364, 4047364, 4407635, 4407636, 4501707, 4039273, 4047362, 4047363, 4047364, 4126471, 4247294, 4350915, 4047365, 4151199, 4350913, 4350914, 4478508, 4047360, 4047361, 4047364, 4407637, 4039277, 4126473, 4047365, 4047367, 4126473, 4478509, 4047366, 4047367, 4195585, 4247296, 4407638, 4034848, 4034859, 4039389, 4047478, 4047478, 4043918, 4043919, 4043917, 4043918, 4043908, 4043920, 4043921, 4043910, 4043921, 4043921, 4043922, 4043922, 4412279, 4379330, 4043933, 4043934, 4052002, 4052005, 4052008, 4052009, 4052010, 4052010, 4131116, 4142164, 4155844, 4291657, 4355560, 4355574, 4379331, 4412281, 4412282, 4615942, 4794545, 5060106, 5497941, 5803636, 4155846, 4050571, 4055336, 4486479, 4060092, 4060093, 4060096, 4060080, 4060079, 4060082, 4060096, 4060082, 4060082, 4060096, 4060098, 4060097, 4060098, 4060082, 4060083, 4060084, 4060097, 4060098, 4060099, 4060084, 4060097, 4060098, 4060099, 4060083, 4060084, 4060084, 4060085, 4060099, 4060100, 4060084, 4060085, 4060085, 4060097, 4060099, 4060099, 4060100, 4060085, 4060086, 4060086, 4060097, 4060098, 4060099, 4060100, 4060100, 4060101, 4060086, 4060087, 4060088, 4060098, 4060099, 4060100, 4060100, 4060101, 4060101, 4060087, 4060088, 4060099, 4060099, 4060100, 4060101, 4060101, 4060102, 4060100, 4060102, 4060102, 4060103, 4060103, 4060101, 4060102, 4420369, 4060112, 4060113, 4060114, 4163934, 4260028, 4299743, 4420370, 4491242, 4795206, 4060114, 4060114, 4139204, 4420370, 4060114, 4060115, 4060115, 4163936, 4363666, 4420371, 4491243, 4802634, 4060115, 4060116, 4139207, 4208319, 4260028, 4363651, 4363659, 4363667, 4363668, 4420372, 4420372, 4420373, 4420375, 4425101, 4802636, 5811726, 4060116, 4060117, 4060119, 4115499, 4139203, 4139206, 4139206, 4139207, 4150498, 4240471, 4249627, 4260030, 4363665, 4363668, 4363669, 4420372, 4425097, 4425101, 4441900, 4514443, 4553282, 4624034, 4695858, 4942560, 4060117, 4075956, 4139204, 4139204, 4139206, 4139207, 4139208, 4139208, 4150255, 4150499, 4150499, 4150501, 4163936, 4163936, 4163937, 4192959, 4208320, 4260031, 4265499, 4299746, 4299746, 4357049, 4362661, 4362663, 4363648, 4363650, 4363651, 4363652, 4363665, 4363665, 4363667, 4363668, 4363669, 4363669, 4363673, 4375655, 4387419, 4387425, 4390415, 4410498, 4420373, 4420373, 4420374, 4420374, 4420375, 4441901, 4450824, 4491244, 4491245, 4491245, 4514443, 4514446, 4553283, 4553283, 4624034, 4624034, 4652784, 4688531, 4693311, 4695773, 4795207, 4795208, 4795209, 4802636, 4802636, 4802638, 4802639, 4942562, 5142367, 5811729, 4139209, 4163936, 4190691, 4208320, 4362661, 4420373, 4420371, 4363652, 4079703, 4079713, 4563085, 4091836, 4091912, 4179816, 4091987, 4155163, 4436328, 4163389, 4414305, 4166994, 4417114, 4170893, 4170913, 4170935, 4170946, 4858053, 4171024, 4171100, 4192449, 4183732, 4201026, 4213804, 4497221, 4218306, 4218307, 4218307, 4218298, 4218308, 4218295, 4218310, 4218308, 4218311, 4218311, 4218312, 4218312, 4218299, 4218313, 4218314, 4218313, 4218315, 4218313, 4218318, 4218323, 4499475, 4570349, 4874310, 4442753, 4218328, 4305794, 4441764, 4259467, 4442772, 4243041, 4243041, 4269796, 4339136, 4442757, 4442774, 4442775, 4442777, 4499478, 4521006, 4570349, 4632388, 4881741, 4881741, 5021665, 4243042, 4442756, 4442758, 4442774, 4499479, 4593552, 4499481, 4901166, 4240407, 4240409, 4240410, 4581397, 4240654, 4510526, 4730026, 4240881, 4240896, 4240896, 4240897, 4240896, 4240898, 4240897, 4240899, 4240896, 4241011, 4240911, 4254333, 4254333, 4510770, 4515495, 4581641, 4581642, 4510772, 4532298, 4893034, 4454067, 4604842, 4454050, 4454064, 4241125, 4497510, 4250185, 4515415, 4267769, 4267770, 4267770, 4267771, 4267772, 4267773, 4267768, 4267769, 4267771, 4267771, 4267772, 4267774, 4267770, 4267773, 4524205, 4294538, 4349874, 4524206, 4727867, 4368604, 4476537, 4524207, 4595078, 4595079, 4657118, 5609590, 4368604, 4467485, 4467492, 4476537, 4524207, 4535122, 4579738, 4595079, 4906470, 4467502, 4522400, 4587424, 4467505, 4467505, 4545738, 4300620, 4346947, 4321280, 4321282, 4321300, 4321311, 4494252, 4550964, 4321319, 4550975, 4550979, 4494278, 4325817, 4325821, 4496524, 5176119, 4553235, 4356535, 4356535, 4356536, 4356538, 4568588, 4573313, 4639460, 4568589, 5216413, 4573318, 4393274, 4393275, 4431354, 4530254, 4420888, 4420950, 4421020, 4544156, 4431977, 4825810, 4439156, 4609901, 4459956, 4459957, 4459958, 4459958, 4459959, 4459963, 4563595, 4563579, 4563579, 4563594, 4563595, 4587350, 4620300, 4823960, 4563600, 4620301, 4563597, 4469438, 4469439, 4695912, 4695913, 5007307, 4568338, 4470898, 4470899, 4470902, 4569065, 4696645, 4625776, 4539390, 4539391, 4539393, 4603294, 4602305, 4603314, 4603314, 4660017, 4660018, 4585088, 4626144, 4649265, 4714956, 4653992, 4717316, 4665220, 4665222, 4666210, 4666211, 4666223, 4667267, 4722932, 4722934, 5105197, 4665890, 4665894, 4856179, 4666559, 4667195, 4667185, 4667185, 4667197, 4667198, 4667198, 4667199, 4667201, 4667207, 4667200, 4667207, 4667186, 4667204, 4667206, 4667209, 4667211, 4667214, 4667187, 4667200, 4667202, 4667204, 4667207, 4667208, 4667209, 4667210, 4667210, 4667213, 4667215, 4667217, 4667217, 4667195, 4667200, 4667205, 4667210, 4667210, 4667216, 4667223, 4667224, 4667213, 4667227, 4667209, 4667227, 4723919, 4667212, 4667229, 4723920, 4667214, 4667214, 4667217, 4667232, 4667217, 4667218, 4667231, 4723921, 4728649, 4667219, 4667219, 4667231, 4667233, 4667234, 4667234, 4723922, 4667232, 4667233, 4667234, 4667218, 4667219, 4667231, 4667235, 4667219, 4667220, 4667222, 4667228, 4667233, 4667233, 4667235, 4667236, 4856832, 4667220, 4667235, 4667221, 4667223, 4667226, 4667235, 4667236, 4667236, 4667221, 4667222, 4667227, 4667228, 4667233, 4667236, 4667237, 4667237, 4667234, 4667234, 4667235, 4667237, 4667237, 4927586, 4667225, 4667234, 4667235, 4667237, 4667238, 4667238, 4667233, 4667236, 4667237, 4667238, 4667239, 4723927, 4667236, 4667237, 4667228, 4667230, 4667238, 4667240, 4667233, 4667239, 4723929, 4723929, 4794801, 4667231, 4714991, 4723929, 4667241, 4723930, 4667243, 4728655, 4667242, 4787147, 4818003, 4667241, 4856842, 5098768, 4667242, 4723935, 4667242, 4667246, 4710564, 4723936, 4667249, 4667315, 4667315, 4667316, 4667317, 4667249, 4667317, 4723938, 4667249, 4667250, 4667316, 4667318, 4667318, 4723938, 4723939, 4787154, 5098773, 5106203, 4667318, 4723939, 4943439, 4667251, 4667252, 4667317, 4667318, 4723939, 6115292, 4667251, 4676270, 4723940, 4745468, 4794811, 4667252, 4667320, 4667322, 4676270, 4693982, 4723939, 4723940, 4745468, 4794812, 4794814, 4856852, 4943435, 4996878, 5346829, 5485357, 4667253, 4667321, 4723939, 4723941, 4723942, 4728666, 4856851, 5030975, 5106206, 6115296, 4723941, 4779470, 4818010, 4856851, 4856852, 4667396, 4667396, 4667397, 4667397, 4667398, 4667398, 4667402, 4694060, 4724018, 4724019, 4724020, 4728743, 4745546, 4794890, 4794890, 4794891, 4818090, 7189382, 4724020, 4669313, 4669313, 4724977, 4685298, 4685300, 4685301, 4685302, 4685429, 4737533, 4732972, 4732971, 4685558, 4754626, 4687650, 4966560, 4691203, 4691342, 4691481, 4736060, 4709233, 4744951, 4714732, 4714738, 4714739, 4714743, 4714855, 4714856, 4714857, 4714858, 4714860, 4714975, 4714976, 4714977, 4747807, 4747808, 4818679, 4880718, 4720726, 4720727, 4720728, 4761598, 4772212, 4983099, 4750791, 4753897, 4767269, 4838141, 4760891, 4770766, 4762765, 4771703, 4777024, 4849704, 4780625, 4780641, 4780626, 4780642, 4780627, 4780640, 4780642, 4780629, 4780630, 4780630, 4780631, 4780638, 4780639, 4780639, 4780640, 4780640, 4780641, 4780641, 4780642, 4780642, 4780643, 4780643, 4780644, 4780644, 4780645, 4780646, 4780630, 4780631, 4780632, 4780639, 4780639, 4780640, 4780641, 4780641, 4780642, 4780642, 4780643, 4780643, 4780645, 4780632, 4780639, 4780640, 4780640, 4780641, 4780641, 4780642, 4780643, 4780643, 4780645, 4780640, 4780640, 4780641, 4780641, 4780642, 4780643, 4780644, 4780646, 4780633, 4780644, 4780641, 4780646, 4780644, 4780648, 4780648, 4780649, 4780649, 4780650, 4780651, 4780653, 4780653, 4780654, 4780742, 4780742, 4780743, 4780743, 4780744, 4780649, 4780650, 4780651, 4780651, 4780652, 4780652, 4780654, 4780654, 4780743, 4780743, 4780744, 4780650, 4780651, 4780651, 4780652, 4780653, 4780653, 4780655, 4780655, 4780742, 4780743, 4780743, 4780744, 4780744, 4780745, 4780651, 4780652, 4780652, 4780653, 4780653, 4780655, 4780743, 4780744, 4780744, 4780747, 4780653, 4780654, 4780743, 4780744, 4780745, 4780745, 4780653, 4780654, 4780656, 4780656, 4780743, 4780744, 4780744, 4780745, 4780745, 4780747, 4780654, 4780655, 4780656, 4780656, 4780657, 4780657, 4780744, 4780744, 4780745, 4780745, 4780746, 4780746, 4780747, 4851513, 4780655, 4780657, 4780657, 4780745, 4780745, 4780746, 4780746, 4780656, 4780657, 4780657, 4780658, 4780659, 4780745, 4780745, 4780746, 4780746, 4780747, 4780747, 4780748, 4780658, 4780747, 4780747, 4780748, 4913553, 4780658, 4780659, 4780747, 4780747, 4780748, 4792278, 4780659, 4780746, 4780747, 4780747, 4780748, 4780748, 4780749, 4780750, 4780753, 4785372, 4851515, 4851516, 4913550, 4913554, 5053581, 4780660, 4780747, 4780748, 4780748, 4780749, 4780749, 4802172, 4851516, 4913554, 4984304, 5000139, 5000139, 5087679, 5502638, 4780748, 4780748, 4780750, 4984306, 5000143, 4780749, 4851517, 4780834, 4780835, 4780836, 4780846, 4780836, 4780836, 4780837, 4780847, 4780836, 4780837, 4780837, 4780838, 4780838, 4780845, 4780847, 4780847, 4780848, 4780837, 4780838, 4780838, 4780839, 4780839, 4780848, 4780848, 4780838, 4780839, 4780839, 4780840, 4780847, 4780848, 4780849, 4780849, 4780840, 4780848, 4780849, 4780849, 4780849, 4780849, 4780850, 4780850, 4780851, 4780851, 4780852, 4780850, 4780853, 4780857, 4785469, 4780857, 4780858, 4780859, 4851615, 4780859, 4780860, 4780860, 4780861, 4783573, 4783574, 4783575, 4785467, 4785468, 4785468, 4785469, 4785469, 4785470, 4785471, 4785472, 4785472, 4785473, 4790070, 4791658, 4791661, 4792379, 4802271, 4802272, 4802273, 4811196, 4818060, 4818061, 4836275, 4843618, 4851615, 4851615, 4851616, 4851616, 4851617, 4874811, 4874815, 4874815, 4874816, 4874816, 4884720, 4913652, 4913654, 4913654, 4913655, 4913655, 4913657, 4984405, 4984405, 5000239, 5000248, 5013154, 5039068, 5053681, 5053681, 5111736, 5155579, 5155579, 5155580, 5163007, 5163007, 5163008, 5163009, 5163009, 5163010, 5436523, 5502737, 5674558, 10015231, 4780860, 4783575, 4785469, 4785472, 4791660, 4793580, 4802272, 4843618, 4851616, 4851616, 4874815, 4874816, 4913654, 4913655, 4984405, 5000239, 5048900, 5053681, 5163007, 5163008, 5163008, 5163010, 5428570, 4785469, 4791662, 4802273, 4802275, 4818062, 4851616, 4984407, 4785475, 4851617, 4851617, 4913655, 4785472, 4785474, 4851617, 4851618, 4913652, 5163010, 4785311, 4786301, 4786302, 4786303, 4786303, 4788200, 4854343, 4854344, 4854344, 4916382, 5165735, 4794388, 4789765, 4789768, 4789933, 4988864, 4790091, 4790092, 4790093, 4790093, 4790093, 4790096, 4790096, 4790082, 4790094, 4790097, 4790097, 4790100, 4790097, 4790098, 4790097, 4790099, 4790101, 4790086, 4790099, 4790099, 4790100, 4790102, 4790096, 4790100, 4790101, 4790096, 4790101, 4790102, 4790103, 4790102, 4790103, 4790103, 4790104, 4790099, 4790112, 4856239, 4830294, 4848703, 4856240, 4918278, 4918279, 4989029, 5004871, 5116361, 4796284, 4806899, 4856240, 4889345, 4918279, 4989030, 5004870, 4796288, 4856243, 4886489, 4856243, 4856244, 4989033, 5049865, 5507366, 4806901, 4815062, 4856244, 4856245, 4918283, 5053531, 5167636, 4918283, 4918284, 4856246, 4879448, 5043701, 5167637, 4856246, 4799299, 4811501, 4802473, 4802472, 4802473, 4802474, 4802476, 4802479, 4802481, 4885628, 4862430, 4862431, 5513553, 5877256, 4862432, 4924470, 4862435, 4924472, 4862435, 4803911, 4863147, 4863149, 4925186, 4806321, 5012980, 4823685, 4823698, 4823699, 4823699, 4823700, 4823700, 4823701, 4823700, 4823701, 4823689, 4823702, 4823702, 4823714, 4873042, 4896244, 4823714, 5021666, 4857703, 4865385, 4865386, 4873043, 4873044, 4873044, 4896244, 4896244, 4935082, 4935082, 5021666, 5021667, 5075109, 5133165, 5177007, 5177008, 5184436, 5324361, 4830864, 5180588, 4840017, 4840092, 4840167, 4943313, 4841547, 4841546, 5014755, 5014756, 4855274, 4855279, 4855280, 4881032, 5465787, 4892437, 4870495, 4888444, 4891701, 4891704, 4891704, 4907044, 5211009, 5218436, 4906392, 4906393, 4914390, 4937590, 4976428, 4906787, 4937786, 4907065, 4907066, 4907070, 4907188, 4907190, 4907191, 4907311, 4907311, 4907311, 4907315, 4907315, 4914846, 4914847, 4976885, 4914848, 4976888, 4976888, 4922371, 4922387, 4922372, 4922373, 4922384, 4922385, 4922386, 4922387, 4922387, 4922388, 4922388, 4922389, 4922390, 4922391, 4922391, 4922392, 4922373, 4922374, 4922375, 4922376, 4922387, 4922388, 4922388, 4922389, 4922390, 4922391, 4922374, 4922375, 4922387, 4922388, 4922388, 4922389, 4922389, 4922390, 4922392, 4922388, 4922389, 4922390, 4922389, 4922392, 4922393, 4922390, 4922391, 5226348, 4984424, 4922401, 5937177, 4922402, 4922403, 4922403, 4922404, 4945588, 4984421, 4984425, 4984426, 5055175, 5055175, 5055177, 5071010, 5071017, 5071018, 5071019, 5071021, 5083926, 5119671, 5182510, 5211787, 5226350, 5226351, 5233779, 5233781, 5373703, 5390105, 4922403, 4922404, 4922404, 4922405, 4922405, 4922409, 4945587, 4945588, 4945588, 4945589, 4945589, 4984426, 4984426, 5055177, 5058389, 5071019, 5119672, 5124454, 5127002, 5226352, 5233780, 5233782, 5499341, 5573509, 6242868, 4922404, 4922405, 4922405, 4922406, 4922407, 4922408, 4922409, 4922410, 4945585, 4945587, 4945587, 4945588, 4945589, 4945589, 4984422, 4984425, 4984426, 4984427, 4984427, 4984428, 4984429, 4984430, 5033076, 5055177, 5055178, 5058383, 5058390, 5071011, 5071015, 5071018, 5071018, 5071020, 5116008, 5119672, 5119673, 5124453, 5173660, 5226351, 5226352, 5233779, 5233779, 5233780, 5233780, 5233781, 5233781, 5233782, 5373704, 5390108, 5573510, 6242871, 6242872, 4945589, 4945590, 4984427, 5058391, 5120771, 5124455, 5226352, 5233782, 5279584, 5830929, 4922411, 4945588, 4984427, 5124455, 5233780, 5233782, 4925992, 4945590, 5053197, 5055179, 5182510, 5233780, 5573511, 4952640, 5071022, 5175001, 5937449, 4945592, 4984430, 5233783, 4984430, 5055181, 5124458, 5173671, 4945592, 5226356, 4925996, 4984432, 5071025, 5127008, 5072428, 4929590, 4929590, 4988021, 5237378, 5237382, 4968782, 4968783, 4968784, 4968785, 4968774, 4968786, 4968786, 4968774, 4968786, 4968787, 4968787, 4968787, 4968775, 4968787, 4968788, 4968788, 4968788, 4968789, 5007624, 5007624, 4968800, 5007624, 5256979, 5007625, 5007625, 5007626, 5078374, 5078375, 5078376, 5078376, 5094208, 5094212, 5094215, 5094217, 5094218, 5107128, 5139201, 5142871, 5142872, 5142873, 5147652, 5150203, 5198198, 5205707, 5233087, 5249548, 5249550, 5249551, 5256977, 5256978, 5256978, 5256979, 5396901, 5413306, 5596709, 4982894, 4982897, 4982906, 5149933, 5264040, 5529607, 4988593, 4988594, 5088278, 5017527, 5046440, 5046455, 5046456, 5046457, 5046459, 5046441, 5046458, 5046445, 5046447, 5046461, 5046464, 5046464, 5046449, 5046450, 5046450, 5046452, 5046461, 5046462, 5046462, 5046463, 5046464, 5046464, 5046465, 5046465, 5046466, 5046466, 5046467, 5046467, 5046468, 5046450, 5046451, 5046464, 5046464, 5046465, 5046465, 5046466, 5046467, 5046473, 5046451, 5046464, 5046465, 5046465, 5046466, 5046467, 5046453, 5046465, 5046466, 5046467, 5046468, 5046466, 5046468, 5046468, 5046470, 5046466, 5046468, 5046469, 5046470, 5046468, 5046470, 5117209, 5295816, 5046476, 5046479, 5117211, 5117213, 5046478, 5181711, 5571737, 5046478, 5295819, 5295819, 5046479, 5046480, 5046480, 5046485, 5079240, 5117215, 5117215, 5133049, 5133056, 5145967, 5178037, 5181710, 5181712, 5186491, 5186491, 5189040, 5189472, 5244546, 5273826, 5288389, 5288390, 5295817, 5295819, 5435741, 5046480, 5046481, 5046481, 5046482, 5046482, 5117215, 5117216, 5117216, 5117217, 5120424, 5120427, 5133055, 5133056, 5145967, 5150034, 5155352, 5176601, 5186491, 5189472, 5221602, 5288389, 5288390, 5288390, 5295817, 5295817, 5295818, 5295819, 5295820, 5295820, 5452147, 5561379, 5635548, 6238200, 6304909, 5046481, 5046483, 5117216, 5117216, 5133055, 5145969, 5178052, 5235698, 5244547, 5288391, 5046485, 5117217, 5133058, 5181710, 5181711, 5186492, 5288390, 5288391, 5295818, 5295819, 5295820, 5117217, 5117217, 5117220, 5186493, 5244549, 5288391, 5288391, 5295819, 5295820, 5117217, 5133052, 5133060, 5181711, 5117218, 5133052, 5288393, 6304910, 5295823, 5117219, 5133062, 5295824, 5117221, 5117224, 5112013, 5127885, 5143759, 5143760, 5144027, 6047955, 5144292, 5181960, 5183998, 5183999, 5189191, 5201823, 5187949, 5187963, 5187963, 5187964, 5187964, 5187950, 5187951, 5187953, 5187965, 5187965, 5187966, 5187966, 5187967, 5187969, 5187954, 5187966, 5187967, 5187967, 5187968, 5187968, 5187968, 5187968, 5187970, 5187969, 5252459, 5187980, 5203807, 5366568, 5366570, 5522896, 5187981, 5203799, 5203799, 5203807, 5187981, 5187982, 5257243, 5259790, 5306449, 5307788, 5315298, 5315299, 5359140, 5359140, 5359141, 5366568, 5366568, 5366570, 5632129, 5632130, 5187982, 5187983, 5191178, 5203800, 5203801, 5203803, 5203804, 5203807, 5203809, 5203810, 5216718, 5216720, 5241891, 5242511, 5247352, 5248795, 5248801, 5248807, 5257242, 5306449, 5307788, 5307788, 5315298, 5359140, 5359140, 5359141, 5359141, 5359142, 5366568, 5366569, 5366569, 5366570, 5366571, 5506493, 5706299, 5706299, 5755067, 6070124, 6375656, 5203800, 5203801, 5216719, 5252461, 5257243, 5257244, 5257245, 5292353, 5359139, 5359142, 5366570, 5366571, 5397926, 5706299, 5706300, 5187985, 5203808, 5248801, 5359143, 5366572, 5194387, 5194391, 5194390, 5194393, 5194396, 5194377, 5194400, 5194395, 5207019, 5194414, 5255678, 5509707, 5255679, 5255679, 5311006, 5362358, 5318518, 5219617, 5219618, 5219618, 5219626, 5219634, 5219635, 5219636, 5219619, 5219620, 5219626, 5219634, 5219634, 5219635, 5219636, 5219636, 5219637, 5219637, 5219638, 5219640, 5219628, 5219635, 5219642, 5219636, 5219644, 5219645, 5219645, 5219630, 5219646, 5219647, 5219648, 5219649, 5219634, 5219642, 5219649, 5219650, 5219650, 5219650, 5219642, 5219650, 5219651, 5219644, 5219651, 5219651, 5219652, 5219653, 5219653, 5219653, 5219651, 5219653, 5219657, 5219655, 5219657, 5374976, 5219653, 5219655, 5219656, 5219659, 5219655, 5273079, 5374976, 5219660, 5273078, 5322286, 5331135, 5382404, 5382405, 5382406, 5522330, 5382405, 5722136, 5382408, 5232555, 5268299, 5382407, 5273080, 5264509, 5268300, 5268304, 5382410, 5413762, 5219666, 5219667, 5232559, 5232560, 5258895, 5264648, 5268305, 5273084, 5273085, 5323630, 5331140, 5374982, 5374983, 5382410, 5382411, 5382411, 5382412, 5382412, 5382413, 5382414, 5623036, 5722141, 5232560, 5232561, 5268303, 5268304, 5273085, 5308195, 5331142, 5360420, 5382411, 5382412, 5382413, 5382414, 5647972, 5268305, 5273085, 5331143, 5382411, 5222451, 5274483, 5245465, 5245466, 5245466, 5245454, 5245467, 5245467, 5245468, 5245468, 5245469, 5271378, 5277536, 5277546, 5281211, 5285991, 5335200, 5344047, 5344048, 5373327, 5387889, 5387890, 5395318, 5395319, 5395320, 5535242, 5253603, 5275747, 5264234, 5264284, 5264336, 5404752, 5295811, 5306381, 5297050, 5297169, 5297294, 5297295, 5297288, 5297298, 5526395, 5421236, 5307126, 5561158, 5297888, 5298015, 5298138, 5298141, 5307546, 5421654, 5306737, 5319176, 5418525, 5309369, 5309501, 5309615, 5309627, 5309620, 5309623, 5309631, 5309631, 5309635, 5309643, 5309640, 5309636, 5309640, 5309647, 5309646, 5419968, 5419969, 6436489, 5427402, 5376132, 5419975, 5419977, 5419978, 5313301, 5427409, 6024552, 5313303, 5376143, 5316955, 5316940, 5316956, 5316942, 5316956, 5316956, 5316957, 5316944, 5316956, 5316957, 5316958, 5316958, 5316960, 5316961, 5316962, 5316962, 5316970, 5316971, 5321737, 5353445, 5431066, 5316974, 5318054, 5321737, 5324719, 5338966, 5372283, 5379792, 5379793, 5379794, 5409070, 5423633, 5423635, 5423636, 5423637, 5431064, 5431066, 5440276, 5587391, 5696626, 5770794, 5379795, 5409072, 5431065, 5696627, 5372286, 5321741, 5319148, 5319149, 5432160, 5432158, 5326503, 5326518, 5326518, 5326519, 5326519, 5326520, 5326520, 5326521, 5326519, 5326519, 5326520, 5326518, 5326520, 5326520, 5326519, 5326521, 5326521, 5326507, 5326520, 5326533, 5435845, 6139241, 5384573, 5384574, 5428416, 5428417, 5435845, 5435846, 5435847, 5575768, 5775575, 6138964, 5326534, 5326536, 5377064, 5384574, 5384576, 5413853, 5428414, 5428416, 5428416, 5428417, 5435844, 5435845, 5435845, 5435846, 5435847, 5435847, 5467197, 5701406, 5329067, 5384574, 5428417, 5435843, 5435845, 5435847, 5329502, 5384577, 5428418, 5435845, 5870450, 5435846, 5435848, 5575771, 5435847, 5435851, 5331439, 5331528, 5331613, 5331616, 5331613, 5331613, 5331617, 5331617, 5331620, 5331618, 5332045, 5364177, 5703952, 5778120, 5438395, 5378274, 5438393, 5438394, 5364182, 5332356, 5332418, 5332480, 5332481, 5332482, 5332482, 5332483, 5364608, 5431397, 5438828, 6447913, 5438829, 5360973, 5453072, 5389935, 5445561, 5394710, 5462512, 5710563, 5396738, 5396740, 5396743, 5396743, 5419687, 5463527, 5470956, 5470957, 5470959, 6480047, 5424931, 5424932, 5424933, 5424933, 5424942, 5426271, 5433782, 5485054, 5477624, 5485053, 5485054, 5485057, 5427606, 5427607, 5427595, 5427607, 5427607, 5427608, 5478958, 5486388, 5435117, 5435118, 5478959, 5478959, 5478960, 5486387, 5486388, 5486390, 5521365, 5642717, 5751949, 5826118, 5442628, 5442628, 5442631, 5442632, 5442629, 5442631, 5442617, 5442629, 5442630, 5442630, 5471907, 5471908, 5486470, 5486471, 5486471, 5486472, 5486472, 5493898, 5493899, 5493899, 5493900, 5633823, 5734524, 5833629, 6014888, 6502990, 5470006, 5486474, 5493903, 5633826, 5493904, 5497381, 5497385, 5497476, 5521275, 5497565, 5513938, 5501185, 5501186, 5501187, 5501188, 5501188, 5515750, 5515751, 5515751, 5515752, 5523179, 5523179, 5523182, 5862909, 6226833, 5530297, 5530297, 5530298, 5530310, 5530298, 5530299, 5530311, 5530313, 5530299, 5530300, 5530300, 5530312, 5530312, 5530314, 5530300, 5530301, 5530312, 5530313, 5530301, 5530302, 5530302, 5530312, 5530313, 5530313, 5530313, 5530314, 5530314, 5530314, 5530325, 5530325, 5530326, 5537737, 5537739, 5537740, 5537740, 5537741, 5537741, 5537742, 5537742, 5537743, 5537743, 5583546, 5677664, 5677666, 5694065, 5694067, 5694068, 5778362, 5778363, 5803298, 5803301, 5803302, 5803302, 5877470, 5877470, 5877471, 5877472, 5916894, 6058730, 6241172, 6241231, 6241232, 6241265, 6241280, 6241281, 6241293, 6449015, 6546565, 6546830, 6546832, 5530327, 5537739, 5537740, 5537740, 5537741, 5537741, 5537742, 5537742, 5537743, 5537743, 5537744, 5537744, 5677665, 5778364, 5803302, 5803303, 5803303, 5877471, 5877471, 5926240, 6546832, 5537741, 5537743, 6241139, 6241296, 5537742, 5537745, 5545152, 5545154, 5545154, 5545169, 5545154, 5545155, 5545155, 5545156, 5545157, 5545169, 5545169, 5545170, 5545155, 5545156, 5545156, 5545157, 5545157, 5545158, 5545158, 5545170, 5545171, 5545171, 5545172, 5545172, 5545173, 5545173, 5545156, 5545157, 5545157, 5545158, 5545158, 5545159, 5545169, 5545169, 5545171, 5545171, 5545172, 5545172, 5545173, 5545173, 5545174, 5545174, 5545157, 5545158, 5545158, 5545159, 5545159, 5545160, 5545172, 5545172, 5545173, 5545173, 5545174, 5545158, 5545159, 5545159, 5545160, 5545160, 5545169, 5545171, 5545171, 5545172, 5545172, 5545173, 5545173, 5545174, 5545174, 5545175, 5545175, 5545159, 5545160, 5545160, 5545161, 5545170, 5545171, 5545172, 5545172, 5545173, 5545173, 5545175, 5545175, 5545160, 5545161, 5545161, 5545163, 5545172, 5545173, 5545173, 5545174, 5545174, 5545175, 5545175, 5545176, 5545176, 5545161, 5545162, 5545162, 5545163, 5545171, 5545172, 5545173, 5545173, 5545174, 5545174, 5545175, 5545175, 5545176, 5545176, 5545177, 5545177, 5545173, 5545173, 5545174, 5545174, 5545175, 5545175, 5545176, 5545176, 5545177, 5545177, 5545164, 5545164, 5545175, 5545177, 5545177, 5545178, 5545178, 5545165, 5545177, 5545178, 5545178, 5545179, 5545179, 5545184, 5545184, 5545186, 5545186, 5545184, 5545185, 5545186, 5545187, 5545186, 5545187, 5545188, 5884900, 5545185, 5545186, 5545186, 5545187, 5545188, 5810731, 5884901, 5545186, 5545187, 5545187, 5545188, 5545188, 5545189, 5545189, 5785795, 5545187, 5545188, 5545188, 5545189, 5545189, 5685095, 5785794, 5810733, 5884901, 5884902, 6008461, 6248572, 5545188, 5545189, 5545189, 5545190, 5685096, 5685097, 5701499, 5810732, 5810733, 5884902, 5884902, 5884903, 6248568, 6248711, 5545189, 5545190, 5545190, 5685096, 5685098, 5701499, 5701500, 5701501, 5810733, 5810734, 5884903, 6012677, 6364360, 6554263, 6554264, 5545190, 5545191, 5545191, 5545193, 5685097, 5701501, 5785793, 5810734, 5810734, 5821092, 5884903, 5884904, 6487555, 6554263, 6554264, 5545191, 5545192, 5576529, 5580152, 5685097, 5685099, 5701501, 5701502, 5701503, 5810734, 5810734, 5810735, 5884903, 5884903, 5884904, 6248730, 6248829, 6554264, 7204260, 7628275, 5545192, 5545193, 5545194, 5545194, 5546514, 5576279, 5576524, 5576525, 5576527, 5576527, 5576529, 5576530, 5576530, 5576531, 5590980, 5590981, 5685098, 5685099, 5685100, 5701499, 5701501, 5701501, 5701502, 5701503, 5723634, 5759097, 5785796, 5785798, 5785799, 5810733, 5810734, 5810735, 5810735, 5816129, 5884903, 5884904, 5884904, 5884905, 5924328, 5933671, 5933672, 5933673, 5933674, 5961899, 6076693, 6248571, 6248572, 6248573, 6248665, 6248738, 6325876, 6554263, 6554264, 6554265, 6554265, 5545193, 5545194, 5576530, 5685098, 5685100, 5701502, 5701503, 5701503, 5701504, 5759098, 5785797, 5810733, 5810735, 5810736, 5810752, 5818691, 5884904, 5884905, 6061052, 6302210, 7204261, 5545195, 5685100, 5685101, 5884906, 6482153, 5545196, 5561545, 5785796, 5810737, 5884905, 5685100, 5547851, 5686435, 5563597, 5894115, 5577904, 5594952, 5584010, 5830149, 5607378, 5841834, 5607872, 5607872, 5607874, 5607876, 5607877, 5607877, 5607882, 5607884, 5607880, 5607881, 5607881, 5607886, 5817142, 5716445, 5842084, 5716447, 5817146, 5716448, 5716450, 5732852, 5716450, 5842088, 5732857, 5916258, 5612005, 5718512, 5615126, 5615127, 5736476, 5845710, 5636779, 5636781, 5636782, 5636782, 5636782, 5856536, 5730899, 6106853, 5755503, 5990065, 5825017, 5825015, 5825005, 5825014, 5825015, 5825015, 5825016, 5825016, 5825017, 5825018, 5825019, 5825019, 5825020, 5825022, 5825007, 5825019, 5825019, 5825020, 5825020, 5825022, 5825023, 5825024, 5825024, 5825020, 5825022, 5825023, 5825094, 5825026, 5825027, 5950652, 6388630, 6694180, 5825027, 5825030, 5825031, 5825031, 5825095, 5841421, 5925716, 5950653, 6024821, 5825028, 5950653, 5950654, 6024822, 6388751, 5825029, 5825031, 5841420, 5925715, 5950651, 5950654, 5956047, 6024822, 6064246, 5841419, 5950654, 6024823, 5841419, 5925718, 5825033, 5825035, 5925717, 5950654, 5950655, 5950655, 6024824, 5841421, 5841424, 5950656, 5950656, 6388496, 6388585, 5825034, 5825035, 5825036, 5825036, 5841421, 5841422, 5841423, 5925717, 5925717, 5925720, 5950655, 5950656, 5950656, 5950662, 6024824, 6024824, 6024825, 6024825, 6046894, 6073593, 6149396, 6196647, 6264955, 6373839, 6388632, 6388634, 5841422, 5841423, 5841424, 5925718, 5925720, 5950656, 5950657, 5950657, 6024825, 6024826, 6388642, 6388764, 5841425, 5972479, 5899020, 5925718, 5925721, 5950657, 5950658, 5841426, 5950658, 6694188, 5950659, 6024827, 6024828, 5841424, 6024828, 6024829, 5825172, 5950730, 5950730, 5857822, 5857808, 5857809, 5857824, 5857823, 5857824, 5857811, 5857812, 5857824, 5857825, 5857810, 5857824, 5857825, 5857825, 5857811, 5857812, 5857826, 5857813, 5857813, 5857824, 5857825, 5857826, 5857826, 5857827, 5857825, 5857827, 5857828, 5857829, 5857814, 5857828, 5857828, 5857829, 5857829, 5857828, 5857828, 5857829, 5857830, 5857828, 5942118, 6041226, 6041226, 5857839, 5967058, 6089997, 6281366, 5967083, 6089996, 5857841, 5857843, 5857843, 5942121, 5967058, 5967060, 6041228, 6041228, 6041229, 6404894, 6404896, 6405037, 6482202, 6749665, 5857843, 5942121, 5967059, 5967060, 5967060, 5967061, 5967074, 6041227, 6041228, 6041229, 6041229, 6118225, 6217377, 6404896, 6405156, 5857843, 6041229, 6222489, 5857844, 5942125, 5967061, 5967062, 5967062, 6041229, 6404930, 5942120, 5942121, 5942123, 5942125, 5967059, 5967062, 6041230, 6041231, 6404898, 6404992, 6710591, 5967062, 5902091, 5989191, 5989192, 5973015, 5973016, 6024653, 6098822, 5999715, 6026414, 6026416, 6026416, 6026415, 6026416, 6026417, 6026417, 6026418, 6026403, 6026417, 6026418, 6026418, 6026418, 6026419, 6026419, 6026420, 6026420, 6026421, 6026421, 6125524, 6026435, 6051356, 6125525, 6125525, 6306784, 6051355, 6051357, 6051357, 6051357, 6051358, 6051379, 6125526, 6125526, 6156532, 6164948, 6174299, 6489192, 6489287, 6489335, 6794889, 6076291, 6076276, 6076276, 6076293, 6076291, 6076277, 6076296, 6076294, 6076294, 6076296, 6076278, 6076279, 6076279, 6076293, 6076293, 6076294, 6076294, 6076295, 6076295, 6076296, 6076296, 6076279, 6076280, 6076285, 6076293, 6076294, 6076294, 6076295, 6076295, 6076296, 6076296, 6076297, 6076298, 6076298, 6076300, 6076301, 6076302, 6076294, 6076295, 6076295, 6076296, 6076296, 6076297, 6076297, 6076298, 6076299, 6076295, 6076296, 6076298, 6076315, 6076322, 6076304, 6076328, 6076308, 6098115, 6076309, 6086652, 6150461, 6150462, 6514132, 6076309, 6076310, 6076310, 6076311, 6076312, 6076313, 6081687, 6150462, 6150463, 6326610, 6514257, 6076310, 6076311, 6076311, 6076312, 6076312, 6076313, 6076313, 6076314, 6150461, 6150462, 6150463, 6150463, 6189886, 6199231, 6199232, 6227458, 6326612, 6514129, 6514270, 6514272, 6747711, 6819557, 6076311, 6076312, 6076312, 6076313, 6076314, 6076316, 6076320, 6076331, 6081688, 6098118, 6150463, 6150463, 6150464, 6199233, 6390592, 6514131, 6514134, 6514224, 6514225, 6514273, 6819824, 10662957, 6076312, 6076313, 6076313, 6076314, 6076314, 6076319, 6076320, 6076322, 6150463, 6150464, 6150464, 6150465, 6227459, 6326612, 6514289, 6514403, 6747712, 6819825, 6819825, 6076313, 6076314, 6076330, 6076333, 6093386, 6150463, 6150464, 6150464, 6150465, 6150465, 6184749, 6189889, 6326612, 6393772, 6514353, 6819826, 6076314, 6076316, 6081690, 6150463, 6150464, 6150465, 6150465, 6514132, 6514135, 6514274, 6722009, 6747713, 6076315, 6076317, 6076318, 6076319, 6076320, 6076321, 6076326, 6098119, 6150465, 6150466, 6150467, 6199235, 6514225, 6514291, 6514391, 6076317, 6150466, 6150466, 6199238, 6819828, 7104530, 6076333, 6076334, 6150466, 6150467, 6199237, 6076323, 6150466, 6150467, 6150467, 6514133, 6514227, 6150467, 6076337, 6150469, 6150469, 6076338, 6150470, 6150470, 6076340, 6076340, 6076341, 6150471, 6150472, 6150472, 6150473, 6150473, 6150474, 6150477, 6150482, 6322304, 6514310, 6150483, 6514152, 6326632, 6150485, 6093407, 6150484, 6150485, 6150485, 6150485, 6150486, 6087077, 6087078, 6092043, 6155852, 6155853, 6155853, 6155853, 6092203, 6092202, 6158415, 6330238, 6097006, 6097008, 6097010, 6160817, 6209586, 6160818, 6160819, 6110471, 6110472, 6167550, 6167551, 6119938, 6119938, 6119939, 6119940, 6172284, 6172285, 6172285, 6535951, 6224614, 6224615, 6224615, 6224615, 6224616, 6224616, 6224617, 6224628, 6224629, 6224630, 6224631, 6224631, 6224632, 6224616, 6224617, 6224617, 6224631, 6224631, 6224632, 6224632, 6224633, 6224617, 6224618, 6224618, 6224629, 6224630, 6224631, 6224631, 6224632, 6224632, 6224633, 6224633, 6224618, 6224628, 6224629, 6224631, 6224632, 6224632, 6224633, 6224633, 6224634, 6224631, 6224632, 6224633, 6224633, 6224634, 6224634, 6224632, 6224633, 6224642, 6224644, 6224644, 6224645, 6224645, 6588437, 6893990, 6893990, 6224644, 6224645, 6224646, 6265531, 6273398, 6224646, 6224646, 6224647, 6224647, 6273401, 6893992, 6224646, 6224647, 6224647, 6224648, 6254142, 6264053, 6264054, 6273399, 6273400, 6400779, 6588298, 6588299, 6588333, 6588391, 6690816, 6893992, 6933067, 6224647, 6224648, 6224648, 6264054, 6273399, 6273400, 6273401, 6313309, 6319506, 6349203, 6400780, 6405890, 6405891, 6482051, 6588297, 6588297, 6588299, 6588299, 6588300, 6588301, 6588392, 6588393, 6588440, 6588441, 6588458, 6588459, 6588506, 6588554, 6588562, 6665604, 6893722, 6893726, 6893992, 6893993, 6893993, 6224648, 6224649, 6264053, 6264055, 6273401, 6273401, 6273402, 6274185, 6301627, 6301628, 6319507, 6349203, 6396453, 6400780, 6400780, 6405891, 6405892, 6462097, 6588298, 6588299, 6588299, 6588300, 6588302, 6588334, 6588392, 6588393, 6588393, 6588441, 6588457, 6588459, 6588519, 6588567, 6679153, 6796177, 6821881, 6893727, 6893990, 6893991, 6893991, 6893992, 6893993, 6224649, 6264054, 6264055, 6273399, 6273400, 6273402, 6316158, 6400780, 6400781, 6405891, 6405892, 6588298, 6588300, 6588301, 6588301, 6588302, 6588302, 6588303, 6588387, 6588390, 6588394, 6588427, 6588441, 6588441, 6588457, 6588460, 6588478, 6588516, 6588535, 6588570, 6588576, 6588577, 6665605, 6893727, 6893989, 6893991, 6893992, 6893994, 6893994, 6246702, 6259905, 6264055, 6264056, 6264056, 6264059, 6264059, 6264061, 6273401, 6273402, 6273402, 6273403, 6273403, 6273406, 6301628, 6301629, 6303798, 6316159, 6319506, 6391653, 6396454, 6400781, 6400781, 6405890, 6405892, 6405892, 6405893, 6407686, 6421014, 6588298, 6588299, 6588299, 6588300, 6588300, 6588301, 6588301, 6588303, 6588392, 6588393, 6588393, 6588394, 6588426, 6588441, 6588442, 6588442, 6588443, 6588457, 6588457, 6588458, 6588460, 6588469, 6588504, 6588517, 6588521, 6588533, 6588536, 6588572, 6588572, 6588573, 6821881, 6893728, 6893728, 6893990, 6893992, 6893993, 6893994, 6893994, 6893995, 6268767, 6268768, 6295467, 6504118, 6283650, 6378710, 6286644, 6924997, 6293196, 6622672, 6295171, 6623708, 6303475, 6303475, 6303475, 6303476, 6303476, 6303476, 6303477, 6303477, 6303474, 6303475, 6303478, 6303479, 6303480, 6303483, 6303484, 6303485, 6303487, 6521469, 6440200, 6627813, 6312823, 6628004, 6933413, 6312825, 6388625, 6627721, 6627863, 6627879, 6312823, 6312825, 6627724, 6627755, 6627863, 6627864, 6933149, 6933149, 6933414, 6627723, 6627725, 6627817, 6933418, 6521475, 6306494, 6629455, 6322166, 6322167, 6322153, 6322167, 6322169, 6322170, 6322157, 6322168, 6322168, 6322169, 6322155, 6322169, 6322169, 6322171, 6322155, 6322157, 6322168, 6322169, 6322170, 6322170, 6322171, 6322171, 6322168, 6322169, 6322170, 6322171, 6322172, 6322172, 6322160, 6322173, 6322173, 6322175, 6322173, 6322175, 6322177, 6322178, 6362076, 6322184, 6350394, 6449547, 6350395, 6397971, 6322185, 6454660, 6637068, 6637211, 6942760, 6942761, 6322186, 6322188, 6350395, 6350396, 6350397, 6368275, 6368277, 6454659, 6454660, 6637161, 6637211, 6637291, 6637347, 6942495, 6942759, 6942761, 6322188, 6398535, 6454661, 6637068, 6637228, 6322187, 6340080, 6364927, 6449549, 6449549, 6449550, 6637067, 6637068, 6637161, 6637162, 6942496, 6942760, 6322190, 6350397, 6447059, 6449552, 6530819, 6530821, 6637068, 6637126, 6637162, 6637163, 6637196, 6637211, 6637229, 6637281, 6942759, 6942763, 6942764, 6637069, 6637071, 6449552, 6637072, 6328853, 6637325, 6323736, 6369055, 6335524, 6374949, 6357983, 6358086, 6358189, 6370572, 6378616, 6378619, 6378621, 6378622, 6378622, 6378620, 6378622, 6378623, 6665383, 6396499, 6482883, 6559042, 6665386, 6665434, 6396501, 6429403, 6477774, 6665292, 6665293, 6665296, 6665421, 6665436, 6665509, 6970721, 6970987, 6970988, 6970722, 6382960, 6382961, 6667548, 6398670, 6401983, 6401983, 6437878, 6677100, 6407680, 6407681, 6679963, 6985249, 6985514, 6414372, 6414376, 6414376, 6414377, 6414378, 6414380, 6414377, 6414381, 6683427, 6683262, 6683295, 6683311, 6683329, 6916750, 6515884, 6683264, 6760476, 6683300, 6495654, 6471747, 6711856, 6473772, 6473774, 6473774, 6473773, 6528370, 6606617, 6712994, 6712996, 6713009, 6712962, 6712998, 6474885, 6474908, 6713566, 6480180, 6480181, 6528553, 6716214, 6558660, 6558734, 6558809, 6755383, 6568273, 6568273, 6568274, 6568276, 6760246, 6760362, 6993700, 6760120, 6760244, 6760120, 6571977, 6572055, 6572099, 6581417, 6576926, 6576912, 6576925, 6576926, 6576926, 6576927, 6576927, 6576928, 6576929, 6576929, 6576930, 6576930, 6576931, 6576913, 6576927, 6576929, 6576929, 6576930, 6576928, 6576929, 6576932, 6764537, 6764573, 6764573, 6764587, 7070138, 6576942, 6576943, 6764447, 6764539, 6764540, 6764574, 6764588, 6764588, 7070136, 7070139, 6576944, 6576946, 6580872, 6764541, 6764588, 6764590, 6582040, 6764447, 6764595, 6764450, 7069875, 6764590, 6764651, 6742054, 6764449, 6764750, 6764449, 7070143, 7070144, 6582043, 6764449, 6764450, 6764452, 6582968, 6627445, 6584813, 7045347, 6587145, 6587146, 6587146, 6587135, 6587147, 6587146, 6587147, 6587148, 6587148, 6769276, 6769831, 6663304, 6754902, 6769552, 6769553, 6769554, 6769554, 6769555, 6769555, 6769556, 6769648, 6769649, 6769697, 6769712, 6769794, 6769819, 7074983, 7075248, 7075248, 7075249, 6590738, 6590826, 6590828, 6590835, 6590907, 6590920, 6590927, 6590927, 6771444, 6771601, 6590940, 6749052, 6608209, 7085779, 6617392, 6617392, 6784680, 6784820, 6671920, 6811939, 6699582, 6825926, 6704897, 6704898, 6704911, 6828563, 7105390, 6828582, 6711242, 6711373, 6711503, 6909038, 6739462, 6739464, 6739464, 6739465, 6739466, 6739466, 6739467, 7151408, 6845714, 6845715, 6845808, 6845809, 6845842, 6845869, 7151406, 7151408, 6907180, 6907252, 6907326, 6929776, 6922657, 6922659, 6922660, 7243003, 7170893, 7243004, 6951404, 6951405, 6951405, 6951683, 6951682, 6951684, 6951960, 6951949, 6951962, 6951962, 6951949, 6951950, 6951952, 6951956, 6951958, 6951961, 6951963, 6951965, 6951949, 6951950, 6951962, 6951963, 6951950, 6951951, 6951952, 6951959, 6951961, 6951962, 6951964, 6951951, 6951952, 6951962, 6951962, 6951963, 6951963, 6951964, 6951964, 6951967, 6951952, 6951962, 6951963, 6951963, 6951964, 6951964, 6951965, 6951967, 6951967, 6951962, 6951963, 6951965, 6951965, 6951967, 6951968, 6951966, 6951968, 6951965, 6951966, 6951968, 6951969, 6951967, 6951969, 6951971, 6951958, 6951970, 6951970, 6951969, 6951971, 6951971, 6952055, 7542356, 6952087, 6951973, 6951975, 6952090, 6952091, 7257656, 6951974, 6951976, 6951978, 6952149, 7185544, 7257655, 6951975, 6951976, 6951979, 6952055, 6952105, 6952123, 6952134, 6952234, 6952240, 7257655, 7257657, 7606122, 6951977, 6951997, 6952091, 6952092, 6951977, 6951980, 6952054, 6952090, 6952266, 7257656, 6951980, 6951980, 6951999, 6952057, 6952057, 6952058, 6952059, 6952060, 6952092, 6952093, 6952104, 6952106, 6952106, 6952112, 6952121, 6952124, 6952137, 6952168, 6952213, 6952218, 6952233, 6952237, 7029269, 7054480, 7185544, 7257392, 7257654, 7257656, 7257658, 7257658, 7257659, 7296733, 6951980, 6952059, 6951982, 6952059, 6952060, 6952060, 6952061, 6952096, 6952096, 6952120, 6951983, 6952049, 6952059, 6952059, 6952060, 6952060, 6952061, 6952062, 6952062, 6952063, 6952093, 6952094, 6952095, 6952096, 6952097, 6952108, 6952109, 6952168, 6952227, 6952236, 6952237, 6952243, 7257659, 7257660, 6952061, 6952128, 6952028, 6952027, 6952028, 6952029, 6952030, 6952034, 6952087, 6952088, 6952086, 6952088, 6952089, 6952124, 6952124, 6952125, 6952091, 6952074, 6952147, 6952139, 6952140, 6952144, 6952145, 6952147, 6952146, 6952149, 6952136, 6952137, 6952137, 6952140, 6952147, 6952149, 6952138, 6952147, 6952150, 6952138, 6952139, 6952150, 6952140, 6952151, 6952151, 6952142, 6952152, 6952152, 6952153, 6952153, 6952179, 6952182, 7257480, 7257748, 6952215, 6952181, 6952182, 6952182, 6952183, 6952184, 6952184, 6952185, 6952187, 6952198, 6952198, 6952199, 6952205, 6952213, 6952214, 6952216, 6952216, 6952217, 6952236, 6952261, 6952262, 6952271, 6952275, 6952291, 6952292, 6952293, 6952300, 6952303, 6952306, 6952308, 6952311, 6952311, 6952312, 6952315, 6952320, 6952326, 6952332, 6952333, 7029362, 7054572, 7185637, 7257482, 7257484, 7257486, 7257745, 7257747, 7257748, 7257748, 7257749, 7257750, 7257750, 7257751, 6952202, 6952215, 6952201, 6952203, 6952204, 6952214, 6952215, 6952216, 6952217, 6952214, 6952216, 6952228, 6952217, 6952205, 6952208, 6952217, 6952219, 6952207, 6952217, 6952218, 6952219, 6952220, 6952218, 6952218, 6952219, 6952220, 6952219, 6952220, 6952220, 6952220, 6952276, 7244900, 6952286, 6952313, 7257517, 6952230, 6952352, 7257784, 6952231, 6952231, 6952232, 6952232, 6952233, 6952233, 6952234, 6952243, 6952248, 6952248, 6952268, 6952315, 6952360, 6952386, 7029395, 7096635, 7159966, 7185671, 7185671, 7185672, 7257517, 7257518, 7257780, 7257780, 7257781, 7257782, 7257782, 7257783, 7257783, 7257784, 7257784, 6952248, 6952249, 7257784, 6952233, 6952247, 7257782, 7257784, 7257784, 7257785, 7257785, 6952233, 6952234, 6952240, 6952248, 6952249, 6952250, 6952234, 6952235, 6952236, 6952237, 6952244, 6952245, 6952246, 6952246, 6952247, 6952247, 6952248, 6952249, 6952249, 6952250, 6952250, 6952266, 6952240, 6952247, 6952250, 6952250, 6952251, 6952251, 6952253, 6952250, 6952250, 6952275, 6952250, 6952254, 6952263, 6952283, 6952251, 6952255, 6952257, 6952252, 6952255, 6952295, 6952255, 6952274, 6952273, 6952267, 6952273, 6952260, 6952261, 6952273, 6952274, 6952262, 6952272, 6952274, 7029412, 7257798, 6952262, 6952262, 6952276, 6952264, 6952267, 6952330, 7257800, 6952264, 6952265, 6952265, 6952267, 6952268, 6952278, 6952279, 6952279, 6952283, 6952285, 6952291, 6952301, 6952316, 6952356, 6952371, 6952377, 6952379, 6952384, 6952408, 7029413, 7257534, 7257799, 7257799, 7257800, 7257801, 7257802, 6952265, 6952266, 6952267, 6952268, 6952277, 6952278, 6952280, 6952281, 6952282, 6952288, 6952290, 6952292, 6952293, 6952350, 6952356, 6952364, 6952379, 6952379, 6952384, 6952394, 7005748, 7029414, 7155355, 7185688, 7185688, 7185689, 7191589, 7244920, 7257535, 7257535, 7257799, 7257799, 7257800, 7257800, 7257801, 7257801, 7257802, 6952266, 6952267, 6952268, 6952281, 6952281, 6952282, 6952283, 6952283, 6952284, 6952284, 6952332, 6952334, 6952382, 6952411, 7005748, 7054621, 7257536, 7257799, 7257801, 6952269, 6952279, 6952281, 6952283, 6952285, 6952298, 6952308, 6952375, 7185689, 7257536, 7257803, 7257802, 6952284, 6952285, 6952289, 6952285, 6952317, 6952330, 6952331, 6952271, 6952283, 6952286, 6952286, 6952287, 6952290, 6952306, 6952309, 6952313, 6952314, 6952315, 6952318, 6952318, 6952320, 6952324, 6952324, 6952327, 6952328, 6952329, 6952329, 6952331, 6952331, 6952332, 6952333, 6952334, 6952338, 7185691, 6952276, 6952327, 6952354, 7257805, 6952296, 6952336, 6952341, 6952388, 7257810, 6952330, 7104997, 6952380, 7185702, 7257813, 7257814, 6952296, 7185703, 7257812, 6952295, 7257813, 6952356, 6952392, 6952296, 6952351, 6952296, 6952297, 8331825, 6952335, 6952374, 7257817, 6952353, 7257551, 6952425, 7257816, 7257818, 6952403, 7170567, 7185706, 7257552, 7257815, 7257818, 6952373, 6952384, 7542522, 6952331, 6952332, 7257818, 7257818, 6952325, 6952395, 7257820, 7257821, 6952313, 6952350, 6952352, 6952407, 7257820, 7257821, 6952360, 6952378, 6952369, 6952310, 6952350, 6952363, 6952319, 6952373, 6952358, 7257560, 6952380, 6952379, 6952381, 6952366, 6952384, 6952397, 6952374, 6952384, 6952373, 6952421, 6952371, 6952399, 6952407, 6952416, 6952353, 6952412, 6952368, 6952398, 6952418, 7257847, 6952361, 6952432, 6952402, 6952362, 6952413, 7257581, 7257847, 7257848, 6952367, 7257845, 6952367, 6952430, 6952379, 6952382, 6952389, 6952390, 6952428, 7185739, 7257850, 6952411, 7257854, 6952412, 7257854, 6952412, 6952419, 7029467, 7257591, 7185744, 6952451, 6952424, 6952383, 6952427, 7257859, 7257860, 6952387, 6952448, 6952388, 6952395, 6952387, 6952390, 6952395, 6952434, 6952438, 6952448, 11100995, 6952402, 7005808, 6952420, 6952433, 6952438, 7185752, 7257863, 6952457, 7257862, 7257863, 7257865, 6952410, 6952438, 6952449, 6952473, 7257863, 6952441, 7043027, 6952442, 6952445, 6952461, 6952462, 7185754, 7257864, 7257868, 6952462, 6952459, 7257867, 6952446, 6952412, 7257870, 6952453, 6952460, 6952424, 7257871, 7257872, 6952456, 6952439, 6952458, 6952440, 6952467, 6952460, 7257876, 6952421, 7257611, 6952466, 6952440, 6952465, 6952479, 6952463, 6952477, 6952455, 6952430, 6952458, 6952486, 6952507, 7029496, 6952444, 6952470, 6952500, 6952469, 6952503, 6952510, 6952466, 6952464, 7257887, 6952474, 6952497, 6952507, 7185779, 7257891, 7043049, 7257890, 7185779, 6952510, 6952515, 6952516, 6952457, 6952470, 6952494, 6952454, 7257628, 6952471, 6952503, 6952518, 6952516, 6952480, 6952521, 7257893, 7257895, 6952477, 6952521, 6952523, 6952498, 6952476, 6952524, 6952476, 6952510, 6952524, 6952476, 6952525, 6952526, 7257900, 6952526, 6952527, 7257903, 6952483, 6952527, 6952515, 6952528, 7185792, 7105740, 6952529, 6952530, 6952483, 6952493, 6952531, 6952532, 6952494, 7257907, 6952485, 6952534, 7257912, 6952530, 6952535, 6952491, 6952494, 6952492, 6952521, 6952491, 6952492, 6952494, 6952536, 7257914, 6952492, 6952493, 6952496, 6952531, 6952537, 6952538, 7257649, 6952538, 7029526, 11101047, 6952495, 6952500, 6952501, 6952538, 6952542, 6952500, 6952511, 6952518, 6952522, 6952538, 6952539, 6952539, 6952526, 6952540, 6952498, 6952540, 6952540, 6952541, 6952541, 6952541, 6952505, 6952542, 6952543, 6952543, 6952544, 7185807, 6952504, 6952507, 6952527, 6952544, 6952513, 6952541, 6952544, 6952545, 6952545, 7029533, 6952536, 6952545, 6952546, 6952546, 6952520, 6952520, 6952529, 6952546, 6952547, 7257924, 6952547, 7257923, 6952547, 6952548, 7257925, 7185812, 6952551, 7257924, 7185814, 6952522, 6952552, 7257929, 7257930, 6952532, 6952557, 7185819, 7257931, 7257931, 6952556, 7257934, 7257935, 6952559, 7257936, 6952560, 7257671, 7257938, 6952542, 6952548, 6952564, 6952564, 7257673, 6952567, 6952566, 6952567, 6952568, 6952569, 6952571, 7245064, 6952570, 6952570, 6952570, 6952571, 6952569, 6952572, 7185833, 6952570, 7257947, 7029564, 6952576, 7257954, 7185844, 7257952, 6952578, 7185842, 6952580, 6952582, 7257692, 6952582, 7257960, 6952584, 6952584, 6952586, 7054782, 7185847, 7185848, 7185848, 7185849, 7257694, 7257694, 7257957, 7257958, 7257958, 7257959, 7257959, 7257960, 7257960, 7257961, 7068054, 7257695, 7257958, 7257960, 6952586, 6952586, 7029574, 7054782, 7054783, 7068058, 7160143, 7160145, 7185848, 7185850, 7185850, 7191749, 7217470, 7257695, 7257957, 7257957, 7257958, 7257958, 7257959, 7257959, 7257960, 7257961, 7257961, 7257962, 7274988, 7005908, 7029572, 7185848, 7245080, 7245081, 7257959, 7257960, 7257961, 7257961, 11101950, 7185849, 7185850, 7257960, 7257960, 7257697, 7257697, 7257961, 7257695, 7257963, 7257964, 7059241, 7059242, 7059244, 7059246, 7311296, 7082910, 7311299, 7298325, 7311295, 7106574, 7106575, 7106576, 7106576, 7106576, 7106577, 7106577, 7106577, 7106578, 7106579, 7334963, 7334698, 7334961, 7334962, 7334963, 7256230, 7262853, 7262853, 7334699, 7334962, 7334963, 7334963, 7334964, 7334965, 7334965, 7133655, 7133699, 7133702, 7133743, 7276429, 7348539, 7348542, 7156994, 7156995, 7156996, 7156997, 7156998, 7359908, 7360172, 7360173, 7360174, 7183543, 7183546, 7373446, 7373447, 7373449, 7241055, 7402200, 7257718, 7410531, 7259018, 7411183, 7358458, 7460904, 7367717, 7367719, 7367720, 7367719, 7367721, 7367719, 7465532, 7465533, 7465536, 7465537, 7465538, 7388910, 7389014, 7389108, 7476256, 7405880, 7418403, 7419111, 7419126, 7419126, 7419127, 7419127, 7419126, 7419127, 7419127, 7419128, 7419129, 7419129, 7419128, 7419128, 7419129, 7419129, 7419130, 7419129, 7419134, 7419142, 7419142, 7490973, 7491236, 7491236, 7491238, 7491239, 7491240, 7490973, 7490974, 7491236, 7491236, 7491237, 7491238, 7491239, 7491240, 7491241, 7491241, 7459487, 7490973, 7490974, 7490975, 7491237, 7491238, 7491239, 7491239, 7491240, 7491240, 7491241, 7490975, 7491237, 7491238, 7491239, 7491239, 7491240, 7491241, 7491239, 7491241, 7491243, 7429935, 7429935, 7496644, 7496378, 7430925, 7430926, 7430925, 7496871, 7497137, 7497138, 7482364, 7482492, 7482620, 7522982, 7499847, 7531600, 7505877, 7505885, 7534615, 7534618, 7537400, 7537495, 7537587, 7537588, 7537590, 7550465, 7550467, 7550468, 7550469, 7550470, 7562817, 7562803, 7562804, 7562817, 7562819, 7562818, 7562818, 7562805, 7562805, 7562820, 7562820, 7562821, 7562806, 7562819, 7562820, 7562821, 7562821, 7562821, 7562822, 7562822, 7562824, 7563085, 7563007, 7563085, 7563085, 7562836, 7563085, 7563085, 7563086, 7562836, 7563007, 7563083, 7563084, 7563085, 7563085, 7563086, 7563086, 7563087, 7563087, 7563089, 7562837, 7563084, 7563085, 7563085, 7563086, 7563086, 7563087, 7563087, 7563089, 7563088, 7563088, 7563188, 7563190, 7563266, 7563268, 7563333, 7563330, 7563331, 7563331, 7563330, 7563331, 7563331, 7563334, 7563334, 7563332, 7563332, 7563333, 7563333, 7563334, 7563334, 7563335, 7563336, 7563333, 7563333, 7563334, 7563334, 7563335, 7563335, 7563333, 7563334, 7563334, 7563335, 7563335, 7563336, 7563336, 7563350, 7563334, 7563335, 7563335, 7563336, 7563336, 7563337, 7563337, 7563349, 7563351, 7563335, 7563336, 7563336, 7563337, 7563337, 7563338, 7563349, 7563351, 7563336, 7563337, 7563337, 7563338, 7563338, 7563350, 7563351, 7563352, 7563353, 7563354, 7563337, 7563338, 7563338, 7563351, 7563352, 7563352, 7563338, 7563339, 7563339, 7563340, 7563351, 7563352, 7563353, 7563353, 7563354, 7563354, 7563355, 7563356, 7563357, 7563339, 7563340, 7563340, 7563341, 7563351, 7563351, 7563352, 7563352, 7563353, 7563353, 7563354, 7563354, 7563355, 7563356, 7563357, 7563357, 7563358, 7563340, 7563341, 7563342, 7563351, 7563352, 7563352, 7563353, 7563353, 7563354, 7563354, 7563355, 7563355, 7563356, 7563356, 7563357, 7563358, 7563341, 7563342, 7563350, 7563351, 7563352, 7563352, 7563353, 7563353, 7563354, 7563354, 7563355, 7563355, 7563356, 7563356, 7563357, 7563357, 7563358, 7563358, 7563359, 7563342, 7563351, 7563352, 7563353, 7563353, 7563354, 7563354, 7563355, 7563355, 7563356, 7563356, 7563357, 7563357, 7563358, 7563359, 7563353, 7563355, 7563356, 7563354, 7563362, 7563363, 7563365, 7563367, 7563363, 7563365, 7563366, 7563366, 7563369, 7602426, 7563364, 7563365, 7563365, 7563366, 7563366, 7563367, 7563367, 7563368, 7563368, 7563370, 7943782, 8213347, 11406542, 7563365, 7563366, 7563366, 7563367, 7563367, 7563368, 7563366, 7563367, 7563367, 7563368, 7563368, 7563369, 7563369, 7563371, 7563371, 8637360, 7563367, 7563368, 7563368, 7563369, 7563369, 7563370, 7563370, 7563371, 7957061, 7563368, 7563369, 7563369, 7563370, 7563370, 7563371, 7563372, 7563372, 7777999, 7848056, 7848056, 7848057, 8213349, 8637234, 8637361, 7563369, 7563370, 7563370, 7563371, 7563372, 7563372, 7563373, 7602429, 7692358, 7848056, 7848057, 7848057, 7957062, 7958453, 8213495, 8337078, 8494495, 7563370, 7563371, 7563371, 7563372, 7563372, 7563373, 7563374, 7563374, 7602429, 7701579, 7741836, 7848057, 7848058, 7943784, 8637361, 9941102, 11406486, 7563371, 7563372, 7563372, 7563373, 7563373, 7563374, 7563374, 7602430, 7778001, 7848057, 7848058, 7848058, 7848059, 8213350, 8213351, 8637361, 8637363, 8637364, 9280365, 7563372, 7563373, 7563373, 7563374, 7563374, 7563375, 7701579, 7701580, 7720178, 7778001, 7848058, 7848058, 7848059, 7848060, 7943786, 8213351, 8418211, 8637362, 7563373, 7563374, 7563374, 7563375, 7563375, 7602431, 7701580, 7701580, 7701581, 7778002, 7778074, 7848058, 7848058, 7848059, 7848059, 7848060, 7868971, 7943786, 7943787, 8213351, 8213352, 8494497, 8494498, 8637236, 8637361, 8637362, 8637363, 8637363, 8637364, 7563374, 7563375, 7563375, 7563376, 7778002, 7848059, 7848059, 7848060, 8637362, 8637363, 7563375, 7563376, 7563376, 7563377, 7563377, 7602432, 7720182, 7778003, 7835398, 7848059, 7848060, 7848060, 7848061, 7848061, 7987649, 8213352, 8213354, 8247924, 8296272, 8337081, 8494499, 8576827, 8637237, 8637363, 8637363, 8637364, 8637365, 7563376, 7563377, 7602147, 7602432, 7611141, 7665561, 7701581, 7701582, 7760973, 7778003, 7778075, 7809058, 7848060, 7848060, 7848061, 7848061, 7848062, 7943787, 7943788, 8199937, 8213353, 8213353, 8213354, 8213497, 8450605, 8494499, 8494499, 8601037, 8637238, 8637362, 8637363, 8637365, 8637368, 8638847, 9257004, 9280368, 9280368, 7563377, 7602433, 7633015, 7701582, 7704739, 7720180, 7720183, 7720184, 7742821, 7778004, 7845811, 7848060, 7848061, 7848061, 7848062, 8036578, 8213353, 8213498, 8637238, 8637363, 8637365, 7563378, 7563379, 7572161, 7580361, 7602433, 7634957, 7665558, 7665562, 7701582, 7701583, 7720184, 7742821, 7778076, 7779029, 7785914, 7836167, 7836168, 7848060, 7848061, 7848061, 7848062, 7848062, 7848063, 7882715, 8072427, 8213354, 8213355, 8213497, 8296671, 8418213, 8637239, 8637365, 8637365, 8637366, 7778005, 7848062, 7848062, 7602434, 7848062, 7848063, 7580957, 7965859, 7597395, 7597430, 8230388, 7633829, 7640961, 7641028, 7641123, 7886969, 7641490, 7641500, 7641499, 7641500, 7641501, 7641501, 7641509, 7641510, 7641511, 7704629, 7704630, 7874466, 7887128, 7887128, 7887129, 7887129, 7982856, 8026717, 8169009, 8252421, 8312040, 8312042, 8533567, 8676431, 8676432, 8676437, 9226291, 9294231, 9393685, 7658915, 7658982, 7658983, 7659048, 7659050, 7895901, 7895902, 7670263, 7901541, 7702664, 11476188, 7706552, 7773177, 7767754, 7767758, 7767758, 7767760, 7950256, 8315549, 7950257, 8219429, 7821387, 7977086, 7839787, 7839800, 7839800, 7839801, 7839802, 7839802, 7839803, 7839800, 7839801, 7839803, 7839804, 7839801, 7839801, 7839804, 7986278, 7986279, 7985437, 7986279, 7986280, 8351716, 7986279, 7986280, 7916296, 7984035, 7986280, 7986281, 7986282, 7986282, 7986281, 7986282, 7839821, 7880066, 7986283, 7846117, 7989438, 7877001, 7877002, 7877004, 7877004, 7877009, 8004881, 8004881, 8004881, 8004881, 8004886, 7920321, 7920328, 8391835, 8026544, 7922266, 7922296, 7922298, 8027536, 7958646, 7958729, 7958804, 8045809, 7992640, 7992641, 7992641, 7992642, 7992714, 7992714, 7992715, 7992715, 7992716, 7992715, 7992716, 7992715, 7992716, 7992716, 7992787, 7992787, 7992787, 7992788, 7992789, 7992789, 7992789, 7992790, 7992790, 8062770, 8062771, 8062771, 8062772, 8328799, 8062772, 8062772, 8062773, 7994693, 8063725, 8008461, 8070608, 8054749, 8054847, 8054946, 8068476, 8082012, 8107386, 8107430, 8107496, 8120092, 8107635, 8107769, 8120291, 8108970, 8108971, 8120864, 8128258, 8128268, 8130507, 8130513, 8131071, 8131200, 8131328, 8132041, 8132743, 8132743, 8132744, 8132744, 8132744, 8132745, 8132745, 8132746, 8132758, 8132758, 8132759, 8132759, 8132760, 8132760, 8132745, 8132746, 8132746, 8132747, 8132759, 8132759, 8132760, 8132760, 8132761, 8132761, 8132746, 8132747, 8132759, 8132759, 8132760, 8132760, 8132761, 8132761, 8132747, 8132748, 8132748, 8132759, 8132760, 8132760, 8132761, 8132761, 8132762, 8132762, 8132748, 8132749, 8132755, 8132759, 8132760, 8132760, 8132761, 8132761, 8132762, 8132762, 8132763, 8132761, 8132762, 8132761, 8132765, 8133023, 8132772, 8132772, 8132772, 8132773, 8498051, 8132773, 8132774, 8132774, 8132775, 8132775, 8167409, 8498051, 8498052, 8922062, 8132774, 8132775, 8132775, 8132776, 8132776, 8183092, 8228486, 8228487, 8272350, 8493884, 8498052, 8498052, 8498053, 8498198, 8557671, 8921937, 8922063, 8922064, 8922067, 9149111, 9413475, 9565065, 10563211, 8132775, 8132776, 8132776, 8132777, 8185548, 8228487, 8228487, 8228488, 8272351, 8281231, 8281242, 8318935, 8318936, 8417532, 8493884, 8498052, 8498053, 8498053, 8498054, 8498198, 8557672, 8557714, 8557716, 8581367, 8690050, 8702911, 8779198, 8921937, 8922063, 8922063, 8922064, 8922064, 8922065, 8922065, 8922067, 9565065, 9565068, 11692045, 8132776, 8132777, 8132777, 8132778, 8135569, 8135571, 8167414, 8183093, 8190863, 8225699, 8228487, 8228488, 8228488, 8228489, 8243157, 8272350, 8272350, 8272351, 8272351, 8281238, 8398788, 8474889, 8493883, 8493884, 8498052, 8498053, 8498053, 8498054, 8498058, 8498197, 8498198, 8574172, 8621782, 8702912, 8779199, 8921938, 8922063, 8922064, 8922065, 8922065, 8922066, 10563213, 8132777, 8132778, 8132779, 8132780, 8162016, 8167414, 8183093, 8187179, 8196522, 8225699, 8228488, 8228488, 8228489, 8241763, 8272351, 8272351, 8318934, 8334973, 8474882, 8483266, 8493880, 8494738, 8497680, 8498052, 8498053, 8498053, 8498054, 8532625, 8557673, 8581370, 8621782, 8662644, 8702912, 8779199, 8779199, 8779200, 8921938, 8922062, 8922063, 8922064, 8922064, 8132778, 8135572, 8167416, 8183094, 8212748, 8228488, 8228489, 8241767, 8272350, 8272352, 8272354, 8398789, 8493884, 8493884, 8498054, 8498054, 8498055, 8498057, 8574176, 8702913, 8779199, 8779200, 8921938, 8921939, 8922063, 8922065, 8922065, 8220986, 8220987, 8228489, 8228490, 8498054, 8498055, 8498055, 8779200, 8921939, 8922065, 8922066, 8922068, 8498057, 8133279, 8133289, 8557934, 8138375, 8138379, 8500859, 8231296, 8500861, 8174640, 8943031, 8191268, 8271013, 8202060, 8202065, 8202066, 8202066, 8202067, 8202069, 8202067, 8956713, 8202136, 8956715, 8956590, 8263140, 8532706, 8263143, 8202203, 8532771, 8233419, 8233420, 8233422, 8233424, 8233552, 8233553, 8233552, 8753241, 8278819, 8233682, 8233684, 8544343, 8548512, 8548513, 8238336, 8550841, 8241652, 8241751, 8241850, 8326922, 8248962, 8556152, 8260284, 8260281, 9628826, 8561961, 8292734, 8578040, 8309206, 8309206, 8309290, 8837659, 8309373, 8582186, 8318635, 8318637, 8590989, 8321425, 8324200, 8324209, 8324210, 8324211, 8324212, 8324212, 8324213, 8324213, 8324214, 8324210, 8324212, 8324213, 8324210, 8324211, 8324212, 8324213, 8324214, 8324215, 8324220, 8324222, 8324308, 8324309, 8324312, 8324308, 8324309, 8324225, 8324310, 8338880, 8368075, 8414660, 8589608, 8593777, 8593777, 8593924, 8653396, 8677091, 8593404, 8593777, 8593778, 8414661, 8593778, 8669900, 8593778, 8653398, 8368076, 8593779, 9017790, 8324406, 8324397, 8324407, 8324407, 8324414, 8593873, 8593874, 8653497, 9017758, 9418443, 8758467, 8350760, 8350762, 8350763, 8350766, 8607052, 9030937, 8381348, 8607053, 9031064, 9031065, 8353549, 8353550, 8353551, 8577202, 8608446, 8411932, 8411934, 8411937, 8411936, 8411937, 8411937, 8411937, 8411937, 8411938, 8411939, 8411938, 8411939, 8411942, 8458520, 8637638, 8426008, 8637639, 9061650, 8420829, 8637640, 8637641, 8918786, 8521059, 8637640, 8637641, 8637642, 8637640, 8429705, 8429726, 8429719, 8646526, 8646530, 8646531, 8646541, 8440080, 8472595, 8505107, 8505108, 8505108, 8505110, 8505108, 8505109, 8505110, 9108235, 9108236, 8637282, 8684225, 9108110, 8767540, 8600815, 8684229, 8509792, 8686568, 8537183, 8700264, 8581513, 8782104, 8630183, 9170649, 8664809, 8664810, 8664891, 8664893, 8664894, 8664975, 8664977, 8664977, 8764158, 8764159, 8764159, 8671101, 8767222, 8696516, 8779928, 8702304, 8782824, 8769455, 8816398, 8800880, 8800955, 8801029, 8832198, 8817010, 8817015, 8817017, 9121325, 8840181, 8840182, 8833767, 8848555, 8836513, 9273940, 8855001, 8855004, 8855005, 8855005, 8855004, 8855006, 8855007, 8855008, 8855007, 8859173, 8859174, 8918797, 9283059, 8859172, 8859175, 8859176, 8859176, 8856715, 8860030, 8862599, 8862972, 8863118, 8863327, 8863329, 8863341, 8863341, 8863330, 8863331, 8863331, 8863332, 8863332, 8863339, 8863340, 8863340, 8863341, 8863341, 8863342, 8863342, 8863343, 8863343, 8863344, 8863348, 8863331, 8863332, 8863332, 8863333, 8863340, 8863340, 8863341, 8863342, 8863342, 8863343, 8863344, 8863344, 8863345, 8863346, 8863349, 8863332, 8863333, 8863333, 8863340, 8863341, 8863341, 8863342, 8863343, 8863343, 8863344, 8863344, 8863345, 8863333, 8863341, 8863341, 8863342, 8863342, 8863343, 8863343, 8863344, 8863348, 8863334, 8863342, 8863342, 8863344, 8863342, 8863343, 8863348, 8863357, 8863349, 8863350, 8863351, 8863352, 8863479, 8863484, 8863485, 8863485, 8863350, 8863351, 8863351, 8863352, 8863352, 8863354, 8863359, 8863484, 8863484, 8863485, 8863486, 8863486, 8863487, 8863488, 8863488, 8863351, 8863352, 8863352, 8863353, 8863353, 8863354, 8863354, 8863355, 8863355, 8863483, 8863484, 8863485, 8863485, 8863486, 8863486, 8863487, 8863487, 8863488, 8863488, 8863489, 8863352, 8863353, 8863353, 8863354, 8863355, 8863356, 8863357, 8863359, 8863486, 8863486, 8863487, 8863353, 8863354, 8863355, 8863483, 8863486, 8863486, 8863487, 8863487, 8863488, 8863488, 8863489, 8863354, 8863355, 8863355, 8863356, 8863356, 8863357, 8863360, 8863486, 8863486, 8863487, 8863487, 8863488, 8863488, 8863489, 8863489, 8863490, 8863491, 8863355, 8863356, 8863356, 8863357, 8863358, 8863486, 8863487, 8863487, 8863488, 8863488, 8863489, 8863489, 8863490, 8863490, 8863491, 9068201, 9287353, 8863356, 8863357, 8863357, 8863487, 8863488, 8863488, 8863489, 8863490, 8863491, 8863357, 8863358, 8863358, 8863359, 8863487, 8863488, 8863488, 8863489, 8863489, 8863490, 8863493, 9144489, 8863358, 8863361, 8863487, 8863488, 8863489, 8863489, 8863490, 9287355, 8863360, 8863360, 8863361, 8863361, 8863489, 8863489, 8863490, 8863491, 8863491, 8863493, 8863490, 8863490, 8863491, 8863493, 8863489, 8863490, 8863491, 8863492, 8863492, 8863493, 9287230, 8863491, 8863489, 8863492, 8863494, 8863492, 8863492, 8863367, 9287358, 8863492, 8863493, 8863494, 8863494, 8863497, 9144497, 8863619, 8863618, 8863617, 8863617, 8863619, 8863631, 8863618, 8863619, 8863619, 8863620, 8863622, 8863633, 8863619, 8863620, 8863620, 8863621, 8863621, 8863622, 8863634, 8863620, 8863621, 8863621, 8863622, 8863622, 8863623, 8863623, 8863633, 8863633, 8863634, 8863634, 8863621, 8863622, 8863622, 8863623, 8863623, 8863624, 8863624, 8863625, 8863632, 8863633, 8863633, 8863634, 8863634, 8863635, 8863622, 8863623, 8863623, 8863624, 8863624, 8863625, 8863633, 8863634, 8863634, 8863635, 8863635, 8863623, 8863624, 8863624, 8863625, 8863634, 8863634, 8863635, 8863636, 8863624, 8863625, 8863625, 8863626, 8863633, 8863633, 8863634, 8863634, 8863635, 8863635, 8863636, 8863636, 8863625, 8863626, 8863626, 8863635, 8863635, 8863636, 8863636, 8863637, 8863626, 8863627, 8863627, 8863628, 8863634, 8863634, 8863635, 8863635, 8863636, 8863636, 8863637, 8863637, 8863627, 8863628, 8863628, 8863635, 8863636, 8863636, 8863637, 8863637, 8863638, 8863628, 8863629, 8863635, 8863636, 8863636, 8863637, 8863637, 8863638, 8863638, 8863629, 8863636, 8863637, 8863637, 8863638, 8863638, 8863639, 8863636, 8863637, 8863638, 8863639, 9287365, 8863644, 8863645, 8863644, 8863645, 8863645, 8863644, 8863645, 8863645, 8863646, 8863646, 9068346, 8863645, 8863646, 8863646, 8863647, 8898059, 8923008, 8939611, 8946805, 9144633, 9144634, 9287372, 9287496, 9287498, 9287498, 9287499, 9287500, 8863646, 8863647, 8863647, 9068347, 9287499, 8863647, 8863648, 8898060, 8923150, 9144634, 9287373, 9907140, 9930503, 8863648, 8863649, 8898061, 8923108, 8923109, 8987218, 9028079, 9068348, 9076642, 9144634, 9144635, 9144635, 9287374, 9287498, 9287499, 9287500, 9287502, 9287503, 9287505, 9523846, 9930502, 9930504, 12056675, 12057481, 8863649, 8874139, 8877446, 8898061, 8923010, 8923011, 8923109, 8923109, 8923110, 8923110, 8923150, 8923151, 8923151, 8939612, 8946801, 8946803, 8946804, 8946804, 8946805, 8987218, 8987220, 8987240, 8992689, 9028080, 9055475, 9068348, 9072921, 9100743, 9144633, 9144634, 9144634, 9144635, 9144635, 9144636, 9165278, 9251170, 9251173, 9287374, 9287374, 9287498, 9287499, 9287500, 9287500, 9287501, 9287501, 9287502, 9287506, 9394972, 9579040, 9778911, 9930501, 9930504, 10017650, 10928650, 11571640, 12056675, 8923109, 8923112, 8932507, 9068349, 9068349, 9287375, 9287500, 8884643, 9941009, 8891253, 8891335, 8891416, 8936997, 8932485, 8957573, 8957574, 9102772, 9179060, 9321798, 9321798, 9321921, 9321924, 8982383, 8982382, 8982383, 8982384, 8982524, 8982525, 8982526, 8982527, 8982579, 8982580, 8982580, 8982581, 8982581, 8982582, 8982582, 8982583, 8982589, 8982570, 8982583, 8982583, 8982584, 8982595, 8982590, 8982589, 9127819, 9204106, 8982623, 9346971, 8982592, 8982598, 8982625, 9127820, 9183296, 8982593, 8982624, 9204107, 9346973, 8982595, 8982595, 8982601, 8982624, 8982625, 9006275, 9046691, 9346973, 8982624, 8982625, 8982623, 8982624, 8982625, 8982625, 8982626, 9204109, 11631112, 8982626, 9204109, 9204110, 8982630, 9204113, 9114955, 9989984, 9346983, 8982663, 8982661, 8982664, 8982664, 8982654, 8982665, 8982665, 8982655, 8982666, 8982657, 8982666, 8982666, 8982667, 8982673, 8982674, 9006319, 8999126, 9127862, 9114989, 9127862, 9160257, 9160258, 9164306, 9257672, 9346888, 9347013, 9347014, 9347014, 9347015, 9347019, 9347020, 9493397, 9574061, 9990015, 10424265, 10500593, 10988164, 11785105, 9347021, 9347020, 9001380, 9137222, 9015585, 9015590, 9015590, 9015592, 9363475, 9144326, 9327151, 9363479, 9144327, 9220614, 9723161, 9029182, 9370273, 9029971, 9029971, 9029970, 9029970, 9029973, 9029974, 9029975, 9029976, 9029976, 9029979, 9029981, 9029980, 9370541, 9227803, 9227805, 9370544, 9370670, 9151519, 9370545, 9151520, 9370546, 9134839, 9151521, 9370547, 9151522, 9110789, 9110824, 9110826, 9110862, 9110827, 9110831, 9110850, 9179081, 9411106, 9411107, 9116296, 9411107, 9110903, 9110904, 9110976, 9110978, 9111066, 9111097, 9411058, 9411186, 9111270, 9111329, 9268484, 9411375, 9121741, 9121741, 9121742, 9197400, 9197401, 9416428, 9192523, 9192523, 9192524, 9192525, 9192526, 9451817, 12221119, 9232792, 9451819, 9232794, 9415619, 9239697, 9332666, 9247323, 9247324, 9247336, 9260197, 9312398, 9479349, 9479350, 9776062, 9273048, 9273049, 9273059, 9273060, 9273061, 9273062, 9273062, 9273063, 9273063, 9273066, 9273068, 9273063, 9273064, 9273069, 9273065, 9342570, 9492085, 9492211, 9273074, 9349346, 9349347, 9492086, 9492086, 9492212, 10135215, 9273075, 9273076, 9273076, 9273077, 9349348, 9492087, 9492213, 9492213, 9492215, 9273077, 9273077, 9273079, 9349348, 9349349, 9492088, 9492213, 9492215, 9273077, 9349349, 9492214, 9492214, 9273078, 9273081, 9349349, 9349349, 9349350, 9349350, 9492089, 9492213, 9492214, 9492215, 9273080, 9273081, 9303550, 9349351, 9455888, 9492089, 9492089, 9492093, 9492215, 9492215, 9635535, 9492091, 9349352, 9492216, 9492217, 9492218, 9492094, 9492220, 9282204, 9353919, 9289649, 9500506, 9334034, 9522699, 9337848, 9337849, 9337850, 9337850, 9381741, 9524481, 9524607, 9345948, 9528658, 9366110, 9538735, 9377463, 9544414, 9384013, 9547563, 9412098, 9561613, 9425635, 9425620, 9425634, 9425635, 9425620, 9425633, 9425633, 9425635, 9425635, 9425636, 9425621, 9425622, 9425635, 9425636, 9425636, 9425637, 9425622, 9425623, 9425633, 9425634, 9425634, 9425637, 9425637, 9425635, 9425637, 9425638, 9425638, 10211503, 9568373, 9568498, 9568373, 9568498, 9425650, 9568374, 9425651, 9479156, 9568375, 9568501, 9479158, 9568375, 9568375, 9568501, 9568502, 9425652, 9568376, 9568501, 9568502, 9568503, 9714883, 9479158, 9532175, 9568376, 9568376, 9568501, 9568502, 9568502, 9568503, 9568504, 9586923, 9945025, 10211506, 11629279, 13913992, 9466924, 9589020, 9532676, 9532676, 9532678, 9532679, 9622020, 9622021, 9622021, 9621896, 9590322, 9650860, 9638706, 9638709, 9638709, 9674910, 9675036, 9675036, 9675041, 9711099, 9711108, 9711109, 9711111, 9711112, 9711100, 9711109, 9711110, 9711110, 9711111, 9711111, 9711112, 9711112, 9711113, 9711110, 9711117, 9711235, 9711119, 9711120, 9711121, 9711121, 9711122, 9711123, 9711233, 9711233, 9711234, 9711234, 9711235, 9711235, 9711236, 9711236, 9711237, 9711240, 9711241, 9711242, 9711242, 9711121, 9711121, 9711122, 9711122, 9711123, 9711125, 9711234, 9711235, 9711235, 9711236, 9711236, 9711237, 9711237, 9711238, 9711239, 9711242, 9711236, 9711237, 9711235, 9711236, 9711237, 9711123, 9711124, 9711236, 9711237, 9711237, 9711239, 9711240, 9711124, 9711125, 9711235, 9711236, 9711236, 9711237, 9711237, 9711238, 9711238, 9711243, 9711236, 9711237, 9711237, 9711238, 9711238, 9711240, 9711241, 9711238, 9711238, 9711239, 9711239, 9711242, 9711243, 9711348, 9711349, 9711348, 9711349, 9711350, 9711350, 9711350, 9711351, 9711352, 9711356, 9711364, 9711350, 9711351, 9711351, 9711352, 9711353, 9711365, 9711351, 9711352, 9711352, 9711353, 9711354, 9711354, 9711355, 9711356, 9711356, 9711357, 9711358, 9711366, 9711367, 9711368, 9711369, 9711369, 9711352, 9711353, 9711353, 9711354, 9711354, 9711355, 9711355, 9711356, 9711356, 9711357, 9711357, 9711358, 9711358, 9711359, 9711359, 9711360, 9711361, 9711365, 9711366, 9711367, 9711367, 9711368, 9711368, 9711369, 9711369, 9711370, 9711372, 9711353, 9711354, 9711354, 9711355, 9711356, 9711357, 9711357, 9711358, 9711358, 9711359, 9711362, 9711364, 9711364, 9711366, 9711368, 9711368, 9711372, 9711373, 9711354, 9711355, 9711355, 9711356, 9711356, 9711357, 9711357, 9711358, 9711358, 9711359, 9711362, 9711365, 9711367, 9711368, 9711368, 9711369, 9711369, 9711355, 9711356, 9711356, 9711357, 9711357, 9711358, 9711358, 9711359, 9711359, 9711360, 9711360, 9711363, 9711364, 9711366, 9711367, 9711368, 9711368, 9711369, 9711369, 9711370, 9711370, 9711371, 9711373, 9711374, 9711356, 9711357, 9711357, 9711358, 9711358, 9711359, 9711359, 9711369, 9711357, 9711358, 9711358, 9711359, 9711359, 9711360, 9711369, 9711370, 9711371, 9711375, 9711375, 9711358, 9711359, 9711359, 9711360, 9711360, 9711361, 9711361, 9711362, 9711363, 9711369, 9711370, 9711371, 9711371, 9711372, 9711375, 9711376, 9711359, 9711360, 9711360, 9711361, 9711361, 9711362, 9711362, 9711366, 9711370, 9711371, 9711371, 9711372, 9711374, 9711375, 9711376, 9711376, 9711360, 9711361, 9711361, 9711362, 9711362, 9711364, 9711370, 9711371, 9711371, 9711372, 9711372, 9711373, 9711374, 9711376, 9711377, 9711361, 9711362, 9711362, 9711363, 9711363, 9711364, 9711364, 9711372, 9711372, 9711373, 9711376, 9711377, 9711377, 9711362, 9711363, 9711363, 9711364, 9711364, 9711367, 9711371, 9711372, 9711372, 9711373, 9711374, 9711375, 9711376, 9711377, 9711377, 9711378, 9711363, 9711364, 9711364, 9711365, 9711366, 9711366, 9711369, 9711370, 9711371, 9711371, 9711372, 9711372, 9711373, 9711373, 9711374, 9711374, 9711375, 9711375, 9711376, 9711377, 9711377, 9711378, 9711378, 9711364, 9711365, 9711365, 9711366, 9711367, 9711368, 9711370, 9711371, 9711372, 9711373, 9711373, 9711374, 9711374, 9711375, 9711375, 9711376, 9711377, 9711378, 9711378, 9711379, 9711365, 9711366, 9711367, 9711369, 9711371, 9711371, 9711372, 9711372, 9711373, 9711373, 9711374, 9711374, 9711375, 9711376, 9711378, 9711378, 9711379, 9711366, 9711367, 9711367, 9711369, 9711372, 9711373, 9711374, 9711374, 9711375, 9711377, 9711378, 9711379, 9711367, 9711372, 9711374, 9711375, 9711380, 9711368, 9711369, 9711373, 9711374, 9711375, 9711375, 9711380, 9711371, 9711374, 9711375, 9711375, 9711376, 9711376, 9711371, 9711375, 9711376, 9711381, 9711377, 9711377, 9711372, 9711373, 9711375, 9711376, 11352512, 9711378, 10864941, 9711377, 9711378, 9711378, 9711379, 9711380, 9711379, 9711380, 9711377, 9711380, 9711380, 9711381, 9711385, 9711380, 9711380, 9711382, 9711379, 9711380, 9711380, 9711381, 9711381, 9711385, 9711386, 10354369, 9711381, 9711381, 9711383, 9711385, 10557058, 9711381, 9711382, 9711382, 9711383, 9711386, 9711387, 9857750, 10002905, 9711382, 9711383, 9711383, 9711384, 9711384, 9711385, 9711386, 9711387, 9711387, 9711388, 10354371, 9711383, 9711384, 9711384, 9711385, 9711385, 9711386, 9711387, 9711387, 9711388, 9711388, 9719597, 9829193, 9857748, 9938414, 9938416, 10091252, 10354371, 10354372, 10698863, 10788618, 10865483, 10865484, 11139843, 12480493, 9711384, 9711385, 9711385, 9711386, 9711386, 9711387, 9711387, 9711388, 9711388, 9711389, 9719600, 9938415, 9938416, 10091907, 10111927, 10146549, 10331007, 10354371, 10354372, 10429230, 10788618, 10865483, 11352515, 11995506, 9711385, 9711386, 9711386, 9711387, 9711388, 9711388, 9711389, 9711389, 9719601, 9938416, 10354371, 10354372, 10354373, 10816846, 9711386, 9711387, 9711387, 9711388, 9711388, 9711389, 9711389, 9711390, 9711390, 9884371, 9938416, 9947714, 10087892, 10354370, 10354373, 9711387, 9711388, 9711388, 9711389, 9711389, 9711390, 9711390, 9711391, 9719601, 9995813, 10354372, 10354373, 11928798, 11995507, 9711388, 9711389, 9711390, 9711390, 9711391, 9711391, 9719601, 9938417, 10354373, 9711390, 9711390, 9711391, 9711391, 9711392, 9766146, 9819273, 9938417, 9947715, 9995814, 10154150, 10261734, 10331011, 9711390, 9711391, 9711391, 9711392, 9711391, 9711392, 9711392, 9711392, 9711393, 9995816, 10354376, 11995511, 12480497, 9711393, 9711394, 9719603, 9719605, 9766240, 9776229, 9787589, 9787908, 9829197, 9857754, 9947717, 9969029, 9995816, 10007622, 10008087, 10087895, 10087895, 10091911, 10111931, 10111932, 10154152, 10154156, 10202783, 10202785, 10202870, 10260180, 10328950, 10331007, 10331011, 10331013, 10354374, 10354375, 10354375, 10354376, 10354376, 10354377, 10373474, 10526692, 10537232, 10579512, 10698868, 10865489, 10865491, 11352521, 11352522, 11352522, 11772153, 11995510, 12480498, 9711394, 9711396, 9719603, 9719604, 9719605, 9719606, 9719611, 9722896, 9729793, 9766147, 9766242, 9766243, 9787889, 9829198, 9854693, 9857753, 9872645, 9883787, 9929310, 9938420, 9938420, 9947718, 9947718, 9947719, 9969029, 9982742, 9995817, 10006409, 10006409, 10007622, 10037196, 10050257, 10087894, 10087895, 10091912, 10091913, 10091914, 10111932, 10111932, 10113146, 10146554, 10154152, 10154157, 10202781, 10202782, 10202784, 10202784, 10202785, 10202893, 10249455, 10261231, 10305584, 10331010, 10331011, 10331013, 10335433, 10354374, 10354375, 10354375, 10354376, 10354376, 10354377, 10354377, 10402203, 10537233, 10698868, 10742250, 10865489, 11064801, 11199087, 11225694, 11352521, 11352522, 11352522, 11683583, 11761708, 11776364, 11776365, 11995511, 12480498, 12480539, 12480548, 12480552, 12481354, 9711649, 9719604, 9719605, 9719605, 9766242, 9766244, 9773342, 9776230, 9787578, 9829198, 9933763, 9938420, 9938421, 9947718, 9962491, 9995818, 10007622, 10008087, 10034694, 10087896, 10111932, 10111932, 10154153, 10154154, 10202781, 10202782, 10202784, 10202842, 10260181, 10261234, 10331013, 10331014, 10345684, 10354375, 10354376, 10354376, 10354377, 10354377, 10354378, 10642010, 10698869, 10788624, 11166826, 11225695, 11352522, 11352522, 12480499, 12480548, 9719607, 9711915, 9872912, 9714329, 9714403, 9714475, 10262776, 9727824, 9727828, 9727829, 9727830, 9727830, 9727830, 9727831, 9727832, 9727833, 9727833, 9727839, 9774407, 9955943, 10362602, 9955943, 10179926, 10339239, 10873714, 10162378, 10211007, 10362602, 10362603, 10362603, 9946647, 10014636, 10100140, 10362604, 10362602, 10120160, 9734411, 10365891, 9748214, 9748215, 9748236, 10372795, 10372797, 9820910, 9820912, 9821006, 9821008, 9820987, 9821045, 9821102, 9821102, 9821103, 9821112, 9821102, 9821104, 9821113, 9821103, 9821104, 10385871, 10409236, 10144788, 12535409, 10409239, 10409239, 10166801, 10664101, 9835301, 10009677, 9841091, 9841111, 9841117, 10395873, 10395894, 10419265, 9863835, 9863856, 9864107, 9864116, 9864381, 9864385, 9864420, 9864421, 9864440, 10024249, 10039024, 10430907, 10505771, 9926309, 10438478, 9927172, 9927177, 10368078, 10462279, 9947011, 9947012, 9947012, 9947013, 9947138, 9947139, 9947139, 9947265, 10056360, 10086970, 10472317, 9998007, 9998006, 10497688, 10497690, 10004128, 10004129, 10004130, 10004130, 10004131, 10475547, 10094094, 10349160, 10500750, 10500752, 10033906, 10033981, 10034047, 10109045, 10162572, 10056194, 10260303, 10057368, 10057450, 10057533, 10527451, 10147235, 10147373, 10147511, 10549077, 10156142, 10170098, 10165446, 10165458, 10165459, 10165459, 10165459, 10165459, 10165460, 10165459, 10165460, 10165460, 10165471, 10264239, 10429824, 10486701, 10581415, 11328504, 10165472, 10174757, 10189530, 10229951, 10235125, 10318296, 10338968, 10338971, 10558049, 10558052, 10581414, 10581415, 10581415, 10581416, 10764277, 12222551, 10338971, 10338972, 10401770, 10581414, 10581416, 10581417, 10184042, 10184054, 10184054, 10184055, 10184055, 10184057, 10184055, 10184056, 10567348, 10590713, 11588859, 10243958, 10243959, 10275650, 10348269, 10348269, 10467044, 10565372, 10590712, 10590713, 10590713, 10590714, 10935205, 11549990, 11852231, 10205367, 10590714, 10590716, 10213602, 10213603, 10213607, 10605487, 10605487, 10605490, 10226680, 10226681, 10226682, 10226684, 10612026, 10588664, 10612028, 11610175, 10370801, 10254106, 10254165, 10254221, 11136910, 10280249, 10280250, 10280251, 10280253, 10280351, 10280352, 10280352, 10280353, 10280353, 10280352, 10280354, 10638811, 10280455, 10280456, 10280456, 10280457, 10280457, 10396465, 10638913, 10290198, 10436110, 10487322, 10544718, 10545768, 10372432, 10291111, 10401798, 10294442, 10294447, 10294447, 10645907, 10674392, 10362591, 10299944, 10648659, 10301439, 10301438, 10497888, 10649405, 10649407, 10303870, 10303865, 10303873, 10303865, 10303868, 10408175, 10650620, 11648767, 12291759, 10650628, 10304794, 10304794, 10304797, 10304800, 10651082, 10346961, 10443264, 12777210, 10358005, 10411207, 10363011, 10363021, 10680191, 10680198, 10367243, 10682306, 10389128, 10389132, 10493028, 10688438, 10430731, 10430731, 10451587, 11225166, 10464397, 10464412, 10464412, 10464413, 10464413, 10730893, 10488450, 10523071, 10530672, 10530674, 10579298, 10579300, 10730892, 10730894, 11242007, 10468474, 10490478, 10471133, 10471133, 10734252, 10471224, 10471312, 10734339, 10472445, 10472447, 10472447, 10472446, 10472447, 10583318, 10734909, 10734910, 10492466, 10734912, 10512481, 10512481, 10512485, 10512471, 10512483, 10512484, 10512484, 10512485, 10512485, 10512486, 10512486, 10512487, 10512484, 10512484, 10512486, 10512486, 10512487, 10512488, 10512489, 10512486, 10512487, 10754926, 10754928, 10661782, 10692042, 10754929, 10754928, 10754929, 10512503, 10603335, 10731565, 10731566, 10754930, 10603336, 10603337, 10754929, 10754929, 10754930, 11753075, 12881101, 10661785, 10731562, 10754930, 10754931, 10754931, 10754932, 10654672, 10754933, 11753078, 10750116, 10754932, 10514911, 10514911, 12214654, 10756142, 10581723, 10581726, 10581726, 10581835, 10637953, 10695353, 10789549, 10789548, 10581948, 10589436, 10591766, 10794568, 10596913, 10596922, 10596926, 10596926, 10596926, 10596928, 10596916, 10596929, 10596930, 10596933, 10596933, 10797147, 10797149, 10797148, 10797150, 10797150, 10797151, 10645556, 10596944, 10797151, 10797152, 10797153, 10999841, 10632018, 10814694, 10638088, 10794369, 10694168, 10694183, 10694186, 10694193, 10694173, 10694194, 10694196, 10694191, 10694193, 10694194, 10694195, 10694242, 10694190, 10694193, 10694194, 10694198, 10694201, 10694249, 10694191, 10694190, 10694252, 10751582, 10694229, 10726525, 11843928, 10845783, 10845786, 12467083, 12045604, 10845788, 10822426, 10845790, 10845788, 10845790, 10845792, 10845794, 10694292, 10694357, 10845836, 10694374, 10845842, 10822480, 10845842, 10845842, 10845844, 11028700, 11843989, 10694387, 10694409, 10845892, 10822529, 11028751, 10845891, 10750034, 10873704, 10758860, 10878118, 10787580, 10787655, 10787726, 10892572, 11147428, 10796867, 10796932, 10796988, 10897183, 10807940, 10808063, 10808186, 10902778, 10808979, 10808982, 10808982, 10808980, 10808981, 10903174, 10903176, 10903175, 10903177, 10903177, 10903178, 10879815, 10811082, 10811083, 10811084, 10811085, 10811086, 10904227, 10880859, 10904229, 10904229, 11087085, 11902374, 11902374, 10812091, 11482498, 10871608, 10871656, 10871735, 10871792, 10911215, 10899787, 12473175, 10946583, 10946740, 10946749, 10946825, 10946897, 10946828, 10946901, 10946951, 10946952, 10946962, 10946961, 10946971, 10946972, 10972166, 10972166, 11406413, 10950640, 10950639, 10950641, 10950643, 10950644, 10950645, 10950631, 10950645, 10950646, 10950646, 10950646, 10950646, 10950647, 10950647, 10950647, 10974008, 10974009, 10974010, 11302147, 11485122, 10974008, 10974008, 10974009, 10974009, 10974010, 10974010, 11846822, 11972155, 10959497, 10978439, 10979986, 10988680, 10987742, 10987746, 10992559, 10992560, 10997355, 10997355, 10997356, 10997357, 10997370, 10997356, 10997357, 10997357, 10997358, 10997371, 10997371, 10997372, 10997372, 10997373, 10997373, 10997357, 10997358, 10997358, 10997372, 10997373, 10997374, 10997358, 10997359, 10997359, 10997372, 10997372, 10997373, 10997373, 10997374, 10997374, 10997359, 10997360, 10997373, 10997374, 10997375, 10997360, 10997361, 10997372, 10997373, 10997373, 10997374, 10997374, 10997375, 10997375, 10997372, 10997373, 10997373, 10997374, 10997374, 10997375, 10997375, 10997376, 10997376, 10997387, 10997385, 10997387, 10997388, 11995518, 10997386, 10997387, 10997387, 10997388, 10997388, 11180231, 11995518, 10997387, 10997388, 10997388, 10997389, 11356516, 11459847, 11508479, 11868691, 11995518, 10997388, 10997389, 10997389, 11459848, 11508486, 11508486, 11508489, 11548927, 11868691, 11995519, 13123495, 10997389, 10997390, 11016472, 11045204, 11180230, 11431621, 11868692, 11995519, 11995519, 12236628, 12258892, 13123496, 13123545, 10997390, 11015233, 11016473, 11025856, 11072231, 11072232, 11072233, 11072234, 11084520, 11180231, 11180231, 11180232, 11180232, 11180233, 11252229, 11341865, 11341866, 11356614, 11431621, 11441497, 11459849, 11505397, 11508483, 11508483, 11508485, 11508485, 11508487, 11508488, 11508488, 11508489, 11508490, 11605416, 11749445, 11868692, 11995518, 11995519, 11995520, 11995520, 11995521, 11996146, 12041172, 12246062, 12415152, 12419363, 12571799, 12638509, 12638510, 12751284, 13123496, 13123546, 11016471, 11016473, 11016519, 11025853, 11025854, 11025856, 11025856, 11025857, 11038033, 11062225, 11071621, 11072229, 11072232, 11072233, 11072233, 11072234, 11072234, 11072235, 11072235, 11072236, 11072237, 11084522, 11133967, 11169693, 11180231, 11180232, 11180232, 11180233, 11180234, 11180235, 11183991, 11200064, 11252230, 11252230, 11252231, 11252232, 11252232, 11253089, 11278910, 11286470, 11341864, 11341866, 11341867, 11417730, 11431621, 11431622, 11431622, 11459849, 11465452, 11508480, 11508481, 11508482, 11508483, 11508484, 11508485, 11508486, 11508486, 11508487, 11508487, 11508488, 11508488, 11508489, 11508489, 11508490, 11508490, 11508491, 11520664, 11544295, 11575142, 11640112, 11661271, 11675480, 11744464, 11787287, 11864166, 11868693, 11868693, 11958525, 11995518, 11995519, 11995519, 11995520, 11995520, 11995521, 11995521, 11995522, 12041174, 12258893, 12419363, 12419364, 12638510, 12638510, 13123497, 13123544, 13123546, 13123546, 13124353, 11033091, 12013378, 11035626, 11035619, 11035629, 11035674, 11035692, 11035709, 11035767, 11527646, 12014676, 11035774, 11077590, 11103743, 11112762, 11199454, 11199455, 11361088, 11479070, 11527702, 11054331, 11054332, 11054334, 11054334, 11054335, 11054335, 11100713, 11208711, 11228542, 11370341, 11370344, 11370345, 11460100, 12023997, 12023998, 12023998, 12154193, 13151974, 11078687, 11220886, 11093028, 11093032, 11120059, 11916519, 11119358, 11119472, 11119585, 11241334, 11127073, 11722960, 11145865, 11145868, 11145890, 11254477, 11416109, 11145913, 12069786, 11147088, 11147089, 11147091, 11147076, 11147092, 11147077, 11147092, 11147093, 11147077, 11147092, 11147093, 11147094, 11147094, 11147095, 11147095, 11147095, 11147096, 11147097, 11147098, 11416726, 11583339, 11255090, 11327091, 11871280, 12070380, 11244551, 11255091, 11255092, 11361330, 11416727, 11416728, 11534709, 11583341, 11583347, 11583348, 11583351, 11811491, 11832905, 11943553, 12070377, 12070378, 12070379, 12070380, 12070381, 12595356, 12646658, 12693531, 13198357, 13198406, 13198406, 11171664, 11171664, 11171665, 11267374, 11595626, 12082663, 12548587, 11189702, 11438028, 11270554, 11645070, 11342001, 11342002, 11342005, 11514177, 12167828, 12587461, 11363085, 11363073, 11363087, 11363088, 11363088, 11363089, 11363090, 11363090, 11363088, 11363088, 11363088, 11363089, 11363090, 11363090, 11363092, 11363092, 11363096, 11363093, 11691342, 11363103, 11414914, 11524723, 11691341, 11691345, 12178375, 12178376, 11366847, 11642706, 11691344, 12178375, 12178376, 12178377, 12821366, 11614479, 11642706, 11691344, 11927321, 11940804, 11942210, 11959059, 12051550, 12178377, 12178377, 12801529, 11524724, 12178377, 12178378, 12821368, 13306355, 11691339, 12178378, 12178379, 11691340, 11691348, 11524732, 11370603, 11646461, 11695092, 11695093, 11402748, 11489154, 11634306, 11711173, 12198204, 11447643, 12220653, 11466741, 11540463, 11507083, 11507084, 11507082, 11507085, 11507084, 11507086, 11507086, 11507087, 12250372, 12250373, 11714703, 12123547, 12250374, 13378351, 11556780, 11596721, 11642474, 12123548, 12250375, 11508802, 11597577, 11560500, 11560590, 11560685, 11623552, 11572640, 12283152, 11575561, 11575561, 11630958, 11720713, 11748941, 11797580, 11606472, 12300066, 11614197, 11816897, 11653646, 12784022, 11686353, 11686354, 11686355, 11686356, 11686356, 11686357, 11686343, 11686356, 11686356, 11686357, 11686357, 11686358, 11686358, 11686360, 11686357, 11686357, 11686362, 11852977, 12340010, 11852976, 12051837, 12340009, 11686372, 11852975, 11686372, 11804340, 11852972, 11852975, 11852977, 11852978, 12102534, 12213183, 12340009, 12340010, 12340011, 11776113, 11804340, 11852970, 11852972, 11852974, 11852975, 11852976, 11852977, 11852977, 12002603, 12126839, 12213184, 12340008, 12340010, 12340011, 12340011, 12340012, 12963162, 12963163, 13467988, 11804341, 11852978, 11852981, 11715720, 11716039, 11715848, 11715866, 11715875, 11790865, 11716360, 12355043, 11773116, 11773337, 11773559, 12383610, 11777866, 12385768, 11838083, 11928835, 11865865, 11865853, 11865855, 11865865, 11865866, 11865867, 11865868, 11865866, 11865866, 11865866, 11865876, 11865878, 11875743, 11894093, 11942730, 11942732, 11942732, 12429762, 12429763, 12429764, 11942730, 11942734, 12192289, 12429764, 12429764, 13473313, 12429766, 11942736, 11885618, 11885619, 11885826, 12439639, 11886032, 11904175, 11922310, 11922317, 11922319, 11922320, 11922323, 11922323, 11922324, 11922325, 11922319, 11922329, 11922397, 11922441, 11922331, 11970954, 11970954, 11970957, 12331163, 12457988, 12457989, 12457990, 12457990, 12917461, 13042406, 12037676, 12457993, 12457994, 12457994, 11970959, 11970959, 11970961, 11970962, 11970964, 11983278, 12237169, 12457992, 12457994, 12457994, 12721367, 13585971, 11970965, 12120587, 12457995, 12331168, 11922478, 12458069, 11922565, 12458112, 11933547, 11976583, 12013476, 12013676, 12013879, 12503802, 12018523, 12018525, 12379266, 12019062, 12019576, 12019586, 12019587, 12019587, 12019588, 12019572, 12019577, 12019579, 12019586, 12019587, 12019589, 12019592, 12019591, 12019574, 12019593, 12019593, 12019594, 12019577, 12019596, 12019596, 12019581, 12019596, 12019579, 12019580, 12019597, 12019582, 12019597, 12019598, 12019598, 12019581, 12019583, 12019598, 12019598, 12019582, 12019598, 12019599, 12019599, 12019599, 12019600, 12019601, 12019584, 12019585, 12019594, 12019595, 12019599, 12019600, 12019600, 12019600, 12019601, 12019585, 12019593, 12019600, 12019601, 12019601, 12019601, 12019601, 12019602, 12019603, 12019602, 12019602, 12019603, 12019589, 12019589, 12019594, 12019603, 12019603, 12019602, 12019603, 12019604, 12019603, 12019603, 12019604, 12019604, 12019605, 12019605, 12019603, 12019604, 12019604, 12019604, 12019609, 12019609, 12307520, 12506624, 12930469, 12116523, 12379800, 12441673, 12019611, 12019612, 12506628, 12506629, 12506630, 12506629, 12506631, 12506630, 12019616, 12019617, 12055407, 12169225, 12293464, 12379805, 12506630, 12506631, 12506632, 12506633, 12506633, 12506634, 12770005, 13634659, 12019617, 12088972, 12169225, 12169226, 12269158, 12287316, 12290702, 12379806, 12379807, 12506630, 12506631, 12506632, 12506632, 12506633, 12506633, 12506634, 12551227, 12930475, 13149623, 13634610, 12055408, 12182904, 12287316, 12381305, 12506632, 12506633, 12506634, 12506634, 12930477, 13149624, 13634610, 12255574, 12379807, 12506634, 12506634, 13149624, 12506635, 12967003, 12506635, 13634661, 12043947, 12044085, 12044222, 12044229, 12518938, 12392118, 12091210, 12091212, 12091214, 12091214, 12091342, 13670464, 12542438, 12542439, 12542440, 12672634, 12542438, 12091473, 12542566, 12100487, 13170229, 12152905, 12152910, 12992917, 12573287, 12153029, 12183241, 12158338, 12575998, 12213453, 12213455, 12213457, 12476729, 12603559, 12603560, 12282850, 13281249, 12318846, 12318849, 12318849, 12318846, 12318850, 12529426, 12656253, 12318864, 12656256, 12656257, 13784233, 12656255, 12656257, 12656259, 12325165, 12659414, 12346202, 12669930, 12353586, 12673625, 12417314, 12417447, 12417579, 12705619, 12418226, 12705949, 12475887, 12607948, 12491544, 12491549, 12742603, 12742606, 13162237, 12501512, 12953230, 12518512, 12518611, 12518707, 12518710, 12518709, 12518711, 12756184, 12756183, 12557081, 12756185, 12521326, 12757491, 12552011, 12772836, 12555027, 12555028, 12774345, 12774345, 13417333, 12561797, 12768755, 12567333, 12567320, 12567392, 13908481, 12567468, 12780561, 12568316, 12780990, 12577204, 12658610, 12595452, 12595452, 12595462, 12794557, 13218401, 12794562, 12622271, 12807967, 12686792, 12686863, 12686931, 12840295, 12730948, 12730980, 12862327, 12739994, 12739995, 12740007, 12740008, 12740009, 12740010, 12740010, 12740008, 12740010, 12740010, 12740011, 12740011, 12740012, 12829841, 12866835, 12866835, 12740024, 12866835, 12866836, 12866837, 12866837, 12866838, 12866836, 12866837, 12866838, 13509828, 13994814, 12866836, 12866837, 12866838, 12866838, 12743001, 12743013, 12868333, 12868341, 12863753, 12928707, 12915933, 13378644, 12919669, 12919677, 12919748, 12919754, 12919826, 12919827, 12956743, 12956743, 12975714, 12984687, 12993645, 12993645, 12993647, 12993646, 12993647, 12993647, 12993646, 12993648, 12993661, 12993647, 12993648, 12993648, 12993649, 12993650, 12993662, 12993648, 12993649, 12993649, 12993650, 12993650, 12993651, 12993651, 12993662, 12993662, 12993663, 12993664, 12993664, 12993665, 12993665, 12993650, 12993651, 12993651, 12993652, 12993652, 12993661, 12993662, 12993662, 12993663, 12993663, 12993664, 12993665, 12993665, 12993666, 12993666, 12993667, 12993668, 12993668, 12993651, 12993652, 12993652, 12993660, 12993662, 12993663, 12993663, 12993664, 12993664, 12993665, 12993665, 12993666, 12993666, 12993667, 12993652, 12993653, 12993663, 12993664, 12993665, 12993666, 12993666, 12993667, 12993656, 12993664, 12993665, 12993665, 12993666, 12993666, 12993667, 12993667, 12993665, 12993667, 12993667, 12993669, 12993666, 12993670, 12993675, 12993673, 12993676, 12993677, 12993678, 12993675, 12993676, 12993677, 12993677, 12993678, 12993678, 13464300, 12993676, 12993677, 12993677, 12993678, 13417506, 14121639, 14121689, 12993677, 12993678, 12993678, 12993679, 12993679, 12993680, 12993680, 13257037, 13417505, 13454031, 13636652, 14121640, 12993678, 12993679, 12993679, 12993680, 12993679, 12993680, 12993680, 12993681, 13257037, 13305992, 13413297, 13417505, 13417507, 13417508, 13454032, 13636654, 13972046, 14121641, 14121690, 12993680, 12993681, 12993681, 12993682, 12993682, 12993683, 12993684, 13039318, 13413297, 13413297, 13413299, 13417508, 13417508, 13417509, 13443164, 13454033, 13459576, 13616815, 13616816, 13616816, 13636654, 13636655, 14121641, 14121690, 14121690, 14121691, 14122497, 12993681, 12993682, 12993682, 12993683, 12993684, 12993685, 13166733, 13177546, 13195337, 13257038, 13273711, 13396062, 13413296, 13413297, 13413297, 13417507, 13417508, 13417509, 13417509, 13417510, 13454031, 13454033, 13569943, 13569947, 13616816, 13616817, 13636654, 13636655, 13636655, 13723163, 13747460, 13896726, 14121642, 14121691, 14121692, 12993682, 12993683, 12993683, 12993684, 12993685, 12993685, 13000549, 13003559, 13038262, 13039318, 13112692, 13123858, 13123860, 13123861, 13168398, 13177569, 13195337, 13195338, 13234775, 13257038, 13257038, 13257039, 13276277, 13324726, 13340698, 13396065, 13404016, 13413295, 13413297, 13413298, 13417508, 13417508, 13417509, 13417509, 13417510, 13420187, 13454031, 13454034, 13480149, 13518642, 13548667, 13569945, 13595103, 13616816, 13616817, 13616817, 13636655, 13636655, 13636656, 13636656, 13747461, 14050063, 14121642, 14121642, 14121658, 14121691, 14121692, 14121701, 12993683, 12993684, 12993685, 12993685, 12993689, 13038261, 13039318, 13039319, 13080046, 13123861, 13195338, 13195339, 13257039, 13257039, 13257040, 13266131, 13335496, 13340699, 13402854, 13413300, 13413300, 13417509, 13417510, 13417510, 13520117, 13522333, 13616817, 13616818, 13636655, 13636656, 13636657, 13867889, 14121642, 14121643, 14121692, 14121692, 12993684, 12993685, 13039319, 13039320, 13123859, 13257039, 13257039, 13417510, 13417510, 13417511, 13454035, 13616817, 13636655, 13636656, 13636657, 14121643, 14121643, 14121698, 13123862, 13257039, 13413299, 13413300, 13417510, 13417511, 13616817, 13636657, 14121644, 14121692, 14121693, 13257040, 13417511, 13636657, 14121644, 14121694, 13352387, 14121645, 14121694, 14121694, 13616819, 14121645, 13039322, 13417512, 13417513, 13454037, 13616821, 14121646, 14121648, 12994927, 13053589, 13007447, 13424407, 13013447, 13646544, 13082852, 13082855, 13082858, 14166281, 13301633, 13498630, 13084967, 13084967, 13084967, 13084968, 13084968, 13084968, 13302688, 13458946, 13458946, 13463158, 13662466, 13682304, 13682304, 14167341, 14167292, 13112260, 14180948, 13166424, 13703195, 13231715, 14240665, 13254048, 13254050, 13254052, 13254052, 13254054, 13254055, 13254055, 14251832, 13766847, 14251884, 13766849, 13325531, 13747011, 14251836, 13547703, 14251837, 13339797, 13339878, 13339958, 13430184, 13343130, 13592240, 13361428, 13601390, 13361471, 13601411, 13397006, 13397006, 13397007, 13526394, 13537164, 13619177, 13619178, 13818485, 13818486, 13873717, 13404946, 13462675, 13475883, 13475884, 14362751, 13877765, 13494749, 13668050, 13520406, 13520407, 13520405, 13520406, 13520407, 13520407, 13520408, 13520408, 13520409, 13520410, 13520410, 13520411, 13520407, 13520407, 13520411, 13520408, 13520412, 13520413, 13520499, 13520500, 13520501, 13717402, 13520502, 13680878, 13717402, 13880185, 14385060, 13520502, 13520502, 13900024, 14385061, 13520503, 13598865, 13900025, 14385013, 13680881, 14010832, 13680881, 14385014, 14385063, 13536485, 13569365, 13880190, 14385015, 13900029, 13520594, 13520594, 13680970, 13833407, 13880278, 13880278, 14385103, 14385153, 13538590, 13538684, 13538778, 13909209, 13552569, 13552616, 14401167, 13553783, 13697580, 13558884, 13700115, 13618322, 13618320, 13948982, 14433971, 13655784, 13655786, 13655787, 14452700, 13744358, 13748568, 13947877, 13967716, 13677368, 13677384, 13677444, 13677486, 13677519, 13677587, 13795982, 13958765, 13759499, 13687724, 13687728, 13687850, 14468672, 13687976, 13983807, 13711099, 13975532, 13798459, 13798464, 13819906, 13819908, 13812039, 13812037, 13826693, 14530878, 13814366, 14047006, 13832925, 13832926, 13832926, 13832927, 13832928, 13832928, 13832929, 13832929, 13832929, 13832930, 13832931, 13832928, 13832931, 13832930, 13832931, 13832931, 14036213, 14541272, 14541272, 14056285, 13837140, 13837140, 14036448, 14541273, 14541323, 13837140, 13837141, 13837141, 13938273, 14056287, 14280459, 14541274, 14541323, 13837140, 13841332, 13841334, 13841348, 13841335, 13841349, 13841349, 13841351, 13841335, 13841350, 13841350, 13841351, 13841351, 13841336, 13841349, 13841350, 13841351, 13841351, 13841352, 13841351, 13841352, 13841352, 13841353, 13841353, 13841353, 13841354, 13841354, 13841364, 14040658, 14060496, 14545532, 13841366, 13841366, 14040658, 14060497, 14546340, 13841366, 13868751, 13877876, 13883419, 14040659, 14040659, 14060497, 14060498, 14545484, 14545484, 14545534, 13841367, 13877876, 14040659, 14040660, 14060496, 14060497, 14060498, 14060498, 14545485, 14545534, 13844030, 13877877, 13888078, 13954911, 14040659, 14040660, 14040660, 14060498, 14060498, 14060499, 14173273, 14545485, 14545485, 14545535, 13877877, 14545535, 13877878, 13846707, 13846704, 14548159, 14548162, 13892661, 14571138, 13896151, 14087898, 13912602, 14076283, 13914383, 13914440, 13914388, 13914447, 13914447, 13914448, 13914459, 13914449, 13914503, 13924648, 13980530, 14077229, 14077229, 14077230, 14077230, 14077231, 14097068, 14097068, 14097069, 14196891, 14228422, 14582054, 14582055, 14582055, 14582104, 14582105, 14077230, 14077231, 14582056, 13914655, 13914838, 13915001, 13915121, 14582370, 13925499, 13925501, 13925513, 14102578, 14587566, 13934798, 13934799, 13934867, 13934868, 13934937, 14016980, 14107289, 14592275, 13966635, 14123142, 14043615, 14043617, 14141790, 14161628, 14161630, 14046563, 14046564, 14046565, 14354212, 14143265, 14163103, 14648090, 14050984, 14051011, 14650369, 14068472, 14659047, 14099023, 14169493, 14103668, 14191656, 14146221, 14146222, 14146223, 14146223, 14146225, 14697919, 14212933, 14697969, 14212933, 14325708, 14697969, 14698776, 14162493, 14706054, 14196539, 14238092, 14239497, 14239509, 14239732, 14239951, 14239965, 14239952, 14239965, 14239966, 14239966, 14239967, 14239952, 14239964, 14239964, 14239965, 14239966, 14239967, 14239967, 14239954, 14239964, 14239965, 14239966, 14239967, 14239968, 14239956, 14239966, 14239967, 14239967, 14239967, 14239969, 14259802, 14744789, 14744789, 14259802, 14744790, 14259804, 14744790, 14239981, 14259804, 14239981, 14239981, 14525417, 14744792, 14744841, 14239982, 14259805, 14259806, 14413755, 14744792, 14744842, 14259804, 14259805, 14259806, 14259806, 14339606, 14372580, 14465224, 14475276, 14595198, 14744792, 14744793, 14744830, 14744842, 14279640, 14279627, 14279642, 14279628, 14279629, 14279640, 14279643, 14279643, 14279644, 14279629, 14279642, 14279642, 14279643, 14279643, 14279644, 14279644, 14279630, 14279641, 14279642, 14279643, 14279643, 14279644, 14279644, 14279645, 14279645, 14279643, 14279644, 14279645, 14279646, 14279645, 14279654, 14764627, 14279657, 14279657, 14764628, 14764629, 14279658, 14764629, 14764629, 14764679, 14392418, 14764630, 14764679, 14279658, 14279659, 14390448, 14433593, 14764630, 14764630, 14764680, 14279659, 14390451, 14397890, 14445342, 14764630, 14764631, 14764680, 14764683, 14279660, 14282412, 14411000, 14474500, 14680204, 14764631, 14764631, 14764673, 14764681, 14764682, 14765487, 14764631, 14764632, 14285181, 14767401, 14350431, 14800024, 14439245, 14844431, 14452657, 14851136, 14479290, 14864454, 14501251, 14501251, 14501253, 14501253, 14501254, 14875433, 14875483, 14875434, 14505193, 14505193, 14505194, 14877405, 14600889, 14877406, 14516133, 14882874, 14542349, 14542353, 14895982, 14676607, 14587541, 14587545, 14918578, 14918626, 14918629, 14611038, 14930376, 14661850, 14661861, 14955786, 14669401, 14669462, 14669681, 14669975, 14959827, 14690481, 14885621, 14696580, 14973096, 14710585, 14980150, 14728002, 14728073, 14988859, 14742113, 14846272, 14799786, 15024702, 14810867, 14810870, 15030244, 14950425, 14950426, 14950428, 15100070, 15100021, 15100071, 15100022, 15080756, 15080758, 15080831, 15080832, 15080833, 15080907, 15080909, 15165261, 15106454, 15178034, 15249601, 15249602, 15249652, 15249603, 15249604, 15249605, 15249605, 15249606, 15249606, 15249608, 15249610, 15249612, 15249612, 15249614, 15249614, 15249615, 15249616, 15249625, 15249626, 15249626, 15249629, 15249637, 15249647, 15249648, 15249649, 15249649, 15249650, 15249650, 15249651, 15249651, 15249652, 15249652, 15249604, 15249605, 15249605, 15249606, 15249606, 15249612, 15249613, 15249613, 15249616, 15249632, 15249637, 15249638, 15249643, 15249647, 15249648, 15249650, 15249650, 15249651, 15249652, 15249652, 15249653, 15249607, 15249613, 15249617, 15249626, 15249652, 15249653, 15249653, 15249613, 15249653, 15249614, 15249654, 15249614, 15249653, 15249654, 15249654, 15249612, 15249615, 15249648, 15249652, 15249654, 15249655, 15249639, 15249615, 15249618, 15249633, 15249659, 15249631, 15249634, 15249635, 15249645, 15249654, 15249655, 15249656, 15249659, 15249660, 15249660, 15249661, 15249661, 15249661, 15249662, 15249662, 15249637, 15249662, 15249663, 15249662, 15249664, 15249663, 15249663, 15249664, 15249664, 15249668, 15249670, 15249651, 15249674, 15249673, 15249674, 15249675, 15249675, 15249675, 15249676, 15249665, 15249677, 15249680, 15249681, 15249685, 15249682, 15249684, 15249685, 15249685, 15249686, 15249687, 15249689, 15249690, 15249693, 15249693, 15249694, 15249694, 15249694, 15249694, 15249694, 15249695, 15249696, 15249696, 15249696, 15249698, 15249698, 15249698, 15249697, 15249698, 15249698, 15249699, 15249699, 15249698, 15249699, 15249699, 15249700, 15249699, 15249700, 15249700, 15249700, 15249701, 15249701, 15249725, 15249702, 15249703, 15249703, 15249704, 15249704, 15249705, 15249705, 15249706, 15249706, 15249707, 15249707, 15249708, 15249710, 15249711, 15249711, 15249717, 15249720, 15249722, 15249723, 15249725, 15249726, 15249727, 15249728, 15249728, 15249729, 15249703, 15249704, 15249704, 15249705, 15249706, 15249707, 15249711, 15249728, 15249704, 15249705, 15249705, 15249706, 15249707, 15249707, 15249708, 15249709, 15249709, 15249710, 15249711, 15249712, 15249712, 15249713, 15249719, 15249726, 15249728, 15249729, 15249705, 15249706, 15249706, 15249707, 15249707, 15249708, 15249708, 15249709, 15249710, 15249711, 15249712, 15249713, 15249713, 15249723, 15249724, 15249726, 15249727, 15249728, 15249729, 15249706, 15249707, 15249708, 15249708, 15249709, 15249707, 15249708, 15249708, 15249709, 15249709, 15249710, 15249711, 15249713, 15249714, 15249708, 15249709, 15249709, 15249710, 15249710, 15249711, 15249711, 15249712, 15249713, 15249713, 15249714, 15249720, 15249721, 15249722, 15249725, 15249725, 15249726, 15249727, 15249727, 15249728, 15249729, 15249730, 15249731, 15249709, 15249710, 15249710, 15249710, 15249711, 15249711, 15249712, 15249712, 15249713, 15249713, 15249714, 15249714, 15249715, 15249715, 15249717, 15249719, 15249723, 15249724, 15249725, 15249726, 15249726, 15249727, 15249728, 15249729, 15249730, 15249732, 15249711, 15249712, 15249712, 15249713, 15249713, 15249714, 15249714, 15249715, 15249715, 15249716, 15249717, 15249718, 15249721, 15249724, 15249726, 15249726, 15249727, 15249728, 15249728, 15249729, 15249730, 15249731, 15249732, 15249712, 15249713, 15249713, 15249714, 15249714, 15249715, 15249715, 15249716, 15249716, 15249717, 15249717, 15249718, 15249718, 15249719, 15249720, 15249721, 15249722, 15249724, 15249726, 15249726, 15249727, 15249727, 15249728, 15249729, 15249729, 15249730, 15249731, 15249731, 15249733, 15249713, 15249714, 15249715, 15249716, 15249716, 15249717, 15249717, 15249718, 15249721, 15249727, 15249728, 15249714, 15249715, 15249715, 15249716, 15249716, 15249717, 15249717, 15249718, 15249718, 15249719, 15249720, 15249721, 15249723, 15249725, 15249725, 15249726, 15249727, 15249728, 15249728, 15249729, 15249730, 15249730, 15249731, 15249733, 15249715, 15249716, 15249716, 15249717, 15249717, 15249718, 15249718, 15249719, 15249719, 15249721, 15249723, 15249724, 15249725, 15249725, 15249726, 15249726, 15249727, 15249728, 15249729, 15249729, 15249730, 15249730, 15249731, 15249732, 15249733, 15249733, 15249734, 15249716, 15249717, 15249717, 15249718, 15249727, 15249728, 15249729, 15249731, 15249733, 15249717, 15249718, 15249718, 15249719, 15249720, 15249726, 15249727, 15249727, 15249731, 15249732, 15249733, 15249734, 15249735, 15249735, 15249718, 15249719, 15249719, 15249720, 15249720, 15249721, 15249721, 15249722, 15249724, 15249725, 15249727, 15249728, 15249729, 15249730, 15249730, 15249731, 15249731, 15249732, 15249732, 15249733, 15249734, 15249735, 15249736, 15249719, 15249720, 15249720, 15249721, 15249721, 15249724, 15249725, 15249728, 15249728, 15249729, 15249730, 15249730, 15249731, 15249732, 15249732, 15249733, 15249734, 15249735, 15249736, 15249720, 15249721, 15249721, 15249722, 15249722, 15249723, 15249724, 15249726, 15249727, 15249728, 15249729, 15249730, 15249731, 15249731, 15249732, 15249732, 15249733, 15249733, 15249734, 15249735, 15249737, 15249721, 15249722, 15249722, 15249723, 15249724, 15249725, 15249725, 15249726, 15249726, 15249727, 15249728, 15249728, 15249729, 15249730, 15249731, 15249731, 15249732, 15249732, 15249733, 15249733, 15249734, 15249735, 15249736, 15249736, 15249737, 15249737, 15249723, 15249725, 15249726, 15249727, 15249729, 15249730, 15249732, 15249733, 15249733, 15249734, 15249735, 15249736, 15249737, 15249738, 15249723, 15249726, 15249726, 15249729, 15249730, 15249731, 15249732, 15249732, 15249733, 15249734, 15249735, 15249736, 15249737, 15249738, 15249724, 15249725, 15249726, 15249728, 15249729, 15249730, 15249730, 15249731, 15249731, 15249732, 15249732, 15249733, 15249733, 15249734, 15249735, 15249735, 15249736, 15249727, 15249728, 15249729, 15249729, 15249730, 15249731, 15249733, 15249733, 15249734, 15249735, 15249732, 15249733, 15249734, 15249735, 15249729, 15249733, 15249736, 15249732, 15249735, 15249736, 15249730, 15249731, 15249733, 15249733, 15249735, 15249737, 15249741, 15249730, 15249736, 15249736, 15249737, 15249731, 15249732, 15249734, 15249736, 15249738, 15249734, 15249736, 15249737, 15249737, 15249738, 15249740, 15249741, 15249743, 15249737, 15249737, 15249739, 15249740, 15249743, 15249735, 15249735, 15249737, 15249738, 15249739, 15249742, 15249744, 15249738, 15249739, 15249736, 15249737, 15249738, 15249739, 15249740, 15249741, 15249745, 15249737, 15249738, 15249738, 15249739, 15249739, 15249740, 15249740, 15249741, 15249741, 15249743, 15249743, 15249744, 15249745, 15249738, 15249739, 15249740, 15249740, 15249741, 15249742, 15249742, 15249743, 15249744, 15249739, 15249740, 15249742, 15249742, 15249740, 15249741, 15249742, 15249743, 15249743, 15249745, 15249741, 15249742, 15249742, 15249743, 15249743, 15249744, 15249744, 15249745, 15249746, 15249746, 15249747, 15249747, 15249742, 15249743, 15249743, 15249744, 15249744, 15249745, 15249745, 15249746, 15249746, 15249747, 15249748, 15249743, 15249744, 15249744, 15249745, 15249746, 15249746, 15249747, 15249747, 15249748, 15249748, 15249744, 15249745, 15249746, 15249747, 15249748, 15249749, 15249745, 15249746, 15249746, 15249747, 15249748, 15249748, 15249749, 15249749, 15249746, 15249747, 15249747, 15249748, 15249748, 15249749, 15249749, 15249750, 15249747, 15249748, 15249748, 15249749, 15249749, 15249750, 15249750, 15249748, 15249749, 15249750, 15249750, 15249751, 15249749, 15249750, 15249750, 15249751, 15249751, 17440608, 15249750, 15249751, 15249751, 15249752, 15249751, 15249752, 15249752, 15250533, 15249752, 15249753, 15249753, 15250534, 15249754, 15249755, 15249755, 15249756, 15249756, 15249757, 15249760, 15249760, 15249761, 15249762, 15249763, 15249764, 15249764, 15249765, 15249767, 15249769, 15249770, 15249770, 15249771, 15249772, 15249773, 15249774, 15249774, 15249775, 15249776, 15249790, 15249793, 15249793, 15249795, 15249801, 15249802, 15249803, 15249803, 15249804, 15250534, 15719776, 16099179, 17003955, 17200685, 19739755, 15249755, 15249756, 15249756, 15249757, 15249757, 15249758, 15249758, 15249759, 15249759, 15249760, 15249760, 15249761, 15249761, 15249762, 15249762, 15249763, 15249764, 15249765, 15249766, 15249767, 15249769, 15249769, 15249770, 15249771, 15249771, 15249772, 15249774, 15249775, 15249775, 15249776, 15249778, 15249783, 15249784, 15249785, 15249785, 15249789, 15249792, 15249793, 15249794, 15249799, 15249799, 15249800, 15249801, 15249802, 15249802, 15249803, 15249803, 15249804, 15250535, 15250584, 15249756, 15249758, 15249758, 15249759, 15249760, 15249760, 15249762, 15249763, 15249766, 15249771, 15249777, 15249796, 15249802, 15249757, 15249758, 15249758, 15249759, 15249760, 15249762, 15249762, 15249763, 15249763, 15249764, 15249765, 15249765, 15249766, 15249766, 15249767, 15249769, 15249770, 15249771, 15249773, 15249774, 15249775, 15249776, 15249777, 15249779, 15249780, 15249781, 15249784, 15249785, 15249785, 15249788, 15249788, 15249794, 15249795, 15249797, 15249800, 15249802, 15249802, 15249803, 15249803, 15249804, 15249805, 15250535, 15250536, 15249758, 15249759, 15249759, 15249760, 15249761, 15249761, 15249762, 15249763, 15249764, 15249764, 15249765, 15249766, 15249767, 15249771, 15249772, 15249776, 15249776, 15249784, 15249787, 15249789, 15249792, 15249795, 15249803, 15249804, 15249805, 15250536, 15249759, 15249760, 15249760, 15249761, 15249767, 15249771, 15249792, 15249795, 15249799, 15249801, 15249804, 15249806, 15249760, 15249761, 15249762, 15249762, 15249763, 15249764, 15249764, 15249765, 15249767, 15249767, 15249768, 15249771, 15249773, 15249773, 15249774, 15249775, 15249777, 15249778, 15249779, 15249784, 15249793, 15249796, 15249800, 15249802, 15249804, 15249804, 15249805, 15249806, 15250592, 15249762, 15249764, 15249767, 15249775, 15249805, 15249763, 15249764, 15249766, 15249768, 15249774, 15249807, 15249763, 15249766, 15249766, 15249764, 15249765, 15249765, 15249766, 15249766, 15249767, 15249767, 15249769, 15249775, 15249775, 15249777, 15249778, 15249807, 15249765, 15249766, 15249766, 15249767, 15249768, 15249778, 15249798, 15249806, 15249766, 15249767, 15249771, 15249807, 15250540, 15249768, 15249768, 15249769, 15249771, 15249772, 15249775, 15249776, 15249777, 15249788, 15249794, 15249806, 15249810, 15250541, 15249768, 15249770, 15249771, 15249772, 15249774, 15249776, 15249779, 15249782, 15249802, 15249808, 15249769, 15249770, 15249771, 15249772, 15249773, 15249774, 15249776, 15249776, 15249777, 15249778, 15249781, 15249792, 15249795, 15249804, 15249806, 15249770, 15249772, 15249773, 15249773, 15249774, 15249776, 15249776, 15249777, 15249778, 15249778, 15249779, 15249779, 15249781, 15249783, 15249796, 15249799, 15249801, 15249809, 15249811, 15249811, 15250542, 15249774, 15249775, 15249776, 15249810, 15249810, 15249811, 15250543, 15249773, 15249773, 15249774, 15249779, 15250543, 15249773, 15249812, 15249775, 15249776, 15249779, 15249780, 15249782, 15249809, 15249811, 15249813, 15250544, 15250544, 15249776, 15249777, 15249778, 15249779, 15249780, 15249781, 15249781, 15249783, 15249784, 15249785, 15249791, 15249811, 15249812, 15249812, 15250545, 15249776, 15249777, 15249785, 15249780, 15249780, 15249781, 15249782, 15249783, 15249784, 15249784, 15249785, 15249786, 15249786, 15249787, 15249788, 15249794, 15249796, 15249805, 15249812, 15249813, 15249813, 15249814, 15249814, 15249815, 15250546, 15249781, 15249781, 15249781, 15249783, 15249787, 15249787, 15249788, 15249789, 15249790, 15249782, 15249815, 15249801, 15249816, 15249784, 15249788, 15249789, 15249789, 15249796, 15249817, 15249818, 15249785, 15249785, 15249786, 15249787, 15249788, 15249788, 15249789, 15249789, 15249790, 15249791, 15249802, 15249815, 15249816, 15249817, 15249818, 15249818, 15250549, 15249790, 15249794, 15249818, 15249786, 15249787, 15249788, 15249789, 15249790, 15249790, 15249791, 15249792, 15249797, 15249798, 15249801, 15249802, 15249809, 15249815, 15249817, 15249818, 15249819, 15249819, 15250550, 15249787, 15249788, 15249789, 15249789, 15249791, 15249792, 15249809, 15249816, 15249816, 15249817, 15249818, 15249818, 15249820, 15249788, 15249789, 15249790, 15249791, 15249792, 15249793, 15249794, 15249817, 15249789, 15249792, 15249805, 15249818, 15249821, 15249791, 15249791, 15249792, 15249792, 15249793, 15249802, 15249819, 15249821, 15249792, 15249793, 15249795, 15249808, 15249819, 15249793, 15249793, 15249794, 15249796, 15249806, 15249807, 15249811, 15249820, 15249822, 15250553, 15249793, 15249794, 15249794, 15249805, 15249819, 15249821, 15249795, 15249796, 15249797, 15249798, 15249802, 15249805, 15249807, 15249813, 15249815, 15249816, 15249817, 15249818, 15249821, 15249822, 15249823, 15250554, 15250554, 15249795, 15249796, 15249798, 15249799, 15249805, 15249808, 15249810, 15249813, 15249814, 15249821, 15249821, 15249824, 15250555, 15249796, 15249797, 15249797, 15249798, 15249800, 15249806, 15249808, 15249808, 15249810, 15249812, 15249814, 15249815, 15249816, 15249818, 15249821, 15249821, 15249822, 15249822, 15249823, 15249823, 15249824, 15249808, 15249809, 15249816, 15249822, 15249823, 15249823, 15249825, 15250556, 15249803, 15249806, 15249815, 15249822, 15249823, 15249825, 15249813, 15249814, 15249823, 15249824, 15249824, 15249826, 15249804, 15249816, 15249818, 15249822, 15249808, 15249810, 15249811, 15249819, 15249821, 15249826, 15249809, 15249820, 15249821, 15249822, 15249826, 15249813, 15249828, 15249817, 15249812, 15249813, 15249819, 15249824, 15249829, 15249811, 15249814, 15249827, 15249827, 15249812, 15249815, 15249822, 15249832, 15249817, 15249832, 15249820, 15249823, 15249825, 15249831, 15249818, 15249820, 15249823, 15249834, 15249818, 15249821, 15249832, 15249834, 15249820, 15249823, 15249828, 15249833, 15249819, 15249822, 15249826, 15249830, 15249831, 15249831, 15249820, 15249824, 15249834, 15249826, 15249827, 15249827, 15249829, 15249830, 15249830, 15249833, 15249833, 15249834, 15249835, 15249835, 15249824, 15249828, 15249831, 15249838, 15249825, 15249834, 15249828, 15249829, 15249836, 15249837, 15249837, 15249829, 15249835, 15249837, 15250626, 15249827, 15249829, 15249832, 15249837, 15249834, 15249834, 15249840, 15249831, 15249832, 15249833, 15249837, 15249838, 15249840, 15249839, 15249832, 15249833, 15249833, 15249834, 15249835, 15249836, 15249836, 15249839, 15249840, 15249840, 15249841, 15249842, 15249842, 15249834, 15249835, 15249841, 15249842, 15249843, 15249836, 15249837, 15249840, 15249841, 15249842, 15249835, 15249836, 15249837, 15249841, 15249841, 15249842, 15249842, 15249844, 15250575, 15249838, 15249839, 15249843, 15249844, 15249844, 15249839, 15249841, 15249842, 15249843, 15249844, 15249845, 15249841, 15249842, 15249842, 15249844, 15249842, 15249842, 15249843, 15249843, 15249844, 15249844, 15249845, 15249846, 15249846, 15250577, 15249843, 15249844, 15249845, 15249844, 15249844, 15249844, 15249845, 15249846, 15249844, 15249845, 15249845, 15249846, 15249846, 15249847, 15249847, 15250579, 15249845, 15249846, 15249846, 15249847, 15249847, 15249846, 15249847, 15249847, 15249848, 15249848, 15249849, 15249847, 15249848, 15249848, 15249849, 15249850, 15249848, 15249849, 15249849, 15249850, 15249850, 15249849, 15249850, 15249850, 15249851, 15249850, 15249851, 15249851, 15249851, 15249852, 15249852, 15250583, 15249853, 15249854, 15250583, 15250584, 15250626, 15250633, 15250634, 15250636, 15250637, 15250638, 15250638, 15249854, 15250568, 15250584, 15250584, 15250634, 15250585, 15251298, 15251314, 15251315, 15251316, 15251316, 15251317, 15251317, 15251320, 15251322, 15251322, 15251325, 15251325, 15251327, 15251328, 15251328, 15251330, 15251332, 15251336, 15251336, 15251337, 15251337, 15251342, 15251342, 15251343, 15251343, 15251344, 15251345, 15251345, 15251346, 15251347, 15251349, 15251350, 15251350, 15251353, 15251355, 15251357, 15251359, 15251381, 15251388, 15251318, 15251342, 15251342, 15251343, 15251343, 15251345, 15251346, 15251348, 15251318, 15251343, 15251343, 15251344, 15251344, 15251344, 15251321, 15251344, 15251344, 15251345, 15251327, 15251330, 15251340, 15251343, 15251345, 15251345, 15251347, 15251347, 15251333, 15251350, 15251353, 15251347, 15251354, 15251374, 15251354, 15251355, 15251342, 15251349, 15251355, 15251356, 15251358, 15251356, 15251356, 15251350, 15251358, 15251360, 15251363, 15251364, 15251365, 15251380, 15251364, 15251364, 15251365, 15251365, 15251379, 15251368, 15251369, 15251369, 15251370, 15251371, 15251370, 15251371, 15251372, 15251373, 15251371, 15251372, 15251372, 15251373, 15251378, 15251372, 15251373, 15251374, 15251374, 15251376, 15251373, 15251374, 15251375, 15251397, 15251375, 15251377, 15251376, 15251377, 15251377, 15251378, 15251378, 15251379, 15251379, 15251380, 15251380, 15251381, 15251381, 15251383, 15251387, 15251388, 15251391, 15251393, 15251393, 15251395, 15251395, 15251396, 15251421, 15251377, 15251378, 15251378, 15251378, 15251379, 15251379, 15251380, 15251380, 15251381, 15251381, 15251382, 15251382, 15251384, 15251379, 15251380, 15251380, 15251381, 15251381, 15251380, 15251381, 15251381, 15251382, 15251382, 15251383, 15251383, 15251392, 15251397, 15251398, 15251403, 15251381, 15251382, 15251382, 15251383, 15251384, 15251385, 15251382, 15251383, 15251383, 15251384, 15251384, 15251386, 15251388, 15251391, 15251406, 15251416, 15251383, 15251384, 15251417, 15251384, 15251385, 15251387, 15251387, 15251393, 15251415, 15251385, 15251386, 15251387, 15251387, 15251388, 15251390, 15251393, 15251394, 15251399, 15251402, 15251403, 15251425, 15251386, 15251387, 15251388, 15251388, 15251390, 15251392, 15251393, 15251395, 15251399, 15251403, 15251387, 15251388, 15251388, 15251389, 15251389, 15251391, 15251392, 15251393, 15251394, 15251395, 15251395, 15251396, 15251397, 15251399, 15251400, 15251401, 15251402, 15251402, 15251403, 15251388, 15251389, 15251389, 15251391, 15251407, 15251389, 15251390, 15251392, 15251405, 15251420, 15251390, 15251402, 15251391, 15251392, 15251392, 15251393, 15251393, 15251394, 15251394, 15251395, 15251395, 15251396, 15251397, 15251397, 15251398, 15251399, 15251400, 15251402, 15251403, 15251428, 15251392, 15251393, 15251393, 15251394, 15251398, 15251394, 15251395, 15251397, 15251398, 15251395, 15251396, 15251396, 15251397, 15251397, 15251398, 15251399, 15251399, 15251402, 15251404, 15251405, 15251406, 15251407, 15251408, 15251409, 15251413, 15251415, 15251423, 15251396, 15251397, 15251398, 15251399, 15251399, 15251400, 15251423, 15251397, 15251398, 15251398, 15251399, 15251406, 15251398, 15251399, 15251400, 15251399, 15251400, 15251401, 15251402, 15251406, 15251407, 15251413, 15251400, 15251401, 15251401, 15251402, 15251403, 15251403, 15251406, 15251407, 15251408, 15251410, 15251425, 15251401, 15251402, 15251402, 15251402, 15251403, 15251403, 15251404, 15251404, 15251405, 15251405, 15251406, 15251406, 15251407, 15251408, 15251408, 15251409, 15251412, 15251413, 15251403, 15251404, 15251405, 15251406, 15251406, 15251408, 15251409, 15251409, 15251412, 15251415, 15251404, 15251405, 15251405, 15251406, 15251407, 15251407, 15251408, 15251409, 15251409, 15251410, 15251411, 15251413, 15251414, 15251427, 15251405, 15251406, 15251408, 15251408, 15251410, 15251412, 15251406, 15251407, 15251407, 15251408, 15251408, 15251409, 15251409, 15251410, 15251410, 15251411, 15251412, 15251407, 15251408, 15251408, 15251409, 15251409, 15251410, 15251410, 15251411, 15251411, 15251412, 15251413, 15251424, 15251408, 15251409, 15251409, 15251409, 15251410, 15251410, 15251411, 15251412, 15251412, 15251424, 15251410, 15251411, 15251412, 15251412, 15251413, 15251411, 15251412, 15251412, 15251413, 15251413, 15251420, 15251412, 15251413, 15251413, 15251414, 15251414, 15251415, 15251416, 15251431, 15251413, 15251414, 15251414, 15251415, 15251416, 15251417, 15251417, 15251418, 15251418, 15251419, 15251420, 15251429, 15251432, 15251415, 15251416, 15251416, 15251417, 15251417, 15251418, 15251418, 15251419, 15251419, 15251422, 15251433, 15251440, 15251416, 15251417, 15251417, 15251418, 15251418, 15251419, 15251419, 15251420, 15251420, 15251421, 15251431, 15251433, 15251435, 15251417, 15251418, 15251418, 15251419, 15251420, 15251420, 15251428, 15251418, 15251419, 15251419, 15251420, 15251420, 15251421, 15251421, 15251422, 15251432, 15251442, 15251419, 15251420, 15251420, 15251421, 15251421, 15251422, 15251422, 15251423, 15251427, 15251435, 15251420, 15251421, 15251421, 15251422, 15251422, 15251423, 15251423, 15251425, 15251435, 15251443, 15251421, 15251422, 15251422, 15251423, 15251423, 15251424, 15251425, 15251430, 15251431, 15251436, 15251422, 15251423, 15251423, 15251424, 15251424, 15251425, 15251427, 15251427, 15251428, 15251433, 15251436, 15251444, 15251423, 15251424, 15251424, 15251425, 15251426, 15251431, 15251432, 15251435, 15251437, 15251439, 15251444, 15251424, 15251425, 15251425, 15251426, 15251427, 15251427, 15251428, 15251431, 15251432, 15251435, 15251437, 15251437, 15251442, 15251445, 15251425, 15251426, 15251426, 15251427, 15251428, 15251431, 15251435, 15251436, 15251438, 15251426, 15251428, 15251428, 15251438, 15251446, 15251427, 15251428, 15251428, 15251429, 15251429, 15251430, 15251431, 15251432, 15251433, 15251433, 15251434, 15251434, 15251435, 15251435, 15251436, 15251437, 15251438, 15251439, 15251441, 15251443, 15251443, 15251446, 15251428, 15251429, 15251429, 15251430, 15251432, 15251433, 15251434, 15251435, 15251437, 15251447, 15251429, 15251430, 15251431, 15251433, 15251434, 15251434, 15251438, 15251440, 15251447, 15251430, 15251431, 15251431, 15251432, 15251433, 15251433, 15251434, 15251435, 15251435, 15251437, 15251438, 15251440, 15251440, 15251442, 15251448, 15251431, 15251432, 15251432, 15251433, 15251433, 15251434, 15251435, 15251435, 15251436, 15251436, 15251437, 15251438, 15251439, 15251448, 15251432, 15251433, 15251434, 15251434, 15251435, 15251436, 15251441, 15251443, 15251433, 15251434, 15251434, 15251435, 15251436, 15251436, 15251437, 15251438, 15251440, 15251441, 15251445, 15251449, 15251434, 15251435, 15251435, 15251436, 15251437, 15251440, 15251435, 15251436, 15251437, 15251438, 15251441, 15251436, 15251437, 15251439, 15251440, 15251443, 15251437, 15251438, 15251438, 15251439, 15251439, 15251440, 15251442, 15251444, 15251438, 15251439, 15251440, 15251440, 15251441, 15251442, 15251443, 15251449, 15251452, 15251440, 15251441, 15251441, 15251442, 15251442, 15251443, 15251443, 15251445, 15251449, 15251450, 15251453, 15251441, 15251442, 15251442, 15251443, 15251443, 15251444, 15251442, 15251443, 15251443, 15251444, 15251444, 15251448, 15251450, 15251451, 15251443, 15251444, 15251444, 15251445, 15251444, 15251445, 15251445, 15251447, 15251449, 15251450, 15251451, 15251452, 15251445, 15251446, 15251448, 15251452, 15251446, 15251447, 15251448, 15251450, 15251456, 15251447, 15251448, 15251448, 15251449, 15251449, 15251450, 15251451, 15251452, 15251452, 15251453, 15251453, 15251454, 15251455, 15251456, 15251448, 15251449, 15251449, 15251450, 15251451, 15251451, 15251453, 15251454, 15251449, 15251450, 15251450, 15251451, 15251452, 15251450, 15251451, 15251452, 15251452, 15251451, 15251452, 15251452, 15251453, 15251454, 15251454, 15251455, 15251455, 15251456, 15251458, 15251458, 15251485, 15251486, 15253395, 15251452, 15251453, 15251453, 15251455, 15251455, 15251456, 15251456, 15251459, 15251485, 15251454, 15251454, 15251456, 15251457, 15251460, 15251455, 15251456, 15251456, 15251457, 15251457, 15251458, 15251460, 15251487, 15251456, 15251457, 15251457, 15253397, 15251457, 15251458, 15251458, 15251459, 15251460, 15251461, 15251488, 15251458, 15251459, 15251462, 15251459, 15251460, 15251461, 15251462, 15251462, 15251460, 15251461, 15251461, 15251462, 15251462, 15251463, 15251461, 15251462, 15251462, 15251463, 15251463, 15251462, 15251463, 15251463, 15251464, 15251463, 15251464, 15251464, 15251464, 15251465, 15251465, 15251493, 15251466, 15251467, 15251467, 15251468, 15251468, 15251471, 15251475, 15251476, 15251478, 15251478, 15251481, 15251481, 15251482, 15251483, 15251484, 15251485, 15251487, 15251488, 15251489, 15251490, 15251491, 15251491, 15251492, 15251492, 15251493, 15251493, 15251494, 15253367, 15253402, 15253404, 15720631, 15720632, 15251467, 15251468, 15251468, 15251469, 15251469, 15251470, 15251470, 15251471, 15251472, 15251472, 15251473, 15251474, 15251476, 15251478, 15251478, 15251479, 15251479, 15251482, 15251483, 15251484, 15251485, 15251485, 15251486, 15251487, 15251489, 15251489, 15251490, 15251490, 15251491, 15251491, 15251492, 15251492, 15251493, 15251493, 15251494, 15251494, 15251468, 15251469, 15251479, 15251484, 15251485, 15251488, 15251490, 15251491, 15251492, 15251493, 15251470, 15251480, 15251483, 15251493, 15251494, 15251480, 15251481, 15251490, 15251493, 15251494, 15251480, 15251483, 15251484, 15251486, 15251489, 15251490, 15251491, 15251492, 15251492, 15251493, 15251494, 15251494, 15251495, 15251495, 15251496, 15251477, 15251494, 15251495, 15251474, 15251495, 15251489, 15251483, 15251495, 15251496, 15251499, 15251498, 15251499, 15251492, 15251500, 15251501, 15251501, 15251502, 15251503, 15251491, 15251495, 15251497, 15251502, 15251503, 15251504, 15251505, 15251501, 15251504, 15251493, 15251504, 15251505, 15251505, 15251503, 15251497, 15251506, 15251508, 15251504, 15251505, 15251507, 15251509, 15251509, 15251510, 15251509, 15251509, 15251510, 15251508, 15251510, 15251507, 15251508, 15251509, 15251509, 15251510, 15251510, 15251511, 15251509, 15251508, 15251510, 16100053, 15251511, 15251512, 15251511, 15251512, 15251512, 15251513, 15251514, 15251512, 15251513, 15251512, 15251512, 15251514, 15251514, 15251515, 15251515, 15251514, 15251513, 15251514, 15251515, 15251516, 15251516, 15251517, 15251514, 15251515, 15251515, 15251516, 15251517, 15251515, 15251516, 15251517, 15251516, 15251517, 15251517, 15251518, 15251517, 15251518, 15251518, 15251519, 15251518, 15251519, 15251519, 15251520, 15251520, 15251521, 15251521, 15251522, 15251525, 15253302, 15253395, 15253395, 15253430, 15253431, 15253432, 15253432, 15253444, 15253445, 15253446, 15253447, 15253448, 15253449, 15253453, 15309528, 15388600, 15565519, 15720659, 15720660, 15720660, 16100061, 16100061, 16100062, 17004839, 17004863, 17633091, 17689843, 18707805, 19242826, 19740639, 15251523, 15253395, 15253396, 15253454, 15253396, 15251600, 15253469, 15255158, 15255168, 15255251, 15255261, 15255268, 15255269, 15255270, 15255270, 15255271, 15255271, 15255272, 15255273, 15255273, 15255274, 15255275, 15255276, 15255289, 15255290, 15255298, 15255301, 15255302, 15255302, 15255303, 15255303, 15255304, 15255272, 15255274, 15255276, 15255294, 15255300, 15255303, 15255303, 15255304, 15255304, 15255291, 15255304, 15255305, 15255305, 15255305, 15255305, 15255305, 15255306, 15255306, 15255306, 15255306, 15255307, 15255308, 15255308, 15255308, 15255309, 15255309, 15255310, 15255324, 15255324, 15255325, 15255325, 15255328, 15255333, 15255334, 15255336, 15255337, 15255337, 15255379, 15255337, 15255338, 15255338, 15255379, 15255339, 15255340, 15255341, 15255341, 15255342, 15255342, 15255344, 15255346, 15255346, 15255347, 15255347, 15255348, 15255349, 15255349, 15255350, 15255351, 15255352, 15255352, 15255353, 15255354, 15255354, 15255355, 15255356, 15255356, 15255357, 15255357, 15255358, 15255359, 15255359, 15255360, 15255360, 15255361, 15255361, 15255362, 15255362, 15255363, 15255363, 15255365, 15255366, 15255366, 15255371, 15255377, 15255378, 15255378, 15255379, 15255379, 15255380, 15255341, 15255341, 15255342, 15255343, 15255344, 15255349, 15255350, 15255352, 15255353, 15255354, 15255354, 15255358, 15255358, 15255362, 15255363, 15255370, 15255379, 15255380, 15255342, 15255343, 15255344, 15255349, 15255351, 15255354, 15255355, 15255356, 15255358, 15255381, 15255343, 15255344, 15255344, 15255346, 15255350, 15255351, 15255351, 15255352, 15255355, 15255356, 15255357, 15255359, 15255359, 15255362, 15255363, 15255364, 15255348, 15255350, 15255354, 15255355, 15255355, 15255356, 15255356, 15255357, 15255364, 15255364, 15255365, 15255365, 15255381, 15255382, 15255353, 15255357, 15255352, 15255357, 15255357, 15255360, 15255360, 15255361, 15255364, 15255365, 15255383, 15255358, 15255360, 15255362, 15255385, 15255359, 15255361, 15255368, 15255368, 15255360, 15255357, 15255362, 15255362, 15255366, 15255376, 15255384, 15255386, 15255362, 15255362, 15255363, 15255364, 15255365, 15255361, 15255363, 15255364, 15255365, 15255389, 15255389, 15255365, 15255369, 15255366, 15255367, 15255369, 15255373, 15255367, 15255392, 15255367, 15255367, 15255368, 15255370, 15255371, 15255374, 15255393, 15255367, 15255368, 15255369, 15255371, 15255371, 15255372, 15255374, 15255375, 15255377, 15255377, 15255389, 15255394, 15255369, 15255370, 15255370, 15255371, 15255371, 15255372, 15255372, 15255373, 15255374, 15255374, 15255375, 15255376, 15255376, 15255377, 15255377, 15255378, 15255378, 15255380, 15255381, 15255381, 15255382, 15255382, 15255383, 15255385, 15255388, 15255391, 15255392, 15255393, 15255394, 15255394, 15722584, 15255370, 15255371, 15255372, 15255373, 15255376, 15255395, 15255371, 15255372, 15255372, 15255373, 15255373, 15255374, 15255375, 15255375, 15255376, 15255376, 15255377, 15255377, 15255378, 15255378, 15255380, 15255380, 15255381, 15255384, 15255395, 15255373, 15255373, 15255376, 15255378, 15255374, 15255375, 15255376, 15255378, 15255379, 15255391, 15255396, 15255374, 15255375, 15255375, 15255378, 15255378, 15255379, 15255380, 15255380, 15255397, 15255712, 17006765, 15255375, 15255376, 15255377, 15255377, 15255378, 15255378, 15255379, 15255379, 15255380, 15255380, 15255381, 15255383, 15255384, 15255386, 15255388, 15255389, 15255392, 15255397, 16101988, 15255376, 15255377, 15255378, 15255378, 15255379, 15255379, 15255380, 15255380, 15255381, 15255397, 15255398, 15255378, 15255378, 15255379, 15255379, 15255380, 15255380, 15255381, 15255381, 15255382, 15255382, 15255384, 15255388, 15255391, 15255394, 15255396, 15255398, 15255398, 15255379, 15255380, 15255381, 15255382, 15255399, 15255399, 15255380, 15255381, 15255382, 15255382, 15255383, 15255383, 15255384, 15255386, 15255387, 15255391, 15255392, 15255393, 15255397, 15255399, 15255400, 15255381, 15255382, 15255382, 15255383, 15255386, 15255386, 15255387, 15255389, 15255391, 15255400, 16101989, 15255382, 15255383, 15255383, 15255384, 15255385, 15255387, 15255388, 15255388, 15255392, 15255398, 15255400, 15255400, 15255401, 15255383, 15255384, 15255384, 15255385, 15255385, 15255386, 15255387, 15255388, 15255391, 15255396, 15255401, 15255401, 15255384, 15255385, 15255385, 15255386, 15255386, 15255387, 15255387, 15255388, 15255389, 15255397, 15255402, 15255385, 15255386, 15255386, 15255387, 15255388, 15255388, 15255389, 15255389, 15255390, 15255392, 15255393, 15255394, 15255395, 15255396, 15255396, 15255398, 15255399, 15255400, 15255401, 15255401, 15255402, 15255402, 15255403, 15722591, 15255386, 15255387, 15255388, 15255389, 15255389, 15255390, 15255393, 15255395, 15255397, 15255398, 15255399, 15255402, 15255403, 15255387, 15255388, 15255389, 15255390, 15255391, 15255391, 15255396, 15255401, 15255402, 15255403, 15255403, 15255404, 15255389, 15255389, 15255390, 15255390, 15255391, 15255394, 15255395, 15255396, 15255399, 15255400, 15255402, 15255403, 15255404, 15255390, 15255397, 15255402, 15255404, 15255404, 15255391, 15255402, 15255405, 15255391, 15255392, 15255392, 15255393, 15255396, 15255397, 15255398, 15255398, 15255401, 15255402, 15255404, 15255405, 15255392, 15255393, 15255396, 15255396, 15255397, 15255397, 15255398, 15255398, 15255400, 15255400, 15255403, 15255405, 15255406, 15255394, 15255395, 15255398, 15255399, 15255405, 15255406, 15255406, 15255395, 15255396, 15255397, 15255400, 15255404, 15255405, 15255407, 15255403, 15255407, 15255407, 15255402, 15255408, 15255398, 15255408, 15255408, 15255400, 15255409, 15255405, 15255409, 15255409, 15255405, 15255406, 15255407, 15255409, 15255410, 15255404, 15255410, 15255410, 15255404, 15255405, 15255408, 15255411, 15255409, 15255411, 15255405, 15255410, 15255411, 15255411, 15255412, 15255409, 15255410, 15255410, 15255412, 15255413, 15255410, 15255413, 15255413, 15255409, 15255410, 15255411, 15255413, 15255414, 15255414, 15255415, 15255415, 15255413, 15255416, 15722604, 15255413, 15255415, 15255416, 15255416, 15255417, 15255416, 15255416, 15255417, 15495635, 15722606, 15722606, 16102009, 15255416, 15255417, 15255418, 15255418, 15255418, 15255418, 15255419, 15255419, 15255420, 15255421, 15255422, 15255429, 15255444, 15255452, 15255453, 15255453, 15255454, 15255454, 15255455, 15495638, 15567468, 15567468, 15722608, 15722608, 15722609, 15922261, 15922262, 16055655, 16102009, 16102010, 16102011, 16102011, 16102012, 16382055, 16765316, 17006788, 17006788, 17006812, 17295747, 15255421, 15255422, 15255422, 15255423, 15255423, 15255424, 15255424, 15255425, 15255425, 15255426, 15255426, 15255427, 15255428, 15255428, 15255429, 15255429, 15255430, 15255430, 15255431, 15255432, 15255433, 15255434, 15255435, 15255435, 15255437, 15255438, 15255439, 15255441, 15255442, 15255443, 15255443, 15255444, 15255444, 15255446, 15255447, 15255449, 15255450, 15255451, 15255451, 15255452, 15255452, 15255453, 15255453, 15255454, 15255454, 15255455, 15255455, 15722609, 16102010, 16102011, 15255423, 15255424, 15255425, 15255426, 15255427, 15255429, 15255430, 15255431, 15255434, 15255434, 15255443, 15255451, 15255453, 15255454, 15255454, 15255455, 15255455, 15255456, 15255423, 15255426, 15255456, 15567470, 15255457, 15255427, 15255429, 15255432, 15255455, 15255457, 15255457, 15255429, 15255458, 15255452, 15255456, 15255458, 15495641, 15255430, 15255457, 15255429, 15255431, 15255443, 15255449, 15255458, 15255458, 15255459, 15255459, 15255430, 15255432, 15255445, 15255445, 15255451, 15255457, 15255458, 15255459, 15255452, 15255458, 15255460, 15255460, 15255450, 15255458, 15255447, 15255452, 15255459, 15255461, 15255462, 15255458, 15255461, 15255462, 15255462, 15255461, 15255463, 15255441, 15255453, 15255462, 15255464, 15255441, 15255464, 15255464, 15255453, 15255456, 15255463, 15255452, 15255459, 15255456, 15255457, 15255454, 15255451, 15255458, 15255467, 15255469, 15255471, 15255462, 15255468, 15255470, 15255472, 15255471, 15255474, 15255474, 15255471, 15255475, 15255473, 15255475, 15255476, 15255475, 15255475, 15255468, 15255475, 15255478, 15255469, 15255477, 15255478, 15255477, 15255478, 15255479, 15255475, 15255479, 15255480, 15255479, 15255480, 15255480, 15255480, 15255480, 15255481, 15255476, 15255483, 15255482, 15255483, 15255482, 15255483, 15255485, 15255483, 15255484, 15255485, 15255486, 15255485, 15255486, 15255487, 15255486, 15255486, 15255487, 15255487, 15255486, 15255487, 15255487, 15255488, 15255487, 15255488, 15255488, 15255488, 15255489, 15255489, 15255490, 15255526, 15255607, 15268366, 15311512, 15322156, 15323625, 15346373, 15348973, 15390584, 15430511, 15493038, 15495673, 15495674, 15567503, 15567503, 15567504, 15567504, 15567505, 15567505, 15610225, 15610357, 15722640, 15722642, 15722642, 15722643, 15722643, 15722644, 15722644, 15873483, 15922296, 15922297, 15922297, 15946464, 15968051, 15994563, 16028513, 16100728, 16102044, 16102045, 16102045, 16102046, 16102046, 16102047, 16102048, 16347736, 16381930, 16381931, 16382087, 16382089, 16458879, 16828892, 17006815, 17006823, 17006823, 17006847, 17443479, 15348974, 15495676, 15567503, 15567504, 15567504, 15722641, 15722643, 15722644, 15722644, 15722645, 15722680, 15255799, 15722835, 15256062, 16102336, 15281254, 16114934, 15367544, 15367545, 15778676, 15778677, 15388835, 15562353, 15391779, 16170199, 15437277, 16919796, 15442513, 15442515, 15442531, 15442532, 15442589, 15442591, 15442607, 15442625, 15442656, 15442662, 15442664, 15442682, 15442717, 15816250, 15661116, 15661116, 15816256, 15816257, 16195657, 15816260, 15816277, 15462522, 15661154, 15816295, 15482289, 15836062, 15525693, 15525694, 16237155, 15857753, 15605549, 15897681, 15730599, 15960205, 15735868, 15735868, 15735869, 15735869, 15735870, 15735870, 15735874, 17247019, 15962839, 15962840, 16342241, 15807700, 15962840, 15962842, 15879516, 15879517, 15879530, 15879531, 15879531, 15879532, 15879532, 15879536, 15879529, 15879531, 15879531, 15879532, 15879532, 15879533, 15879533, 15879535, 15879532, 15879532, 15879533, 15879533, 15879534, 15879528, 15879536, 15879541, 15922240, 15879546, 16034671, 16034671, 16659764, 15879546, 15879548, 15879551, 16034670, 16034671, 16034671, 16034672, 16034672, 16185511, 16414072, 16414073, 16414074, 16414074, 15879548, 15922254, 16034668, 16034670, 16034671, 16034672, 16034672, 16034673, 16034675, 16234325, 16414073, 16414074, 16414074, 16659765, 17140921, 16034672, 16034673, 16034673, 16414073, 16034672, 16034673, 16034674, 16414074, 16414076, 16034673, 16034674, 16034674, 16034676, 16034677, 16414079, 15964949, 15964960, 15964974, 15965051, 15965159, 16077499, 16077500, 16077500, 15965250, 16077537, 16189808, 16189794, 16189795, 16189809, 16189796, 16189796, 16189796, 16189797, 16189797, 16189811, 16189811, 16189812, 16189812, 16189797, 16189798, 16189811, 16189812, 16189812, 16189813, 16189813, 16189798, 16189809, 16189810, 16189811, 16189812, 16189812, 16189813, 16189813, 16189814, 16189814, 16189815, 16189800, 16189810, 16189811, 16189811, 16189812, 16189812, 16189813, 16189813, 16189814, 16189814, 16189815, 16189815, 16189817, 16189815, 16189819, 16189825, 16189825, 16189826, 16189824, 16189826, 16569212, 16849256, 16189826, 16189827, 16413632, 16189826, 16189827, 16189827, 16569212, 16569213, 16569216, 17473991, 16189827, 16189828, 16189828, 16413735, 16495684, 16569213, 16569213, 16569214, 16569214, 16569215, 16569216, 16814905, 16849098, 16849099, 17296061, 17473992, 16189828, 16189829, 16189829, 16189830, 16189831, 16278134, 16288135, 16340652, 16389465, 16389466, 16416968, 16493872, 16495685, 16569213, 16569214, 16569215, 16569215, 16814905, 16849098, 16849098, 17232522, 17296061, 17329100, 17473992, 17473992, 17910648, 16189829, 16189830, 16189830, 16189835, 16389466, 16389467, 16389468, 16413735, 16448812, 16493873, 16509317, 16511056, 16522857, 16569214, 16569214, 16569215, 16569215, 16569216, 16569216, 16569217, 16569218, 16814906, 16849099, 16849100, 16849259, 17296062, 17296063, 17473993, 17910648, 16189830, 16189831, 16189831, 16225150, 16330064, 16330066, 16339703, 16340653, 16389465, 16389466, 16389467, 16389467, 16389468, 16389468, 16413736, 16413737, 16435219, 16435220, 16435221, 16493873, 16495681, 16495683, 16509159, 16543889, 16569214, 16569214, 16569215, 16569215, 16569216, 16569216, 16569217, 16569217, 16569218, 16629532, 16751319, 16814906, 16849099, 16849099, 16849100, 16849101, 16849254, 16849276, 17296062, 17473993, 17473993, 16189832, 16389468, 16430370, 16569215, 16569215, 16569216, 16569216, 16543892, 16569215, 16569216, 16389469, 16569216, 16389469, 16330068, 16569217, 16189838, 16569220, 16569221, 16260485, 16552066, 16366468, 16366538, 16366599, 16657609, 16386460, 16487792, 16470313, 16470316, 16470315, 16624478, 16709463, 16709465, 16489592, 16719105, 16491491, 16720053, 16720054, 16720054, 16999939, 17624831, 16589118, 16589119, 16589119, 16589120, 16589106, 16589120, 16589121, 16634874, 16634875, 16683884, 16695336, 16708812, 16768867, 16768867, 16768868, 16768868, 16768869, 16768869, 17048752, 17048753, 17048754, 17495715, 16637449, 16637450, 16637555, 16637557, 16637656, 16637656, 16637657, 16637657, 16637660, 16637661, 16793134, 16793136, 16793137, 17697913, 16659140, 16659142, 16746778, 16793135, 16793136, 16644120, 16721024, 16670923, 16809770, 16680624, 16680625, 16680626, 16680627, 16680627, 16680629, 16814621, 16814620, 16814620, 16814621, 17719399, 16814620, 16814622, 16707867, 16708026, 16708186, 16768374, 16733648, 16841131, 16778649, 16778651, 16863633, 16863634, 16797927, 16797918, 16797933, 16797953, 16797946, 16873269, 17118966, 16873287, 16798028, 16798104, 16872053, 16801551, 16801548, 16801550, 16801551, 16801554, 16801553, 16801554, 16815024, 16875082, 16875083, 16875083, 16822598, 16849766, 16875086, 17155125, 16828501, 16828504, 16828506, 16828503, 16888557, 16888558, 16888558, 16888559, 16888563, 16828817, 16888715, 16832293, 16890451, 16843643, 16843643, 16896128, 16896128, 16855900, 16855903, 16902257, 16902259, 16897964, 16897971, 16897978, 16923289, 16923294, 16923298, 16946001, 16947318, 16947318, 16948598, 16948599, 16948599, 16948600, 16948600, 16948601, 16948601, 16948602, 16948614, 16948614, 16948615, 16948600, 16948601, 16948601, 16948602, 16948602, 16948603, 16948604, 16948615, 16948615, 16948601, 16948602, 16948602, 16948603, 16948603, 16948604, 16948604, 16948615, 16948615, 16948616, 16948602, 16948603, 16948603, 16948604, 16948604, 16948615, 16948616, 16948616, 16948617, 16948617, 16948618, 16948619, 16948619, 16948603, 16948604, 16948604, 16948605, 16948616, 16948616, 16948617, 16948617, 16948618, 16948618, 16948619, 16948621, 16948604, 16948605, 16948605, 16948606, 16948617, 16948617, 16948618, 16948618, 16948619, 16948620, 16948605, 16948617, 16948618, 16948618, 16948619, 16948619, 16948620, 16948609, 16948618, 16948618, 16948619, 16948620, 16948621, 16948618, 16948618, 16948619, 16948620, 16948620, 16948622, 16948619, 16948620, 16948621, 16948621, 16948629, 16948630, 16948631, 16948631, 17853393, 17965489, 16948630, 16948631, 16948631, 16948632, 17228501, 17853393, 16948631, 16948632, 16948632, 16948633, 16948633, 16998462, 17167680, 17194307, 17228499, 17228501, 17228501, 17228538, 17228660, 17381282, 17675463, 17853394, 17853417, 17853418, 17853421, 17853445, 17853448, 18142354, 18142354, 18290049, 18538942, 16948632, 16948633, 16948633, 16948634, 16948638, 17194307, 17194309, 17198364, 17228500, 17228501, 17228502, 17268027, 17381281, 17480484, 17675463, 17853386, 17853394, 18142354, 16948633, 16948634, 16948635, 16948636, 16948636, 16963772, 16964101, 17064183, 17064187, 17167676, 17194308, 17194309, 17194310, 17198364, 17202992, 17228500, 17228501, 17228501, 17228502, 17228502, 17228656, 17228658, 17228659, 17228660, 17349862, 17381282, 17410318, 17577461, 17611703, 17637700, 17675464, 17723653, 17853394, 17853395, 17853419, 17853445, 18290050, 18481646, 18538456, 16948634, 16948635, 16948635, 16948636, 16948636, 16948637, 16964099, 16964100, 16969988, 17064184, 17064184, 17186467, 17194308, 17194310, 17202993, 17228501, 17228502, 17228502, 17228503, 17228646, 17228659, 17228660, 17228661, 17228662, 17228662, 17228689, 17675464, 17853387, 17853395, 17853419, 17853420, 17853445, 17853449, 18136591, 18142354, 18142355, 18290051, 17194309, 17202993, 17228502, 17228503, 17228662, 17228662, 17853395, 17853396, 17853420, 17853449, 18481700, 16948636, 17064185, 17194309, 17228503, 17228658, 17228662, 17381283, 17853396, 16948637, 17194310, 17194315, 17228503, 17228503, 17228504, 17228649, 17708505, 17853389, 17853396, 17853397, 18142356, 17194310, 17228494, 17228504, 17853422, 17194311, 17228505, 17853398, 17228508, 16978923, 17868545, 16979578, 16979578, 16979580, 17778298, 17243982, 17868874, 16991395, 17874803, 17048293, 17048304, 18339916, 17069244, 17069319, 17069395, 17913781, 17179751, 17179751, 17179752, 17179750, 17179752, 17179756, 17968961, 17309875, 18405618, 17309876, 17968963, 17309876, 17344070, 17309877, 17312884, 17313137, 17313390, 18035811, 17386743, 17386800, 17447569, 17386901, 17387006, 17422217, 17424364, 18091292, 17439984, 17439995, 17440001, 17440007, 17440008, 17440016, 17440026, 17440008, 17440009, 17440027, 17440028, 17440031, 17440019, 17440025, 17474194, 17474195, 17440032, 17440050, 17448692, 17474200, 17474200, 17474201, 17474201, 17474202, 17474305, 17474357, 17474358, 17474359, 17474360, 17474361, 17513727, 17523148, 17530015, 17595561, 17626982, 17726183, 17857623, 17921163, 17921193, 18099094, 18099118, 17440051, 17474201, 17726183, 18099095, 17474209, 18099112, 17474220, 17474380, 17562848, 17726200, 17857424, 18099113, 17448107, 17478245, 18103137, 17457361, 17457362, 17457362, 17457462, 17457463, 17457464, 17457372, 17457464, 17457464, 17457464, 17457465, 17457565, 17457556, 17457566, 17457566, 17482972, 17482974, 17483119, 17483131, 17483131, 18107866, 18396826, 18396827, 17508360, 17508370, 17508388, 17508390, 17508392, 17508394, 17508396, 17508398, 17508369, 17508370, 17508370, 17508389, 17508391, 17508391, 17508392, 17508392, 17508393, 17508394, 17508396, 17508397, 17508397, 17508398, 17508399, 17508399, 17508371, 17508385, 17508392, 17508392, 17508393, 17508394, 17508395, 17508398, 17508400, 17508371, 17508395, 17508395, 17508399, 17508400, 17508401, 17508391, 17508392, 17508392, 17508393, 17508393, 17508394, 17508394, 17508395, 17508395, 17508396, 17508397, 17508397, 17508398, 17508398, 17508399, 17508399, 17508400, 17508400, 17508401, 17508402, 17508403, 17508403, 17508408, 17508409, 17508414, 17508422, 17508445, 18133279, 18133282, 18133307, 17661170, 18133283, 17508416, 18133284, 17508416, 18133285, 17508418, 17508419, 17508421, 17661173, 17760374, 18133277, 18133285, 17508417, 17508417, 17508419, 17508421, 17508552, 18133286, 18133286, 18133310, 18133336, 17508419, 17508421, 17508422, 17508424, 17508553, 17508424, 17508540, 17955356, 18133287, 17508423, 17508554, 17661175, 17661175, 18133288, 18422247, 17508421, 17508421, 17508422, 17508423, 17508502, 17508538, 17508553, 17563826, 18133280, 18133288, 17508425, 17508423, 17508424, 17508482, 17508554, 17508555, 17661177, 18133289, 17508423, 17508424, 17508425, 17508428, 17508558, 17547922, 17955359, 18133290, 18133343, 17508425, 17508426, 17508497, 17508499, 17508529, 17508540, 17661177, 17891602, 18133290, 17508426, 17508550, 17508558, 17654419, 18051127, 18133291, 17508427, 17508546, 17661179, 18133291, 17508428, 17508428, 17508434, 17508546, 17508549, 17508558, 17508558, 17661179, 17661179, 17857358, 17955361, 17988401, 18133291, 18133292, 17508485, 17508509, 17661179, 17955361, 18133284, 18133292, 17508430, 17508555, 17508556, 17508557, 17508561, 17661181, 17955362, 18133292, 18133293, 18133317, 18133320, 17508553, 17508556, 17955362, 17988402, 18133293, 18133293, 18133294, 17508553, 18133294, 18133295, 18133295, 18133296, 18133298, 18133300, 17508520, 18133301, 17508571, 17960455, 17508564, 17508605, 17508616, 17508628, 17508629, 18133366, 17508654, 17508660, 17508630, 18133376, 17508687, 17508710, 17508704, 17508680, 17508683, 17508703, 17508685, 17508707, 17508709, 17508684, 17508680, 17508699, 17508691, 17508682, 17508703, 17508693, 17508701, 17508704, 17508706, 17508705, 17508705, 17508702, 17508705, 17508706, 17508706, 17508699, 17508704, 17508706, 17508706, 17508707, 17508708, 17508703, 17508714, 17508704, 17508707, 17508708, 17508708, 17508711, 17508705, 17508707, 17508689, 17508691, 17508704, 17508709, 17508709, 17508711, 17508711, 17508707, 17508709, 17508709, 17508711, 17508692, 17508711, 17508712, 17508713, 17508714, 17508713, 17508714, 17508714, 17988538, 18133430, 18133432, 17512251, 18133433, 17955503, 18133436, 17508725, 17508724, 17717551, 17508745, 17661326, 18133432, 18133440, 17508727, 18133441, 18133441, 18133442, 17661329, 18133442, 17508732, 17661330, 17760534, 17941905, 17955512, 18133435, 18133442, 18133443, 18133467, 17955512, 18133435, 18133443, 18133444, 18133444, 17508733, 17547940, 17955514, 18133445, 17891975, 18133437, 18133445, 17508735, 17891970, 17654574, 17661335, 18133438, 18133446, 18133470, 18133447, 18133450, 17508767, 17661338, 18133454, 17661342, 18133455, 18133460, 18133463, 17955542, 18133497, 17515804, 18136986, 17587158, 17587295, 17587436, 17587427, 17587437, 17587442, 17700691, 17850814, 17994873, 18172804, 17606279, 18182225, 17619252, 17649155, 17620019, 18189098, 17662343, 17662475, 17662604, 18210416, 17679055, 17679123, 17679188, 17679203, 18218681, 17685643, 18221908, 17751101, 17751103, 17751248, 18254628, 17751395, 18254773, 17800430, 17800430, 18279301, 18003795, 17813931, 17813946, 17813946, 17813947, 17813945, 17813947, 17813948, 17813933, 17813948, 17813947, 17813949, 17813950, 18286058, 17813961, 17871594, 18286051, 18286059, 18575016, 18722714, 17813963, 18044367, 18286059, 18286059, 18286060, 18286060, 17870174, 18286061, 17872018, 17942184, 17926395, 17926395, 18342282, 17929237, 17944410, 17959630, 18358946, 18012349, 18012349, 18012349, 18012350, 18012351, 18012352, 18385260, 18385261, 18385261, 18821917, 18385254, 18114187, 18436177, 18206300, 18482234, 18482289, 18207155, 18241190, 18274791, 18274791, 18274795, 18274795, 18455866, 18516483, 18516484, 18275223, 18275227, 18275227, 18275229, 18275229, 18516699, 18516699, 18516723, 18326798, 18831453, 18375104, 18388718, 18402295, 18402296, 18402370, 18402306, 18402372, 18402312, 18402381, 18580236, 18402364, 18402398, 18580276, 18402444, 18402446, 18402448, 18402469, 18402562, 18402645, 18435411, 18503187, 18580293, 18580301, 18580354, 18580302, 18580304, 18580325, 18402748, 18580487, 18402920, 18580576, 18412448, 18585307, 18468390, 18468391, 18468392, 18468393, 18613282, 18613283, 18498683, 18917385, 18577015, 18667591, 18593844, 18676000, 18603941, 18681056, 18636922, 18636958, 18636995, 18697576, 18758149, 18758172, 18758156, 18758157, 18758158, 18758158, 18758159, 18758159, 18758161, 18758163, 18758166, 18758166, 18758167, 18758168, 18758169, 18758176, 18758179, 18758179, 18758180, 18758180, 18758181, 18758181, 18758182, 18758182, 18758181, 18758181, 18758181, 18758181, 18758182, 18758182, 18758183, 18758183, 18758183, 18758185, 18758187, 18758176, 18758176, 18758178, 18758191, 18758191, 18758254, 19047129, 19194822, 19194847, 18758191, 18758192, 18758218, 19194823, 18758192, 18758193, 18758200, 18758202, 18758203, 18758203, 18758203, 18758204, 18758204, 18758205, 18758209, 18758223, 18758230, 18758235, 18758257, 18758205, 18758206, 18758206, 18758207, 18758207, 18758208, 18758208, 18758210, 18758211, 18758214, 18758215, 18758216, 18758216, 18758218, 18758220, 18758220, 18758221, 18758221, 18758222, 18758222, 18758223, 18758224, 18758224, 18758225, 18758230, 18758230, 18758231, 18758232, 18758233, 18758234, 18758235, 18758236, 18758237, 18758240, 18758245, 18758256, 18758257, 18758206, 18758207, 18758207, 18758208, 18758208, 18758209, 18758210, 18758211, 18758212, 18758212, 18758213, 18758215, 18758217, 18758218, 18758220, 18758221, 18758223, 18758223, 18758224, 18758224, 18758225, 18758225, 18758226, 18758226, 18758227, 18758228, 18758228, 18758231, 18758231, 18758233, 18758233, 18758234, 18758234, 18758235, 18758236, 18758245, 18758249, 18758257, 18758257, 18758207, 18758208, 18758208, 18758209, 18758209, 18758211, 18758213, 18758213, 18758216, 18758217, 18758218, 18758221, 18758222, 18758223, 18758223, 18758224, 18758224, 18758225, 18758226, 18758226, 18758227, 18758230, 18758231, 18758232, 18758233, 18758234, 18758235, 18758245, 18758250, 18758256, 18758257, 18758257, 18758258, 18758208, 18758209, 18758209, 18758210, 18758212, 18758212, 18758213, 18758214, 18758222, 18758222, 18758223, 18758224, 18758224, 18758225, 18758226, 18758227, 18758232, 18758232, 18758235, 18758236, 18758256, 18758257, 18758258, 18758258, 18758209, 18758212, 18758218, 18758226, 18758226, 18758227, 18758229, 18758231, 18758233, 18758235, 18758254, 18758255, 18758257, 18758258, 18758258, 18758211, 18758215, 18758223, 18758224, 18758226, 18758227, 18758230, 18758233, 18758258, 18758211, 18758213, 18758219, 18758226, 18758227, 18758227, 18758228, 18758228, 18758230, 18758231, 18758234, 18758253, 18758259, 18758260, 18758213, 18758215, 18758215, 18758224, 18758226, 18758227, 18758227, 18758228, 18758229, 18758232, 18758234, 18758260, 18758229, 18758217, 18758221, 18758229, 18758230, 18758230, 18758235, 18758236, 18758239, 18758243, 18758250, 18758229, 18758243, 18758227, 18758227, 18758231, 18758240, 18758263, 18758227, 18758228, 18758232, 18758220, 18758228, 18758232, 18758233, 18758238, 18758263, 18758233, 18758230, 18758236, 18758235, 18758266, 18758241, 18758232, 18758233, 18758234, 18758236, 18758237, 18758242, 18758244, 18758246, 18758264, 18758268, 18758268, 18758241, 18758244, 18758238, 18758245, 18758240, 18758240, 18758246, 18758250, 18758252, 18758240, 18758240, 18758241, 18758241, 18758246, 18758248, 18758250, 18758259, 18758265, 18758271, 18758272, 18758272, 18758241, 18758250, 18758255, 18758273, 18758242, 18758247, 18758251, 18758242, 18758242, 18758246, 18758248, 18758250, 18758252, 18758273, 18758241, 18758243, 18758248, 18758252, 18758257, 18758258, 18758260, 18758274, 18758243, 18758243, 18758249, 18758251, 18758274, 18758275, 18758243, 18758244, 18758244, 18758249, 18758249, 18758250, 18758255, 18758256, 18758276, 18758244, 18758245, 18758249, 18758250, 18758250, 18758252, 18758253, 18758253, 18758254, 18758276, 18758245, 18758246, 18758247, 18758247, 18758248, 18758248, 18758249, 18758249, 18758250, 18758250, 18758251, 18758252, 18758253, 18758254, 18758254, 18758256, 18758257, 18758264, 18758264, 18758267, 18758275, 18758276, 18758277, 19047158, 19194856, 18758246, 18758248, 18758248, 18758249, 18758250, 18758250, 18758251, 18758251, 18758253, 18758254, 18758255, 18758258, 18758259, 18758269, 18758273, 18758276, 18758276, 18758277, 18758277, 18758278, 18758252, 18758253, 18758257, 19047162, 18758254, 18758252, 18758252, 18758253, 18758254, 18758255, 18758250, 18758253, 18758256, 18758258, 18758253, 18758254, 18758255, 18758257, 18758260, 18758254, 18758257, 18758258, 18758254, 18758255, 18758256, 18758255, 18758255, 18758258, 18758255, 18758256, 18758256, 18758257, 18758271, 18758281, 18758256, 18758258, 18758259, 18758259, 18758260, 18758260, 18758266, 18758277, 18758277, 18758281, 18758281, 18758282, 18758282, 18758257, 18758258, 18758259, 18758260, 18758260, 18758261, 18758262, 18758263, 18758264, 18758264, 18758265, 18758265, 18758268, 18758269, 18758270, 18758270, 18758271, 18758273, 18758273, 18758274, 18758275, 18758276, 18758278, 18758278, 18758280, 18758281, 18758282, 18758282, 18758283, 18758259, 18758283, 18758279, 18758260, 18758261, 18758261, 18758262, 18758262, 18758263, 18758263, 18758264, 18758265, 18758265, 18758266, 18758267, 18758270, 18758272, 18758272, 18758276, 18758276, 18758277, 18758280, 18758283, 18758283, 18758284, 18758284, 18758262, 18758266, 18758267, 18758272, 18758276, 18758284, 18758262, 18758263, 18758264, 18758265, 18758266, 18758268, 18758269, 18758270, 18758274, 18758277, 18758277, 18758284, 18758285, 18758285, 18758263, 18758264, 18758265, 18758267, 18758268, 18758268, 18758269, 18758277, 18758280, 18758281, 18758284, 18758285, 18758285, 18758286, 18758264, 18758265, 18758265, 18758266, 18758267, 18758268, 18758268, 18758269, 18758269, 18758270, 18758272, 18758273, 18758274, 18758275, 18758275, 18758276, 18758277, 18758278, 18758278, 18758279, 18758279, 18758280, 18758280, 18758281, 18758282, 18758284, 18758285, 18758285, 18758286, 18758286, 18758287, 18758265, 18758266, 18758268, 18758269, 18758281, 18758286, 18758286, 18758287, 18758266, 18758270, 18758277, 18758280, 18758282, 18758268, 18758269, 18758270, 18758270, 18758274, 18758276, 18758277, 18758277, 18758279, 18758282, 18758283, 18758283, 18758287, 18758287, 18758288, 18758288, 18758288, 18758272, 18758274, 18758278, 18758284, 18758288, 18758288, 18758289, 18758277, 18758288, 18758272, 18758272, 18758278, 18758279, 18758282, 18758282, 18758285, 18758288, 18758289, 18758289, 18758290, 18758273, 18758276, 18758278, 18758285, 18758289, 18758290, 18758273, 18758276, 18758280, 18758283, 18758286, 18758286, 18758290, 18758290, 18758291, 18758274, 18758277, 18758279, 18758286, 18758290, 18758291, 18758291, 18758278, 18758291, 18758291, 18758292, 18758278, 18758283, 18758286, 18758287, 18758288, 18758291, 18758292, 18758292, 18758285, 18758293, 18758294, 18758294, 18758294, 18758281, 18758283, 18758285, 18758289, 18758294, 18758294, 18758295, 18758290, 18758294, 18758295, 18758284, 18758287, 18758294, 18758295, 18758296, 19047180, 18758286, 18758287, 18758289, 18758289, 18758291, 18758292, 18758292, 18758295, 18758296, 18758297, 18758296, 18758297, 18758295, 18758296, 18758298, 18758297, 18758297, 18758298, 18758298, 18758292, 18758298, 18758299, 18758299, 18758299, 18758291, 18758300, 18758295, 18758295, 18758299, 18758299, 18758300, 18758300, 18758295, 18758296, 18758299, 18758300, 18758300, 18758301, 18758296, 18758301, 18758301, 18758302, 18758301, 18758301, 18758302, 18758302, 19047187, 18758297, 18758302, 18758303, 18758302, 18758303, 18758303, 18758302, 18758302, 18758303, 18758303, 18758304, 18758301, 18758302, 18758303, 18758303, 18758304, 18758304, 18758303, 18758303, 18758304, 18758304, 18758305, 18758304, 18758306, 18758305, 18758306, 18758306, 18758307, 18758307, 18758307, 18758308, 18758332, 19082602, 18758308, 18758309, 18758327, 18758331, 18758332, 18758332, 18870328, 19047191, 19139377, 19161340, 19194888, 18758309, 18758310, 18758310, 18758314, 18758318, 18758321, 18758322, 18758322, 18758324, 18758326, 18758327, 18758329, 18758330, 18758330, 18758331, 18758331, 18758332, 18758332, 18758333, 18878251, 18944463, 18987341, 19047192, 19047192, 19047193, 19047193, 19194888, 19194913, 19386484, 19443266, 18758310, 18758316, 18758316, 18758317, 18758321, 18758324, 18758326, 18758327, 18758328, 18758328, 18758329, 18758330, 18758330, 18758331, 18758331, 18758332, 18758332, 18758333, 18758333, 19047192, 19047194, 19047194, 18758312, 18758319, 18758325, 18758331, 18758331, 18758332, 18758332, 18758333, 18758333, 18758334, 18758334, 18758331, 18758338, 18758339, 18758337, 18758339, 18758339, 18758340, 18758341, 18758341, 18758344, 18758344, 18758344, 18758346, 18758336, 18758346, 18758345, 18758347, 18758348, 18758348, 18758349, 18758344, 18758348, 18758349, 18758350, 18758351, 18758349, 18758350, 18758351, 18758351, 18758352, 18758350, 18758351, 18758351, 18758352, 18758352, 18758353, 18758353, 19194909, 18758354, 18758352, 18758353, 18758353, 18758354, 18758354, 18758353, 18758354, 18758354, 18758355, 18758354, 18758355, 18758355, 19194911, 18758355, 18758356, 19194911, 18758356, 18758357, 18793679, 18813072, 18840333, 18850819, 18870352, 18870353, 18870354, 18878273, 18878275, 18911068, 18924046, 18933783, 18933843, 18944487, 18954987, 18987365, 19037475, 19047212, 19047212, 19047214, 19047215, 19047216, 19047216, 19047217, 19047217, 19047218, 19047218, 19047219, 19047219, 19047220, 19082624, 19082627, 19088148, 19088149, 19194907, 19194909, 19194912, 19194912, 19194937, 19386508, 19386535, 19443261, 19443290, 19047217, 19047218, 19194913, 18829026, 18905700, 18867800, 19101945, 18922323, 18922324, 19129206, 19129206, 18952344, 19129207, 19276903, 18943296, 19139697, 18982360, 18982360, 18982360, 18982361, 18982361, 18982362, 18982362, 18982364, 18982366, 19056495, 19306919, 19306920, 18982373, 19159224, 19159224, 19159225, 19306920, 18982374, 19159224, 19159225, 19159225, 19159226, 19200158, 19306921, 19159225, 19159226, 19159227, 18990284, 19056499, 19159229, 19306924, 19159229, 18998203, 18998204, 18998205, 18998205, 18998215, 19314841, 18998217, 19167143, 19167148, 19074924, 19167147, 19314843, 19063794, 19199943, 19089750, 19212922, 19109209, 19109235, 19370364, 19109345, 19370414, 19130630, 19130630, 19223618, 19233359, 19233360, 19381055, 19151629, 19151632, 19151640, 19391555, 19243861, 19238101, 19216385, 19276236, 19423932, 19316628, 19316637, 19316671, 19316690, 19326377, 19326389, 19324560, 19324562, 19478020, 19330324, 19336085, 19336069, 19336071, 19336073, 19336073, 19336074, 19336073, 19336091, 19336074, 19336076, 19336090, 19336075, 19336076, 19336076, 19336077, 19336077, 19336078, 19336078, 19336079, 19336088, 19336090, 19336091, 19336091, 19336092, 19336092, 19336093, 19336076, 19336077, 19336077, 19336078, 19336079, 19336091, 19336092, 19336092, 19336093, 19336077, 19336078, 19336078, 19336079, 19336079, 19336091, 19336092, 19336092, 19336093, 19336093, 19336094, 19336078, 19336079, 19336079, 19336080, 19336080, 19336081, 19336090, 19336090, 19336092, 19336092, 19336093, 19336093, 19336094, 19336079, 19336080, 19336080, 19336092, 19336093, 19336093, 19336094, 19336094, 19336095, 19336093, 19336094, 19336094, 19336095, 19336095, 19336096, 19336096, 19336094, 19336094, 19336095, 19336096, 19336082, 19336095, 19336095, 19336096, 19336096, 19336095, 19336096, 19336095, 19336096, 19336103, 19336105, 19483786, 19336106, 19336107, 19336107, 19336107, 19483787, 19336107, 19336108, 19336108, 19483787, 19483812, 19336108, 19336109, 19336109, 19371503, 19423855, 19460297, 19483788, 19675384, 19675410, 19732166, 19336109, 19336110, 19336110, 19336112, 19371503, 19377023, 19377024, 19377025, 19383912, 19428279, 19438034, 19438138, 19450747, 19450751, 19460297, 19483785, 19483788, 19483788, 19483813, 19483817, 19483818, 19336110, 19336111, 19336117, 19371503, 19377022, 19377023, 19450750, 19450751, 19450752, 19483789, 19483813, 19483815, 19377024, 19450238, 19483789, 19483789, 19483790, 19483790, 19483791, 19371511, 19406912, 19406897, 19406912, 19406913, 19406914, 19406915, 19406913, 19519198, 19519198, 19519199, 19519201, 19417951, 19417951, 19417938, 19417949, 19417953, 19417952, 19417954, 19417953, 19417954, 19417954, 19524714, 19417967, 19524717, 19524717, 19524717, 19524718, 19469487, 19431730, 19531606, 19511618, 19571550, 19520460, 19520461, 19575971, 19575995, 19521019, 19576250, 19539977, 19585731, 19540180, 19540291, 19540400, 19585939, 19564380, 19564385, 19597932, 19846334, 19565400, 19565402, 19565408, 19565398, 19565408, 19565409, 19598441, 19565419, 19598441, 19598445, 19598469, 19598446, 19584499, 19584499, 19607990, 19607990, 19631463, 19631464, 19631467, 19631468, 19631469, 19631470, 19631470, 19631471, 19631471, 19631472, 19631472, 19631477, 19631478, 19631479, 19631479, 19631480, 19631486, 19631488, 19631489, 19631489, 19631490, 19631491, 19631491, 19631492, 19631492, 19631524, 19631543, 19631546, 19631490, 19631492, 19631493, 19631471, 19631472, 19631473, 19631493, 19631494, 19631492, 19631493, 19631493, 19631494, 19631494, 19631494, 19631495, 19631495, 19631495, 19631495, 19631496, 19631496, 19631496, 19631501, 19631503, 19631503, 19631503, 19631504, 19631511, 19631513, 19631511, 19631511, 19631514, 19631512, 19631513, 19631514, 19631514, 19631568, 19631513, 19631514, 19631515, 19631541, 19631515, 19631515, 19631530, 19631515, 19631516, 19631516, 19631534, 19631538, 19631542, 19631542, 19631567, 19631568, 19631517, 19631518, 19631518, 19631519, 19631519, 19631520, 19631520, 19631521, 19631521, 19631522, 19631524, 19631524, 19631525, 19631525, 19631527, 19631527, 19631528, 19631529, 19631530, 19631530, 19631531, 19631531, 19631532, 19631533, 19631534, 19631535, 19631535, 19631536, 19631537, 19631538, 19631538, 19631539, 19631539, 19631540, 19631540, 19631541, 19631541, 19631542, 19631542, 19631543, 19631543, 19631544, 19631545, 19631545, 19631546, 19631546, 19631547, 19631547, 19631548, 19631549, 19631554, 19631556, 19631558, 19631563, 19631567, 19631568, 19631518, 19631519, 19631519, 19631521, 19631521, 19631522, 19631529, 19631530, 19631535, 19631535, 19631537, 19631538, 19631538, 19631539, 19631540, 19631540, 19631541, 19631542, 19631543, 19631543, 19631544, 19631544, 19631546, 19631549, 19631568, 19631522, 19631523, 19631531, 19631532, 19631536, 19631537, 19631542, 19631543, 19631544, 19631552, 19631569, 19631522, 19631522, 19631531, 19631544, 19631544, 19631550, 19631542, 19631544, 19631545, 19631570, 19631524, 19631532, 19631543, 19631543, 19631544, 19631545, 19631545, 19631538, 19631539, 19631543, 19631543, 19631547, 19631526, 19631534, 19631541, 19631542, 19631544, 19631545, 19631547, 19631547, 19631549, 19631561, 19631572, 19631533, 19631541, 19631542, 19631543, 19631546, 19631549, 19631532, 19631540, 19631541, 19631542, 19631543, 19631544, 19631544, 19631545, 19631546, 19631547, 19631573, 19631544, 19631545, 19631546, 19631551, 19631575, 19631548, 19631548, 19631541, 19631544, 19631539, 19631546, 19631550, 19631550, 19631578, 19631549, 19631549, 19631550, 19631552, 19631554, 19631554, 19631555, 19631579, 19631551, 19631553, 19631555, 19631547, 19631550, 19631558, 19631548, 19631550, 19631554, 19631555, 19631555, 19631556, 19631562, 19631549, 19631549, 19631557, 19631559, 19631584, 19631552, 19631555, 19631557, 19631557, 19631558, 19631560, 19631561, 19631561, 19631562, 19631566, 19631583, 19631585, 19631588, 19631553, 19631555, 19631558, 19631558, 19631559, 19631560, 19631561, 19631562, 19631563, 19631564, 19631567, 19631570, 19631580, 19631585, 19631586, 19631556, 19631557, 19631561, 19631561, 19631566, 19631567, 19631586, 19631557, 19631559, 19631564, 19631565, 19631571, 19631587, 19631588, 19631581, 19631558, 19631559, 19631560, 19631560, 19631561, 19631563, 19631563, 19631564, 19631564, 19631566, 19631566, 19631567, 19631568, 19631568, 19631569, 19631588, 19879861, 19631560, 19631560, 19631561, 19631562, 19631563, 19631564, 19631567, 19631570, 19631574, 19631588, 19631589, 19631561, 19631561, 19631562, 19631562, 19631563, 19631564, 19631565, 19631565, 19631566, 19631567, 19631570, 19631570, 19631571, 19631573, 19631589, 19631590, 19631590, 19631562, 19631563, 19631564, 19631565, 19631565, 19631566, 19631566, 19631567, 19631567, 19631568, 19631570, 19631571, 19631589, 19631590, 19631591, 19631563, 19631564, 19631565, 19631565, 19631566, 19631566, 19631567, 19631567, 19631568, 19631568, 19631569, 19631570, 19631572, 19631578, 19631591, 19631564, 19631565, 19631566, 19631566, 19631567, 19631567, 19631568, 19631569, 19631589, 19631591, 19631566, 19631566, 19631567, 19631567, 19631568, 19631569, 19631570, 19631573, 19631592, 19631567, 19631568, 19631568, 19631567, 19631568, 19631568, 19631569, 19631570, 19631570, 19631571, 19631593, 19631568, 19631569, 19631569, 19631570, 19631570, 19631571, 19631571, 19631572, 19631572, 19631574, 19631575, 19631578, 19631586, 19631587, 19631590, 19631590, 19631593, 19631569, 19631570, 19631570, 19631571, 19631571, 19631572, 19631572, 19631573, 19631574, 19631575, 19631578, 19631579, 19631588, 19631589, 19631591, 19631592, 19631594, 19631570, 19631571, 19631572, 19631572, 19631573, 19631573, 19631574, 19631574, 19631575, 19631575, 19631578, 19631579, 19631579, 19631582, 19631586, 19631588, 19631590, 19631593, 19631593, 19631594, 19631571, 19631572, 19631572, 19631573, 19631573, 19631574, 19631574, 19631576, 19631576, 19631578, 19631579, 19631580, 19631585, 19631587, 19631587, 19631589, 19631592, 19631593, 19631594, 19631595, 19631572, 19631573, 19631574, 19631578, 19631586, 19631587, 19631595, 19631595, 19631573, 19631574, 19631574, 19631575, 19631575, 19631577, 19631577, 19631581, 19631582, 19631584, 19631586, 19631594, 19631596, 19631574, 19631575, 19631575, 19631576, 19631577, 19631578, 19631579, 19631581, 19631583, 19631589, 19631590, 19631592, 19631594, 19631595, 19631596, 19631596, 19631575, 19631576, 19631576, 19631577, 19631578, 19631590, 19631596, 19631596, 19631597, 19631576, 19631577, 19631577, 19631578, 19631581, 19631582, 19631582, 19631588, 19631589, 19631593, 19631594, 19631595, 19631597, 19631597, 19631579, 19631582, 19631582, 19631584, 19631591, 19631592, 19631594, 19631597, 19631598, 19823145, 19631578, 19631579, 19631580, 19631582, 19631591, 19631596, 19631597, 19631598, 19631598, 19631579, 19631580, 19631596, 19631598, 19631599, 19631580, 19631581, 19631599, 19631582, 19631583, 19631585, 19631585, 19631586, 19631589, 19631590, 19631590, 19631592, 19631593, 19631593, 19631594, 19631594, 19631595, 19631597, 19631598, 19631598, 19631599, 19631599, 19631600, 19631602, 19631584, 19631587, 19631595, 19631596, 19631597, 19631598, 19631600, 19631591, 19631601, 19631602, 19631588, 19631600, 19631602, 19631600, 19631603, 19631590, 19631596, 19631599, 19631600, 19631602, 19631603, 19631591, 19631596, 19631601, 19631602, 19631603, 19631604, 19631597, 19631604, 19631605, 19631597, 19631603, 19631605, 19631605, 19631604, 19631606, 19631607, 19631607, 19631608, 19631601, 19631601, 19631602, 19631603, 19631609, 19631602, 19631610, 19631603, 19631605, 19631607, 19631609, 19631610, 19631611, 19631606, 19631611, 19631606, 19631606, 19631608, 19631612, 19631608, 19631612, 19631612, 19631612, 19631613, 19631613, 19631613, 19631610, 19631613, 19631613, 19631614, 19631611, 19631614, 19631614, 19631612, 19631614, 19631615, 19631615, 19631615, 19631615, 19631616, 19631615, 19631616, 19631616, 19631615, 19631617, 19631619, 19631617, 19631617, 19823164, 19879920, 19631617, 19631618, 19631620, 19631618, 19631619, 19631620, 19631620, 19631621, 19631621, 19631622, 19631624, 19631625, 19631628, 19631629, 19631630, 19631631, 19631632, 19631634, 19631637, 19631637, 19631638, 19631639, 19631640, 19631640, 19631641, 19631641, 19631642, 19631642, 19631643, 19631643, 19787752, 19823139, 19823139, 19823166, 19823193, 19879921, 19879946, 19879986, 21930687, 19631620, 19631621, 19631621, 19631622, 19631622, 19631624, 19631625, 19631629, 19631631, 19631634, 19631638, 19631639, 19631640, 19631641, 19631641, 19631642, 19631642, 19631643, 19631643, 19631644, 19879922, 19631622, 19631643, 19631643, 19631644, 19631622, 19631645, 19631623, 19631626, 19631627, 19631631, 19631639, 19631643, 19631643, 19631644, 19631644, 19631645, 19631645, 19631624, 19631627, 19631630, 19631643, 19631644, 19631645, 19631645, 19631646, 19823142, 19631627, 19631632, 19631644, 19631645, 19631646, 19631630, 19631647, 19631647, 19631641, 19631643, 19631644, 19631645, 19631646, 19631647, 19631647, 19631648, 19631648, 19631649, 19631650, 19631646, 19631652, 19631649, 19631649, 19631650, 19631651, 19631652, 19823177, 19631653, 19631645, 19631655, 19631654, 19631655, 19631657, 19631658, 19631659, 19631659, 19631660, 19631660, 19631661, 19631661, 19631660, 19631661, 19631661, 19631661, 19631662, 19631663, 19631661, 19631662, 19631662, 19631663, 19631663, 19631663, 19631664, 19631663, 19631664, 19631664, 19631665, 19631663, 19631664, 19631664, 19631665, 19631664, 19631665, 19631665, 19631666, 19631665, 19631666, 19631666, 19631666, 19631667, 19879915, 19631667, 19631668, 19631669, 19681627, 19754038, 19787778, 19787782, 19787782, 19787784, 19787785, 19787787, 19802464, 19803381, 19823163, 19823164, 19823190, 19823218, 19879916, 19879967, 19879969, 19880010, 19880518, 19880555, 19880556, 20517909, 20676722, 19823164, 19823164, 19823165, 19731642, 19731721, 19731820, 19873277, 19876423, 19876424, 19945548, 19945549, 19943900, 19943910, 19943916, 19943915, 19943917, 19943918, 19943919, 19943919, 19943922, 19979314, 19979296, 19979296, 19979298, 19979298, 19979298, 19973274, 19984513, 19975149, 19975222, 19994949, 19995765, 20005225, 20014659, 20014660, 20014661, 20014662, 20014662, 20014664, 20014668, 20014669, 20014670, 20014671, 20014685, 20014686, 20014686, 20014687, 20014735, 20014686, 20014686, 20014687, 20014686, 20014687, 20014688, 20014689, 20014690, 20014694, 20014696, 20014696, 20014697, 20014758, 20014711, 20014712, 20014712, 20014713, 20014714, 20014714, 20014715, 20014715, 20014716, 20014716, 20014717, 20014718, 20014718, 20014720, 20014721, 20014722, 20014723, 20014724, 20014724, 20014725, 20014725, 20014726, 20014726, 20014728, 20014728, 20014729, 20014730, 20014730, 20014731, 20014731, 20014732, 20014732, 20014733, 20014733, 20014734, 20014734, 20014735, 20014735, 20014736, 20014736, 20014737, 20014737, 20014738, 20014738, 20014739, 20014739, 20014740, 20014740, 20014741, 20014742, 20014744, 20014746, 20014747, 20014749, 20014761, 20014762, 20014714, 20014715, 20014715, 20014718, 20014729, 20014730, 20014731, 20014731, 20014732, 20014734, 20014735, 20014735, 20014736, 20014736, 20014738, 20014738, 20014739, 20014739, 20014740, 20014741, 20014762, 20014716, 20014717, 20014727, 20014732, 20014733, 20014736, 20014737, 20014737, 20014738, 20014739, 20014740, 20014742, 20014763, 20014716, 20014728, 20014733, 20014735, 20014737, 20014750, 20014717, 20014719, 20014730, 20014733, 20014735, 20014736, 20014737, 20014738, 20014740, 20014734, 20014735, 20014736, 20014737, 20014738, 20014738, 20014740, 20014745, 20014735, 20014737, 20014738, 20014739, 20014737, 20014735, 20014737, 20014737, 20014738, 20014738, 20014739, 20014740, 20014740, 20014742, 20014742, 20014743, 20014766, 20014736, 20014738, 20014741, 20014749, 20014767, 20014753, 20014744, 20014752, 20014772, 20014747, 20014773, 20014749, 20014748, 20014751, 20014751, 20014740, 20014749, 20014745, 20014746, 20014750, 20014746, 20014755, 20014777, 20014752, 20014748, 20014750, 20014747, 20014748, 20014748, 20014750, 20014751, 20014753, 20014754, 20014755, 20014756, 20014757, 20014757, 20014749, 20014752, 20014753, 20014754, 20014755, 20014756, 20014759, 20014767, 20014780, 20014751, 20014752, 20014754, 20014756, 20014757, 20014780, 20014751, 20014752, 20014754, 20014755, 20014755, 20014757, 20014758, 20014758, 20014759, 20014781, 20014752, 20014753, 20014755, 20014756, 20014757, 20014753, 20014754, 20014754, 20014756, 20014757, 20014758, 20014758, 20014760, 20014764, 20868265, 20014755, 20014755, 20014756, 20014756, 20014757, 20014758, 20014759, 20014759, 20014760, 20014761, 20014764, 20014765, 20014767, 20014782, 20014782, 20014756, 20014756, 20014757, 20014758, 20014759, 20014760, 20014761, 20014762, 20014762, 20014757, 20014758, 20014759, 20014760, 20014762, 20014758, 20014759, 20014760, 20014760, 20014761, 20014771, 20014758, 20014760, 20014761, 20014762, 20014763, 20014764, 20014765, 20014768, 20014784, 20014784, 20014759, 20014760, 20014760, 20014761, 20014761, 20014762, 20014762, 20014763, 20014763, 20014764, 20014764, 20014765, 20014766, 20014767, 20014769, 20014771, 20014772, 20014773, 20014781, 20014782, 20014782, 20014784, 20014785, 20014760, 20014761, 20014761, 20014762, 20014762, 20014763, 20014763, 20014764, 20014764, 20014765, 20014762, 20014762, 20014762, 20014763, 20014764, 20014764, 20014765, 20014766, 20014769, 20014770, 20014774, 20014783, 20014786, 20014763, 20014764, 20014764, 20014765, 20014765, 20014766, 20014767, 20014768, 20014768, 20014773, 20014784, 20014787, 20014764, 20014765, 20014765, 20014766, 20014766, 20014767, 20014767, 20014769, 20014770, 20014772, 20014773, 20014774, 20014775, 20014778, 20014779, 20014784, 20014785, 20014786, 20014786, 20014787, 20014787, 20014765, 20014766, 20014766, 20014767, 20014767, 20014768, 20014769, 20014770, 20014773, 20014775, 20014778, 20014782, 20014785, 20014787, 20014788, 20014766, 20014767, 20014767, 20014768, 20014768, 20014769, 20014771, 20014772, 20014775, 20014776, 20014777, 20014781, 20014787, 20014788, 20014788, 20014767, 20014768, 20014768, 20014769, 20014770, 20014770, 20014771, 20014776, 20014777, 20014779, 20014783, 20014786, 20014786, 20014787, 20014789, 20014768, 20014769, 20014769, 20014771, 20014772, 20014776, 20014778, 20014782, 20014789, 20014789, 20014769, 20014770, 20014771, 20014772, 20014773, 20014774, 20014777, 20014783, 20014784, 20014786, 20014789, 20014790, 20014770, 20014772, 20014773, 20014777, 20014785, 20014788, 20014790, 20014772, 20014773, 20014774, 20014775, 20014776, 20014777, 20014778, 20014779, 20014787, 20014790, 20014791, 20014791, 20014774, 20014778, 20014787, 20014791, 20014792, 20014777, 20014792, 20014792, 20014793, 20014777, 20014779, 20014780, 20014780, 20014781, 20014786, 20014787, 20014789, 20014789, 20014791, 20014791, 20014792, 20014793, 20014793, 20014793, 20014794, 20014778, 20014783, 20014788, 20014794, 20014782, 20014783, 20014794, 20014795, 20014795, 20014796, 20014796, 20014795, 20014784, 20014789, 20014794, 20014797, 20014786, 20014787, 20014792, 20014795, 20014795, 20014796, 20014796, 20014797, 20014797, 20014798, 20014787, 20014798, 20014791, 20014792, 20014793, 20014795, 20014795, 20014798, 20014799, 20014799, 20014794, 20014800, 20014801, 20014801, 20014802, 20014795, 20014802, 20014797, 20014800, 20014803, 20014798, 20014799, 20014804, 20014804, 20014803, 20014805, 20014803, 20014805, 20014805, 20014802, 20014803, 20014806, 20014806, 20014807, 20014807, 20014807, 20014806, 20014807, 20014808, 20014808, 20014808, 20014809, 20014809, 20014809, 20014810, 20014810, 20014811, 20014812, 20014813, 20014813, 20014815, 20014818, 20014821, 20014823, 20014824, 20014825, 20014825, 20014826, 20014826, 20014827, 20014832, 20014835, 20014835, 20014836, 20014836, 20014837, 20014837, 20071488, 20071517, 20072032, 21406677, 22203959, 20014812, 20014813, 20014813, 20014818, 20014822, 20014824, 20014825, 20014829, 20014830, 20014831, 20014834, 20014835, 20014835, 20014836, 20014836, 20014837, 20014837, 20014838, 20071518, 20014818, 20014822, 20014826, 20014832, 20014837, 20014838, 20014838, 20014839, 20014829, 20014838, 20014839, 20014828, 20014841, 20014843, 20014839, 20014844, 20014847, 20014848, 20014849, 20014850, 20014851, 20014851, 20014841, 20014852, 20014843, 20014853, 20014853, 20014854, 20014855, 20014856, 20014856, 20014857, 20014859, 20014860, 20014861, 20014860, 20014861, 20014861, 20014862, 20014862, 20014862, 20014863, 20014863, 20014864, 20014865, 20071448, 20071514, 20071514, 20071544, 20071546, 20071562, 20071608, 20072058, 20072058, 20072154, 20868320, 20071515, 20071515, 20128098, 20128164, 20128165, 20128166, 20128166, 20128167, 20128167, 20128169, 20128174, 20128182, 20128187, 20128188, 20128191, 20128193, 20128193, 20128194, 20128194, 20128209, 20128166, 20128167, 20128190, 20128191, 20128193, 20128194, 20128194, 20128195, 20128195, 20128195, 20128192, 20128195, 20128196, 20128196, 20128196, 20128196, 20128198, 20128198, 20128203, 20128211, 20128212, 20128216, 20128217, 20128215, 20128219, 20128220, 20128220, 20128222, 20128222, 20128222, 20128223, 20128223, 20128224, 20128225, 20128225, 20128226, 20128226, 20128227, 20128227, 20128228, 20128228, 20128229, 20128229, 20128230, 20128230, 20128231, 20128231, 20128232, 20128233, 20128234, 20128235, 20128235, 20128236, 20128236, 20128237, 20128237, 20128238, 20128239, 20128240, 20128240, 20128241, 20128242, 20128242, 20128243, 20128243, 20128244, 20128244, 20128245, 20128245, 20128246, 20128246, 20128247, 20128247, 20128248, 20128248, 20128249, 20128250, 20128251, 20128251, 20128252, 20128253, 20128269, 20128270, 20128288, 20128299, 20128225, 20128226, 20128226, 20128227, 20128228, 20128229, 20128230, 20128230, 20128231, 20128231, 20128233, 20128233, 20128237, 20128239, 20128242, 20128243, 20128244, 20128244, 20128245, 20128245, 20128247, 20128247, 20128249, 20128270, 20128270, 20128226, 20128227, 20128227, 20128228, 20128230, 20128230, 20128231, 20128232, 20128238, 20128238, 20128243, 20128246, 20128247, 20128249, 20128271, 20128228, 20128229, 20128230, 20128243, 20128244, 20128246, 20128228, 20128229, 20128231, 20128231, 20128233, 20128236, 20128240, 20128244, 20128246, 20128246, 20128247, 20128252, 20128272, 20128229, 20128230, 20128232, 20128239, 20128240, 20128241, 20128245, 20128247, 20128247, 20128249, 20128230, 20128242, 20128245, 20128245, 20128232, 20128232, 20128233, 20128233, 20128241, 20128246, 20128247, 20128247, 20128248, 20128251, 20128273, 20128234, 20128246, 20128247, 20128233, 20128241, 20128247, 20128252, 20128235, 20128236, 20128241, 20128244, 20128247, 20128247, 20128249, 20128250, 20128251, 20128251, 20128252, 20128257, 20128265, 20128275, 20128238, 20128240, 20128241, 20128243, 20128247, 20128247, 20128248, 20128250, 20128250, 20128252, 20128257, 20128239, 20128242, 20128244, 20128245, 20128247, 20128248, 20128251, 20128253, 20128256, 20128276, 20128249, 20128251, 20128254, 20128276, 20128244, 20128248, 20128249, 20128258, 20128250, 20128252, 20128277, 20128244, 20128250, 20128250, 20128251, 20128253, 20128255, 20128278, 20128244, 20128251, 20128253, 20128254, 20128244, 20128252, 20128254, 20128246, 20128253, 20128281, 20128247, 20128254, 20128256, 20128256, 20128258, 20128249, 20128254, 20128255, 20128256, 20128257, 20128259, 20128259, 20128253, 20128255, 20128257, 20128252, 20128255, 20128255, 20128257, 20128263, 20128252, 20128255, 20128255, 20128256, 20128256, 20128257, 20128259, 20128261, 20128262, 20128275, 20128255, 20128256, 20128257, 20128260, 20128261, 20128266, 20128257, 20128260, 20128258, 20128262, 20128261, 20128259, 20128261, 20128260, 20128262, 20128262, 20128264, 20128279, 20128260, 20128261, 20128262, 20128263, 20128264, 20128264, 20128265, 20128276, 20128261, 20128262, 20128262, 20128263, 20128263, 20128264, 20128264, 20128265, 20128265, 20128266, 20128266, 20128267, 20128268, 20128269, 20128269, 20128270, 20128279, 20128288, 20128262, 20128263, 20128264, 20128269, 20128264, 20128264, 20128265, 20128266, 20128268, 20128289, 20128264, 20128265, 20128267, 20128267, 20128271, 20128308, 20128265, 20128266, 20128266, 20128267, 20128267, 20128268, 20128268, 20128269, 20128269, 20128271, 20128272, 20128272, 20128273, 20128274, 20128289, 20128290, 20128266, 20128267, 20128267, 20128268, 20128268, 20128269, 20128269, 20128270, 20128270, 20128271, 20128271, 20128272, 20128272, 20128273, 20128273, 20128279, 20128281, 20128285, 20128286, 20128289, 20128290, 20128291, 20128267, 20128268, 20128269, 20128269, 20128270, 20128273, 20128286, 20128268, 20128269, 20128269, 20128270, 20128270, 20128271, 20128272, 20128272, 20128273, 20128292, 20128269, 20128270, 20128270, 20128271, 20128272, 20128273, 20128273, 20128274, 20128283, 20128286, 20128290, 20128292, 20128292, 20128270, 20128271, 20128271, 20128272, 20128273, 20128273, 20128274, 20128274, 20128275, 20128276, 20128288, 20128292, 20128293, 20128271, 20128272, 20128272, 20128273, 20128273, 20128274, 20128274, 20128275, 20128275, 20128277, 20128278, 20128279, 20128283, 20128284, 20128284, 20128288, 20128290, 20128291, 20128293, 20128293, 20128272, 20128273, 20128273, 20128274, 20128274, 20128275, 20128275, 20128276, 20128276, 20128278, 20128279, 20128281, 20128283, 20128284, 20128287, 20128288, 20128290, 20128293, 20128294, 20128273, 20128274, 20128274, 20128275, 20128275, 20128276, 20128276, 20128277, 20128278, 20128279, 20128281, 20128284, 20128288, 20128291, 20128292, 20128294, 20128275, 20128275, 20128276, 20128276, 20128278, 20128281, 20128293, 20128295, 20128275, 20128276, 20128276, 20128277, 20128277, 20128279, 20128281, 20128282, 20128283, 20128288, 20128294, 20128295, 20128276, 20128277, 20128277, 20128278, 20128278, 20128281, 20128286, 20128290, 20128291, 20128292, 20128295, 20128296, 20128277, 20128278, 20128278, 20128283, 20128285, 20128286, 20128290, 20128291, 20128292, 20128293, 20128294, 20128294, 20128296, 20128296, 20128278, 20128279, 20128280, 20128281, 20128283, 20128284, 20128284, 20128286, 20128287, 20128287, 20128288, 20128291, 20128294, 20128295, 20128296, 20128296, 20128297, 20128279, 20128280, 20128281, 20128281, 20128282, 20128284, 20128285, 20128287, 20128289, 20128291, 20128292, 20128292, 20128293, 20128295, 20128296, 20128297, 20128297, 20128280, 20128281, 20128281, 20128284, 20128284, 20128285, 20128286, 20128289, 20128291, 20128291, 20128293, 20128295, 20128295, 20128297, 20128297, 20128298, 20128289, 20128292, 20128295, 20128298, 20128299, 20128283, 20128291, 20128292, 20128293, 20128295, 20128296, 20128299, 20128286, 20128300, 20128299, 20128300, 20128287, 20128292, 20128296, 20128301, 20128288, 20128292, 20128295, 20128301, 20128302, 20128299, 20128293, 20128295, 20128299, 20128299, 20128300, 20128302, 20128303, 20128293, 20128299, 20128303, 20128299, 20128304, 20128304, 20128305, 20128295, 20128300, 20128300, 20128305, 20128306, 20128301, 20128304, 20128306, 20128306, 20128306, 20128307, 20128307, 20128304, 20128307, 20128308, 20128309, 20128309, 20128305, 20128306, 20128307, 20128308, 20128308, 20128310, 20128310, 20128307, 20128309, 20128310, 20128311, 20128307, 20128311, 20128308, 20128309, 20128310, 20128312, 20128311, 20128312, 20128312, 20128311, 20128313, 20128313, 20128312, 20128314, 20128313, 20128314, 20128314, 20128315, 20128315, 20128316, 20128317, 20128317, 20128318, 20128319, 20128321, 20128322, 20128325, 20128325, 20128329, 20128329, 20128330, 20128331, 20128333, 20128334, 20128334, 20128335, 20128338, 20128339, 20128340, 20128340, 20128341, 20128342, 20128342, 20128343, 20128343, 20128344, 20128344, 20128345, 20128345, 20128784, 20128785, 20128814, 20128815, 20128815, 20128819, 20128827, 20128831, 20128835, 20128837, 20128879, 20128880, 20925046, 20128317, 20128318, 20128318, 20128319, 20128322, 20128325, 20128328, 20128328, 20128329, 20128330, 20128331, 20128334, 20128335, 20128336, 20128339, 20128340, 20128341, 20128342, 20128342, 20128343, 20128343, 20128344, 20128344, 20128345, 20128345, 20128346, 20128330, 20128334, 20128340, 20128344, 20128345, 20128345, 20128346, 20128346, 20128323, 20128326, 20128335, 20128344, 20128346, 20128347, 20128342, 20128345, 20128346, 20128347, 20128348, 20128339, 20128345, 20128351, 20128351, 20128342, 20128353, 20128353, 20128354, 20128354, 20128355, 20128357, 20128354, 20128353, 20128356, 20128358, 20128354, 20128356, 20128355, 20128358, 20128361, 20128353, 20128356, 20128357, 20128359, 20128361, 20128361, 20128362, 20128362, 20128363, 20128363, 20128354, 20128360, 20128363, 20128363, 20128364, 20128359, 20128363, 20128365, 20128363, 20128358, 20128365, 20128367, 20128363, 20128366, 20128368, 20128365, 20128367, 20128368, 20128368, 20128369, 20128866, 20128369, 20128370, 20128367, 20128368, 20128368, 20128369, 20128370, 20128368, 20128369, 20128370, 20128371, 20128371, 20128370, 20128371, 20128372, 20128370, 20128371, 20128371, 20128372, 20128372, 20128371, 20128372, 20128372, 20128373, 20128812, 20128372, 20128373, 20128373, 20128373, 20128374, 20128374, 20128375, 20128376, 20128813, 20128814, 20128843, 20128843, 20128844, 20128845, 20128845, 20128846, 20128847, 20128848, 20128864, 20128865, 20128872, 20128908, 20128910, 20638446, 20638446, 20766264, 20766265, 20811993, 20925076, 21681247, 20128814, 20128814, 20128815, 20129252, 20129253, 20129254, 20129254, 20129255, 20129255, 20129256, 20129257, 20129260, 20129264, 20129272, 20129273, 20129275, 20129280, 20129281, 20129281, 20129282, 20129282, 20129283, 20129283, 20129284, 20129284, 20129285, 20129328, 20129254, 20129257, 20129282, 20129282, 20129283, 20129283, 20129284, 20129256, 20129257, 20129274, 20129282, 20129283, 20129283, 20129284, 20129284, 20129285, 20129284, 20129284, 20129285, 20129284, 20129285, 20129286, 20129287, 20129287, 20129291, 20129293, 20129293, 20129302, 20129302, 20129302, 20129304, 20129306, 20129309, 20129311, 20129310, 20129311, 20129311, 20129312, 20129312, 20129313, 20129313, 20129312, 20129313, 20129313, 20129314, 20129314, 20129316, 20129324, 20129329, 20129332, 20129333, 20129334, 20129337, 20129358, 20129313, 20129314, 20129314, 20129316, 20129316, 20129320, 20129321, 20129330, 20129332, 20129333, 20129333, 20129334, 20129335, 20129336, 20129337, 20129341, 20129342, 20129348, 20129358, 20129314, 20129315, 20129315, 20129316, 20129316, 20129328, 20129330, 20129333, 20129334, 20129335, 20129337, 20129353, 20129359, 20129315, 20129316, 20129316, 20129317, 20129318, 20129318, 20129319, 20129322, 20129325, 20129330, 20129331, 20129333, 20129333, 20129334, 20129334, 20129335, 20129335, 20129336, 20129337, 20129338, 20129342, 20129359, 20129316, 20129317, 20129317, 20129318, 20129318, 20129319, 20129320, 20129321, 20129322, 20129323, 20129323, 20129325, 20129325, 20129326, 20129326, 20129327, 20129328, 20129331, 20129331, 20129334, 20129334, 20129335, 20129336, 20129336, 20129337, 20129337, 20129338, 20129339, 20129339, 20129340, 20129340, 20129341, 20129341, 20129342, 20129348, 20129359, 20129360, 20129317, 20129318, 20129318, 20129320, 20129320, 20129321, 20129321, 20129322, 20129323, 20129323, 20129324, 20129324, 20129325, 20129325, 20129326, 20129326, 20129327, 20129329, 20129330, 20129331, 20129332, 20129333, 20129334, 20129335, 20129335, 20129336, 20129336, 20129337, 20129337, 20129338, 20129338, 20129340, 20129340, 20129342, 20129356, 20129358, 20129360, 20129318, 20129319, 20129319, 20129320, 20129321, 20129322, 20129323, 20129326, 20129328, 20129329, 20129330, 20129332, 20129332, 20129333, 20129334, 20129335, 20129335, 20129336, 20129337, 20129337, 20129338, 20129339, 20129340, 20129350, 20129361, 20129319, 20129320, 20129321, 20129321, 20129322, 20129325, 20129327, 20129328, 20129329, 20129333, 20129335, 20129335, 20129336, 20129336, 20129339, 20129339, 20129361, 20129320, 20129321, 20129321, 20129322, 20129322, 20129323, 20129323, 20129324, 20129325, 20129327, 20129327, 20129329, 20129329, 20129330, 20129333, 20129336, 20129336, 20129337, 20129337, 20129338, 20129338, 20129339, 20129340, 20129342, 20129343, 20129344, 20129361, 20129362, 20129328, 20129333, 20129337, 20129337, 20129362, 20129334, 20129338, 20129342, 20129363, 20129323, 20129328, 20129328, 20129331, 20129334, 20129337, 20129337, 20129338, 20129338, 20129329, 20129330, 20129331, 20129332, 20129335, 20129338, 20129339, 20129339, 20129340, 20129329, 20129333, 20129335, 20129340, 20129330, 20129332, 20129336, 20129331, 20129333, 20129334, 20129340, 20129341, 20129341, 20129344, 20129332, 20129341, 20129342, 20129347, 20129331, 20129332, 20129338, 20129338, 20129367, 20129338, 20129344, 20129345, 20129346, 20129340, 20129343, 20129344, 20129333, 20129340, 20129343, 20129334, 20129338, 20129340, 20129344, 20129345, 20129349, 20129369, 20129336, 20129337, 20129338, 20129341, 20129343, 20129343, 20129344, 20129344, 20129345, 20129346, 20129347, 20129349, 20129355, 20129369, 20129344, 20129344, 20129346, 20129346, 20129348, 20129350, 20129339, 20129342, 20129345, 20129345, 20129346, 20129347, 20129353, 20129371, 20129342, 20129346, 20129346, 20129347, 20129368, 20129346, 20129343, 20129344, 20129345, 20129346, 20129347, 20129347, 20129348, 20129348, 20129352, 20129347, 20129348, 20129349, 20129352, 20129349, 20129352, 20129366, 20766750, 20129346, 20129349, 20129350, 20129351, 20129355, 20129373, 20129375, 20129348, 20129349, 20129349, 20129350, 20129350, 20129351, 20129352, 20129353, 20129356, 20129357, 20129358, 20129375, 20129351, 20129351, 20129352, 20129351, 20129353, 20129357, 20129352, 20129353, 20129356, 20129358, 20129377, 20129352, 20129353, 20129354, 20129354, 20129356, 20129357, 20129359, 20129360, 20129360, 20129377, 20129378, 20129353, 20129354, 20129355, 20129355, 20129356, 20129356, 20129357, 20129358, 20129358, 20129359, 20129359, 20129360, 20129361, 20129361, 20129377, 20129378, 20129354, 20129355, 20129355, 20129356, 20129356, 20129357, 20129357, 20129358, 20129358, 20129359, 20129359, 20129360, 20129360, 20129361, 20129361, 20129362, 20129363, 20129367, 20129369, 20129370, 20129371, 20129371, 20129378, 20129378, 20129379, 20129355, 20129356, 20129357, 20129360, 20129360, 20129361, 20129379, 20129356, 20129357, 20129358, 20129359, 20129359, 20129360, 20129360, 20129361, 20129361, 20129362, 20129362, 20129371, 20129372, 20129379, 20129380, 20129357, 20129358, 20129358, 20129359, 20129360, 20129360, 20129361, 20129361, 20129362, 20129362, 20129363, 20129364, 20129372, 20129375, 20129377, 20129379, 20129380, 20129380, 20129358, 20129359, 20129359, 20129361, 20129362, 20129373, 20129377, 20129378, 20129381, 20129359, 20129360, 20129360, 20129361, 20129361, 20129362, 20129363, 20129363, 20129364, 20129364, 20129368, 20129376, 20129381, 20129381, 20129360, 20129361, 20129361, 20129362, 20129362, 20129363, 20129363, 20129364, 20129364, 20129378, 20129379, 20129380, 20129382, 20129361, 20129363, 20129364, 20129365, 20129379, 20129382, 20129362, 20129363, 20129363, 20129364, 20129365, 20129365, 20129372, 20129375, 20129376, 20129380, 20129381, 20129381, 20129383, 20129363, 20129364, 20129364, 20129365, 20129365, 20129366, 20129371, 20129375, 20129376, 20129377, 20129379, 20129381, 20129382, 20129383, 20129364, 20129365, 20129365, 20129366, 20129366, 20129367, 20129375, 20129376, 20129379, 20129380, 20129382, 20129383, 20129384, 20129365, 20129366, 20129366, 20129367, 20129367, 20129368, 20129370, 20129372, 20129374, 20129376, 20129379, 20129379, 20129380, 20129382, 20129384, 20129366, 20129367, 20129367, 20129368, 20129368, 20129370, 20129373, 20129375, 20129376, 20129377, 20129378, 20129381, 20129384, 20129385, 20129367, 20129368, 20129368, 20129369, 20129372, 20129374, 20129377, 20129377, 20129380, 20129385, 20129385, 20129368, 20129369, 20129369, 20129371, 20129372, 20129374, 20129376, 20129377, 20129378, 20129378, 20129379, 20129382, 20129383, 20129383, 20129384, 20129384, 20129385, 20129385, 20129386, 20129369, 20129370, 20129370, 20129371, 20129372, 20129373, 20129373, 20129377, 20129378, 20129378, 20129379, 20129381, 20129381, 20129382, 20129382, 20129383, 20129384, 20129385, 20129385, 20129386, 20129386, 20129370, 20129371, 20129373, 20129373, 20129374, 20129375, 20129376, 20129378, 20129379, 20129385, 20129386, 20129387, 20129374, 20129379, 20129385, 20129387, 20129374, 20129376, 20129380, 20129386, 20129386, 20129387, 20129387, 20129388, 20129378, 20129387, 20129389, 20129389, 20129381, 20129383, 20129387, 20129390, 20129383, 20129386, 20129388, 20129390, 20129385, 20129389, 20129391, 20129383, 20129385, 20129390, 20129384, 20129390, 20129392, 20129392, 20129393, 20129387, 20129389, 20129393, 20129393, 20129391, 20129394, 20129387, 20129392, 20129394, 20129395, 20129395, 20129395, 20129389, 20129391, 20129392, 20129394, 20129395, 20129395, 20129396, 20129390, 20129396, 20129393, 20129397, 20129395, 20129396, 20129397, 20129392, 20129397, 20129398, 20129393, 20129395, 20129398, 20129395, 20129398, 20129399, 20129395, 20129397, 20129399, 20129396, 20129397, 20129397, 20129398, 20129400, 20129397, 20129399, 20129400, 20129400, 20129400, 20129401, 20129401, 20129401, 20129401, 20129402, 20129402, 20129402, 20129403, 20129403, 20129404, 20129405, 20129405, 20129406, 20129406, 20129407, 20129408, 20129410, 20129410, 20129411, 20129411, 20129412, 20129412, 20129413, 20129413, 20129414, 20129415, 20129415, 20129416, 20129416, 20129417, 20129417, 20129418, 20129418, 20129419, 20129422, 20129422, 20129423, 20129423, 20129424, 20129424, 20129427, 20129429, 20129430, 20129431, 20129432, 20129433, 20129433, 20129434, 20129434, 20129435, 20638960, 20766780, 20925590, 20129405, 20129406, 20129406, 20129408, 20129409, 20129409, 20129410, 20129410, 20129411, 20129411, 20129412, 20129413, 20129414, 20129415, 20129416, 20129417, 20129417, 20129418, 20129418, 20129419, 20129419, 20129423, 20129423, 20129424, 20129425, 20129427, 20129431, 20129433, 20129433, 20129434, 20129434, 20129435, 20129435, 20129407, 20129408, 20129409, 20129410, 20129410, 20129411, 20129412, 20129412, 20129413, 20129414, 20129416, 20129417, 20129418, 20129418, 20129419, 20129421, 20129423, 20129433, 20129434, 20129434, 20129435, 20129436, 20129418, 20129419, 20129419, 20129436, 20766780, 20129426, 20129437, 20129417, 20129426, 20129437, 20129420, 20129421, 20129427, 20129427, 20129437, 20129438, 20129418, 20129422, 20129439, 20129417, 20129418, 20129417, 20129422, 20129424, 20129419, 20129421, 20129421, 20129423, 20129440, 20129422, 20129423, 20129430, 20129441, 20129422, 20129424, 20129429, 20129429, 20129430, 20129431, 20129441, 20129442, 20129424, 20129425, 20129431, 20129436, 20129438, 20129421, 20129442, 20129443, 20129435, 20129422, 20129424, 20129424, 20129425, 20129427, 20129432, 20129438, 20129444, 20129424, 20129425, 20129426, 20129426, 20129427, 20129425, 20129426, 20129427, 20129429, 20129429, 20129430, 20129434, 20129440, 20129442, 20129445, 20129446, 20129428, 20129429, 20129430, 20129434, 20129444, 20129446, 20129429, 20129446, 20129447, 20129429, 20129430, 20129431, 20129436, 20129445, 20129447, 20129447, 20129430, 20129431, 20129436, 20129442, 20129446, 20129447, 20129448, 20129431, 20129432, 20129436, 20129443, 20129444, 20129446, 20129446, 20129447, 20129448, 20129448, 20129432, 20129433, 20129437, 20129437, 20129438, 20129439, 20129443, 20129445, 20129446, 20129447, 20129447, 20129448, 20129448, 20129449, 20129437, 20129438, 20129445, 20129447, 20129449, 20129449, 20129434, 20129438, 20129450, 20129438, 20129450, 20129451, 20129453, 20129443, 20129450, 20129451, 20129452, 20129453, 20129442, 20129443, 20129443, 20129454, 20129443, 20129444, 20129446, 20129451, 20129453, 20129453, 20129454, 20129454, 20129444, 20129454, 20129455, 20129445, 20129446, 20129447, 20129452, 20129453, 20129454, 20129455, 20129455, 20129446, 20129455, 20129455, 20129456, 20129453, 20129455, 20129456, 20129457, 20129455, 20129456, 20129458, 20129458, 20129458, 20129460, 20129460, 20129461, 20129460, 20129461, 20129460, 20129461, 20129462, 20129462, 20129463, 20129461, 20129462, 20129463, 20129463, 20129462, 20129463, 20129463, 20129464, 20129464, 20129464, 20129464, 20129465, 20129465, 20129466, 20129486, 20129488, 20129504, 20129534, 20195257, 20195258, 20195258, 20195260, 20195261, 20208648, 20208688, 20228000, 20228001, 20228002, 20228003, 20302056, 20302057, 20302058, 20302074, 20302075, 20302081, 20302279, 20302291, 20328315, 20396384, 20417712, 20435251, 20560370, 20587301, 20587302, 20612498, 20612499, 20612499, 20612501, 20638986, 20638988, 20638988, 20638989, 20638989, 20638990, 20638991, 20638991, 20638992, 20638992, 20638993, 20638993, 20638994, 20678028, 20725426, 20766808, 20766808, 20766809, 20766809, 20766810, 20766810, 20766811, 20766811, 20766812, 20766813, 20812539, 20812539, 20812540, 20812541, 20812543, 20812545, 20812546, 20812547, 20812547, 20812548, 20906320, 20906320, 20906323, 20906324, 20906325, 20906327, 20906327, 20906328, 20925621, 20925621, 20925653, 21025298, 21146728, 21464004, 21651000, 22179611, 22198006, 20302075, 20302075, 20302279, 20512329, 20612498, 20638986, 20638989, 20638990, 20638992, 20638992, 20638993, 20766809, 20766810, 20766811, 20906326, 20906331, 20925622, 20925654, 20925642, 20639013, 20129617, 20766878, 20925735, 20261064, 20261065, 20261065, 20261067, 20261068, 20293810, 20367881, 20704798, 20832617, 20991428, 20293811, 20704795, 20991428, 20287841, 20287881, 20287922, 20287921, 20985551, 20846044, 20326536, 20326548, 20326549, 20326552, 20326551, 20326554, 20326553, 20326554, 20326554, 20400622, 20400629, 20737539, 20737535, 20400624, 20737539, 21024171, 20483898, 20737542, 20737540, 20474665, 20474665, 20474685, 20474686, 20474688, 20474688, 20474689, 20474690, 20474683, 20474706, 20474708, 20474708, 20474709, 20474707, 20474707, 20474708, 20474709, 20474709, 20474716, 20785129, 20811621, 20811621, 20474910, 20811623, 20939442, 20985170, 20474732, 20811623, 21098253, 20474733, 20811624, 20474733, 20811624, 20811625, 20474734, 20474913, 20811624, 20811625, 20811625, 21078904, 21098255, 20474913, 20607886, 20684963, 20785134, 20785136, 20811621, 20811621, 20811622, 20811623, 20811623, 20811624, 20811625, 20811626, 20811627, 20939443, 20939443, 20939444, 20985174, 20985181, 21078953, 21078954, 21098256, 20475114, 20475126, 20616758, 20785331, 20811826, 20811826, 20811827, 20939643, 20939644, 20939645, 20955532, 21098456, 20527175, 20837852, 20641240, 20894886, 20663358, 20905962, 20705968, 20706152, 20706335, 21055250, 20741049, 20944789, 20758412, 21220821, 20895204, 20895208, 21149685, 21149689, 20991286, 21069909, 21045154, 21045155, 21096843, 21096844, 21095548, 21095550, 21095544, 21095551, 21095550, 21095552, 21095550, 21095552, 21095552, 21095554, 21095554, 21122037, 21389379, 21122041, 21122042, 21295597, 21122043, 21389238, 21122043, 21122044, 21408673, 21122044, 21122044, 21148510, 21148510, 21148512, 21148512, 21148525, 21148513, 21148513, 21148528, 21148528, 21148514, 21148515, 21148528, 21148529, 21148514, 21148529, 21148514, 21148515, 21148525, 21148527, 21148528, 21148529, 21148515, 21148516, 21148529, 21148530, 21148516, 21148516, 21148518, 21148531, 21148517, 21148518, 21148518, 21148519, 21148520, 21148527, 21148528, 21148530, 21148530, 21148531, 21148532, 21148532, 21148518, 21148519, 21148519, 21148520, 21148520, 21148532, 21148532, 21148533, 21148533, 21148534, 21148534, 21148535, 21148519, 21148520, 21148520, 21148522, 21148533, 21148534, 21148534, 21148535, 21148535, 21148536, 21148520, 21148521, 21148521, 21148522, 21148532, 21148533, 21148534, 21148535, 21148535, 21148521, 21148522, 21148534, 21148534, 21148535, 21148535, 21148536, 21148522, 21148534, 21148536, 21148535, 21148536, 21148538, 21148537, 21148536, 21148538, 21148542, 21435157, 21148543, 21435159, 21148545, 21276349, 21435160, 21148545, 21148546, 21435161, 21148546, 21415861, 21415866, 21435161, 21148547, 21148548, 21148548, 21148549, 21148549, 21148550, 21276348, 21276348, 21276349, 21276349, 21276350, 21276350, 21276351, 21276351, 21288969, 21292237, 21322080, 21322080, 21322082, 21322083, 21322084, 21322087, 21322087, 21322088, 21322089, 21415727, 21415805, 21415858, 21415860, 21415860, 21415862, 21415863, 21415865, 21415865, 21415866, 21415868, 21415869, 21415870, 21435161, 21435162, 21435194, 21656268, 21148548, 21148549, 21148549, 21276349, 21276349, 21276351, 21276351, 21276352, 21415862, 21435162, 21148549, 21148550, 21148551, 21180646, 21276350, 21276351, 21276351, 21276352, 21322081, 21322082, 21435163, 21435210, 21519767, 21148550, 21148551, 21148551, 21152288, 21180645, 21276352, 21276352, 21322081, 21322081, 21415792, 21415864, 21435163, 21148551, 21148552, 21276351, 21276351, 21276352, 21276352, 21276353, 21276353, 21276354, 21276354, 21322082, 21322082, 21322083, 21322084, 21322085, 21322089, 21322089, 21322090, 21415797, 21415872, 21435164, 21148552, 21276352, 21276353, 21276354, 21276355, 21322082, 21322082, 21322088, 21322089, 21322090, 21435164, 21148554, 21157340, 21276352, 21276353, 21276353, 21276354, 21276354, 21322082, 21322083, 21322084, 21322086, 21322087, 21322089, 21435165, 21322090, 21156039, 21280103, 21166142, 21330892, 21212758, 21212759, 21308465, 21308465, 21226608, 21315390, 21321402, 21521597, 21404164, 21404152, 21404152, 21404165, 21404165, 21404166, 21404151, 21404152, 21404152, 21404153, 21404166, 21404166, 21404167, 21404167, 21404168, 21404168, 21404169, 21404152, 21404153, 21404153, 21404154, 21404167, 21404168, 21404170, 21404153, 21404154, 21404168, 21404169, 21404170, 21404171, 21404154, 21404155, 21404156, 21404156, 21404167, 21404168, 21404169, 21404170, 21404171, 21404171, 21404155, 21404156, 21404156, 21404157, 21404165, 21404168, 21404169, 21404170, 21404171, 21404171, 21404172, 21404172, 21404173, 21404156, 21404157, 21404157, 21404158, 21404169, 21404171, 21404172, 21404172, 21404172, 21404173, 21404158, 21404170, 21404171, 21404173, 21404173, 21404174, 21404171, 21404172, 21404173, 21404173, 21404174, 21404174, 21404174, 21404175, 21404176, 21404182, 21562978, 21562978, 21404184, 21543544, 21543592, 21562979, 21404183, 21404185, 21420055, 21543680, 21404183, 21404184, 21404185, 21404185, 21404186, 21562980, 21404186, 21449905, 21562980, 21404186, 21404186, 21404187, 21449899, 21449905, 21562981, 21404187, 21562981, 21404187, 21404188, 21449901, 21449907, 21404188, 21404189, 21404190, 21416789, 21449900, 21449901, 21449901, 21449904, 21449907, 21449908, 21449908, 21449909, 21543615, 21543623, 21543632, 21543677, 21543682, 21543686, 21543688, 21543689, 21543692, 21543693, 21562982, 21563014, 21662659, 21404189, 21404190, 21449900, 21449901, 21449901, 21449902, 21449903, 21449903, 21449906, 21449908, 21514895, 21543614, 21543688, 21543694, 21562983, 21563015, 21633918, 21662662, 21784089, 21784142, 21449901, 21449902, 21449903, 21449904, 21562983, 21563015, 21444685, 21449901, 21449902, 21449902, 21562984, 21444667, 21449909, 21429410, 21462523, 21556299, 21556310, 21575603, 21435943, 21435944, 21578867, 21578868, 21485158, 21547302, 21485195, 21490413, 21495612, 21495613, 21495616, 21495616, 21495617, 21495618, 21495619, 21495620, 21495627, 21495629, 21495634, 21495613, 21495614, 21495614, 21495615, 21495618, 21495619, 21495620, 21495621, 21495628, 21495628, 21495629, 21495629, 21495630, 21495630, 21495631, 21495632, 21495633, 21495634, 21495615, 21495615, 21495617, 21495618, 21495619, 21495620, 21495620, 21495621, 21495628, 21495629, 21495629, 21495630, 21495630, 21495631, 21495631, 21495632, 21495633, 21495633, 21495634, 21495636, 21495616, 21495621, 21495633, 21495618, 21495619, 21495622, 21495623, 21495630, 21495631, 21495631, 21495634, 21495635, 21495637, 21495637, 21495631, 21495632, 21495632, 21495637, 21495619, 21495623, 21495638, 21495621, 21495623, 21495638, 21495637, 21495638, 21495639, 21495640, 21495622, 21495634, 21495639, 21495640, 21495624, 21495635, 21495626, 21495633, 21495634, 21495640, 21495640, 21495633, 21495641, 21495626, 21495638, 21495641, 21495634, 21495636, 21495638, 21495642, 21495642, 21495627, 21495635, 21495639, 21495642, 21495629, 21495637, 21495639, 21495640, 21495641, 21495642, 21495643, 21495643, 21495644, 21495638, 21495639, 21495644, 21495644, 21495644, 21495645, 21495644, 21495646, 21495645, 21608741, 21495644, 21495647, 21589421, 21495645, 21495646, 21495648, 21495651, 22147093, 21495650, 21495652, 21608711, 21608743, 21679646, 21495652, 21608711, 21608743, 21495649, 21495649, 21495650, 21495651, 21495652, 21495652, 21589415, 21589416, 21608712, 21693316, 21495648, 21495650, 21495651, 21495653, 21608712, 21608744, 21495650, 21495651, 21495653, 21495654, 21608713, 21608767, 21679648, 21495652, 21495654, 21608713, 21495654, 21608714, 21495655, 21608714, 21495656, 21608715, 21495656, 21589344, 21589417, 21608715, 21495656, 21495657, 21589279, 21608716, 21608775, 21495657, 21495658, 21495659, 21608717, 21495658, 21495659, 21495659, 21495661, 21589282, 21589346, 21589351, 21589353, 21589362, 21589415, 21589416, 21589421, 21589422, 21589423, 21589424, 21589427, 21608717, 21608717, 21608752, 21829824, 21589359, 21589416, 21589418, 21608718, 21589419, 21589421, 21589422, 21608718, 21589351, 21608719, 21608721, 21609453, 21665626, 21625640, 21894834, 21682920, 21682982, 21702356, 21683069, 21683084, 21683087, 21683087, 21683088, 21683089, 21683051, 21683094, 21683099, 21702417, 21683101, 21683102, 21683103, 21683109, 21683107, 21683109, 21683152, 21683140, 21683162, 21683164, 21702455, 21702456, 21702457, 21702458, 21683153, 21702459, 21702459, 21683167, 21702461, 21683170, 21683191, 21683176, 21683193, 21683184, 21683197, 21683198, 21683188, 21683191, 21683192, 21683193, 21683185, 21683191, 21683195, 21683176, 21683194, 21683182, 21683192, 21683196, 21683197, 21683199, 21683197, 21683196, 21683196, 21683196, 21683198, 21683204, 21683206, 21683186, 21683199, 21683205, 21683206, 21683206, 21683186, 21683198, 21683199, 21683187, 21683188, 21683200, 21683200, 21683201, 21683202, 21683203, 21683204, 21683205, 21683206, 21683207, 21683205, 21683207, 21683190, 21683205, 21683203, 21683203, 21683208, 21683209, 21683204, 21683207, 21683208, 21683209, 21683203, 21683206, 21683209, 21683210, 21683209, 21683210, 21683207, 21683210, 21683212, 21683211, 21683210, 21683205, 21683213, 21683206, 21683213, 21683214, 21702490, 21683212, 21702493, 21702494, 21683221, 21702494, 21702495, 21683215, 21702495, 21702495, 21702496, 21683221, 21702496, 22240879, 21683223, 21702497, 21683221, 21702497, 21702498, 21683225, 21702498, 21702557, 21683221, 21702499, 21683226, 21702499, 21923606, 21702500, 21683227, 21702501, 21702502, 21683229, 21702502, 21702503, 21702535, 21702503, 21702535, 21702504, 21721776, 21721777, 21721778, 21721778, 21721779, 21721779, 21721780, 21721787, 21721787, 21721788, 21721797, 21721806, 21721806, 21721807, 21721807, 21721808, 21721808, 21721809, 21721825, 21721851, 21721852, 21721787, 21721808, 21721809, 21721809, 21721809, 21721810, 21721810, 21721810, 21721810, 21721811, 21721811, 21721797, 21721818, 21721818, 21721819, 21721798, 21721810, 21721818, 21721819, 21721822, 21721832, 21721836, 21721846, 21721884, 21821464, 21821464, 21942915, 22477950, 21721820, 21721820, 21721829, 21721832, 21721837, 21721838, 21721837, 21721839, 21721839, 21721840, 21721840, 21721841, 21721842, 21721842, 21721843, 21721843, 21721844, 21721844, 21721845, 21721845, 21721846, 21721846, 21721847, 21721847, 21721848, 21721848, 21721849, 21721849, 21721850, 21721851, 21721851, 21721852, 21721853, 21721854, 21721855, 21721855, 21721856, 21721857, 21721857, 21721858, 21721858, 21721859, 21721859, 21721860, 21721860, 21721861, 21721861, 21721862, 21721862, 21721863, 21721865, 21721867, 21721867, 21721868, 21721870, 21721871, 21721873, 21721877, 21721877, 21721881, 21721883, 21721883, 21721884, 21721842, 21721843, 21721843, 21721844, 21721845, 21721845, 21721846, 21721847, 21721850, 21721850, 21721851, 21721852, 21721852, 21721853, 21721854, 21721855, 21721857, 21721858, 21721859, 21721859, 21721860, 21721860, 21721861, 21721861, 21721862, 21721863, 21721865, 21721866, 21721883, 21721884, 21721885, 21721843, 21721844, 21721844, 21721846, 21721848, 21721860, 21721863, 21721868, 21721884, 21721844, 21721845, 21721846, 21721846, 21721847, 21721847, 21721849, 21721850, 21721851, 21721856, 21721858, 21721859, 21721860, 21721861, 21721862, 21721863, 21721864, 21721869, 21721885, 21721886, 21721845, 21721846, 21721846, 21721849, 21721852, 21721859, 21721859, 21721860, 21721863, 21721866, 21721885, 21721846, 21721847, 21721847, 21721848, 21721848, 21721849, 21721849, 21721851, 21721852, 21721853, 21721853, 21721860, 21721860, 21721861, 21721861, 21721862, 21721863, 21721866, 21721866, 21721867, 21721867, 21721870, 21721887, 21721848, 21721861, 21721862, 21721864, 21721871, 21721887, 21721848, 21721849, 21721850, 21721851, 21721854, 21721857, 21721861, 21721862, 21721863, 21721865, 21721849, 21721850, 21721854, 21721855, 21721859, 21721859, 21721861, 21721862, 21721863, 21721864, 21721866, 21721868, 21721868, 21721872, 21721887, 21721850, 21721851, 21721856, 21721863, 21721863, 21721864, 21721865, 21721888, 21721851, 21721852, 21721853, 21721856, 21721862, 21721863, 21721866, 21721873, 21721888, 21721853, 21721855, 21721856, 21721863, 21721864, 21721865, 21721865, 21721877, 21721882, 21721888, 21721854, 21721857, 21721869, 21721889, 21721856, 21721862, 21721863, 21721864, 21721865, 21721868, 21721855, 21721860, 21721864, 21721866, 21721863, 21721865, 21721866, 21721867, 21721891, 21721866, 21721860, 21721867, 21721872, 21721892, 21721860, 21721864, 21721866, 21721866, 21721867, 21721868, 21721882, 21721888, 21721867, 21721867, 21721867, 21721868, 21721868, 21721869, 21721870, 21721884, 21721894, 21721866, 21721877, 21721878, 21721867, 21721868, 21721870, 21721869, 21721870, 21721871, 21721895, 21721869, 21721872, 21721872, 21721875, 21721885, 21721871, 21721872, 21721872, 21721871, 21721871, 21721872, 21721873, 21721871, 21721874, 21721874, 21721876, 21721899, 21721873, 21721874, 21721875, 21721876, 21721878, 21721879, 21721881, 21721883, 21721899, 21721874, 21721875, 21721875, 21721876, 21721877, 21721878, 21721879, 21721880, 21721880, 21721881, 21721882, 21721883, 21721884, 21721893, 21721899, 21721900, 21721875, 21721876, 21721877, 21721879, 21721884, 21721876, 21721877, 21721877, 21721878, 21721878, 21721879, 21721879, 21721880, 21721881, 21721881, 21721882, 21721883, 21721883, 21721884, 21721885, 21721885, 21721890, 21721893, 21721894, 21721900, 21721901, 21721877, 21721878, 21721879, 21721879, 21721880, 21721880, 21721881, 21721882, 21721882, 21721883, 21721885, 21721885, 21721886, 21721889, 21721895, 21721896, 21721901, 21721901, 21721902, 21721878, 21721879, 21721879, 21721880, 21721881, 21721881, 21721882, 21721883, 21721883, 21721885, 21721886, 21721886, 21721890, 21721891, 21721891, 21721892, 21721892, 21721895, 21721901, 21721902, 21721879, 21721880, 21721880, 21721881, 21721882, 21721884, 21721886, 21721887, 21721892, 21721902, 21721880, 21721881, 21721881, 21721882, 21721883, 21721883, 21721884, 21721884, 21721886, 21721887, 21721887, 21721893, 21721899, 21721902, 21721903, 21721881, 21721882, 21721882, 21721883, 21721884, 21721885, 21721886, 21721887, 21721887, 21721894, 21721900, 21721903, 21721882, 21721883, 21721884, 21721884, 21721885, 21721885, 21721886, 21721887, 21721888, 21721894, 21721902, 21721903, 21721904, 21721904, 21721905, 21721883, 21721884, 21721885, 21721886, 21721886, 21721888, 21721888, 21721890, 21721901, 21721902, 21721904, 21721885, 21721885, 21721886, 21721886, 21721887, 21721888, 21721889, 21721889, 21721892, 21721894, 21721904, 21721904, 21721905, 21721906, 21721887, 21721886, 21721887, 21721887, 21721888, 21721889, 21721890, 21721890, 21721903, 21721905, 21721906, 21721907, 21942938, 21721887, 21721888, 21721888, 21721890, 21721890, 21721891, 21721893, 21721906, 21721889, 21721889, 21721890, 21721891, 21721891, 21721893, 21721906, 21721907, 21821509, 21721889, 21721891, 21721891, 21721892, 21721894, 21721897, 21721898, 21721900, 21721901, 21721907, 21721890, 21721891, 21721892, 21721905, 21721908, 21721891, 21721892, 21721893, 21721892, 21721893, 21721893, 21721894, 21721896, 21721896, 21721897, 21721897, 21721900, 21721902, 21721908, 21721909, 21721909, 21721910, 21942941, 21721894, 21721895, 21721895, 21721896, 21721897, 21721897, 21721898, 21721900, 21721900, 21721901, 21721902, 21721903, 21721905, 21721905, 21721906, 21721907, 21721908, 21721909, 21721910, 21721910, 21721911, 21721895, 21721897, 21721898, 21721900, 21721901, 21721901, 21721902, 21721903, 21721905, 21721906, 21721906, 21721907, 21721907, 21721908, 21721910, 21721910, 21721911, 21721896, 21721911, 21721904, 21721911, 21721905, 21721912, 21721912, 21721900, 21721902, 21721903, 21721905, 21721907, 21721912, 21721913, 21721913, 21721913, 21721912, 21721913, 21721914, 21721908, 21721913, 21721914, 21721914, 21721905, 21721911, 21721915, 21721909, 21721915, 21721915, 21721916, 21721910, 21721916, 21721916, 21721909, 21721917, 21721918, 21721912, 21721914, 21721913, 21721918, 21721918, 21721915, 21721918, 21721916, 21721919, 21721919, 21721920, 21792780, 21721918, 21721920, 21721920, 21721921, 21721917, 21721921, 21721921, 21721921, 21721922, 21721922, 21721922, 21721921, 21721922, 21721923, 21721922, 21721923, 21721924, 21721922, 21721923, 21721924, 21721924, 21721924, 21721925, 21721924, 21721925, 21721925, 21721926, 21721927, 21721928, 21721929, 21721929, 21721930, 21721930, 21721933, 21721947, 21721948, 21721948, 21721951, 21721952, 21721954, 21721956, 21721958, 21721958, 21721959, 21792787, 21821528, 21821528, 21821529, 21942958, 21942979, 21943011, 22260234, 22478014, 21721927, 21721928, 21721929, 21721929, 21721930, 21721930, 21721931, 21721932, 21721933, 21721934, 21721936, 21721936, 21721937, 21721938, 21721942, 21721943, 21721944, 21721947, 21721948, 21721949, 21721952, 21721952, 21721953, 21721953, 21721954, 21721956, 21721957, 21721957, 21721958, 21721958, 21721959, 21721959, 21806456, 21721928, 21721929, 21721930, 21721931, 21721931, 21721939, 21721941, 21721942, 21721943, 21721945, 21721948, 21721948, 21721949, 21721952, 21721953, 21721954, 21721954, 21721955, 21721956, 21721956, 21721957, 21721958, 21721959, 21721959, 21721960, 21792788, 21821527, 21821529, 21942959, 22260235, 22478028, 21721931, 21721932, 21721938, 21721942, 21721951, 21721959, 21721960, 21806457, 21942959, 21721930, 21721961, 21721947, 21721961, 21721933, 21721950, 21721958, 21721934, 21721945, 21721961, 21721947, 21721951, 21721956, 21721963, 21721949, 21721951, 21721955, 21721961, 21721962, 21721963, 21721963, 21792790, 21942984, 21721945, 21721950, 21721966, 21721967, 21721966, 21721968, 21721957, 21721969, 21721970, 21721971, 21721965, 21721973, 21721974, 21721974, 21721961, 21721975, 21721963, 21721975, 21721976, 21721970, 21721974, 21721977, 21721965, 21721972, 21721978, 21721972, 21721969, 21721974, 21721975, 21721978, 21721979, 21721979, 21721980, 21721974, 21721980, 21721970, 21721981, 21721980, 21721981, 21721981, 21721983, 21721984, 21721977, 21721980, 21721984, 21721978, 21721981, 21721982, 21721984, 21721985, 21721981, 21721981, 21721983, 21721984, 21721985, 21721985, 21943006, 21721985, 21721985, 21721986, 21721982, 21721986, 21721986, 21721986, 21721986, 21721987, 21721987, 21721988, 21721988, 21721988, 21721987, 21721988, 21721989, 21721990, 21721990, 21721990, 21721990, 21721991, 21721991, 21721992, 21729048, 21792819, 21792820, 21792826, 21806489, 21806489, 21806490, 21809391, 21809392, 21809392, 21809393, 21809394, 21809395, 21809395, 21809396, 21809397, 21821560, 21821560, 21821561, 21821561, 21821562, 21821562, 21821565, 21882370, 21924548, 21924550, 21942989, 21942990, 21942991, 21943012, 21943012, 21943040, 21943043, 22143485, 22260267, 22260304, 22478046, 22478060, 22478061, 22975874, 22994269, 21792820, 21809394, 21821561, 21924549, 21942991, 21736114, 21736181, 21736248, 21950124, 21863647, 21863648, 21863650, 21863651, 21863656, 21863668, 21863669, 21863670, 21863671, 21863675, 21863652, 21863653, 21863656, 21863671, 21863672, 21863672, 21863672, 21863677, 21863677, 21863687, 21863688, 21863689, 21863689, 21863690, 21863691, 21863692, 21863744, 21863745, 21863742, 21863693, 21863696, 21863697, 21863746, 21863695, 21863697, 21863747, 21863747, 21863747, 21863745, 21863745, 21863750, 21863751, 21863795, 21863795, 21863797, 21863798, 21863799, 21863800, 21863801, 21863804, 21863813, 21863803, 21863813, 21863803, 21863815, 21863807, 21863817, 21863825, 21863829, 21863830, 21863831, 21877403, 21877406, 21877406, 21880310, 21892477, 21892478, 22013908, 22013929, 22013959, 22331184, 22013911, 22013912, 21863838, 22013913, 21892479, 21890995, 21891000, 21891000, 21891000, 21891001, 21891001, 21891002, 21891002, 21891003, 21891005, 21891001, 21891002, 21891002, 21891001, 22027500, 21893904, 21906072, 21893905, 21906075, 21891016, 21893903, 21893905, 21893906, 21906073, 21906075, 22027503, 21893906, 21906073, 21906074, 22027503, 21893906, 22027504, 22344781, 22344782, 22531780, 21896808, 21896809, 21896816, 21896808, 21896795, 21896796, 21896797, 21896810, 21896810, 21896811, 21896811, 21896813, 21896814, 21896815, 21896815, 21896817, 21896802, 21896804, 21896811, 21896811, 21896812, 21896812, 21896816, 21896814, 21896813, 21896818, 21896813, 21896816, 21896818, 21896821, 21896822, 22030406, 22030407, 21908978, 22030408, 21896829, 21896829, 21908978, 22030407, 22030408, 22030466, 21908979, 22030409, 22030430, 22347685, 21908980, 22030409, 21896834, 22030410, 22030411, 21896836, 21908980, 22030411, 22030412, 22030413, 22030414, 22030414, 21908985, 22030415, 21921140, 21921128, 21921129, 21921129, 21921143, 21921129, 21921144, 21921130, 21921131, 21921132, 21921142, 21921142, 21921143, 21921144, 21921145, 21921145, 21921133, 21921134, 21921143, 21921143, 21921144, 21921144, 21921145, 21921146, 21921144, 21921146, 21921147, 21921148, 21921147, 21921149, 21921150, 21921149, 21921148, 21921151, 22042598, 22359885, 21921157, 22042572, 22042573, 21921158, 22042573, 22042596, 21921159, 21921159, 22042574, 22042595, 22359850, 21921160, 21921161, 21921161, 21921162, 21937154, 21997436, 22037896, 22042573, 22042574, 22042575, 22042596, 22042624, 22042628, 22042632, 22249794, 22359850, 22359851, 22042575, 22042597, 22042576, 22359889, 21921164, 22042576, 22359853, 22042577, 22042599, 21953164, 22058584, 22042760, 22103381, 22073786, 22118925, 22127180, 22127110, 22127184, 22127258, 22127283, 22145625, 22127385, 22145725, 22154705, 22154782, 22154860, 22159462, 22163988, 22163989, 22163990, 22163991, 22163991, 22163992, 22163992, 22163996, 22164001, 22164008, 22164009, 22164010, 22164010, 22164011, 22164011, 22164065, 22163992, 22163993, 22164011, 22164011, 22164012, 22163997, 22164012, 22164012, 22164013, 22164013, 22164013, 22164012, 22164013, 22164017, 22164017, 22481276, 22164030, 22164030, 22164031, 22164030, 22164031, 22164032, 22164060, 22164032, 22164033, 22164034, 22164037, 22164053, 22164060, 22164064, 22164065, 22164066, 22164087, 22164033, 22164034, 22164034, 22164037, 22164038, 22164038, 22164040, 22164041, 22164043, 22164044, 22164044, 22164045, 22164048, 22164049, 22164050, 22164051, 22164051, 22164053, 22164054, 22164054, 22164055, 22164055, 22164056, 22164056, 22164057, 22164058, 22164059, 22164059, 22164060, 22164060, 22164061, 22164061, 22164063, 22164063, 22164064, 22164064, 22164065, 22164066, 22164066, 22164067, 22164068, 22164069, 22164069, 22164070, 22164079, 22164080, 22164086, 22164087, 22164035, 22164043, 22164045, 22164052, 22164054, 22164056, 22164058, 22164059, 22164059, 22164060, 22164060, 22164061, 22164063, 22164065, 22164066, 22164068, 22164070, 22164087, 22164087, 22164041, 22164044, 22164060, 22164060, 22164067, 22164061, 22164109, 22164058, 22164091, 22164049, 22164058, 22164059, 22164063, 22164064, 22164065, 22164070, 22164071, 22164092, 22164064, 22164064, 22164066, 22164070, 22164050, 22164064, 22164064, 22164064, 22164066, 22164069, 22164058, 22164060, 22164068, 22164069, 22164070, 22164080, 22164071, 22164071, 22164072, 22164086, 22164090, 22164098, 22164070, 22164102, 22164069, 22164074, 22164083, 22164075, 22164076, 22164076, 22164103, 22164097, 22164077, 22164079, 22164079, 22164079, 22164080, 22164081, 22164085, 22164085, 22164107, 22481308, 22164077, 22164080, 22164086, 22164087, 22164088, 22164082, 22164080, 22164087, 22164088, 22164083, 22164086, 22164081, 22164082, 22164084, 22164086, 22164087, 22164088, 22164089, 22164089, 22164091, 22164099, 22164100, 22164102, 22164102, 22164110, 22164092, 22164082, 22164085, 22164087, 22164083, 22164084, 22164084, 22164085, 22164085, 22164086, 22164086, 22164088, 22164088, 22164089, 22164090, 22164090, 22164092, 22164094, 22164112, 22164113, 22481350, 22164085, 22164087, 22164089, 22164090, 22164091, 22164113, 22164086, 22164087, 22164088, 22164088, 22164089, 22164091, 22164091, 22164092, 22164093, 22164095, 22164101, 22164105, 22164106, 22164106, 22164113, 22164113, 22164088, 22164090, 22164095, 22164114, 22164088, 22164092, 22164089, 22164090, 22164090, 22164091, 22164091, 22164092, 22164092, 22164093, 22164093, 22164094, 22164094, 22164095, 22164095, 22164096, 22164097, 22164099, 22164101, 22164104, 22164104, 22164106, 22164106, 22164107, 22164107, 22164108, 22164110, 22164114, 22164114, 22164115, 22164091, 22164093, 22164093, 22164115, 22164115, 22164094, 22164116, 22164094, 22164095, 22164094, 22164094, 22164095, 22164096, 22164096, 22164097, 22164100, 22164100, 22164106, 22164107, 22164112, 22164116, 22164117, 22164095, 22164095, 22164117, 22164095, 22164096, 22164097, 22164108, 22164117, 22164118, 22164096, 22164097, 22164098, 22164098, 22164101, 22164104, 22164107, 22164109, 22164112, 22164113, 22164116, 22164118, 22164097, 22164098, 22164098, 22164099, 22164100, 22164101, 22164101, 22164102, 22164103, 22164104, 22164107, 22164108, 22164109, 22164110, 22164111, 22164111, 22164113, 22164117, 22164118, 22164118, 22164119, 22164119, 22164099, 22164111, 22164119, 22164099, 22164100, 22164108, 22164109, 22164110, 22164112, 22164116, 22164119, 22164120, 22164120, 22164100, 22164101, 22164102, 22164104, 22164110, 22164117, 22164118, 22164118, 22164120, 22164120, 22164121, 22164102, 22164103, 22164110, 22164113, 22164116, 22164121, 22164103, 22164117, 22164121, 22164121, 22164105, 22164113, 22164120, 22164122, 22164122, 22164123, 22164108, 22164115, 22164122, 22164123, 22164123, 22164114, 22164124, 22164124, 22164125, 22164125, 22164126, 22164126, 22164127, 22164128, 22164122, 22164129, 22164125, 22164129, 22164129, 22164123, 22164130, 22164130, 22164131, 22164131, 22164130, 22164131, 22164132, 22164132, 22164132, 22164132, 22164133, 22481333, 22164133, 22164133, 22164134, 22164134, 22164135, 22164132, 22164136, 22164136, 22164137, 22164137, 22164138, 22164138, 22164138, 22164139, 22164139, 22164139, 22164140, 22164140, 22164141, 22164142, 22164146, 22164147, 22164148, 22164151, 22164151, 22164157, 22164159, 22164160, 22164160, 22164161, 22164161, 22164162, 22164162, 22481342, 22481379, 22481379, 22668337, 22699121, 22699134, 22699135, 22699137, 22816255, 23196948, 22164142, 22164143, 22164144, 22164147, 22164148, 22164149, 22164149, 22164152, 22164157, 22164159, 22164160, 22164161, 22164161, 22164162, 22164162, 22164163, 22481342, 22164143, 22164145, 22164161, 22164162, 22164163, 22164163, 22164163, 22164164, 22164163, 22164165, 22164163, 22164167, 22164168, 22481384, 22164168, 22164169, 22164159, 22164169, 22164170, 22164170, 22164172, 22164172, 22164173, 22164178, 22164177, 22164179, 22164180, 22481360, 22164179, 22164181, 22481398, 22164181, 22164181, 22164182, 22164182, 22164182, 22164182, 22164183, 22164183, 22481363, 22164184, 22164185, 22285464, 22285471, 22324523, 22364600, 22371306, 22371308, 22373140, 22427910, 22460062, 22477837, 22477838, 22481362, 22481363, 22481363, 22481400, 22481401, 22481416, 22699152, 22699155, 22816183, 22816210, 23196997, 23278646, 22481364, 22481365, 22406816, 22406823, 22406889, 22406947, 22602773, 22484926, 22641767, 22564990, 22565010, 22565043, 22565044, 22681806, 22899585, 22578440, 22578440, 22578441, 22578441, 22578448, 22688497, 22670056, 22688498, 22688535, 22688498, 22688499, 22688503, 22582109, 22690332, 22691711, 22745165, 22756006, 22777307, 22761676, 22761721, 22761753, 22780149, 22791506, 22791507, 22795032, 22798541, 22798542, 22798542, 22798543, 22798544, 22798544, 22798545, 22798545, 22798546, 22798550, 22798554, 22798564, 22798566, 22798567, 22798567, 22798568, 22798569, 22798573, 22798573, 22798576, 22798578, 22798579, 22798579, 22798580, 22798565, 22798570, 22798580, 22798580, 22798546, 22798570, 22798580, 22798547, 22798581, 22798571, 22798572, 22798582, 22798582, 22798583, 22798577, 22798591, 22798654, 22798590, 22798601, 22798603, 22798604, 22798603, 22798605, 22798597, 22798600, 22798605, 22798606, 22798606, 22798607, 22798610, 22798610, 22798610, 22798612, 22798613, 22798615, 22798615, 22798615, 22798616, 22798616, 22798617, 22798618, 22798618, 22798619, 22798619, 22798620, 22798621, 22798621, 22798622, 22798622, 22798623, 22798624, 22798624, 22798625, 22798626, 22798627, 22798627, 22798628, 22798628, 22798629, 22798629, 22798630, 22798631, 22798632, 22798632, 22798633, 22798633, 22798634, 22798634, 22798635, 22798636, 22798637, 22798638, 22798638, 22798639, 22798639, 22798640, 22798640, 22798642, 22798642, 22798643, 22798645, 22798649, 22798653, 22798654, 22798655, 22798655, 22798618, 22798619, 22798619, 22798623, 22798624, 22798627, 22798628, 22798630, 22798630, 22798632, 22798632, 22798633, 22798633, 22798638, 22798639, 22798644, 22798645, 22798651, 22798653, 22798655, 22798656, 22798621, 22798626, 22798628, 22798629, 22798632, 22798633, 22798620, 22798621, 22798623, 22798624, 22798629, 22798631, 22798631, 22798633, 22798634, 22798634, 22798656, 22798626, 22798627, 22798629, 22798631, 22798633, 22798635, 22798640, 22798634, 22798640, 22798658, 22798627, 22798631, 22798654, 22798633, 22798637, 22798632, 22798632, 22798636, 22798637, 22798638, 22798643, 22798660, 22798630, 22798633, 22798637, 22798631, 22798633, 22798634, 22798643, 22798637, 22798639, 22798640, 22798640, 22798663, 22798637, 22798641, 22798664, 22798638, 22798639, 22798639, 22798641, 22798642, 22798643, 22798648, 22798640, 22798643, 22798640, 22798641, 22798642, 22798642, 22798643, 22798644, 22798649, 22798654, 22798656, 22798656, 22798657, 22798661, 22798666, 22798644, 22798652, 22798666, 22798642, 22798644, 22798645, 22798645, 22798646, 22798648, 22798649, 22798649, 22798650, 22798651, 22798651, 22798653, 22798653, 22798655, 22798656, 22798665, 22798666, 22798667, 22798667, 22798668, 22798705, 22798644, 22798645, 22798646, 22798647, 22798651, 22798652, 22798656, 22798656, 22798668, 22798668, 22798647, 22798646, 22798647, 22798647, 22798649, 22798649, 22798652, 22798652, 22798653, 22798655, 22798657, 22798658, 22798670, 22798647, 22798648, 22798653, 22798657, 22798667, 22798670, 22798648, 22798649, 22798649, 22798650, 22798650, 22798651, 22798652, 22798652, 22798653, 22798654, 22798654, 22798655, 22798655, 22798656, 22798656, 22798657, 22798657, 22798658, 22798659, 22798660, 22798665, 22798666, 22798667, 22798667, 22798668, 22798669, 22798670, 22798671, 22798649, 22798650, 22798650, 22798651, 22798651, 22798652, 22798652, 22798653, 22798653, 22798654, 22798654, 22798655, 22798655, 22798656, 22798656, 22798657, 22798658, 22798659, 22798659, 22798661, 22798662, 22798664, 22798666, 22798666, 22798667, 22798667, 22798669, 22798669, 22798670, 22798670, 22798671, 22798671, 22798672, 22798653, 22798661, 22798671, 22798672, 22798654, 22798655, 22798655, 22798672, 22798672, 22798654, 22798657, 22798657, 22798658, 22798659, 22798660, 22798666, 22798668, 22798673, 22798657, 22798661, 22798673, 22798655, 22798656, 22798659, 22798673, 22798674, 22798656, 22798658, 22798662, 22798674, 22798656, 22798657, 22798657, 22798658, 22798675, 22798657, 22798658, 22798658, 22798659, 22798660, 22798663, 22798663, 22798665, 22798670, 22798673, 22798675, 22798675, 22798658, 22798659, 22798663, 22798675, 22798676, 22798659, 22798660, 22798660, 22798661, 22798661, 22798664, 22798664, 22798665, 22798666, 22798670, 22798671, 22798675, 22798676, 22798676, 22798660, 22798661, 22798662, 22798664, 22798665, 22798666, 22798667, 22798673, 22798675, 22798677, 22798661, 22798662, 22798662, 22798663, 22798663, 22798665, 22798665, 22798666, 22798667, 22798667, 22798672, 22798672, 22798675, 22798677, 22798662, 22798663, 22798665, 22798666, 22798678, 22798666, 22798667, 22798668, 22798675, 22798678, 22798666, 22798666, 22798672, 22798672, 22798673, 22798677, 22798678, 22798679, 22798667, 22798668, 22798669, 22798679, 22798667, 22798669, 22798668, 22798678, 22798680, 22798668, 22798681, 22798669, 22798670, 22798671, 22798671, 22798672, 22798673, 22798674, 22798675, 22798680, 22798680, 22798681, 22798681, 22798670, 22798671, 22798672, 22798673, 22798676, 22798680, 22798681, 22798681, 22798682, 22798672, 22798676, 22798679, 22798681, 22798682, 22798682, 22798673, 22798677, 22798680, 22798681, 22798682, 22798683, 22798683, 22798683, 22798684, 22798675, 22798684, 22798685, 22798686, 22798686, 22798686, 22798687, 22798681, 22798686, 22798687, 22798688, 22798683, 22798688, 22798686, 22798687, 22798688, 22798689, 22798688, 22798688, 22798689, 22798690, 22798690, 22798690, 22798689, 22798691, 22798690, 22798691, 22798691, 23016395, 22798692, 22798691, 22798692, 22798692, 22798692, 22798693, 22798693, 23514224, 22798694, 22798695, 22798696, 22798697, 22798698, 22798699, 22798699, 22798700, 22798701, 22798703, 22798704, 22798704, 22798706, 22798713, 22798715, 22798717, 22798719, 22798720, 22798721, 22798724, 22798725, 22798726, 22798726, 22798727, 22798728, 22798728, 22798729, 22798729, 22798730, 22798730, 22798731, 22842139, 22985614, 22985615, 23016395, 23016397, 23016397, 23016398, 23016404, 23016408, 23016410, 23016410, 23016417, 23041788, 23133493, 23133531, 23514225, 22798695, 22798696, 22798697, 22798697, 22798698, 22798698, 22798700, 22798701, 22798701, 22798702, 22798702, 22798705, 22798706, 22798710, 22798714, 22798716, 22798719, 22798721, 22798724, 22798725, 22798726, 22798726, 22798727, 22798727, 22798728, 22798728, 22798729, 22798729, 22798730, 22798730, 22798731, 22798731, 23016398, 22798704, 22798732, 22798728, 22798730, 22798732, 22798733, 22798725, 22798701, 22798705, 22798719, 22798730, 22798734, 22798701, 22798718, 22798731, 22798705, 22798731, 22798735, 22798736, 23133472, 22798736, 22798722, 22798734, 22798711, 22798720, 22798723, 22798738, 22798724, 22798735, 22798737, 22798738, 22798739, 22798719, 22798740, 22798724, 22798731, 22798725, 22798741, 22798735, 22798743, 22798747, 23041803, 22798750, 22798745, 22798747, 22798747, 22798749, 22798751, 22798749, 22798752, 22798751, 22798752, 22798752, 22798741, 22798751, 22798753, 22798753, 22798754, 22798748, 22798753, 22798756, 22798753, 22798756, 22798755, 22798757, 22798748, 22798757, 22798758, 22798758, 22798759, 22798755, 22798755, 22798759, 22798761, 22798758, 22798761, 22798762, 22798763, 22798763, 22798764, 22798761, 22798762, 22798764, 22798763, 22798764, 22798765, 22798764, 22798765, 22798765, 22798765, 22798766, 22798765, 22798766, 22798767, 22798767, 22798768, 22819792, 22819793, 22819795, 22819804, 22819883, 22819909, 22819911, 22819911, 22819913, 22842176, 22842177, 22843968, 22855405, 22903372, 22926180, 22927297, 22936811, 22956601, 22956602, 22956602, 22956603, 22985639, 22985640, 22985643, 22985646, 22985647, 22985650, 22985651, 22985652, 22985652, 22992680, 23016430, 23016431, 23016431, 23016432, 23016432, 23016433, 23016433, 23016434, 23016434, 23016435, 23016436, 23016437, 23016437, 23016438, 23016438, 23016439, 23016440, 23016441, 23016441, 23016442, 23016442, 23016443, 23016443, 23016444, 23016444, 23016445, 23016445, 23016446, 23016446, 23016447, 23016447, 23016448, 23016448, 23016449, 23016449, 23016450, 23016451, 23041823, 23041823, 23041824, 23041824, 23041825, 23042569, 23042582, 23133475, 23133502, 23514262, 23595938, 22819913, 22842177, 22985652, 23016431, 23016435, 23016442, 23016448, 23041824, 22840825, 22840827, 22840828, 22840831, 22840832, 22840948, 22840949, 22840949, 22840950, 22840851, 22840950, 22840951, 22840952, 22840952, 22840952, 22840961, 22841008, 22841040, 22841067, 22841069, 22841070, 22841069, 22841071, 22841069, 22841070, 22841071, 22841073, 22841073, 22841073, 22841073, 22841074, 23037593, 23006808, 23037591, 23037604, 23154631, 23037592, 22863336, 23037605, 23037606, 23037591, 23037592, 23037592, 23037593, 23037593, 23037604, 23037605, 23154633, 22885599, 22885600, 22885603, 22885605, 22885603, 23059857, 23058798, 23059858, 23059860, 23059869, 23059870, 23176900, 23059861, 23059869, 22889236, 23061714, 22912073, 23073099, 23007987, 23121061, 23053634, 23053695, 23053790, 23143996, 23055878, 23055949, 23056025, 23145098, 23074863, 23074933, 23074996, 23154547, 23114450, 23114452, 23114457, 23114454, 23114459, 23174279, 23174285, 23174286, 23291330, 23174291, 23172523, 23172513, 23172524, 23172521, 23172524, 23172528, 23172526, 23172531, 23172529, 23172531, 23172533, 23172535, 23172536, 23172546, 23172555, 23172537, 23172548, 23172554, 23172556, 23172558, 23172557, 23172539, 23172555, 23172557, 23172556, 23172558, 23172567, 23172568, 23172574, 23172574, 23172576, 23172578, 23202279, 23203334, 23203337, 23203338, 23203338, 23203339, 23203339, 23203347, 23203348, 23203348, 23203350, 23203350, 23203351, 23203351, 23203356, 23228728, 23228729, 23228730, 23320379, 23701166, 23701194, 23203340, 23320381, 23186607, 23236494, 23231993, 23233050, 23233053, 23233053, 23234096, 23234096, 23234097, 23234105, 23234106, 23234108, 23234096, 23234097, 23234098, 23234112, 23234097, 23234098, 23234098, 23234099, 23234110, 23234115, 23234116, 23234099, 23234099, 23234111, 23234111, 23234112, 23234116, 23234100, 23234109, 23234111, 23234112, 23234116, 23234117, 23234100, 23234100, 23234107, 23234110, 23234111, 23234112, 23234112, 23234114, 23234118, 23234119, 23234100, 23234101, 23234106, 23234109, 23234110, 23234111, 23234112, 23234112, 23234113, 23234114, 23234115, 23234115, 23234117, 23234101, 23234102, 23234102, 23234105, 23234105, 23234106, 23234107, 23234108, 23234110, 23234110, 23234111, 23234111, 23234112, 23234112, 23234113, 23234113, 23234114, 23234114, 23234115, 23234116, 23234116, 23234117, 23234117, 23234118, 23234120, 23234102, 23234104, 23234105, 23234106, 23234106, 23234107, 23234107, 23234108, 23234109, 23234110, 23234110, 23234111, 23234111, 23234112, 23234112, 23234113, 23234113, 23234114, 23234114, 23234115, 23234115, 23234116, 23234116, 23234117, 23234117, 23234118, 23234118, 23234119, 23234119, 23234120, 23234121, 23234122, 23234122, 23234123, 23234128, 23234133, 23234106, 23234109, 23234111, 23234113, 23234114, 23234113, 23234116, 23234109, 23234116, 23234114, 23234113, 23234113, 23234114, 23234115, 23234134, 23234112, 23234113, 23234115, 23234120, 23234136, 23234116, 23234118, 23234119, 23234124, 23234118, 23234119, 23234124, 23234115, 23234121, 23234136, 23234118, 23234119, 23234126, 23234117, 23234118, 23234117, 23234119, 23234119, 23234120, 23234116, 23234117, 23234118, 23234118, 23234119, 23234119, 23234121, 23234126, 23234139, 23234141, 23234117, 23234119, 23234119, 23234120, 23234122, 23234119, 23234119, 23234120, 23234120, 23234121, 23234121, 23234122, 23234123, 23234125, 23234126, 23234127, 23234119, 23234120, 23234120, 23234121, 23234121, 23234122, 23234122, 23234123, 23234142, 23234120, 23234121, 23234121, 23234122, 23234122, 23234125, 23234129, 23234130, 23234132, 23234141, 23234141, 23234121, 23234122, 23234122, 23234123, 23234123, 23234124, 23234125, 23234127, 23234128, 23234131, 23234122, 23234123, 23234123, 23234124, 23234124, 23234126, 23234127, 23234127, 23234129, 23234132, 23234142, 23234123, 23234124, 23234124, 23234125, 23234126, 23234127, 23234130, 23234133, 23234143, 23234124, 23234125, 23234125, 23234126, 23234126, 23234127, 23234128, 23234129, 23234129, 23234141, 23234144, 23234125, 23234126, 23234126, 23234127, 23234128, 23234128, 23234130, 23234143, 23234144, 23234145, 23234126, 23234127, 23234127, 23234128, 23234128, 23234129, 23234130, 23234132, 23234144, 23234144, 23234145, 23234127, 23234128, 23234128, 23234129, 23234129, 23234130, 23234130, 23234131, 23234132, 23234133, 23234137, 23234144, 23234145, 23234146, 23234128, 23234129, 23234129, 23234130, 23234130, 23234131, 23234131, 23234133, 23234133, 23234145, 23234145, 23234146, 23234129, 23234130, 23234130, 23234131, 23234132, 23234145, 23234146, 23234147, 23259504, 23234130, 23234131, 23234131, 23234132, 23234132, 23234133, 23234135, 23234146, 23234146, 23234147, 23260227, 23351156, 23234131, 23234132, 23234132, 23234133, 23234133, 23234135, 23234135, 23234136, 23234137, 23234140, 23234146, 23234147, 23234148, 23259505, 23351156, 23234132, 23234133, 23234133, 23234134, 23234134, 23234135, 23234136, 23234137, 23234139, 23234142, 23234146, 23234147, 23234147, 23234148, 23259505, 23351157, 23234133, 23234134, 23234134, 23234135, 23234135, 23234136, 23234136, 23234137, 23234137, 23234138, 23234139, 23234140, 23234145, 23234147, 23234148, 23234149, 23259506, 23260253, 23351157, 23533137, 23750340, 23234134, 23234135, 23234135, 23234136, 23234137, 23234138, 23234147, 23234148, 23234148, 23234149, 23259506, 23351158, 23234135, 23234136, 23234136, 23234137, 23234138, 23234139, 23234139, 23234140, 23234141, 23234143, 23234147, 23234148, 23234148, 23234149, 23234150, 23234150, 23260266, 23351158, 23234137, 23234138, 23234139, 23234141, 23234149, 23234149, 23234150, 23259507, 23263650, 23351159, 23731946, 23234138, 23234139, 23234142, 23234149, 23234150, 23260260, 23260267, 23300416, 23351159, 23731946, 23234138, 23234139, 23234140, 23234146, 23234150, 23234150, 23260267, 23234139, 23234140, 23234141, 23234142, 23234150, 23234150, 23234151, 23234152, 23351160, 23351214, 23731947, 23234140, 23234141, 23234151, 23234151, 23234152, 23351161, 23234141, 23234142, 23234151, 23234152, 23234153, 23351161, 23234142, 23234143, 23234145, 23234152, 23234153, 23259510, 23351162, 23234143, 23234145, 23234152, 23234153, 23234154, 23351162, 23234145, 23234146, 23234153, 23234153, 23234154, 23260270, 23351163, 23351163, 23234147, 23234154, 23351164, 23234154, 23234155, 23234156, 23259513, 23351164, 23234154, 23259513, 23351165, 23351165, 23351166, 23234156, 23234157, 23351168, 23234159, 23351169, 23234160, 23234161, 23234162, 23351171, 23234162, 23234163, 23234163, 23259520, 23260279, 23351171, 23351172, 23351265, 23234163, 23234164, 23234164, 23259521, 23259522, 23259523, 23260280, 23351172, 23351223, 23351226, 23492547, 23731959, 23731987, 23234164, 23351173, 23234165, 23259522, 23259523, 23259523, 23259524, 23259524, 23259525, 23259525, 23260245, 23260274, 23260276, 23260281, 23351173, 23351201, 23351201, 23351202, 23351203, 23351231, 23351233, 23351267, 23533145, 23731960, 23731988, 23732011, 23750356, 23808888, 23259522, 23260281, 23285762, 23351174, 23284893, 23284880, 23284880, 23284892, 23284893, 23284893, 23284894, 23284894, 23284895, 23284895, 23284881, 23284882, 23284883, 23284895, 23284896, 23284895, 23284895, 23284896, 23284896, 23284897, 23284895, 23284896, 23284897, 23284897, 23284896, 23284897, 23284898, 23284907, 23757358, 23284908, 23285652, 23757359, 23284909, 23325451, 23376545, 23757393, 23284909, 23284910, 23284911, 23285617, 23285648, 23285652, 23285653, 23376545, 23376575, 23757332, 23284910, 23285647, 23285649, 23285653, 23376482, 23376546, 23376573, 23376595, 23376639, 23757333, 23284911, 23285649, 23285652, 23285652, 23376546, 23376604, 23574926, 23376547, 23757361, 23376641, 23286336, 23286341, 23286341, 23377265, 23377269, 23758056, 23377269, 23286394, 23286396, 23286390, 23286401, 23286390, 23286407, 23286403, 23286408, 23286409, 23286411, 23286405, 23286409, 23286410, 23286411, 23286412, 23286414, 23286415, 23377295, 23286417, 23377300, 23758088, 23377302, 23377302, 23377303, 23377304, 23326211, 23377304, 23377304, 23776489, 23377307, 23293181, 23761505, 23337413, 23402825, 23366010, 23366012, 23417103, 23417105, 23366711, 23417454, 23468118, 23468181, 23468182, 23468183, 23468183, 23468184, 23468184, 23468185, 23468185, 23468187, 23468192, 23468194, 23468195, 23468208, 23468209, 23468209, 23468210, 23468210, 23468211, 23468183, 23468209, 23468209, 23468210, 23468210, 23468211, 23468209, 23468210, 23468210, 23468211, 23468211, 23468212, 23468212, 23468213, 23468212, 23468215, 23468203, 23468219, 23468243, 23468285, 23468286, 23468222, 23468224, 23468235, 23468236, 23468236, 23468237, 23468256, 23468257, 23468237, 23468238, 23468238, 23468239, 23468247, 23468251, 23468256, 23468256, 23468258, 23468259, 23468260, 23468260, 23468261, 23468261, 23468262, 23468267, 23468284, 23468285, 23468238, 23468239, 23468242, 23468259, 23468260, 23468260, 23468262, 23468285, 23468285, 23468239, 23468240, 23468251, 23468257, 23468257, 23468259, 23468259, 23468260, 23468262, 23468264, 23468266, 23468267, 23468268, 23468281, 23468286, 23468240, 23468241, 23468241, 23468245, 23468254, 23468256, 23468257, 23468257, 23468258, 23468260, 23468261, 23468261, 23468262, 23468262, 23468263, 23468264, 23468264, 23468265, 23468266, 23468267, 23468282, 23468286, 23468286, 23468241, 23468242, 23468243, 23468243, 23468245, 23468246, 23468247, 23468250, 23468254, 23468258, 23468259, 23468259, 23468260, 23468260, 23468261, 23468262, 23468262, 23468263, 23468263, 23468264, 23468264, 23468265, 23468265, 23468267, 23468269, 23468269, 23468270, 23468272, 23468281, 23468284, 23468286, 23468287, 23468242, 23468243, 23468243, 23468244, 23468244, 23468246, 23468246, 23468251, 23468252, 23468253, 23468255, 23468255, 23468256, 23468257, 23468258, 23468259, 23468260, 23468260, 23468261, 23468262, 23468262, 23468263, 23468264, 23468265, 23468266, 23468266, 23468268, 23468270, 23468274, 23468276, 23468280, 23468282, 23468285, 23468287, 23468287, 23468246, 23468247, 23468251, 23468255, 23468260, 23468261, 23468262, 23468263, 23468264, 23468266, 23468271, 23468288, 23468264, 23468288, 23468260, 23468262, 23468264, 23468248, 23468289, 23468249, 23468290, 23468256, 23468266, 23468267, 23468288, 23468291, 23468259, 23468265, 23468266, 23468267, 23468268, 23468269, 23468274, 23468280, 23468291, 23468268, 23468267, 23468261, 23468267, 23468270, 23468287, 23468269, 23468270, 23468272, 23468272, 23468275, 23468270, 23468273, 23468275, 23468275, 23468276, 23468277, 23468275, 23468281, 23468297, 23468302, 23468278, 23468280, 23468282, 23468277, 23468279, 23468280, 23468287, 23468278, 23468279, 23468283, 23468284, 23468287, 23468287, 23468304, 23468278, 23468280, 23468305, 23468278, 23468280, 23468284, 23468287, 23468289, 23468279, 23468282, 23468282, 23468284, 23468301, 23468306, 23468281, 23468281, 23468282, 23468283, 23468283, 23468284, 23468284, 23468285, 23468286, 23468287, 23468288, 23468289, 23468289, 23468292, 23468294, 23468302, 23468303, 23468306, 23468282, 23468283, 23468283, 23468284, 23468284, 23468285, 23468286, 23468286, 23468287, 23468287, 23468288, 23468298, 23468299, 23468302, 23468303, 23468307, 23468307, 23468283, 23468284, 23468284, 23468285, 23468285, 23468286, 23468286, 23468287, 23468288, 23468288, 23468290, 23468290, 23468294, 23468295, 23468302, 23468307, 23468308, 23468284, 23468285, 23468286, 23468286, 23468287, 23468288, 23468289, 23468290, 23468292, 23468295, 23468297, 23468302, 23468305, 23468308, 23468308, 23468285, 23468286, 23468287, 23468288, 23468288, 23468289, 23468291, 23468292, 23468296, 23468300, 23468304, 23468305, 23468306, 23468309, 23468286, 23468287, 23468287, 23468288, 23468289, 23468290, 23468291, 23468298, 23468302, 23468309, 23468287, 23468288, 23468290, 23468292, 23468301, 23468307, 23468309, 23468310, 23468289, 23468290, 23468290, 23468291, 23468291, 23468297, 23468298, 23468306, 23468310, 23468289, 23468293, 23468294, 23468309, 23468311, 23468291, 23468292, 23468294, 23468298, 23468302, 23468304, 23468305, 23468306, 23468311, 23468311, 23468309, 23468312, 23468292, 23468293, 23468295, 23468295, 23468309, 23468310, 23468312, 23468312, 23468293, 23468295, 23468295, 23468302, 23468308, 23468310, 23468311, 23468313, 23468296, 23468297, 23468313, 23468313, 23468314, 23468314, 23468306, 23468307, 23468312, 23468314, 23468315, 23468307, 23468310, 23468311, 23468313, 23468315, 23468307, 23468310, 23468314, 23468315, 23468316, 23468316, 23468317, 23468318, 23468319, 23468319, 23468309, 23468319, 23468316, 23468320, 23468321, 23468321, 23468322, 23468323, 23468315, 23468316, 23468317, 23468318, 23468324, 23468318, 23468320, 23468324, 23468319, 23468321, 23468325, 23468326, 23468322, 23468325, 23468326, 23468326, 23468327, 23468327, 23468328, 23468328, 23468349, 23468326, 23468329, 23468327, 23468328, 23468329, 23468330, 23507771, 23468330, 23468330, 23468348, 23468330, 23468331, 23849070, 23468331, 23468331, 23468332, 23468332, 23468333, 23468334, 23468334, 23468336, 23468336, 23468337, 23468342, 23468344, 23468347, 23468351, 23468354, 23468355, 23468358, 23468358, 23468359, 23468359, 23468360, 23468360, 23849044, 23849072, 23925968, 23468334, 23468336, 23468337, 23468338, 23468343, 23468347, 23468356, 23468358, 23468358, 23468359, 23468359, 23468360, 23468360, 23468361, 23468337, 23468359, 23468360, 23468361, 23468344, 23468345, 23468346, 23468346, 23468350, 23468364, 23468362, 23468364, 23468359, 23468365, 23468367, 23468367, 23468368, 23468368, 23468369, 23468369, 23468370, 23468370, 23468372, 23468370, 23468372, 23468373, 23468374, 23468377, 23468378, 23468379, 23468381, 23849065, 23468382, 23468383, 23468383, 23468382, 23468384, 23468385, 23468383, 23468384, 23468385, 23468384, 23468385, 23468385, 23468386, 23468385, 23468386, 23468386, 23468386, 23468387, 23468387, 23849099, 23468388, 23468389, 23468415, 23477486, 23556861, 23584291, 23584298, 23584298, 23589405, 23589409, 23589518, 23609659, 23616643, 23650199, 23653342, 23653342, 23653343, 23653344, 23653344, 23653353, 23661719, 23666605, 23666607, 23666608, 23666609, 23666663, 23666663, 23666664, 23666665, 23666665, 23666666, 23666667, 23666667, 23666669, 23666670, 23666670, 23666671, 23666671, 23666672, 23666673, 23666675, 23671365, 23696927, 23696928, 23696929, 23696929, 23699928, 23699929, 23699929, 23711558, 23831761, 23840530, 23846010, 23849071, 23849072, 23849086, 23849088, 23849093, 23849098, 23849099, 23849099, 23849119, 23849127, 23849900, 23867467, 23468390, 23666675, 23671369, 23849072, 23849099, 23849100, 23666666, 23666668, 23849073, 23849101, 23849099, 23486623, 23486697, 23486744, 23858284, 23547249, 23888519, 23645406, 23937617, 23700224, 23700231, 23700232, 23965005, 23782601, 23965033, 23710457, 23710472, 23710460, 23970123, 23970123, 23710548, 23710621, 23710724, 23970212, 23970305, 23750947, 23750946, 23990358, 23990360, 23764932, 23997360, 23832014, 23832026, 23832038, 23832085, 23832156, 23832138, 23832168, 23832148, 23832150, 23832171, 24030971, 23832191, 24030973, 24030975, 23838324, 23838324, 23838299, 23838326, 23838326, 23838335, 23838438, 23851571, 23851590, 23884910, 24034054, 24034081, 23838533, 24034149, 23855073, 23860016, 24042425, 23864801, 23864877, 23864837, 23864839, 23864840, 23864845, 23864897, 24047304, 24047331, 23864902, 23864953, 23864953, 23864954, 23864942, 23864955, 23864955, 23864955, 23864957, 23864958, 23864956, 23864956, 23864958, 23864958, 23864961, 23864967, 23864950, 23864957, 23864959, 23864968, 23864958, 23864968, 23864960, 23864968, 23864971, 23864969, 23864968, 23864973, 23864972, 23864963, 23864971, 23864975, 23864977, 24047362, 24047389, 23898220, 24047362, 24047389, 24047390, 23864978, 23864980, 24047363, 24047390, 24047364, 24047392, 24047365, 24047392, 24047368, 24047397, 24047371, 24047399, 24047372, 24047373, 24047373, 24047374, 24047401, 24047402, 23874355, 23874357, 23874360, 24052089, 24052064, 24052116, 23925484, 23925483, 23925486, 23925487, 24077655, 24077629, 24077629, 23931480, 23931481, 23931482, 23931482, 23931483, 24080652, 24080652, 24080653, 23954789, 24092303, 24195147, 24212458, 24212713, 24221255, 24223675, 24223744, 24223816, 24226809, 24229755, 24229756, 24229757, 24229760, 24229761, 24229762, 24229778, 24229782, 24229783, 24229783, 24229784, 24229831, 24229757, 24229760, 24229761, 24229764, 24229765, 24229765, 24229766, 24229766, 24229767, 24229771, 24229774, 24229781, 24229784, 24229785, 24229785, 24229786, 24229786, 24229787, 24229787, 24229766, 24229766, 24229767, 24229787, 24229787, 24229767, 24229787, 24229788, 24229788, 24229767, 24229787, 24229788, 24229788, 24229773, 24229781, 24229783, 24229788, 24229789, 24229776, 24229789, 24229789, 24229790, 24229794, 24229796, 24229797, 24229797, 24229799, 24229800, 24229804, 24229804, 24229805, 24229805, 24229807, 24229807, 24229808, 24229808, 24229808, 24229808, 24229809, 24229809, 24229810, 24229810, 24229811, 24229812, 24229812, 24229813, 24229813, 24229814, 24229814, 24229815, 24229815, 24229816, 24229816, 24229817, 24229819, 24229820, 24229821, 24229821, 24229822, 24229823, 24229825, 24229826, 24229826, 24229827, 24229827, 24229828, 24229828, 24229829, 24229829, 24229830, 24229830, 24229831, 24229831, 24229832, 24229832, 24229833, 24229833, 24229834, 24229834, 24229835, 24229835, 24229836, 24229837, 24229838, 24229838, 24229839, 24229844, 24229851, 24229853, 24229855, 24229856, 24229859, 24229812, 24229813, 24229813, 24229814, 24229814, 24229815, 24229815, 24229817, 24229817, 24229818, 24229819, 24229820, 24229821, 24229821, 24229822, 24229823, 24229823, 24229824, 24229824, 24229825, 24229826, 24229826, 24229827, 24229827, 24229828, 24229829, 24229829, 24229830, 24229830, 24229831, 24229831, 24229832, 24229832, 24229833, 24229834, 24229834, 24229835, 24229835, 24229836, 24229837, 24229837, 24229838, 24229839, 24229842, 24229844, 24229845, 24229859, 24229814, 24229814, 24229815, 24229821, 24229827, 24229829, 24229829, 24229830, 24229832, 24229832, 24229833, 24229834, 24229834, 24229835, 24229815, 24229815, 24229816, 24229830, 24229832, 24229832, 24229833, 24229834, 24229835, 24229815, 24229816, 24229816, 24229818, 24229823, 24229825, 24229827, 24229830, 24229831, 24229836, 24229836, 24229858, 24229816, 24229817, 24229817, 24229818, 24229819, 24229825, 24229827, 24229829, 24229831, 24229831, 24229832, 24229833, 24229833, 24229834, 24229836, 24229836, 24229818, 24229825, 24229827, 24229829, 24229829, 24229832, 24229833, 24229836, 24229838, 24229818, 24229819, 24229820, 24229820, 24229821, 24229823, 24229823, 24229825, 24229826, 24229828, 24229828, 24229829, 24229830, 24229833, 24229833, 24229834, 24229834, 24229836, 24229837, 24229837, 24229838, 24229839, 24229840, 24229863, 24229820, 24229820, 24229826, 24229829, 24229835, 24229838, 24229825, 24229836, 24229838, 24229839, 24229821, 24229824, 24229837, 24229838, 24229839, 24229822, 24229827, 24229831, 24229836, 24229836, 24229839, 24229840, 24229841, 24229824, 24229826, 24229827, 24229834, 24229835, 24229839, 24229840, 24229826, 24229829, 24229838, 24229842, 24229843, 24229828, 24229831, 24229828, 24229837, 24229840, 24229842, 24229829, 24229831, 24229835, 24229837, 24229838, 24229842, 24229855, 24229831, 24229832, 24229832, 24229835, 24229836, 24229841, 24229843, 24229836, 24229839, 24229833, 24229834, 24229836, 24229837, 24229839, 24229840, 24229841, 24229841, 24229842, 24229842, 24229845, 24229846, 24229834, 24229836, 24229840, 24229841, 24229844, 24229870, 24229838, 24229838, 24229840, 24229841, 24229843, 24229843, 24229845, 24229841, 24229846, 24229846, 24229839, 24229843, 24229846, 24229840, 24229842, 24229840, 24229841, 24229843, 24229844, 24229844, 24229846, 24229848, 24229849, 24229850, 24229841, 24229843, 24229843, 24229844, 24229845, 24229845, 24229847, 24229849, 24229849, 24229858, 24229842, 24229845, 24229845, 24229846, 24229848, 24229849, 24229849, 24229850, 24229865, 24229844, 24229845, 24229846, 24229847, 24229847, 24229849, 24229851, 24229853, 24229846, 24229847, 24229845, 24229846, 24229847, 24229848, 24229849, 24229850, 24229850, 24229851, 24229846, 24229847, 24229847, 24229848, 24229848, 24229849, 24229850, 24229850, 24229851, 24229851, 24229852, 24229852, 24229853, 24229854, 24229854, 24229876, 24229847, 24229848, 24229849, 24229852, 24229848, 24229849, 24229849, 24229850, 24229850, 24229851, 24229851, 24229852, 24229852, 24229853, 24229854, 24229856, 24229857, 24229858, 24229861, 24229849, 24229850, 24229850, 24229851, 24229851, 24229852, 24229852, 24229853, 24229853, 24229854, 24229854, 24229850, 24229851, 24229851, 24229852, 24229853, 24229853, 24229854, 24229854, 24229855, 24229856, 24229851, 24229852, 24229853, 24229853, 24229854, 24229854, 24229855, 24229855, 24229856, 24229867, 24229852, 24229853, 24229853, 24229854, 24229854, 24229855, 24229855, 24229856, 24229857, 24229859, 24229872, 24229854, 24229854, 24229855, 24229855, 24229858, 24248200, 24229855, 24229855, 24229856, 24229857, 24229855, 24229856, 24229856, 24229857, 24229857, 24229858, 24229856, 24229857, 24229857, 24229858, 24229859, 24229859, 24229861, 24229862, 24229864, 24229865, 24229881, 24229882, 24248230, 24229857, 24229858, 24229858, 24229859, 24229859, 24229860, 24229861, 24229861, 24229862, 24229862, 24229866, 24229858, 24229859, 24229859, 24229860, 24229860, 24229861, 24229862, 24229862, 24229863, 24229864, 24229864, 24229865, 24229865, 24229866, 24229866, 24229867, 24229868, 24229877, 24229878, 24229882, 24229859, 24229860, 24229860, 24229861, 24229862, 24229862, 24229866, 24229883, 24229860, 24229861, 24229861, 24229862, 24229862, 24229863, 24229863, 24229864, 24229865, 24229865, 24229866, 24229866, 24229867, 24229867, 24229868, 24229869, 24229870, 24229872, 24229872, 24229874, 24229875, 24229877, 24229877, 24229878, 24229879, 24229881, 24229884, 24229861, 24229862, 24229862, 24229863, 24229864, 24229866, 24229867, 24229862, 24229863, 24229864, 24229864, 24229865, 24229866, 24229866, 24229867, 24229867, 24229868, 24229869, 24229871, 24229872, 24229873, 24229874, 24229885, 24229863, 24229864, 24229864, 24229865, 24229865, 24229866, 24229866, 24229867, 24229867, 24229868, 24229868, 24229869, 24229869, 24229870, 24229870, 24229871, 24229873, 24229874, 24229874, 24229875, 24229876, 24229877, 24229883, 24229884, 24229885, 24229885, 24229864, 24229865, 24229865, 24229866, 24229866, 24229867, 24229865, 24229866, 24229866, 24229867, 24229867, 24229868, 24229868, 24229869, 24229869, 24229871, 24229874, 24229874, 24229883, 24229886, 24229886, 24229866, 24229867, 24229867, 24229868, 24229868, 24229869, 24229869, 24229870, 24229870, 24229871, 24229871, 24229872, 24229874, 24229875, 24229883, 24229884, 24229886, 24229887, 24229867, 24229868, 24229868, 24229869, 24229869, 24229870, 24229870, 24229871, 24229871, 24229872, 24229872, 24229873, 24229875, 24229875, 24229876, 24229887, 24229887, 24229868, 24229869, 24229869, 24229870, 24229870, 24229871, 24229871, 24229872, 24229872, 24229873, 24229873, 24229876, 24229877, 24229878, 24229880, 24229880, 24229884, 24229884, 24229886, 24229887, 24229888, 24229869, 24229870, 24229870, 24229871, 24229871, 24229872, 24229872, 24229873, 24229876, 24229876, 24229880, 24229888, 24229870, 24229871, 24229871, 24229872, 24229872, 24229873, 24229873, 24229874, 24229874, 24229875, 24229876, 24229877, 24229877, 24229878, 24229879, 24229880, 24229883, 24229883, 24229885, 24229887, 24229888, 24229888, 24229889, 24229871, 24229872, 24229872, 24229873, 24229873, 24229874, 24229874, 24229875, 24229875, 24229876, 24229877, 24229879, 24229889, 24229889, 24229872, 24229873, 24229873, 24229874, 24229874, 24229875, 24229875, 24229877, 24229878, 24229883, 24229884, 24229885, 24229886, 24229889, 24229889, 24229890, 24229873, 24229874, 24229874, 24229875, 24229875, 24229878, 24229878, 24229879, 24229880, 24229880, 24229881, 24229882, 24229883, 24229885, 24229885, 24229886, 24229888, 24229888, 24229889, 24229889, 24229890, 24229890, 24229874, 24229875, 24229875, 24229876, 24229876, 24229877, 24229877, 24229878, 24229878, 24229879, 24229879, 24229881, 24229881, 24229885, 24229886, 24229887, 24229890, 24229890, 24229891, 24229875, 24229876, 24229876, 24229877, 24229878, 24229878, 24229879, 24229879, 24229880, 24229880, 24229881, 24229881, 24229882, 24229883, 24229884, 24229886, 24229886, 24229887, 24229888, 24229889, 24229890, 24229891, 24229891, 24229876, 24229877, 24229877, 24229878, 24229879, 24229879, 24229880, 24229880, 24229881, 24229882, 24229882, 24229883, 24229884, 24229886, 24229889, 24229891, 24229891, 24229892, 24229877, 24229878, 24229880, 24229880, 24229884, 24229887, 24229889, 24229890, 24229892, 24229892, 24229878, 24229879, 24229879, 24229880, 24229880, 24229881, 24229881, 24229882, 24229883, 24229884, 24229884, 24229885, 24229885, 24229888, 24229888, 24229889, 24229889, 24229890, 24229891, 24229892, 24229892, 24229893, 24229879, 24229881, 24229882, 24229882, 24229885, 24229886, 24229890, 24229893, 24229893, 24229881, 24229882, 24229882, 24229883, 24229884, 24229893, 24229894, 24229883, 24229886, 24229886, 24229888, 24229894, 24229882, 24229883, 24229887, 24229895, 24229883, 24229884, 24229884, 24229885, 24229886, 24229887, 24229887, 24229888, 24229890, 24229890, 24229891, 24229892, 24229892, 24229893, 24229894, 24229895, 24229895, 24229884, 24229885, 24229885, 24229886, 24229886, 24229887, 24229888, 24229889, 24229889, 24229890, 24229890, 24229892, 24229892, 24229893, 24229894, 24229895, 24229895, 24229896, 24229885, 24229886, 24229887, 24229888, 24229888, 24229889, 24229890, 24229891, 24229891, 24229892, 24229893, 24229895, 24229896, 24229896, 24229887, 24229887, 24229888, 24229889, 24229889, 24229890, 24229891, 24229893, 24229895, 24229895, 24229896, 24229897, 24229888, 24229889, 24229897, 24229888, 24229889, 24229890, 24229890, 24229892, 24229893, 24229894, 24229896, 24229897, 24229898, 24229889, 24229890, 24229890, 24229891, 24229892, 24229893, 24229894, 24229895, 24229896, 24229897, 24229897, 24229898, 24229898, 24229891, 24229893, 24229896, 24229897, 24229898, 24229899, 24229891, 24229892, 24229892, 24229893, 24229893, 24229894, 24229894, 24229895, 24229896, 24229896, 24229897, 24229899, 24229899, 24229892, 24229893, 24229894, 24229895, 24229896, 24229896, 24229897, 24229897, 24229898, 24229898, 24229899, 24229900, 24229894, 24229894, 24229896, 24229896, 24229897, 24229898, 24229900, 24229900, 24229895, 24229897, 24229898, 24229899, 24229901, 24229895, 24229896, 24229897, 24229899, 24229900, 24229901, 24229901, 24229896, 24229897, 24229897, 24229898, 24229898, 24229899, 24229901, 24229902, 24248221, 24229900, 24229901, 24229902, 24229902, 24229898, 24229899, 24229899, 24229900, 24229900, 24229902, 24229902, 24229903, 24229899, 24229900, 24229903, 24229903, 24229900, 24229901, 24229901, 24229902, 24229903, 24229903, 24229904, 24229901, 24229902, 24229902, 24229903, 24229903, 24229904, 24229904, 24229902, 24229903, 24229904, 24229904, 24229905, 24229903, 24229904, 24229904, 24229905, 24229905, 24229904, 24229905, 24229905, 24229906, 24229905, 24229906, 24229906, 24229906, 24229907, 24229907, 24229934, 24311507, 24229908, 24229909, 24229909, 24229910, 24229911, 24229911, 24229914, 24229915, 24229919, 24229920, 24229920, 24229922, 24229923, 24229924, 24229924, 24229925, 24229925, 24229926, 24229926, 24229927, 24229927, 24229928, 24229929, 24229930, 24229931, 24229931, 24229932, 24229932, 24229933, 24229934, 24229934, 24229935, 24230657, 24230659, 24230660, 24230660, 24230661, 24248170, 24248227, 24248227, 24248256, 24248256, 24311508, 24229909, 24229910, 24229910, 24229911, 24229912, 24229912, 24229913, 24229913, 24229914, 24229915, 24229916, 24229917, 24229917, 24229918, 24229919, 24229919, 24229920, 24229920, 24229921, 24229922, 24229923, 24229924, 24229925, 24229925, 24229926, 24229927, 24229928, 24229929, 24229930, 24229930, 24229931, 24229932, 24229932, 24229933, 24229933, 24229934, 24229935, 24229935, 24230661, 24248228, 24229911, 24229911, 24229912, 24229913, 24229914, 24229916, 24229918, 24229918, 24229921, 24229923, 24229929, 24229932, 24229933, 24229933, 24229934, 24229936, 24229933, 24229936, 24229936, 24229913, 24229915, 24229921, 24229927, 24229929, 24229937, 24230662, 24229914, 24229930, 24229937, 24229914, 24229917, 24229929, 24229938, 24229915, 24229924, 24229930, 24229930, 24229932, 24229938, 24229923, 24229927, 24229933, 24229934, 24229923, 24229933, 24229922, 24229927, 24229935, 24229921, 24229937, 24229940, 24229941, 24229922, 24229924, 24229942, 24229924, 24229925, 24229939, 24229942, 24248235, 24229933, 24229927, 24229928, 24229935, 24229942, 24229927, 24229936, 24229940, 24229944, 24229929, 24229935, 24229940, 24229945, 24229936, 24229936, 24229939, 24229940, 24229943, 24229944, 24229944, 24229946, 24229945, 24229936, 24229944, 24229945, 24229947, 24229938, 24248239, 24229947, 24229945, 24229937, 24229939, 24229940, 24229942, 24229939, 24229948, 24229948, 24229946, 24229940, 24229941, 24229941, 24248243, 24229941, 24229944, 24229942, 24229943, 24229944, 24229946, 24229947, 24229948, 24229951, 24229952, 24229946, 24229948, 24229949, 24229952, 24229948, 24229952, 24229953, 24229945, 24229946, 24229947, 24229947, 24229949, 24248246, 24229947, 24229951, 24229952, 24229954, 24229947, 24229948, 24229951, 24229948, 24229949, 24229950, 24229951, 24229953, 24229949, 24229950, 24229951, 24229952, 24229953, 24229954, 24229955, 24229951, 24229953, 24229954, 24229954, 24229955, 24229956, 24248248, 24229952, 24229953, 24229955, 24229956, 24229955, 24229954, 24229954, 24229955, 24229955, 24229956, 24229957, 24229957, 24248250, 24229955, 24229956, 24229958, 24229955, 24229956, 24229957, 24229957, 24229958, 24229956, 24229957, 24229957, 24229959, 24229957, 24229958, 24230684, 24230685, 24248252, 24229958, 24229959, 24229959, 24229960, 24229959, 24229960, 24229960, 24229960, 24229961, 24229961, 24229962, 24230001, 24230685, 24230685, 24230686, 24230686, 24230687, 24230687, 24230688, 24230690, 24230691, 24248139, 24248246, 24248254, 24248254, 24248283, 24306786, 24311535, 24230686, 24230687, 24230688, 24230688, 24248254, 24248255, 24248284, 24248307, 24248348, 24306788, 24311535, 24230727, 24231422, 24231410, 24231411, 24231424, 24231411, 24231412, 24231412, 24231413, 24231416, 24231426, 24231427, 24231412, 24231427, 24231427, 24231414, 24231415, 24231424, 24231425, 24231426, 24231426, 24231427, 24231427, 24231428, 24231428, 24231429, 24231430, 24231430, 24231427, 24231429, 24231418, 24231428, 24231430, 24231429, 24231430, 24231431, 24231429, 24231430, 24231431, 24231439, 24231440, 24231562, 24231562, 24248992, 24231439, 24231441, 24231441, 24231564, 24248993, 24248993, 24231442, 24231442, 24231443, 24248994, 24231442, 24248994, 24231443, 24231444, 24231445, 24231446, 24231566, 24248879, 24248994, 24248995, 24249024, 24231446, 24248995, 24249024, 24248996, 24249025, 24248996, 24248997, 24248997, 24248998, 24249027, 24231698, 24231699, 24249110, 24249128, 24249157, 24266391, 24266490, 24266507, 24266529, 24266538, 24266538, 24266546, 24266547, 24266548, 24266548, 24266549, 24266549, 24266550, 24266550, 24266551, 24266551, 24266552, 24266553, 24266554, 24266554, 24266555, 24266556, 24266557, 24266557, 24266559, 24266562, 24266564, 24266567, 24266568, 24266569, 24266570, 24266573, 24266574, 24266574, 24266575, 24266575, 24266576, 24266549, 24266552, 24266556, 24266557, 24266569, 24266575, 24266575, 24266576, 24266576, 24266550, 24266554, 24266555, 24266556, 24266576, 24266550, 24266552, 24266555, 24266576, 24266576, 24266577, 24266577, 24266577, 24266578, 24266578, 24266578, 24266560, 24266579, 24266579, 24266560, 24266580, 24266581, 24266581, 24266582, 24266582, 24266583, 24266583, 24266584, 24266584, 24266579, 24266585, 24266585, 24266585, 24266586, 24266587, 24266585, 24266591, 24266592, 24266596, 24266597, 24266597, 24266598, 24266598, 24266599, 24266601, 24266602, 24266602, 24266603, 24266603, 24266603, 24266604, 24266604, 24266605, 24266606, 24266606, 24266607, 24266607, 24266608, 24266608, 24266609, 24266610, 24266610, 24266611, 24266611, 24266612, 24266612, 24266613, 24266613, 24266614, 24266614, 24266615, 24266616, 24266616, 24266617, 24266617, 24266618, 24266618, 24266619, 24266620, 24266620, 24266621, 24266622, 24266622, 24266623, 24266623, 24266624, 24266624, 24266625, 24266625, 24266626, 24266626, 24266627, 24266628, 24266628, 24266629, 24266630, 24266631, 24266631, 24266633, 24266633, 24266634, 24266635, 24266643, 24266651, 24266651, 24266606, 24266607, 24266607, 24266608, 24266608, 24266609, 24266610, 24266611, 24266611, 24266613, 24266614, 24266615, 24266615, 24266616, 24266617, 24266620, 24266620, 24266621, 24266622, 24266623, 24266624, 24266624, 24266625, 24266626, 24266626, 24266627, 24266628, 24266629, 24266631, 24266632, 24266646, 24266647, 24266652, 24266607, 24266608, 24266608, 24266611, 24266614, 24266615, 24266620, 24266625, 24266626, 24266627, 24266612, 24266614, 24266624, 24266625, 24266625, 24266626, 24266621, 24266625, 24266625, 24266626, 24266628, 24266611, 24266616, 24266617, 24266620, 24266625, 24266625, 24266626, 24266627, 24266627, 24266634, 24266654, 24266617, 24266623, 24266629, 24266617, 24266618, 24266619, 24266623, 24266627, 24266629, 24266630, 24266628, 24266630, 24266618, 24266629, 24266631, 24266620, 24266620, 24266622, 24266629, 24266630, 24266632, 24266634, 24266618, 24266620, 24266620, 24266621, 24266621, 24266625, 24266627, 24266630, 24266631, 24266630, 24266633, 24266620, 24266631, 24266632, 24266638, 24266621, 24266627, 24266631, 24266633, 24266634, 24266628, 24266634, 24266636, 24266623, 24266624, 24266632, 24266632, 24266634, 24266635, 24266639, 24266623, 24266631, 24266626, 24266629, 24266630, 24266631, 24266632, 24266632, 24266633, 24266633, 24266637, 24266634, 24266634, 24266635, 24266636, 24266636, 24266627, 24266635, 24266636, 24266637, 24266637, 24266638, 24266645, 24266631, 24266634, 24266635, 24266635, 24266638, 24266639, 24266640, 24266629, 24266635, 24266638, 24266636, 24266636, 24266637, 24266634, 24266637, 24266640, 24266638, 24266637, 24266638, 24266639, 24266641, 24266639, 24266641, 24266641, 24266639, 24266639, 24266641, 24266642, 24266639, 24266640, 24266640, 24266640, 24266641, 24266643, 24266643, 24266648, 24266668, 24266640, 24266641, 24266641, 24266643, 24266644, 24266645, 24266646, 24266650, 24266641, 24266642, 24266642, 24266643, 24266643, 24266644, 24266644, 24266646, 24266669, 24266642, 24266643, 24266644, 24266645, 24266646, 24266647, 24266650, 24266643, 24266644, 24266644, 24266645, 24266645, 24266646, 24266646, 24266647, 24266647, 24266648, 24266649, 24266649, 24266650, 24266652, 24266653, 24266662, 24266666, 24266670, 24266670, 24266644, 24266645, 24266645, 24266646, 24266647, 24266648, 24266648, 24266649, 24266654, 24266671, 24266645, 24266646, 24266646, 24266647, 24266648, 24266648, 24266649, 24266651, 24266651, 24266652, 24266646, 24266647, 24266648, 24266648, 24266649, 24266652, 24266647, 24266648, 24266649, 24266649, 24266650, 24266651, 24266651, 24266652, 24266652, 24266653, 24266654, 24266663, 24266667, 24266669, 24266672, 24266672, 24266648, 24266649, 24266649, 24266650, 24266650, 24266651, 24266651, 24266652, 24266652, 24266653, 24266653, 24266654, 24266654, 24266655, 24266658, 24266664, 24266664, 24266665, 24266669, 24266670, 24266671, 24266672, 24266673, 24266649, 24266650, 24266654, 24266650, 24266651, 24266651, 24266652, 24266652, 24266653, 24266653, 24266654, 24266654, 24266656, 24266664, 24266665, 24266665, 24266666, 24266668, 24266669, 24266671, 24266673, 24266674, 24266651, 24266652, 24266652, 24266653, 24266653, 24266654, 24266654, 24266656, 24266656, 24266671, 24266674, 24266652, 24266653, 24266653, 24266654, 24266654, 24266655, 24266655, 24266656, 24266657, 24266658, 24266658, 24266661, 24266665, 24266670, 24266674, 24266675, 24266653, 24266654, 24266654, 24266655, 24266656, 24266656, 24266658, 24266669, 24266671, 24266672, 24266674, 24266675, 24266675, 24266654, 24266655, 24266655, 24266656, 24266656, 24266659, 24266666, 24266672, 24266675, 24266655, 24266656, 24266656, 24266657, 24266657, 24266658, 24266658, 24266659, 24266662, 24266666, 24266667, 24266669, 24266671, 24266673, 24266674, 24266675, 24266676, 24266676, 24266656, 24266657, 24266657, 24266658, 24266658, 24266659, 24266660, 24266660, 24266662, 24266666, 24266666, 24266667, 24266667, 24266672, 24266673, 24266674, 24266674, 24266676, 24266676, 24266677, 24266677, 24266657, 24266658, 24266658, 24266659, 24266659, 24266660, 24266661, 24266662, 24266664, 24266665, 24266667, 24266668, 24266676, 24266677, 24266677, 24266658, 24266659, 24266659, 24266660, 24266660, 24266661, 24266661, 24266663, 24266664, 24266665, 24266666, 24266667, 24266668, 24266669, 24266669, 24266671, 24266672, 24266673, 24266673, 24266674, 24266674, 24266675, 24266676, 24266676, 24266677, 24266677, 24266678, 24266659, 24266660, 24266660, 24266661, 24266661, 24266662, 24266663, 24266667, 24266668, 24266669, 24266670, 24266673, 24266674, 24266675, 24266676, 24266678, 24266678, 24266660, 24266661, 24266662, 24266662, 24266664, 24266674, 24266676, 24266678, 24266679, 24266661, 24266662, 24266662, 24266663, 24266667, 24266668, 24266668, 24266670, 24266671, 24266671, 24266676, 24266676, 24266679, 24266679, 24266662, 24266663, 24266663, 24266664, 24266665, 24266667, 24266667, 24266669, 24266670, 24266670, 24266671, 24266672, 24266673, 24266674, 24266675, 24266675, 24266676, 24266677, 24266678, 24266679, 24266680, 24266665, 24266665, 24266671, 24266679, 24266680, 24266664, 24266665, 24266666, 24266666, 24266668, 24266670, 24266671, 24266672, 24266672, 24266673, 24266673, 24266674, 24266676, 24266677, 24266679, 24266680, 24266681, 24266671, 24266674, 24266677, 24266680, 24266681, 24266681, 24266678, 24266682, 24266682, 24266678, 24266680, 24266682, 24266683, 24266674, 24266682, 24266683, 24266675, 24266683, 24266681, 24266685, 24266676, 24266682, 24266684, 24266685, 24266686, 24266676, 24266679, 24266686, 24266687, 24266680, 24266683, 24266685, 24266686, 24266686, 24266687, 24266687, 24266679, 24266687, 24266688, 24266679, 24266683, 24266685, 24266688, 24266684, 24266685, 24266687, 24266688, 24266689, 24266685, 24266685, 24266689, 24266689, 24266684, 24266685, 24266685, 24266686, 24266687, 24266690, 24266687, 24266690, 24266690, 24266686, 24266688, 24266690, 24266691, 24266691, 24266692, 24266688, 24266692, 24266692, 24266691, 24266692, 24266693, 24266690, 24266691, 24266692, 24266693, 24266693, 24266690, 24266691, 24266693, 24266693, 24266694, 24266691, 24266692, 24266694, 24266694, 24266692, 24266694, 24266695, 24266694, 24266694, 24266695, 24266695, 24266695, 24266696, 24266696, 24266696, 24266696, 24266697, 24266697, 24266698, 24266699, 24266699, 24266704, 24266711, 24266715, 24266716, 24266716, 24266718, 24266720, 24266722, 24266724, 24266725, 24266725, 24266726, 24266726, 24266727, 24286781, 24286782, 24325147, 24325148, 24325149, 24325151, 24325153, 24325156, 24325157, 24329903, 24266699, 24266700, 24266700, 24266701, 24266701, 24266702, 24266703, 24266707, 24266709, 24266711, 24266711, 24266712, 24266712, 24266713, 24266716, 24266717, 24266719, 24266720, 24266721, 24266722, 24266723, 24266723, 24266725, 24266725, 24266726, 24266726, 24266727, 24266727, 24286782, 24266700, 24266701, 24266705, 24266710, 24266713, 24266720, 24266722, 24266723, 24266725, 24266726, 24266726, 24266727, 24266727, 24266728, 24266726, 24266726, 24266727, 24266728, 24266728, 24266717, 24266725, 24266727, 24266727, 24266728, 24266729, 24266728, 24266727, 24266730, 24266731, 24266723, 24266733, 24266733, 24266730, 24266737, 24266729, 24266740, 24266739, 24266740, 24329916, 24266741, 24266735, 24266741, 24266739, 24266742, 24266741, 24266743, 24266734, 24266745, 24266735, 24266742, 24266745, 24266745, 24266746, 24266745, 24266742, 24266746, 24266747, 24266747, 24266747, 24266749, 24266745, 24266749, 24266750, 24266748, 24266749, 24266751, 24266748, 24266749, 24266750, 24266750, 24266751, 24266748, 24266750, 24266751, 24266752, 24266751, 24266751, 24266752, 24266752, 24266753, 24266753, 24266752, 24266753, 24266753, 24266754, 24266753, 24266754, 24266754, 24266754, 24266755, 24266755, 24266756, 24266757, 24276771, 24276773, 24276773, 24276776, 24286807, 24286810, 24286810, 24286811, 24286811, 24286812, 24286813, 24286815, 24286815, 24286819, 24325176, 24325176, 24325177, 24325177, 24325178, 24325178, 24325180, 24325181, 24325181, 24325182, 24325182, 24325183, 24325183, 24325184, 24325184, 24325185, 24325185, 24325186, 24325186, 24325187, 24329932, 24286811, 24286812, 24329932, 24325178, 24286801, 24286801, 24286803, 24286807, 24335206, 24296841, 24335215, 24339963, 24306861, 24306863, 24306864, 24306865, 24306881, 24306883, 24306883, 24306884, 24306865, 24306866, 24306866, 24306877, 24306880, 24306880, 24306881, 24306881, 24306882, 24306882, 24306883, 24306883, 24306884, 24306885, 24306887, 24306866, 24306867, 24306872, 24306874, 24306875, 24306876, 24306877, 24306880, 24306881, 24306881, 24306882, 24306882, 24306883, 24306883, 24306884, 24306884, 24306885, 24306885, 24306886, 24306886, 24306889, 24306889, 24306867, 24306880, 24306881, 24306882, 24306882, 24306883, 24306884, 24306887, 24306874, 24306878, 24306881, 24306882, 24306882, 24306883, 24306883, 24306884, 24306884, 24306885, 24306885, 24306886, 24306886, 24306887, 24306888, 24306888, 24306889, 24306889, 24306890, 24306891, 24306895, 24306896, 24306896, 24306888, 24306895, 24306893, 24306901, 24306894, 24306899, 24306892, 24306895, 24345243, 24306896, 24306896, 24306896, 24306900, 24306900, 24306901, 24345246, 24350001, 24306896, 24306897, 24306897, 24306898, 24306899, 24306902, 24306904, 24345246, 24345253, 24345255, 24350002, 24306897, 24306901, 24345246, 24345247, 24345248, 24345250, 24345256, 24350002, 24306898, 24306899, 24306900, 24306900, 24306901, 24306902, 24306903, 24306904, 24306908, 24345247, 24345247, 24345248, 24345248, 24345249, 24345251, 24345251, 24345254, 24345256, 24345257, 24345257, 24350003, 24306899, 24306900, 24306901, 24306901, 24306902, 24306903, 24306905, 24306906, 24345249, 24345254, 24345255, 24345255, 24345256, 24345257, 24345258, 24350003, 24306900, 24306901, 24306901, 24306902, 24306902, 24345248, 24345249, 24345253, 24345256, 24350004, 24306901, 24306902, 24306903, 24306905, 24345250, 24345256, 24350004, 24306902, 24306903, 24306903, 24306904, 24306905, 24306906, 24306906, 24345249, 24345249, 24345250, 24345253, 24345254, 24345255, 24345256, 24345259, 24345259, 24350005, 24306904, 24306905, 24306906, 24306911, 24345249, 24345250, 24345251, 24345256, 24345259, 24350005, 24306904, 24306905, 24306906, 24306907, 24306911, 24345251, 24350006, 24306906, 24306910, 24333239, 24345252, 24345253, 24345256, 24345257, 24345257, 24350006, 24345252, 24345257, 24345260, 24350007, 24306908, 24345252, 24345253, 24345257, 24345260, 24345261, 24350007, 24306908, 24345253, 24345254, 24345256, 24350008, 24306914, 24345253, 24345254, 24345257, 24345261, 24345261, 24350008, 24306910, 24345261, 24345263, 24350009, 24345255, 24345263, 24350009, 24306916, 24345255, 24345255, 24350010, 24345255, 24350010, 24345255, 24345256, 24345267, 24345257, 24345258, 24345259, 24345263, 24345266, 24350013, 24345259, 24359588, 24376355, 24383597, 24383598, 24383602, 24383604, 24383604, 24383605, 24383605, 24383611, 24383612, 24383612, 24383613, 24383614, 24383598, 24383598, 24383599, 24383599, 24383602, 24383604, 24383604, 24383605, 24383605, 24383606, 24383607, 24383612, 24383612, 24383613, 24383613, 24383614, 24383617, 24383598, 24383602, 24383606, 24383606, 24383607, 24383613, 24383617, 24383622, 24383599, 24383600, 24383601, 24383601, 24383602, 24383602, 24383603, 24383604, 24383604, 24383605, 24383605, 24383606, 24383606, 24383607, 24383607, 24383608, 24383612, 24383613, 24383613, 24383614, 24383614, 24383615, 24383615, 24383616, 24383616, 24383617, 24383617, 24383618, 24383618, 24383619, 24383619, 24383620, 24383621, 24383622, 24383623, 24383603, 24383603, 24383605, 24383607, 24383608, 24383608, 24383614, 24383602, 24383603, 24383606, 24383610, 24383614, 24383619, 24383624, 24383615, 24383608, 24383605, 24383607, 24383609, 24383625, 24383625, 24383605, 24383609, 24383610, 24383611, 24383626, 24383606, 24383607, 24383607, 24383609, 24383610, 24383611, 24383607, 24383608, 24383609, 24383610, 24383611, 24383618, 24383620, 24383627, 24383608, 24383609, 24383610, 24383610, 24383611, 24383612, 24383627, 24383627, 24383609, 24383610, 24383610, 24383612, 24383628, 24383610, 24383611, 24383611, 24383612, 24383613, 24383613, 24383620, 24383621, 24383628, 24383629, 24383611, 24383612, 24383612, 24383613, 24383613, 24383614, 24383620, 24383621, 24383628, 24383629, 24383612, 24383613, 24383613, 24383614, 24383614, 24383619, 24383619, 24383620, 24383620, 24383629, 24383613, 24383614, 24383614, 24383615, 24383621, 24383622, 24383624, 24383629, 24383630, 24383614, 24383615, 24383615, 24383620, 24383621, 24383630, 24383630, 24383631, 24383615, 24383616, 24383622, 24383624, 24383625, 24383627, 24383630, 24383630, 24383631, 24383616, 24383617, 24383622, 24383622, 24383623, 24383623, 24383625, 24383627, 24383631, 24383631, 24383632, 24383635, 24383617, 24383619, 24383622, 24383623, 24383623, 24383624, 24383625, 24383626, 24383630, 24383631, 24383631, 24383632, 24383632, 24383636, 24383623, 24383632, 24383633, 24383634, 24383625, 24383627, 24383636, 24383627, 24383629, 24383632, 24383637, 24383637, 24388367, 24383628, 24383629, 24383632, 24383637, 24388368, 24383629, 24383630, 24383631, 24383634, 24383637, 24383638, 24388368, 24383630, 24383631, 24383633, 24383637, 24383638, 24383638, 24388369, 24383632, 24383632, 24383635, 24383637, 24383638, 24383639, 24383639, 24388369, 24383633, 24383639, 24388370, 24383633, 24383635, 24383638, 24388370, 24383635, 24383637, 24383640, 24388371, 24383639, 24388371, 24383638, 24383638, 24383641, 24383641, 24388372, 24383637, 24388372, 24383643, 24388373, 24383642, 24383643, 24388373, 24383644, 24388374, 24388374, 24383645, 24383645, 24388376, 24383645, 24383646, 24388376, 24383646, 24388377, 24383647, 24383648, 24383648, 24383651, 24388377, 24383651, 24388378, 24388378, 24388379, 24388381], "xaxis": "x", "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 10, 3, 2, 2, 2, 0, 0, 0, 1, 0, 1, 1, 145, 29, 14, 7, 2, 1, 1, 5, 2, 9, 1, 359, 105, 60, 4, 3, 26, 34, 28, 3, 326, 161, 15, 3, 3, 2, 6, 63, 102, 27, 3, 269, 23, 7, 8, 7, 23, 124, 184, 45, 1, 1, 46, 36, 14, 20, 13, 5, 26, 202, 262, 108, 9, 6, 25, 45, 24, 2, 2, 4, 12, 17, 34, 9, 18, 15, 6, 10, 9, 12, 6, 3, 13, 4, 6, 3, 2, 58, 10, 290, 72, 3, 0, 0, 0, 0, 0, 0, 0, 0, 596, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 76, 19, 3, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 3, 0, 0, 0, 1, 1, 2, 2, 3, 1, 6, 12, 5, 1, 1, 1, 3, 1, 1, 1, 2, 3, 2, 1, 1, 3, 4, 1, 3, 1, 1, 7, 1, 3, 2, 1, 1, 1, 0, 0, 0, 0, 5, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 4, 6, 1, 2, 1, 1, 3, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 2, 3, 2, 16, 1, 3, 2, 9, 61, 1, 1, 4, 80, 4, 8, 5, 4, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 4, 1, 10, 2, 1, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 3, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 3, 1, 2, 2, 2, 32, 40, 2, 1, 37, 1, 2, 2, 5, 1, 2, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 1, 2, 2, 1, 9, 5, 3, 69, 9, 2, 1, 2, 2, 1, 10, 6, 1, 2, 2, 2, 3, 1, 0, 0, 1, 1, 0, 4, 0, 0, 1, 0, 0, 0, 1, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 1, 0, 0, 2, 1, 0, 2, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 1, 1, 4, 52, 14, 3, 1, 1, 1, 1, 2, 4, 1, 2, 3, 1, 3, 1, 2, 3, 2, 0, 2, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 9, 4, 2, 6, 2, 1, 1, 1, 2, 1, 2, 3, 1, 6, 2, 2, 4, 2, 30, 8, 1, 2, 5, 1, 2, 1, 1, 1, 3, 2, 7, 4, 16, 3, 2, 2, 1, 1, 193, 3, 1, 2, 1, 1, 2, 2, 2, 4, 2, 1, 1, 1, 525, 53, 1, 3, 6, 2, 1, 3, 1, 1, 4, 1, 1, 1, 646, 1, 1, 2, 2, 1, 107, 15, 2, 39, 1, 33, 100, 88, 14, 17, 2, 132, 89, 41, 56, 137, 54, 1, 2, 2, 4, 4, 2, 2, 4, 1, 3, 106, 3, 2, 3, 2, 2, 5, 3, 2, 2, 2, 1, 1, 2, 18, 2, 4, 1, 2, 1, 1, 1, 1, 1, 3, 2, 1, 1, 3, 1, 29, 1, 3, 9, 2, 3, 3, 2, 1, 2, 2, 2, 1, 107, 2, 2, 1, 1, 1, 1, 64, 2, 3, 2, 3, 1, 1, 37, 64, 19, 2, 2, 2, 1, 1, 126, 70, 2, 3, 183, 60, 65, 18, 1, 223, 54, 2, 4, 3, 2, 1, 1, 1, 252, 61, 3, 2, 1, 1, 315, 123, 98, 2, 6, 2, 1, 1, 331, 101, 31, 22, 3, 4, 4, 3, 3, 451, 59, 18, 3, 4, 2, 557, 119, 59, 3, 3, 2, 734, 55, 15, 3, 1, 2, 1, 761, 150, 36, 1, 4, 3, 1, 2, 2, 766, 107, 1, 0, 3, 1, 1, 804, 31, 67, 13, 3, 2, 1, 1, 1, 816, 16, 33, 39, 14, 5, 4, 3, 7, 1, 4, 5, 2, 0, 687, 67, 70, 2, 2, 7, 1, 606, 51, 51, 42, 3, 1, 3, 6, 1, 627, 82, 1, 1, 0, 3, 2, 2, 602, 136, 60, 1, 5, 2, 3, 2, 5, 2, 2, 0, 745, 28, 12, 4, 2, 3, 0, 3, 1, 2, 885, 100, 1, 1, 4, 2, 1, 6, 3, 0, 899, 125, 3, 1, 0, 2, 0, 1, 3, 0, 2, 1, 742, 253, 28, 1, 1, 4, 0, 1, 0, 1, 748, 101, 0, 1, 1, 0, 367, 285, 75, 75, 40, 2, 18, 2, 2, 61, 0, 7, 2, 3, 1, 1, 0, 261, 86, 39, 1, 4, 1, 0, 0, 278, 40, 69, 45, 23, 80, 3, 1, 0, 86, 92, 46, 116, 3, 1, 1, 0, 49, 35, 37, 54, 22, 48, 34, 113, 4, 133, 32, 5, 0, 88, 22, 96, 0, 1, 87, 16, 0, 0, 84, 15, 71, 2, 116, 31, 0, 1, 46, 14, 65, 2, 3, 5, 1, 0, 0, 0, 33, 15, 3, 11, 0, 0, 3, 17, 5, 2, 3, 1, 0, 1, 2, 16, 5, 1, 1, 2, 0, 34, 82, 24, 4, 27, 29, 26, 6, 1, 9, 1, 121, 52, 136, 61, 72, 152, 19, 154, 52, 1217, 1, 14920, 2, 38632, 201, 3, 1, 3, 4, 1, 1, 43991, 146, 11, 6, 26, 1, 48292, 437, 141, 78, 53, 10, 49572, 1587, 415, 122, 47, 43, 106, 94, 73, 4, 46556, 4255, 105, 344, 51, 119, 193, 109, 383, 79, 18, 41225, 2798, 1235, 440, 107, 220, 177, 272, 364, 1176, 605, 822, 7, 20091, 8732, 4029, 533, 612, 755, 772, 1339, 1040, 4151, 1630, 2934, 226, 12856, 3436, 434, 706, 226, 522, 1090, 643, 1458, 696, 1135, 148, 7968, 683, 1165, 1121, 136, 2454, 716, 4949, 1411, 2719, 124, 843, 2316, 1273, 75, 571, 591, 1101, 7001, 1490, 794, 445, 207, 445, 203, 1194, 68, 174, 849, 169, 130, 851, 425, 1873, 253, 471, 83, 783, 815, 2507, 365, 76, 225, 170, 689, 175, 1896, 54, 468, 2362, 4069, 329, 727, 185, 18, 5606, 1270, 1000, 20166, 15363, 264, 64, 2, 27760, 258, 39, 50905, 1926, 165, 14, 1, 0, 48274, 1267, 227, 31, 46053, 1934, 45467, 81, 42461, 15, 15, 36874, 177, 3, 13, 32538, 52, 28, 0, 27495, 294, 10, 1, 0, 0, 0, 0, 23930, 7, 8839, 581, 13, 12, 4, 0, 0, 0, 0, 0, 7269, 83, 5, 7, 4, 1, 0, 5306, 84, 47, 17, 5, 2, 3, 2, 3, 2, 2, 1, 1, 1, 0, 0, 0, 3064, 673, 126, 19, 8, 1, 6, 6, 9, 5, 3, 1, 1, 15, 9, 5, 8, 3, 5, 1, 1, 3, 1, 1, 1, 0, 0, 0, 0, 2306, 330, 40, 12, 24, 3, 1, 49, 16, 45, 47, 15, 2, 1, 3, 5, 5, 2, 5, 1, 2, 0, 0, 0, 0, 1410, 202, 106, 114, 50, 27, 9, 21, 16, 38, 7, 9, 59, 2, 4, 46, 59, 16, 5, 6, 4, 13, 4, 3, 24, 13, 9, 2, 2, 3, 5, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 818, 107, 65, 22, 14, 20, 43, 14, 1, 3, 43, 22, 23, 81, 14, 37, 6, 2, 23, 18, 2, 35, 22, 20, 17, 4, 9, 2, 1, 4, 1, 2, 2, 1, 0, 0, 0, 0, 83, 48, 115, 25, 33, 72, 62, 15, 21, 197, 6, 63, 10, 57, 6, 23, 9, 11, 17, 19, 27, 6, 24, 6, 2, 5, 8, 2, 1, 0, 0, 0, 0, 0, 15, 21, 11, 5, 26, 2, 21, 10, 5, 72, 9, 5, 4, 20, 9, 5, 14, 9, 5, 2, 8, 4, 2, 0, 0, 1, 15, 16, 17, 10, 7, 12, 5, 4, 92, 3, 2, 3, 7, 5, 5, 8, 1, 1, 1, 41, 70, 4, 6, 4, 68, 6, 5, 5, 2, 2, 2, 0, 0, 27, 3, 56, 13, 14, 8, 10, 8, 3, 8, 2, 6, 4, 1, 0, 0, 57, 6, 3, 8, 12, 4, 4, 4, 7, 4, 5, 4, 1, 51, 8, 15, 37, 12, 63, 4, 11, 78, 4, 6, 8, 4, 6, 7, 2, 3, 3, 1, 4, 99, 12, 4, 9, 9, 2, 12, 4, 11, 13, 8, 11, 0, 3, 39, 10, 8, 5, 11, 6, 3, 71, 36, 12, 13, 4, 4, 2, 5, 5, 2, 3, 1, 5, 220, 6, 6, 10, 2, 13, 7, 18, 9, 5, 14, 108, 49, 9, 46, 47, 18, 4, 3, 50, 9, 8, 9, 2, 3, 31, 81, 227, 34, 75, 20, 6, 6, 21, 14, 2, 3, 3, 2, 2, 0, 0, 70, 84, 80, 7, 5, 5, 5, 8, 10, 1, 0, 225, 123, 10, 4, 2, 7, 21, 3, 1, 0, 578, 60, 7, 35, 8, 5, 7, 18, 28, 10, 1, 3, 1, 1, 0, 669, 180, 48, 22, 21, 28, 9, 3, 2, 689, 87, 42, 60, 8, 5, 16, 10, 1, 7, 2, 1, 0, 0, 669, 135, 42, 30, 24, 9, 3, 2, 2, 1, 3, 1, 0, 629, 122, 5, 1, 4, 30, 8, 8, 4, 3, 0, 691, 63, 26, 10, 2, 5, 3, 10, 2, 4, 4, 0, 0, 0, 0, 759, 68, 61, 32, 8, 4, 6, 2, 2, 1, 1, 2, 1, 1, 1, 0, 0, 752, 44, 24, 5, 6, 7, 5, 2, 2, 1, 1, 0, 0, 0, 694, 111, 43, 9, 8, 3, 8, 1, 5, 1, 0, 0, 0, 0, 636, 84, 15, 17, 32, 17, 8, 3, 1, 4, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 617, 38, 19, 22, 18, 3, 9, 22, 5, 5, 8, 3, 3, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 428, 71, 22, 14, 17, 8, 9, 2, 16, 6, 3, 1, 3, 3, 5, 1, 1, 0, 0, 0, 0, 0, 0, 315, 24, 29, 11, 9, 3, 2, 5, 1, 1, 4, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 236, 29, 13, 7, 1, 1, 5, 4, 1, 6, 5, 3, 1, 2, 2, 1, 0, 0, 0, 0, 184, 22, 9, 31, 4, 4, 12, 1, 2, 3, 1, 1, 1, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 121, 41, 22, 6, 13, 1, 1, 6, 2, 2, 3, 2, 0, 1, 0, 0, 0, 0, 0, 80, 12, 20, 4, 5, 1, 1, 1, 9, 1, 1, 0, 0, 0, 0, 0, 0, 0, 61, 1, 2, 7, 4, 8, 3, 6, 8, 1, 1, 2, 0, 0, 0, 0, 0, 0, 26, 27, 6, 16, 4, 2, 5, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 12, 2, 6, 3, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 16, 2, 3, 2, 11, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 7, 6, 4, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 8, 4, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 2, 2, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 2, 2, 4, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 13, 3, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 12, 2, 2, 1, 1, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 1, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 2, 1, 3, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 4, 1, 1, 2, 2, 3, 2, 1, 7, 1, 1, 4, 7, 5, 14, 7, 1, 21, 8, 25, 9, 1, 48, 88, 29, 2, 112, 32, 1, 2, 1, 780, 8, 4, 2, 2874, 456, 91, 16, 1, 6, 3398, 199, 39, 3, 4746, 240, 49, 7, 1, 6343, 169, 18, 5, 8633, 156, 2, 11185, 16, 4, 30736, 22, 2, 1, 3, 39912, 1, 6, 5, 5, 8, 2, 2, 53006, 217, 50, 68, 32, 118, 76, 57, 29, 11, 3, 42, 9, 10, 6, 52403, 442, 146, 29, 386, 925, 568, 1495, 700, 526, 30, 20, 10, 22807, 46, 161, 174, 558, 131, 295, 3707, 8723, 11725, 3588, 1520, 318, 168, 24, 22, 1, 218, 243, 76, 548, 269, 659, 1122, 1136, 5710, 9435, 3087, 1009, 116, 102, 72, 148, 47, 162, 243, 77, 175, 598, 99, 28, 457, 368, 326, 319, 177, 302, 325, 1089, 77, 623, 4477, 654, 323, 5, 13619, 2785, 522, 26, 35889, 6648, 344, 38, 40, 42691, 2752, 1066, 1, 46894, 4923, 302, 27, 48478, 816, 62, 50442, 1026, 6, 3, 1, 0, 48359, 326, 40, 2, 45780, 482, 10, 42508, 81, 7, 4, 0, 37536, 79, 4, 0, 32019, 253, 41, 6, 0, 0, 28873, 111, 10, 3, 1, 4, 0, 24776, 154, 7, 5, 0, 21342, 124, 2, 2, 0, 17730, 109, 8, 2, 0, 0, 0, 13407, 437, 38, 16, 1, 3, 2, 1, 0, 0, 0, 0, 11389, 124, 10, 7, 1, 0, 0, 8861, 114, 28, 2, 7, 8, 2, 1, 1, 1, 1, 0, 0, 6699, 182, 27, 21, 6, 2, 5, 5, 1, 1, 2, 6, 4, 3, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5050, 250, 72, 41, 19, 5, 12, 6, 6, 1, 2, 2, 2, 1, 1, 3, 0, 0, 0, 0, 0, 3990, 213, 27, 22, 10, 11, 15, 3, 3, 6, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3124, 201, 20, 23, 15, 18, 10, 10, 4, 2, 5, 3, 4, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2411, 280, 52, 18, 15, 22, 2, 1, 3, 10, 4, 2, 4, 2, 2, 4, 0, 4, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1958, 168, 45, 30, 12, 13, 19, 9, 7, 7, 2, 2, 1, 1, 1, 3, 3, 2, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1420, 363, 107, 25, 15, 4, 6, 4, 2, 2, 5, 5, 1, 4, 1, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1217, 121, 62, 4, 8, 2, 3, 2, 2, 9, 5, 2, 3, 1, 5, 1, 1, 1, 2, 0, 0, 0, 0, 0, 1152, 174, 67, 25, 12, 4, 2, 5, 4, 2, 2, 4, 5, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 926, 179, 67, 19, 6, 15, 1, 9, 1, 4, 1, 5, 3, 2, 3, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 872, 93, 42, 10, 18, 9, 9, 2, 0, 1, 5, 1, 1, 1, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 680, 227, 56, 28, 22, 2, 1, 1, 4, 1, 3, 1, 1, 1, 2, 0, 0, 0, 0, 0, 562, 156, 31, 11, 3, 6, 6, 2, 4, 1, 2, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 533, 131, 55, 32, 10, 2, 8, 3, 1, 6, 1, 2, 2, 4, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 489, 92, 62, 37, 1, 9, 13, 1, 4, 9, 1, 1, 2, 0, 0, 0, 0, 0, 0, 391, 111, 64, 14, 34, 9, 9, 1, 2, 5, 1, 1, 1, 3, 7, 1, 0, 0, 0, 0, 0, 250, 107, 102, 25, 24, 11, 14, 6, 2, 2, 2, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 179, 101, 53, 36, 25, 5, 19, 1, 1, 4, 1, 2, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 171, 59, 41, 42, 10, 10, 13, 13, 1, 2, 1, 6, 2, 0, 0, 0, 0, 0, 179, 59, 28, 12, 39, 2, 21, 1, 7, 4, 2, 1, 0, 0, 0, 0, 144, 93, 21, 17, 6, 11, 15, 1, 5, 1, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 47, 57, 27, 1, 5, 8, 2, 12, 8, 10, 0, 0, 0, 0, 97, 87, 76, 17, 6, 2, 1, 6, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 72, 29, 17, 9, 18, 7, 3, 3, 7, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 107, 61, 7, 15, 11, 19, 12, 1, 2, 1, 1, 16, 12, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 89, 15, 18, 20, 10, 7, 1, 7, 10, 7, 13, 13, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 67, 1, 40, 25, 20, 5, 1, 8, 1, 18, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 34, 21, 22, 3, 6, 1, 4, 0, 0, 0, 0, 23, 6, 22, 20, 6, 0, 0, 0, 0, 0, 6, 19, 21, 6, 4, 45, 18, 1, 0, 0, 0, 22, 1, 9, 2, 1, 17, 19, 0, 0, 0, 0, 0, 3, 10, 12, 6, 50, 29, 0, 0, 0, 9, 13, 3, 1, 9, 2, 0, 0, 0, 5, 1, 0, 0, 0, 6, 1, 2, 19, 1, 0, 0, 0, 0, 0, 0, 1, 13, 4, 0, 0, 1, 0, 0, 0, 3, 25, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 149, 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 197, 1, 0, 0, 0, 0, 0, 0, 0, 15, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 3, 1, 2, 1, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 0, 1, 1, 1, 2, 0, 0, 0, 0, 0, 2, 1, 1, 1, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 2, 1, 0, 0, 0, 0, 3, 2, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 1, 2, 1, 1, 2, 1, 8, 1, 1, 1, 4, 2, 26, 33, 1, 7, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 2, 6, 0, 1, 3, 2, 2, 1, 3, 1, 1, 1, 2, 3, 1, 2, 1, 2, 1, 3, 2, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 67, 3, 3, 3, 1, 1, 1, 3, 56, 42, 7, 1, 1, 8, 12, 4, 4, 65, 80, 6, 1, 6, 1, 2, 8, 1, 3, 2, 4, 1, 1, 1, 2, 3, 3, 6, 0, 0, 2, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 47, 4, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 2, 0, 0, 1, 1, 1, 1, 1, 1, 14, 5, 14, 1, 1, 1, 1, 56, 64, 1, 3, 7, 3, 1, 3, 5, 1, 1, 128, 3, 3, 2, 1, 2, 1, 1, 670, 12, 12, 56, 87, 78, 73, 28, 18, 15, 14, 16, 3, 8, 13, 1, 2, 1, 5, 6, 2, 1, 1, 1, 1, 1, 5, 38, 15, 67, 97, 185, 41, 86, 69, 44, 60, 60, 12, 23, 24, 17, 4, 2, 1, 3, 2, 11, 0, 4, 25, 13, 5, 8, 31, 12, 4, 6, 18, 1, 0, 101, 13, 14, 2, 11, 3, 0, 0, 136, 33, 91, 20, 30, 14, 9, 7, 10, 8, 7, 2, 1, 0, 0, 0, 0, 102, 61, 25, 20, 13, 5, 17, 13, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 61, 37, 23, 12, 16, 13, 0, 0, 0, 0, 0, 0, 123, 64, 36, 20, 13, 1, 16, 4, 4, 4, 1, 0, 0, 0, 0, 0, 0, 0, 142, 30, 15, 17, 3, 9, 5, 7, 2, 1, 0, 0, 0, 0, 0, 0, 118, 77, 49, 16, 36, 16, 20, 3, 1, 1, 3, 1, 0, 0, 0, 0, 0, 145, 25, 51, 4, 6, 9, 3, 7, 4, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 141, 49, 23, 13, 5, 3, 8, 5, 5, 1, 2, 0, 0, 94, 71, 28, 19, 6, 1, 1, 7, 2, 3, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 91, 72, 34, 3, 7, 2, 1, 1, 1, 0, 0, 0, 109, 55, 30, 11, 10, 1, 7, 3, 5, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 127, 27, 9, 15, 2, 4, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 90, 21, 45, 39, 10, 1, 1, 2, 3, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 60, 17, 27, 8, 1, 5, 2, 1, 2, 1, 0, 0, 0, 0, 28, 10, 23, 6, 8, 3, 10, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 37, 16, 15, 6, 2, 7, 4, 2, 5, 3, 0, 0, 0, 0, 0, 0, 0, 0, 27, 30, 18, 3, 6, 5, 4, 8, 1, 1, 1, 0, 0, 0, 0, 24, 2, 9, 12, 5, 5, 3, 4, 1, 0, 0, 0, 0, 20, 19, 1, 2, 5, 10, 1, 4, 1, 0, 0, 7, 8, 4, 5, 4, 6, 4, 1, 0, 0, 0, 0, 0, 0, 1, 6, 4, 2, 5, 4, 3, 3, 2, 0, 0, 16, 8, 1, 2, 4, 3, 1, 0, 0, 0, 0, 0, 0, 0, 1, 10, 7, 7, 3, 1, 2, 2, 2, 0, 0, 0, 5, 3, 1, 7, 3, 1, 0, 0, 0, 0, 11, 5, 1, 2, 0, 0, 0, 6, 8, 8, 2, 2, 0, 0, 8, 2, 2, 1, 2, 4, 2, 1, 0, 13, 6, 3, 1, 0, 0, 0, 0, 0, 0, 7, 12, 1, 1, 0, 0, 0, 0, 1, 13, 4, 1, 0, 0, 0, 0, 4, 1, 2, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1, 2, 1, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 10, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 2, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 3, 2, 1, 1, 1, 1, 2, 10, 3, 4, 2, 1, 3, 2, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 2, 2, 3, 1, 25, 1, 3, 1, 1, 1, 2, 4, 1, 1, 2, 1, 1, 1, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 4, 1, 3, 1, 5, 29, 3, 2, 8, 1, 1, 2, 1, 2, 12, 4, 1, 4, 1, 1, 1, 5, 3, 1, 6, 1, 2, 2, 1, 1, 1, 1, 1, 2, 2, 1, 2, 1, 1, 1, 2, 1, 1, 1, 0, 1, 1, 1, 1, 0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 18, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 2, 1, 5, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 2, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 3, 4, 11, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 10, 2, 3, 2, 2, 2, 1, 2, 2, 1, 2, 2, 2, 3, 2, 4, 1, 5, 2, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 18, 3, 21, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 20, 14, 9, 1, 7, 5, 2, 13, 3, 14, 2, 11, 2, 2, 1, 5, 8, 4, 8, 2, 4, 3, 5, 10, 1, 8, 7, 7, 1, 16, 5, 11, 3, 1, 2, 2, 2, 5, 12, 8, 6, 16, 1, 3, 1, 17, 7, 4, 14, 3, 3, 16, 8, 25, 3, 1, 2, 8, 2, 4, 6, 8, 19, 2, 4, 1, 11, 2, 2, 11, 8, 20, 34, 13, 5, 2, 3, 8, 4, 8, 2, 14, 13, 14, 4, 1, 8, 9, 5, 12, 3, 6, 2, 3, 1, 1, 3, 4, 4, 3, 3, 1, 2, 1, 7, 0, 6, 4, 1, 9, 4, 2, 10, 2, 4, 0, 0, 4, 10, 7, 2, 2, 2, 0, 0, 0, 0, 12, 7, 10, 1, 1, 0, 0, 0, 0, 33, 2, 4, 2, 0, 0, 0, 0, 0, 17, 16, 7, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 2, 1, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 86, 3, 9, 3, 5, 799, 40, 5, 8, 6, 2, 112, 9, 4, 2, 2, 3, 1, 14, 4, 6, 186, 16, 16, 44, 4, 1, 1, 0, 0, 0, 0, 2, 19, 22, 0, 0, 0, 0, 0, 4, 1, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 6, 4, 1, 1, 71, 3, 2, 2, 2, 4, 152, 77, 99, 7, 33, 70, 326, 25, 22, 2, 2, 35, 60, 107, 36, 15, 30, 90, 28, 49, 156, 3, 2, 4, 23, 54, 0, 0, 0, 0, 145, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 1, 1, 0, 0, 0, 0, 4, 0, 1, 0, 1, 1, 1, 1, 4, 0, 0, 0, 0, 0, 0, 14, 8, 11, 11, 6, 22, 12, 2, 4, 2, 1, 6, 4, 5, 3, 6, 8, 12, 2, 3, 2, 6, 4, 14, 5, 4, 2, 1, 2, 1, 5, 3, 1, 1, 1, 1, 1, 1, 5, 3, 1, 0, 0, 0, 3, 3, 4, 1, 0, 0, 0, 0, 0, 7, 1, 2, 0, 0, 0, 0, 0, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 4, 1, 1, 1, 1, 1, 7, 3, 1, 4, 2, 7, 5, 1, 3, 3, 1, 3, 3, 5, 4, 3, 3, 2, 18, 21, 3, 9, 3, 1, 5, 5, 10, 3, 3, 7, 8, 4, 4, 13, 2, 2, 5, 2, 0, 3, 3, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 4, 1, 0, 0, 0, 0, 0, 1, 1, 1, 2, 1, 1, 1, 1, 25, 15, 7, 13, 6, 2, 1, 1, 1, 1, 0, 0, 6, 2, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 3, 1, 1, 2, 1, 1, 4, 7, 1, 1, 2, 1, 2, 4, 1, 2, 2, 2, 1, 5, 1, 2, 9, 5, 1, 7, 1, 3, 3, 4, 30, 1, 2, 2, 2, 4, 1, 0, 0, 2, 0, 0, 1, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 9, 6, 9, 4, 2, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 7, 1, 16, 2, 1, 4, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 4, 2, 1, 2, 2, 3, 1, 1, 2, 2, 1, 2, 3, 2, 3, 3, 4, 1, 1, 1, 1, 3, 7, 2, 2, 1, 2, 1, 1, 2, 1, 2, 19, 25, 12, 8, 3, 4, 5, 1, 1, 1, 1, 2, 1, 1, 3, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 5, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 10, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 4, 2, 1, 1, 5, 1, 2, 3, 3, 3, 5, 1, 5, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 10, 1, 3, 1, 1, 1, 2, 1, 2, 3, 24, 2, 1, 2, 1, 21, 3, 4, 2, 1, 4, 8, 2, 1, 1, 2, 4, 3, 1, 1, 1, 3, 3, 1, 1, 1, 2, 2, 1, 2, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 4, 2, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 1, 4, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 3, 3, 1, 1, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 0, 0, 2, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 3, 1, 8, 2, 1, 4, 3, 28, 1, 1, 1, 0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 19, 1, 0, 0, 0, 0, 0, 0, 1, 4, 4, 8, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 3, 1, 6, 3, 3, 2, 54, 57, 12, 12, 2, 2, 2, 2, 2, 1, 1, 100, 52, 23, 5, 6, 10, 2, 2, 1, 1, 1, 229, 59, 22, 17, 9, 7, 4, 1, 1, 1, 5, 3, 1, 374, 67, 24, 18, 20, 13, 15, 3, 3, 2, 7, 4, 15, 1, 5, 275, 165, 121, 57, 52, 20, 10, 2, 1, 19, 8, 23, 9, 166, 176, 67, 52, 20, 3, 8, 3, 4, 15, 21, 7, 2, 5, 238, 90, 48, 30, 10, 4, 3, 25, 20, 16, 9, 7, 320, 155, 99, 3, 7, 3, 7, 16, 33, 41, 43, 10, 3, 1, 1, 287, 164, 54, 9, 2, 3, 1, 2, 4, 4, 50, 54, 79, 18, 6, 1, 384, 52, 25, 36, 3, 4, 12, 5, 5, 3, 25, 94, 129, 23, 15, 119, 35, 36, 24, 30, 24, 10, 40, 6, 9, 15, 18, 5, 8, 163, 177, 99, 66, 29, 1, 22, 21, 12, 5, 17, 4, 9, 1, 8, 35, 53, 90, 12, 17, 1, 21, 20, 2, 11, 10, 19, 25, 13, 8, 1, 5, 17, 3, 15, 17, 34, 22, 25, 15, 14, 1, 4, 4, 19, 9, 6, 4, 7, 10, 24, 22, 2, 8, 3, 30, 20, 16, 10, 4, 9, 15, 17, 3, 2, 4, 40, 10, 10, 13, 18, 3, 5, 14, 8, 2, 8, 14, 6, 26, 37, 9, 0, 0, 16, 11, 1, 7, 20, 9, 2, 0, 280, 168, 33, 8, 0, 0, 687, 80, 25, 2, 0, 0, 0, 0, 0, 0, 0, 0, 726, 245, 8, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 630, 22, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 176, 34, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 1, 1, 2, 1, 1, 1, 2, 2, 1, 3, 4, 1, 2, 4, 16, 3, 35, 1, 3, 2, 1, 2, 2, 0, 0, 0, 1, 1, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 0, 2, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 2, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 0, 0, 2, 1, 2, 1, 1, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 1, 0, 0, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 13, 2, 1, 2, 1, 1, 1, 1, 1, 0, 1, 1, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 1, 1, 1, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 1, 1, 3, 5, 1, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 2, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 4, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 142, 65, 22, 21, 18, 4, 2, 1, 75, 41, 21, 7, 5, 3, 1, 110, 25, 10, 13, 57, 50, 14, 6, 2, 1, 59, 32, 26, 4, 3, 95, 40, 23, 10, 3, 36, 22, 1, 4, 42, 22, 22, 7, 5, 1, 12, 3, 63, 49, 14, 3, 10, 2, 12, 2, 3, 67, 22, 13, 13, 6, 4, 1, 18, 3, 4, 2, 1, 3, 5, 3, 4, 2, 2, 3, 163, 69, 18, 6, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 117, 38, 33, 11, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 75, 58, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 47, 9, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3, 0, 0, 0, 2, 0, 0, 1, 0, 1, 1, 0, 0, 4, 0, 0, 0, 0, 5, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 12, 1, 2, 1, 1, 1, 2, 3, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 2, 1, 5, 1, 3, 3, 1, 44, 9, 1, 3, 5, 1, 3, 1, 1, 2, 7, 2, 2, 0, 0, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 6, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 7, 3, 2, 4, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 2, 2, 1, 2, 2, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 2, 4, 2, 1, 0, 0, 0, 1, 0, 1, 0, 1, 4, 5, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 19, 1, 1, 2, 2, 1, 300, 82, 62, 35, 18, 11, 5, 1, 1, 1, 1, 1, 297, 90, 71, 40, 11, 4, 2, 3, 5, 434, 103, 45, 18, 6, 3, 1, 4, 565, 260, 49, 3, 13, 1, 1, 1, 882, 155, 46, 15, 8, 4, 3, 3, 1, 2, 1, 1, 1550, 186, 49, 30, 7, 3, 2, 5, 1, 1, 2032, 276, 87, 36, 26, 11, 3, 4, 6, 2, 2, 2094, 605, 128, 53, 12, 3, 15, 4, 4, 5, 6, 4, 3, 4, 2, 1, 2405, 326, 64, 35, 13, 18, 9, 4, 10, 12, 4, 11, 3, 3, 2915, 503, 78, 12, 56, 4, 11, 12, 5, 11, 16, 6, 6, 12, 8, 18, 12, 15, 16, 3142, 423, 199, 84, 17, 2, 20, 19, 18, 12, 34, 15, 57, 34, 3, 2, 1, 1, 2296, 841, 425, 48, 79, 54, 18, 16, 5, 71, 40, 7, 61, 32, 14, 141, 59, 76, 20, 35, 26, 7, 2, 3, 3, 1, 1448, 726, 102, 90, 81, 20, 27, 13, 33, 51, 54, 43, 35, 6, 154, 94, 92, 30, 22, 5, 1, 1339, 256, 80, 128, 47, 20, 45, 37, 14, 10, 121, 7, 14, 88, 22, 33, 19, 151, 113, 85, 73, 469, 269, 233, 22, 61, 19, 58, 236, 181, 117, 63, 51, 117, 35, 103, 472, 134, 86, 121, 16, 4, 9, 4, 1, 1, 1, 85, 215, 53, 18, 47, 25, 18, 50, 129, 28, 12, 69, 13, 90, 44, 32, 16, 3, 161, 48, 67, 54, 32, 52, 27, 74, 43, 22, 67, 68, 56, 39, 93, 17, 112, 86, 46, 71, 19, 63, 100, 101, 53, 7, 15, 28, 94, 25, 49, 8, 42, 60, 8, 21, 40, 14, 48, 24, 45, 20, 9, 11, 60, 40, 43, 95, 58, 19, 37, 33, 87, 30, 31, 29, 27, 33, 28, 15, 18, 11, 9, 28, 6, 6, 2, 14, 84, 21, 62, 79, 12, 29, 128, 235, 169, 34, 64, 4, 36, 47, 56, 32, 51, 31, 270, 19, 79, 35, 8, 87, 12, 76, 166, 101, 48, 29, 61, 47, 46, 87, 39, 11, 22, 72, 33, 156, 86, 29, 30, 2, 1, 87, 290, 63, 175, 25, 2, 104, 150, 82, 86, 33, 5, 0, 506, 214, 87, 23, 1, 0, 1703, 969, 341, 36, 17, 5, 5, 3, 6, 1, 0, 0, 1887, 895, 44, 12, 13, 5, 3204, 311, 49, 31, 3, 1, 2, 1, 1, 0, 0, 3653, 336, 172, 31, 22, 1, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 2729, 554, 102, 43, 13, 10, 1, 1, 4, 1, 0, 0, 0, 0, 0, 0, 2369, 193, 74, 34, 8, 12, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1972, 376, 68, 37, 4, 10, 7, 5, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1594, 206, 22, 17, 10, 6, 3, 3, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1331, 158, 72, 27, 16, 4, 2, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 886, 225, 49, 24, 19, 18, 2, 2, 2, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 542, 173, 51, 19, 26, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 452, 106, 22, 38, 1, 5, 1, 1, 2, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 371, 75, 56, 1, 11, 1, 4, 2, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 237, 119, 8, 2, 1, 2, 2, 3, 5, 8, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 198, 5, 10, 5, 2, 1, 3, 1, 5, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 45, 31, 5, 7, 12, 5, 8, 15, 3, 1, 2, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 9, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 20, 3, 1, 5, 3, 5, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 2, 3, 3, 4, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 5, 0, 0, 0, 1, 2, 1, 1, 1, 6, 7, 1, 2, 17, 4, 2, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 2, 1, 1, 1, 3, 1, 2, 2, 2, 3, 2, 1, 1, 1, 2, 3, 2, 3, 2, 2, 5, 7, 4, 1, 1, 4, 3, 3, 2, 6, 22, 1, 2, 14, 3, 6, 9, 26, 43, 3, 4, 11, 7, 13, 3, 17, 66, 3, 2, 4, 2, 1, 5, 3, 0, 3, 3, 6, 0, 0, 0, 0, 0, 0, 2, 6, 0, 0, 3, 10, 6, 0, 0, 0, 0, 0, 5, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 10, 8, 0, 4, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 3, 1, 1, 1, 1, 1, 2, 2, 1, 3, 5, 1, 2, 8, 1, 6, 8, 2, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 1, 6, 2, 2, 3, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 8, 4, 1, 1, 1, 1, 2, 6, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 1, 0, 0, 0, 2, 1, 0, 0, 0, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 11, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 3, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 11, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 2, 2, 1, 1, 1, 1, 2, 2, 2, 1, 2, 4, 1, 1, 2, 1, 1, 1, 4, 3, 2, 1, 1, 1, 1, 1, 1, 4, 1, 1, 1, 0, 2, 3, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1, 2, 1, 2, 2, 0, 2, 1, 1, 1, 2, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 0, 1, 1, 2, 1, 3, 3, 5, 2, 2, 1, 2, 2, 1, 5, 3, 2, 2, 3, 1, 11, 3, 0, 3, 1, 1, 3, 7, 1, 3, 1, 2, 1, 2, 0, 1, 2, 1, 2, 2, 1, 1, 1, 0, 0, 0, 2, 0, 0, 2, 0, 2, 0, 1, 0, 0, 1, 0, 0, 1, 0, 2, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 1, 1, 11, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 1, 3, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 3, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 66, 17, 14, 1, 16, 19, 18, 17, 5, 22, 68, 6, 10, 2, 3, 5, 8, 1, 1, 7, 15, 2, 9, 28, 3, 7, 6, 53, 2, 2, 1, 2, 3, 5, 8, 5, 7, 2, 8, 1, 2, 3, 13, 6, 3, 6, 1, 3, 13, 1, 4, 2, 5, 2, 3, 1, 2, 10, 5, 3, 3, 4, 1, 1, 0, 0, 0, 0, 0, 6, 8, 7, 3, 3, 2, 3, 1, 0, 0, 0, 1, 2, 3, 10, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 2, 2, 12, 1, 3, 1, 0, 0, 0, 0, 8, 4, 0, 0, 0, 0, 7, 2, 2, 3, 0, 0, 0, 0, 0, 0, 3, 17, 6, 3, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 2, 6, 3, 3, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 4, 5, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 7, 5, 4, 12, 6, 7, 3, 2, 1, 1, 1, 23, 5, 30, 11, 1, 2, 1, 68, 9, 19, 2, 6, 2, 2, 100, 5, 1, 4, 6, 75, 10, 9, 3, 18, 1, 1, 2, 3, 5, 1, 1, 0, 1, 4, 2, 0, 19, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 5, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 6, 3, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 1, 1, 1, 1, 17, 1, 1, 2, 1, 1, 1, 2, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 2, 1, 0, 0, 0, 2, 1, 0, 0, 0, 8, 0, 1, 1, 3, 0, 0, 0, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 22, 11, 1, 1, 1, 39, 19, 22, 1, 1, 1, 1, 1, 1, 16, 2, 1, 1, 17, 32, 17, 1, 1, 2, 2, 1, 2, 16, 9, 34, 3, 1, 1, 3, 1, 2, 3, 1, 1, 4, 2, 0, 0, 1, 0, 3, 21, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 1, 2, 1, 2, 1, 5, 3, 1, 2, 16, 1, 10, 3, 1, 5, 3, 4, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 2, 3, 1, 1, 1, 1, 4, 2, 2, 1, 3, 2, 2, 1, 35, 41, 4, 4, 1, 1, 2, 1, 1, 3, 1, 2, 5, 15, 2, 1, 1, 1, 2, 1, 2, 10, 2, 1, 2, 2, 3, 2, 1, 2, 2, 1, 1, 3, 2, 1, 1, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 1, 0, 0, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 4, 2, 1, 1, 3, 1, 2, 3, 23, 35, 7, 1, 1, 3, 24, 5, 1, 2, 1, 2, 2, 1, 0, 1, 0, 0, 0, 0, 2, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 1, 1, 2, 1, 1, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 4, 2, 2, 3, 5, 2, 1, 1, 1, 2, 2, 1, 2, 1, 1, 1, 1, 3, 3, 1, 3, 1, 4, 2, 2, 5, 1, 2, 5, 1, 3, 8, 4, 3, 1, 1, 1, 1, 1, 1, 1, 1, 0, 2, 1, 1, 2, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 1, 1, 6, 5, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 0, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 4, 2, 2, 3, 9, 1, 4, 3, 1, 5, 3, 1, 1, 1, 3, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 10, 15, 2, 1, 1, 1, 1, 13, 1, 2, 2, 1, 1, 2, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 0, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 1, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 9, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 7, 4, 1, 6, 1, 1, 3, 1, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 3, 6, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 3, 1, 3, 1, 8, 37, 3, 30, 3, 3, 9, 1, 18, 2, 12, 1, 2, 2, 116, 40, 24, 2, 4, 3, 1, 28, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 6, 3, 2, 2, 1, 1, 1, 3, 17, 6, 21, 1, 8, 3, 2, 3, 2, 4, 2, 1, 3, 1, 2, 25, 5, 13, 12, 2, 2, 5, 2, 7, 8, 2, 1, 4, 1, 1, 7, 6, 12, 2, 2, 1, 5, 6, 3, 2, 4, 17, 20, 39, 16, 2, 2, 3, 4, 5, 7, 19, 9, 5, 12, 7, 2, 30, 11, 1, 2, 3, 2, 4, 5, 4, 6, 3, 6, 74, 9, 1, 2, 3, 10, 2, 6, 7, 20, 20, 26, 3, 41, 7, 4, 8, 4, 6, 13, 28, 17, 20, 25, 21, 23, 55, 1, 1, 3, 14, 12, 5, 5, 3, 5, 14, 41, 7, 1, 2, 3, 10, 9, 1, 5, 2, 6, 3, 4, 3, 3, 1, 2, 3, 1, 3, 2, 1, 1, 2, 2, 1, 0, 3, 7, 6, 3, 11, 0, 0, 4, 10, 3, 5, 8, 15, 1, 0, 10, 3, 3, 6, 9, 0, 0, 0, 0, 0, 0, 0, 19, 7, 5, 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 17, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 30, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 51, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 2, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 1, 0, 1, 1, 4, 1, 14, 16, 4, 10, 2, 1, 64, 10, 1, 1, 1, 2, 8, 7, 12, 6, 1, 1, 1, 2, 1, 2, 0, 4, 1, 0, 0, 0, 3, 2, 2, 1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 2, 2, 1, 10, 4, 1, 2, 4, 1, 1, 14, 1, 1, 2, 1, 6, 1, 6, 8, 5, 3, 5, 3, 7, 2, 0, 0, 0, 4, 0, 0, 0, 0, 0, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 3, 1, 0, 0, 0, 1, 1, 1, 1, 1, 2, 2, 1, 1, 3, 2, 9, 1, 2, 1, 2, 2, 15, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 3, 2, 1, 1, 1, 21, 1, 2, 6, 2, 5, 6, 6, 3, 2, 1, 18, 1, 1, 5, 46, 57, 28, 21, 14, 7, 9, 3, 1, 1, 1, 1, 5, 10, 14, 3, 3, 1, 1, 3, 1, 2, 4, 2, 1, 1, 2, 1, 5, 0, 1, 0, 0, 0, 0, 1, 5, 10, 2, 2, 2, 0, 0, 0, 0, 0, 10, 7, 3, 6, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 3, 5, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 1, 1, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 2, 0, 0, 0, 0, 1, 1, 0, 0, 2, 1, 1, 1, 0, 0, 0, 0, 1, 3, 1, 5, 15, 1, 1, 1, 1, 2, 2, 1, 3, 64, 4, 3, 11, 22, 6, 4, 5, 23, 24, 6, 8, 7, 20, 54, 129, 103, 25, 37, 4, 4, 3, 4, 9, 4, 15, 6, 8, 8, 7, 12, 9, 6, 9, 6, 2, 3, 1, 2, 1, 1, 0, 0, 0, 1, 8, 3, 0, 0, 5, 4, 2, 8, 0, 0, 15, 16, 8, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 50, 16, 29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 1, 3, 1, 1, 1, 6, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 3, 1, 1, 2, 1, 2, 1, 5, 3, 1, 1, 2, 1, 14, 3, 6, 9, 1, 2, 3, 1, 4, 2, 1, 2, 2, 1, 2, 2, 1, 1, 0, 1, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 12, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 2, 1, 0, 0, 0, 1, 1, 1, 1, 2, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 4, 0, 1, 1, 0, 0, 1, 2, 1, 0, 3, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 2, 1, 1, 2, 10, 4, 1, 2, 3, 1, 1, 1, 1, 3, 1, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 1, 5, 1, 2, 19, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 1, 1, 1, 3, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 4, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 2, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 9, 2, 1, 2, 2, 2, 9, 4, 1, 1, 1, 4, 2, 1, 4, 5, 4, 1, 3, 9, 13, 1, 4, 5, 2, 4, 1, 4, 7, 3, 5, 1, 6, 1, 13, 5, 5, 1, 1, 2, 1, 1, 1, 3, 3, 1, 1, 3, 1, 2, 1, 2, 0, 0, 0, 2, 4, 0, 0, 0, 2, 4, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 7, 2, 0, 0, 0, 0, 2, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 1, 4, 1, 1, 22, 2, 1, 9, 1, 1, 14, 1, 55, 1, 1, 7, 1, 2, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 2, 1, 2, 2, 2, 1, 1, 2, 3, 1, 4, 1, 2, 2, 33, 2, 1, 1, 1, 6, 3, 1, 1, 5, 6, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 1, 0, 0, 0, 0, 0, 2, 1, 1, 1, 4, 1, 5, 3, 2, 2, 1, 1, 1, 2, 1, 2, 1, 33, 30, 5, 3, 1, 1, 2, 11, 6, 3, 1, 1, 1, 2, 0, 1, 2, 1, 1, 4, 1, 1, 3, 2, 1, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 1, 1, 0, 0, 2, 1, 1, 2, 1, 0, 0, 5, 1, 0, 1, 1, 1, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 1, 2, 3, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 3, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 2, 1, 1, 1, 2, 2, 3, 3, 2, 0, 4, 1, 2, 3, 1, 1, 1, 1, 1, 2, 2, 4, 2, 1, 1, 3, 1, 1, 1, 0, 2, 2, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 2, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 0, 3, 1, 1, 1, 1, 0, 3, 1, 1, 2, 1, 0, 0, 0, 1, 0, 1, 0, 2, 1, 1, 1, 1, 0, 0, 1, 0, 2, 0, 2, 1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1, 2, 0, 2, 2, 1, 1, 0, 1, 0, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 1, 1, 0, 1, 2, 0, 0, 1, 0, 0, 0, 0, 0, 1, 2, 2, 1, 0, 2, 0, 1, 0, 1, 1, 1, 1, 1, 3, 2, 1, 1, 0, 2, 1, 1, 2, 1, 1, 1, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 2, 1, 1, 1, 1, 1, 0, 0, 1, 2, 1, 1, 0, 1, 0, 1, 1, 3, 1, 1, 0, 1, 1, 0, 0, 1, 1, 2, 0, 0, 1, 1, 0, 2, 3, 2, 0, 0, 1, 1, 0, 2, 1, 0, 2, 1, 2, 1, 1, 2, 6, 0, 1, 3, 1, 2, 2, 2, 0, 1, 0, 0, 1, 1, 2, 3, 1, 2, 1, 2, 3, 2, 2, 1, 1, 3, 4, 1, 2, 1, 1, 6, 3, 3, 3, 3, 2, 0, 1, 2, 1, 1, 2, 2, 3, 3, 1, 0, 2, 1, 2, 1, 1, 0, 2, 3, 2, 0, 1, 0, 1, 1, 0, 0, 1, 0, 0, 3, 1, 0, 0, 2, 1, 0, 0, 0, 2, 0, 0, 1, 0, 1, 0, 0, 3, 3, 1, 2, 0, 1, 2, 2, 1, 1, 1, 0, 1, 1, 1, 1, 2, 1, 0, 2, 0, 0, 1, 0, 0, 0, 1, 0, 1, 1, 0, 1, 0, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 5, 1, 1, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 2, 8, 1, 0, 0, 0, 1, 1, 3, 1, 1, 0, 0, 0, 0, 1, 2, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 4, 2, 11, 2, 5, 9, 6, 5, 1, 8, 1, 2, 1, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 4, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 5, 6, 3, 2, 1, 2, 33, 33, 3, 2, 1, 1, 0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 3, 1, 7, 4, 4, 3, 2, 12, 1, 1, 1, 3, 2, 3, 2, 2, 15, 13, 8, 7, 13, 10, 2, 1, 22, 19, 7, 26, 4, 2, 1, 1, 1, 35, 29, 43, 6, 9, 1, 1, 2, 44, 91, 21, 6, 1, 7, 4, 1, 1, 1, 167, 10, 8, 1, 4, 1, 846, 222, 31, 15, 1, 4, 14, 4, 1, 5, 1, 3, 2, 1184, 153, 19, 3, 7, 2, 7, 9, 9, 39, 24, 6, 9, 7, 6, 2, 1, 1363, 188, 6, 19, 52, 29, 37, 63, 38, 94, 93, 49, 22, 13, 2, 2, 520, 22, 13, 11, 25, 246, 91, 107, 145, 288, 211, 120, 81, 30, 13, 4, 5, 2, 3, 5, 29, 26, 48, 42, 88, 110, 188, 163, 113, 18, 31, 8, 1, 3, 6, 23, 4, 7, 6, 33, 6, 3, 15, 14, 11, 25, 3, 0, 4, 53, 66, 82, 75, 27, 6, 14, 3, 1, 0, 0, 0, 49, 6, 68, 12, 12, 7, 87, 115, 72, 45, 2, 9, 2, 1, 1, 0, 256, 83, 55, 22, 13, 10, 2, 2, 0, 486, 265, 117, 39, 20, 3, 1, 6, 0, 0, 0, 0, 0, 0, 0, 669, 216, 69, 15, 7, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 625, 349, 108, 6, 13, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 642, 152, 18, 18, 10, 4, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 639, 58, 73, 26, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 234, 206, 106, 7, 21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 168, 45, 5, 9, 0, 0, 0, 0, 0, 0, 185, 46, 22, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 95, 46, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 146, 1, 8, 114, 148, 22, 7, 103, 158, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 1, 0, 2, 0, 1, 0, 1, 1, 2, 1, 0, 0, 0, 0, 2, 0, 1, 1, 3, 2, 3, 4, 3, 1, 1, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 7, 2, 8, 0, 1, 2, 1, 0, 1, 5, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 2, 1, 1, 1, 2, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 138, 36, 13, 6, 1, 1, 28, 11, 5, 4, 232, 76, 27, 3, 22, 46, 47, 13, 3, 1, 267, 49, 6, 43, 149, 20, 19, 3, 93, 11, 5, 12, 64, 206, 99, 24, 9, 2, 3, 6, 2, 13, 28, 55, 91, 35, 7, 1, 2, 19, 3, 13, 1, 0, 2, 9, 9, 29, 0, 99, 42, 5, 4, 3, 0, 0, 0, 0, 347, 49, 18, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 218, 49, 15, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 99, 7, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 6, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1, 2, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 1, 0, 2, 0, 2, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 3, 4, 2, 15, 2, 2, 1, 1, 1, 1, 8, 3, 6, 1, 8, 4, 2, 1, 1, 1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 6, 4, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1, 1, 3, 1, 1, 1, 2, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 3, 0, 0, 0, 1, 1, 2, 0, 0, 0, 1, 0, 16, 0, 1, 0, 1, 0, 1, 2, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 3, 1, 1, 310, 60, 11, 2, 1, 32, 31, 33, 5, 3, 6, 5, 1, 2, 2, 1, 277, 48, 8, 4, 84, 44, 37, 1, 4, 1, 1, 1, 1, 1, 1, 90, 18, 5, 159, 124, 58, 3, 10, 3, 1, 1, 2, 5, 90, 28, 43, 2, 1, 9, 1, 1, 8, 25, 7, 1, 20, 2, 1, 1, 168, 115, 6, 3, 0, 0, 0, 0, 253, 10, 8, 8, 7, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 79, 46, 63, 35, 7, 10, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 35, 13, 1, 3, 1, 1, 2, 0, 0, 0, 20, 17, 2, 0, 0, 0, 0, 0, 0, 0, 0, 37, 9, 6, 11, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 16, 6, 7, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 3, 0, 0, 0, 0, 0, 0, 3, 3, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 7, 1, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 4, 2, 6, 1, 1, 2, 12, 18, 3, 1, 3, 2, 3, 50, 20, 1, 1, 1, 4, 2, 1, 2, 9, 1, 136, 16, 30, 24, 12, 8, 6, 4, 1, 2, 1, 8, 15, 4, 69, 65, 70, 25, 17, 6, 25, 3, 8, 9, 8, 62, 34, 7, 3, 1, 12, 1, 3, 113, 81, 10, 1, 2, 2, 3, 3, 2, 6, 5, 7, 218, 42, 19, 25, 7, 14, 16, 14, 196, 58, 38, 17, 8, 11, 18, 29, 19, 33, 26, 36, 43, 22, 16, 8, 107, 14, 58, 65, 21, 4, 16, 3, 9, 71, 28, 5, 17, 4, 4, 2, 20, 25, 8, 30, 5, 8, 22, 24, 9, 0, 7, 1, 3, 6, 10, 10, 22, 8, 11, 2, 0, 46, 118, 61, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 83, 57, 28, 0, 0, 215, 45, 0, 0, 0, 0, 0, 0, 303, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 2, 8, 6, 10, 3, 6, 2, 1, 1, 1, 3, 2, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 3, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2, 1, 4, 7, 1, 9, 1, 1, 10, 5, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 3, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 6, 1, 2, 4, 1, 1, 0, 0, 0, 0, 0, 2, 2, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 1, 0, 4, 4, 2, 0, 0, 0, 0, 0, 2, 1, 3, 10, 17, 27, 4, 14, 7, 2, 1, 2, 4, 1, 2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 2, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 4, 1, 1, 1, 1, 2, 7, 3, 3, 7, 1, 1, 2, 1, 10, 20, 3, 7, 27, 2, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 2, 0, 1, 2, 5, 0, 0, 0, 0, 5, 1, 1, 2, 2, 2, 153, 79, 3, 7, 4, 9, 8, 3, 3, 1, 0, 42, 1, 7, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 5, 6, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 7, 3, 7, 8, 1, 3, 1, 1, 3, 4, 1, 2, 1, 1, 136, 25, 8, 33, 1, 3, 1, 1, 2, 1, 2, 4, 3, 1, 3, 1, 145, 73, 178, 10, 11, 7, 18, 9, 2, 5, 13, 4, 2, 2, 1, 1, 2, 2, 2, 26, 28, 13, 2, 4, 2, 3, 1, 84, 131, 6, 1, 3, 5, 2, 4, 10, 4, 3, 2, 3, 3, 26, 10, 1, 2, 175, 4, 6, 4, 8, 1, 6, 15, 3, 2, 3, 4, 3, 5, 3, 9, 1, 488, 243, 94, 39, 21, 42, 67, 50, 17, 16, 6, 10, 6, 2, 4, 21, 7, 34, 12, 7, 4, 2, 1, 31, 478, 90, 10, 17, 7, 4, 6, 4, 758, 101, 10, 28, 37, 16, 14, 4, 4, 3, 2, 1029, 63, 50, 11, 15, 9, 10, 3, 5, 3, 3, 2, 4, 2, 4, 6, 1179, 54, 50, 80, 14, 12, 4, 11, 11, 16, 12, 5, 5, 2, 9, 3, 1202, 213, 42, 24, 2, 5, 4, 9, 6, 3, 2, 4, 6, 8, 8, 1153, 326, 22, 5, 2, 8, 4, 9, 3, 13, 8, 27, 3, 1514, 70, 15, 17, 9, 6, 7, 34, 9, 13, 3, 3, 32, 4, 19, 6, 1727, 93, 9, 8, 19, 8, 5, 10, 12, 34, 21, 62, 99, 87, 5, 33, 25, 2, 21, 19, 28, 44, 3, 521, 58, 11, 56, 37, 7, 11, 27, 15, 259, 297, 458, 9, 8, 26, 39, 75, 82, 87, 8, 145, 9, 51, 8, 12, 26, 10, 10, 33, 103, 171, 91, 10, 3, 5, 21, 26, 43, 16, 7, 5, 3, 16, 26, 106, 13, 3, 5, 43, 57, 10, 9, 7, 8, 6, 48, 6, 4, 11, 21, 11, 16, 44, 16, 57, 11, 5, 49, 33, 13, 6, 1, 9, 1, 6, 54, 5, 0, 7, 0, 15, 14, 10, 1, 4, 2, 3, 11, 9, 4, 9, 6, 8, 10, 16, 49, 2, 2, 29, 13, 9, 1, 0, 55, 64, 14, 22, 0, 46, 50, 27, 3, 34, 7, 0, 0, 215, 270, 34, 25, 27, 3, 55, 23, 27, 4, 0, 346, 105, 190, 25, 55, 3, 52, 99, 154, 40, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 340, 334, 106, 108, 41, 40, 43, 32, 198, 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 219, 14, 60, 12, 31, 66, 62, 2, 0, 0, 0, 0, 0, 0, 162, 35, 2, 37, 151, 158, 219, 38, 1, 0, 0, 0, 0, 0, 0, 58, 105, 25, 64, 49, 41, 30, 1, 0, 0, 0, 0, 0, 0, 5, 24, 194, 96, 19, 1, 0, 0, 0, 131, 7, 12, 5, 2, 0, 0, 0, 0, 0, 0, 0, 0, 39, 20, 58, 1, 378, 303, 30, 966, 150, 0, 0, 0, 0, 1761, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 161, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 1, 3, 3, 2, 5, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 2, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 2, 2, 2, 4, 2, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 1, 1, 1, 0, 0, 0, 5, 0, 0, 0, 1, 1, 0, 0, 1, 2, 1, 1, 1, 0, 0, 0, 0, 0, 2, 4, 2, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 2, 28, 4, 3, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 9, 2, 1, 9, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 6, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 5, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 3, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 5, 3, 2, 1, 1, 1, 1, 5, 2, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 4, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 8, 1, 1, 1, 1, 2, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 7, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 2, 4, 2, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 2, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 0, 1, 0, 1, 0, 4, 8, 1, 5, 4, 1, 1, 2, 2, 1, 1, 0, 0, 0, 1, 1, 1, 2, 1, 1, 1, 7, 3, 1, 2, 5, 11, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 1, 1, 3, 1, 6, 6, 1, 24, 3, 2, 3, 2, 1, 3, 7, 6, 26, 1, 5, 2, 16, 32, 2, 8, 1, 5, 3, 4, 1, 46, 5, 11, 4, 2, 172, 4, 14, 18, 35, 51, 56, 156, 106, 2, 12, 11, 38, 19, 44, 85, 105, 5, 1, 3, 12, 3, 0, 3, 12, 4, 7, 3, 0, 0, 7, 5, 40, 7, 0, 0, 0, 0, 0, 18, 20, 20, 0, 0, 0, 0, 0, 0, 0, 0, 46, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 168, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 4, 10, 1, 8, 0, 4, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 6, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 2, 3, 1, 1, 7, 1, 7, 4, 2, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 3, 4, 5, 1, 1, 2, 5, 2, 2, 3, 5, 1, 4, 2, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 7, 0, 0, 0, 0, 1, 0, 1, 0, 1, 3, 1, 3, 1, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 2, 2, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 2, 2, 1, 1, 2, 1, 6, 25, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 1, 1, 12, 4, 1, 1, 2, 1, 2, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 2, 2, 11, 1, 3, 14, 3, 1, 3, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 2, 3, 2, 1, 1, 1, 3, 3, 1, 1, 2, 1, 2, 1, 1, 4, 1, 2, 3, 3, 2, 2, 1, 1, 1, 4, 3, 2, 7, 2, 7, 1, 1, 2, 4, 9, 1, 11, 7, 2, 1, 2, 4, 1, 1, 2, 2, 3, 1, 1, 1, 2, 3, 2, 2, 1, 2, 1, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 3, 2, 0, 0, 0, 0, 0, 0, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 5, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 3, 0, 0, 0, 2, 0, 1, 0, 1, 2, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 2, 1, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 4, 6, 0, 1, 1, 1, 1, 2, 21, 3, 1, 1, 2, 2, 3, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 5, 1, 4, 1, 4, 2, 1, 1, 9, 46, 52, 6, 1, 4, 5, 15, 149, 11, 2, 1, 1, 7, 1, 6, 11, 5, 1, 5, 259, 84, 27, 4, 9, 3, 3, 24, 32, 133, 28, 76, 36, 31, 6, 3, 1, 1, 55, 45, 7, 5, 6, 17, 8, 54, 3, 37, 166, 76, 20, 1, 9, 9, 23, 45, 23, 53, 10, 21, 1, 15, 34, 5, 13, 17, 11, 6, 16, 2, 14, 1, 10, 2, 4, 2, 5, 2, 1, 10, 24, 3, 22, 6, 4, 0, 19, 2, 6, 9, 0, 0, 0, 19, 65, 104, 22, 25, 5, 1, 0, 0, 0, 0, 0, 5, 2, 2, 12, 96, 18, 16, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 258, 74, 5, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 198, 14, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 18, 6, 3, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 1, 4, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 4, 4, 1, 0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 1, 0, 0, 1, 0, 1, 2, 1, 2, 6, 2, 1, 2, 1, 2, 2, 2, 1, 1, 2, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 4, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 3, 1, 0, 0, 0, 0, 0, 2, 1, 4, 0, 2, 1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 1, 2, 2, 3, 2, 1, 2, 5, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 2, 1, 2, 1, 1, 1, 5, 3, 6, 20, 10, 15, 1, 36, 25, 1, 12, 1, 1, 1, 1, 0, 0, 0, 2, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 0, 3, 2, 10, 116, 2, 1, 1, 12, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 2, 1, 0, 0, 1, 1, 0, 0, 3, 0, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 1, 2, 0, 1, 0, 1, 0, 1, 0, 1, 1, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 1, 0, 3, 1, 1, 1, 1, 1, 3, 5, 2, 1, 2, 2, 8, 11, 2, 1, 2, 1, 5, 43, 1, 2, 2, 1, 3, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 2, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 7, 1, 7, 11, 5, 12, 2, 3, 1, 1, 34, 17, 2, 2, 9, 1, 3, 7, 20, 62, 2, 2, 1, 3, 3, 1, 1, 0, 3, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0, 1, 4, 1, 0, 0, 0, 1, 0, 1, 1, 0, 0, 2, 1, 0, 0, 0, 1, 0, 1, 2, 0, 2, 1, 0, 2, 0, 1, 0, 1, 0, 1, 0, 1, 2, 0, 2, 0, 1, 0, 1, 1, 0, 1, 2, 1, 0, 0, 0, 0, 2, 1, 0, 0, 0, 1, 2, 0, 1, 0, 1, 46, 1, 59076, 2491, 1291, 1892, 1396, 917, 332, 915, 3747, 2, 50, 494, 403, 222, 138, 1, 116, 534, 1194, 169, 1, 2, 584, 1064, 1164, 7228, 2501, 11205, 931, 3244, 2078, 1954, 1489, 7299, 9291, 394, 1135, 170, 185, 449, 2893, 1038, 837, 2225, 734, 1344, 12661, 1004, 8810, 58, 266, 1776, 569, 395, 1596, 993, 155, 1419, 662, 2721, 531, 940, 357, 726, 1367, 267, 3337, 456, 707, 2346, 1865, 918, 333, 268, 221, 1030, 463, 384, 1278, 324, 525, 1264, 270, 1523, 7134, 2450, 7282, 665, 395, 0, 1137, 1, 12, 8, 494, 1, 402, 169, 568, 223, 3, 462, 393, 139, 385, 1501, 2, 2, 116, 2, 535, 394, 186, 917, 771, 1566, 162, 507, 1319, 540, 536, 1, 1037, 1, 1, 983, 1265, 836, 376, 440, 1683, 170, 1565, 919, 2, 1, 3, 1944, 465, 2336, 1392, 131, 1543, 257, 999, 402, 15811, 30765, 181, 25666, 643, 99122, 1, 89977, 85083, 15041, 2037, 11, 7356, 7, 771, 1188, 357, 4, 103, 23, 7, 8, 9, 463, 4, 5, 8, 9, 617, 130, 4, 1, 67283, 16705, 741, 2639, 1881, 382, 379, 123, 108737, 8991, 5020, 18366, 8013, 2594, 755, 267, 27, 14, 11, 5, 1, 4, 8, 8, 10, 8, 20197, 26994, 77151, 1151, 6583, 4779, 1187, 42, 2475, 151, 9, 35, 10, 3, 28, 6, 36, 2, 16, 8254, 19128, 13, 3449, 1162, 34957, 756, 1823, 958, 414, 12, 1375, 14, 13, 6275, 70417, 37040, 21361, 2379, 7324, 6297, 692, 3039, 1903, 1135, 334, 612, 35, 29, 613, 13, 11, 12, 507, 16, 8, 56, 5110, 1943, 1151, 48347, 31960, 255, 1589, 993, 7, 1712, 629, 1281, 1316, 20, 2303, 1704, 515, 14, 13, 740, 52, 33, 14, 23, 5, 1297, 62429, 2354, 15814, 3153, 1076, 1934, 1329, 2580, 826, 4143, 449, 877, 15, 10, 11, 268, 1285, 847, 11, 3, 219, 10, 861, 14621, 35127, 31983, 4356, 2631, 5840, 4087, 3997, 3772, 1100, 1085, 1486, 470, 1061, 759, 701, 2624, 404, 10, 655, 76, 1778, 46, 194, 512, 12, 31, 1938, 88, 5726, 4681, 1361, 2088, 22, 2392, 492, 1334, 550, 964, 26, 24808, 1851, 12452, 7826, 2575, 2827, 4161, 94, 996, 1562, 247, 443, 385, 5, 325, 259, 1180, 48, 650, 23, 538, 433, 1423, 915, 8878, 9645, 7970, 17460, 4074, 5511, 3334, 2135, 2212, 622, 15, 2047, 664, 778, 1921, 1188, 126, 651, 3437, 622, 899, 5, 1389, 32, 49, 19, 364, 6704, 6005, 655, 541, 6, 1312, 586, 386, 693, 6981, 8124, 8272, 3487, 1137, 1212, 298, 571, 933, 545, 1189, 321, 647, 1394, 7940, 2049, 6556, 25, 2735, 6587, 9, 3597, 23, 916, 776, 16, 14, 2639, 19, 804, 652, 2009, 476, 630, 1362, 712, 638, 14553, 9913, 98, 259, 3251, 4172, 355, 1028, 2146, 1037, 2013, 3600, 617, 3207, 954, 729, 503, 360, 45, 6457, 2924, 6715, 4422, 469, 6, 2299, 1198, 2718, 1523, 28, 2522, 974, 1612, 380, 2863, 720, 45, 1031, 23, 7, 3559, 3606, 4628, 3744, 3176, 3736, 1486, 453, 3203, 32, 961, 247, 1106, 439, 4259, 4322, 3051, 628, 524, 2556, 20, 21, 1533, 384, 18, 8, 2146, 116, 2125, 660, 7, 1024, 3558, 26, 81, 883, 15, 11, 510, 498, 746, 1023, 1377, 29, 260, 1800, 14, 5940, 1480, 1069, 450, 1073, 1674, 1063, 267, 1960, 2985, 1326, 422, 2673, 5250, 1407, 1471, 543, 1159, 2846, 3150, 2044, 335, 1296, 2711, 10, 990, 876, 758, 471, 1131, 860, 470, 10, 268, 1961, 3945, 255, 716, 14, 3162, 623, 4690, 442, 760, 2300, 3735, 3271, 11, 1941, 100, 3, 1378, 1487, 551, 24, 454, 1031, 702, 1482, 1379, 2217, 2384, 1652, 4224, 13, 1154, 386, 796, 3736, 875, 1576, 2046, 8, 759, 31, 1030, 2715, 7, 611, 421, 1617, 9, 1830, 276, 1802, 758, 2882, 843, 2, 762, 11, 30, 838, 11951, 5614, 297, 792, 2328, 1084, 1090, 6, 13, 1960, 13, 2680, 795, 829, 742, 1187, 462, 1664, 1470, 26, 10, 1974, 3192, 2853, 545, 1471, 547, 26, 8610, 5060, 1514, 5935, 1359, 2818, 3735, 2300, 16, 491, 5, 15, 14062, 4359, 12052, 5284, 6439, 753, 3003, 477, 6329, 2228, 1179, 3519, 27706, 7240, 8746, 4206, 13, 1291, 1324, 1170, 2597, 9136, 948, 666, 25, 774, 621, 29275, 13717, 6, 15343, 8633, 13, 6866, 3465, 21321, 1956, 15098, 661, 7953, 1353, 11002, 317, 6575, 42381, 3137, 6286, 134, 4772, 651, 9589, 1394, 13, 3156, 5, 14311, 55249, 1299, 24949, 6282, 0, 8600, 2453, 8577, 3695, 21518, 64715, 17507, 0, 25216, 4513, 155585, 0, 97727, 953, 430, 944, 26, 145, 4, 209, 4, 18, 1, 2, 1, 6, 2, 5, 9, 3, 188, 2, 351, 165, 7, 1, 19, 1, 2, 1, 1, 19, 51, 55, 45, 1, 0, 0, 0, 0, 0, 0, 15551, 38572, 9059, 2503, 6589, 582, 1162, 692, 1387, 867, 156, 2242, 507, 3821, 358, 496, 1, 2247, 854, 328, 4, 813, 297, 274, 240, 292, 738, 604, 281, 122, 219, 247, 326, 229, 86, 192, 127, 8, 170, 160, 375, 283, 245, 1224, 414, 59, 277, 182, 0, 0, 8738, 984, 527, 1405, 652, 957, 357, 1355, 216, 561, 284, 163, 267, 9872, 1285, 11001, 253, 386, 2168, 2911, 1233, 334, 920, 243, 842, 1328, 230, 1573, 398, 22, 849, 189, 1130, 118, 393, 351, 170, 461, 1085, 441, 224, 532, 536, 459, 0, 8, 641, 302, 631, 880, 1646, 1007, 346, 72, 0, 0, 1064, 7133, 439, 393, 1650, 550, 3, 381, 1147, 295, 410, 673, 5, 1401, 3, 422, 663, 481, 116, 774, 681, 167, 348, 602, 12, 0, 1453, 454, 118, 229, 912, 708, 289, 0, 27, 435, 237, 1, 352, 274, 2263, 719, 2464, 884, 2170, 3114, 724, 1160, 890, 418, 1708, 1084, 610, 1227, 1014, 717, 193, 684, 373, 1276, 838, 150, 1176, 233, 377, 155, 0, 891, 891, 526, 3, 36, 273, 117, 250, 498, 662, 1, 392, 691, 1406, 627, 532, 2610, 1076, 427, 988, 171, 119, 327, 570, 437, 215, 5, 212, 994, 227, 1235, 371, 398, 0, 272, 531, 211, 3, 154, 0, 3970, 1269, 675, 1406, 280, 373, 905, 548, 281, 1104, 494, 6, 0, 1693, 947, 1850, 356, 492, 406, 232, 226, 350, 289, 3091, 210, 1190, 1078, 3451, 426, 1131, 323, 685, 687, 1, 1257, 13, 898, 126, 448, 2930, 650, 2828, 529, 495, 499, 2359, 368, 2, 326, 582, 593, 486, 4, 446, 0, 332, 645, 3, 0, 855, 494, 209, 294, 170, 509, 0, 946, 674, 411, 370, 0, 525, 242, 2510, 524, 721, 388, 945, 537, 321, 118, 0, 0, 271, 280, 670, 3101, 1003, 504, 911, 374, 466, 2854, 346, 1095, 507, 643, 0, 647, 229, 1, 1960, 4218, 1056, 854, 2, 355, 910, 886, 684, 407, 961, 166, 410, 4, 498, 423, 590, 228, 492, 4, 4, 0, 228, 528, 425, 493, 278, 327, 523, 3, 493, 208, 1068, 116, 381, 498, 441, 1845, 688, 417, 113, 3, 4937, 1910, 483, 322, 1203, 841, 225, 720, 1055, 377, 833, 566, 1209, 2, 347, 239, 0, 527, 2, 1, 2464, 1252, 595, 1571, 403, 409, 1570, 117, 485, 365, 645, 362, 1563, 1029, 317, 371, 7, 6, 0, 503, 839, 661, 1925, 3671, 123, 2, 686, 273, 218, 387, 85, 3, 492, 482, 870, 1792, 426, 609, 547, 325, 289, 491, 188, 581, 1, 321, 268, 945, 288, 1309, 231, 290, 3, 354, 561, 481, 664, 660, 2186, 1011, 2630, 1, 996, 1129, 322, 373, 116, 0, 838, 1, 1221, 440, 266, 214, 2668, 236, 885, 467, 402, 803, 943, 0, 226, 909, 881, 162, 351, 113, 124, 0, 0, 1286, 410, 1121, 153, 1015, 1846, 424, 0, 721, 277, 664, 3, 0, 1068, 1836, 1803, 419, 904, 494, 560, 2453, 710, 339, 2921, 687, 708, 836, 449, 1076, 1231, 3008, 1033, 556, 238, 395, 201, 265, 350, 409, 243, 203, 0, 1398, 962, 436, 608, 522, 235, 485, 923, 376, 682, 310, 22, 482, 0, 583, 546, 492, 451, 884, 668, 220, 171, 466, 462, 152, 1, 903, 940, 145, 345, 683, 481, 1397, 484, 282, 416, 480, 401, 364, 409, 440, 417, 246, 408, 225, 531, 961, 230, 325, 2166, 1016, 491, 5, 465, 498, 115, 386, 644, 482, 441, 493, 363, 481, 450, 535, 394, 439, 460, 362, 561, 885, 12, 115, 941, 720, 872, 466, 2889, 2292, 2909, 447, 407, 1845, 1128, 3, 643, 191, 1015, 697, 434, 663, 288, 886, 344, 530, 0, 497, 680, 642, 372, 447, 496, 484, 922, 1396, 360, 480, 126, 338, 321, 34, 1016, 490, 479, 416, 1774, 407, 1767, 374, 1565, 1008, 962, 334, 920, 1446, 496, 14, 49, 448, 1843, 1015, 695, 834, 919, 1395, 686, 489, 350, 1267, 937, 493, 0, 1871, 641, 1401, 225, 162, 359, 640, 151, 1274, 667, 170, 1352, 718, 415, 483, 188, 2076, 2738, 322, 835, 682, 3292, 880, 26, 0, 2337, 406, 640, 219, 695, 159, 393, 125, 1083, 1885, 187, 674, 838, 726, 149, 0, 3382, 2743, 489, 1972, 981, 4494, 7796, 3765, 836, 119, 427, 7039, 2564, 3688, 724, 475, 23373, 4966, 1330, 2781, 515, 40334, 3462, 10215, 3346, 32569, 26687, 4497, 38162, 1663, 84442, 0, 912, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 56, 13076, 2017, 1817, 1785, 8331, 246, 646, 107, 4, 263, 200, 2754, 725, 776, 371, 1694, 442, 884, 831, 6469, 19024, 45067, 339, 1182, 26, 1297, 48, 1259, 1, 9, 9, 4, 2, 1, 1, 1, 1, 1590, 228, 2302, 1984, 6824, 181, 13, 12, 394, 631, 437, 565, 327, 1496, 394, 619, 259, 519, 5, 320, 560, 128, 5208, 4089, 37, 395, 247, 649, 109, 0, 1, 0, 264, 201, 512, 246, 1127, 1368, 58, 293, 430, 511, 775, 372, 463, 1964, 32, 2, 441, 883, 832, 561, 1, 127, 229, 2576, 7450, 21, 33001, 187, 321, 15, 15678, 3496, 89015, 281, 6, 172, 15741, 300, 234, 77, 3679, 4132, 109593, 2, 4141, 27, 5939, 122900, 1613, 3649, 4757, 1891, 125, 213, 671, 9, 273, 131, 9, 13, 5, 11, 7, 2, 5, 8, 4, 5074, 486, 788, 42963, 33721, 44581, 5463, 921, 516, 599, 12, 16, 129, 20006, 22036, 2782, 173, 168, 56735, 4268, 5, 225, 239, 6, 18, 8, 18, 6, 2, 118652, 3760, 5316, 1225, 17, 19, 91732, 33620, 8504, 62, 111, 18, 71, 19, 4, 25, 83995, 13066, 8, 124499, 239, 12, 82, 14, 7, 85299, 67563, 15, 130, 543, 274, 30, 12, 6, 2, 3, 2, 85110, 125, 84, 61, 184, 7, 19, 45, 10, 18, 84995, 30074, 37297, 4139, 208, 554, 13, 23, 28, 23, 136, 8, 18, 24, 48, 24, 29, 5, 14, 41487, 40340, 2672, 869, 11, 68464, 2721, 552, 20, 16, 147832, 14, 2922, 6725, 12409, 132098, 5850, 3724, 149, 1174, 795, 5977, 547, 371, 30, 151, 20, 4, 72, 12, 1418, 1507, 209, 8078, 75, 13563, 39, 299, 40, 91505, 33744, 2020, 6009, 5995, 16744, 86, 890, 108, 92, 64, 51, 64, 50, 6, 3, 58, 30, 68319, 8675, 7796, 11926, 368, 471, 54, 15303, 57203, 32592, 1108, 14, 11822, 5578, 105, 81727, 3140, 168, 78, 2, 10, 8, 17156, 113890, 1593, 2738, 127, 204, 36, 14, 25, 24, 75, 16544, 408, 234, 123860, 44608, 75, 1541, 346, 15, 132, 184, 98, 32, 114, 55, 83, 74, 37, 124479, 1520, 264, 174, 240, 233, 327, 84, 24, 14, 23517, 119205, 30375, 501, 305, 270, 950, 373, 142, 169, 185, 46, 84, 61, 21719, 1217, 95, 55, 22, 520, 141244, 54, 1746, 394, 533, 571, 43, 163, 9, 17, 22, 3440, 134795, 16003, 18017, 1301, 79, 975, 551, 167, 85, 114, 19, 2944, 188, 386, 85975, 52375, 1514, 581, 291, 224, 27, 100155, 1989, 748, 34, 688, 143529, 1547, 24426, 1002, 2546, 17, 11987, 127126, 3513, 7622, 216, 37, 63, 3, 12753, 935, 100421, 67223, 7, 687, 1, 68, 4, 13, 2, 26, 66, 104681, 2, 522, 475, 342, 513, 3, 58, 23, 67, 81, 1, 51724, 139167, 85, 687, 285, 391, 37, 38, 90, 188, 15, 85, 15, 51623, 154, 37, 187, 30, 7, 39, 79235, 51830, 57087, 1865, 18, 832, 1974, 1052, 218, 23, 42619, 33856, 2025, 1126, 261, 322, 1, 130, 521, 3, 91048, 692, 1005, 2276, 932, 2, 14, 522, 187, 6, 98675, 28421, 30783, 20339, 660, 4677, 13, 4, 378, 52, 38095, 37554, 26387, 258, 1372, 457, 47, 25, 14, 69, 51, 19, 45056, 22459, 135, 1069, 34, 20, 44, 53, 66, 1, 23, 109601, 205, 6390, 74, 119, 61, 112, 19, 12, 311, 239, 102, 10, 4, 23912, 157497, 37, 947, 20, 150, 475, 14, 117, 24768, 52, 263, 137, 5, 33429, 66877, 83877, 9910, 382, 1294, 92, 2019, 769, 486, 36, 264, 55, 33, 67, 269, 153, 123, 145, 35, 50, 55, 15604, 16697, 773, 158, 171, 113, 331, 68, 67, 4, 78434, 3087, 473, 418, 290, 32, 14, 27, 4, 150870, 3011, 11221, 705, 651, 7810, 4329, 898, 1008, 481, 66, 523, 5, 8, 28, 27724, 64789, 7395, 2703, 417, 53294, 5688, 2380, 450, 368, 301, 53, 66, 4, 17691, 549, 383, 9424, 2593, 505, 48, 25, 9621, 4978, 2222, 67268, 6297, 4524, 254, 419, 193, 113, 48, 11, 1064, 480, 15585, 570, 485, 115, 1149, 7396, 211, 522, 15, 4319, 824, 93, 170, 59, 2641, 126506, 36442, 684, 1168, 309, 730, 22, 2639, 144025, 1746, 3872, 915, 45, 443, 27, 39, 67135, 101753, 1410, 13356, 711, 1820, 5183, 33, 28, 75, 52, 64446, 514, 3601, 523, 1025, 1610, 42978, 97871, 3609, 11494, 17252, 45, 69, 20, 38433, 677, 2237, 3673, 27293, 75504, 53405, 95, 97, 13, 27, 74, 26528, 6306, 70, 41, 119124, 57, 476, 213, 8, 31973, 15434, 48867, 15608, 34869, 6507, 57317, 601, 219, 972, 249, 64, 43, 254, 3414, 10105, 6655, 4471, 2858, 4354, 158, 58, 6087, 152, 3757, 1060, 7967, 10106, 26816, 7206, 22376, 12451, 615, 2957, 14060, 42, 41, 100, 356, 170, 9, 666, 97, 20, 0, 2154, 15963, 63012, 196, 69, 520, 262, 275, 33, 2769, 36216, 77, 191, 119, 48243, 104144, 43989, 13959, 387, 214, 218, 13, 36413, 10717, 1170, 0, 112098, 28545, 285, 71, 250, 292, 43, 165664, 2074, 74, 207086, 3341, 441, 29, 2087, 182296, 5262, 1268, 3271, 4665, 15974, 33704, 12212, 28180, 43336, 69925, 6211, 7013, 13049, 12712, 4529, 5248, 10658, 17023, 26021, 83178, 1, 85869, 1194, 353, 674, 772, 353, 545, 632, 450, 266, 10, 257, 162, 202, 942, 1, 801, 747, 551, 92, 2339, 6682, 1784, 1995, 3555, 93, 817, 0, 0, 0, 0, 0, 4787, 2235, 1696, 8724, 1270, 319, 1310, 324, 251, 307, 839, 258, 625, 381, 2269, 181, 290, 726, 294, 3263, 220, 635, 230, 176, 2906, 330, 2078, 876, 2053, 5762, 24971, 4463, 6853, 3224, 125, 5, 395, 961, 230, 331, 266, 739, 480, 122, 1587, 859, 774, 246, 327, 1453, 180, 189, 248, 265, 1530, 144, 929, 693, 589, 775, 371, 419, 243, 1876, 560, 679, 3176, 224, 329, 348, 1, 441, 831, 320, 873, 439, 874, 354, 325, 252, 308, 588, 252, 440, 257, 890, 282, 631, 380, 231, 355, 342, 985, 1671, 397, 451, 267, 180, 230, 245, 289, 247, 229, 15, 692, 256, 587, 545, 326, 192, 2, 4, 326, 108, 20, 684, 201, 439, 404, 1223, 2237, 885, 391, 90, 219, 514, 992, 0, 229, 341, 737, 370, 479, 242, 251, 586, 418, 465, 685, 1680, 1026, 344, 202, 571, 227, 992, 5309, 368, 19, 12, 605, 584, 2662, 304, 121, 592, 2888, 480, 9669, 1514, 2435, 479, 21843, 35493, 15662, 99, 26801, 6366, 77069, 46, 27724, 76923, 27825, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 2, 0, 1, 1, 0, 0, 22, 8191, 663, 638, 708, 121, 192, 198, 31, 206, 274, 125, 127, 73, 162, 151, 47, 2, 2673, 23019, 6598, 142, 390, 427, 274, 242, 247, 1820, 4122, 575, 74, 473, 122, 610, 34, 162, 343, 207, 143, 123, 193, 199, 391, 32, 105, 104, 276, 554, 80, 46, 75, 72, 273, 161, 241, 152, 48, 248, 4, 3941, 737, 36108, 2, 12496, 5949, 5448, 4181, 220, 3631, 597, 1005, 329, 730, 43, 257, 710, 4913, 876, 1335, 330, 2761, 5355, 18368, 27, 2240, 120, 1815, 1726, 2228, 1322, 495, 855, 236, 197, 22, 282, 476, 20, 173, 27, 245, 217, 79, 47, 438, 81, 161, 639, 4811, 2, 1997, 388, 613, 294, 318, 239, 157, 529, 359, 619, 4504, 517, 642, 377, 160, 183, 250, 400, 1282, 710, 482, 419, 1506, 793, 2181, 306, 1, 285, 1104, 210, 1279, 546, 301, 327, 365, 229, 1129, 1145, 281, 2, 5, 1, 15, 204, 901, 2, 303, 721, 1105, 166, 1156, 711, 407, 252, 185, 242, 369, 107, 215, 218, 1499, 1468, 1610, 2, 295, 309, 4, 164, 353, 319, 487, 547, 110, 555, 672, 492, 192, 330, 442, 288, 464, 105, 3, 127, 28, 302, 240, 62, 2387, 94, 443, 675, 5280, 524, 347, 129, 1539, 230, 627, 1, 873, 366, 595, 41, 1008, 4385, 893, 229, 0, 243, 1, 1104, 5754, 3117, 32, 698, 64, 267, 19, 2, 354, 321, 317, 3622, 12723, 972, 900, 3300, 7118, 4076, 3950, 189, 967, 2551, 588, 556, 909, 72, 142, 1403, 639, 333, 6, 952, 372, 626, 1131, 885, 152, 39, 235, 453, 1908, 0, 1219, 1105, 8, 1286, 0, 26, 31, 2090, 1669, 4354, 1709, 989, 528, 283, 1623, 321, 1194, 1870, 2091, 700, 2, 860, 1633, 304, 429, 227, 1412, 443, 33, 847, 1, 895, 369, 102, 781, 121, 2236, 2285, 269, 3, 618, 1007, 449, 60, 685, 0, 0, 3239, 6717, 834, 855, 1610, 413, 380, 1092, 2014, 100, 283, 604, 33, 51, 346, 254, 2, 1147, 0, 5519, 849, 241, 148, 3175, 331, 623, 899, 1550, 309, 2035, 1736, 3238, 1104, 1633, 1994, 2010, 4058, 489, 328, 167, 17, 295, 373, 1, 1, 818, 1519, 893, 1382, 359, 221, 798, 992, 669, 1859, 297, 1399, 79, 875, 1230, 247, 3, 372, 112, 268, 1, 307, 1204, 1342, 406, 246, 442, 53, 989, 6, 539, 111, 1238, 0, 2833, 2118, 3338, 772, 2, 190, 3, 383, 1026, 1010, 212, 256, 710, 251, 3548, 803, 18, 674, 3, 969, 9, 330, 218, 631, 2040, 4747, 457, 73, 1136, 306, 1, 170, 715, 818, 247, 2150, 886, 1933, 1432, 1396, 2164, 1883, 669, 979, 447, 1711, 487, 1513, 1476, 725, 561, 48, 677, 129, 223, 395, 1701, 4565, 1, 0, 230, 346, 3, 601, 103, 309, 1246, 423, 5, 73, 311, 863, 1376, 199, 355, 33, 556, 158, 663, 2, 381, 296, 489, 2214, 1, 238, 782, 1165, 1093, 333, 166, 6, 655, 578, 117, 500, 304, 948, 305, 356, 1, 488, 908, 859, 190, 56, 2477, 412, 321, 264, 256, 257, 108, 2, 665, 363, 143, 1391, 380, 1095, 1286, 449, 981, 168, 2076, 533, 51, 244, 348, 485, 1682, 894, 411, 197, 8, 270, 292, 1412, 320, 154, 302, 5, 248, 669, 2479, 248, 563, 2327, 371, 926, 218, 410, 729, 303, 590, 217, 155, 296, 532, 693, 329, 786, 1632, 390, 858, 562, 980, 218, 576, 2751, 371, 167, 1512, 857, 1217, 654, 1284, 107, 532, 1471, 10, 1002, 1381, 1511, 325, 562, 4, 388, 372, 1155, 245, 3063, 627, 218, 1828, 0, 106, 676, 1741, 3, 831, 1009, 389, 2461, 0, 0, 0, 0, 372, 1472, 1075, 373, 3171, 1063, 3747, 18736, 47936, 1, 3, 1, 1, 11, 94, 11, 24, 29, 618, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11018, 574, 208, 1208, 297, 424, 230, 751, 440, 630, 158, 88, 472, 434, 108, 52, 65, 64, 45, 122, 122, 70, 20, 157, 17, 598, 75, 42, 444, 186, 235, 41, 263, 153, 109, 608, 188, 115, 387, 184, 14, 2122, 1051, 2185, 2206, 5202, 9081, 0, 0, 0, 564, 90, 1183, 620, 64, 566, 286, 390, 490, 734, 171, 47, 2224, 352, 542, 482, 1218, 941, 3, 162, 409, 0, 208, 908, 113, 145, 335, 211, 65, 294, 1, 238, 183, 89, 0, 163, 67, 267, 203, 106, 420, 159, 186, 492, 255, 425, 64, 143, 354, 204, 266, 29, 745, 158, 149, 424, 319, 162, 157, 114, 295, 89, 65, 202, 63, 241, 113, 115, 330, 102, 125, 107, 441, 54, 146, 354, 2, 65, 391, 46, 121, 147, 126, 123, 489, 735, 71, 19, 156, 18, 736, 246, 131, 224, 74, 105, 142, 353, 120, 112, 41, 488, 445, 355, 64, 234, 40, 125, 124, 137, 161, 419, 109, 185, 735, 70, 124, 390, 152, 294, 311, 157, 146, 382, 442, 164, 46, 187, 359, 597, 179, 171, 34, 41, 141, 23, 2435, 906, 1671, 1295, 85, 180, 969, 1400, 1453, 3978, 1641, 4600, 2266, 23083, 19, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 0, 7, 1, 1, 3, 14, 2, 2, 0, 1, 6, 1, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 2, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 3, 1, 4, 25, 19, 1, 2, 1, 1, 3, 5, 15, 2, 1, 1, 1, 1, 1, 4, 2, 1, 1, 1, 2, 0, 1, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 16, 0, 17, 0, 0, 0, 1, 0, 1, 2, 1, 1, 1, 1, 12, 19, 3, 4, 3, 1, 3, 66, 21, 4, 13, 16, 21, 8, 134, 4, 2, 6, 7, 24, 81, 92, 36, 1, 1, 2, 6, 2, 3, 13, 9, 49, 72, 123, 38, 1, 1, 2, 3, 1, 3, 4, 2, 3, 2, 0, 0, 8, 3, 0, 2, 5, 6, 0, 0, 0, 0, 19, 21, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 62, 24, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 89, 4, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 2, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 4, 0, 8, 0, 0, 0, 0, 0, 1, 5, 7, 10, 1, 4, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 3, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 4, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 10, 1, 1, 11, 0, 0, 0, 2, 1, 0, 1, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 2, 1, 0, 0, 1, 1, 1, 0, 0, 0, 36, 0, 0, 1, 1, 126, 14, 5, 3, 1, 1, 2, 4, 1, 268, 30, 12, 1, 4, 9, 1, 1, 7, 269, 102, 32, 1, 4, 1, 4, 23, 58, 44, 171, 28, 1, 1, 15, 60, 150, 35, 47, 31, 6, 1, 2, 100, 34, 14, 14, 15, 130, 85, 29, 73, 18, 1, 3, 17, 22, 12, 5, 29, 93, 15, 20, 14, 1, 8, 26, 21, 5, 8, 6, 4, 5, 24, 27, 19, 2, 1, 3, 22, 19, 5, 3, 2, 5, 2, 6, 6, 68, 15, 1, 2, 0, 0, 388, 3, 5, 2, 0, 0, 69, 184, 19, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 17, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 90, 4, 7, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 6, 5, 2, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1, 2, 0, 1, 0, 1, 0, 2, 2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 1, 1, 0, 0, 1, 0, 1, 0, 9, 1, 4, 141, 3, 1, 1, 14, 2, 1, 3, 1, 2, 1, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 6, 4, 3, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 5, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 12, 1, 1, 5, 2, 1, 3, 4, 1, 2, 1, 6, 2, 1, 6, 1, 2, 1, 1, 1, 1, 2, 1, 5, 1, 2, 1, 4, 1, 1, 4, 3, 4, 8, 3, 14, 5, 6, 14, 6, 16, 8, 9, 2, 7, 6, 6, 4, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 3, 0, 2, 0, 1, 1, 1, 0, 0, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 2, 2, 3, 2, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 3, 1, 4, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 2, 3, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 1, 0, 0, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 3, 1, 4, 1, 2, 1, 2, 3, 1, 1, 1, 3, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 2, 2, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 3, 0, 3, 0, 4, 8, 4, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 9, 3, 1, 1, 6, 1, 1, 1, 2, 1, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 1, 2, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 15, 73, 2, 25, 1, 2, 0, 1, 1, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 3, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 27, 2, 48, 1666, 118, 340, 117, 88, 92, 41, 4, 52, 75, 87, 65, 74, 120, 128, 805, 11621, 3974, 209, 12, 1, 941, 751, 120, 59, 243, 43, 49, 71, 89, 93, 42, 3, 50, 48, 0, 0, 0, 0, 0, 0, 66, 3, 0, 0, 55, 12, 73, 122, 123, 8, 911, 23, 15217, 6, 2, 1, 6, 2, 10, 23159, 1510, 335, 488, 202, 176, 438, 246, 67, 2, 183, 54, 654, 1, 13, 101, 98, 87, 11, 315, 100, 12, 193, 1696, 121, 372, 1656, 214, 54, 351, 188, 162, 22, 131, 185, 66, 1829, 9288, 721, 358, 647, 668, 223, 890, 268, 463, 151, 127, 194, 107, 2, 35, 494, 684, 397, 9, 384, 364, 3406, 221, 3, 54, 52, 95, 760, 1291, 254, 85, 161, 183, 310, 117, 339, 206, 1377, 209, 4191, 966, 335, 218, 914, 418, 534, 217, 80, 421, 51, 90, 262, 52, 55, 40, 240, 156, 798, 515, 97, 110, 105, 625, 18, 56, 8, 24, 148, 50, 249, 48, 86, 706, 213, 185, 454, 220, 255, 51, 147, 432, 118, 92, 59, 110, 110, 34, 743, 143, 504, 68, 30, 103, 363, 175, 48, 755, 89, 128, 156, 344, 73, 104, 99, 73, 108, 88, 265, 128, 54, 74, 130, 756, 85, 277, 187, 399, 136, 180, 16, 154, 43, 70, 144, 66, 1, 134, 248, 128, 98, 85, 50, 24, 20, 112, 2, 244, 356, 131, 155, 56, 786, 118, 42, 260, 68, 3, 119, 44, 38, 794, 85, 113, 297, 62, 74, 188, 269, 221, 257, 52, 3, 68, 464, 152, 535, 245, 757, 128, 75, 120, 144, 148, 758, 3, 195, 184, 81, 55, 108, 96, 83, 129, 45, 524, 96, 259, 71, 24, 52, 1, 0, 12, 34, 2, 283, 89, 298, 100, 98, 357, 349, 196, 399, 151, 109, 106, 99, 60, 48, 8, 911, 93, 67, 22, 51, 1, 8, 55, 543, 1, 255, 184, 221, 54, 96, 270, 77, 0, 0, 0, 143, 195, 11, 316, 268, 95, 185, 8, 225, 305, 1, 252, 4, 150, 0, 0, 10, 367, 356, 83, 178, 600, 60, 2, 50, 64, 42, 1534, 83, 583, 320, 461, 109, 271, 203, 78, 929, 4761, 849, 174, 198, 341, 74, 0, 42, 120, 39, 59, 317, 356, 0, 0, 43, 240, 1, 110, 161, 119, 994, 1546, 597, 0, 51, 117, 74, 88, 107, 224, 74, 304, 46, 2, 40, 42, 56, 0, 82, 92, 235, 358, 194, 176, 288, 335, 48, 75, 154, 525, 0, 138, 120, 32, 75, 0, 98, 426, 2, 160, 221, 90, 120, 455, 93, 2, 84, 78, 2508, 629, 285, 191, 412, 183, 161, 114, 59, 99, 21, 130, 198, 190, 5595, 669, 1137, 3935, 99, 260, 80, 620, 410, 287, 1, 38, 187, 53, 760, 310, 92, 137, 598, 82, 1, 204, 204, 32, 196, 343, 1137, 667, 270, 10, 195, 203, 665, 458, 1484, 3, 143, 937, 1, 79, 485, 412, 51, 514, 537, 387, 400, 132, 59, 98, 503, 202, 767, 613, 134, 86, 4, 61, 59, 10, 53, 1219, 143, 59, 124, 199, 109, 12, 3, 186, 7, 108, 173, 126, 771, 156, 186, 272, 50, 98, 1, 94, 208, 158, 303, 116, 211, 107, 486, 489, 732, 875, 758, 133, 9, 313, 188, 607, 430, 61, 186, 9, 89, 76, 163, 149, 84, 133, 94, 175, 134, 31, 95, 73, 209, 444, 1489, 1395, 1, 153, 140, 182, 55, 98, 48, 92, 189, 214, 152, 274, 155, 142, 33, 249, 194, 181, 70, 3, 3, 91, 175, 150, 326, 139, 126, 661, 547, 1, 185, 81, 116, 131, 312, 130, 326, 210, 222, 80, 416, 85, 157, 223, 550, 123, 405, 226, 151, 280, 73, 329, 79, 68, 273, 54, 83, 142, 270, 48, 79, 4, 156, 417, 85, 295, 97, 198, 5, 141, 133, 646, 1, 96, 328, 189, 3, 132, 160, 221, 179, 98, 107, 80, 108, 115, 10, 142, 269, 37, 78, 69, 197, 513, 75, 644, 226, 77, 52, 101, 536, 4, 758, 83, 119, 0, 6, 156, 301, 534, 186, 67, 109, 372, 717, 177, 7, 4, 3, 84, 139, 222, 47, 272, 173, 91, 389, 75, 295, 162, 174, 3, 59, 34, 58, 114, 1134, 358, 152, 67, 168, 83, 964, 182, 533, 401, 247, 58, 33, 90, 49, 139, 0, 512, 674, 317, 113, 511, 208, 157, 171, 1142, 666, 849, 108, 87, 103, 226, 397, 332, 264, 51, 42, 31, 107, 757, 2, 806, 756, 4419, 156, 103, 8069, 1319, 12, 0, 23015, 21, 12, 57, 24, 314, 0, 0, 0, 0, 0, 15289, 32, 8, 31, 34, 17, 0, 0, 21, 3, 69, 1, 2, 267, 782, 116, 765, 388, 2012, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 952, 54, 110, 289, 36, 149, 26, 449, 215, 187, 433, 202, 66, 815, 684, 921, 1715, 2875, 4392, 0, 0, 0, 48, 74, 36, 4, 115, 25, 101, 103, 338, 122, 6, 47, 32, 55, 109, 51, 129, 76, 38, 106, 2, 35, 16, 4, 1, 2, 81, 66, 35, 20, 25, 42, 121, 281, 2, 41, 68, 214, 11, 51, 134, 174, 88, 132, 33, 46, 153, 46, 0, 69, 232, 263, 160, 201, 625, 500, 678, 306, 498, 1036, 650, 452, 0, 2161, 3125, 0, 7050, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 1, 0, 3, 3, 0, 0, 0, 0, 0, 1, 0, 2, 1, 1, 7, 12, 3, 1, 3, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 1, 3, 2, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 5, 0, 1, 0, 2, 3, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 2, 0, 0, 2, 1, 4, 2, 0, 0, 1, 1, 0, 0, 1, 1, 1, 3, 1, 1, 2, 1, 2, 1, 1, 27, 17, 23, 13, 1, 2, 1, 2, 3, 3, 19, 8, 22, 9, 1, 22, 15, 9, 1, 4, 16, 18, 18, 2, 32, 12, 3, 1, 2, 5, 9, 26, 19, 3, 4, 15, 7, 2, 2, 2, 5, 9, 5, 2, 18, 52, 54, 3, 4, 1, 4, 3, 16, 21, 43, 5, 2, 6, 7, 14, 2, 3, 1, 1, 5, 3, 4, 1, 5, 7, 5, 2, 1, 9, 2, 6, 3, 10, 4, 0, 6, 1, 5, 2, 0, 38, 12, 2, 0, 0, 82, 6, 3, 0, 0, 0, 0, 0, 0, 0, 33, 8, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 3, 0, 0, 0, 0, 1, 1, 1, 1, 3, 2, 1, 1, 2, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 2, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 1, 2, 16, 319, 634, 932, 168, 211, 185, 67, 44, 95, 2, 9, 109, 2, 57, 74, 33, 109, 791, 357, 393, 10060, 6209, 1, 1, 1, 81, 127, 117, 153, 143, 152, 179, 21, 137, 134, 83, 273, 479, 300, 15, 166, 49, 187, 153, 69, 45, 96, 0, 1, 110, 0, 58, 77, 32, 62, 132, 193, 10, 775, 311, 20, 152, 9, 23, 13, 173, 327, 153, 316, 187, 13162, 63, 6, 2, 91, 12, 185, 6009, 1152, 327, 356, 456, 523, 410, 1267, 1095, 571, 217, 553, 73, 48, 8, 415, 622, 191, 619, 7, 257, 186, 179, 45, 1333, 1046, 578, 149, 621, 705, 76, 981, 777, 1478, 256, 997, 138, 449, 2400, 915, 1249, 600, 185, 725, 193, 288, 1, 75, 258, 719, 174, 156, 55, 106, 923, 6817, 277, 419, 80, 145, 200, 115, 174, 388, 112, 851, 208, 67, 471, 270, 184, 129, 85, 88, 281, 6, 422, 148, 88, 194, 665, 141, 281, 109, 278, 168, 5, 84, 2, 132, 212, 36, 202, 56, 155, 72, 266, 1, 80, 81, 116, 163, 221, 143, 96, 134, 193, 155, 45, 146, 82, 245, 87, 203, 406, 127, 1, 23, 137, 344, 142, 101, 87, 201, 110, 358, 91, 260, 3, 165, 225, 183, 398, 2, 188, 4, 61, 3, 189, 141, 348, 92, 218, 271, 98, 137, 51, 74, 49, 182, 7, 190, 2, 47, 87, 94, 30, 289, 104, 206, 81, 191, 359, 93, 78, 64, 52, 223, 167, 144, 115, 110, 156, 284, 245, 108, 6, 255, 795, 82, 97, 46, 365, 94, 91, 10, 66, 162, 113, 147, 77, 164, 24, 208, 73, 253, 870, 573, 53, 243, 535, 58, 33, 124, 293, 48, 160, 61, 149, 617, 113, 252, 170, 90, 360, 10, 24, 60, 4, 207, 0, 1, 76, 12, 92, 29, 107, 249, 111, 145, 803, 390, 54, 306, 109, 167, 0, 40, 270, 38, 2, 0, 288, 113, 62, 27, 768, 192, 22, 73, 1, 89, 93, 75, 385, 129, 136, 366, 120, 141, 202, 260, 0, 0, 106, 55, 68, 150, 97, 5, 198, 180, 116, 251, 112, 244, 292, 2, 46, 239, 62, 73, 120, 199, 4, 38, 398, 78, 664, 651, 495, 103, 5, 281, 176, 315, 0, 21, 0, 53, 37, 250, 75, 0, 133, 219, 52, 28, 174, 148, 608, 634, 776, 305, 4, 139, 166, 244, 192, 351, 0, 87, 546, 216, 290, 502, 334, 237, 118, 56, 1894, 2228, 1194, 118, 158, 478, 488, 322, 143, 117, 71, 158, 10, 90, 155, 166, 690, 1209, 857, 156, 271, 869, 5, 278, 348, 164, 323, 137, 143, 93, 194, 321, 151, 643, 1951, 173, 247, 88, 959, 225, 337, 630, 220, 868, 193, 239, 247, 101, 217, 51, 107, 247, 67, 904, 882, 267, 656, 445, 534, 361, 347, 297, 341, 204, 65, 155, 148, 179, 161, 114, 158, 359, 483, 1040, 595, 98, 155, 208, 123, 119, 302, 81, 299, 309, 378, 59, 590, 80, 2, 78, 166, 74, 229, 2, 244, 859, 248, 118, 473, 664, 4, 91, 168, 351, 88, 131, 99, 116, 10, 198, 808, 843, 51, 91, 118, 598, 112, 90, 340, 1071, 285, 332, 201, 280, 83, 61, 344, 8, 44, 178, 75, 142, 186, 2189, 104, 58, 267, 57, 82, 167, 258, 277, 302, 0, 38, 428, 589, 285, 121, 215, 359, 131, 546, 122, 118, 39, 16, 1279, 340, 117, 107, 146, 126, 193, 67, 417, 152, 114, 212, 159, 311, 273, 208, 121, 220, 23, 23, 6, 134, 122, 2660, 2, 3, 118, 89, 590, 245, 139, 116, 72, 148, 297, 223, 214, 745, 4, 59, 194, 5, 129, 266, 214, 267, 343, 246, 167, 192, 154, 142, 222, 145, 56, 565, 117, 135, 596, 1, 342, 173, 159, 351, 113, 147, 228, 211, 254, 43, 118, 245, 246, 349, 112, 56, 649, 244, 168, 227, 310, 221, 403, 272, 91, 63, 423, 789, 60, 673, 243, 193, 105, 88, 128, 589, 325, 242, 425, 120, 485, 1075, 293, 165, 241, 506, 926, 1, 496, 23, 549, 1069, 0, 0, 119, 680, 161, 6946, 11308, 122, 15, 621, 178, 38, 95, 302, 60, 253, 1, 48, 24, 76, 46, 57, 53, 145, 140, 361, 511, 237, 815, 3452, 140, 1547, 0, 0, 0, 0, 0, 0, 0, 0, 0, 219, 140, 411, 586, 212, 51, 528, 172, 52, 177, 234, 224, 69, 96, 1861, 519, 1178, 3038, 201, 1140, 0, 10, 75, 210, 33, 139, 14, 134, 24, 138, 69, 61, 95, 70, 74, 432, 26, 28, 71, 36, 133, 67, 191, 296, 14, 70, 0, 39, 108, 11, 103, 57, 94, 65, 52, 40, 212, 271, 99, 56, 139, 109, 84, 36, 67, 134, 36, 22, 70, 139, 171, 55, 170, 0, 51, 47, 23, 95, 46, 80, 75, 39, 60, 118, 89, 35, 47, 170, 118, 94, 225, 234, 56, 36, 134, 192, 81, 6, 186, 37, 205, 261, 55, 149, 522, 595, 1573, 137, 296, 1005, 111, 169, 3859, 39, 364, 1218, 13780, 0, 1863, 29, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 0, 1, 0, 15, 2161, 241, 76, 36, 343, 5, 2, 5, 4, 778, 5196, 9298, 1, 7, 531, 838, 823, 218, 25, 77, 37, 345, 6, 0, 1, 0, 1, 945, 604, 7494, 6606, 2095, 701, 1704, 707, 158, 53, 1230, 269, 397, 33, 629, 31, 63, 94, 62, 115, 49, 131, 124, 83, 99, 3, 178, 777, 296, 190, 435, 517, 769, 1123, 433, 261, 439, 1186, 4131, 136, 78, 997, 811, 1238, 373, 263, 577, 276, 1, 176, 90, 47, 43, 75, 250, 4552, 767, 875, 386, 623, 49, 75, 45, 171, 80, 330, 32, 184, 508, 863, 190, 125, 226, 100, 109, 251, 691, 5, 460, 384, 48, 166, 103, 688, 244, 114, 98, 93, 30, 460, 154, 260, 174, 696, 181, 117, 270, 575, 135, 387, 74, 82, 47, 309, 379, 93, 286, 17, 71, 3, 397, 45, 84, 4, 84, 55, 480, 54, 576, 307, 110, 44, 74, 204, 146, 620, 45, 51, 178, 90, 79, 85, 108, 174, 225, 34, 632, 32, 64, 95, 63, 116, 50, 385, 132, 125, 261, 124, 5, 212, 3, 51, 43, 48, 2, 76, 60, 116, 2, 148, 140, 314, 49, 59, 116, 9, 34, 172, 690, 78, 398, 220, 0, 0, 6, 52, 170, 49, 52, 55, 296, 6, 26, 66, 149, 234, 3, 80, 3, 2, 38, 81, 219, 340, 635, 3, 242, 87, 156, 83, 304, 73, 76, 426, 36, 180, 0, 43, 42, 313, 1252, 53, 290, 49, 207, 12, 202, 106, 55, 23, 64, 139, 108, 206, 812, 67, 83, 46, 49, 189, 81, 49, 84, 44, 33, 212, 798, 71, 43, 109, 123, 60, 1522, 591, 22, 137, 204, 153, 81, 77, 90, 9, 1684, 574, 2509, 2504, 2314, 914, 607, 530, 108, 206, 60, 218, 119, 244, 149, 70, 541, 96, 90, 75, 362, 435, 937, 175, 583, 154, 262, 52, 693, 178, 2, 2, 137, 176, 763, 1722, 1358, 127, 215, 418, 317, 145, 122, 303, 26, 157, 3375, 1119, 980, 540, 456, 90, 67, 51, 73, 74, 79, 897, 1654, 1909, 1811, 976, 441, 234, 572, 307, 219, 115, 222, 409, 179, 19, 64, 203, 100, 74, 38, 34, 1346, 1041, 825, 223, 100, 263, 230, 69, 5, 1, 795, 143, 84, 142, 91, 713, 1483, 561, 179, 128, 246, 98, 1136, 90, 254, 47, 385, 58, 138, 235, 999, 402, 701, 1007, 199, 72, 126, 796, 829, 242, 86, 67, 110, 166, 3, 1569, 695, 106, 1048, 47, 260, 531, 83, 43, 498, 852, 336, 540, 68, 210, 154, 38, 188, 213, 2, 84, 113, 909, 460, 19, 160, 433, 53, 68, 1213, 327, 147, 121, 148, 2, 311, 213, 270, 49, 320, 2315, 99, 120, 80, 50, 327, 189, 69, 244, 683, 179, 115, 117, 575, 371, 83, 150, 107, 127, 93, 106, 109, 144, 119, 1400, 80, 74, 120, 114, 89, 33, 121, 119, 148, 115, 197, 215, 262, 116, 310, 574, 73, 148, 652, 5, 309, 143, 88, 127, 205, 212, 476, 2880, 122, 178, 124, 110, 230, 81, 301, 95, 589, 585, 4, 386, 87, 142, 21, 573, 63, 80, 572, 191, 109, 212, 99, 88, 308, 272, 52, 229, 174, 211, 126, 49, 80, 223, 416, 465, 74, 125, 925, 1023, 306, 399, 495, 79, 385, 4831, 7952, 505, 37, 36, 24, 111, 84, 282, 112, 33, 58, 0, 0, 63, 9, 146, 127, 45, 439, 581, 7191, 0, 0, 0, 0, 0, 812, 60, 76, 88, 104, 125, 195, 42, 205, 66, 120, 20, 37, 66, 82, 571, 675, 4429, 0, 68, 67, 128, 75, 70, 24, 870, 59, 19, 20, 75, 35, 25, 69, 112, 88, 66, 191, 283, 235, 360, 57, 3, 34, 10, 4, 18, 76, 41, 204, 65, 74, 119, 119, 19, 37, 142, 31, 158, 207, 30, 1115, 1604, 20, 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 4951, 337, 267, 306, 138, 348, 64, 501, 3, 92, 1556, 539, 515, 8341, 9154, 1, 61, 488, 84, 718, 161, 46, 1984, 1497, 74, 329, 149, 410, 204, 183, 128, 139, 244, 107, 63, 218, 289, 4, 93, 85, 150, 1355, 1029, 555, 303, 145, 426, 13974, 10123, 3442, 969, 2388, 2536, 358, 986, 444, 1174, 2230, 929, 1521, 419, 228, 35, 954, 485, 326, 26, 972, 328, 481, 2, 110, 98, 110, 294, 2, 486, 1247, 7549, 7, 484, 65, 2067, 4414, 174, 12, 391, 411, 1508, 788, 680, 2, 286, 54, 57, 346, 139, 307, 1176, 1, 1, 113, 285, 560, 252, 125, 927, 93, 1049, 115, 718, 32, 498, 635, 246, 331, 1997, 215, 90, 516, 693, 89, 319, 46, 100, 150, 177, 122, 906, 227, 314, 152, 282, 115, 2, 2, 395, 197, 114, 482, 98, 234, 256, 178, 246, 128, 398, 2, 331, 200, 196, 148, 313, 27, 954, 1, 261, 410, 196, 54, 253, 407, 3, 608, 223, 283, 1188, 503, 246, 235, 161, 133, 67, 254, 228, 272, 257, 434, 170, 638, 162, 12, 166, 126, 43, 127, 243, 78, 266, 292, 565, 284, 486, 196, 184, 273, 219, 1111, 224, 796, 107, 139, 107, 133, 266, 170, 270, 258, 4, 94, 95, 153, 463, 188, 19, 90, 10, 57, 394, 472, 769, 39, 1134, 93, 151, 191, 128, 661, 57, 191, 116, 719, 122, 197, 108, 149, 36, 116, 205, 186, 297, 320, 34, 9, 214, 499, 136, 59, 354, 166, 314, 162, 259, 167, 27, 260, 55, 700, 222, 500, 395, 206, 5, 218, 269, 103, 185, 85, 691, 609, 1, 453, 1, 396, 184, 3, 105, 720, 7, 470, 171, 153, 28, 228, 42, 2, 597, 703, 2, 0, 134, 274, 111, 28, 266, 1, 121, 87, 962, 160, 297, 75, 277, 2052, 719, 338, 459, 7, 94, 124, 151, 1354, 521, 882, 5527, 8394, 10, 271, 2097, 374, 1886, 368, 491, 343, 454, 234, 371, 50, 201, 6, 63, 1071, 218, 1348, 587, 3, 9, 238, 161, 293, 563, 176, 2, 6, 0, 9469, 175, 644, 131, 863, 304, 873, 282, 58, 89, 277, 68, 106, 71, 19, 231, 726, 3159, 1454, 3556, 7771, 2742, 2301, 589, 1316, 1170, 765, 828, 1383, 59, 124, 96, 145, 112, 290, 288, 213, 877, 351, 11, 426, 40, 58, 124, 65, 1056, 1170, 691, 855, 238, 0, 81, 440, 2, 5, 1684, 1665, 309, 1663, 44, 39, 269, 187, 225, 284, 3, 28, 308, 4065, 617, 1905, 90, 205, 263, 77, 271, 118, 300, 3, 374, 566, 6286, 3863, 366, 373, 105, 929, 1487, 1679, 466, 29, 183, 666, 452, 168, 17, 296, 5, 10, 156, 1885, 4590, 58, 556, 811, 647, 1580, 765, 1202, 300, 110, 190, 261, 204, 128, 274, 46, 26, 256, 1054, 2928, 2367, 1369, 2239, 1870, 1740, 723, 350, 251, 72, 391, 77, 517, 169, 3, 2133, 602, 1205, 1403, 467, 191, 57, 3, 68, 818, 458, 1403, 222, 1, 216, 249, 75, 250, 54, 418, 847, 1036, 821, 1303, 124, 43, 71, 206, 64, 658, 105, 57, 1218, 1930, 2292, 490, 98, 16, 237, 134, 270, 439, 390, 46, 27, 509, 2265, 4183, 762, 347, 325, 424, 567, 265, 172, 855, 131, 109, 369, 5, 258, 465, 476, 2571, 2542, 93, 730, 159, 604, 98, 117, 175, 290, 1172, 189, 491, 251, 726, 173, 565, 6819, 590, 134, 335, 87, 340, 233, 253, 167, 123, 164, 355, 289, 3, 153, 203, 3783, 125, 459, 201, 826, 135, 177, 135, 167, 253, 225, 301, 1292, 160, 359, 131, 192, 491, 169, 71, 315, 70, 577, 490, 248, 813, 339, 174, 184, 165, 127, 232, 331, 567, 269, 251, 118, 152, 252, 110, 173, 203, 725, 202, 173, 2179, 205, 67, 265, 278, 16, 499, 750, 183, 291, 53, 1050, 163, 549, 494, 722, 133, 614, 1601, 595, 277, 123, 190, 2045, 415, 382, 250, 182, 414, 1595, 168, 249, 844, 181, 932, 1003, 66, 898, 580, 687, 1398, 1612, 5933, 13684, 656, 643, 12, 80, 13, 8, 254, 17, 52, 60, 91, 92, 927, 52, 12, 191, 4, 138, 192, 102, 64, 136, 62, 570, 1438, 1060, 1659, 496, 4736, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 338, 243, 173, 204, 49, 359, 122, 156, 420, 59, 242, 1194, 56, 149, 113, 107, 269, 252, 243, 289, 455, 567, 695, 1932, 770, 3962, 169, 72, 67, 254, 38, 143, 132, 106, 113, 178, 84, 242, 48, 209, 13, 73, 98, 62, 140, 79, 14, 160, 10, 169, 140, 215, 112, 147, 16, 121, 155, 53, 456, 132, 61, 60, 92, 241, 91, 83, 26, 149, 220, 418, 147, 184, 389, 805, 51, 9, 3, 55, 40, 20, 79, 148, 122, 82, 78, 77, 3, 66, 112, 161, 78, 12, 102, 226, 178, 0, 91, 74, 91, 145, 97, 60, 87, 77, 251, 121, 220, 405, 262, 57, 117, 574, 72, 810, 283, 393, 539, 1311, 518, 1368, 0, 1612, 317, 1539, 1555, 6959, 4756, 21, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20, 3217, 4391, 335, 135, 371, 82, 134, 32, 10, 147, 144, 95, 45, 21, 979, 5411, 11445, 6715, 835, 169, 22, 7, 1, 996, 218, 373, 791, 441, 388, 46, 89, 210, 477, 168, 905, 2357, 1094, 138, 1, 337, 184, 43, 99, 274, 430, 83, 136, 33, 1, 3, 148, 145, 476, 93, 2, 46, 22, 1698, 321, 8483, 821, 101, 1, 3, 25615, 920, 147, 224, 6, 145, 41, 1, 73, 507, 10, 62, 398, 31666, 2016, 90, 104, 302, 56, 138, 230, 121, 185, 436, 54, 134, 82, 169, 30, 119, 44, 495, 39010, 383, 27, 5, 8, 4, 11, 3, 381, 386, 167, 3, 57, 56297, 101, 3, 29, 96, 40, 3, 2, 137, 4, 90, 489, 244, 257, 49, 55, 1, 209, 156, 113, 15, 263, 46687, 1274, 430, 2362, 253, 113, 218, 330, 12, 174, 77, 113, 318, 104, 82, 160, 955, 21, 176, 358, 817, 2469, 259, 359, 9, 62, 434, 75, 148, 13, 132, 87, 242, 230, 136, 70, 706, 14912, 3358, 5612, 1817, 972, 429, 519, 1008, 603, 1201, 781, 934, 185, 116, 2775, 11, 667, 711, 348, 311, 1345, 216, 458, 2552, 2117, 169, 723, 360, 193, 311, 477, 96, 93, 4, 6, 146, 902, 3001, 4938, 6, 157, 94, 893, 301, 1422, 154, 347, 126, 378, 473, 4, 200, 22, 879, 1252, 319, 677, 47, 219, 229, 84, 58, 2607, 71, 617, 182, 259, 187, 734, 264, 251, 9, 45, 299, 629, 227, 3, 551, 12, 31, 163, 2888, 577, 818, 1411, 1184, 15, 120, 1129, 1423, 336, 228, 166, 381, 1324, 703, 1180, 129, 79, 98, 316, 268, 115, 231, 10, 358, 381, 254, 64, 116, 26, 7, 164, 2, 25, 17, 1222, 1194, 239, 455, 245, 90, 180, 143, 1842, 697, 253, 230, 183, 722, 460, 400, 218, 120, 411, 594, 226, 20, 1700, 260, 232, 2195, 310, 161, 425, 331, 73, 13, 302, 373, 139, 235, 481, 183, 175, 275, 388, 308, 78, 133, 343, 812, 188, 124, 1195, 598, 482, 3850, 303, 299, 240, 117, 71, 44, 1365, 1582, 344, 3275, 238, 1972, 1562, 1230, 1063, 144, 226, 163, 532, 222, 12, 2, 42, 254, 104, 83, 669, 1276, 231, 91, 262, 155, 265, 337, 456, 385, 1680, 101, 61, 311, 416, 278, 184, 89, 167, 1021, 145, 741, 595, 345, 289, 304, 5, 347, 2, 244, 0, 836, 536, 313, 417, 63, 22, 176, 342, 106, 2714, 2258, 1945, 1738, 660, 266, 4, 339, 235, 113, 183, 811, 3, 95, 343, 119, 438, 46, 89, 490, 107, 3898, 2892, 157, 116, 284, 199, 13, 202, 319, 174, 243, 10059, 2687, 1092, 74, 383, 579, 117, 247, 159, 751, 98, 286, 399, 166, 89, 357, 1905, 7421, 8987, 548, 2014, 1843, 407, 715, 1008, 998, 984, 570, 334, 199, 687, 1490, 293, 153, 144, 132, 178, 85, 66, 501, 1234, 531, 272, 462, 618, 348, 219, 170, 5019, 1873, 3687, 715, 1079, 926, 1366, 154, 700, 822, 537, 572, 118, 368, 422, 1825, 5494, 2455, 576, 1112, 388, 771, 494, 5, 2071, 613, 206, 177, 314, 184, 228, 127, 1638, 1372, 382, 88, 76, 4, 194, 462, 10, 72, 3376, 637, 2577, 1593, 1382, 816, 238, 111, 272, 161, 191, 70, 141, 705, 3176, 1564, 2375, 1749, 1267, 534, 748, 979, 453, 227, 155, 474, 2148, 1375, 1284, 161, 104, 203, 1532, 1278, 2330, 1179, 1482, 352, 613, 102, 189, 116, 256, 42, 54, 315, 2268, 2172, 1138, 679, 1345, 267, 169, 210, 169, 304, 243, 63, 183, 822, 3376, 417, 1110, 1262, 816, 593, 69, 147, 242, 64, 202, 90, 2431, 3702, 1263, 3039, 1806, 696, 610, 336, 94, 491, 79, 8, 133, 374, 167, 2658, 1483, 1180, 1294, 1961, 322, 81, 347, 147, 156, 250, 237, 105, 220, 1219, 1306, 1147, 386, 538, 10, 962, 335, 20, 535, 822, 1194, 3511, 345, 789, 386, 231, 441, 264, 633, 226, 293, 303, 202, 183, 162, 283, 35, 62, 716, 4633, 924, 1048, 724, 131, 478, 257, 715, 267, 153, 439, 123, 73, 684, 284, 81, 82, 518, 401, 137, 1098, 5068, 165, 735, 1201, 131, 1282, 162, 383, 92, 261, 678, 630, 990, 1036, 164, 323, 801, 471, 207, 312, 266, 308, 228, 118, 1323, 385, 80, 129, 533, 1202, 157, 479, 181, 130, 230, 256, 479, 479, 1035, 424, 1283, 95, 168, 280, 206, 472, 1444, 85, 384, 386, 537, 103, 265, 289, 412, 1203, 276, 1147, 169, 701, 313, 281, 195, 313, 1284, 311, 1878, 170, 845, 304, 248, 314, 236, 158, 305, 383, 263, 315, 306, 1097, 240, 417, 778, 244, 282, 521, 196, 373, 385, 243, 1156, 197, 228, 322, 63, 523, 1668, 2547, 267, 1481, 2328, 2627, 227, 2786, 10141, 19128, 2036, 304, 1, 203, 183, 94, 115, 93, 57, 209, 3, 107, 2, 136, 71, 467, 277, 856, 46, 925, 598, 217, 496, 82, 72, 89, 186, 3, 157, 521, 122, 49, 64, 20, 45, 484, 108, 285, 330, 4753, 0, 0, 0, 3762, 1112, 81, 392, 83, 259, 310, 1137, 71, 696, 183, 1354, 53, 449, 222, 748, 161, 768, 1107, 43, 184, 177, 1, 390, 89, 44, 60, 288, 83, 212, 262, 463, 3649, 143, 325, 331, 113, 367, 303, 206, 233, 82, 43, 145, 259, 200, 90, 548, 90, 22, 83, 69, 42, 266, 1789, 347, 416, 252, 401, 0, 0, 80, 86, 227, 37, 229, 239, 216, 86, 77, 57, 95, 332, 84, 260, 112, 78, 470, 133, 213, 588, 45, 401, 9, 304, 78, 2, 86, 137, 109, 56, 38, 98, 111, 110, 302, 106, 184, 130, 105, 105, 261, 83, 83, 108, 77, 91, 149, 388, 599, 57, 150, 110, 262, 137, 78, 96, 113, 126, 87, 589, 465, 338, 81, 31, 55, 49, 36, 501, 185, 113, 305, 150, 138, 478, 510, 189, 161, 167, 1303, 119, 551, 68, 359, 289, 205, 923, 149, 124, 297, 143, 807, 1208, 430, 89, 108, 182, 129, 199, 216, 12, 593, 343, 635, 286, 169, 80, 512, 111, 170, 93, 186, 175, 2146, 648, 1640, 334, 118, 264, 533, 98, 757, 636, 138, 251, 637, 82, 89, 124, 21, 638, 176, 37, 87, 458, 534, 148, 415, 158, 155, 148, 56, 71, 305, 199, 1629, 556, 153, 227, 8059, 2362, 333, 146, 118, 645, 2494, 2414, 6531, 163, 1077, 324, 511, 4460, 4483, 147, 107, 43, 331, 124, 104, 374, 110, 170, 263, 344, 510, 19, 166, 250, 637, 220, 305, 149, 595, 224, 117, 851, 1139, 167, 1253, 4931, 4146, 17200, 93, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 3, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 1, 2, 3, 1, 1, 1, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1, 2, 1, 1, 1, 2, 1, 3, 5, 14, 3, 3, 2, 1, 31, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 26, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 1, 0, 1, 0, 5, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 1, 1, 1, 3, 1, 2, 2, 1, 1, 1, 3, 1, 1, 5, 1, 1, 1, 3, 8, 1, 1, 1, 1, 24, 1, 10, 76, 21, 18, 7, 4, 2, 3, 3, 7, 14, 219, 2, 83, 10, 6, 3, 7, 12, 27, 4, 10, 2, 2, 1, 64, 14, 5, 2, 61, 7, 1, 7, 5, 1, 45, 6, 5, 8, 9, 34, 12, 12, 5, 26, 2, 40, 4, 17, 4, 2, 3, 41, 6, 23, 3, 1, 3, 9, 3, 1, 0, 2, 0, 2, 0, 0, 4, 8, 0, 20, 0, 0, 0, 46, 79, 21, 10, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 13, 3, 0, 0, 0, 0, 0, 0, 0, 54, 22, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 14, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 2, 5, 2, 2, 1, 2, 3, 1, 2, 1, 1, 1, 3, 1, 1, 1, 1, 11, 9, 1, 1, 9, 1, 31, 3, 1, 4, 2, 4, 2, 3, 29, 4, 16, 8, 12, 11, 2, 6, 7, 6, 11, 72, 19, 1, 1, 1, 14, 3, 1, 2, 3, 4, 6, 4, 12, 12, 7, 3, 12, 1, 1, 15, 3, 3, 20, 2, 1, 2, 1, 1, 1, 0, 0, 1, 0, 0, 0, 3, 7, 0, 0, 3, 14, 2, 2, 1, 0, 2, 0, 0, 3, 16, 3, 0, 0, 0, 2, 0, 13, 4, 0, 0, 49, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 1, 2, 0, 0, 1, 0, 1, 0, 6, 5, 1, 1, 1, 2, 1, 1, 1, 3, 1, 7, 1, 2, 1, 1, 1, 2, 2, 1, 1, 4, 2, 7, 2, 1, 2, 1, 1, 2, 4, 2, 2, 1, 3, 2, 3, 3, 2, 3, 2, 4, 3, 3, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 1, 4, 1, 1, 2, 1, 2, 3, 3, 5, 1, 2, 5, 1, 1, 1, 2, 3, 2, 1, 3, 2, 2, 1, 1, 2, 4, 3, 2, 2, 1, 3, 3, 1, 2, 2, 3, 2, 2, 8, 1, 1, 3, 2, 4, 1, 3, 3, 2, 2, 2, 24, 3, 2, 5, 5, 1, 5, 2, 1, 2, 2, 2, 0, 2, 2, 0, 2, 1, 2, 2, 0, 1, 1, 0, 0, 0, 3, 0, 0, 1, 2, 3, 5, 1, 2, 0, 0, 0, 0, 1, 1, 1, 3, 0, 0, 1, 2, 1, 1, 0, 0, 0, 2, 1, 0, 3, 0, 5, 0, 1, 0, 2, 0, 0, 0, 4, 1, 0, 0, 0, 3, 1, 1, 0, 2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 5, 0, 1, 6, 1, 1, 1, 2, 1, 2, 1, 0, 1, 1, 1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 3, 4, 1, 1, 2, 1, 2, 1, 1, 1, 3, 2, 2, 2, 1, 1, 1, 1, 1, 5, 3, 1, 1, 1, 1, 3, 4, 2, 1, 3, 0, 1, 0, 0, 1, 0, 0, 2, 0, 0, 0, 1, 0, 0, 1, 0, 1, 0, 0, 1, 0, 0, 2, 0, 1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 10, 2834, 1571, 201, 371, 543, 53, 1613, 237, 114, 7, 222, 262, 200, 243, 3639, 23678, 3574, 4, 2, 38, 79, 1410, 1346, 27, 1583, 148, 58, 377, 316, 232, 54, 24, 241, 1015, 372, 5, 0, 2, 19, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 113, 8, 1, 221, 261, 201, 447, 5506, 145, 36478, 17719, 2329, 6175, 2604, 5630, 405, 2129, 2966, 1630, 2103, 1761, 214, 217, 32, 123, 395, 829, 878, 288, 4, 399, 330, 1, 254, 58, 530, 1829, 3747, 304, 4235, 2389, 1870, 1193, 244, 822, 66, 434, 1014, 218, 359, 459, 317, 1418, 151, 526, 317, 4, 263, 239, 1142, 3290, 883, 924, 2430, 734, 897, 456, 750, 421, 195, 1590, 293, 736, 202, 545, 665, 57, 37, 661, 365, 2321, 1438, 90, 55, 427, 161, 139, 47, 7, 112, 173, 836, 62, 571, 276, 484, 205, 493, 302, 239, 227, 468, 1524, 1073, 453, 918, 668, 250, 184, 649, 444, 2, 2, 317, 1107, 5, 194, 151, 265, 120, 875, 12, 501, 62, 572, 541, 482, 183, 857, 1135, 175, 631, 16, 1246, 370, 1075, 338, 415, 342, 481, 336, 293, 678, 486, 176, 522, 135, 306, 277, 17, 231, 286, 1, 149, 392, 72, 784, 500, 1, 180, 63, 192, 1120, 373, 573, 267, 109, 2, 360, 458, 540, 195, 661, 785, 456, 265, 375, 224, 1059, 1603, 600, 487, 367, 193, 547, 206, 20, 347, 982, 206, 607, 89, 560, 339, 598, 255, 541, 217, 146, 351, 1501, 251, 37, 203, 458, 786, 177, 463, 598, 1068, 139, 280, 196, 167, 574, 483, 494, 215, 459, 208, 542, 553, 268, 185, 3, 573, 2, 30, 650, 2, 337, 124, 218, 397, 853, 1092, 177, 303, 483, 228, 267, 607, 1538, 445, 241, 294, 679, 484, 695, 276, 214, 775, 147, 484, 110, 203, 5, 854, 207, 546, 401, 331, 1151, 90, 58, 1, 1, 1, 2, 38, 96, 160, 605, 225, 57, 209, 855, 208, 753, 209, 2, 6, 541, 1429, 452, 543, 447, 277, 75, 621, 200, 1219, 4328, 2086, 656, 25, 158, 293, 13, 560, 133, 196, 46, 1004, 3, 168, 594, 1285, 161, 305, 319, 416, 6224, 5042, 462, 1516, 1849, 1529, 1286, 862, 5, 231, 1418, 546, 662, 1564, 2524, 459, 551, 280, 136, 157, 829, 2973, 525, 990, 1825, 1380, 1125, 1092, 119, 297, 796, 677, 790, 32, 257, 362, 318, 343, 817, 26, 1680, 1881, 480, 542, 2235, 111, 674, 953, 468, 226, 990, 614, 682, 194, 512, 37, 162, 677, 163, 1206, 324, 816, 390, 756, 148, 519, 229, 140, 256, 677, 649, 40, 704, 330, 4, 92, 370, 187, 1781, 564, 418, 268, 170, 972, 87, 673, 260, 1491, 795, 367, 822, 180, 918, 538, 3, 11, 134, 419, 1890, 340, 1, 138, 355, 925, 1071, 378, 74, 104, 252, 316, 2, 57, 240, 1522, 604, 577, 212, 320, 638, 10, 129, 193, 1071, 2459, 1131, 896, 1305, 100, 795, 1685, 604, 270, 84, 298, 141, 1122, 42, 112, 2002, 176, 1006, 2, 1560, 526, 777, 367, 954, 1002, 43, 0, 434, 126, 465, 1811, 1682, 760, 260, 40, 789, 107, 245, 134, 1103, 742, 119, 1340, 0, 560, 1893, 2468, 987, 150, 178, 461, 175, 239, 781, 124, 575, 2036, 155, 1071, 197, 989, 3, 181, 198, 5103, 3064, 4, 594, 660, 6, 437, 462, 210, 1410, 3526, 19, 0, 5611, 466, 486, 267, 524, 0, 694, 344, 58, 116, 375, 1139, 786, 716, 240, 605, 136, 2861, 6616, 33, 22, 735, 672, 380, 777, 143, 464, 631, 780, 229, 471, 180, 1526, 446, 93, 3059, 7454, 66, 388, 817, 485, 396, 741, 268, 5, 114, 1, 352, 523, 149, 194, 1275, 772, 257, 381, 525, 285, 226, 333, 850, 193, 507, 865, 585, 819, 36, 684, 723, 267, 436, 820, 485, 467, 115, 376, 630, 522, 484, 1718, 195, 464, 1098, 978, 2291, 2, 0, 227, 789, 294, 1562, 316, 621, 1415, 631, 663, 1425, 1765, 154, 252, 192, 419, 664, 123, 92, 103, 937, 209, 509, 155, 367, 297, 20634, 33280, 3201, 35, 43, 80, 100, 66, 101, 133, 2, 0, 2, 139, 157, 200, 92, 12, 2462, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10549, 297, 240, 321, 132, 216, 1694, 230, 131, 57, 260, 58, 457, 72, 217, 521, 188, 524, 185, 482, 175, 169, 507, 501, 65, 209, 903, 557, 351, 296, 1561, 10606, 0, 1560, 9, 315, 284, 1015, 63, 270, 87, 99, 280, 693, 8, 22, 8, 259, 137, 117, 48, 3, 149, 476, 46, 300, 1215, 5357, 0, 0, 0, 0, 0, 0, 40, 11, 53, 240, 65, 104, 998, 0, 0, 293, 42, 241, 292, 219, 42, 102, 131, 79, 314, 220, 86, 417, 142, 65, 86, 10, 367, 207, 673, 1488, 0, 0, 229, 132, 100, 56, 261, 59, 52, 455, 71, 64, 228, 510, 86, 218, 80, 98, 221, 158, 500, 279, 187, 64, 240, 79, 220, 239, 6, 87, 45, 171, 88, 44, 1212, 184, 7, 39, 14, 6, 351, 176, 64, 9, 102, 238, 78, 227, 131, 168, 278, 643, 233, 183, 226, 158, 131, 118, 0, 248, 387, 78, 26, 116, 123, 68, 87, 44, 279, 444, 101, 486, 186, 366, 1957, 1167, 246, 146, 696, 1532, 6271, 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 3, 165, 33, 59, 4, 11, 105, 4, 1, 1, 166, 34, 20, 177, 6, 79, 21, 1, 6, 176, 175, 27, 179, 1, 73, 1, 0, 0, 0, 12, 1, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 4, 2, 6, 1, 243, 18, 2, 134, 175, 76, 20, 21, 176, 180, 20, 1, 1, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 1, 1, 1, 11, 7, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 2, 1, 7, 4, 1, 1, 1, 1, 1, 1, 1, 4, 1, 2, 2, 1, 2, 1, 1, 4, 1, 1, 2, 2, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 4, 1, 14, 4, 1, 2, 3, 5, 10, 172, 1, 1, 1, 3, 1, 3, 7, 25, 2, 2, 6, 2, 1, 2, 2, 2, 1, 2, 1, 0, 0, 3, 0, 0, 2, 0, 0, 4, 1, 0, 0, 0, 2, 1, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 2, 1, 2, 1, 0, 0, 2, 0, 1, 0, 1, 0, 2, 5, 298, 94, 53, 707, 92, 42, 2, 16, 15, 40, 514, 4402, 2356, 1, 36, 116, 18, 69, 67, 26, 71, 27, 28, 616, 146, 117, 93, 27, 43, 0, 17, 6, 11, 160, 654, 171, 2, 6339, 43, 2, 45, 1, 24, 20, 12, 31, 134, 2270, 316, 38, 35, 542, 170, 150, 154, 89, 131, 445, 70, 73, 6, 87, 27, 49, 147, 151, 3, 169, 131, 794, 56, 68, 1099, 275, 1661, 97, 299, 1575, 41, 546, 1, 88, 679, 545, 204, 85, 94, 23, 33, 261, 63, 16, 26, 19, 3037, 76, 245, 41, 89, 146, 154, 16, 83, 167, 176, 184, 395, 99, 48, 108, 35, 42, 132, 114, 153, 35, 111, 21, 1, 39, 1, 77, 36, 63, 78, 27, 1, 142, 150, 55, 46, 38, 39, 49, 53, 33, 154, 2, 150, 46, 80, 31, 36, 246, 155, 90, 73, 60, 39, 81, 79, 64, 42, 252, 71, 35, 60, 9, 0, 1, 3, 247, 88, 28, 90, 50, 77, 26, 16, 83, 99, 0, 61, 0, 59, 122, 26, 26, 0, 2, 119, 3, 44, 68, 63, 14, 88, 78, 62, 0, 141, 63, 153, 20, 86, 38, 102, 43, 260, 57, 1, 23, 45, 15, 151, 211, 30, 206, 153, 606, 118, 179, 89, 0, 185, 8, 28, 20, 2, 0, 212, 618, 128, 8, 4, 28, 44, 903, 324, 22, 37, 122, 213, 76, 22, 355, 152, 97, 80, 55, 31, 417, 507, 12, 183, 50, 152, 300, 134, 6, 54, 338, 217, 207, 581, 611, 119, 137, 120, 36, 47, 98, 64, 234, 84, 136, 48, 30, 13, 1, 19, 35, 114, 193, 74, 1623, 22, 247, 9, 79, 134, 21, 3, 119, 55, 100, 275, 93, 196, 2, 7, 76, 80, 71, 100, 26, 40, 440, 107, 41, 65, 307, 99, 1, 55, 99, 1, 731, 295, 16, 1, 107, 122, 3, 86, 22, 78, 68, 918, 66, 341, 184, 71, 186, 2, 40, 53, 7, 48, 5, 72, 18, 87, 25, 36, 5, 121, 27, 396, 1604, 1, 52, 65, 125, 113, 88, 84, 55, 35, 89, 64, 156, 765, 14, 41, 127, 13, 87, 31, 112, 68, 14, 191, 127, 77, 44, 62, 39, 42, 89, 69, 64, 36, 40, 69, 185, 10, 99, 184, 491, 266, 38, 59, 86, 43, 486, 62, 12, 287, 235, 8, 84, 123, 83, 151, 63, 4, 2, 54, 28, 135, 246, 121, 47, 294, 74, 29, 96, 12, 64, 115, 331, 0, 216, 54, 123, 134, 28, 77, 113, 114, 98, 111, 78, 67, 98, 202, 85, 73, 296, 2249, 5323, 207, 48, 12, 131, 0, 37, 60, 1, 1, 52, 28, 22, 935, 1988, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 567, 56, 43, 74, 10, 165, 17, 137, 15, 19, 89, 74, 7, 22, 1270, 2448, 0, 118, 26, 93, 32, 210, 257, 57, 117, 42, 27, 39, 33, 47, 0, 13, 9, 31, 125, 132, 16, 2, 134, 68, 14, 59, 38, 18, 0, 53, 34, 0, 41, 148, 66, 64, 109, 26, 79, 2728, 0, 8, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 4, 0, 2, 0, 1, 0, 1, 1, 0, 0, 1, 4, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 1, 1, 0, 44, 4, 52, 2320, 369, 256, 31, 209, 159, 89, 102, 139, 63, 2, 152, 16, 1070, 84, 50, 251, 50, 335, 10271, 8430, 53, 173, 852, 1286, 53, 177, 142, 184, 74, 32, 419, 30, 3, 160, 91, 2, 0, 140, 54, 64, 1, 153, 17, 39, 89, 136, 632, 701, 38, 86, 49, 91, 101, 151, 51, 154, 305, 278, 13006, 8646, 794, 2577, 182, 835, 188, 321, 3, 1208, 330, 521, 146, 580, 195, 106, 226, 150, 2098, 94, 104, 5616, 1090, 2892, 1105, 6015, 4625, 91, 7, 26, 242, 50, 164, 185, 779, 919, 98, 78, 169, 7, 17, 365, 29, 94, 223, 4, 366, 3270, 1130, 577, 282, 435, 225, 501, 277, 465, 291, 970, 564, 870, 616, 272, 138, 124, 80, 225, 118, 206, 372, 150, 161, 76, 849, 284, 411, 532, 283, 183, 86, 65, 377, 266, 818, 61, 427, 76, 236, 298, 89, 27, 283, 15, 55, 394, 380, 64, 98, 284, 92, 151, 320, 4, 158, 232, 315, 184, 133, 375, 331, 87, 436, 129, 394, 226, 147, 508, 156, 237, 149, 332, 162, 495, 107, 498, 6, 77, 2, 559, 217, 90, 149, 1, 146, 608, 5, 924, 1016, 882, 573, 2, 84, 51, 14, 66, 48, 95, 105, 9, 1361, 779, 1735, 1046, 15, 93, 6, 140, 333, 56, 30, 76, 30, 138, 2, 16, 63, 222, 13, 1054, 4, 343, 1919, 530, 46, 334, 23, 64, 6, 290, 78, 7, 481, 3842, 1870, 67, 88, 6, 387, 251, 176, 691, 205, 68, 799, 596, 285, 399, 435, 56, 6854, 131, 329, 497, 407, 362, 297, 628, 974, 1576, 499, 214, 20, 121, 461, 363, 281, 1780, 44, 417, 10, 246, 188, 87, 286, 267, 307, 312, 18, 287, 962, 289, 181, 476, 149, 1412, 142, 1575, 1640, 1367, 96, 871, 912, 116, 88, 2338, 454, 269, 151, 131, 65, 1096, 314, 334, 182, 9, 16, 494, 771, 1887, 1, 82, 16, 132, 30, 42, 191, 289, 98, 22, 217, 6, 299, 197, 208, 30, 340, 68, 232, 133, 409, 488, 34, 145, 278, 82, 94, 146, 173, 300, 51, 216, 296, 24, 122, 5, 370, 348, 284, 348, 3, 684, 173, 41, 62, 141, 32, 356, 368, 381, 143, 297, 5, 450, 1549, 333, 81, 135, 1419, 257, 44, 167, 95, 125, 99, 705, 558, 1564, 314, 95, 2057, 34, 288, 91, 149, 178, 1410, 138, 72, 316, 212, 139, 2299, 357, 22, 222, 2, 92, 601, 288, 1825, 313, 278, 309, 76, 217, 1253, 139, 19, 71, 245, 91, 1167, 199, 301, 170, 198, 381, 354, 411, 29, 211, 48, 470, 143, 280, 207, 491, 90, 16, 3163, 636, 550, 683, 226, 238, 121, 108, 26, 952, 1517, 7993, 513, 821, 378, 67, 131, 295, 395, 349, 2079, 49, 127, 43, 160, 618, 499, 39, 289, 81, 114, 277, 616, 1870, 284, 571, 225, 628, 290, 237, 120, 130, 198, 300, 627, 94, 935, 91, 125, 332, 90, 600, 1237, 241, 71, 336, 668, 434, 86, 70, 453, 206, 401, 954, 0, 184, 205, 518, 1369, 962, 2413, 9958, 0, 15852, 14, 8, 166, 174, 38, 39, 36, 41, 14, 36, 33, 231, 49, 15, 156, 43, 79, 22, 32, 37, 56, 54, 144, 357, 191, 70, 173, 126, 142, 5478, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 296, 298, 90, 318, 384, 336, 92, 284, 553, 158, 82, 61, 57, 11, 525, 240, 117, 140, 261, 138, 235, 141, 76, 68, 187, 689, 249, 297, 189, 146, 354, 8383, 0, 136, 166, 162, 91, 42, 7, 88, 170, 2, 42, 143, 126, 93, 148, 140, 74, 169, 523, 36, 0, 133, 37, 283, 143, 179, 163, 64, 94, 40, 62, 73, 83, 1, 135, 15, 37, 144, 94, 252, 39, 10, 0, 180, 134, 147, 133, 165, 14, 149, 145, 123, 16, 120, 36, 162, 41, 93, 155, 116, 35, 2, 16, 27, 43, 34, 2, 21, 139, 40, 86, 193, 57, 115, 290, 137, 141, 450, 250, 288, 235, 136, 12, 786, 202, 71, 1316, 42, 48, 537, 102, 753, 122, 598, 789, 615, 13, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 4, 4, 2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 3, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 5, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 2, 0, 3, 0, 1, 2, 1, 0, 1, 2, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 2, 3, 1, 2, 1, 3, 1, 4, 6, 13, 27, 2, 14, 1, 99, 2, 2, 25, 1, 1, 67, 10, 44, 58, 11, 7, 1, 56, 8, 54, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 3, 10, 2, 2, 2, 2, 1, 1, 1, 2, 8, 6, 1, 2, 3, 1, 1, 1, 1, 3, 6, 2, 1, 65, 2, 2, 1, 1, 1, 1, 3, 3, 2, 1, 8, 8, 9, 2, 3, 5, 1, 2, 1, 8, 6, 2, 2, 1, 6, 3, 7, 6, 3, 4, 2, 3, 1, 14, 20, 12, 9, 11, 16, 14, 13, 11, 17, 7, 4, 10, 16, 36, 22, 1, 5, 6, 4, 2, 6, 2, 2, 4, 1, 1, 2, 3, 2, 5, 2, 2, 2, 1, 1, 1, 4, 1, 1, 1, 1, 4, 6, 2, 3, 1, 3, 2, 4, 2, 1, 2, 4, 1, 5, 1, 2, 2, 3, 1, 2, 1, 1, 1, 6, 3, 3, 1, 1, 1, 9, 1, 2, 1, 1, 2, 6, 3, 1, 7, 2, 5, 3, 3, 5, 4, 7, 1, 3, 3, 3, 9, 20, 7, 2, 5, 1, 8, 1, 1, 3, 8, 8, 13, 4, 3, 3, 4, 3, 2, 1, 39, 14, 11, 8, 11, 6, 2, 2, 2, 4, 46, 49, 17, 11, 14, 1, 1, 3, 3, 1, 1, 95, 35, 16, 10, 3, 6, 3, 2, 2, 230, 64, 30, 6, 1, 1, 6, 1, 5, 3, 7, 357, 133, 13, 6, 10, 2, 3, 2, 2, 5, 578, 38, 27, 11, 10, 10, 4, 3, 6, 10, 4, 821, 138, 100, 73, 29, 39, 4, 11, 2, 6, 4, 12, 8, 8, 540, 275, 158, 73, 27, 3, 14, 3, 3, 10, 20, 6, 531, 170, 32, 54, 2, 11, 6, 8, 0, 683, 182, 102, 33, 40, 1, 7, 12, 4, 25, 0, 0, 555, 462, 70, 108, 4, 5, 15, 1, 2, 1, 25, 8, 6, 0, 0, 556, 98, 156, 12, 7, 13, 13, 5, 8, 6, 7, 6, 22, 17, 0, 0, 418, 554, 47, 2, 22, 20, 2, 2, 1, 3, 1, 1, 1, 67, 159, 40, 0, 0, 0, 0, 0, 341, 18, 1, 9, 6, 5, 24, 108, 136, 26, 0, 0, 86, 27, 25, 138, 18, 7, 13, 2, 2, 20, 6, 15, 371, 602, 49, 1, 0, 0, 23, 18, 11, 1, 26, 59, 18, 0, 0, 0, 0, 9, 1, 1, 3, 26, 0, 0, 0, 0, 0, 2, 3, 2, 2, 2, 47, 0, 4, 15, 2, 3, 75, 14, 62, 27, 0, 0, 0, 4, 4, 5, 34, 10, 0, 2, 3, 14, 19, 1, 0, 5, 3, 4, 1, 3, 0, 0, 2, 3, 15, 3, 1, 0, 2, 1, 14, 1, 1, 0, 0, 0, 1, 1, 0, 1, 4, 8, 0, 0, 3, 0, 0, 0, 0, 19, 5, 0, 1, 0, 7, 73, 43, 0, 637, 1, 84, 0, 0, 0, 0, 0, 27, 1481, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 25, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 2, 3, 4, 2, 46, 44, 7, 2, 1, 4, 1, 1, 9, 1, 3, 3, 2, 4, 1, 2, 1, 7, 2, 1, 1, 1, 0, 1, 0, 0, 1, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 5, 1, 0, 0, 0, 0, 1, 1, 1, 3, 1, 1, 3, 1, 1, 1, 2, 1, 4, 2, 10, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1, 3, 938, 288, 32, 62, 13, 3, 77, 37, 9, 59, 14, 193, 1352, 3589, 3813, 1070, 33, 59, 162, 39, 181, 368, 163, 13, 78, 148, 115, 34, 63, 14, 4, 78, 38, 1, 1, 0, 0, 0, 58, 13, 335, 44, 1843, 187, 1, 1, 5371, 457, 64, 72, 49, 74, 1, 1, 51, 193, 158, 85, 32, 12, 24, 14, 28, 603, 9636, 195, 43, 33, 44, 168, 2, 69, 646, 13107, 96, 3, 17, 2, 5, 88, 119, 11, 43, 8, 60, 41, 17, 382, 16650, 182, 77, 52, 75, 40, 10, 1, 43, 191, 102, 398, 86, 11, 12, 4, 54, 22, 14, 4, 8, 9, 713, 8387, 941, 238, 45, 271, 144, 90, 102, 14, 38, 48, 173, 206, 1428, 824, 686, 109, 151, 59, 177, 152, 49, 22, 91, 42, 122, 138, 81, 46, 92, 379, 2384, 533, 279, 210, 123, 48, 223, 643, 117, 235, 197, 128, 72, 121, 86, 279, 128, 106, 25, 845, 758, 232, 197, 53, 168, 70, 202, 114, 82, 100, 85, 80, 39, 194, 241, 1760, 155, 78, 64, 189, 81, 28, 222, 89, 73, 143, 114, 336, 82, 201, 130, 212, 110, 46, 124, 49, 44, 67, 158, 26, 103, 302, 66, 392, 53, 84, 80, 28, 47, 75, 150, 50, 91, 50, 103, 119, 65, 68, 163, 74, 198, 2, 126, 13, 0, 318, 67, 76, 71, 74, 49, 126, 1, 7, 104, 124, 16, 157, 0, 127, 1, 74, 129, 37, 0, 50, 41, 82, 116, 68, 32, 72, 18, 86, 69, 0, 164, 39, 26, 172, 1355, 315, 226, 65, 129, 228, 156, 248, 34, 20, 88, 14, 121, 2, 1, 125, 350, 530, 705, 321, 691, 283, 224, 17, 34, 42, 204, 110, 99, 84, 23, 47, 125, 165, 881, 125, 425, 199, 517, 81, 76, 166, 164, 13, 10, 82, 142, 36, 78, 71, 42, 1055, 27, 83, 68, 120, 11, 51, 141, 19, 126, 64, 90, 128, 1, 63, 110, 1, 461, 144, 49, 80, 120, 194, 130, 56, 28, 76, 257, 101, 362, 130, 19, 56, 35, 22, 81, 27, 84, 163, 353, 168, 110, 171, 191, 94, 23, 326, 229, 138, 124, 327, 78, 106, 12, 39, 29, 415, 157, 96, 50, 121, 308, 204, 99, 5, 64, 158, 53, 116, 82, 73, 751, 41, 261, 53, 121, 73, 118, 205, 79, 33, 214, 111, 52, 55, 328, 54, 1, 16, 220, 215, 80, 845, 29, 79, 89, 54, 138, 192, 43, 365, 77, 35, 38, 74, 312, 214, 53, 1, 234, 487, 125, 169, 80, 1, 281, 55, 77, 2, 76, 40, 85, 558, 66, 83, 157, 53, 93, 212, 78, 82, 53, 81, 158, 303, 52, 79, 127, 52, 82, 282, 97, 380, 637, 1, 160, 138, 159, 186, 160, 309, 0, 75, 607, 0, 15, 390, 0, 185, 126, 131, 2392, 5088, 155, 35, 24, 6, 5, 1351, 35, 123, 33, 75, 63, 14, 97, 156, 575, 906, 2951, 0, 0, 0, 97, 78, 25, 118, 1372, 114, 46, 78, 44, 199, 81, 277, 814, 1567, 46, 48, 33, 119, 33, 77, 23, 47, 7, 24, 119, 6, 41, 162, 69, 85, 65, 59, 507, 617, 1355, 24, 37, 31, 51, 61, 93, 40, 82, 1, 72, 0, 62, 206, 30, 36, 77, 31, 118, 57, 116, 107, 54, 64, 339, 160, 101, 131, 500, 1328, 2929, 0, 30, 10, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 1, 0, 1, 0, 1, 1, 1, 0, 0, 0, 2, 1, 1, 0, 0, 2, 1, 1, 0, 0, 1, 1, 0, 0, 2, 0, 1, 3, 2, 0, 1, 2, 1, 3, 4, 8, 0, 4, 0, 0, 3, 1, 1, 1, 3, 1, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 1, 0, 1, 2, 2, 1, 0, 0, 0, 0, 1, 1, 2, 1, 3, 3, 2, 1, 1, 1, 5, 1, 6, 1, 1, 2, 1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 1, 1, 10, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 2, 1, 0, 15, 6269, 898, 62644, 40, 17, 15, 77, 100, 996, 29, 1, 1074, 5207, 1974, 11757, 8938, 10950, 5162, 4259, 526, 494, 1473, 7, 517, 1930, 1887, 1440, 4233, 16806, 692, 521, 1990, 863, 6591, 1806, 1737, 4629, 2580, 41, 2193, 608, 4049, 4632, 2194, 458, 4460, 3978, 18, 1146, 1465, 2519, 528, 2692, 2082, 540, 1, 1, 459, 8, 4461, 1, 19, 516, 1929, 458, 1013, 876, 575, 1476, 38332, 27, 71621, 121233, 697, 120, 3637, 1512, 63, 2658, 1581, 286, 3, 919, 39, 40, 1599, 1039, 709, 1087, 1088, 651, 55, 16, 13, 53, 103, 130, 6, 615, 2050, 57, 835, 224, 64, 22, 279, 389, 469, 186, 12, 629, 2, 28, 2, 77, 3, 213, 3, 1, 5, 3, 82, 27098, 6737, 20268, 15898, 106, 10938, 3, 79, 4061, 1580, 61, 570, 2195, 2941, 2599, 1600, 5159, 2658, 1114, 144, 2012, 30, 1127, 128, 22, 159, 101, 2127, 2488, 39, 46, 2948, 9, 32, 95, 15, 1152, 15, 243, 1051, 34, 11, 264, 6, 82, 957, 1112, 5046, 1488, 17903, 1008, 76, 94, 250, 8, 671, 63, 18, 82, 1142, 7, 22, 1213, 4386, 37, 43, 10, 1143, 12, 4, 9558, 2022, 6087, 3062, 2289, 3778, 1992, 35, 20, 10, 10, 110, 1975, 3495, 4427, 7157, 3981, 1596, 1489, 1748, 2321, 23, 11, 15, 37, 211, 16, 3, 2023, 3190, 10, 10, 7, 8, 9, 25, 107, 6116, 3496, 2437, 1742, 3759, 8921, 3400, 1556, 2821, 9, 2805, 2504, 1000, 5, 1755, 35, 13, 2121, 472, 17, 34, 4, 478, 4, 1582, 1730, 4388, 3353, 1076, 4, 3497, 2024, 8, 280, 5710, 1581, 1442, 4, 9, 3855, 8149, 3064, 128, 889, 32, 1731, 80, 582, 3856, 3481, 1743, 24, 3, 15, 3760, 170, 1412, 581, 62, 3761, 1582, 8923, 7, 28, 8, 8924, 4867, 1200, 569, 3762, 3331, 472, 8926, 2196, 6532, 3498, 2290, 923, 11, 708, 8927, 2021, 5712, 3858, 10, 13, 1557, 5631, 2586, 1079, 1031, 1011, 3484, 993, 2022, 4389, 1830, 1601, 171, 4862, 2197, 4245, 2499, 7310, 7, 994, 109, 2551, 1115, 2032, 8, 145, 1490, 2806, 3507, 3859, 6, 3361, 639, 1109, 2024, 4006, 1397, 3498, 4, 37, 11, 9136, 11, 3787, 83, 20, 709, 6, 3864, 1202, 3, 2198, 11, 3, 2292, 1120, 5, 10, 12, 96, 1748, 17, 1, 1001, 25, 26, 72, 5, 12, 10, 2817, 93, 17, 7, 18, 11969, 4433, 796, 1582, 18, 12, 5, 80, 2931, 16, 6, 1072, 1, 24, 74, 7, 22, 5, 113, 8149, 67, 29, 13758, 9, 3355, 1580, 1538, 11, 1281, 9, 9, 0, 0, 38, 4190, 3, 9261, 4391, 1978, 3721, 1632, 2440, 9654, 2, 24, 40, 3656, 15, 2622, 197, 605, 663, 27, 48, 127, 94, 5741, 964, 1108, 1595, 3674, 4, 5, 1090, 687, 23, 25, 2151, 18825, 3624, 13498, 7, 10, 8, 222, 20, 2848, 13947, 29, 13, 0, 0, 2147, 1474, 7549, 2, 9052, 2631, 1332, 1602, 37, 1557, 45213, 12808, 9, 172, 1, 23, 8, 3, 21, 5, 9, 422, 0, 43526, 86, 10030, 2023, 3798, 455, 101, 8, 8, 2200, 1116, 24257, 58140, 3784, 6813, 2163, 19, 1153, 32, 1286, 1732, 927, 2250, 17, 1080, 48, 12, 259, 44, 5, 1204, 27684, 30, 78, 16, 2, 15, 1601, 1, 9848, 47742, 15396, 3374, 98, 8345, 1025, 132, 1637, 23, 6246, 35, 1617, 184, 18, 774, 244, 8, 1996, 54, 3, 16, 9, 109, 2029, 3, 34, 10244, 2171, 592, 25, 26, 2553, 14, 25894, 2847, 19685, 6017, 3957, 487, 2, 5414, 88, 1599, 3786, 1747, 1, 1050, 11, 9, 3935, 2849, 13039, 4506, 3504, 8972, 3850, 46, 32, 500, 34, 176, 14, 229, 2117, 12, 1549, 71, 4, 32, 4, 19, 20, 19, 1060, 44, 3863, 1612, 22, 31, 23, 3360, 9292, 60, 72, 27, 6, 29, 113, 3, 20, 3, 12, 11, 22, 139, 51, 10763, 17747, 3649, 7199, 52, 3307, 1462, 1261, 31, 2503, 17, 1763, 4, 123, 1982, 9, 1092, 308, 7907, 113, 2479, 1013, 7622, 58, 32, 2846, 43, 43, 21, 12, 331, 9, 24, 265, 10, 3103, 8614, 5922, 4446, 3303, 3264, 155, 1297, 15, 42, 9, 139, 8, 5, 19, 1268, 989, 2, 1833, 2171, 172, 10943, 19, 85, 1066, 921, 5, 2, 60, 29, 5, 2664, 53, 11261, 10924, 130, 1228, 3968, 3398, 10, 1902, 1495, 11, 1064, 2520, 5, 15, 14, 6, 568, 44, 10, 12, 1733, 19, 27, 3562, 141, 40, 2382, 2227, 10, 991, 933, 8953, 9, 22, 9, 14, 42, 5233, 1093, 9066, 11257, 15, 2644, 29, 3776, 5276, 1868, 2201, 20, 640, 1120, 2238, 86, 1588, 1374, 34, 1569, 57, 125, 31, 17, 24, 11, 2040, 15, 9, 2126, 7, 4, 1475, 8, 8, 1113, 448, 69, 264, 24, 215, 5870, 7, 15, 1079, 15, 53, 1600, 18, 23, 12, 4, 23, 14, 1093, 4971, 90, 6746, 191, 270, 2814, 3864, 22, 59, 2364, 3546, 16, 7, 4, 31, 29, 8, 175, 11, 1101, 11, 12, 33, 309, 149, 2513, 8122, 5722, 19, 13, 67, 1260, 1016, 15, 1877, 38, 3776, 1115, 45, 3372, 19, 2946, 166, 161, 26, 57, 18, 12, 232, 2519, 228, 1562, 97, 42, 4407, 1730, 20, 3439, 2765, 275, 11, 9, 2031, 584, 1146, 96, 15, 483, 1428, 72, 933, 24, 12, 6399, 414, 939, 21, 8528, 10, 14, 11, 14, 1504, 36, 9882, 6, 4401, 6, 14, 2006, 12, 1080, 3865, 1731, 473, 20, 39, 14, 21, 2, 1207, 3775, 9026, 15, 33, 34, 18, 12, 119, 11, 1014, 19, 56, 3071, 44, 333, 110, 96, 1033, 19, 2316, 58, 1218, 81, 4, 103, 2451, 76, 8, 16, 1568, 688, 3186, 6383, 259, 84, 5722, 7, 7285, 16, 44, 3, 251, 1022, 1997, 2804, 4400, 1101, 50, 10, 90, 28, 942, 22, 50, 6, 8945, 15, 1093, 17, 72, 18, 25, 8, 5752, 8, 4172, 22, 8, 13, 14, 18, 1121, 19, 5720, 30, 30, 36, 24, 9, 54, 22, 46, 28, 13, 25, 55, 7745, 14, 3777, 5, 2018, 12, 6471, 22, 5, 51, 7, 1219, 34, 3866, 8, 18, 11, 4087, 4, 30, 49, 2051, 5720, 62, 10041, 22, 942, 8, 2297, 1164, 43, 21, 117, 8, 16, 1282, 18, 1128, 38, 11, 1869, 15, 15, 33, 52, 52, 20, 8, 480, 47, 84, 94, 18, 7, 9, 19, 15, 7240, 78, 0, 2222, 1858, 427, 23, 10, 5747, 26, 9, 9, 14, 1048, 58, 19, 22, 2500, 34, 94, 42, 12824, 29, 1401, 15283, 82, 33, 40, 3777, 1731, 5305, 6048, 77, 24, 47, 21, 35, 108, 924, 2164, 9032, 18023, 413, 17, 3764, 944, 89, 15, 9815, 188, 34479, 71, 141495, 2, 0, 71314, 149, 6, 9, 23, 15, 10, 1, 3, 4, 1, 4, 8, 1, 2, 78, 5, 3, 1, 126, 9, 85, 16, 42, 3, 44, 16, 3, 103, 20, 4, 1154, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34169, 1513, 1442, 1737, 871, 104, 2041, 2174, 440, 1057, 861, 605, 601, 986, 496, 2043, 1329, 281, 790, 988, 354, 1099, 0, 0, 289, 633, 3696, 803, 149, 552, 1578, 932, 524, 540, 2174, 534, 524, 1455, 0, 0, 6933, 3555, 1006, 2488, 5677, 696, 3762, 2142, 2669, 491, 914, 1567, 132, 1, 1638, 605, 527, 462, 525, 2849, 722, 1289, 798, 570, 2155, 0, 863, 2191, 496, 502, 2848, 456, 798, 870, 1005, 862, 6, 501, 7, 1393, 871, 1095, 105, 513, 1526, 500, 1676, 721, 4458, 1217, 441, 9, 2847, 1058, 698, 4457, 2846, 323, 536, 0, 604, 4456, 1883, 1877, 600, 863, 1144, 1495, 121, 7304, 1059, 864, 495, 4458, 2846, 2641, 799, 1290, 514, 1884, 2, 1330, 1924, 743, 282, 3, 1004, 0, 791, 987, 2, 14, 1677, 492, 14, 870, 353, 1098, 9, 16, 1923, 0, 19, 603, 4663, 28, 126, 11, 1058, 23, 36, 1270, 4456, 2845, 1922, 217, 1964, 1003, 31, 1876, 632, 861, 455, 1143, 0, 1875, 123, 569, 131, 602, 2190, 8, 5822, 3268, 208, 631, 84, 600, 4455, 3760, 1244, 1738, 913, 860, 598, 1094, 237, 1752, 2189, 587, 0, 6326, 109, 1393, 38, 551, 4623, 7528, 1563, 597, 4021, 1008, 1590, 0, 2843, 630, 2, 2658, 2630, 950, 2105, 684, 4766, 8169, 2977, 1435, 9487, 1427, 0, 0, 0, 11333, 5751, 6610, 5638, 11825, 11434, 4707, 14819, 10350, 36059, 428, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 5, 1, 1, 4, 3, 1, 1, 5, 1, 4, 1, 5, 3, 66, 10, 8, 2, 2, 2, 1, 2, 1, 1, 2, 3, 1, 1, 3, 2, 1, 1, 0, 0, 0, 2, 1, 1, 0, 0, 0, 2, 1, 1, 0, 1, 0, 2, 1, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, 0, 3, 1, 0, 1, 1, 1, 20, 4108, 1631, 3168, 2064, 804, 796, 277, 133, 403, 284, 185, 130, 162, 829, 348, 701, 124, 180, 111, 384, 9, 57, 84, 8, 302, 161, 48, 2465, 22843, 4177, 128, 67, 140, 150, 396, 186, 464, 2208, 401, 91, 224, 303, 99, 933, 619, 149, 164, 201, 401, 1550, 237, 2572, 219, 810, 799, 266, 13, 284, 339, 134, 285, 226, 186, 296, 467, 473, 679, 272, 151, 562, 61, 700, 123, 181, 7, 104, 389, 10, 58, 482, 152, 8, 7, 178, 116, 162, 389, 49, 3490, 730, 41564, 25313, 1881, 234, 1709, 3961, 609, 706, 315, 187, 1787, 3656, 635, 1005, 1121, 147, 801, 174, 1469, 520, 805, 664, 287, 40, 604, 1177, 1549, 997, 565, 942, 933, 2075, 461, 1969, 9382, 780, 2846, 856, 4467, 7518, 3665, 477, 1464, 213, 353, 2, 800, 91, 196, 12, 10, 369, 387, 1166, 1985, 1222, 1290, 1404, 445, 183, 1238, 750, 2089, 776, 359, 468, 390, 381, 315, 457, 886, 272, 342, 263, 936, 2589, 329, 119, 1961, 2498, 291, 39, 273, 266, 308, 118, 160, 5, 770, 824, 111, 147, 534, 738, 466, 106, 181, 279, 6, 664, 135, 382, 3, 771, 171, 206, 2626, 5, 1487, 555, 417, 852, 270, 310, 733, 1374, 141, 28, 37, 539, 446, 72, 148, 383, 86, 1106, 192, 190, 95, 279, 223, 752, 488, 188, 321, 298, 382, 1470, 266, 87, 112, 303, 698, 228, 455, 1440, 1403, 796, 197, 234, 444, 193, 249, 421, 168, 172, 269, 219, 608, 334, 7, 590, 188, 148, 473, 52, 15, 1700, 219, 360, 475, 1239, 175, 384, 536, 229, 541, 295, 469, 701, 1493, 481, 690, 418, 138, 456, 384, 1441, 85, 324, 171, 79, 366, 304, 316, 385, 1567, 553, 220, 33, 121, 271, 3, 14, 272, 892, 606, 10, 798, 374, 772, 125, 3003, 1404, 1045, 1010, 1113, 1113, 230, 513, 212, 284, 280, 1738, 190, 540, 674, 7, 341, 0, 56, 524, 2, 687, 569, 319, 304, 399, 0, 469, 1070, 663, 88, 262, 170, 932, 16, 156, 4201, 424, 1643, 895, 289, 160, 16, 1086, 7687, 1052, 10433, 12131, 298, 1768, 1644, 1609, 3, 1202, 12, 146, 65, 131, 162, 6, 304, 592, 682, 153, 1319, 1635, 3, 2, 66, 700, 0, 13, 820, 7330, 3074, 1926, 634, 71, 191, 68, 105, 61, 1098, 1353, 676, 128, 164, 59, 18642, 7560, 461, 1764, 630, 1100, 313, 62, 224, 27, 84, 221, 89, 235, 294, 123, 432, 16986, 6316, 9858, 1674, 260, 5427, 6332, 327, 1308, 671, 668, 340, 203, 171, 2, 301, 214, 221, 8, 135, 1205, 1686, 191, 241, 299, 5553, 12842, 4147, 513, 4288, 3138, 589, 778, 11, 17, 524, 123, 202, 194, 13, 23, 286, 262, 1212, 5206, 1420, 655, 2967, 501, 361, 1895, 324, 656, 345, 1096, 6994, 3996, 8210, 6185, 1223, 1483, 308, 732, 1230, 593, 239, 411, 289, 291, 497, 1547, 1225, 6996, 3748, 449, 316, 584, 39, 131, 585, 249, 42, 200, 707, 3545, 775, 921, 221, 116, 132, 422, 177, 309, 20222, 3370, 3948, 406, 665, 580, 197, 264, 83, 38, 5, 384, 366, 273, 72, 318, 712, 2714, 8569, 16986, 2492, 1050, 1705, 2075, 547, 264, 572, 113, 67, 164, 615, 469, 130, 266, 611, 353, 941, 4003, 1, 7261, 804, 221, 618, 2368, 381, 70, 63, 261, 151, 135, 404, 534, 1111, 1109, 5948, 4648, 1145, 3266, 172, 1642, 1175, 524, 387, 75, 587, 650, 778, 67, 151, 444, 1659, 10, 968, 281, 39, 132, 52, 510, 703, 4350, 5594, 789, 1508, 281, 615, 2150, 189, 72, 220, 193, 945, 486, 333, 943, 286, 221, 302, 2190, 493, 913, 2841, 282, 318, 275, 596, 1065, 2615, 731, 408, 24, 200, 447, 207, 328, 92, 3, 493, 195, 325, 588, 2838, 187, 1701, 1440, 135, 142, 132, 420, 1169, 547, 4, 1023, 193, 761, 4, 551, 407, 133, 183, 43, 733, 2369, 306, 173, 311, 508, 470, 743, 326, 479, 4, 142, 574, 486, 9, 341, 670, 485, 1294, 14, 216, 552, 882, 3070, 575, 744, 1407, 71, 757, 1193, 327, 147, 305, 478, 174, 282, 833, 571, 5, 254, 412, 386, 260, 348, 419, 152, 446, 139, 447, 206, 112, 327, 219, 205, 648, 574, 279, 191, 706, 989, 525, 777, 1193, 570, 421, 220, 2162, 590, 458, 418, 1064, 1103, 340, 300, 569, 152, 111, 492, 473, 11, 669, 353, 484, 596, 936, 204, 760, 1293, 444, 130, 3, 563, 1448, 526, 550, 491, 783, 393, 468, 1406, 746, 3005, 586, 197, 299, 1308, 2413, 248, 204, 492, 2660, 181, 571, 746, 668, 761, 1334, 1686, 220, 460, 2757, 2738, 905, 3593, 30255, 38398, 125, 378, 6, 1, 132, 1, 1, 84, 51, 255, 603, 771, 1142, 845, 1519, 2955, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6542, 633, 1195, 228, 55, 87, 155, 136, 95, 644, 58, 470, 394, 1099, 74, 245, 139, 159, 183, 580, 131, 37, 1849, 1592, 6592, 2819, 3669, 7930, 0, 132, 385, 300, 129, 421, 90, 118, 243, 265, 342, 1802, 471, 1281, 637, 34, 401, 218, 147, 329, 384, 119, 237, 147, 466, 215, 226, 56, 88, 154, 299, 5, 135, 94, 130, 643, 57, 350, 120, 0, 392, 270, 149, 398, 705, 379, 133, 2, 80, 4, 642, 203, 48, 6, 300, 83, 138, 89, 50, 158, 93, 182, 269, 117, 181, 222, 174, 118, 181, 82, 495, 11, 36, 641, 118, 35, 494, 1625, 849, 577, 363, 766, 2896, 1236, 872, 119, 4547, 6911, 4080, 5711, 5781, 21141, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 1, 2, 1, 2, 1, 1, 17, 1, 6, 1, 7, 6, 3, 11, 6, 8, 2, 9, 3, 1, 1, 5, 33, 1, 1, 1, 1, 3, 2, 12, 6, 27, 6, 4, 1, 1, 1, 2, 2, 2, 3, 1, 1, 7, 3, 2, 4, 4, 1, 2, 1, 1, 2, 4, 25, 7, 24, 14, 17, 10, 6, 4, 5, 1, 2, 2, 1, 3, 2, 3, 1, 1, 3, 1, 2, 2, 2, 1, 2, 2, 2, 1, 0, 2, 1, 1, 1, 1, 1, 0, 0, 1, 11, 2, 3, 2, 1, 1, 0, 0, 0, 0, 5, 1, 0, 0, 0, 0, 0, 0, 5, 3, 7, 3, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 3, 2, 2, 0, 0, 0, 0, 0, 3, 1, 3, 2, 0, 0, 0, 2, 3, 1, 1, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 2, 1, 2, 1, 1, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3, 1, 2, 3, 1, 5, 2, 1, 1, 3, 1, 1, 10, 2, 1, 1, 1, 4, 3, 1, 2, 1, 2, 3, 3, 3, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 3, 1, 7, 4, 1, 7, 3, 2, 3, 1, 4, 4, 3, 14, 12, 8, 4, 6, 1, 1, 5, 2, 3, 2, 1, 1, 1, 2, 1, 1, 2, 1, 2, 2, 1, 2, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 1, 4, 1, 1, 1, 1, 2, 1, 2, 2, 3, 3, 1, 2, 2, 4, 2, 3, 4, 1, 2, 3, 2, 3, 4, 8, 1, 2, 2, 1, 1, 8, 5, 1, 1, 4, 9, 10, 1, 1, 2, 6, 2, 2, 5, 1, 9, 11, 10, 4, 4, 5, 5, 3, 3, 4, 12, 29, 11, 3, 2, 2, 2, 4, 3, 12, 20, 3, 5, 9, 3, 5, 3, 10, 22, 30, 35, 13, 2, 9, 21, 32, 1, 41, 19, 3, 2, 2, 5, 4, 1, 24, 50, 7, 3, 23, 11, 3, 6, 3, 14, 54, 2, 1, 2, 5, 6, 29, 11, 6, 6, 7, 5, 4, 27, 62, 2, 1, 8, 3, 1, 2, 6, 3, 1, 1, 1, 1, 2, 1, 0, 2, 2, 2, 5, 0, 6, 3, 1, 7, 5, 49, 0, 3, 1, 1, 1, 10, 13, 0, 5, 1, 1, 2, 2, 4, 1, 0, 1, 1, 0, 4, 1, 2, 0, 5, 3, 6, 0, 2, 0, 1, 1, 3, 7, 0, 1, 0, 1, 0, 6, 6, 0, 2, 0, 0, 6, 1, 0, 3, 3, 0, 73, 0, 22, 2, 1, 1, 0, 3, 0, 0, 0, 0], "yaxis": "y"}], "layout": {"height": 300, "legend": {"tracegroupgap": 0}, "shapes": [{"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 15249653, "x1": 15249653, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 15251489, "x1": 15251489, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 15255320, "x1": 15255320, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 18758299, "x1": 18758299, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 19631624, "x1": 19631624, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 20014695, "x1": 20014695, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 20128327, "x1": 20128327, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 20129287, "x1": 20129287, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 21721800, "x1": 21721800, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 22164042, "x1": 22164042, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 22798647, "x1": 22798647, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 23468267, "x1": 23468267, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 24229845, "x1": 24229845, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}, {"line": {"dash": "dash", "width": 1}, "opacity": 0.2, "type": "line", "x0": 24266727, "x1": 24266727, "xref": "x", "y0": 0, "y1": 1, "yref": "y domain"}], "template": {"data": {"bar": [{"error_x": {"color": "rgb(36,36,36)"}, "error_y": {"color": "rgb(36,36,36)"}, "marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "baxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmapgl"}], "histogram": [{"marker": {"line": {"color": "white", "width": 0.6}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "rgb(237,237,237)"}, "line": {"color": "white"}}, "header": {"fill": {"color": "rgb(217,217,217)"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "colorscale": {"diverging": [[0.0, "rgb(103,0,31)"], [0.1, "rgb(178,24,43)"], [0.2, "rgb(214,96,77)"], [0.3, "rgb(244,165,130)"], [0.4, "rgb(253,219,199)"], [0.5, "rgb(247,247,247)"], [0.6, "rgb(209,229,240)"], [0.7, "rgb(146,197,222)"], [0.8, "rgb(67,147,195)"], [0.9, "rgb(33,102,172)"], [1.0, "rgb(5,48,97)"]], "sequential": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "sequentialminus": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]]}, "colorway": ["#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF"], "font": {"color": "rgb(36,36,36)"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "white", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "white", "polar": {"angularaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "radialaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "scene": {"xaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "zaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}, "shapedefaults": {"fillcolor": "black", "line": {"width": 0}, "opacity": 0.3}, "ternary": {"aaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "baxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "caxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}}, "title": {"text": "X"}, "width": 750, "xaxis": {"anchor": "y", "domain": [0.0, 1.0], "title": {"text": "midpoint"}}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0], "title": {"text": "depth"}}}}, "text/html": ["<div>                            <div id=\"789d0739-af1d-4a8f-b2bb-a900fb29375e\" class=\"plotly-graph-div\" style=\"height:300px; width:750px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"789d0739-af1d-4a8f-b2bb-a900fb29375e\")) {                    Plotly.newPlot(                        \"789d0739-af1d-4a8f-b2bb-a900fb29375e\",                        [{\"hovertemplate\":\"midpoint=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"\",\"marker\":{\"color\":\"lightsalmon\",\"symbol\":\"circle\"},\"mode\":\"markers\",\"name\":\"\",\"showlegend\":false,\"x\":[9293,9395,37332,71130,71131,71132,71132,71133,71133,71134,71134,190919,205512,205962,205963,205964,220562,251045,251047,251048,251203,353027,353028,353029,376927,376928,376928,376929,376932,376939,376942,376956,376957,376957,376958,376958,376959,376959,376960,377037,377038,665500,3476182,3476267,4712811,7624851,7625657,8474300,10007352,12114878,12196554,18631,18706,18781,18782,18808,18825,80544,80545,80546,74677,108478,142262,142262,142263,142264,142264,142265,142265,142266,142266,142278,142279,142280,142280,142264,142265,142265,142266,142279,142279,142280,142280,142281,142265,142266,142266,142267,142269,142269,142279,142280,142280,142281,142281,142266,142267,142267,142268,142268,142280,142280,142281,142281,142282,142283,142267,142268,142268,142269,142269,142270,142280,142281,142281,142282,142268,142269,142281,142282,142282,142283,142269,142270,142281,142282,142282,142283,142282,142283,142283,142282,142283,142283,142284,142283,142284,142284,142284,142285,142294,142295,142295,142295,142296,142296,277111,277111,433342,448075,448076,448103,448105,448106,142296,142297,142297,143404,262067,262068,262068,276659,276659,277111,277112,277113,281418,281419,290596,322195,322196,322351,355809,424175,448075,448076,448076,448077,448078,448084,448086,448105,448105,448106,448107,142297,142298,142298,142299,142299,142300,142302,181955,205729,235053,248711,262067,262068,262068,262069,262071,276661,277109,277109,277111,277111,277112,277112,277114,281419,301568,301569,322193,322193,322194,322194,322195,322195,322196,322196,322197,322199,322351,322352,322352,364018,392707,394996,424176,424177,430290,448069,448075,448076,448076,448077,448077,448078,448078,448079,448081,448084,448087,448089,448090,448091,448092,448092,448095,448104,448105,448106,448106,448107,448107,142298,142299,142303,143405,208592,248712,262068,262068,262069,262070,262070,276660,276661,277111,277112,277113,281419,281420,281421,322194,322196,322197,322198,322352,322353,424176,430290,448076,448077,448077,448079,448080,448105,448106,448106,448107,448107,448108,208593,248712,262066,262068,276662,277113,277113,322197,322352,424178,448077,448088,448089,448090,448108,448108,322198,322353,391708,448078,448108,262071,448109,277114,448110,262070,277115,322201,277117,144524,144587,144600,144675,144730,278307,144871,323520,221629,316786,269178,325516,274899,274899,274900,328375,388503,328375,327820,369427,355138,355139,428623,368495,387846,381849,381838,381839,381839,381851,381851,381852,381853,381853,381854,381854,381855,381856,381857,381858,381858,381839,381853,381853,381854,381855,381840,381853,381854,381855,381855,381852,381853,381855,381855,381856,381857,381858,381863,396895,442135,543959,401203,381866,381869,381870,396897,396897,441981,543961,567892,396897,396898,441982,442135,442137,514782,543961,567861,567861,567864,567891,381870,396897,396898,396898,441982,543962,381872,396447,442138,475595,543962,381872,396448,396899,396899,441979,442138,567864,567891,396899,396900,441984,441984,396900,441984,567863,567894,396902,396902,567866,543968,411037,411034,411038,411037,411037,411039,411040,411040,411041,411041,411042,411042,411042,411486,411488,529373,411056,411490,411490,411492,411491,456574,456575,456730,582458,582483,582487,411492,582484,411492,456577,411493,411493,411494,582489,411938,411940,411926,411941,411941,411942,411927,411928,411929,411941,411942,411942,411929,411930,411942,411943,411944,411944,411945,411957,582908,411957,436399,457027,457181,416249,416250,436400,457025,457026,457027,457027,457028,457182,457182,457183,482757,529827,559006,559007,559008,565121,568173,582906,582907,582907,582908,582909,582909,582910,582911,582915,582918,582918,582920,582921,582933,582935,582936,582936,582937,582938,420554,420554,420555,420555,420556,420556,420556,420557,420556,461486,461487,563311,461332,461487,572479,587241,461332,420571,461333,461333,461488,587228,587244,440706,461333,461334,461489,563313,587214,587229,587243,587244,438914,470513,441140,597536,460858,460859,460857,460858,481483,607394,583463,607364,607372,481641,481486,502090,502107,502105,502108,502093,502108,502093,502105,502107,502107,502109,502094,502108,502109,502094,502110,502095,502096,502107,502109,502109,502110,502110,502109,502109,502111,502111,502111,502112,502113,502114,502116,502121,502122,628016,502124,628001,502124,627988,627990,502125,604089,502125,502265,502266,502266,527841,535723,604090,604091,627989,627990,627990,627991,627998,628005,628008,628017,628018,628019,628021,628021,502127,502266,502266,571620,574912,604090,610204,610206,627990,627991,627991,627993,627994,627995,627996,627997,627999,628019,628020,628021,628022,604091,628020,527842,535724,604092,627992,628021,628022,627993,604093,627993,502404,502406,502407,502407,502416,502419,502419,502420,502420,502421,502421,502422,502422,502418,502418,502420,502421,502422,502422,502422,502422,502423,502422,502424,502523,502525,502433,502433,502528,502434,628144,628175,502435,502527,604244,628175,502435,502526,502436,502525,502527,575066,604245,604246,604248,610359,620667,628145,628145,628146,628146,628147,628147,628148,628149,628149,628150,628151,628153,628157,628158,628158,628160,628173,628173,628174,628174,628175,628175,628176,628176,628177,502529,502530,502531,604246,628146,628146,628147,628148,628158,628174,628175,628177,628177,12384492,535879,604246,628147,628149,628176,628176,628178,502624,502631,502632,502631,502633,502634,502635,502635,604345,628261,535983,604350,628250,628279,628280,628282,553568,553568,653717,653719,653749,569335,569336,569336,569337,569337,661633,661603,604691,637703,661632,661610,585766,669825,640041,673055,641125,641126,679708,697499,643154,643193,674625,647711,647711,647712,647713,647711,676890,700790,700791,676891,700819,700821,676892,706068,706056,706056,706057,706057,706069,706069,706070,706070,706071,706073,706069,706073,706069,706070,706071,706072,706059,706071,706071,706071,706071,706073,706071,706082,729973,706083,729971,729974,729982,729998,706084,706085,729970,729971,729975,729982,729987,730001,706085,715237,729963,729969,729970,729970,729971,729973,729974,729975,729981,729985,729988,729998,729999,729999,730000,730001,730001,706088,729970,729971,729971,729972,729973,729980,729999,730000,730001,730002,729971,730002,730002,729984,730001,729974,718296,718297,718297,718296,718297,718297,736113,736094,736111,736085,736098,736114,724402,724403,724403,739164,739167,739143,739166,738914,746422,753851,753860,753858,753864,753866,753854,753855,753855,753857,753867,753869,753869,753855,753856,753856,753857,753858,753858,753860,753862,753864,753868,753869,753870,753870,753871,753871,753872,753873,753874,753856,753857,753857,753858,753858,753861,753862,753864,753865,753866,753869,753870,753871,753871,753872,753872,753873,753873,753874,753875,753857,753858,753859,753862,753864,753866,753870,753870,753872,753872,753874,753875,753877,753878,753858,753859,753859,753860,753861,753864,753865,753866,753867,753872,753873,753877,753881,753885,753859,753860,753863,753870,753885,753886,753860,753861,753862,753862,753863,753863,753864,753864,753865,753865,753866,753866,753867,753867,753868,753868,753869,753871,753871,753872,753873,753873,753874,753876,753884,753888,753889,753863,753866,753867,753867,753870,753873,753875,753876,753876,753886,753886,753887,753887,753889,753865,753871,753871,753872,753874,753885,753887,753887,753888,753889,753885,753867,753868,753874,753877,753888,753866,753866,753869,753874,753874,753875,753878,753879,753886,753887,753888,753888,753889,753868,753876,753887,753888,753889,753889,753890,753868,753874,753877,753878,753883,753889,753890,753868,753869,753870,753870,753871,753872,753890,753891,753869,753870,753876,753880,753870,753871,753871,753874,753874,753871,753872,753873,753876,753879,753882,753889,753892,753892,753872,753873,753877,753880,753892,753895,753873,753874,753874,753880,753890,753892,753893,753895,753874,753875,753875,753876,753879,753880,753881,753892,753894,753875,753876,753877,753878,753891,753893,753876,753877,753877,753878,753882,753883,753877,753878,753878,753879,753881,753882,753895,753878,753879,753879,753881,753881,753887,753893,753894,753896,753879,753880,753882,753895,753896,753896,753897,753880,753881,753881,753882,753884,753896,753896,753897,753898,753881,753882,753882,753883,753883,753884,753884,753885,753886,753894,753895,753896,753897,753899,753882,753883,753883,753884,753884,753897,753897,753883,753884,753884,753885,753885,753887,753897,753898,753898,753884,753885,753886,753887,753898,753898,753899,753899,753885,753886,753886,753888,753888,753896,753898,753898,753899,753899,753901,753901,753886,753887,753887,753888,753897,753898,753899,753900,753901,753902,753887,753888,753888,753889,753890,753897,753898,753899,753900,753902,753888,753889,753889,753890,753890,753898,753899,753900,753901,753901,753902,753903,753889,753890,753890,753894,753900,753901,753902,753902,753903,753903,753890,753899,753900,753901,753902,753903,753891,753892,753892,753893,753894,753894,753895,753897,753899,753900,753901,753901,753902,753902,753903,753904,753904,753892,753894,753900,753902,753902,753903,753904,753905,753893,753894,753894,753895,753895,753901,753902,753904,753905,753894,753895,753897,753901,753902,753903,753903,753904,753895,753898,753902,753897,753898,753900,753902,753902,753904,753897,753899,753902,753906,753898,753899,753903,753904,753904,753899,753904,753905,753907,753900,753903,753904,753907,753905,753905,753909,753910,753907,753908,753908,753909,753910,753910,753911,753911,753912,753913,753909,753910,753910,753911,753911,753913,753913,753910,753911,753911,753912,753912,753913,753913,753914,753911,753912,753912,753913,753914,753914,753912,753913,753913,753914,753914,753915,753913,753914,753914,753915,753915,753914,753915,753915,753916,753915,753916,753916,753916,753917,753917,753918,753918,753919,753919,753920,753927,753928,753930,753931,753931,753932,753920,753921,753921,753922,753923,753933,753921,753922,753922,753923,753929,753932,753922,753923,753923,753924,753926,753929,753929,753930,753930,753932,753923,753924,753924,753925,753925,753926,753929,753930,753930,753931,753932,753924,753925,753925,753926,753926,753927,753928,753929,753929,753930,753930,753931,753934,753925,753926,753926,753927,753927,753928,753929,753929,753930,753930,753931,753931,753932,753926,753927,753927,753928,753929,753929,753930,753930,753931,753931,753932,753932,753927,753928,753928,753929,753930,753930,753931,753931,753932,753932,753933,753928,753929,753929,753930,753930,753931,753931,753932,753932,753933,753930,753931,753931,753932,753932,753933,753933,753930,753931,753931,753932,753932,753933,753933,753934,753934,753932,753933,753933,753934,753933,753934,753935,753933,753934,753934,753935,753935,753934,753935,753935,753936,753936,753937,753935,753936,753936,753936,753937,753937,753938,753940,753937,753938,753938,753938,753939,753939,753940,753941,754009,753939,753940,753940,753941,753940,753941,753941,753942,753942,753943,753943,753943,753944,753944,753945,753944,753945,753945,754011,753945,753946,753946,753947,754012,754012,754013,754014,753946,753948,753947,753948,753948,753949,753950,754010,754011,754012,754013,754014,753948,753949,753949,753950,753951,753970,754013,753949,753950,753950,753951,753951,753953,753954,753957,753960,753962,753963,753963,753964,753964,754011,754012,754013,753950,753951,753951,753952,753952,753953,753954,753955,753955,753956,753957,753958,753959,753959,753960,753963,753963,753964,753964,753965,753965,753966,753967,753968,753987,754010,754011,754011,754014,753951,753952,753952,753953,753954,753954,753956,753958,753958,753960,753961,753961,753962,753962,753963,753964,753964,753965,753965,753967,753968,754008,754011,754012,754013,753952,753953,753953,753954,753954,753955,753955,753956,753956,753957,753957,753958,753958,753959,753959,753960,753961,753961,753962,753962,753963,753963,753964,753964,753965,753965,753966,753966,753967,753967,753968,753969,753970,753970,753971,753972,754008,754010,754010,754011,754011,754012,754012,754013,754014,753953,753954,753954,753955,753955,753956,753956,753957,753957,753958,753958,753959,753959,753960,753961,753962,753962,753963,753963,753964,753964,753965,753965,753966,753966,753967,753968,753968,753969,753970,753970,753971,753972,753978,754011,754011,754012,754013,753954,753955,753955,753956,753956,753957,753957,753958,753958,753959,753959,753960,753960,753961,753962,753962,753963,753964,753964,753965,753965,753966,753966,753967,753967,753968,753968,753971,753973,754011,754011,754012,754013,754013,753955,753956,753957,753957,753958,753958,753959,753960,753960,753961,753961,753962,753962,753963,753963,753964,753965,753965,753966,753966,753967,753967,753970,754014,754015,753956,753957,753957,753958,753958,753959,753959,753961,753961,753962,753962,753964,753965,753965,753966,753966,753967,753967,753968,753969,753957,753958,753959,753959,753960,753962,753966,753966,753967,753968,753969,753972,754014,754016,753958,753959,753961,753962,753965,753965,753966,753967,753967,753968,753968,753969,753969,753985,754013,754014,753959,753961,753961,753962,753963,753963,753964,753966,753967,753967,753968,753971,753976,753960,753961,753962,753962,753963,753963,753964,753964,753965,753966,753967,753967,753968,753969,753970,753971,753973,753975,753977,753961,753962,753962,753963,753963,753964,753965,753965,753966,753968,753969,753969,753970,754015,753962,753963,753964,753965,753967,753968,753970,753971,753964,753964,753965,753966,753967,753969,753970,753971,753971,753973,753976,753979,753964,753965,753965,753966,753967,753967,753968,753969,753970,753970,753971,753971,753965,753966,753966,753967,753967,753968,753968,753970,753971,753971,753972,753972,753973,753974,753966,753967,753967,753968,753968,753969,753969,753971,753971,753972,753972,753973,753974,753975,753980,754017,754019,753967,753968,753968,753969,753970,753971,753971,753972,753973,753980,754018,753968,753969,753970,753971,753971,753973,753973,753974,753975,754020,753969,753970,753970,753971,753971,753972,753972,753973,753973,753974,753974,753975,753978,753982,754017,753970,753971,753971,753972,753972,753973,753974,753974,753975,753971,753972,753972,753973,753973,753974,753974,753975,753975,753976,753979,753983,754021,754022,753972,753973,753973,753974,753975,753975,753976,753976,753977,753977,753979,753981,754022,753973,753974,753974,753975,753975,753976,753976,753979,753983,753984,754023,753974,753975,753975,753976,753977,753977,753978,753978,753979,753980,753980,754022,754022,754023,754023,753975,753976,753976,753977,753977,753978,753979,753979,753980,753981,753982,753982,753985,753986,753991,754023,754024,753976,753977,753977,753978,753978,753979,753980,753982,753984,753985,753991,754023,754024,754024,753977,753978,753978,753979,753979,753980,753980,753981,753984,753985,754022,754024,754024,754025,753978,753979,753979,753980,753980,753981,753981,753982,753982,753983,753984,753986,753987,753993,754018,754021,754022,754023,754024,754025,754025,753979,753980,753980,753981,753981,753982,753982,753983,753983,753984,753984,753985,753986,753987,753991,753993,754020,754022,754024,754025,754025,754026,754027,753980,753981,753981,753982,753982,753983,753983,753984,753984,753985,753985,753986,753987,753987,753988,753988,753991,754024,754024,754025,754025,754026,754026,753981,753982,753982,753983,753983,753984,753984,753985,753986,753988,753989,753992,753992,753994,753995,754024,754025,754025,754026,754027,754027,753982,753983,753983,753984,753984,753985,753985,753986,753986,753987,753987,753988,753989,753989,753994,753996,754025,754026,754027,754027,753983,753984,753984,753985,753985,753986,753986,753988,753988,753989,753989,753990,753990,753992,753993,753994,753995,754024,754025,754026,754026,754027,754027,754028,753984,753985,753985,753986,753986,753987,753987,753988,753989,753989,753990,753994,753998,754004,754026,754027,754028,754028,754030,753985,753986,753986,753987,753987,753988,753988,753989,753990,753990,753991,754026,754027,754027,754028,754028,754029,754030,753986,753987,753987,753988,753988,753989,753990,753990,753991,753991,753992,753995,753997,754027,754028,754028,754029,754029,753987,753988,753988,753989,753989,753990,753991,753991,753992,753995,753997,753998,754027,754027,754028,754028,754029,754029,754030,754030,754032,753989,753989,753990,753991,753991,753992,753996,753997,754000,754006,754028,754029,754030,754030,754031,754031,753989,753990,753991,753991,753992,753992,753994,753998,754026,754027,754028,754028,754029,754029,754030,754030,754031,754032,753990,753991,753992,753992,753993,753993,753996,753998,753998,754023,754029,754029,754030,754031,754031,754032,754033,754033,753991,753992,753992,753993,753993,753994,753994,753999,754027,754030,754031,754031,754032,754032,753992,753993,753994,753997,753999,754002,754027,754030,754031,754032,754032,754033,753993,753994,753994,753996,753999,754000,754028,754031,754031,754032,754032,754033,754034,753994,753995,753995,753998,754000,754002,754030,754030,754031,754031,754032,754033,753995,753996,753996,753999,753999,754001,754002,754004,754025,754028,754030,754030,754031,754032,754032,754033,754033,754034,753996,753997,753999,754000,754001,754001,754002,754032,754033,754033,754034,754034,753997,754000,754000,754002,754033,754034,754035,754036,754002,754007,754033,754034,754034,754035,754034,754003,754035,754036,754030,754037,754037,754035,754036,754036,754037,754005,754035,754036,754036,754037,754037,754038,754038,754035,754006,754019,754037,754037,754039,754015,754035,754036,754037,754038,754038,754039,754039,754040,754042,754022,754038,754040,754021,754039,754040,754040,754040,754022,754041,754036,754041,754042,754042,754046,754047,754049,754052,754053,754053,754053,754063,754064,754065,754064,754066,754065,754066,754067,754065,754068,754064,754068,754068,754066,754068,754069,754066,754068,754069,754069,754070,754067,754068,754069,754071,754068,754069,754069,754070,754070,754071,754069,754070,754070,754071,754071,754070,754071,754071,754072,754071,754072,754072,754073,754074,754072,754073,754073,754075,754073,754074,754074,754075,754075,754076,754074,754075,754075,754076,754075,754076,754076,754077,754077,754076,754077,754077,754078,754077,754078,754078,754078,754079,754079,754079,754080,754089,754092,754095,754080,754081,754088,754092,754093,754093,754095,754097,754081,754082,754088,754089,754090,754090,754091,754091,754092,754092,754093,754094,754094,754095,754095,754082,754083,754087,754087,754088,754089,754089,754090,754090,754091,754091,754094,754095,754083,754085,754086,754087,754088,754088,754089,754089,754090,754090,754091,754091,754092,754092,754093,754094,754098,754085,754087,754087,754088,754088,754089,754089,754090,754090,754091,754091,754092,754092,754093,754092,754092,754093,754093,754094,754095,754094,754095,754095,754093,754095,754095,754095,754096,754096,754095,754096,754096,754097,754096,754097,754097,754098,754100,754097,754098,754098,754099,754098,754099,754099,754100,754100,754099,754100,754100,754102,754100,754101,754101,754102,754101,754102,754102,754102,754103,754103,754106,754111,1042550,754103,754104,754104,754106,754104,754105,754105,754105,754106,754106,754107,3031856,754106,754107,754108,2021185,754107,754108,754108,754109,2394349,8002711,754108,754109,754109,754110,754111,754112,1324498,754109,754110,754110,754111,1324498,754110,754111,754112,754115,2124841,754111,754112,754112,754113,1042555,1320137,2021922,754112,754113,754113,754114,754115,754115,754119,754120,1042556,1324500,2394350,2767370,754113,754114,754114,754115,754124,1303634,3415196,754114,754115,754115,754116,754116,754117,754117,754120,754122,754132,754135,1042556,1324501,754115,754116,754116,754117,754117,754118,754118,754119,754119,754120,754121,754121,754122,754123,754125,754126,754128,754128,754136,957055,990838,1042557,1317718,1324501,1549362,1985572,1985573,5232736,8001859,754116,754117,754117,754118,754118,754119,754120,754120,754121,754122,754122,754124,754125,754127,754127,754128,990839,1042557,1295449,1317718,1317720,754117,754118,754118,754119,754119,754120,754120,754121,754121,754123,754124,754126,754131,948033,957056,1042558,1084591,1086293,1197631,1320138,1324502,2230886,2394349,8001860,754118,754119,754119,754120,754120,754121,754121,754122,754123,754124,754124,754126,754127,754128,754129,754131,754137,990839,990840,1042558,1190441,1317721,1320138,1320139,1320140,1324503,2394354,754119,754120,754120,754121,754121,754122,754122,754123,754123,754124,754124,754125,754125,754126,754126,754127,754127,754129,754132,754135,754136,793043,824123,901639,957055,957057,1042558,1042558,1042559,1042576,1320139,1465950,1613865,1985573,754120,754121,754121,754122,754122,754123,754123,754124,754124,754125,754125,754126,754127,754127,754128,754128,754129,754129,754130,754131,973864,990840,1042559,1042559,1042560,1197628,1324504,2021914,754121,754122,754122,754123,754123,754124,754124,754125,754125,754126,754127,754128,754128,754129,754129,754130,754130,754131,754134,754136,957057,990841,1042559,1042559,1042560,1042560,1119522,1317722,1320140,1324504,1324505,754122,754123,754123,754124,754124,754125,754125,754126,754126,754127,754128,754128,754129,754129,754130,754130,754131,754132,754139,990841,1042559,1042560,1042561,1324505,754123,754124,754124,754125,754125,754126,754126,754127,754128,754129,754130,754130,754131,754132,754132,754133,754138,857671,860213,973864,990842,990842,990843,1197629,1197629,1324505,754124,754125,754125,754126,754126,754127,754127,754128,754128,754129,754130,754131,754131,754132,754132,754133,754136,754140,754141,957060,990842,1042561,1042562,1197633,1205241,1320141,1324506,754125,754126,754126,754127,754127,754128,754128,754129,754129,754130,754131,754131,754132,754132,754133,754140,754141,831908,858656,861125,963572,973865,990843,990843,1042563,1042581,1324506,1555487,754126,754127,754127,754128,754128,754129,754130,754130,754131,754131,754133,754133,754135,754140,754140,858656,957060,1042562,1042563,1320142,754127,754128,754128,754129,754129,754130,754130,754131,754133,754133,754135,754136,754137,754140,754141,754141,826522,858657,990844,990846,1042563,1317724,1324507,1479922,754128,754129,754129,754130,754130,754131,754132,754132,754133,754133,754134,754135,754136,754141,754142,754143,759282,858657,957060,990844,990845,1042562,1042564,1070171,1119526,1197632,1317725,1320145,1324508,754129,754130,754130,754131,754131,754132,754133,754134,754135,754136,754142,754142,754143,858659,957062,973869,990845,1190448,1320143,754130,754131,754131,754132,754132,754133,754133,754135,754135,754136,754137,754138,754139,754142,754143,754143,820303,857674,990845,990846,1324509,754131,754132,754132,754133,754133,754134,754135,754135,754136,754140,754143,754143,754144,793049,863496,940522,957063,990846,990846,1042565,1135581,1177033,1599774,754132,754133,754133,754134,754134,754135,754135,754136,754136,754137,754139,754142,754143,754143,754144,754146,793048,917860,957063,973869,990846,990847,1197635,1317727,754133,754134,754134,754135,754135,754136,754137,754137,754138,754143,754144,754144,754145,839573,957065,1042565,1042566,1324510,754134,754135,754135,754136,754136,754137,754137,754138,754140,754144,754144,754145,861129,897345,957064,1324511,754135,754136,754136,754137,754137,754138,754138,754140,754141,754143,754145,754145,754146,754146,926926,948042,990848,1042567,1197635,1317728,1320146,1320148,1324511,1613873,1985581,754136,754137,754137,754138,754138,754139,754140,754140,754141,754145,754146,990848,1042568,1197635,1324512,754137,754138,754138,754139,754139,754141,754144,754146,754146,754147,926925,957066,973873,990849,990849,1042568,1197636,1324512,754138,754139,754139,754140,754140,754141,754141,754144,754146,754147,754147,858662,858664,948044,957065,990849,1042569,1084602,1190452,1320149,1324513,754139,754140,754140,754141,754141,754142,754142,754144,754144,754146,754146,754147,754147,754148,861124,926927,957065,957066,973875,990850,1042568,1042569,1197637,1320149,1324513,754140,754141,754141,754142,754142,754143,754144,754145,754146,754147,754147,754148,754148,857680,858663,926927,957062,957065,957067,957068,990850,990851,1042568,1190451,754141,754142,754142,754143,754143,754144,754145,754146,754148,754148,754149,918156,926927,926929,957069,973875,990851,1042569,1042570,1324514,754142,754143,754143,754144,754146,754148,754148,754149,990851,1320149,1320150,1324515,754143,754144,754149,754149,754150,831917,857682,858665,990852,1324515,754144,754145,754145,754146,754149,754149,754150,754150,1042572,1320151,1324516,754145,754148,754148,754149,754149,754150,754150,1042572,1320151,1320155,1324516,1613879,754146,754147,754148,754150,754150,754151,990853,1320152,1324517,754150,754151,754152,754150,754151,754152,990854,1042573,1197645,754150,754153,973879,990855,1324518,754152,754154,754152,754153,754154,820313,857685,957073,990856,990856,4443447,754153,754153,754154,1197643,2394370,754155,990857,990857,1042576,754154,754155,754155,924680,957074,957075,963589,990857,1042577,1119538,1190330,1190460,1197646,1324521,754155,754156,820315,828162,858670,861140,926936,957075,990858,990858,1042577,1320159,1324521,754156,754157,860230,957075,973884,990858,990859,1042577,1042578,754157,754158,754158,766825,766826,783300,793063,793063,793064,820316,826534,826536,826538,857688,857688,858672,858673,858673,861141,912158,924681,948053,957073,957074,957076,957076,957077,973881,973882,973883,973885,990859,990859,990860,1042576,1042576,1042577,1042577,1042578,1042578,1042579,1190461,1197646,1317739,1320157,1320158,766828,858674,863511,948054,955845,957073,957074,957076,963591,990859,990860,1003530,1034880,1042578,1042579,1479936,990860,1042579,957074,973886,764446,764525,764604,1329751,779509,779510,779510,930938,844607,1055260,812456,1071733,831980,831979,831980,831982,831984,831985,831986,897590,1029776,995995,1081497,1081499,1081499,1081500,1029781,886488,924843,990851,1023247,894140,1033588,898927,898929,898932,898933,898934,1392550,997075,1114972,999333,1063255,930083,902240,908541,909705,909706,1051665,1402304,914781,1054201,925027,1042518,961234,961232,961234,961234,961235,961237,961235,961238,961236,961237,1060620,1077428,1060622,1146124,1423705,964682,1146125,1428070,962223,1428072,963201,963204,963198,963199,963202,963202,963204,963203,963203,963207,963205,963206,963206,963208,1302172,1061604,1095386,1294991,963218,1095389,1061606,1095389,1095390,1061607,1061608,1072248,1061608,1078415,1061608,1061609,1095392,1095393,1147113,966318,966319,1030769,1096947,968131,968133,968137,968139,968140,968141,968282,1149576,1064073,1427156,1097858,1193313,968425,1149735,972877,972880,1066444,1100228,1040568,1467734,1049174,1104589,1070171,1200591,1081612,1090675,1082181,1082272,1082369,1121187,1121190,1095216,1095217,1095218,1095218,1141109,1144420,1161396,1213114,1213115,1099726,1099726,1099729,1099727,1099730,1099729,1099730,1129865,1497313,1490530,1129865,1163651,1215371,1129866,1163652,1129870,1126925,1384038,1141959,1141960,1141960,1142041,1142042,1142042,1142043,1142124,1142125,1184848,1184850,1236566,1236566,1518511,1157548,1244282,1160003,1160003,1160004,1160005,1159992,1160006,1160004,1160006,1159994,1160004,1160007,1160004,1160007,1160008,1159995,1159996,1160008,1160009,1160009,1160009,1193788,1520670,1193789,1245506,1193790,1527453,1160022,1176812,1176814,1176814,1176815,1176816,1176817,1193791,1193792,1193794,1237812,1245511,1245529,1253835,1295649,1393263,1393264,1393394,1400579,1527455,1743560,2433841,1193792,1193792,1173034,1173035,1173036,1173036,1183328,1183331,1200305,1295758,1181286,1181362,1181437,1256222,1186989,1187000,1190309,1193605,1193621,1193621,1193622,1193620,1193622,1193609,1193621,1193622,1193622,1193623,1193621,1193622,1193623,1193623,1193624,1193624,1193625,1193625,1262316,1346824,1193635,1262317,1210598,1210598,1262317,1262318,1515209,1544262,1210599,1210599,1262317,1262317,1262318,1262318,1339280,1539899,1227561,1227562,1227562,1227563,1227564,1227574,1227575,1227575,1227576,1227576,1227577,1227577,1227578,1227562,1227575,1227575,1227576,1227576,1227577,1227577,1227578,1227575,1227576,1227577,1227577,1227578,1227576,1227578,1227577,1227580,1227579,1227581,1227579,1227589,1227589,1227590,1279293,1434361,1227590,1227590,1279293,1427178,1556873,1561238,1227590,1227591,1240243,1279291,1279295,1339086,1427178,1227591,1227592,1227592,1227593,1279294,1279294,1279295,1279295,1356257,1427048,1427179,1434363,1434363,1554456,1554457,1556874,1556875,1561239,1836503,2222309,1227592,1227593,1279294,1279294,1279295,1279295,1279296,1279296,1279311,1279313,1279314,1287618,1323030,1323031,1356257,1356258,1427041,1427179,1434363,1434364,1434366,1532187,1540807,1554456,1554458,1554459,1556874,1556875,1556876,1556877,1561240,2149492,2631087,1227596,1279295,1279295,1279296,1279296,1279297,1279314,1279315,1307010,1356258,1427180,1434364,1554458,1556875,1556876,1556877,1556879,1279296,1554457,1279296,1339090,1356259,1556876,1556877,1556877,1279298,1556879,1252917,1252918,1291966,1291968,1315614,1478381,1598477,1330995,1330996,1330997,1330996,1330997,1330998,1330997,1330998,1330998,1331014,1331014,1331015,1331017,1330998,1330999,1331010,1331013,1331013,1331014,1331014,1331015,1331015,1331016,1331017,1330999,1331014,1331015,1331016,1331016,1331017,1331017,1331030,1331000,1331010,1331014,1331014,1331015,1331015,1331016,1331016,1331017,1331017,1331018,1331018,1331019,1331019,1331020,1331020,1331021,1331021,1331022,1331023,1331025,1331026,1331026,1331030,1331031,1331034,1331013,1331013,1331014,1331014,1331015,1331015,1331016,1331016,1331017,1331017,1331018,1331018,1331019,1331019,1331020,1331020,1331021,1331021,1331022,1331023,1331031,1331025,1606172,1331027,1331028,1331030,1331028,1331031,1331029,1331029,1331030,1331030,1331031,1331033,1478897,1331029,1331030,1331030,1331031,1331032,1331032,1608595,2274029,1331030,1331031,1331031,1331032,1331032,1331033,1331034,1331034,1331035,1331036,1331036,1331038,1331046,1358729,1486082,1486083,1612959,1331031,1331032,1331032,1331033,1331033,1331034,1331034,1331035,1331035,1331036,1331049,1478900,1486083,1486088,1583907,1608594,1608594,1608595,1608596,5097181,1331032,1331033,1331033,1331034,1331034,1331035,1331036,1478899,1493693,1608595,1608597,1612960,1843941,1331033,1331034,1331034,1331035,1331035,1331036,1331036,1331037,1331039,1331039,1331050,1390809,1407978,1478899,1606179,1608595,1608596,1612960,1331034,1331035,1331035,1331036,1331036,1331037,1331037,1331038,1331039,1331042,1486084,1608596,1608599,1612961,2310307,2682811,1331035,1331036,1331036,1331037,1331037,1331038,1331038,1331043,1331048,1331050,1331051,1331051,1608596,1608597,1608597,1612961,1902323,1331036,1331037,1331037,1331038,1331038,1331039,1331039,1331040,1331040,1331041,1331041,1331051,1331052,1404970,1478903,1583909,1608596,1608597,1612962,1331037,1331038,1331038,1331039,1331039,1331040,1331040,1331041,1331041,1331044,1331052,1486086,2274036,1331038,1331039,1331039,1331040,1331040,1331041,1331041,1331042,1331043,1331044,1331049,1331050,1374754,1407981,1407981,1583910,1608597,1608598,1608599,1608600,1612963,1862851,1888227,1331039,1331040,1331040,1331041,1331041,1331044,1331050,1331051,1331052,1339344,1478902,1612963,1331040,1331041,1331041,1331042,1331042,1331043,1331044,1331044,1331045,1331046,1331051,1331053,1374754,1374755,1478903,1486087,1486088,1490547,1528852,1608598,1331041,1331042,1331042,1331043,1331043,1331044,1331044,1331045,1331046,1331047,1331052,1478904,1608597,1608600,1608600,1608601,1867813,2177040,1331042,1331043,1331043,1331044,1331044,1331046,1331047,1331048,1331049,1331049,1331050,1331052,1331054,1358625,1407983,1486088,1487827,1608599,1608602,1331043,1331044,1331044,1331045,1331046,1331047,1331048,1331048,1331051,1331055,1358735,1486089,1608600,1608601,1331044,1331045,1331045,1331046,1331046,1331047,1331048,1331049,1331051,1331052,1331053,1486089,1608600,1608601,1608601,1608603,1862853,2274037,1331045,1331046,1331046,1331047,1331047,1331048,1331048,1331049,1331051,1331052,1407984,1407984,1478904,1478906,1583914,1608601,1608602,1612966,1331046,1331047,1331047,1331048,1331048,1331049,1331051,1331052,1331052,1331053,1331054,1374756,1478773,1486090,1862854,1331047,1331048,1331048,1331049,1331049,1331050,1331051,1331053,1331055,1478776,1608602,1608604,1612967,1331048,1331049,1331049,1331050,1331050,1331051,1331053,1331054,1331055,1384265,1583915,1331049,1331050,1331051,1331051,1331052,1331054,1331056,1331056,1373057,1407987,1478908,1608603,1608604,1612968,1331050,1331051,1331051,1331052,1331052,1331054,1331055,1331056,1331056,1612969,2274039,1331051,1331052,1331052,1331053,1331054,1331055,1331057,1358631,1358633,1478908,1596891,1605205,1608606,1612969,1331052,1331053,1331053,1331054,1331054,1331055,1331056,1331056,1331057,1612970,2274041,2682820,1331054,1331054,1331055,1331056,1331057,1331058,1407988,1478910,1608605,1608606,1331054,1331056,1331056,1331057,1374764,1583918,1612971,1331056,1331056,1331057,1331057,1331058,1374760,1478911,1331057,1331057,1331058,1331059,1331057,1331058,1331059,1331059,1339355,1331058,1331059,1331060,1331060,1339357,1407991,1486097,1606189,1608609,2274045,1331059,1331060,1331061,1331063,1390823,1407991,1606190,1608608,1331060,1331061,1331061,1331063,1478913,1606257,1608608,1829082,1331061,1331062,1331064,1407993,1486098,1486099,1486153,1612974,1331062,1331064,1339355,1358743,1374764,1407991,1407993,1407993,1478914,1478915,1486098,1486099,1486100,1493708,1606191,1608609,1608610,1608610,1608613,1612975,1768388,1768389,2274043,1331064,1331065,1339355,1358745,1358745,1360890,1374766,1390825,1407993,1478916,1486099,1486099,1583923,1608610,1608610,1608611,1608611,1612975,1486099,1608612,1612976,1331067,1612977,1381171,1407995,1407995,1478786,1486102,1583925,1608612,1608612,1608614,1612977,2177053,1478919,1486102,1583925,1608615,1612978,2682825,1347661,1347663,1347661,1347662,1347670,1347671,1616915,1416299,1487222,1616918,1616919,1616921,1621288,1386219,1386223,1386225,1386226,1386329,1386332,1386333,1386439,1386440,1386440,1386441,1386441,1386439,1386442,1636304,1506610,1411969,1506480,1506610,1513794,1633888,1636303,1636309,10757309,1390732,1515941,1415077,1650622,1650624,1650625,1418481,1418477,1418480,1418482,1418482,1418481,1418482,1418485,1418481,1418482,1418483,1418485,1418564,1537423,1652325,1451709,1522630,1529815,1529815,1529816,1649909,1652328,1946056,1529816,1529817,1529818,1418649,1652409,1431287,1431288,1536217,1634040,1663094,1437497,1437501,1539323,1666203,1450597,1450598,1450598,1450599,1538688,1467767,1467767,1668384,1672749,1478919,1682547,1484934,1484923,1484924,1484936,1484938,1484938,1484939,1484941,1484924,1484925,1484935,1484936,1484939,1484939,1484940,1484940,1484941,1484940,1484941,1685553,1685554,1484950,1555858,1563043,1660864,1683137,1685553,1689918,1979280,1607274,1685554,1555858,1563044,1563045,1484954,1570654,1685557,1689921,1484957,1555730,1563045,1563045,1660775,1660869,1685556,1685557,1484960,1563045,1689922,1563046,1683141,1555732,1555863,1555735,1500026,1578195,1517070,1861412,1599952,1747428,1626501,1626511,1626514,1626515,1626515,1626516,1626644,1626648,1626647,1626647,1626650,1626651,1626649,1626650,1626650,1626651,1626652,1626779,1626780,1626765,1626768,1626781,1626766,1626781,1626782,1626782,1626782,1626783,1626782,1626783,1626784,1626783,1626784,1626784,1626786,1626786,1626786,1626786,1626786,1626787,1633965,1756479,1626799,1633966,1633966,1633967,1633969,1641574,1731790,1754060,1756477,1756478,1756478,1756479,1756480,1760842,1916255,2036106,1633966,1633968,1756477,1916256,2421913,2421914,1633966,1756479,1641134,1641135,1641135,1641136,1641136,1641137,1641148,1641149,1641150,1641150,1641151,1641151,1641152,1641152,1641136,1641145,1641148,1641150,1641151,1641151,1641152,1641152,1641154,1641149,1641149,1641151,1641152,1641152,1641150,1641151,1641152,1641153,1641153,1641139,1641140,1641152,1641154,1641150,1641152,1641155,1641152,1641153,1641153,1641160,1641154,1641160,1641163,1641163,1641203,1641163,1641164,1641165,1641166,1641203,1641204,1641165,1641204,1641165,1641205,1763661,1763662,2429100,1641166,1641167,1641205,1641205,1648759,1738974,1747593,1751948,1761243,1761244,1763660,1763661,1763662,1763662,1763663,1763663,1763664,1763664,1768027,1992888,2429098,1641167,1681242,1761244,1763662,1763662,1763663,1763663,1763665,1768027,2057389,1641207,1761244,1763663,1763664,1763665,1763665,1768028,1738976,1761245,1763663,1763663,1763664,1763665,1763666,1768028,1641207,1763665,1768029,1763665,2837882,1641254,1641254,1641255,1641256,1648808,1739024,1739025,1761292,1761293,1763709,1763710,1763711,1763711,1763713,1768076,1992937,1739024,1763711,1768077,1644625,1765397,1650065,1765700,1656362,1656363,1656364,1656353,1656366,1656368,1656374,1656657,1656657,1656658,1656381,1656661,1771268,1771269,1775633,1775635,1656949,1656951,1656951,1656953,1656960,1771559,1771560,1771560,1771561,2000786,1721329,1803752,1726677,1806423,1729611,1807892,1836610,1844891,1836792,1836795,1836797,1836797,1836798,1836800,1836799,1836797,1859066,1865848,1861484,1861485,1861485,1861487,1861487,1865850,1859067,1861485,1861486,1861488,1865850,1861487,1865853,1853170,1853172,2780420,1869672,1854033,1854034,1870102,1870103,1862742,1862743,1874455,1874456,1879372,1882774,1881322,1881330,1881331,1881331,1881332,1881333,1881334,1881323,1881331,1881332,1881332,1881333,1881331,1881332,1881333,1881333,1881334,1881334,1881334,1881335,1881337,1881344,1881398,1881400,1881399,1881401,1881402,1881343,1881399,1881401,1881401,1881402,1881403,1881400,1881400,1881402,1881402,1881404,1881401,1881402,1881403,1881404,1881404,1883755,1888117,1881405,1881465,1881466,1881466,1881470,1881470,1881472,1881473,1883816,1883817,1883818,1883818,1883819,1883819,1883820,1883822,1888181,1888182,1883818,1883819,1883819,1883820,1883821,1883821,1888184,2029627,1883819,1883820,1883820,1883821,1883822,1886156,1886169,1886155,1886156,1886157,1886158,1886158,1886159,1886159,1886160,1886172,1886172,1886173,1886173,1886174,1886174,1886175,1886175,1886176,1886158,1886159,1886159,1886160,1886160,1886161,1886171,1886172,1886173,1886173,1886174,1886174,1886175,1886176,1886159,1886160,1886160,1886161,1886161,1886163,1886163,1886172,1886173,1886174,1886174,1886175,1886175,1886176,1886176,1886177,1886160,1886161,1886161,1886162,1886173,1886174,1886175,1886175,1886176,1886176,1886177,1886177,1886161,1886162,1886162,1886174,1886176,1886176,1886177,1886177,1886178,1886162,1886163,1886163,1886175,1886176,1886176,1886177,1886177,1886178,1886178,1886163,1886165,1886175,1886176,1886176,1886177,1886178,1886178,1886179,1886180,1886175,1886176,1886177,1886178,1886178,1886179,1886179,1886176,1886181,1886181,1886179,1886178,1886178,1886179,1886180,1886181,1886188,1886187,1886188,1890537,1886187,1886188,1886189,1886188,1886189,1886189,1886190,1886190,1886191,1890538,2551607,1886189,1886190,1886190,1886191,1886191,1886192,1890538,2121519,2121520,2551610,1886190,1886191,1886191,1886192,1886194,1890539,2045952,2145388,2551611,1886191,1886192,1886192,1886193,1890539,2145388,2179901,2179902,2551613,1886192,1886193,1886193,1886194,1886195,1890540,1890540,2045953,2106791,2106792,2115401,2121522,2179903,2551608,2551609,2551612,2551614,2796924,1886193,1886194,1886195,1890540,1890541,2045953,2045954,2045955,2179902,1886194,1886196,1890541,2106649,2121522,2145390,2179903,2179905,2551610,2551611,2551611,2551612,2796925,1890541,1890542,2045954,2121523,2551611,2551613,2551615,1890542,2551617,1890542,1890543,2045956,2045956,1890543,1894887,1894888,1894889,1894889,1894890,1894890,1894897,1894898,1894898,1894899,1894899,1894900,1894898,1894898,1894899,1894900,1894898,1894899,1894900,1894899,1894899,1894900,1894907,1894908,1894908,1894909,1894909,1894911,1894913,1894977,1894977,1894978,1894978,1894908,1894909,1894909,1894978,1894978,1894979,1894979,1894980,1894909,1894910,1894912,1894979,1894979,1894980,1894910,1894979,1894979,1894980,1894980,1894981,1894981,1894911,1894979,1894979,1894980,1894980,1894981,1894981,1894982,2555969,1894980,1894981,1894981,1894982,1894981,1894982,1894984,1895048,1895048,1895048,1895049,1895050,1895060,1895049,1895050,1895050,1895051,1895059,1895060,1895050,1895051,1895051,1895059,1895060,1895060,1895061,1895051,1895052,1895054,1895060,1895060,1895061,1895061,1895052,1895061,1895061,1895062,1895061,1895062,1895062,1895064,1895069,1895070,1895070,1895071,2111227,2125961,2556048,3431922,1895071,2050392,2050393,2050524,2101191,2111088,2119840,2125961,2125961,2184342,2184344,2556049,2556050,2556051,2964830,1895076,1925294,1954709,1954710,1954713,1954715,1974555,2036423,2036424,2036426,2050393,2050393,2050394,2050394,2050395,2056736,2091275,2091275,2091277,2101191,2111085,2111085,2111088,2111090,2111230,2111231,2111232,2111232,2111234,2119839,2119840,2119841,2125960,2125960,2125961,2125961,2125962,2133583,2144867,2149829,2170244,2170244,2170245,2170245,2170247,2170248,2184341,2184342,2184342,2184343,2184343,2184344,2184345,2206993,2278278,2344460,2381614,2402523,2424130,2459051,2459052,2459053,2476779,2483230,2483231,2530035,2556048,2556049,2556050,2556050,2556051,2556051,2556052,2556052,2556053,2556053,2556054,2556054,2556055,2592385,2592400,2595404,2801364,2801365,2829627,2958944,2964827,2964829,2964834,5803212,2050400,1955526,1955631,1955735,2080730,2014362,2014363,2014367,2014369,2110046,2170741,2243995,2076150,2054087,2129925,2137931,2222626,2177778,2177790,2177791,2177793,2177793,2191760,2522979,2191760,2522981,3106194,3106195,2205714,2205715,2205723,2205724,2205724,2205725,2205725,2205726,2205726,2205727,2205728,2205715,2205716,2205724,2205724,2205725,2205725,2205726,2205726,2205727,2205727,2205724,2205725,2205725,2205726,2205726,2205727,2205727,2205728,2205728,2205725,2205726,2205727,2205729,2205728,2205729,2205730,2205730,2205733,2205734,2205735,2205857,2205857,2205858,2205734,2205735,2205735,2205737,2205857,2205857,2205858,2205858,2205860,2205735,2205736,2205737,2205857,2205858,2205858,2205859,2205860,2205736,2205737,2205738,2205856,2205857,2205858,2205858,2205859,2205859,2205860,2205860,2205861,2205862,2711382,2205737,2205738,2205738,2205856,2205857,2205857,2205858,2205858,2205859,2205859,2205860,2205861,2205861,2205862,2205859,2205859,2205860,2205861,2205861,2205863,2339675,2205857,2205859,2205859,2205860,2205861,2205861,2205859,2205859,2205860,2205861,2205862,2205863,2205863,2205859,2205861,2281296,2205862,2205861,2205988,2205989,2205990,2205991,2205979,2205991,2205991,2205979,2205980,2205991,2205992,2205980,2205981,2205981,2205991,2205991,2205992,2205992,2205981,2205991,2205992,2205993,2205993,2205982,2205983,2205983,2205984,2205991,2205992,2205992,2205993,2205993,2205992,2205993,2205994,2205984,2205993,2205994,2205994,2205985,2205994,2205994,2205995,2205993,2205995,2205995,2205999,2205997,2205998,2206002,2281426,2206003,2206003,2266550,2266553,2711516,2206004,2256250,2266554,2275306,2281426,2325709,2339807,2339808,2339809,2956829,2206004,2266554,2266555,2266697,2266699,2281427,2281428,2300333,2339808,2339809,2339809,2685501,2711514,2711517,2256249,2266552,2266555,2266557,2266697,2266697,2266698,2266700,2266700,2275307,2275307,2281426,2281427,2281428,2281428,2289049,2305295,2325708,2325709,2325711,2325712,2339808,2339808,2339809,2339810,2339812,2421491,2537080,2538721,2638697,2685502,2711516,2711516,2711517,2711517,2711518,2711518,2711522,2971952,3120296,2711517,2711517,2233785,2256659,2281430,2325715,2711519,2325714,2325715,2218420,2287646,2261573,2261683,2261793,2294454,2287492,2287491,2287494,2322177,2322179,2752266,2306509,2306512,2316814,2761779,2307326,2307326,2317365,2317366,2332096,2390477,2332096,2327110,2327102,2327111,2327111,2327112,2327112,2327113,2327113,2327114,2327115,2327115,2327116,2327117,2327117,2327119,2327118,2327117,2327119,2327255,2327257,2327124,2327125,2327125,2327126,2327256,2327256,2327257,2327259,2327260,2327262,2327126,2327127,2327257,2327258,2327259,2327259,2327260,2327260,2327261,2327259,2327261,2327261,2327128,2327129,2327257,2327258,2327259,2327260,2327260,2327262,2327259,2327262,2327129,2327260,2327261,2327261,2327262,2327262,2327263,2327259,2327261,2327261,2327263,2327264,2327263,2327399,2327393,2327401,2327401,2327390,2327392,2327400,2327401,2327403,2327400,2327401,2327402,2327404,2327403,2327392,2327393,2327394,2327395,2327402,2327403,2327403,2327405,2327394,2327395,2327396,2327402,2327404,2327405,2327395,2327403,2327404,2327405,2327406,2327396,2327405,2327406,2327396,2327397,2327407,2327398,2327404,2327405,2327406,2327407,2327408,2327406,2327408,2327406,2327408,2327410,2342131,2365998,2327415,2386414,2400513,2327413,2342131,2386416,2327416,2336012,2342132,2342132,2386414,2400513,2699401,2772221,2327416,2336012,2342132,2342133,2366000,2386417,2400513,2482194,2494449,2597784,2691561,2692950,2699402,2772221,2772221,2772224,2772225,2342134,2327418,2336013,2336014,2342132,2342133,2342133,2342134,2342134,2342135,2342135,2349756,2366002,2366003,2386417,2386417,2386418,2400515,2400515,2400517,2400520,2675227,2699403,2699404,2746208,2772223,2772223,2772224,2772224,2772225,2772226,2772227,2342133,2342134,2361041,2342144,2344608,2344617,2344619,2344619,2344618,2344619,2344619,2344621,2344621,2344610,2344619,2344620,2344620,2344621,2344620,2344699,2344700,2344630,2344631,2344699,2344700,2344700,2344701,2344701,2344702,2344700,2344700,2344701,2344702,2344700,2344701,2344703,2344701,2344701,2344702,2344701,2344701,2344702,2344780,2344771,2344780,2344782,2344781,2344781,2344782,2344783,2344783,2344782,2344784,2344784,2344785,2344792,2350820,2350820,2350821,2395104,2395104,2409201,2409201,2683915,2754895,2780909,2780910,2780911,2780912,3026223,2350822,2780909,2350823,2374690,2708091,2780910,2780912,3026225,3189688,3562711,2350823,3189690,2356848,2356848,2356862,2356863,2356867,2356873,2356850,2356864,2356864,2356865,2356865,2356866,2356866,2356867,2356869,2356850,2356851,2356862,2356863,2356865,2356865,2356866,2356867,2356867,2356868,2356869,2356874,2356874,2356851,2356866,2356866,2356867,2356868,2356868,2356871,2356852,2356863,2356865,2356866,2356867,2356867,2356868,2356868,2356869,2356869,2356870,2356871,2356872,2356874,2356875,2356867,2356869,2356886,2356880,2401147,2356879,2786953,2786953,2356880,2401142,2533802,2786955,2401153,2415246,2437897,2760939,2786955,2356881,2356882,2356883,2364487,2375772,2401150,2401150,2496927,2761014,2786954,2356883,2356884,2356885,2356886,2401151,2415246,2415247,2415247,2415252,2437898,2515902,2612519,2714135,2714136,2786955,2786955,2786956,2786956,2786957,2786958,2356884,2356884,2356885,2356886,2356888,2380734,2415247,2415248,2689961,2714136,2714136,2760941,2786955,2786956,2786958,2786959,2822570,3032269,2356887,2356891,2415247,2415248,2415249,2415249,2415250,2496934,2714136,2714137,2786955,2786956,2786956,2786957,2786958,2786960,2356885,2356886,2356887,2380735,2401151,2415248,2415249,2786955,2786956,2786957,2786957,2786960,2356896,2401153,2415249,2415249,2509185,2612520,2786956,2786957,2786958,2415250,2415252,2612520,2786957,2786958,3021052,2786958,2401152,2415250,2415251,2415253,2786958,2786958,2786959,3195737,2401154,2474525,2509187,2415252,2786959,2786960,2786962,2786961,2401157,2786962,2786964,2380742,2786965,2375784,2786968,2372107,2372108,2372108,2372109,2721757,2768635,2422868,2721757,2394675,2394675,2394676,2394676,2434149,2779843,2805857,2805858,2805861,2399637,2434150,2733039,2805858,2404598,2404598,2404599,2404600,2404599,2520797,2425014,2425015,2439111,2439113,2533047,2810820,2810822,2810824,2439111,2439112,2556242,2636383,2636384,2738001,2810819,2810820,2810821,2810823,2445423,2445426,2445431,2445432,2445431,2445432,2445432,2445433,2445433,2445432,2445433,2445433,2445433,2445434,2445434,2445434,2445420,2445435,2445435,2445435,2445435,2445436,2445436,2656797,2459526,2445559,2831237,2459529,2459530,2459531,2482181,2518804,2541211,2728315,2768214,2805223,2831238,2831239,2831241,2459529,2459531,2459531,2459533,2459533,2734244,2758419,2768214,2831239,2831240,2831242,2459530,2459531,2459532,2758414,2831237,2831238,2831239,2831239,2831240,2831240,2831243,3221950,2831239,2445683,2459652,2473626,2473612,2473612,2473626,2473627,2473627,2473628,2473628,2473629,2473612,2473613,2473613,2473614,2473627,2473627,2473628,2473629,2473614,2473615,2473628,2473628,2473629,2473629,2473630,2473628,2473629,2473629,2473630,2473615,2473628,2473629,2473630,2473630,2473633,2473617,2473629,2473630,2473631,2473631,2473630,2473630,2473632,2473633,2473630,2473633,2473634,2473633,2473634,2473635,2473643,2551678,2845334,2845335,2845336,2473643,2473644,2473644,2473646,2555313,2567563,2670899,2748340,2772512,2772516,2830991,2845335,2845335,2845336,2845336,2845337,2845337,2845338,2845338,2845339,2845340,2845341,3090650,3090652,3236045,3254115,3254115,2473644,2473645,2567564,2691809,2705039,2748341,2772517,2845334,2845335,2845335,2845336,2845336,2845338,2845338,2473645,2614949,2670899,2748340,2819322,2845334,2845336,2845336,2845337,2845338,2845338,2845341,3090650,3090651,3254116,2496280,2748342,2772517,2845336,2845337,2845340,2845340,2845341,2772518,2772518,2845337,2845337,2845338,2845338,2845339,2845337,2819324,2761995,2845340,2845340,2615470,2518923,2518924,2519045,2519046,2519046,2519168,2519169,2736586,2795284,2842089,2868105,2592174,2592174,2731812,2904608,2629730,2923386,2636989,2636990,2636992,2636999,2636999,2927018,2854197,2927016,2927018,2927020,2927021,2661496,2661497,2661497,2661498,2661499,2913329,2939275,2939269,2939269,2939270,2939270,2939271,2939273,2674936,2873170,2707882,2707906,2707930,2962483,2710745,2963897,2756265,2986653,2757303,2987173,2793859,2793932,2794004,3005520,2868163,2868167,2868167,2868168,2868168,2868168,2868168,2868169,2868169,2868243,2969785,3042603,2969785,3042605,3042606,3042604,3042605,3042606,3042608,3042605,2868323,3042681,2871446,2871447,2871547,2871548,2871647,2944096,3044343,2910037,2966569,3063564,2936447,3076747,2953203,3085122,2954009,3085524,3011194,3114115,3016550,3116795,3023046,3023047,3023049,3023051,3023050,3023050,3023051,3047226,3120046,3047226,3120044,3120045,3120045,3120046,3120046,3120048,3050355,3133699,3055752,3136412,3058498,3058501,3137769,3137772,3071394,3071394,3071389,3071401,3071402,3071402,3071404,3071401,3071402,3071402,3071403,3071404,3071404,3144217,3144218,3071414,3144221,3144224,3071414,3144220,3144223,3071415,3118207,3118281,3144221,3144221,3144222,3144222,3144223,3144223,3144224,3144225,3144226,3553002,3144221,3144222,3144223,3144226,3144222,3144223,3090995,3154019,3154020,3165008,3165011,3165083,3165083,3165084,3165084,3165085,3165085,3165159,3165160,3165160,3165161,3165161,3165162,3165163,3191099,3191099,3191100,3191100,3191101,3191101,3191102,3191103,3191105,3191107,3191101,3191101,3188352,3202696,3217025,3217026,3217028,3217025,3217026,3217027,3217028,3217026,3217027,3217027,3217028,3217027,3217028,3217028,3217029,3217029,3217030,3217030,3217031,3217031,3217032,3217046,3217028,3217029,3217029,3217030,3217030,3217031,3217031,3217032,3217032,3217033,3217035,3217029,3217030,3217030,3217031,3217031,3217032,3217032,3217033,3217033,3217035,3217046,3217047,3217048,3217030,3217031,3217031,3217032,3217032,3217033,3217033,3217034,3217034,3217036,3217046,3217047,3217047,3217048,3217048,3217031,3217032,3217032,3217033,3217033,3217034,3217034,3217035,3217037,3217047,3217047,3217048,3217048,3217032,3217033,3217033,3217034,3217034,3217035,3217035,3217036,3217037,3217047,3217048,3217048,3217049,3217049,3217033,3217034,3217034,3217035,3217035,3217037,3217044,3217048,3217048,3217049,3217049,3217050,3217034,3217035,3217035,3217036,3217037,3217038,3217046,3217048,3217048,3217049,3217049,3217050,3217050,3217051,3217051,3217035,3217036,3217036,3217037,3217037,3217038,3217038,3217039,3217039,3217047,3217049,3217049,3217050,3217050,3217051,3217051,3217036,3217037,3217037,3217038,3217038,3217039,3217039,3217040,3217040,3217041,3217049,3217050,3217050,3217051,3217051,3217037,3217038,3217038,3217039,3217039,3217040,3217040,3217041,3217043,3217044,3217047,3217048,3217049,3217049,3217050,3217050,3217051,3217051,3217052,3217052,3217038,3217039,3217040,3217041,3217042,3217043,3217047,3217049,3217050,3217050,3217051,3217051,3217052,3217052,3217053,3217039,3217040,3217041,3217049,3217050,3217051,3217051,3217052,3217052,3217054,3217041,3217041,3217042,3217046,3217050,3217051,3217052,3217052,3217053,3217042,3217050,3217051,3217052,3217052,3217053,3217053,3217054,3217052,3217052,3217053,3217053,3217054,3217044,3217052,3217053,3217053,3217054,3217054,3217055,3217044,3217052,3217054,3217054,3217055,3217055,3217054,3217054,3217055,3217055,3217053,3217057,3217058,3217056,3217058,3217060,3217060,3217061,3217061,3217061,3217062,3217063,3217196,3217196,3217062,3217063,3217064,3217062,3217063,3217063,3217064,3217197,3217063,3217064,3217064,3217065,3217197,3612695,3217064,3217065,3217065,3217066,3253321,3356318,3462360,3462361,3462362,3625825,3625826,3625829,3217065,3217066,3217066,3217067,3217067,3217198,3253319,3253352,3256403,3256408,3276467,3286701,3286835,3300608,3462360,3462361,3462361,3462362,3545889,3545889,3545891,3625823,3625824,3625826,3217066,3217067,3217067,3217068,3217197,3217198,3217199,3252661,3252665,3252665,3252670,3256371,3286836,3327910,3356319,3428678,3456614,3456614,3462361,3462361,3462362,3462362,3462363,3462363,3497435,3545890,3625824,3625825,3625826,3625826,3625827,3625828,3625831,3942143,3217067,3217068,3217068,3217141,3217197,3217198,3217198,3217199,3217199,3217200,3217201,3217201,3217596,3233895,3252661,3252665,3252666,3252667,3252668,3252672,3253321,3253322,3253322,3253323,3253326,3253327,3253329,3253332,3253344,3253378,3253379,3253383,3253385,3253388,3253388,3253398,3256371,3256371,3256380,3256381,3256390,3256390,3256404,3256408,3256409,3256457,3286699,3286702,3286833,3300610,3301357,3356316,3356319,3387358,3397181,3456614,3456615,3460878,3462361,3462362,3462362,3462363,3462363,3462364,3477483,3497438,3545890,3545893,3592367,3625824,3625825,3625825,3625826,3625826,3625827,3625828,3625828,3625829,3625830,4646672,3217068,3217069,3217142,3217199,3217200,3217200,3217201,3233893,3233894,3240935,3252665,3252666,3252669,3252672,3252673,3253322,3253323,3253324,3253324,3253325,3253327,3253328,3253333,3253334,3253335,3253340,3253350,3253355,3253380,3253391,3256376,3256409,3256410,3256419,3256443,3256447,3256874,3286702,3286838,3315401,3356319,3356320,3387358,3456617,3462362,3462362,3462363,3462363,3462364,3490625,3497440,3545890,3582728,3625825,3625825,3625826,3625826,3625827,3625828,3217069,3217071,3217199,3217200,3217200,3217201,3217201,3252670,3252673,3253322,3253323,3253328,3253340,3256383,3256392,3256409,3256409,3256447,3256475,3258651,3462362,3462363,3462363,3462364,3462365,3545891,3625826,3217201,3217201,3253385,3253389,3256421,3286839,3462363,3462363,3545892,3625829,3462365,3217225,3462445,3217338,3217339,3217340,3217340,3217331,3217339,3217340,3217341,3217331,3217333,3217340,3217332,3217334,3217341,3217341,3217342,3217342,3217342,3217344,3217345,3217343,3217345,3217346,3217344,3462503,3387499,3625967,3217351,3217352,3234032,3462503,3546031,3217351,3253466,3462503,3592509,3217354,3252808,3253464,3253465,3253466,3253475,3256523,3256537,3256551,3286842,3286974,3286976,3286979,3356462,3462504,3462504,3462505,3462506,3497579,3582870,3607899,3625967,3625968,3625969,3625970,3625971,3252807,3256513,3462506,3625968,3625970,3252816,3462506,3625972,3218138,3256913,3250730,3250731,3250734,3250738,3269511,3479201,3270223,3479204,3264818,3486244,3288256,3288271,3288272,3288276,3288277,3288280,3288270,3288282,3288283,3288285,3288265,3288268,3288283,3288287,3288285,3288285,3288287,3288289,3288283,3288292,3288289,3288292,3288292,3288284,3288293,3288294,3288294,3288295,3288290,3661435,3288296,3497974,3288301,3288937,3497976,3497977,3288303,3292025,3288304,3289006,3292069,3288306,3661442,3497981,3291341,3661443,3288943,3288946,3288954,3497981,3288947,3292064,3497982,3497983,3294272,3548595,3289589,3289580,3289591,3289596,3289596,3289608,3289626,3289588,3289593,3289596,3289601,3289607,3289594,3289597,3289598,3289599,3289597,3289604,3289597,3289600,3289609,3289598,3289606,3289601,3289602,3289613,3289616,3289610,3289611,3289614,3289592,3289611,3289610,3289620,3289609,3289614,3289621,3289621,3289622,3289638,3289623,3289621,3289654,3289669,3662097,3289629,3289631,3498636,3498635,3498636,3289632,3498635,3289636,3498636,3292646,3498636,3498637,3644034,3294923,3498639,3289632,3662101,3289636,3289668,3289635,3289632,3498642,3662106,3292653,3289675,3662109,3289666,3662109,3498648,3292695,3289646,3289669,3289665,3289683,3662114,3289663,3292707,3498651,3292675,3479659,3498650,3662118,3582182,3292671,3323128,3289666,3498652,3446080,3498656,3289671,3289684,3498666,3498669,3498669,3292718,3289716,3498673,3289706,3289719,3289724,3289719,3289704,3289719,3289722,3289718,3289718,3289724,3289724,3289717,3289718,3289724,3289719,3289723,3289734,3289728,3289731,3498690,3498688,3289730,3289740,3289732,3289733,3289746,3289750,3289747,3289753,3289745,3498696,3289755,3292743,3294982,3478568,3498697,3662165,3498698,3662160,3498700,3498702,3498701,3498702,3292711,3296830,3498702,3498705,3662168,3392662,3292716,3498710,3292726,3292804,3662177,3662178,3294390,3501029,3295693,3295684,3295689,3295691,3295693,3295697,3295698,3295702,3295697,3295694,3295704,3295705,3295698,3295712,3295717,3295713,3295714,3295715,3295713,3295728,3295724,3501682,3501684,3295728,3295731,3295750,3295733,3501689,3501688,3501688,3295737,3295739,3501689,3585218,3501690,3501692,3295740,3501696,3481565,3495948,3295797,3501698,3295774,3501698,3295765,3501700,3295764,3665165,3295765,3295765,3295766,3295770,3295768,3295769,3295770,3295804,3295772,3395662,3295773,3295769,3501706,3295786,3295789,3295790,3360230,3436538,3482727,3501718,3501718,3501719,3536793,3665180,3665183,3326195,3501718,3295805,3647115,3501721,3665183,3501722,3574654,3501722,3298011,3501723,3295798,3501724,3501728,3295824,3501732,3501732,3297465,3295840,3295841,3295849,3295856,3295847,3295854,3395710,3295868,3426753,3501757,3501759,3665222,3501764,3298047,3501764,3295898,3501771,3501772,3501785,3296691,3502179,3299136,3438224,3300238,3300244,3300243,3300251,3300249,3300250,3667418,3503958,3503959,3451388,3503961,3667426,3303923,3505795,3335878,3335896,3335916,3685254,3356340,3356341,3356342,3356346,3356347,3356479,3356480,3356480,3356482,3356483,3356603,3356614,3356616,3356617,3356619,3356619,3356620,3422747,3532142,3532143,3532143,3581042,3695608,3532143,3426101,3532144,3532144,3384163,3384164,3470912,3545916,3385660,3527670,3413753,3560713,3424693,3566181,3438765,3573216,3488877,3512383,3495582,3495583,3495584,3495584,3495585,3495586,3601626,3685155,3601626,3601627,3601627,3601628,3601629,3765090,4339793,3535889,3550525,3557661,3557662,3632665,3632666,3796128,3565160,3664677,3577305,3577308,3577309,3577348,3642488,3642489,3577393,3642533,3602523,3602524,3655096,3655097,3640302,3837447,3667413,3667414,3687542,3687542,3669679,3669686,3669685,3846253,3669824,3688677,3669961,3688813,3685233,3696453,3696177,3696178,3696178,3696178,3696179,3696180,3701924,3865387,3701925,3865388,3865388,3704699,3706183,3707655,3707657,3707656,3707657,3707657,3707658,3707658,3707659,3707659,3707660,3707671,3707671,3707672,3707672,3707673,3707673,3707674,3707657,3707658,3707658,3707659,3707671,3707672,3707672,3707673,3707673,3707674,3707658,3707659,3707659,3707660,3707661,3707672,3707672,3707673,3707673,3707674,3707659,3707660,3707660,3707672,3707672,3707673,3707673,3707674,3707674,3707675,3707660,3707661,3707673,3707673,3707674,3707674,3707675,3707675,3707661,3707662,3707673,3707673,3707674,3707674,3707675,3707675,3707676,3707676,3707674,3707674,3707675,3707675,3707676,3707674,3707675,3707675,3707676,3707676,3707686,3707686,3707686,3707687,3707687,3707688,3707688,3707689,3723897,3742748,3790067,3791199,3791200,3791200,3791201,3791202,3825878,3871133,3871134,3871134,3871135,3871135,3871136,3871136,3871137,3707687,3707688,3707688,3707689,3707690,3723373,3735935,3791200,3791201,3791202,3828036,3837676,3837677,3845358,3853064,3853066,3858005,3859355,3871134,3871134,3871135,3871135,3871136,3871136,3871137,3871137,3871138,3707688,3707689,3707689,3707690,3723898,3742748,3791201,3791202,3791203,3791203,3828038,3837677,3853071,3865251,3871134,3871134,3871135,3871135,3871136,3871136,3871137,3871137,3707689,3707690,3707690,3707691,3723266,3723899,3735936,3742745,3742747,3742748,3742750,3758281,3791201,3791201,3791203,3791204,3837677,3853066,3853071,3871135,3871136,3871136,3871137,3871137,3871138,3871138,3871139,3707690,3707691,3707693,3720193,3722794,3723267,3735936,3742748,3742748,3742749,3742749,3742750,3761820,3791201,3791202,3791202,3791203,3791203,3791204,3791204,3825917,3828040,3837678,3853069,3858008,3869447,3871135,3871136,3871136,3871137,3871137,3871138,3871138,3871139,3871140,3707691,3742748,3742748,3742749,3791201,3791202,3791202,3791203,3791203,3791204,3828040,3828040,3837678,3853066,3853067,3853073,3865253,3871136,3871136,3871137,3871137,3871138,3871138,3871139,3871139,3871141,3837679,3853070,3871137,3871138,3871138,3871139,3791204,3871137,3871138,3853075,3732710,3883653,3737910,3806318,3806320,3868188,3738853,3738901,3738964,3738949,3886770,3739072,3739075,3806899,3853375,3740121,3807423,3869291,3887357,3887359,3764195,3764196,3819461,3899394,3899395,3899397,3899397,3771007,3784902,3886268,3899395,3777818,3777820,3777820,3777808,3777821,3777821,3777821,3777821,3777822,3777824,3777822,3777823,3777823,3777823,3777824,3826274,3826274,3826276,3893080,3826272,3826275,3863112,3872752,3883070,3904520,3906209,3906209,3906210,3906211,3906211,3906213,3906211,3805468,3805538,3805606,3805609,3908318,3808372,3808886,3808891,3921740,3898604,3811133,3904792,3815965,3845348,3853532,3944062,3872463,3953530,3874711,3874727,3874714,3874728,3874729,3874731,3874715,3874726,3874729,3874729,3874731,3874730,3874731,3874731,3874731,3874732,3874733,3874721,3874733,3874733,3874734,3874737,3874741,3954662,3954669,3874746,3936592,3954663,3874747,3911567,3936598,3948780,3954663,3954663,3954664,3954665,3874747,3954664,3921206,3936600,3948781,3954664,3954666,3911569,3911569,3921207,3936109,3936595,3936597,3936598,3936600,3936600,3941538,3941539,3948781,3954665,3954665,3954666,3954666,3954667,3954667,3954668,3954668,3954670,3944083,3989341,3944162,3989381,3948402,3948403,3948404,3948405,3948405,3991500,3958043,3958043,3973430,3978373,3991500,3991501,3991502,3991503,3991504,3967666,3967669,3967681,3967681,3967682,3967682,3967682,3967683,3967684,3967683,3967696,4001139,4001140,4001140,4001141,3983074,4001139,4001141,4001142,4001139,4001140,4001142,3988013,3983041,4008817,3988315,3988316,4011454,4011455,3997482,3997973,3998454,3998455,3998456,3998457,3998458,3998461,3998458,3998459,3998462,3998464,3998448,3998465,3998467,3998468,3998464,3998465,3998466,3998467,3998453,3998467,3998468,3998468,3998455,3998466,3998469,3998467,4016528,4016526,4016528,4016528,4016528,4016530,4016529,3998478,3998689,3998690,3998690,4016531,4016532,4016533,3999995,4016532,4016534,4003405,4016533,4016535,4016536,4016536,4016535,4016535,3998901,3998902,3998911,3998912,3998912,3998921,4016752,4029504,4522686,4001517,4001653,4001788,4018190,4008337,4008338,4008338,4008332,4008342,4008352,4021466,4021466,4021467,4021467,4021468,4021471,4021467,4021468,4011037,4011039,4022818,4022821,4022830,4022830,4022828,4022829,4022831,4022831,4028711,4028713,4028713,4028714,4028714,4028714,4031219,4031220,4032908,4032911,4034580,4034581,4034582,4034583,4034583,4034584,4034586,4034582,4034583,4034583,4034584,4034584,4034585,4034585,4034586,4034587,4034598,4034599,4034606,4034583,4034584,4034584,4034585,4034585,4034586,4034586,4034587,4034588,4034584,4034585,4034585,4034586,4034586,4034587,4034588,4034588,4034585,4034586,4034586,4034587,4034587,4034588,4034601,4034604,4034586,4034587,4034587,4034588,4034588,4034589,4034590,4034600,4034601,4034602,4034604,4034605,4034587,4034588,4034588,4034589,4034589,4034590,4034590,4034602,4034603,4034605,4034588,4034589,4034589,4034590,4034590,4034591,4034598,4034603,4034604,4034604,4034607,4034589,4034590,4034590,4034591,4034591,4034592,4034592,4034599,4034601,4034602,4034602,4034603,4034604,4034604,4034605,4034608,4034590,4034591,4034591,4034592,4034592,4034593,4034598,4034599,4034603,4034603,4034604,4034604,4034605,4034609,4034591,4034592,4034592,4034593,4034593,4034594,4034594,4034595,4034599,4034600,4034600,4034602,4034603,4034603,4034604,4034604,4034605,4034605,4034606,4034592,4034593,4034593,4034594,4034594,4034596,4034600,4034601,4034603,4034604,4034604,4034605,4034605,4034606,4034607,4034607,4034608,4034609,4034593,4034594,4034594,4034595,4034595,4034596,4034596,4034598,4034600,4034601,4034601,4034602,4034603,4034603,4034604,4034605,4034605,4034606,4034606,4034607,4034607,4034608,4034608,4034609,4034609,4034610,4034594,4034595,4034595,4034596,4034596,4034597,4034599,4034601,4034601,4034602,4034602,4034604,4034604,4034605,4034605,4034606,4034606,4034607,4034607,4034608,4034609,4034595,4034596,4034596,4034597,4034598,4034598,4034599,4034599,4034600,4034601,4034602,4034602,4034603,4034604,4034604,4034605,4034605,4034606,4034606,4034607,4034607,4034596,4034597,4034597,4034598,4034598,4034599,4034599,4034602,4034603,4034603,4034604,4034604,4034605,4034605,4034606,4034606,4034607,4034607,4034608,4034608,4034609,4034609,4034610,4034611,4034611,4034612,4034597,4034598,4034598,4034599,4034600,4034600,4034603,4034603,4034604,4034604,4034605,4034606,4034606,4034607,4034607,4034608,4034609,4034611,4034598,4034599,4034599,4034601,4034603,4034604,4034604,4034606,4034607,4034608,4034608,4034599,4034600,4034601,4034601,4034602,4034604,4034604,4034605,4034606,4034607,4034607,4034608,4034608,4034609,4034609,4034600,4034602,4034604,4034605,4034608,4034610,4034602,4034602,4034605,4034606,4034607,4034608,4034609,4034609,4034610,4034605,4034608,4034609,4034606,4034606,4034608,4034610,4034604,4034608,4034609,4034610,4034610,4034611,4034611,4034612,4034606,4034610,4034611,4034611,4034612,4034608,4034610,4034611,4034613,4034613,4034614,4034608,4034609,4034610,4034610,4034611,4034611,4034612,4034612,4034613,4034613,4034614,4034614,4034616,4034610,4034611,4034611,4034612,4034612,4034613,4034613,4034614,4034614,4034615,4034616,4034611,4034612,4034612,4034613,4034614,4034614,4034615,4034612,4034613,4034613,4034614,4034615,4034616,4034613,4034614,4034614,4034615,4034615,4034616,4034616,4034619,4034619,4034615,4034615,4034616,4034616,4034617,4034618,4034615,4034616,4034616,4034617,4034617,4034618,6613563,4034616,4034617,4034617,4034618,4034619,4350919,4034617,4034618,4034618,4034619,4034619,4034620,4034620,4034621,4034621,4034622,4407623,4478496,4034618,4034619,4034619,4034620,4034620,4034621,4034619,4034620,4034620,4034621,4034622,4034622,4034623,4034625,4034630,4540535,5798712,4034620,4034621,4034621,4034622,4034622,4034623,4034624,4034625,4034625,4034627,4039261,4047350,4412349,4611285,5055449,5798981,4034621,4034622,4034622,4034623,4034623,4034624,4034625,4034625,4034626,4034628,4047353,4047354,4429153,4478496,4789889,7515991,4034622,4034623,4034623,4034624,4034624,4034625,4034626,4034629,4034630,4039265,4047354,4151188,4407625,4611287,5030509,9642968,4034623,4034624,4034624,4034625,4034625,4034626,4034626,4034627,4034627,4034629,4034632,4047354,4047354,4047355,4137752,4350920,4407626,4407627,4412350,4418540,4432737,5798979,4034624,4034625,4034625,4034626,4034626,4034627,4034627,4034628,4034629,4034631,4047355,4047355,4126460,4137754,4350920,4350926,4407626,4407627,4478498,4611288,4782462,4946218,5493381,5493528,5798981,5798981,4034625,4034626,4034626,4034627,4034627,4034628,4034629,4034631,4034633,4039267,4047355,4047356,4126458,4137753,4151190,4195574,4350922,4350925,4407626,4407627,4478498,4508750,4611288,4611288,4789890,4789891,4034626,4034627,4034627,4034628,4034628,4034629,4034630,4034630,4034632,4034633,4034633,4039265,4039266,4039267,4047355,4047356,4047356,4350905,4350906,4377669,4407624,4407627,4611289,4680565,4782463,4789890,4789893,4929815,5003814,5077275,5493430,4034627,4034628,4034628,4034629,4034629,4034633,4034633,4034634,4034637,4039265,4039267,4039268,4047355,4047356,4047356,4047357,4057160,4126461,4126463,4151191,4180214,4195575,4350920,4350923,4407628,4407628,4478500,4611289,4738620,4789893,4929815,5178391,5798981,9642971,4034628,4034629,4034629,4034630,4034630,4034631,4034632,4034633,4034634,4034634,4034635,4047355,4047356,4047357,4047357,4151192,4349916,4350909,4350925,4407628,4407629,4627132,4683487,4789893,4929816,5798982,4034629,4034630,4034630,4034631,4034632,4034632,4034633,4034634,4034635,4042592,4047352,4047354,4047355,4047355,4047356,4047357,4047358,4137755,4247287,4350924,4407629,4540539,4782465,4789893,4034630,4034631,4034631,4034632,4034632,4034633,4034634,4034634,4034635,4034635,4034636,4034636,4039269,4047356,4047357,4047357,4047358,4047358,4126463,4350923,4350925,4407629,4407630,4540539,4789893,5493450,9642116,4034631,4034632,4034632,4034633,4034633,4034634,4034634,4034635,4034635,4034636,4034637,4039269,4039270,4047356,4047357,4047357,4047358,4047358,4047359,4137756,4350907,4407630,4407630,4407631,4540540,4789894,4789895,4789895,4034632,4034633,4034633,4034634,4034634,4034635,4034635,4034636,4034636,4034637,4034637,4034638,4034638,4034639,4034640,4039269,4039270,4039270,4047354,4047354,4047355,4047356,4047356,4047357,4047357,4047358,4047359,4047359,4109174,4126462,4126463,4126465,4126465,4126466,4151193,4177968,4247286,4247288,4287006,4349918,4350253,4350255,4350909,4350910,4350911,4350925,4350926,4350929,4407628,4407630,4407631,4407632,4412355,4429158,4478502,4478502,4540536,4540540,4540542,4611291,4627134,4680567,4782465,4782466,4789894,4946220,9642117,4034633,4034634,4034636,4034637,4034638,4039271,4047359,4137757,4142401,4350928,4407631,4407631,4034634,4034635,4034635,4034636,4034636,4034637,4034638,4034639,4034640,4034742,4039271,4047359,4047360,4099003,4350910,4407631,4478503,4034635,4034636,4034636,4034637,4034637,4034638,4034640,4034641,4034741,4034742,4039270,4039272,4047359,4047359,4047360,4047361,4047361,4126464,4137759,4177958,4344308,4350911,4350917,4350928,4350929,4351968,4361135,4407632,4407632,4611293,4946224,4034637,4034637,4034639,4034642,4047358,4047361,4047361,4252758,4349920,4407632,4034638,4039272,4039273,4047357,4047358,4047361,4047362,4151196,4407633,4478504,4034639,4034639,4034641,4034642,4047360,4047361,4047362,4047362,4100808,4102787,4126465,4137759,4407633,4680571,4034639,4039273,4047362,4047362,4047363,4252760,4350912,4350928,4394262,4407634,4540544,4789897,4034640,4034642,4034644,4039273,4039274,4039275,4047359,4047360,4047363,4047363,4063218,4151197,4151198,4252031,4309857,4349922,4350912,4350927,4407634,4429161,4429164,4611294,4034641,4034642,4034644,4034745,4039274,4039274,4039275,4042598,4047362,4047362,4047363,4047363,4047364,4047364,4126466,4126467,4137516,4137761,4247293,4341944,4349923,4350914,4350931,4371917,4407635,4478506,4478507,4782470,4789899,9642171,4034642,4039275,4047362,4047364,4047364,4407635,4407636,4501707,4039273,4047362,4047363,4047364,4126471,4247294,4350915,4047365,4151199,4350913,4350914,4478508,4047360,4047361,4047364,4407637,4039277,4126473,4047365,4047367,4126473,4478509,4047366,4047367,4195585,4247296,4407638,4034848,4034859,4039389,4047478,4047478,4043918,4043919,4043917,4043918,4043908,4043920,4043921,4043910,4043921,4043921,4043922,4043922,4412279,4379330,4043933,4043934,4052002,4052005,4052008,4052009,4052010,4052010,4131116,4142164,4155844,4291657,4355560,4355574,4379331,4412281,4412282,4615942,4794545,5060106,5497941,5803636,4155846,4050571,4055336,4486479,4060092,4060093,4060096,4060080,4060079,4060082,4060096,4060082,4060082,4060096,4060098,4060097,4060098,4060082,4060083,4060084,4060097,4060098,4060099,4060084,4060097,4060098,4060099,4060083,4060084,4060084,4060085,4060099,4060100,4060084,4060085,4060085,4060097,4060099,4060099,4060100,4060085,4060086,4060086,4060097,4060098,4060099,4060100,4060100,4060101,4060086,4060087,4060088,4060098,4060099,4060100,4060100,4060101,4060101,4060087,4060088,4060099,4060099,4060100,4060101,4060101,4060102,4060100,4060102,4060102,4060103,4060103,4060101,4060102,4420369,4060112,4060113,4060114,4163934,4260028,4299743,4420370,4491242,4795206,4060114,4060114,4139204,4420370,4060114,4060115,4060115,4163936,4363666,4420371,4491243,4802634,4060115,4060116,4139207,4208319,4260028,4363651,4363659,4363667,4363668,4420372,4420372,4420373,4420375,4425101,4802636,5811726,4060116,4060117,4060119,4115499,4139203,4139206,4139206,4139207,4150498,4240471,4249627,4260030,4363665,4363668,4363669,4420372,4425097,4425101,4441900,4514443,4553282,4624034,4695858,4942560,4060117,4075956,4139204,4139204,4139206,4139207,4139208,4139208,4150255,4150499,4150499,4150501,4163936,4163936,4163937,4192959,4208320,4260031,4265499,4299746,4299746,4357049,4362661,4362663,4363648,4363650,4363651,4363652,4363665,4363665,4363667,4363668,4363669,4363669,4363673,4375655,4387419,4387425,4390415,4410498,4420373,4420373,4420374,4420374,4420375,4441901,4450824,4491244,4491245,4491245,4514443,4514446,4553283,4553283,4624034,4624034,4652784,4688531,4693311,4695773,4795207,4795208,4795209,4802636,4802636,4802638,4802639,4942562,5142367,5811729,4139209,4163936,4190691,4208320,4362661,4420373,4420371,4363652,4079703,4079713,4563085,4091836,4091912,4179816,4091987,4155163,4436328,4163389,4414305,4166994,4417114,4170893,4170913,4170935,4170946,4858053,4171024,4171100,4192449,4183732,4201026,4213804,4497221,4218306,4218307,4218307,4218298,4218308,4218295,4218310,4218308,4218311,4218311,4218312,4218312,4218299,4218313,4218314,4218313,4218315,4218313,4218318,4218323,4499475,4570349,4874310,4442753,4218328,4305794,4441764,4259467,4442772,4243041,4243041,4269796,4339136,4442757,4442774,4442775,4442777,4499478,4521006,4570349,4632388,4881741,4881741,5021665,4243042,4442756,4442758,4442774,4499479,4593552,4499481,4901166,4240407,4240409,4240410,4581397,4240654,4510526,4730026,4240881,4240896,4240896,4240897,4240896,4240898,4240897,4240899,4240896,4241011,4240911,4254333,4254333,4510770,4515495,4581641,4581642,4510772,4532298,4893034,4454067,4604842,4454050,4454064,4241125,4497510,4250185,4515415,4267769,4267770,4267770,4267771,4267772,4267773,4267768,4267769,4267771,4267771,4267772,4267774,4267770,4267773,4524205,4294538,4349874,4524206,4727867,4368604,4476537,4524207,4595078,4595079,4657118,5609590,4368604,4467485,4467492,4476537,4524207,4535122,4579738,4595079,4906470,4467502,4522400,4587424,4467505,4467505,4545738,4300620,4346947,4321280,4321282,4321300,4321311,4494252,4550964,4321319,4550975,4550979,4494278,4325817,4325821,4496524,5176119,4553235,4356535,4356535,4356536,4356538,4568588,4573313,4639460,4568589,5216413,4573318,4393274,4393275,4431354,4530254,4420888,4420950,4421020,4544156,4431977,4825810,4439156,4609901,4459956,4459957,4459958,4459958,4459959,4459963,4563595,4563579,4563579,4563594,4563595,4587350,4620300,4823960,4563600,4620301,4563597,4469438,4469439,4695912,4695913,5007307,4568338,4470898,4470899,4470902,4569065,4696645,4625776,4539390,4539391,4539393,4603294,4602305,4603314,4603314,4660017,4660018,4585088,4626144,4649265,4714956,4653992,4717316,4665220,4665222,4666210,4666211,4666223,4667267,4722932,4722934,5105197,4665890,4665894,4856179,4666559,4667195,4667185,4667185,4667197,4667198,4667198,4667199,4667201,4667207,4667200,4667207,4667186,4667204,4667206,4667209,4667211,4667214,4667187,4667200,4667202,4667204,4667207,4667208,4667209,4667210,4667210,4667213,4667215,4667217,4667217,4667195,4667200,4667205,4667210,4667210,4667216,4667223,4667224,4667213,4667227,4667209,4667227,4723919,4667212,4667229,4723920,4667214,4667214,4667217,4667232,4667217,4667218,4667231,4723921,4728649,4667219,4667219,4667231,4667233,4667234,4667234,4723922,4667232,4667233,4667234,4667218,4667219,4667231,4667235,4667219,4667220,4667222,4667228,4667233,4667233,4667235,4667236,4856832,4667220,4667235,4667221,4667223,4667226,4667235,4667236,4667236,4667221,4667222,4667227,4667228,4667233,4667236,4667237,4667237,4667234,4667234,4667235,4667237,4667237,4927586,4667225,4667234,4667235,4667237,4667238,4667238,4667233,4667236,4667237,4667238,4667239,4723927,4667236,4667237,4667228,4667230,4667238,4667240,4667233,4667239,4723929,4723929,4794801,4667231,4714991,4723929,4667241,4723930,4667243,4728655,4667242,4787147,4818003,4667241,4856842,5098768,4667242,4723935,4667242,4667246,4710564,4723936,4667249,4667315,4667315,4667316,4667317,4667249,4667317,4723938,4667249,4667250,4667316,4667318,4667318,4723938,4723939,4787154,5098773,5106203,4667318,4723939,4943439,4667251,4667252,4667317,4667318,4723939,6115292,4667251,4676270,4723940,4745468,4794811,4667252,4667320,4667322,4676270,4693982,4723939,4723940,4745468,4794812,4794814,4856852,4943435,4996878,5346829,5485357,4667253,4667321,4723939,4723941,4723942,4728666,4856851,5030975,5106206,6115296,4723941,4779470,4818010,4856851,4856852,4667396,4667396,4667397,4667397,4667398,4667398,4667402,4694060,4724018,4724019,4724020,4728743,4745546,4794890,4794890,4794891,4818090,7189382,4724020,4669313,4669313,4724977,4685298,4685300,4685301,4685302,4685429,4737533,4732972,4732971,4685558,4754626,4687650,4966560,4691203,4691342,4691481,4736060,4709233,4744951,4714732,4714738,4714739,4714743,4714855,4714856,4714857,4714858,4714860,4714975,4714976,4714977,4747807,4747808,4818679,4880718,4720726,4720727,4720728,4761598,4772212,4983099,4750791,4753897,4767269,4838141,4760891,4770766,4762765,4771703,4777024,4849704,4780625,4780641,4780626,4780642,4780627,4780640,4780642,4780629,4780630,4780630,4780631,4780638,4780639,4780639,4780640,4780640,4780641,4780641,4780642,4780642,4780643,4780643,4780644,4780644,4780645,4780646,4780630,4780631,4780632,4780639,4780639,4780640,4780641,4780641,4780642,4780642,4780643,4780643,4780645,4780632,4780639,4780640,4780640,4780641,4780641,4780642,4780643,4780643,4780645,4780640,4780640,4780641,4780641,4780642,4780643,4780644,4780646,4780633,4780644,4780641,4780646,4780644,4780648,4780648,4780649,4780649,4780650,4780651,4780653,4780653,4780654,4780742,4780742,4780743,4780743,4780744,4780649,4780650,4780651,4780651,4780652,4780652,4780654,4780654,4780743,4780743,4780744,4780650,4780651,4780651,4780652,4780653,4780653,4780655,4780655,4780742,4780743,4780743,4780744,4780744,4780745,4780651,4780652,4780652,4780653,4780653,4780655,4780743,4780744,4780744,4780747,4780653,4780654,4780743,4780744,4780745,4780745,4780653,4780654,4780656,4780656,4780743,4780744,4780744,4780745,4780745,4780747,4780654,4780655,4780656,4780656,4780657,4780657,4780744,4780744,4780745,4780745,4780746,4780746,4780747,4851513,4780655,4780657,4780657,4780745,4780745,4780746,4780746,4780656,4780657,4780657,4780658,4780659,4780745,4780745,4780746,4780746,4780747,4780747,4780748,4780658,4780747,4780747,4780748,4913553,4780658,4780659,4780747,4780747,4780748,4792278,4780659,4780746,4780747,4780747,4780748,4780748,4780749,4780750,4780753,4785372,4851515,4851516,4913550,4913554,5053581,4780660,4780747,4780748,4780748,4780749,4780749,4802172,4851516,4913554,4984304,5000139,5000139,5087679,5502638,4780748,4780748,4780750,4984306,5000143,4780749,4851517,4780834,4780835,4780836,4780846,4780836,4780836,4780837,4780847,4780836,4780837,4780837,4780838,4780838,4780845,4780847,4780847,4780848,4780837,4780838,4780838,4780839,4780839,4780848,4780848,4780838,4780839,4780839,4780840,4780847,4780848,4780849,4780849,4780840,4780848,4780849,4780849,4780849,4780849,4780850,4780850,4780851,4780851,4780852,4780850,4780853,4780857,4785469,4780857,4780858,4780859,4851615,4780859,4780860,4780860,4780861,4783573,4783574,4783575,4785467,4785468,4785468,4785469,4785469,4785470,4785471,4785472,4785472,4785473,4790070,4791658,4791661,4792379,4802271,4802272,4802273,4811196,4818060,4818061,4836275,4843618,4851615,4851615,4851616,4851616,4851617,4874811,4874815,4874815,4874816,4874816,4884720,4913652,4913654,4913654,4913655,4913655,4913657,4984405,4984405,5000239,5000248,5013154,5039068,5053681,5053681,5111736,5155579,5155579,5155580,5163007,5163007,5163008,5163009,5163009,5163010,5436523,5502737,5674558,10015231,4780860,4783575,4785469,4785472,4791660,4793580,4802272,4843618,4851616,4851616,4874815,4874816,4913654,4913655,4984405,5000239,5048900,5053681,5163007,5163008,5163008,5163010,5428570,4785469,4791662,4802273,4802275,4818062,4851616,4984407,4785475,4851617,4851617,4913655,4785472,4785474,4851617,4851618,4913652,5163010,4785311,4786301,4786302,4786303,4786303,4788200,4854343,4854344,4854344,4916382,5165735,4794388,4789765,4789768,4789933,4988864,4790091,4790092,4790093,4790093,4790093,4790096,4790096,4790082,4790094,4790097,4790097,4790100,4790097,4790098,4790097,4790099,4790101,4790086,4790099,4790099,4790100,4790102,4790096,4790100,4790101,4790096,4790101,4790102,4790103,4790102,4790103,4790103,4790104,4790099,4790112,4856239,4830294,4848703,4856240,4918278,4918279,4989029,5004871,5116361,4796284,4806899,4856240,4889345,4918279,4989030,5004870,4796288,4856243,4886489,4856243,4856244,4989033,5049865,5507366,4806901,4815062,4856244,4856245,4918283,5053531,5167636,4918283,4918284,4856246,4879448,5043701,5167637,4856246,4799299,4811501,4802473,4802472,4802473,4802474,4802476,4802479,4802481,4885628,4862430,4862431,5513553,5877256,4862432,4924470,4862435,4924472,4862435,4803911,4863147,4863149,4925186,4806321,5012980,4823685,4823698,4823699,4823699,4823700,4823700,4823701,4823700,4823701,4823689,4823702,4823702,4823714,4873042,4896244,4823714,5021666,4857703,4865385,4865386,4873043,4873044,4873044,4896244,4896244,4935082,4935082,5021666,5021667,5075109,5133165,5177007,5177008,5184436,5324361,4830864,5180588,4840017,4840092,4840167,4943313,4841547,4841546,5014755,5014756,4855274,4855279,4855280,4881032,5465787,4892437,4870495,4888444,4891701,4891704,4891704,4907044,5211009,5218436,4906392,4906393,4914390,4937590,4976428,4906787,4937786,4907065,4907066,4907070,4907188,4907190,4907191,4907311,4907311,4907311,4907315,4907315,4914846,4914847,4976885,4914848,4976888,4976888,4922371,4922387,4922372,4922373,4922384,4922385,4922386,4922387,4922387,4922388,4922388,4922389,4922390,4922391,4922391,4922392,4922373,4922374,4922375,4922376,4922387,4922388,4922388,4922389,4922390,4922391,4922374,4922375,4922387,4922388,4922388,4922389,4922389,4922390,4922392,4922388,4922389,4922390,4922389,4922392,4922393,4922390,4922391,5226348,4984424,4922401,5937177,4922402,4922403,4922403,4922404,4945588,4984421,4984425,4984426,5055175,5055175,5055177,5071010,5071017,5071018,5071019,5071021,5083926,5119671,5182510,5211787,5226350,5226351,5233779,5233781,5373703,5390105,4922403,4922404,4922404,4922405,4922405,4922409,4945587,4945588,4945588,4945589,4945589,4984426,4984426,5055177,5058389,5071019,5119672,5124454,5127002,5226352,5233780,5233782,5499341,5573509,6242868,4922404,4922405,4922405,4922406,4922407,4922408,4922409,4922410,4945585,4945587,4945587,4945588,4945589,4945589,4984422,4984425,4984426,4984427,4984427,4984428,4984429,4984430,5033076,5055177,5055178,5058383,5058390,5071011,5071015,5071018,5071018,5071020,5116008,5119672,5119673,5124453,5173660,5226351,5226352,5233779,5233779,5233780,5233780,5233781,5233781,5233782,5373704,5390108,5573510,6242871,6242872,4945589,4945590,4984427,5058391,5120771,5124455,5226352,5233782,5279584,5830929,4922411,4945588,4984427,5124455,5233780,5233782,4925992,4945590,5053197,5055179,5182510,5233780,5573511,4952640,5071022,5175001,5937449,4945592,4984430,5233783,4984430,5055181,5124458,5173671,4945592,5226356,4925996,4984432,5071025,5127008,5072428,4929590,4929590,4988021,5237378,5237382,4968782,4968783,4968784,4968785,4968774,4968786,4968786,4968774,4968786,4968787,4968787,4968787,4968775,4968787,4968788,4968788,4968788,4968789,5007624,5007624,4968800,5007624,5256979,5007625,5007625,5007626,5078374,5078375,5078376,5078376,5094208,5094212,5094215,5094217,5094218,5107128,5139201,5142871,5142872,5142873,5147652,5150203,5198198,5205707,5233087,5249548,5249550,5249551,5256977,5256978,5256978,5256979,5396901,5413306,5596709,4982894,4982897,4982906,5149933,5264040,5529607,4988593,4988594,5088278,5017527,5046440,5046455,5046456,5046457,5046459,5046441,5046458,5046445,5046447,5046461,5046464,5046464,5046449,5046450,5046450,5046452,5046461,5046462,5046462,5046463,5046464,5046464,5046465,5046465,5046466,5046466,5046467,5046467,5046468,5046450,5046451,5046464,5046464,5046465,5046465,5046466,5046467,5046473,5046451,5046464,5046465,5046465,5046466,5046467,5046453,5046465,5046466,5046467,5046468,5046466,5046468,5046468,5046470,5046466,5046468,5046469,5046470,5046468,5046470,5117209,5295816,5046476,5046479,5117211,5117213,5046478,5181711,5571737,5046478,5295819,5295819,5046479,5046480,5046480,5046485,5079240,5117215,5117215,5133049,5133056,5145967,5178037,5181710,5181712,5186491,5186491,5189040,5189472,5244546,5273826,5288389,5288390,5295817,5295819,5435741,5046480,5046481,5046481,5046482,5046482,5117215,5117216,5117216,5117217,5120424,5120427,5133055,5133056,5145967,5150034,5155352,5176601,5186491,5189472,5221602,5288389,5288390,5288390,5295817,5295817,5295818,5295819,5295820,5295820,5452147,5561379,5635548,6238200,6304909,5046481,5046483,5117216,5117216,5133055,5145969,5178052,5235698,5244547,5288391,5046485,5117217,5133058,5181710,5181711,5186492,5288390,5288391,5295818,5295819,5295820,5117217,5117217,5117220,5186493,5244549,5288391,5288391,5295819,5295820,5117217,5133052,5133060,5181711,5117218,5133052,5288393,6304910,5295823,5117219,5133062,5295824,5117221,5117224,5112013,5127885,5143759,5143760,5144027,6047955,5144292,5181960,5183998,5183999,5189191,5201823,5187949,5187963,5187963,5187964,5187964,5187950,5187951,5187953,5187965,5187965,5187966,5187966,5187967,5187969,5187954,5187966,5187967,5187967,5187968,5187968,5187968,5187968,5187970,5187969,5252459,5187980,5203807,5366568,5366570,5522896,5187981,5203799,5203799,5203807,5187981,5187982,5257243,5259790,5306449,5307788,5315298,5315299,5359140,5359140,5359141,5366568,5366568,5366570,5632129,5632130,5187982,5187983,5191178,5203800,5203801,5203803,5203804,5203807,5203809,5203810,5216718,5216720,5241891,5242511,5247352,5248795,5248801,5248807,5257242,5306449,5307788,5307788,5315298,5359140,5359140,5359141,5359141,5359142,5366568,5366569,5366569,5366570,5366571,5506493,5706299,5706299,5755067,6070124,6375656,5203800,5203801,5216719,5252461,5257243,5257244,5257245,5292353,5359139,5359142,5366570,5366571,5397926,5706299,5706300,5187985,5203808,5248801,5359143,5366572,5194387,5194391,5194390,5194393,5194396,5194377,5194400,5194395,5207019,5194414,5255678,5509707,5255679,5255679,5311006,5362358,5318518,5219617,5219618,5219618,5219626,5219634,5219635,5219636,5219619,5219620,5219626,5219634,5219634,5219635,5219636,5219636,5219637,5219637,5219638,5219640,5219628,5219635,5219642,5219636,5219644,5219645,5219645,5219630,5219646,5219647,5219648,5219649,5219634,5219642,5219649,5219650,5219650,5219650,5219642,5219650,5219651,5219644,5219651,5219651,5219652,5219653,5219653,5219653,5219651,5219653,5219657,5219655,5219657,5374976,5219653,5219655,5219656,5219659,5219655,5273079,5374976,5219660,5273078,5322286,5331135,5382404,5382405,5382406,5522330,5382405,5722136,5382408,5232555,5268299,5382407,5273080,5264509,5268300,5268304,5382410,5413762,5219666,5219667,5232559,5232560,5258895,5264648,5268305,5273084,5273085,5323630,5331140,5374982,5374983,5382410,5382411,5382411,5382412,5382412,5382413,5382414,5623036,5722141,5232560,5232561,5268303,5268304,5273085,5308195,5331142,5360420,5382411,5382412,5382413,5382414,5647972,5268305,5273085,5331143,5382411,5222451,5274483,5245465,5245466,5245466,5245454,5245467,5245467,5245468,5245468,5245469,5271378,5277536,5277546,5281211,5285991,5335200,5344047,5344048,5373327,5387889,5387890,5395318,5395319,5395320,5535242,5253603,5275747,5264234,5264284,5264336,5404752,5295811,5306381,5297050,5297169,5297294,5297295,5297288,5297298,5526395,5421236,5307126,5561158,5297888,5298015,5298138,5298141,5307546,5421654,5306737,5319176,5418525,5309369,5309501,5309615,5309627,5309620,5309623,5309631,5309631,5309635,5309643,5309640,5309636,5309640,5309647,5309646,5419968,5419969,6436489,5427402,5376132,5419975,5419977,5419978,5313301,5427409,6024552,5313303,5376143,5316955,5316940,5316956,5316942,5316956,5316956,5316957,5316944,5316956,5316957,5316958,5316958,5316960,5316961,5316962,5316962,5316970,5316971,5321737,5353445,5431066,5316974,5318054,5321737,5324719,5338966,5372283,5379792,5379793,5379794,5409070,5423633,5423635,5423636,5423637,5431064,5431066,5440276,5587391,5696626,5770794,5379795,5409072,5431065,5696627,5372286,5321741,5319148,5319149,5432160,5432158,5326503,5326518,5326518,5326519,5326519,5326520,5326520,5326521,5326519,5326519,5326520,5326518,5326520,5326520,5326519,5326521,5326521,5326507,5326520,5326533,5435845,6139241,5384573,5384574,5428416,5428417,5435845,5435846,5435847,5575768,5775575,6138964,5326534,5326536,5377064,5384574,5384576,5413853,5428414,5428416,5428416,5428417,5435844,5435845,5435845,5435846,5435847,5435847,5467197,5701406,5329067,5384574,5428417,5435843,5435845,5435847,5329502,5384577,5428418,5435845,5870450,5435846,5435848,5575771,5435847,5435851,5331439,5331528,5331613,5331616,5331613,5331613,5331617,5331617,5331620,5331618,5332045,5364177,5703952,5778120,5438395,5378274,5438393,5438394,5364182,5332356,5332418,5332480,5332481,5332482,5332482,5332483,5364608,5431397,5438828,6447913,5438829,5360973,5453072,5389935,5445561,5394710,5462512,5710563,5396738,5396740,5396743,5396743,5419687,5463527,5470956,5470957,5470959,6480047,5424931,5424932,5424933,5424933,5424942,5426271,5433782,5485054,5477624,5485053,5485054,5485057,5427606,5427607,5427595,5427607,5427607,5427608,5478958,5486388,5435117,5435118,5478959,5478959,5478960,5486387,5486388,5486390,5521365,5642717,5751949,5826118,5442628,5442628,5442631,5442632,5442629,5442631,5442617,5442629,5442630,5442630,5471907,5471908,5486470,5486471,5486471,5486472,5486472,5493898,5493899,5493899,5493900,5633823,5734524,5833629,6014888,6502990,5470006,5486474,5493903,5633826,5493904,5497381,5497385,5497476,5521275,5497565,5513938,5501185,5501186,5501187,5501188,5501188,5515750,5515751,5515751,5515752,5523179,5523179,5523182,5862909,6226833,5530297,5530297,5530298,5530310,5530298,5530299,5530311,5530313,5530299,5530300,5530300,5530312,5530312,5530314,5530300,5530301,5530312,5530313,5530301,5530302,5530302,5530312,5530313,5530313,5530313,5530314,5530314,5530314,5530325,5530325,5530326,5537737,5537739,5537740,5537740,5537741,5537741,5537742,5537742,5537743,5537743,5583546,5677664,5677666,5694065,5694067,5694068,5778362,5778363,5803298,5803301,5803302,5803302,5877470,5877470,5877471,5877472,5916894,6058730,6241172,6241231,6241232,6241265,6241280,6241281,6241293,6449015,6546565,6546830,6546832,5530327,5537739,5537740,5537740,5537741,5537741,5537742,5537742,5537743,5537743,5537744,5537744,5677665,5778364,5803302,5803303,5803303,5877471,5877471,5926240,6546832,5537741,5537743,6241139,6241296,5537742,5537745,5545152,5545154,5545154,5545169,5545154,5545155,5545155,5545156,5545157,5545169,5545169,5545170,5545155,5545156,5545156,5545157,5545157,5545158,5545158,5545170,5545171,5545171,5545172,5545172,5545173,5545173,5545156,5545157,5545157,5545158,5545158,5545159,5545169,5545169,5545171,5545171,5545172,5545172,5545173,5545173,5545174,5545174,5545157,5545158,5545158,5545159,5545159,5545160,5545172,5545172,5545173,5545173,5545174,5545158,5545159,5545159,5545160,5545160,5545169,5545171,5545171,5545172,5545172,5545173,5545173,5545174,5545174,5545175,5545175,5545159,5545160,5545160,5545161,5545170,5545171,5545172,5545172,5545173,5545173,5545175,5545175,5545160,5545161,5545161,5545163,5545172,5545173,5545173,5545174,5545174,5545175,5545175,5545176,5545176,5545161,5545162,5545162,5545163,5545171,5545172,5545173,5545173,5545174,5545174,5545175,5545175,5545176,5545176,5545177,5545177,5545173,5545173,5545174,5545174,5545175,5545175,5545176,5545176,5545177,5545177,5545164,5545164,5545175,5545177,5545177,5545178,5545178,5545165,5545177,5545178,5545178,5545179,5545179,5545184,5545184,5545186,5545186,5545184,5545185,5545186,5545187,5545186,5545187,5545188,5884900,5545185,5545186,5545186,5545187,5545188,5810731,5884901,5545186,5545187,5545187,5545188,5545188,5545189,5545189,5785795,5545187,5545188,5545188,5545189,5545189,5685095,5785794,5810733,5884901,5884902,6008461,6248572,5545188,5545189,5545189,5545190,5685096,5685097,5701499,5810732,5810733,5884902,5884902,5884903,6248568,6248711,5545189,5545190,5545190,5685096,5685098,5701499,5701500,5701501,5810733,5810734,5884903,6012677,6364360,6554263,6554264,5545190,5545191,5545191,5545193,5685097,5701501,5785793,5810734,5810734,5821092,5884903,5884904,6487555,6554263,6554264,5545191,5545192,5576529,5580152,5685097,5685099,5701501,5701502,5701503,5810734,5810734,5810735,5884903,5884903,5884904,6248730,6248829,6554264,7204260,7628275,5545192,5545193,5545194,5545194,5546514,5576279,5576524,5576525,5576527,5576527,5576529,5576530,5576530,5576531,5590980,5590981,5685098,5685099,5685100,5701499,5701501,5701501,5701502,5701503,5723634,5759097,5785796,5785798,5785799,5810733,5810734,5810735,5810735,5816129,5884903,5884904,5884904,5884905,5924328,5933671,5933672,5933673,5933674,5961899,6076693,6248571,6248572,6248573,6248665,6248738,6325876,6554263,6554264,6554265,6554265,5545193,5545194,5576530,5685098,5685100,5701502,5701503,5701503,5701504,5759098,5785797,5810733,5810735,5810736,5810752,5818691,5884904,5884905,6061052,6302210,7204261,5545195,5685100,5685101,5884906,6482153,5545196,5561545,5785796,5810737,5884905,5685100,5547851,5686435,5563597,5894115,5577904,5594952,5584010,5830149,5607378,5841834,5607872,5607872,5607874,5607876,5607877,5607877,5607882,5607884,5607880,5607881,5607881,5607886,5817142,5716445,5842084,5716447,5817146,5716448,5716450,5732852,5716450,5842088,5732857,5916258,5612005,5718512,5615126,5615127,5736476,5845710,5636779,5636781,5636782,5636782,5636782,5856536,5730899,6106853,5755503,5990065,5825017,5825015,5825005,5825014,5825015,5825015,5825016,5825016,5825017,5825018,5825019,5825019,5825020,5825022,5825007,5825019,5825019,5825020,5825020,5825022,5825023,5825024,5825024,5825020,5825022,5825023,5825094,5825026,5825027,5950652,6388630,6694180,5825027,5825030,5825031,5825031,5825095,5841421,5925716,5950653,6024821,5825028,5950653,5950654,6024822,6388751,5825029,5825031,5841420,5925715,5950651,5950654,5956047,6024822,6064246,5841419,5950654,6024823,5841419,5925718,5825033,5825035,5925717,5950654,5950655,5950655,6024824,5841421,5841424,5950656,5950656,6388496,6388585,5825034,5825035,5825036,5825036,5841421,5841422,5841423,5925717,5925717,5925720,5950655,5950656,5950656,5950662,6024824,6024824,6024825,6024825,6046894,6073593,6149396,6196647,6264955,6373839,6388632,6388634,5841422,5841423,5841424,5925718,5925720,5950656,5950657,5950657,6024825,6024826,6388642,6388764,5841425,5972479,5899020,5925718,5925721,5950657,5950658,5841426,5950658,6694188,5950659,6024827,6024828,5841424,6024828,6024829,5825172,5950730,5950730,5857822,5857808,5857809,5857824,5857823,5857824,5857811,5857812,5857824,5857825,5857810,5857824,5857825,5857825,5857811,5857812,5857826,5857813,5857813,5857824,5857825,5857826,5857826,5857827,5857825,5857827,5857828,5857829,5857814,5857828,5857828,5857829,5857829,5857828,5857828,5857829,5857830,5857828,5942118,6041226,6041226,5857839,5967058,6089997,6281366,5967083,6089996,5857841,5857843,5857843,5942121,5967058,5967060,6041228,6041228,6041229,6404894,6404896,6405037,6482202,6749665,5857843,5942121,5967059,5967060,5967060,5967061,5967074,6041227,6041228,6041229,6041229,6118225,6217377,6404896,6405156,5857843,6041229,6222489,5857844,5942125,5967061,5967062,5967062,6041229,6404930,5942120,5942121,5942123,5942125,5967059,5967062,6041230,6041231,6404898,6404992,6710591,5967062,5902091,5989191,5989192,5973015,5973016,6024653,6098822,5999715,6026414,6026416,6026416,6026415,6026416,6026417,6026417,6026418,6026403,6026417,6026418,6026418,6026418,6026419,6026419,6026420,6026420,6026421,6026421,6125524,6026435,6051356,6125525,6125525,6306784,6051355,6051357,6051357,6051357,6051358,6051379,6125526,6125526,6156532,6164948,6174299,6489192,6489287,6489335,6794889,6076291,6076276,6076276,6076293,6076291,6076277,6076296,6076294,6076294,6076296,6076278,6076279,6076279,6076293,6076293,6076294,6076294,6076295,6076295,6076296,6076296,6076279,6076280,6076285,6076293,6076294,6076294,6076295,6076295,6076296,6076296,6076297,6076298,6076298,6076300,6076301,6076302,6076294,6076295,6076295,6076296,6076296,6076297,6076297,6076298,6076299,6076295,6076296,6076298,6076315,6076322,6076304,6076328,6076308,6098115,6076309,6086652,6150461,6150462,6514132,6076309,6076310,6076310,6076311,6076312,6076313,6081687,6150462,6150463,6326610,6514257,6076310,6076311,6076311,6076312,6076312,6076313,6076313,6076314,6150461,6150462,6150463,6150463,6189886,6199231,6199232,6227458,6326612,6514129,6514270,6514272,6747711,6819557,6076311,6076312,6076312,6076313,6076314,6076316,6076320,6076331,6081688,6098118,6150463,6150463,6150464,6199233,6390592,6514131,6514134,6514224,6514225,6514273,6819824,10662957,6076312,6076313,6076313,6076314,6076314,6076319,6076320,6076322,6150463,6150464,6150464,6150465,6227459,6326612,6514289,6514403,6747712,6819825,6819825,6076313,6076314,6076330,6076333,6093386,6150463,6150464,6150464,6150465,6150465,6184749,6189889,6326612,6393772,6514353,6819826,6076314,6076316,6081690,6150463,6150464,6150465,6150465,6514132,6514135,6514274,6722009,6747713,6076315,6076317,6076318,6076319,6076320,6076321,6076326,6098119,6150465,6150466,6150467,6199235,6514225,6514291,6514391,6076317,6150466,6150466,6199238,6819828,7104530,6076333,6076334,6150466,6150467,6199237,6076323,6150466,6150467,6150467,6514133,6514227,6150467,6076337,6150469,6150469,6076338,6150470,6150470,6076340,6076340,6076341,6150471,6150472,6150472,6150473,6150473,6150474,6150477,6150482,6322304,6514310,6150483,6514152,6326632,6150485,6093407,6150484,6150485,6150485,6150485,6150486,6087077,6087078,6092043,6155852,6155853,6155853,6155853,6092203,6092202,6158415,6330238,6097006,6097008,6097010,6160817,6209586,6160818,6160819,6110471,6110472,6167550,6167551,6119938,6119938,6119939,6119940,6172284,6172285,6172285,6535951,6224614,6224615,6224615,6224615,6224616,6224616,6224617,6224628,6224629,6224630,6224631,6224631,6224632,6224616,6224617,6224617,6224631,6224631,6224632,6224632,6224633,6224617,6224618,6224618,6224629,6224630,6224631,6224631,6224632,6224632,6224633,6224633,6224618,6224628,6224629,6224631,6224632,6224632,6224633,6224633,6224634,6224631,6224632,6224633,6224633,6224634,6224634,6224632,6224633,6224642,6224644,6224644,6224645,6224645,6588437,6893990,6893990,6224644,6224645,6224646,6265531,6273398,6224646,6224646,6224647,6224647,6273401,6893992,6224646,6224647,6224647,6224648,6254142,6264053,6264054,6273399,6273400,6400779,6588298,6588299,6588333,6588391,6690816,6893992,6933067,6224647,6224648,6224648,6264054,6273399,6273400,6273401,6313309,6319506,6349203,6400780,6405890,6405891,6482051,6588297,6588297,6588299,6588299,6588300,6588301,6588392,6588393,6588440,6588441,6588458,6588459,6588506,6588554,6588562,6665604,6893722,6893726,6893992,6893993,6893993,6224648,6224649,6264053,6264055,6273401,6273401,6273402,6274185,6301627,6301628,6319507,6349203,6396453,6400780,6400780,6405891,6405892,6462097,6588298,6588299,6588299,6588300,6588302,6588334,6588392,6588393,6588393,6588441,6588457,6588459,6588519,6588567,6679153,6796177,6821881,6893727,6893990,6893991,6893991,6893992,6893993,6224649,6264054,6264055,6273399,6273400,6273402,6316158,6400780,6400781,6405891,6405892,6588298,6588300,6588301,6588301,6588302,6588302,6588303,6588387,6588390,6588394,6588427,6588441,6588441,6588457,6588460,6588478,6588516,6588535,6588570,6588576,6588577,6665605,6893727,6893989,6893991,6893992,6893994,6893994,6246702,6259905,6264055,6264056,6264056,6264059,6264059,6264061,6273401,6273402,6273402,6273403,6273403,6273406,6301628,6301629,6303798,6316159,6319506,6391653,6396454,6400781,6400781,6405890,6405892,6405892,6405893,6407686,6421014,6588298,6588299,6588299,6588300,6588300,6588301,6588301,6588303,6588392,6588393,6588393,6588394,6588426,6588441,6588442,6588442,6588443,6588457,6588457,6588458,6588460,6588469,6588504,6588517,6588521,6588533,6588536,6588572,6588572,6588573,6821881,6893728,6893728,6893990,6893992,6893993,6893994,6893994,6893995,6268767,6268768,6295467,6504118,6283650,6378710,6286644,6924997,6293196,6622672,6295171,6623708,6303475,6303475,6303475,6303476,6303476,6303476,6303477,6303477,6303474,6303475,6303478,6303479,6303480,6303483,6303484,6303485,6303487,6521469,6440200,6627813,6312823,6628004,6933413,6312825,6388625,6627721,6627863,6627879,6312823,6312825,6627724,6627755,6627863,6627864,6933149,6933149,6933414,6627723,6627725,6627817,6933418,6521475,6306494,6629455,6322166,6322167,6322153,6322167,6322169,6322170,6322157,6322168,6322168,6322169,6322155,6322169,6322169,6322171,6322155,6322157,6322168,6322169,6322170,6322170,6322171,6322171,6322168,6322169,6322170,6322171,6322172,6322172,6322160,6322173,6322173,6322175,6322173,6322175,6322177,6322178,6362076,6322184,6350394,6449547,6350395,6397971,6322185,6454660,6637068,6637211,6942760,6942761,6322186,6322188,6350395,6350396,6350397,6368275,6368277,6454659,6454660,6637161,6637211,6637291,6637347,6942495,6942759,6942761,6322188,6398535,6454661,6637068,6637228,6322187,6340080,6364927,6449549,6449549,6449550,6637067,6637068,6637161,6637162,6942496,6942760,6322190,6350397,6447059,6449552,6530819,6530821,6637068,6637126,6637162,6637163,6637196,6637211,6637229,6637281,6942759,6942763,6942764,6637069,6637071,6449552,6637072,6328853,6637325,6323736,6369055,6335524,6374949,6357983,6358086,6358189,6370572,6378616,6378619,6378621,6378622,6378622,6378620,6378622,6378623,6665383,6396499,6482883,6559042,6665386,6665434,6396501,6429403,6477774,6665292,6665293,6665296,6665421,6665436,6665509,6970721,6970987,6970988,6970722,6382960,6382961,6667548,6398670,6401983,6401983,6437878,6677100,6407680,6407681,6679963,6985249,6985514,6414372,6414376,6414376,6414377,6414378,6414380,6414377,6414381,6683427,6683262,6683295,6683311,6683329,6916750,6515884,6683264,6760476,6683300,6495654,6471747,6711856,6473772,6473774,6473774,6473773,6528370,6606617,6712994,6712996,6713009,6712962,6712998,6474885,6474908,6713566,6480180,6480181,6528553,6716214,6558660,6558734,6558809,6755383,6568273,6568273,6568274,6568276,6760246,6760362,6993700,6760120,6760244,6760120,6571977,6572055,6572099,6581417,6576926,6576912,6576925,6576926,6576926,6576927,6576927,6576928,6576929,6576929,6576930,6576930,6576931,6576913,6576927,6576929,6576929,6576930,6576928,6576929,6576932,6764537,6764573,6764573,6764587,7070138,6576942,6576943,6764447,6764539,6764540,6764574,6764588,6764588,7070136,7070139,6576944,6576946,6580872,6764541,6764588,6764590,6582040,6764447,6764595,6764450,7069875,6764590,6764651,6742054,6764449,6764750,6764449,7070143,7070144,6582043,6764449,6764450,6764452,6582968,6627445,6584813,7045347,6587145,6587146,6587146,6587135,6587147,6587146,6587147,6587148,6587148,6769276,6769831,6663304,6754902,6769552,6769553,6769554,6769554,6769555,6769555,6769556,6769648,6769649,6769697,6769712,6769794,6769819,7074983,7075248,7075248,7075249,6590738,6590826,6590828,6590835,6590907,6590920,6590927,6590927,6771444,6771601,6590940,6749052,6608209,7085779,6617392,6617392,6784680,6784820,6671920,6811939,6699582,6825926,6704897,6704898,6704911,6828563,7105390,6828582,6711242,6711373,6711503,6909038,6739462,6739464,6739464,6739465,6739466,6739466,6739467,7151408,6845714,6845715,6845808,6845809,6845842,6845869,7151406,7151408,6907180,6907252,6907326,6929776,6922657,6922659,6922660,7243003,7170893,7243004,6951404,6951405,6951405,6951683,6951682,6951684,6951960,6951949,6951962,6951962,6951949,6951950,6951952,6951956,6951958,6951961,6951963,6951965,6951949,6951950,6951962,6951963,6951950,6951951,6951952,6951959,6951961,6951962,6951964,6951951,6951952,6951962,6951962,6951963,6951963,6951964,6951964,6951967,6951952,6951962,6951963,6951963,6951964,6951964,6951965,6951967,6951967,6951962,6951963,6951965,6951965,6951967,6951968,6951966,6951968,6951965,6951966,6951968,6951969,6951967,6951969,6951971,6951958,6951970,6951970,6951969,6951971,6951971,6952055,7542356,6952087,6951973,6951975,6952090,6952091,7257656,6951974,6951976,6951978,6952149,7185544,7257655,6951975,6951976,6951979,6952055,6952105,6952123,6952134,6952234,6952240,7257655,7257657,7606122,6951977,6951997,6952091,6952092,6951977,6951980,6952054,6952090,6952266,7257656,6951980,6951980,6951999,6952057,6952057,6952058,6952059,6952060,6952092,6952093,6952104,6952106,6952106,6952112,6952121,6952124,6952137,6952168,6952213,6952218,6952233,6952237,7029269,7054480,7185544,7257392,7257654,7257656,7257658,7257658,7257659,7296733,6951980,6952059,6951982,6952059,6952060,6952060,6952061,6952096,6952096,6952120,6951983,6952049,6952059,6952059,6952060,6952060,6952061,6952062,6952062,6952063,6952093,6952094,6952095,6952096,6952097,6952108,6952109,6952168,6952227,6952236,6952237,6952243,7257659,7257660,6952061,6952128,6952028,6952027,6952028,6952029,6952030,6952034,6952087,6952088,6952086,6952088,6952089,6952124,6952124,6952125,6952091,6952074,6952147,6952139,6952140,6952144,6952145,6952147,6952146,6952149,6952136,6952137,6952137,6952140,6952147,6952149,6952138,6952147,6952150,6952138,6952139,6952150,6952140,6952151,6952151,6952142,6952152,6952152,6952153,6952153,6952179,6952182,7257480,7257748,6952215,6952181,6952182,6952182,6952183,6952184,6952184,6952185,6952187,6952198,6952198,6952199,6952205,6952213,6952214,6952216,6952216,6952217,6952236,6952261,6952262,6952271,6952275,6952291,6952292,6952293,6952300,6952303,6952306,6952308,6952311,6952311,6952312,6952315,6952320,6952326,6952332,6952333,7029362,7054572,7185637,7257482,7257484,7257486,7257745,7257747,7257748,7257748,7257749,7257750,7257750,7257751,6952202,6952215,6952201,6952203,6952204,6952214,6952215,6952216,6952217,6952214,6952216,6952228,6952217,6952205,6952208,6952217,6952219,6952207,6952217,6952218,6952219,6952220,6952218,6952218,6952219,6952220,6952219,6952220,6952220,6952220,6952276,7244900,6952286,6952313,7257517,6952230,6952352,7257784,6952231,6952231,6952232,6952232,6952233,6952233,6952234,6952243,6952248,6952248,6952268,6952315,6952360,6952386,7029395,7096635,7159966,7185671,7185671,7185672,7257517,7257518,7257780,7257780,7257781,7257782,7257782,7257783,7257783,7257784,7257784,6952248,6952249,7257784,6952233,6952247,7257782,7257784,7257784,7257785,7257785,6952233,6952234,6952240,6952248,6952249,6952250,6952234,6952235,6952236,6952237,6952244,6952245,6952246,6952246,6952247,6952247,6952248,6952249,6952249,6952250,6952250,6952266,6952240,6952247,6952250,6952250,6952251,6952251,6952253,6952250,6952250,6952275,6952250,6952254,6952263,6952283,6952251,6952255,6952257,6952252,6952255,6952295,6952255,6952274,6952273,6952267,6952273,6952260,6952261,6952273,6952274,6952262,6952272,6952274,7029412,7257798,6952262,6952262,6952276,6952264,6952267,6952330,7257800,6952264,6952265,6952265,6952267,6952268,6952278,6952279,6952279,6952283,6952285,6952291,6952301,6952316,6952356,6952371,6952377,6952379,6952384,6952408,7029413,7257534,7257799,7257799,7257800,7257801,7257802,6952265,6952266,6952267,6952268,6952277,6952278,6952280,6952281,6952282,6952288,6952290,6952292,6952293,6952350,6952356,6952364,6952379,6952379,6952384,6952394,7005748,7029414,7155355,7185688,7185688,7185689,7191589,7244920,7257535,7257535,7257799,7257799,7257800,7257800,7257801,7257801,7257802,6952266,6952267,6952268,6952281,6952281,6952282,6952283,6952283,6952284,6952284,6952332,6952334,6952382,6952411,7005748,7054621,7257536,7257799,7257801,6952269,6952279,6952281,6952283,6952285,6952298,6952308,6952375,7185689,7257536,7257803,7257802,6952284,6952285,6952289,6952285,6952317,6952330,6952331,6952271,6952283,6952286,6952286,6952287,6952290,6952306,6952309,6952313,6952314,6952315,6952318,6952318,6952320,6952324,6952324,6952327,6952328,6952329,6952329,6952331,6952331,6952332,6952333,6952334,6952338,7185691,6952276,6952327,6952354,7257805,6952296,6952336,6952341,6952388,7257810,6952330,7104997,6952380,7185702,7257813,7257814,6952296,7185703,7257812,6952295,7257813,6952356,6952392,6952296,6952351,6952296,6952297,8331825,6952335,6952374,7257817,6952353,7257551,6952425,7257816,7257818,6952403,7170567,7185706,7257552,7257815,7257818,6952373,6952384,7542522,6952331,6952332,7257818,7257818,6952325,6952395,7257820,7257821,6952313,6952350,6952352,6952407,7257820,7257821,6952360,6952378,6952369,6952310,6952350,6952363,6952319,6952373,6952358,7257560,6952380,6952379,6952381,6952366,6952384,6952397,6952374,6952384,6952373,6952421,6952371,6952399,6952407,6952416,6952353,6952412,6952368,6952398,6952418,7257847,6952361,6952432,6952402,6952362,6952413,7257581,7257847,7257848,6952367,7257845,6952367,6952430,6952379,6952382,6952389,6952390,6952428,7185739,7257850,6952411,7257854,6952412,7257854,6952412,6952419,7029467,7257591,7185744,6952451,6952424,6952383,6952427,7257859,7257860,6952387,6952448,6952388,6952395,6952387,6952390,6952395,6952434,6952438,6952448,11100995,6952402,7005808,6952420,6952433,6952438,7185752,7257863,6952457,7257862,7257863,7257865,6952410,6952438,6952449,6952473,7257863,6952441,7043027,6952442,6952445,6952461,6952462,7185754,7257864,7257868,6952462,6952459,7257867,6952446,6952412,7257870,6952453,6952460,6952424,7257871,7257872,6952456,6952439,6952458,6952440,6952467,6952460,7257876,6952421,7257611,6952466,6952440,6952465,6952479,6952463,6952477,6952455,6952430,6952458,6952486,6952507,7029496,6952444,6952470,6952500,6952469,6952503,6952510,6952466,6952464,7257887,6952474,6952497,6952507,7185779,7257891,7043049,7257890,7185779,6952510,6952515,6952516,6952457,6952470,6952494,6952454,7257628,6952471,6952503,6952518,6952516,6952480,6952521,7257893,7257895,6952477,6952521,6952523,6952498,6952476,6952524,6952476,6952510,6952524,6952476,6952525,6952526,7257900,6952526,6952527,7257903,6952483,6952527,6952515,6952528,7185792,7105740,6952529,6952530,6952483,6952493,6952531,6952532,6952494,7257907,6952485,6952534,7257912,6952530,6952535,6952491,6952494,6952492,6952521,6952491,6952492,6952494,6952536,7257914,6952492,6952493,6952496,6952531,6952537,6952538,7257649,6952538,7029526,11101047,6952495,6952500,6952501,6952538,6952542,6952500,6952511,6952518,6952522,6952538,6952539,6952539,6952526,6952540,6952498,6952540,6952540,6952541,6952541,6952541,6952505,6952542,6952543,6952543,6952544,7185807,6952504,6952507,6952527,6952544,6952513,6952541,6952544,6952545,6952545,7029533,6952536,6952545,6952546,6952546,6952520,6952520,6952529,6952546,6952547,7257924,6952547,7257923,6952547,6952548,7257925,7185812,6952551,7257924,7185814,6952522,6952552,7257929,7257930,6952532,6952557,7185819,7257931,7257931,6952556,7257934,7257935,6952559,7257936,6952560,7257671,7257938,6952542,6952548,6952564,6952564,7257673,6952567,6952566,6952567,6952568,6952569,6952571,7245064,6952570,6952570,6952570,6952571,6952569,6952572,7185833,6952570,7257947,7029564,6952576,7257954,7185844,7257952,6952578,7185842,6952580,6952582,7257692,6952582,7257960,6952584,6952584,6952586,7054782,7185847,7185848,7185848,7185849,7257694,7257694,7257957,7257958,7257958,7257959,7257959,7257960,7257960,7257961,7068054,7257695,7257958,7257960,6952586,6952586,7029574,7054782,7054783,7068058,7160143,7160145,7185848,7185850,7185850,7191749,7217470,7257695,7257957,7257957,7257958,7257958,7257959,7257959,7257960,7257961,7257961,7257962,7274988,7005908,7029572,7185848,7245080,7245081,7257959,7257960,7257961,7257961,11101950,7185849,7185850,7257960,7257960,7257697,7257697,7257961,7257695,7257963,7257964,7059241,7059242,7059244,7059246,7311296,7082910,7311299,7298325,7311295,7106574,7106575,7106576,7106576,7106576,7106577,7106577,7106577,7106578,7106579,7334963,7334698,7334961,7334962,7334963,7256230,7262853,7262853,7334699,7334962,7334963,7334963,7334964,7334965,7334965,7133655,7133699,7133702,7133743,7276429,7348539,7348542,7156994,7156995,7156996,7156997,7156998,7359908,7360172,7360173,7360174,7183543,7183546,7373446,7373447,7373449,7241055,7402200,7257718,7410531,7259018,7411183,7358458,7460904,7367717,7367719,7367720,7367719,7367721,7367719,7465532,7465533,7465536,7465537,7465538,7388910,7389014,7389108,7476256,7405880,7418403,7419111,7419126,7419126,7419127,7419127,7419126,7419127,7419127,7419128,7419129,7419129,7419128,7419128,7419129,7419129,7419130,7419129,7419134,7419142,7419142,7490973,7491236,7491236,7491238,7491239,7491240,7490973,7490974,7491236,7491236,7491237,7491238,7491239,7491240,7491241,7491241,7459487,7490973,7490974,7490975,7491237,7491238,7491239,7491239,7491240,7491240,7491241,7490975,7491237,7491238,7491239,7491239,7491240,7491241,7491239,7491241,7491243,7429935,7429935,7496644,7496378,7430925,7430926,7430925,7496871,7497137,7497138,7482364,7482492,7482620,7522982,7499847,7531600,7505877,7505885,7534615,7534618,7537400,7537495,7537587,7537588,7537590,7550465,7550467,7550468,7550469,7550470,7562817,7562803,7562804,7562817,7562819,7562818,7562818,7562805,7562805,7562820,7562820,7562821,7562806,7562819,7562820,7562821,7562821,7562821,7562822,7562822,7562824,7563085,7563007,7563085,7563085,7562836,7563085,7563085,7563086,7562836,7563007,7563083,7563084,7563085,7563085,7563086,7563086,7563087,7563087,7563089,7562837,7563084,7563085,7563085,7563086,7563086,7563087,7563087,7563089,7563088,7563088,7563188,7563190,7563266,7563268,7563333,7563330,7563331,7563331,7563330,7563331,7563331,7563334,7563334,7563332,7563332,7563333,7563333,7563334,7563334,7563335,7563336,7563333,7563333,7563334,7563334,7563335,7563335,7563333,7563334,7563334,7563335,7563335,7563336,7563336,7563350,7563334,7563335,7563335,7563336,7563336,7563337,7563337,7563349,7563351,7563335,7563336,7563336,7563337,7563337,7563338,7563349,7563351,7563336,7563337,7563337,7563338,7563338,7563350,7563351,7563352,7563353,7563354,7563337,7563338,7563338,7563351,7563352,7563352,7563338,7563339,7563339,7563340,7563351,7563352,7563353,7563353,7563354,7563354,7563355,7563356,7563357,7563339,7563340,7563340,7563341,7563351,7563351,7563352,7563352,7563353,7563353,7563354,7563354,7563355,7563356,7563357,7563357,7563358,7563340,7563341,7563342,7563351,7563352,7563352,7563353,7563353,7563354,7563354,7563355,7563355,7563356,7563356,7563357,7563358,7563341,7563342,7563350,7563351,7563352,7563352,7563353,7563353,7563354,7563354,7563355,7563355,7563356,7563356,7563357,7563357,7563358,7563358,7563359,7563342,7563351,7563352,7563353,7563353,7563354,7563354,7563355,7563355,7563356,7563356,7563357,7563357,7563358,7563359,7563353,7563355,7563356,7563354,7563362,7563363,7563365,7563367,7563363,7563365,7563366,7563366,7563369,7602426,7563364,7563365,7563365,7563366,7563366,7563367,7563367,7563368,7563368,7563370,7943782,8213347,11406542,7563365,7563366,7563366,7563367,7563367,7563368,7563366,7563367,7563367,7563368,7563368,7563369,7563369,7563371,7563371,8637360,7563367,7563368,7563368,7563369,7563369,7563370,7563370,7563371,7957061,7563368,7563369,7563369,7563370,7563370,7563371,7563372,7563372,7777999,7848056,7848056,7848057,8213349,8637234,8637361,7563369,7563370,7563370,7563371,7563372,7563372,7563373,7602429,7692358,7848056,7848057,7848057,7957062,7958453,8213495,8337078,8494495,7563370,7563371,7563371,7563372,7563372,7563373,7563374,7563374,7602429,7701579,7741836,7848057,7848058,7943784,8637361,9941102,11406486,7563371,7563372,7563372,7563373,7563373,7563374,7563374,7602430,7778001,7848057,7848058,7848058,7848059,8213350,8213351,8637361,8637363,8637364,9280365,7563372,7563373,7563373,7563374,7563374,7563375,7701579,7701580,7720178,7778001,7848058,7848058,7848059,7848060,7943786,8213351,8418211,8637362,7563373,7563374,7563374,7563375,7563375,7602431,7701580,7701580,7701581,7778002,7778074,7848058,7848058,7848059,7848059,7848060,7868971,7943786,7943787,8213351,8213352,8494497,8494498,8637236,8637361,8637362,8637363,8637363,8637364,7563374,7563375,7563375,7563376,7778002,7848059,7848059,7848060,8637362,8637363,7563375,7563376,7563376,7563377,7563377,7602432,7720182,7778003,7835398,7848059,7848060,7848060,7848061,7848061,7987649,8213352,8213354,8247924,8296272,8337081,8494499,8576827,8637237,8637363,8637363,8637364,8637365,7563376,7563377,7602147,7602432,7611141,7665561,7701581,7701582,7760973,7778003,7778075,7809058,7848060,7848060,7848061,7848061,7848062,7943787,7943788,8199937,8213353,8213353,8213354,8213497,8450605,8494499,8494499,8601037,8637238,8637362,8637363,8637365,8637368,8638847,9257004,9280368,9280368,7563377,7602433,7633015,7701582,7704739,7720180,7720183,7720184,7742821,7778004,7845811,7848060,7848061,7848061,7848062,8036578,8213353,8213498,8637238,8637363,8637365,7563378,7563379,7572161,7580361,7602433,7634957,7665558,7665562,7701582,7701583,7720184,7742821,7778076,7779029,7785914,7836167,7836168,7848060,7848061,7848061,7848062,7848062,7848063,7882715,8072427,8213354,8213355,8213497,8296671,8418213,8637239,8637365,8637365,8637366,7778005,7848062,7848062,7602434,7848062,7848063,7580957,7965859,7597395,7597430,8230388,7633829,7640961,7641028,7641123,7886969,7641490,7641500,7641499,7641500,7641501,7641501,7641509,7641510,7641511,7704629,7704630,7874466,7887128,7887128,7887129,7887129,7982856,8026717,8169009,8252421,8312040,8312042,8533567,8676431,8676432,8676437,9226291,9294231,9393685,7658915,7658982,7658983,7659048,7659050,7895901,7895902,7670263,7901541,7702664,11476188,7706552,7773177,7767754,7767758,7767758,7767760,7950256,8315549,7950257,8219429,7821387,7977086,7839787,7839800,7839800,7839801,7839802,7839802,7839803,7839800,7839801,7839803,7839804,7839801,7839801,7839804,7986278,7986279,7985437,7986279,7986280,8351716,7986279,7986280,7916296,7984035,7986280,7986281,7986282,7986282,7986281,7986282,7839821,7880066,7986283,7846117,7989438,7877001,7877002,7877004,7877004,7877009,8004881,8004881,8004881,8004881,8004886,7920321,7920328,8391835,8026544,7922266,7922296,7922298,8027536,7958646,7958729,7958804,8045809,7992640,7992641,7992641,7992642,7992714,7992714,7992715,7992715,7992716,7992715,7992716,7992715,7992716,7992716,7992787,7992787,7992787,7992788,7992789,7992789,7992789,7992790,7992790,8062770,8062771,8062771,8062772,8328799,8062772,8062772,8062773,7994693,8063725,8008461,8070608,8054749,8054847,8054946,8068476,8082012,8107386,8107430,8107496,8120092,8107635,8107769,8120291,8108970,8108971,8120864,8128258,8128268,8130507,8130513,8131071,8131200,8131328,8132041,8132743,8132743,8132744,8132744,8132744,8132745,8132745,8132746,8132758,8132758,8132759,8132759,8132760,8132760,8132745,8132746,8132746,8132747,8132759,8132759,8132760,8132760,8132761,8132761,8132746,8132747,8132759,8132759,8132760,8132760,8132761,8132761,8132747,8132748,8132748,8132759,8132760,8132760,8132761,8132761,8132762,8132762,8132748,8132749,8132755,8132759,8132760,8132760,8132761,8132761,8132762,8132762,8132763,8132761,8132762,8132761,8132765,8133023,8132772,8132772,8132772,8132773,8498051,8132773,8132774,8132774,8132775,8132775,8167409,8498051,8498052,8922062,8132774,8132775,8132775,8132776,8132776,8183092,8228486,8228487,8272350,8493884,8498052,8498052,8498053,8498198,8557671,8921937,8922063,8922064,8922067,9149111,9413475,9565065,10563211,8132775,8132776,8132776,8132777,8185548,8228487,8228487,8228488,8272351,8281231,8281242,8318935,8318936,8417532,8493884,8498052,8498053,8498053,8498054,8498198,8557672,8557714,8557716,8581367,8690050,8702911,8779198,8921937,8922063,8922063,8922064,8922064,8922065,8922065,8922067,9565065,9565068,11692045,8132776,8132777,8132777,8132778,8135569,8135571,8167414,8183093,8190863,8225699,8228487,8228488,8228488,8228489,8243157,8272350,8272350,8272351,8272351,8281238,8398788,8474889,8493883,8493884,8498052,8498053,8498053,8498054,8498058,8498197,8498198,8574172,8621782,8702912,8779199,8921938,8922063,8922064,8922065,8922065,8922066,10563213,8132777,8132778,8132779,8132780,8162016,8167414,8183093,8187179,8196522,8225699,8228488,8228488,8228489,8241763,8272351,8272351,8318934,8334973,8474882,8483266,8493880,8494738,8497680,8498052,8498053,8498053,8498054,8532625,8557673,8581370,8621782,8662644,8702912,8779199,8779199,8779200,8921938,8922062,8922063,8922064,8922064,8132778,8135572,8167416,8183094,8212748,8228488,8228489,8241767,8272350,8272352,8272354,8398789,8493884,8493884,8498054,8498054,8498055,8498057,8574176,8702913,8779199,8779200,8921938,8921939,8922063,8922065,8922065,8220986,8220987,8228489,8228490,8498054,8498055,8498055,8779200,8921939,8922065,8922066,8922068,8498057,8133279,8133289,8557934,8138375,8138379,8500859,8231296,8500861,8174640,8943031,8191268,8271013,8202060,8202065,8202066,8202066,8202067,8202069,8202067,8956713,8202136,8956715,8956590,8263140,8532706,8263143,8202203,8532771,8233419,8233420,8233422,8233424,8233552,8233553,8233552,8753241,8278819,8233682,8233684,8544343,8548512,8548513,8238336,8550841,8241652,8241751,8241850,8326922,8248962,8556152,8260284,8260281,9628826,8561961,8292734,8578040,8309206,8309206,8309290,8837659,8309373,8582186,8318635,8318637,8590989,8321425,8324200,8324209,8324210,8324211,8324212,8324212,8324213,8324213,8324214,8324210,8324212,8324213,8324210,8324211,8324212,8324213,8324214,8324215,8324220,8324222,8324308,8324309,8324312,8324308,8324309,8324225,8324310,8338880,8368075,8414660,8589608,8593777,8593777,8593924,8653396,8677091,8593404,8593777,8593778,8414661,8593778,8669900,8593778,8653398,8368076,8593779,9017790,8324406,8324397,8324407,8324407,8324414,8593873,8593874,8653497,9017758,9418443,8758467,8350760,8350762,8350763,8350766,8607052,9030937,8381348,8607053,9031064,9031065,8353549,8353550,8353551,8577202,8608446,8411932,8411934,8411937,8411936,8411937,8411937,8411937,8411937,8411938,8411939,8411938,8411939,8411942,8458520,8637638,8426008,8637639,9061650,8420829,8637640,8637641,8918786,8521059,8637640,8637641,8637642,8637640,8429705,8429726,8429719,8646526,8646530,8646531,8646541,8440080,8472595,8505107,8505108,8505108,8505110,8505108,8505109,8505110,9108235,9108236,8637282,8684225,9108110,8767540,8600815,8684229,8509792,8686568,8537183,8700264,8581513,8782104,8630183,9170649,8664809,8664810,8664891,8664893,8664894,8664975,8664977,8664977,8764158,8764159,8764159,8671101,8767222,8696516,8779928,8702304,8782824,8769455,8816398,8800880,8800955,8801029,8832198,8817010,8817015,8817017,9121325,8840181,8840182,8833767,8848555,8836513,9273940,8855001,8855004,8855005,8855005,8855004,8855006,8855007,8855008,8855007,8859173,8859174,8918797,9283059,8859172,8859175,8859176,8859176,8856715,8860030,8862599,8862972,8863118,8863327,8863329,8863341,8863341,8863330,8863331,8863331,8863332,8863332,8863339,8863340,8863340,8863341,8863341,8863342,8863342,8863343,8863343,8863344,8863348,8863331,8863332,8863332,8863333,8863340,8863340,8863341,8863342,8863342,8863343,8863344,8863344,8863345,8863346,8863349,8863332,8863333,8863333,8863340,8863341,8863341,8863342,8863343,8863343,8863344,8863344,8863345,8863333,8863341,8863341,8863342,8863342,8863343,8863343,8863344,8863348,8863334,8863342,8863342,8863344,8863342,8863343,8863348,8863357,8863349,8863350,8863351,8863352,8863479,8863484,8863485,8863485,8863350,8863351,8863351,8863352,8863352,8863354,8863359,8863484,8863484,8863485,8863486,8863486,8863487,8863488,8863488,8863351,8863352,8863352,8863353,8863353,8863354,8863354,8863355,8863355,8863483,8863484,8863485,8863485,8863486,8863486,8863487,8863487,8863488,8863488,8863489,8863352,8863353,8863353,8863354,8863355,8863356,8863357,8863359,8863486,8863486,8863487,8863353,8863354,8863355,8863483,8863486,8863486,8863487,8863487,8863488,8863488,8863489,8863354,8863355,8863355,8863356,8863356,8863357,8863360,8863486,8863486,8863487,8863487,8863488,8863488,8863489,8863489,8863490,8863491,8863355,8863356,8863356,8863357,8863358,8863486,8863487,8863487,8863488,8863488,8863489,8863489,8863490,8863490,8863491,9068201,9287353,8863356,8863357,8863357,8863487,8863488,8863488,8863489,8863490,8863491,8863357,8863358,8863358,8863359,8863487,8863488,8863488,8863489,8863489,8863490,8863493,9144489,8863358,8863361,8863487,8863488,8863489,8863489,8863490,9287355,8863360,8863360,8863361,8863361,8863489,8863489,8863490,8863491,8863491,8863493,8863490,8863490,8863491,8863493,8863489,8863490,8863491,8863492,8863492,8863493,9287230,8863491,8863489,8863492,8863494,8863492,8863492,8863367,9287358,8863492,8863493,8863494,8863494,8863497,9144497,8863619,8863618,8863617,8863617,8863619,8863631,8863618,8863619,8863619,8863620,8863622,8863633,8863619,8863620,8863620,8863621,8863621,8863622,8863634,8863620,8863621,8863621,8863622,8863622,8863623,8863623,8863633,8863633,8863634,8863634,8863621,8863622,8863622,8863623,8863623,8863624,8863624,8863625,8863632,8863633,8863633,8863634,8863634,8863635,8863622,8863623,8863623,8863624,8863624,8863625,8863633,8863634,8863634,8863635,8863635,8863623,8863624,8863624,8863625,8863634,8863634,8863635,8863636,8863624,8863625,8863625,8863626,8863633,8863633,8863634,8863634,8863635,8863635,8863636,8863636,8863625,8863626,8863626,8863635,8863635,8863636,8863636,8863637,8863626,8863627,8863627,8863628,8863634,8863634,8863635,8863635,8863636,8863636,8863637,8863637,8863627,8863628,8863628,8863635,8863636,8863636,8863637,8863637,8863638,8863628,8863629,8863635,8863636,8863636,8863637,8863637,8863638,8863638,8863629,8863636,8863637,8863637,8863638,8863638,8863639,8863636,8863637,8863638,8863639,9287365,8863644,8863645,8863644,8863645,8863645,8863644,8863645,8863645,8863646,8863646,9068346,8863645,8863646,8863646,8863647,8898059,8923008,8939611,8946805,9144633,9144634,9287372,9287496,9287498,9287498,9287499,9287500,8863646,8863647,8863647,9068347,9287499,8863647,8863648,8898060,8923150,9144634,9287373,9907140,9930503,8863648,8863649,8898061,8923108,8923109,8987218,9028079,9068348,9076642,9144634,9144635,9144635,9287374,9287498,9287499,9287500,9287502,9287503,9287505,9523846,9930502,9930504,12056675,12057481,8863649,8874139,8877446,8898061,8923010,8923011,8923109,8923109,8923110,8923110,8923150,8923151,8923151,8939612,8946801,8946803,8946804,8946804,8946805,8987218,8987220,8987240,8992689,9028080,9055475,9068348,9072921,9100743,9144633,9144634,9144634,9144635,9144635,9144636,9165278,9251170,9251173,9287374,9287374,9287498,9287499,9287500,9287500,9287501,9287501,9287502,9287506,9394972,9579040,9778911,9930501,9930504,10017650,10928650,11571640,12056675,8923109,8923112,8932507,9068349,9068349,9287375,9287500,8884643,9941009,8891253,8891335,8891416,8936997,8932485,8957573,8957574,9102772,9179060,9321798,9321798,9321921,9321924,8982383,8982382,8982383,8982384,8982524,8982525,8982526,8982527,8982579,8982580,8982580,8982581,8982581,8982582,8982582,8982583,8982589,8982570,8982583,8982583,8982584,8982595,8982590,8982589,9127819,9204106,8982623,9346971,8982592,8982598,8982625,9127820,9183296,8982593,8982624,9204107,9346973,8982595,8982595,8982601,8982624,8982625,9006275,9046691,9346973,8982624,8982625,8982623,8982624,8982625,8982625,8982626,9204109,11631112,8982626,9204109,9204110,8982630,9204113,9114955,9989984,9346983,8982663,8982661,8982664,8982664,8982654,8982665,8982665,8982655,8982666,8982657,8982666,8982666,8982667,8982673,8982674,9006319,8999126,9127862,9114989,9127862,9160257,9160258,9164306,9257672,9346888,9347013,9347014,9347014,9347015,9347019,9347020,9493397,9574061,9990015,10424265,10500593,10988164,11785105,9347021,9347020,9001380,9137222,9015585,9015590,9015590,9015592,9363475,9144326,9327151,9363479,9144327,9220614,9723161,9029182,9370273,9029971,9029971,9029970,9029970,9029973,9029974,9029975,9029976,9029976,9029979,9029981,9029980,9370541,9227803,9227805,9370544,9370670,9151519,9370545,9151520,9370546,9134839,9151521,9370547,9151522,9110789,9110824,9110826,9110862,9110827,9110831,9110850,9179081,9411106,9411107,9116296,9411107,9110903,9110904,9110976,9110978,9111066,9111097,9411058,9411186,9111270,9111329,9268484,9411375,9121741,9121741,9121742,9197400,9197401,9416428,9192523,9192523,9192524,9192525,9192526,9451817,12221119,9232792,9451819,9232794,9415619,9239697,9332666,9247323,9247324,9247336,9260197,9312398,9479349,9479350,9776062,9273048,9273049,9273059,9273060,9273061,9273062,9273062,9273063,9273063,9273066,9273068,9273063,9273064,9273069,9273065,9342570,9492085,9492211,9273074,9349346,9349347,9492086,9492086,9492212,10135215,9273075,9273076,9273076,9273077,9349348,9492087,9492213,9492213,9492215,9273077,9273077,9273079,9349348,9349349,9492088,9492213,9492215,9273077,9349349,9492214,9492214,9273078,9273081,9349349,9349349,9349350,9349350,9492089,9492213,9492214,9492215,9273080,9273081,9303550,9349351,9455888,9492089,9492089,9492093,9492215,9492215,9635535,9492091,9349352,9492216,9492217,9492218,9492094,9492220,9282204,9353919,9289649,9500506,9334034,9522699,9337848,9337849,9337850,9337850,9381741,9524481,9524607,9345948,9528658,9366110,9538735,9377463,9544414,9384013,9547563,9412098,9561613,9425635,9425620,9425634,9425635,9425620,9425633,9425633,9425635,9425635,9425636,9425621,9425622,9425635,9425636,9425636,9425637,9425622,9425623,9425633,9425634,9425634,9425637,9425637,9425635,9425637,9425638,9425638,10211503,9568373,9568498,9568373,9568498,9425650,9568374,9425651,9479156,9568375,9568501,9479158,9568375,9568375,9568501,9568502,9425652,9568376,9568501,9568502,9568503,9714883,9479158,9532175,9568376,9568376,9568501,9568502,9568502,9568503,9568504,9586923,9945025,10211506,11629279,13913992,9466924,9589020,9532676,9532676,9532678,9532679,9622020,9622021,9622021,9621896,9590322,9650860,9638706,9638709,9638709,9674910,9675036,9675036,9675041,9711099,9711108,9711109,9711111,9711112,9711100,9711109,9711110,9711110,9711111,9711111,9711112,9711112,9711113,9711110,9711117,9711235,9711119,9711120,9711121,9711121,9711122,9711123,9711233,9711233,9711234,9711234,9711235,9711235,9711236,9711236,9711237,9711240,9711241,9711242,9711242,9711121,9711121,9711122,9711122,9711123,9711125,9711234,9711235,9711235,9711236,9711236,9711237,9711237,9711238,9711239,9711242,9711236,9711237,9711235,9711236,9711237,9711123,9711124,9711236,9711237,9711237,9711239,9711240,9711124,9711125,9711235,9711236,9711236,9711237,9711237,9711238,9711238,9711243,9711236,9711237,9711237,9711238,9711238,9711240,9711241,9711238,9711238,9711239,9711239,9711242,9711243,9711348,9711349,9711348,9711349,9711350,9711350,9711350,9711351,9711352,9711356,9711364,9711350,9711351,9711351,9711352,9711353,9711365,9711351,9711352,9711352,9711353,9711354,9711354,9711355,9711356,9711356,9711357,9711358,9711366,9711367,9711368,9711369,9711369,9711352,9711353,9711353,9711354,9711354,9711355,9711355,9711356,9711356,9711357,9711357,9711358,9711358,9711359,9711359,9711360,9711361,9711365,9711366,9711367,9711367,9711368,9711368,9711369,9711369,9711370,9711372,9711353,9711354,9711354,9711355,9711356,9711357,9711357,9711358,9711358,9711359,9711362,9711364,9711364,9711366,9711368,9711368,9711372,9711373,9711354,9711355,9711355,9711356,9711356,9711357,9711357,9711358,9711358,9711359,9711362,9711365,9711367,9711368,9711368,9711369,9711369,9711355,9711356,9711356,9711357,9711357,9711358,9711358,9711359,9711359,9711360,9711360,9711363,9711364,9711366,9711367,9711368,9711368,9711369,9711369,9711370,9711370,9711371,9711373,9711374,9711356,9711357,9711357,9711358,9711358,9711359,9711359,9711369,9711357,9711358,9711358,9711359,9711359,9711360,9711369,9711370,9711371,9711375,9711375,9711358,9711359,9711359,9711360,9711360,9711361,9711361,9711362,9711363,9711369,9711370,9711371,9711371,9711372,9711375,9711376,9711359,9711360,9711360,9711361,9711361,9711362,9711362,9711366,9711370,9711371,9711371,9711372,9711374,9711375,9711376,9711376,9711360,9711361,9711361,9711362,9711362,9711364,9711370,9711371,9711371,9711372,9711372,9711373,9711374,9711376,9711377,9711361,9711362,9711362,9711363,9711363,9711364,9711364,9711372,9711372,9711373,9711376,9711377,9711377,9711362,9711363,9711363,9711364,9711364,9711367,9711371,9711372,9711372,9711373,9711374,9711375,9711376,9711377,9711377,9711378,9711363,9711364,9711364,9711365,9711366,9711366,9711369,9711370,9711371,9711371,9711372,9711372,9711373,9711373,9711374,9711374,9711375,9711375,9711376,9711377,9711377,9711378,9711378,9711364,9711365,9711365,9711366,9711367,9711368,9711370,9711371,9711372,9711373,9711373,9711374,9711374,9711375,9711375,9711376,9711377,9711378,9711378,9711379,9711365,9711366,9711367,9711369,9711371,9711371,9711372,9711372,9711373,9711373,9711374,9711374,9711375,9711376,9711378,9711378,9711379,9711366,9711367,9711367,9711369,9711372,9711373,9711374,9711374,9711375,9711377,9711378,9711379,9711367,9711372,9711374,9711375,9711380,9711368,9711369,9711373,9711374,9711375,9711375,9711380,9711371,9711374,9711375,9711375,9711376,9711376,9711371,9711375,9711376,9711381,9711377,9711377,9711372,9711373,9711375,9711376,11352512,9711378,10864941,9711377,9711378,9711378,9711379,9711380,9711379,9711380,9711377,9711380,9711380,9711381,9711385,9711380,9711380,9711382,9711379,9711380,9711380,9711381,9711381,9711385,9711386,10354369,9711381,9711381,9711383,9711385,10557058,9711381,9711382,9711382,9711383,9711386,9711387,9857750,10002905,9711382,9711383,9711383,9711384,9711384,9711385,9711386,9711387,9711387,9711388,10354371,9711383,9711384,9711384,9711385,9711385,9711386,9711387,9711387,9711388,9711388,9719597,9829193,9857748,9938414,9938416,10091252,10354371,10354372,10698863,10788618,10865483,10865484,11139843,12480493,9711384,9711385,9711385,9711386,9711386,9711387,9711387,9711388,9711388,9711389,9719600,9938415,9938416,10091907,10111927,10146549,10331007,10354371,10354372,10429230,10788618,10865483,11352515,11995506,9711385,9711386,9711386,9711387,9711388,9711388,9711389,9711389,9719601,9938416,10354371,10354372,10354373,10816846,9711386,9711387,9711387,9711388,9711388,9711389,9711389,9711390,9711390,9884371,9938416,9947714,10087892,10354370,10354373,9711387,9711388,9711388,9711389,9711389,9711390,9711390,9711391,9719601,9995813,10354372,10354373,11928798,11995507,9711388,9711389,9711390,9711390,9711391,9711391,9719601,9938417,10354373,9711390,9711390,9711391,9711391,9711392,9766146,9819273,9938417,9947715,9995814,10154150,10261734,10331011,9711390,9711391,9711391,9711392,9711391,9711392,9711392,9711392,9711393,9995816,10354376,11995511,12480497,9711393,9711394,9719603,9719605,9766240,9776229,9787589,9787908,9829197,9857754,9947717,9969029,9995816,10007622,10008087,10087895,10087895,10091911,10111931,10111932,10154152,10154156,10202783,10202785,10202870,10260180,10328950,10331007,10331011,10331013,10354374,10354375,10354375,10354376,10354376,10354377,10373474,10526692,10537232,10579512,10698868,10865489,10865491,11352521,11352522,11352522,11772153,11995510,12480498,9711394,9711396,9719603,9719604,9719605,9719606,9719611,9722896,9729793,9766147,9766242,9766243,9787889,9829198,9854693,9857753,9872645,9883787,9929310,9938420,9938420,9947718,9947718,9947719,9969029,9982742,9995817,10006409,10006409,10007622,10037196,10050257,10087894,10087895,10091912,10091913,10091914,10111932,10111932,10113146,10146554,10154152,10154157,10202781,10202782,10202784,10202784,10202785,10202893,10249455,10261231,10305584,10331010,10331011,10331013,10335433,10354374,10354375,10354375,10354376,10354376,10354377,10354377,10402203,10537233,10698868,10742250,10865489,11064801,11199087,11225694,11352521,11352522,11352522,11683583,11761708,11776364,11776365,11995511,12480498,12480539,12480548,12480552,12481354,9711649,9719604,9719605,9719605,9766242,9766244,9773342,9776230,9787578,9829198,9933763,9938420,9938421,9947718,9962491,9995818,10007622,10008087,10034694,10087896,10111932,10111932,10154153,10154154,10202781,10202782,10202784,10202842,10260181,10261234,10331013,10331014,10345684,10354375,10354376,10354376,10354377,10354377,10354378,10642010,10698869,10788624,11166826,11225695,11352522,11352522,12480499,12480548,9719607,9711915,9872912,9714329,9714403,9714475,10262776,9727824,9727828,9727829,9727830,9727830,9727830,9727831,9727832,9727833,9727833,9727839,9774407,9955943,10362602,9955943,10179926,10339239,10873714,10162378,10211007,10362602,10362603,10362603,9946647,10014636,10100140,10362604,10362602,10120160,9734411,10365891,9748214,9748215,9748236,10372795,10372797,9820910,9820912,9821006,9821008,9820987,9821045,9821102,9821102,9821103,9821112,9821102,9821104,9821113,9821103,9821104,10385871,10409236,10144788,12535409,10409239,10409239,10166801,10664101,9835301,10009677,9841091,9841111,9841117,10395873,10395894,10419265,9863835,9863856,9864107,9864116,9864381,9864385,9864420,9864421,9864440,10024249,10039024,10430907,10505771,9926309,10438478,9927172,9927177,10368078,10462279,9947011,9947012,9947012,9947013,9947138,9947139,9947139,9947265,10056360,10086970,10472317,9998007,9998006,10497688,10497690,10004128,10004129,10004130,10004130,10004131,10475547,10094094,10349160,10500750,10500752,10033906,10033981,10034047,10109045,10162572,10056194,10260303,10057368,10057450,10057533,10527451,10147235,10147373,10147511,10549077,10156142,10170098,10165446,10165458,10165459,10165459,10165459,10165459,10165460,10165459,10165460,10165460,10165471,10264239,10429824,10486701,10581415,11328504,10165472,10174757,10189530,10229951,10235125,10318296,10338968,10338971,10558049,10558052,10581414,10581415,10581415,10581416,10764277,12222551,10338971,10338972,10401770,10581414,10581416,10581417,10184042,10184054,10184054,10184055,10184055,10184057,10184055,10184056,10567348,10590713,11588859,10243958,10243959,10275650,10348269,10348269,10467044,10565372,10590712,10590713,10590713,10590714,10935205,11549990,11852231,10205367,10590714,10590716,10213602,10213603,10213607,10605487,10605487,10605490,10226680,10226681,10226682,10226684,10612026,10588664,10612028,11610175,10370801,10254106,10254165,10254221,11136910,10280249,10280250,10280251,10280253,10280351,10280352,10280352,10280353,10280353,10280352,10280354,10638811,10280455,10280456,10280456,10280457,10280457,10396465,10638913,10290198,10436110,10487322,10544718,10545768,10372432,10291111,10401798,10294442,10294447,10294447,10645907,10674392,10362591,10299944,10648659,10301439,10301438,10497888,10649405,10649407,10303870,10303865,10303873,10303865,10303868,10408175,10650620,11648767,12291759,10650628,10304794,10304794,10304797,10304800,10651082,10346961,10443264,12777210,10358005,10411207,10363011,10363021,10680191,10680198,10367243,10682306,10389128,10389132,10493028,10688438,10430731,10430731,10451587,11225166,10464397,10464412,10464412,10464413,10464413,10730893,10488450,10523071,10530672,10530674,10579298,10579300,10730892,10730894,11242007,10468474,10490478,10471133,10471133,10734252,10471224,10471312,10734339,10472445,10472447,10472447,10472446,10472447,10583318,10734909,10734910,10492466,10734912,10512481,10512481,10512485,10512471,10512483,10512484,10512484,10512485,10512485,10512486,10512486,10512487,10512484,10512484,10512486,10512486,10512487,10512488,10512489,10512486,10512487,10754926,10754928,10661782,10692042,10754929,10754928,10754929,10512503,10603335,10731565,10731566,10754930,10603336,10603337,10754929,10754929,10754930,11753075,12881101,10661785,10731562,10754930,10754931,10754931,10754932,10654672,10754933,11753078,10750116,10754932,10514911,10514911,12214654,10756142,10581723,10581726,10581726,10581835,10637953,10695353,10789549,10789548,10581948,10589436,10591766,10794568,10596913,10596922,10596926,10596926,10596926,10596928,10596916,10596929,10596930,10596933,10596933,10797147,10797149,10797148,10797150,10797150,10797151,10645556,10596944,10797151,10797152,10797153,10999841,10632018,10814694,10638088,10794369,10694168,10694183,10694186,10694193,10694173,10694194,10694196,10694191,10694193,10694194,10694195,10694242,10694190,10694193,10694194,10694198,10694201,10694249,10694191,10694190,10694252,10751582,10694229,10726525,11843928,10845783,10845786,12467083,12045604,10845788,10822426,10845790,10845788,10845790,10845792,10845794,10694292,10694357,10845836,10694374,10845842,10822480,10845842,10845842,10845844,11028700,11843989,10694387,10694409,10845892,10822529,11028751,10845891,10750034,10873704,10758860,10878118,10787580,10787655,10787726,10892572,11147428,10796867,10796932,10796988,10897183,10807940,10808063,10808186,10902778,10808979,10808982,10808982,10808980,10808981,10903174,10903176,10903175,10903177,10903177,10903178,10879815,10811082,10811083,10811084,10811085,10811086,10904227,10880859,10904229,10904229,11087085,11902374,11902374,10812091,11482498,10871608,10871656,10871735,10871792,10911215,10899787,12473175,10946583,10946740,10946749,10946825,10946897,10946828,10946901,10946951,10946952,10946962,10946961,10946971,10946972,10972166,10972166,11406413,10950640,10950639,10950641,10950643,10950644,10950645,10950631,10950645,10950646,10950646,10950646,10950646,10950647,10950647,10950647,10974008,10974009,10974010,11302147,11485122,10974008,10974008,10974009,10974009,10974010,10974010,11846822,11972155,10959497,10978439,10979986,10988680,10987742,10987746,10992559,10992560,10997355,10997355,10997356,10997357,10997370,10997356,10997357,10997357,10997358,10997371,10997371,10997372,10997372,10997373,10997373,10997357,10997358,10997358,10997372,10997373,10997374,10997358,10997359,10997359,10997372,10997372,10997373,10997373,10997374,10997374,10997359,10997360,10997373,10997374,10997375,10997360,10997361,10997372,10997373,10997373,10997374,10997374,10997375,10997375,10997372,10997373,10997373,10997374,10997374,10997375,10997375,10997376,10997376,10997387,10997385,10997387,10997388,11995518,10997386,10997387,10997387,10997388,10997388,11180231,11995518,10997387,10997388,10997388,10997389,11356516,11459847,11508479,11868691,11995518,10997388,10997389,10997389,11459848,11508486,11508486,11508489,11548927,11868691,11995519,13123495,10997389,10997390,11016472,11045204,11180230,11431621,11868692,11995519,11995519,12236628,12258892,13123496,13123545,10997390,11015233,11016473,11025856,11072231,11072232,11072233,11072234,11084520,11180231,11180231,11180232,11180232,11180233,11252229,11341865,11341866,11356614,11431621,11441497,11459849,11505397,11508483,11508483,11508485,11508485,11508487,11508488,11508488,11508489,11508490,11605416,11749445,11868692,11995518,11995519,11995520,11995520,11995521,11996146,12041172,12246062,12415152,12419363,12571799,12638509,12638510,12751284,13123496,13123546,11016471,11016473,11016519,11025853,11025854,11025856,11025856,11025857,11038033,11062225,11071621,11072229,11072232,11072233,11072233,11072234,11072234,11072235,11072235,11072236,11072237,11084522,11133967,11169693,11180231,11180232,11180232,11180233,11180234,11180235,11183991,11200064,11252230,11252230,11252231,11252232,11252232,11253089,11278910,11286470,11341864,11341866,11341867,11417730,11431621,11431622,11431622,11459849,11465452,11508480,11508481,11508482,11508483,11508484,11508485,11508486,11508486,11508487,11508487,11508488,11508488,11508489,11508489,11508490,11508490,11508491,11520664,11544295,11575142,11640112,11661271,11675480,11744464,11787287,11864166,11868693,11868693,11958525,11995518,11995519,11995519,11995520,11995520,11995521,11995521,11995522,12041174,12258893,12419363,12419364,12638510,12638510,13123497,13123544,13123546,13123546,13124353,11033091,12013378,11035626,11035619,11035629,11035674,11035692,11035709,11035767,11527646,12014676,11035774,11077590,11103743,11112762,11199454,11199455,11361088,11479070,11527702,11054331,11054332,11054334,11054334,11054335,11054335,11100713,11208711,11228542,11370341,11370344,11370345,11460100,12023997,12023998,12023998,12154193,13151974,11078687,11220886,11093028,11093032,11120059,11916519,11119358,11119472,11119585,11241334,11127073,11722960,11145865,11145868,11145890,11254477,11416109,11145913,12069786,11147088,11147089,11147091,11147076,11147092,11147077,11147092,11147093,11147077,11147092,11147093,11147094,11147094,11147095,11147095,11147095,11147096,11147097,11147098,11416726,11583339,11255090,11327091,11871280,12070380,11244551,11255091,11255092,11361330,11416727,11416728,11534709,11583341,11583347,11583348,11583351,11811491,11832905,11943553,12070377,12070378,12070379,12070380,12070381,12595356,12646658,12693531,13198357,13198406,13198406,11171664,11171664,11171665,11267374,11595626,12082663,12548587,11189702,11438028,11270554,11645070,11342001,11342002,11342005,11514177,12167828,12587461,11363085,11363073,11363087,11363088,11363088,11363089,11363090,11363090,11363088,11363088,11363088,11363089,11363090,11363090,11363092,11363092,11363096,11363093,11691342,11363103,11414914,11524723,11691341,11691345,12178375,12178376,11366847,11642706,11691344,12178375,12178376,12178377,12821366,11614479,11642706,11691344,11927321,11940804,11942210,11959059,12051550,12178377,12178377,12801529,11524724,12178377,12178378,12821368,13306355,11691339,12178378,12178379,11691340,11691348,11524732,11370603,11646461,11695092,11695093,11402748,11489154,11634306,11711173,12198204,11447643,12220653,11466741,11540463,11507083,11507084,11507082,11507085,11507084,11507086,11507086,11507087,12250372,12250373,11714703,12123547,12250374,13378351,11556780,11596721,11642474,12123548,12250375,11508802,11597577,11560500,11560590,11560685,11623552,11572640,12283152,11575561,11575561,11630958,11720713,11748941,11797580,11606472,12300066,11614197,11816897,11653646,12784022,11686353,11686354,11686355,11686356,11686356,11686357,11686343,11686356,11686356,11686357,11686357,11686358,11686358,11686360,11686357,11686357,11686362,11852977,12340010,11852976,12051837,12340009,11686372,11852975,11686372,11804340,11852972,11852975,11852977,11852978,12102534,12213183,12340009,12340010,12340011,11776113,11804340,11852970,11852972,11852974,11852975,11852976,11852977,11852977,12002603,12126839,12213184,12340008,12340010,12340011,12340011,12340012,12963162,12963163,13467988,11804341,11852978,11852981,11715720,11716039,11715848,11715866,11715875,11790865,11716360,12355043,11773116,11773337,11773559,12383610,11777866,12385768,11838083,11928835,11865865,11865853,11865855,11865865,11865866,11865867,11865868,11865866,11865866,11865866,11865876,11865878,11875743,11894093,11942730,11942732,11942732,12429762,12429763,12429764,11942730,11942734,12192289,12429764,12429764,13473313,12429766,11942736,11885618,11885619,11885826,12439639,11886032,11904175,11922310,11922317,11922319,11922320,11922323,11922323,11922324,11922325,11922319,11922329,11922397,11922441,11922331,11970954,11970954,11970957,12331163,12457988,12457989,12457990,12457990,12917461,13042406,12037676,12457993,12457994,12457994,11970959,11970959,11970961,11970962,11970964,11983278,12237169,12457992,12457994,12457994,12721367,13585971,11970965,12120587,12457995,12331168,11922478,12458069,11922565,12458112,11933547,11976583,12013476,12013676,12013879,12503802,12018523,12018525,12379266,12019062,12019576,12019586,12019587,12019587,12019588,12019572,12019577,12019579,12019586,12019587,12019589,12019592,12019591,12019574,12019593,12019593,12019594,12019577,12019596,12019596,12019581,12019596,12019579,12019580,12019597,12019582,12019597,12019598,12019598,12019581,12019583,12019598,12019598,12019582,12019598,12019599,12019599,12019599,12019600,12019601,12019584,12019585,12019594,12019595,12019599,12019600,12019600,12019600,12019601,12019585,12019593,12019600,12019601,12019601,12019601,12019601,12019602,12019603,12019602,12019602,12019603,12019589,12019589,12019594,12019603,12019603,12019602,12019603,12019604,12019603,12019603,12019604,12019604,12019605,12019605,12019603,12019604,12019604,12019604,12019609,12019609,12307520,12506624,12930469,12116523,12379800,12441673,12019611,12019612,12506628,12506629,12506630,12506629,12506631,12506630,12019616,12019617,12055407,12169225,12293464,12379805,12506630,12506631,12506632,12506633,12506633,12506634,12770005,13634659,12019617,12088972,12169225,12169226,12269158,12287316,12290702,12379806,12379807,12506630,12506631,12506632,12506632,12506633,12506633,12506634,12551227,12930475,13149623,13634610,12055408,12182904,12287316,12381305,12506632,12506633,12506634,12506634,12930477,13149624,13634610,12255574,12379807,12506634,12506634,13149624,12506635,12967003,12506635,13634661,12043947,12044085,12044222,12044229,12518938,12392118,12091210,12091212,12091214,12091214,12091342,13670464,12542438,12542439,12542440,12672634,12542438,12091473,12542566,12100487,13170229,12152905,12152910,12992917,12573287,12153029,12183241,12158338,12575998,12213453,12213455,12213457,12476729,12603559,12603560,12282850,13281249,12318846,12318849,12318849,12318846,12318850,12529426,12656253,12318864,12656256,12656257,13784233,12656255,12656257,12656259,12325165,12659414,12346202,12669930,12353586,12673625,12417314,12417447,12417579,12705619,12418226,12705949,12475887,12607948,12491544,12491549,12742603,12742606,13162237,12501512,12953230,12518512,12518611,12518707,12518710,12518709,12518711,12756184,12756183,12557081,12756185,12521326,12757491,12552011,12772836,12555027,12555028,12774345,12774345,13417333,12561797,12768755,12567333,12567320,12567392,13908481,12567468,12780561,12568316,12780990,12577204,12658610,12595452,12595452,12595462,12794557,13218401,12794562,12622271,12807967,12686792,12686863,12686931,12840295,12730948,12730980,12862327,12739994,12739995,12740007,12740008,12740009,12740010,12740010,12740008,12740010,12740010,12740011,12740011,12740012,12829841,12866835,12866835,12740024,12866835,12866836,12866837,12866837,12866838,12866836,12866837,12866838,13509828,13994814,12866836,12866837,12866838,12866838,12743001,12743013,12868333,12868341,12863753,12928707,12915933,13378644,12919669,12919677,12919748,12919754,12919826,12919827,12956743,12956743,12975714,12984687,12993645,12993645,12993647,12993646,12993647,12993647,12993646,12993648,12993661,12993647,12993648,12993648,12993649,12993650,12993662,12993648,12993649,12993649,12993650,12993650,12993651,12993651,12993662,12993662,12993663,12993664,12993664,12993665,12993665,12993650,12993651,12993651,12993652,12993652,12993661,12993662,12993662,12993663,12993663,12993664,12993665,12993665,12993666,12993666,12993667,12993668,12993668,12993651,12993652,12993652,12993660,12993662,12993663,12993663,12993664,12993664,12993665,12993665,12993666,12993666,12993667,12993652,12993653,12993663,12993664,12993665,12993666,12993666,12993667,12993656,12993664,12993665,12993665,12993666,12993666,12993667,12993667,12993665,12993667,12993667,12993669,12993666,12993670,12993675,12993673,12993676,12993677,12993678,12993675,12993676,12993677,12993677,12993678,12993678,13464300,12993676,12993677,12993677,12993678,13417506,14121639,14121689,12993677,12993678,12993678,12993679,12993679,12993680,12993680,13257037,13417505,13454031,13636652,14121640,12993678,12993679,12993679,12993680,12993679,12993680,12993680,12993681,13257037,13305992,13413297,13417505,13417507,13417508,13454032,13636654,13972046,14121641,14121690,12993680,12993681,12993681,12993682,12993682,12993683,12993684,13039318,13413297,13413297,13413299,13417508,13417508,13417509,13443164,13454033,13459576,13616815,13616816,13616816,13636654,13636655,14121641,14121690,14121690,14121691,14122497,12993681,12993682,12993682,12993683,12993684,12993685,13166733,13177546,13195337,13257038,13273711,13396062,13413296,13413297,13413297,13417507,13417508,13417509,13417509,13417510,13454031,13454033,13569943,13569947,13616816,13616817,13636654,13636655,13636655,13723163,13747460,13896726,14121642,14121691,14121692,12993682,12993683,12993683,12993684,12993685,12993685,13000549,13003559,13038262,13039318,13112692,13123858,13123860,13123861,13168398,13177569,13195337,13195338,13234775,13257038,13257038,13257039,13276277,13324726,13340698,13396065,13404016,13413295,13413297,13413298,13417508,13417508,13417509,13417509,13417510,13420187,13454031,13454034,13480149,13518642,13548667,13569945,13595103,13616816,13616817,13616817,13636655,13636655,13636656,13636656,13747461,14050063,14121642,14121642,14121658,14121691,14121692,14121701,12993683,12993684,12993685,12993685,12993689,13038261,13039318,13039319,13080046,13123861,13195338,13195339,13257039,13257039,13257040,13266131,13335496,13340699,13402854,13413300,13413300,13417509,13417510,13417510,13520117,13522333,13616817,13616818,13636655,13636656,13636657,13867889,14121642,14121643,14121692,14121692,12993684,12993685,13039319,13039320,13123859,13257039,13257039,13417510,13417510,13417511,13454035,13616817,13636655,13636656,13636657,14121643,14121643,14121698,13123862,13257039,13413299,13413300,13417510,13417511,13616817,13636657,14121644,14121692,14121693,13257040,13417511,13636657,14121644,14121694,13352387,14121645,14121694,14121694,13616819,14121645,13039322,13417512,13417513,13454037,13616821,14121646,14121648,12994927,13053589,13007447,13424407,13013447,13646544,13082852,13082855,13082858,14166281,13301633,13498630,13084967,13084967,13084967,13084968,13084968,13084968,13302688,13458946,13458946,13463158,13662466,13682304,13682304,14167341,14167292,13112260,14180948,13166424,13703195,13231715,14240665,13254048,13254050,13254052,13254052,13254054,13254055,13254055,14251832,13766847,14251884,13766849,13325531,13747011,14251836,13547703,14251837,13339797,13339878,13339958,13430184,13343130,13592240,13361428,13601390,13361471,13601411,13397006,13397006,13397007,13526394,13537164,13619177,13619178,13818485,13818486,13873717,13404946,13462675,13475883,13475884,14362751,13877765,13494749,13668050,13520406,13520407,13520405,13520406,13520407,13520407,13520408,13520408,13520409,13520410,13520410,13520411,13520407,13520407,13520411,13520408,13520412,13520413,13520499,13520500,13520501,13717402,13520502,13680878,13717402,13880185,14385060,13520502,13520502,13900024,14385061,13520503,13598865,13900025,14385013,13680881,14010832,13680881,14385014,14385063,13536485,13569365,13880190,14385015,13900029,13520594,13520594,13680970,13833407,13880278,13880278,14385103,14385153,13538590,13538684,13538778,13909209,13552569,13552616,14401167,13553783,13697580,13558884,13700115,13618322,13618320,13948982,14433971,13655784,13655786,13655787,14452700,13744358,13748568,13947877,13967716,13677368,13677384,13677444,13677486,13677519,13677587,13795982,13958765,13759499,13687724,13687728,13687850,14468672,13687976,13983807,13711099,13975532,13798459,13798464,13819906,13819908,13812039,13812037,13826693,14530878,13814366,14047006,13832925,13832926,13832926,13832927,13832928,13832928,13832929,13832929,13832929,13832930,13832931,13832928,13832931,13832930,13832931,13832931,14036213,14541272,14541272,14056285,13837140,13837140,14036448,14541273,14541323,13837140,13837141,13837141,13938273,14056287,14280459,14541274,14541323,13837140,13841332,13841334,13841348,13841335,13841349,13841349,13841351,13841335,13841350,13841350,13841351,13841351,13841336,13841349,13841350,13841351,13841351,13841352,13841351,13841352,13841352,13841353,13841353,13841353,13841354,13841354,13841364,14040658,14060496,14545532,13841366,13841366,14040658,14060497,14546340,13841366,13868751,13877876,13883419,14040659,14040659,14060497,14060498,14545484,14545484,14545534,13841367,13877876,14040659,14040660,14060496,14060497,14060498,14060498,14545485,14545534,13844030,13877877,13888078,13954911,14040659,14040660,14040660,14060498,14060498,14060499,14173273,14545485,14545485,14545535,13877877,14545535,13877878,13846707,13846704,14548159,14548162,13892661,14571138,13896151,14087898,13912602,14076283,13914383,13914440,13914388,13914447,13914447,13914448,13914459,13914449,13914503,13924648,13980530,14077229,14077229,14077230,14077230,14077231,14097068,14097068,14097069,14196891,14228422,14582054,14582055,14582055,14582104,14582105,14077230,14077231,14582056,13914655,13914838,13915001,13915121,14582370,13925499,13925501,13925513,14102578,14587566,13934798,13934799,13934867,13934868,13934937,14016980,14107289,14592275,13966635,14123142,14043615,14043617,14141790,14161628,14161630,14046563,14046564,14046565,14354212,14143265,14163103,14648090,14050984,14051011,14650369,14068472,14659047,14099023,14169493,14103668,14191656,14146221,14146222,14146223,14146223,14146225,14697919,14212933,14697969,14212933,14325708,14697969,14698776,14162493,14706054,14196539,14238092,14239497,14239509,14239732,14239951,14239965,14239952,14239965,14239966,14239966,14239967,14239952,14239964,14239964,14239965,14239966,14239967,14239967,14239954,14239964,14239965,14239966,14239967,14239968,14239956,14239966,14239967,14239967,14239967,14239969,14259802,14744789,14744789,14259802,14744790,14259804,14744790,14239981,14259804,14239981,14239981,14525417,14744792,14744841,14239982,14259805,14259806,14413755,14744792,14744842,14259804,14259805,14259806,14259806,14339606,14372580,14465224,14475276,14595198,14744792,14744793,14744830,14744842,14279640,14279627,14279642,14279628,14279629,14279640,14279643,14279643,14279644,14279629,14279642,14279642,14279643,14279643,14279644,14279644,14279630,14279641,14279642,14279643,14279643,14279644,14279644,14279645,14279645,14279643,14279644,14279645,14279646,14279645,14279654,14764627,14279657,14279657,14764628,14764629,14279658,14764629,14764629,14764679,14392418,14764630,14764679,14279658,14279659,14390448,14433593,14764630,14764630,14764680,14279659,14390451,14397890,14445342,14764630,14764631,14764680,14764683,14279660,14282412,14411000,14474500,14680204,14764631,14764631,14764673,14764681,14764682,14765487,14764631,14764632,14285181,14767401,14350431,14800024,14439245,14844431,14452657,14851136,14479290,14864454,14501251,14501251,14501253,14501253,14501254,14875433,14875483,14875434,14505193,14505193,14505194,14877405,14600889,14877406,14516133,14882874,14542349,14542353,14895982,14676607,14587541,14587545,14918578,14918626,14918629,14611038,14930376,14661850,14661861,14955786,14669401,14669462,14669681,14669975,14959827,14690481,14885621,14696580,14973096,14710585,14980150,14728002,14728073,14988859,14742113,14846272,14799786,15024702,14810867,14810870,15030244,14950425,14950426,14950428,15100070,15100021,15100071,15100022,15080756,15080758,15080831,15080832,15080833,15080907,15080909,15165261,15106454,15178034,15249601,15249602,15249652,15249603,15249604,15249605,15249605,15249606,15249606,15249608,15249610,15249612,15249612,15249614,15249614,15249615,15249616,15249625,15249626,15249626,15249629,15249637,15249647,15249648,15249649,15249649,15249650,15249650,15249651,15249651,15249652,15249652,15249604,15249605,15249605,15249606,15249606,15249612,15249613,15249613,15249616,15249632,15249637,15249638,15249643,15249647,15249648,15249650,15249650,15249651,15249652,15249652,15249653,15249607,15249613,15249617,15249626,15249652,15249653,15249653,15249613,15249653,15249614,15249654,15249614,15249653,15249654,15249654,15249612,15249615,15249648,15249652,15249654,15249655,15249639,15249615,15249618,15249633,15249659,15249631,15249634,15249635,15249645,15249654,15249655,15249656,15249659,15249660,15249660,15249661,15249661,15249661,15249662,15249662,15249637,15249662,15249663,15249662,15249664,15249663,15249663,15249664,15249664,15249668,15249670,15249651,15249674,15249673,15249674,15249675,15249675,15249675,15249676,15249665,15249677,15249680,15249681,15249685,15249682,15249684,15249685,15249685,15249686,15249687,15249689,15249690,15249693,15249693,15249694,15249694,15249694,15249694,15249694,15249695,15249696,15249696,15249696,15249698,15249698,15249698,15249697,15249698,15249698,15249699,15249699,15249698,15249699,15249699,15249700,15249699,15249700,15249700,15249700,15249701,15249701,15249725,15249702,15249703,15249703,15249704,15249704,15249705,15249705,15249706,15249706,15249707,15249707,15249708,15249710,15249711,15249711,15249717,15249720,15249722,15249723,15249725,15249726,15249727,15249728,15249728,15249729,15249703,15249704,15249704,15249705,15249706,15249707,15249711,15249728,15249704,15249705,15249705,15249706,15249707,15249707,15249708,15249709,15249709,15249710,15249711,15249712,15249712,15249713,15249719,15249726,15249728,15249729,15249705,15249706,15249706,15249707,15249707,15249708,15249708,15249709,15249710,15249711,15249712,15249713,15249713,15249723,15249724,15249726,15249727,15249728,15249729,15249706,15249707,15249708,15249708,15249709,15249707,15249708,15249708,15249709,15249709,15249710,15249711,15249713,15249714,15249708,15249709,15249709,15249710,15249710,15249711,15249711,15249712,15249713,15249713,15249714,15249720,15249721,15249722,15249725,15249725,15249726,15249727,15249727,15249728,15249729,15249730,15249731,15249709,15249710,15249710,15249710,15249711,15249711,15249712,15249712,15249713,15249713,15249714,15249714,15249715,15249715,15249717,15249719,15249723,15249724,15249725,15249726,15249726,15249727,15249728,15249729,15249730,15249732,15249711,15249712,15249712,15249713,15249713,15249714,15249714,15249715,15249715,15249716,15249717,15249718,15249721,15249724,15249726,15249726,15249727,15249728,15249728,15249729,15249730,15249731,15249732,15249712,15249713,15249713,15249714,15249714,15249715,15249715,15249716,15249716,15249717,15249717,15249718,15249718,15249719,15249720,15249721,15249722,15249724,15249726,15249726,15249727,15249727,15249728,15249729,15249729,15249730,15249731,15249731,15249733,15249713,15249714,15249715,15249716,15249716,15249717,15249717,15249718,15249721,15249727,15249728,15249714,15249715,15249715,15249716,15249716,15249717,15249717,15249718,15249718,15249719,15249720,15249721,15249723,15249725,15249725,15249726,15249727,15249728,15249728,15249729,15249730,15249730,15249731,15249733,15249715,15249716,15249716,15249717,15249717,15249718,15249718,15249719,15249719,15249721,15249723,15249724,15249725,15249725,15249726,15249726,15249727,15249728,15249729,15249729,15249730,15249730,15249731,15249732,15249733,15249733,15249734,15249716,15249717,15249717,15249718,15249727,15249728,15249729,15249731,15249733,15249717,15249718,15249718,15249719,15249720,15249726,15249727,15249727,15249731,15249732,15249733,15249734,15249735,15249735,15249718,15249719,15249719,15249720,15249720,15249721,15249721,15249722,15249724,15249725,15249727,15249728,15249729,15249730,15249730,15249731,15249731,15249732,15249732,15249733,15249734,15249735,15249736,15249719,15249720,15249720,15249721,15249721,15249724,15249725,15249728,15249728,15249729,15249730,15249730,15249731,15249732,15249732,15249733,15249734,15249735,15249736,15249720,15249721,15249721,15249722,15249722,15249723,15249724,15249726,15249727,15249728,15249729,15249730,15249731,15249731,15249732,15249732,15249733,15249733,15249734,15249735,15249737,15249721,15249722,15249722,15249723,15249724,15249725,15249725,15249726,15249726,15249727,15249728,15249728,15249729,15249730,15249731,15249731,15249732,15249732,15249733,15249733,15249734,15249735,15249736,15249736,15249737,15249737,15249723,15249725,15249726,15249727,15249729,15249730,15249732,15249733,15249733,15249734,15249735,15249736,15249737,15249738,15249723,15249726,15249726,15249729,15249730,15249731,15249732,15249732,15249733,15249734,15249735,15249736,15249737,15249738,15249724,15249725,15249726,15249728,15249729,15249730,15249730,15249731,15249731,15249732,15249732,15249733,15249733,15249734,15249735,15249735,15249736,15249727,15249728,15249729,15249729,15249730,15249731,15249733,15249733,15249734,15249735,15249732,15249733,15249734,15249735,15249729,15249733,15249736,15249732,15249735,15249736,15249730,15249731,15249733,15249733,15249735,15249737,15249741,15249730,15249736,15249736,15249737,15249731,15249732,15249734,15249736,15249738,15249734,15249736,15249737,15249737,15249738,15249740,15249741,15249743,15249737,15249737,15249739,15249740,15249743,15249735,15249735,15249737,15249738,15249739,15249742,15249744,15249738,15249739,15249736,15249737,15249738,15249739,15249740,15249741,15249745,15249737,15249738,15249738,15249739,15249739,15249740,15249740,15249741,15249741,15249743,15249743,15249744,15249745,15249738,15249739,15249740,15249740,15249741,15249742,15249742,15249743,15249744,15249739,15249740,15249742,15249742,15249740,15249741,15249742,15249743,15249743,15249745,15249741,15249742,15249742,15249743,15249743,15249744,15249744,15249745,15249746,15249746,15249747,15249747,15249742,15249743,15249743,15249744,15249744,15249745,15249745,15249746,15249746,15249747,15249748,15249743,15249744,15249744,15249745,15249746,15249746,15249747,15249747,15249748,15249748,15249744,15249745,15249746,15249747,15249748,15249749,15249745,15249746,15249746,15249747,15249748,15249748,15249749,15249749,15249746,15249747,15249747,15249748,15249748,15249749,15249749,15249750,15249747,15249748,15249748,15249749,15249749,15249750,15249750,15249748,15249749,15249750,15249750,15249751,15249749,15249750,15249750,15249751,15249751,17440608,15249750,15249751,15249751,15249752,15249751,15249752,15249752,15250533,15249752,15249753,15249753,15250534,15249754,15249755,15249755,15249756,15249756,15249757,15249760,15249760,15249761,15249762,15249763,15249764,15249764,15249765,15249767,15249769,15249770,15249770,15249771,15249772,15249773,15249774,15249774,15249775,15249776,15249790,15249793,15249793,15249795,15249801,15249802,15249803,15249803,15249804,15250534,15719776,16099179,17003955,17200685,19739755,15249755,15249756,15249756,15249757,15249757,15249758,15249758,15249759,15249759,15249760,15249760,15249761,15249761,15249762,15249762,15249763,15249764,15249765,15249766,15249767,15249769,15249769,15249770,15249771,15249771,15249772,15249774,15249775,15249775,15249776,15249778,15249783,15249784,15249785,15249785,15249789,15249792,15249793,15249794,15249799,15249799,15249800,15249801,15249802,15249802,15249803,15249803,15249804,15250535,15250584,15249756,15249758,15249758,15249759,15249760,15249760,15249762,15249763,15249766,15249771,15249777,15249796,15249802,15249757,15249758,15249758,15249759,15249760,15249762,15249762,15249763,15249763,15249764,15249765,15249765,15249766,15249766,15249767,15249769,15249770,15249771,15249773,15249774,15249775,15249776,15249777,15249779,15249780,15249781,15249784,15249785,15249785,15249788,15249788,15249794,15249795,15249797,15249800,15249802,15249802,15249803,15249803,15249804,15249805,15250535,15250536,15249758,15249759,15249759,15249760,15249761,15249761,15249762,15249763,15249764,15249764,15249765,15249766,15249767,15249771,15249772,15249776,15249776,15249784,15249787,15249789,15249792,15249795,15249803,15249804,15249805,15250536,15249759,15249760,15249760,15249761,15249767,15249771,15249792,15249795,15249799,15249801,15249804,15249806,15249760,15249761,15249762,15249762,15249763,15249764,15249764,15249765,15249767,15249767,15249768,15249771,15249773,15249773,15249774,15249775,15249777,15249778,15249779,15249784,15249793,15249796,15249800,15249802,15249804,15249804,15249805,15249806,15250592,15249762,15249764,15249767,15249775,15249805,15249763,15249764,15249766,15249768,15249774,15249807,15249763,15249766,15249766,15249764,15249765,15249765,15249766,15249766,15249767,15249767,15249769,15249775,15249775,15249777,15249778,15249807,15249765,15249766,15249766,15249767,15249768,15249778,15249798,15249806,15249766,15249767,15249771,15249807,15250540,15249768,15249768,15249769,15249771,15249772,15249775,15249776,15249777,15249788,15249794,15249806,15249810,15250541,15249768,15249770,15249771,15249772,15249774,15249776,15249779,15249782,15249802,15249808,15249769,15249770,15249771,15249772,15249773,15249774,15249776,15249776,15249777,15249778,15249781,15249792,15249795,15249804,15249806,15249770,15249772,15249773,15249773,15249774,15249776,15249776,15249777,15249778,15249778,15249779,15249779,15249781,15249783,15249796,15249799,15249801,15249809,15249811,15249811,15250542,15249774,15249775,15249776,15249810,15249810,15249811,15250543,15249773,15249773,15249774,15249779,15250543,15249773,15249812,15249775,15249776,15249779,15249780,15249782,15249809,15249811,15249813,15250544,15250544,15249776,15249777,15249778,15249779,15249780,15249781,15249781,15249783,15249784,15249785,15249791,15249811,15249812,15249812,15250545,15249776,15249777,15249785,15249780,15249780,15249781,15249782,15249783,15249784,15249784,15249785,15249786,15249786,15249787,15249788,15249794,15249796,15249805,15249812,15249813,15249813,15249814,15249814,15249815,15250546,15249781,15249781,15249781,15249783,15249787,15249787,15249788,15249789,15249790,15249782,15249815,15249801,15249816,15249784,15249788,15249789,15249789,15249796,15249817,15249818,15249785,15249785,15249786,15249787,15249788,15249788,15249789,15249789,15249790,15249791,15249802,15249815,15249816,15249817,15249818,15249818,15250549,15249790,15249794,15249818,15249786,15249787,15249788,15249789,15249790,15249790,15249791,15249792,15249797,15249798,15249801,15249802,15249809,15249815,15249817,15249818,15249819,15249819,15250550,15249787,15249788,15249789,15249789,15249791,15249792,15249809,15249816,15249816,15249817,15249818,15249818,15249820,15249788,15249789,15249790,15249791,15249792,15249793,15249794,15249817,15249789,15249792,15249805,15249818,15249821,15249791,15249791,15249792,15249792,15249793,15249802,15249819,15249821,15249792,15249793,15249795,15249808,15249819,15249793,15249793,15249794,15249796,15249806,15249807,15249811,15249820,15249822,15250553,15249793,15249794,15249794,15249805,15249819,15249821,15249795,15249796,15249797,15249798,15249802,15249805,15249807,15249813,15249815,15249816,15249817,15249818,15249821,15249822,15249823,15250554,15250554,15249795,15249796,15249798,15249799,15249805,15249808,15249810,15249813,15249814,15249821,15249821,15249824,15250555,15249796,15249797,15249797,15249798,15249800,15249806,15249808,15249808,15249810,15249812,15249814,15249815,15249816,15249818,15249821,15249821,15249822,15249822,15249823,15249823,15249824,15249808,15249809,15249816,15249822,15249823,15249823,15249825,15250556,15249803,15249806,15249815,15249822,15249823,15249825,15249813,15249814,15249823,15249824,15249824,15249826,15249804,15249816,15249818,15249822,15249808,15249810,15249811,15249819,15249821,15249826,15249809,15249820,15249821,15249822,15249826,15249813,15249828,15249817,15249812,15249813,15249819,15249824,15249829,15249811,15249814,15249827,15249827,15249812,15249815,15249822,15249832,15249817,15249832,15249820,15249823,15249825,15249831,15249818,15249820,15249823,15249834,15249818,15249821,15249832,15249834,15249820,15249823,15249828,15249833,15249819,15249822,15249826,15249830,15249831,15249831,15249820,15249824,15249834,15249826,15249827,15249827,15249829,15249830,15249830,15249833,15249833,15249834,15249835,15249835,15249824,15249828,15249831,15249838,15249825,15249834,15249828,15249829,15249836,15249837,15249837,15249829,15249835,15249837,15250626,15249827,15249829,15249832,15249837,15249834,15249834,15249840,15249831,15249832,15249833,15249837,15249838,15249840,15249839,15249832,15249833,15249833,15249834,15249835,15249836,15249836,15249839,15249840,15249840,15249841,15249842,15249842,15249834,15249835,15249841,15249842,15249843,15249836,15249837,15249840,15249841,15249842,15249835,15249836,15249837,15249841,15249841,15249842,15249842,15249844,15250575,15249838,15249839,15249843,15249844,15249844,15249839,15249841,15249842,15249843,15249844,15249845,15249841,15249842,15249842,15249844,15249842,15249842,15249843,15249843,15249844,15249844,15249845,15249846,15249846,15250577,15249843,15249844,15249845,15249844,15249844,15249844,15249845,15249846,15249844,15249845,15249845,15249846,15249846,15249847,15249847,15250579,15249845,15249846,15249846,15249847,15249847,15249846,15249847,15249847,15249848,15249848,15249849,15249847,15249848,15249848,15249849,15249850,15249848,15249849,15249849,15249850,15249850,15249849,15249850,15249850,15249851,15249850,15249851,15249851,15249851,15249852,15249852,15250583,15249853,15249854,15250583,15250584,15250626,15250633,15250634,15250636,15250637,15250638,15250638,15249854,15250568,15250584,15250584,15250634,15250585,15251298,15251314,15251315,15251316,15251316,15251317,15251317,15251320,15251322,15251322,15251325,15251325,15251327,15251328,15251328,15251330,15251332,15251336,15251336,15251337,15251337,15251342,15251342,15251343,15251343,15251344,15251345,15251345,15251346,15251347,15251349,15251350,15251350,15251353,15251355,15251357,15251359,15251381,15251388,15251318,15251342,15251342,15251343,15251343,15251345,15251346,15251348,15251318,15251343,15251343,15251344,15251344,15251344,15251321,15251344,15251344,15251345,15251327,15251330,15251340,15251343,15251345,15251345,15251347,15251347,15251333,15251350,15251353,15251347,15251354,15251374,15251354,15251355,15251342,15251349,15251355,15251356,15251358,15251356,15251356,15251350,15251358,15251360,15251363,15251364,15251365,15251380,15251364,15251364,15251365,15251365,15251379,15251368,15251369,15251369,15251370,15251371,15251370,15251371,15251372,15251373,15251371,15251372,15251372,15251373,15251378,15251372,15251373,15251374,15251374,15251376,15251373,15251374,15251375,15251397,15251375,15251377,15251376,15251377,15251377,15251378,15251378,15251379,15251379,15251380,15251380,15251381,15251381,15251383,15251387,15251388,15251391,15251393,15251393,15251395,15251395,15251396,15251421,15251377,15251378,15251378,15251378,15251379,15251379,15251380,15251380,15251381,15251381,15251382,15251382,15251384,15251379,15251380,15251380,15251381,15251381,15251380,15251381,15251381,15251382,15251382,15251383,15251383,15251392,15251397,15251398,15251403,15251381,15251382,15251382,15251383,15251384,15251385,15251382,15251383,15251383,15251384,15251384,15251386,15251388,15251391,15251406,15251416,15251383,15251384,15251417,15251384,15251385,15251387,15251387,15251393,15251415,15251385,15251386,15251387,15251387,15251388,15251390,15251393,15251394,15251399,15251402,15251403,15251425,15251386,15251387,15251388,15251388,15251390,15251392,15251393,15251395,15251399,15251403,15251387,15251388,15251388,15251389,15251389,15251391,15251392,15251393,15251394,15251395,15251395,15251396,15251397,15251399,15251400,15251401,15251402,15251402,15251403,15251388,15251389,15251389,15251391,15251407,15251389,15251390,15251392,15251405,15251420,15251390,15251402,15251391,15251392,15251392,15251393,15251393,15251394,15251394,15251395,15251395,15251396,15251397,15251397,15251398,15251399,15251400,15251402,15251403,15251428,15251392,15251393,15251393,15251394,15251398,15251394,15251395,15251397,15251398,15251395,15251396,15251396,15251397,15251397,15251398,15251399,15251399,15251402,15251404,15251405,15251406,15251407,15251408,15251409,15251413,15251415,15251423,15251396,15251397,15251398,15251399,15251399,15251400,15251423,15251397,15251398,15251398,15251399,15251406,15251398,15251399,15251400,15251399,15251400,15251401,15251402,15251406,15251407,15251413,15251400,15251401,15251401,15251402,15251403,15251403,15251406,15251407,15251408,15251410,15251425,15251401,15251402,15251402,15251402,15251403,15251403,15251404,15251404,15251405,15251405,15251406,15251406,15251407,15251408,15251408,15251409,15251412,15251413,15251403,15251404,15251405,15251406,15251406,15251408,15251409,15251409,15251412,15251415,15251404,15251405,15251405,15251406,15251407,15251407,15251408,15251409,15251409,15251410,15251411,15251413,15251414,15251427,15251405,15251406,15251408,15251408,15251410,15251412,15251406,15251407,15251407,15251408,15251408,15251409,15251409,15251410,15251410,15251411,15251412,15251407,15251408,15251408,15251409,15251409,15251410,15251410,15251411,15251411,15251412,15251413,15251424,15251408,15251409,15251409,15251409,15251410,15251410,15251411,15251412,15251412,15251424,15251410,15251411,15251412,15251412,15251413,15251411,15251412,15251412,15251413,15251413,15251420,15251412,15251413,15251413,15251414,15251414,15251415,15251416,15251431,15251413,15251414,15251414,15251415,15251416,15251417,15251417,15251418,15251418,15251419,15251420,15251429,15251432,15251415,15251416,15251416,15251417,15251417,15251418,15251418,15251419,15251419,15251422,15251433,15251440,15251416,15251417,15251417,15251418,15251418,15251419,15251419,15251420,15251420,15251421,15251431,15251433,15251435,15251417,15251418,15251418,15251419,15251420,15251420,15251428,15251418,15251419,15251419,15251420,15251420,15251421,15251421,15251422,15251432,15251442,15251419,15251420,15251420,15251421,15251421,15251422,15251422,15251423,15251427,15251435,15251420,15251421,15251421,15251422,15251422,15251423,15251423,15251425,15251435,15251443,15251421,15251422,15251422,15251423,15251423,15251424,15251425,15251430,15251431,15251436,15251422,15251423,15251423,15251424,15251424,15251425,15251427,15251427,15251428,15251433,15251436,15251444,15251423,15251424,15251424,15251425,15251426,15251431,15251432,15251435,15251437,15251439,15251444,15251424,15251425,15251425,15251426,15251427,15251427,15251428,15251431,15251432,15251435,15251437,15251437,15251442,15251445,15251425,15251426,15251426,15251427,15251428,15251431,15251435,15251436,15251438,15251426,15251428,15251428,15251438,15251446,15251427,15251428,15251428,15251429,15251429,15251430,15251431,15251432,15251433,15251433,15251434,15251434,15251435,15251435,15251436,15251437,15251438,15251439,15251441,15251443,15251443,15251446,15251428,15251429,15251429,15251430,15251432,15251433,15251434,15251435,15251437,15251447,15251429,15251430,15251431,15251433,15251434,15251434,15251438,15251440,15251447,15251430,15251431,15251431,15251432,15251433,15251433,15251434,15251435,15251435,15251437,15251438,15251440,15251440,15251442,15251448,15251431,15251432,15251432,15251433,15251433,15251434,15251435,15251435,15251436,15251436,15251437,15251438,15251439,15251448,15251432,15251433,15251434,15251434,15251435,15251436,15251441,15251443,15251433,15251434,15251434,15251435,15251436,15251436,15251437,15251438,15251440,15251441,15251445,15251449,15251434,15251435,15251435,15251436,15251437,15251440,15251435,15251436,15251437,15251438,15251441,15251436,15251437,15251439,15251440,15251443,15251437,15251438,15251438,15251439,15251439,15251440,15251442,15251444,15251438,15251439,15251440,15251440,15251441,15251442,15251443,15251449,15251452,15251440,15251441,15251441,15251442,15251442,15251443,15251443,15251445,15251449,15251450,15251453,15251441,15251442,15251442,15251443,15251443,15251444,15251442,15251443,15251443,15251444,15251444,15251448,15251450,15251451,15251443,15251444,15251444,15251445,15251444,15251445,15251445,15251447,15251449,15251450,15251451,15251452,15251445,15251446,15251448,15251452,15251446,15251447,15251448,15251450,15251456,15251447,15251448,15251448,15251449,15251449,15251450,15251451,15251452,15251452,15251453,15251453,15251454,15251455,15251456,15251448,15251449,15251449,15251450,15251451,15251451,15251453,15251454,15251449,15251450,15251450,15251451,15251452,15251450,15251451,15251452,15251452,15251451,15251452,15251452,15251453,15251454,15251454,15251455,15251455,15251456,15251458,15251458,15251485,15251486,15253395,15251452,15251453,15251453,15251455,15251455,15251456,15251456,15251459,15251485,15251454,15251454,15251456,15251457,15251460,15251455,15251456,15251456,15251457,15251457,15251458,15251460,15251487,15251456,15251457,15251457,15253397,15251457,15251458,15251458,15251459,15251460,15251461,15251488,15251458,15251459,15251462,15251459,15251460,15251461,15251462,15251462,15251460,15251461,15251461,15251462,15251462,15251463,15251461,15251462,15251462,15251463,15251463,15251462,15251463,15251463,15251464,15251463,15251464,15251464,15251464,15251465,15251465,15251493,15251466,15251467,15251467,15251468,15251468,15251471,15251475,15251476,15251478,15251478,15251481,15251481,15251482,15251483,15251484,15251485,15251487,15251488,15251489,15251490,15251491,15251491,15251492,15251492,15251493,15251493,15251494,15253367,15253402,15253404,15720631,15720632,15251467,15251468,15251468,15251469,15251469,15251470,15251470,15251471,15251472,15251472,15251473,15251474,15251476,15251478,15251478,15251479,15251479,15251482,15251483,15251484,15251485,15251485,15251486,15251487,15251489,15251489,15251490,15251490,15251491,15251491,15251492,15251492,15251493,15251493,15251494,15251494,15251468,15251469,15251479,15251484,15251485,15251488,15251490,15251491,15251492,15251493,15251470,15251480,15251483,15251493,15251494,15251480,15251481,15251490,15251493,15251494,15251480,15251483,15251484,15251486,15251489,15251490,15251491,15251492,15251492,15251493,15251494,15251494,15251495,15251495,15251496,15251477,15251494,15251495,15251474,15251495,15251489,15251483,15251495,15251496,15251499,15251498,15251499,15251492,15251500,15251501,15251501,15251502,15251503,15251491,15251495,15251497,15251502,15251503,15251504,15251505,15251501,15251504,15251493,15251504,15251505,15251505,15251503,15251497,15251506,15251508,15251504,15251505,15251507,15251509,15251509,15251510,15251509,15251509,15251510,15251508,15251510,15251507,15251508,15251509,15251509,15251510,15251510,15251511,15251509,15251508,15251510,16100053,15251511,15251512,15251511,15251512,15251512,15251513,15251514,15251512,15251513,15251512,15251512,15251514,15251514,15251515,15251515,15251514,15251513,15251514,15251515,15251516,15251516,15251517,15251514,15251515,15251515,15251516,15251517,15251515,15251516,15251517,15251516,15251517,15251517,15251518,15251517,15251518,15251518,15251519,15251518,15251519,15251519,15251520,15251520,15251521,15251521,15251522,15251525,15253302,15253395,15253395,15253430,15253431,15253432,15253432,15253444,15253445,15253446,15253447,15253448,15253449,15253453,15309528,15388600,15565519,15720659,15720660,15720660,16100061,16100061,16100062,17004839,17004863,17633091,17689843,18707805,19242826,19740639,15251523,15253395,15253396,15253454,15253396,15251600,15253469,15255158,15255168,15255251,15255261,15255268,15255269,15255270,15255270,15255271,15255271,15255272,15255273,15255273,15255274,15255275,15255276,15255289,15255290,15255298,15255301,15255302,15255302,15255303,15255303,15255304,15255272,15255274,15255276,15255294,15255300,15255303,15255303,15255304,15255304,15255291,15255304,15255305,15255305,15255305,15255305,15255305,15255306,15255306,15255306,15255306,15255307,15255308,15255308,15255308,15255309,15255309,15255310,15255324,15255324,15255325,15255325,15255328,15255333,15255334,15255336,15255337,15255337,15255379,15255337,15255338,15255338,15255379,15255339,15255340,15255341,15255341,15255342,15255342,15255344,15255346,15255346,15255347,15255347,15255348,15255349,15255349,15255350,15255351,15255352,15255352,15255353,15255354,15255354,15255355,15255356,15255356,15255357,15255357,15255358,15255359,15255359,15255360,15255360,15255361,15255361,15255362,15255362,15255363,15255363,15255365,15255366,15255366,15255371,15255377,15255378,15255378,15255379,15255379,15255380,15255341,15255341,15255342,15255343,15255344,15255349,15255350,15255352,15255353,15255354,15255354,15255358,15255358,15255362,15255363,15255370,15255379,15255380,15255342,15255343,15255344,15255349,15255351,15255354,15255355,15255356,15255358,15255381,15255343,15255344,15255344,15255346,15255350,15255351,15255351,15255352,15255355,15255356,15255357,15255359,15255359,15255362,15255363,15255364,15255348,15255350,15255354,15255355,15255355,15255356,15255356,15255357,15255364,15255364,15255365,15255365,15255381,15255382,15255353,15255357,15255352,15255357,15255357,15255360,15255360,15255361,15255364,15255365,15255383,15255358,15255360,15255362,15255385,15255359,15255361,15255368,15255368,15255360,15255357,15255362,15255362,15255366,15255376,15255384,15255386,15255362,15255362,15255363,15255364,15255365,15255361,15255363,15255364,15255365,15255389,15255389,15255365,15255369,15255366,15255367,15255369,15255373,15255367,15255392,15255367,15255367,15255368,15255370,15255371,15255374,15255393,15255367,15255368,15255369,15255371,15255371,15255372,15255374,15255375,15255377,15255377,15255389,15255394,15255369,15255370,15255370,15255371,15255371,15255372,15255372,15255373,15255374,15255374,15255375,15255376,15255376,15255377,15255377,15255378,15255378,15255380,15255381,15255381,15255382,15255382,15255383,15255385,15255388,15255391,15255392,15255393,15255394,15255394,15722584,15255370,15255371,15255372,15255373,15255376,15255395,15255371,15255372,15255372,15255373,15255373,15255374,15255375,15255375,15255376,15255376,15255377,15255377,15255378,15255378,15255380,15255380,15255381,15255384,15255395,15255373,15255373,15255376,15255378,15255374,15255375,15255376,15255378,15255379,15255391,15255396,15255374,15255375,15255375,15255378,15255378,15255379,15255380,15255380,15255397,15255712,17006765,15255375,15255376,15255377,15255377,15255378,15255378,15255379,15255379,15255380,15255380,15255381,15255383,15255384,15255386,15255388,15255389,15255392,15255397,16101988,15255376,15255377,15255378,15255378,15255379,15255379,15255380,15255380,15255381,15255397,15255398,15255378,15255378,15255379,15255379,15255380,15255380,15255381,15255381,15255382,15255382,15255384,15255388,15255391,15255394,15255396,15255398,15255398,15255379,15255380,15255381,15255382,15255399,15255399,15255380,15255381,15255382,15255382,15255383,15255383,15255384,15255386,15255387,15255391,15255392,15255393,15255397,15255399,15255400,15255381,15255382,15255382,15255383,15255386,15255386,15255387,15255389,15255391,15255400,16101989,15255382,15255383,15255383,15255384,15255385,15255387,15255388,15255388,15255392,15255398,15255400,15255400,15255401,15255383,15255384,15255384,15255385,15255385,15255386,15255387,15255388,15255391,15255396,15255401,15255401,15255384,15255385,15255385,15255386,15255386,15255387,15255387,15255388,15255389,15255397,15255402,15255385,15255386,15255386,15255387,15255388,15255388,15255389,15255389,15255390,15255392,15255393,15255394,15255395,15255396,15255396,15255398,15255399,15255400,15255401,15255401,15255402,15255402,15255403,15722591,15255386,15255387,15255388,15255389,15255389,15255390,15255393,15255395,15255397,15255398,15255399,15255402,15255403,15255387,15255388,15255389,15255390,15255391,15255391,15255396,15255401,15255402,15255403,15255403,15255404,15255389,15255389,15255390,15255390,15255391,15255394,15255395,15255396,15255399,15255400,15255402,15255403,15255404,15255390,15255397,15255402,15255404,15255404,15255391,15255402,15255405,15255391,15255392,15255392,15255393,15255396,15255397,15255398,15255398,15255401,15255402,15255404,15255405,15255392,15255393,15255396,15255396,15255397,15255397,15255398,15255398,15255400,15255400,15255403,15255405,15255406,15255394,15255395,15255398,15255399,15255405,15255406,15255406,15255395,15255396,15255397,15255400,15255404,15255405,15255407,15255403,15255407,15255407,15255402,15255408,15255398,15255408,15255408,15255400,15255409,15255405,15255409,15255409,15255405,15255406,15255407,15255409,15255410,15255404,15255410,15255410,15255404,15255405,15255408,15255411,15255409,15255411,15255405,15255410,15255411,15255411,15255412,15255409,15255410,15255410,15255412,15255413,15255410,15255413,15255413,15255409,15255410,15255411,15255413,15255414,15255414,15255415,15255415,15255413,15255416,15722604,15255413,15255415,15255416,15255416,15255417,15255416,15255416,15255417,15495635,15722606,15722606,16102009,15255416,15255417,15255418,15255418,15255418,15255418,15255419,15255419,15255420,15255421,15255422,15255429,15255444,15255452,15255453,15255453,15255454,15255454,15255455,15495638,15567468,15567468,15722608,15722608,15722609,15922261,15922262,16055655,16102009,16102010,16102011,16102011,16102012,16382055,16765316,17006788,17006788,17006812,17295747,15255421,15255422,15255422,15255423,15255423,15255424,15255424,15255425,15255425,15255426,15255426,15255427,15255428,15255428,15255429,15255429,15255430,15255430,15255431,15255432,15255433,15255434,15255435,15255435,15255437,15255438,15255439,15255441,15255442,15255443,15255443,15255444,15255444,15255446,15255447,15255449,15255450,15255451,15255451,15255452,15255452,15255453,15255453,15255454,15255454,15255455,15255455,15722609,16102010,16102011,15255423,15255424,15255425,15255426,15255427,15255429,15255430,15255431,15255434,15255434,15255443,15255451,15255453,15255454,15255454,15255455,15255455,15255456,15255423,15255426,15255456,15567470,15255457,15255427,15255429,15255432,15255455,15255457,15255457,15255429,15255458,15255452,15255456,15255458,15495641,15255430,15255457,15255429,15255431,15255443,15255449,15255458,15255458,15255459,15255459,15255430,15255432,15255445,15255445,15255451,15255457,15255458,15255459,15255452,15255458,15255460,15255460,15255450,15255458,15255447,15255452,15255459,15255461,15255462,15255458,15255461,15255462,15255462,15255461,15255463,15255441,15255453,15255462,15255464,15255441,15255464,15255464,15255453,15255456,15255463,15255452,15255459,15255456,15255457,15255454,15255451,15255458,15255467,15255469,15255471,15255462,15255468,15255470,15255472,15255471,15255474,15255474,15255471,15255475,15255473,15255475,15255476,15255475,15255475,15255468,15255475,15255478,15255469,15255477,15255478,15255477,15255478,15255479,15255475,15255479,15255480,15255479,15255480,15255480,15255480,15255480,15255481,15255476,15255483,15255482,15255483,15255482,15255483,15255485,15255483,15255484,15255485,15255486,15255485,15255486,15255487,15255486,15255486,15255487,15255487,15255486,15255487,15255487,15255488,15255487,15255488,15255488,15255488,15255489,15255489,15255490,15255526,15255607,15268366,15311512,15322156,15323625,15346373,15348973,15390584,15430511,15493038,15495673,15495674,15567503,15567503,15567504,15567504,15567505,15567505,15610225,15610357,15722640,15722642,15722642,15722643,15722643,15722644,15722644,15873483,15922296,15922297,15922297,15946464,15968051,15994563,16028513,16100728,16102044,16102045,16102045,16102046,16102046,16102047,16102048,16347736,16381930,16381931,16382087,16382089,16458879,16828892,17006815,17006823,17006823,17006847,17443479,15348974,15495676,15567503,15567504,15567504,15722641,15722643,15722644,15722644,15722645,15722680,15255799,15722835,15256062,16102336,15281254,16114934,15367544,15367545,15778676,15778677,15388835,15562353,15391779,16170199,15437277,16919796,15442513,15442515,15442531,15442532,15442589,15442591,15442607,15442625,15442656,15442662,15442664,15442682,15442717,15816250,15661116,15661116,15816256,15816257,16195657,15816260,15816277,15462522,15661154,15816295,15482289,15836062,15525693,15525694,16237155,15857753,15605549,15897681,15730599,15960205,15735868,15735868,15735869,15735869,15735870,15735870,15735874,17247019,15962839,15962840,16342241,15807700,15962840,15962842,15879516,15879517,15879530,15879531,15879531,15879532,15879532,15879536,15879529,15879531,15879531,15879532,15879532,15879533,15879533,15879535,15879532,15879532,15879533,15879533,15879534,15879528,15879536,15879541,15922240,15879546,16034671,16034671,16659764,15879546,15879548,15879551,16034670,16034671,16034671,16034672,16034672,16185511,16414072,16414073,16414074,16414074,15879548,15922254,16034668,16034670,16034671,16034672,16034672,16034673,16034675,16234325,16414073,16414074,16414074,16659765,17140921,16034672,16034673,16034673,16414073,16034672,16034673,16034674,16414074,16414076,16034673,16034674,16034674,16034676,16034677,16414079,15964949,15964960,15964974,15965051,15965159,16077499,16077500,16077500,15965250,16077537,16189808,16189794,16189795,16189809,16189796,16189796,16189796,16189797,16189797,16189811,16189811,16189812,16189812,16189797,16189798,16189811,16189812,16189812,16189813,16189813,16189798,16189809,16189810,16189811,16189812,16189812,16189813,16189813,16189814,16189814,16189815,16189800,16189810,16189811,16189811,16189812,16189812,16189813,16189813,16189814,16189814,16189815,16189815,16189817,16189815,16189819,16189825,16189825,16189826,16189824,16189826,16569212,16849256,16189826,16189827,16413632,16189826,16189827,16189827,16569212,16569213,16569216,17473991,16189827,16189828,16189828,16413735,16495684,16569213,16569213,16569214,16569214,16569215,16569216,16814905,16849098,16849099,17296061,17473992,16189828,16189829,16189829,16189830,16189831,16278134,16288135,16340652,16389465,16389466,16416968,16493872,16495685,16569213,16569214,16569215,16569215,16814905,16849098,16849098,17232522,17296061,17329100,17473992,17473992,17910648,16189829,16189830,16189830,16189835,16389466,16389467,16389468,16413735,16448812,16493873,16509317,16511056,16522857,16569214,16569214,16569215,16569215,16569216,16569216,16569217,16569218,16814906,16849099,16849100,16849259,17296062,17296063,17473993,17910648,16189830,16189831,16189831,16225150,16330064,16330066,16339703,16340653,16389465,16389466,16389467,16389467,16389468,16389468,16413736,16413737,16435219,16435220,16435221,16493873,16495681,16495683,16509159,16543889,16569214,16569214,16569215,16569215,16569216,16569216,16569217,16569217,16569218,16629532,16751319,16814906,16849099,16849099,16849100,16849101,16849254,16849276,17296062,17473993,17473993,16189832,16389468,16430370,16569215,16569215,16569216,16569216,16543892,16569215,16569216,16389469,16569216,16389469,16330068,16569217,16189838,16569220,16569221,16260485,16552066,16366468,16366538,16366599,16657609,16386460,16487792,16470313,16470316,16470315,16624478,16709463,16709465,16489592,16719105,16491491,16720053,16720054,16720054,16999939,17624831,16589118,16589119,16589119,16589120,16589106,16589120,16589121,16634874,16634875,16683884,16695336,16708812,16768867,16768867,16768868,16768868,16768869,16768869,17048752,17048753,17048754,17495715,16637449,16637450,16637555,16637557,16637656,16637656,16637657,16637657,16637660,16637661,16793134,16793136,16793137,17697913,16659140,16659142,16746778,16793135,16793136,16644120,16721024,16670923,16809770,16680624,16680625,16680626,16680627,16680627,16680629,16814621,16814620,16814620,16814621,17719399,16814620,16814622,16707867,16708026,16708186,16768374,16733648,16841131,16778649,16778651,16863633,16863634,16797927,16797918,16797933,16797953,16797946,16873269,17118966,16873287,16798028,16798104,16872053,16801551,16801548,16801550,16801551,16801554,16801553,16801554,16815024,16875082,16875083,16875083,16822598,16849766,16875086,17155125,16828501,16828504,16828506,16828503,16888557,16888558,16888558,16888559,16888563,16828817,16888715,16832293,16890451,16843643,16843643,16896128,16896128,16855900,16855903,16902257,16902259,16897964,16897971,16897978,16923289,16923294,16923298,16946001,16947318,16947318,16948598,16948599,16948599,16948600,16948600,16948601,16948601,16948602,16948614,16948614,16948615,16948600,16948601,16948601,16948602,16948602,16948603,16948604,16948615,16948615,16948601,16948602,16948602,16948603,16948603,16948604,16948604,16948615,16948615,16948616,16948602,16948603,16948603,16948604,16948604,16948615,16948616,16948616,16948617,16948617,16948618,16948619,16948619,16948603,16948604,16948604,16948605,16948616,16948616,16948617,16948617,16948618,16948618,16948619,16948621,16948604,16948605,16948605,16948606,16948617,16948617,16948618,16948618,16948619,16948620,16948605,16948617,16948618,16948618,16948619,16948619,16948620,16948609,16948618,16948618,16948619,16948620,16948621,16948618,16948618,16948619,16948620,16948620,16948622,16948619,16948620,16948621,16948621,16948629,16948630,16948631,16948631,17853393,17965489,16948630,16948631,16948631,16948632,17228501,17853393,16948631,16948632,16948632,16948633,16948633,16998462,17167680,17194307,17228499,17228501,17228501,17228538,17228660,17381282,17675463,17853394,17853417,17853418,17853421,17853445,17853448,18142354,18142354,18290049,18538942,16948632,16948633,16948633,16948634,16948638,17194307,17194309,17198364,17228500,17228501,17228502,17268027,17381281,17480484,17675463,17853386,17853394,18142354,16948633,16948634,16948635,16948636,16948636,16963772,16964101,17064183,17064187,17167676,17194308,17194309,17194310,17198364,17202992,17228500,17228501,17228501,17228502,17228502,17228656,17228658,17228659,17228660,17349862,17381282,17410318,17577461,17611703,17637700,17675464,17723653,17853394,17853395,17853419,17853445,18290050,18481646,18538456,16948634,16948635,16948635,16948636,16948636,16948637,16964099,16964100,16969988,17064184,17064184,17186467,17194308,17194310,17202993,17228501,17228502,17228502,17228503,17228646,17228659,17228660,17228661,17228662,17228662,17228689,17675464,17853387,17853395,17853419,17853420,17853445,17853449,18136591,18142354,18142355,18290051,17194309,17202993,17228502,17228503,17228662,17228662,17853395,17853396,17853420,17853449,18481700,16948636,17064185,17194309,17228503,17228658,17228662,17381283,17853396,16948637,17194310,17194315,17228503,17228503,17228504,17228649,17708505,17853389,17853396,17853397,18142356,17194310,17228494,17228504,17853422,17194311,17228505,17853398,17228508,16978923,17868545,16979578,16979578,16979580,17778298,17243982,17868874,16991395,17874803,17048293,17048304,18339916,17069244,17069319,17069395,17913781,17179751,17179751,17179752,17179750,17179752,17179756,17968961,17309875,18405618,17309876,17968963,17309876,17344070,17309877,17312884,17313137,17313390,18035811,17386743,17386800,17447569,17386901,17387006,17422217,17424364,18091292,17439984,17439995,17440001,17440007,17440008,17440016,17440026,17440008,17440009,17440027,17440028,17440031,17440019,17440025,17474194,17474195,17440032,17440050,17448692,17474200,17474200,17474201,17474201,17474202,17474305,17474357,17474358,17474359,17474360,17474361,17513727,17523148,17530015,17595561,17626982,17726183,17857623,17921163,17921193,18099094,18099118,17440051,17474201,17726183,18099095,17474209,18099112,17474220,17474380,17562848,17726200,17857424,18099113,17448107,17478245,18103137,17457361,17457362,17457362,17457462,17457463,17457464,17457372,17457464,17457464,17457464,17457465,17457565,17457556,17457566,17457566,17482972,17482974,17483119,17483131,17483131,18107866,18396826,18396827,17508360,17508370,17508388,17508390,17508392,17508394,17508396,17508398,17508369,17508370,17508370,17508389,17508391,17508391,17508392,17508392,17508393,17508394,17508396,17508397,17508397,17508398,17508399,17508399,17508371,17508385,17508392,17508392,17508393,17508394,17508395,17508398,17508400,17508371,17508395,17508395,17508399,17508400,17508401,17508391,17508392,17508392,17508393,17508393,17508394,17508394,17508395,17508395,17508396,17508397,17508397,17508398,17508398,17508399,17508399,17508400,17508400,17508401,17508402,17508403,17508403,17508408,17508409,17508414,17508422,17508445,18133279,18133282,18133307,17661170,18133283,17508416,18133284,17508416,18133285,17508418,17508419,17508421,17661173,17760374,18133277,18133285,17508417,17508417,17508419,17508421,17508552,18133286,18133286,18133310,18133336,17508419,17508421,17508422,17508424,17508553,17508424,17508540,17955356,18133287,17508423,17508554,17661175,17661175,18133288,18422247,17508421,17508421,17508422,17508423,17508502,17508538,17508553,17563826,18133280,18133288,17508425,17508423,17508424,17508482,17508554,17508555,17661177,18133289,17508423,17508424,17508425,17508428,17508558,17547922,17955359,18133290,18133343,17508425,17508426,17508497,17508499,17508529,17508540,17661177,17891602,18133290,17508426,17508550,17508558,17654419,18051127,18133291,17508427,17508546,17661179,18133291,17508428,17508428,17508434,17508546,17508549,17508558,17508558,17661179,17661179,17857358,17955361,17988401,18133291,18133292,17508485,17508509,17661179,17955361,18133284,18133292,17508430,17508555,17508556,17508557,17508561,17661181,17955362,18133292,18133293,18133317,18133320,17508553,17508556,17955362,17988402,18133293,18133293,18133294,17508553,18133294,18133295,18133295,18133296,18133298,18133300,17508520,18133301,17508571,17960455,17508564,17508605,17508616,17508628,17508629,18133366,17508654,17508660,17508630,18133376,17508687,17508710,17508704,17508680,17508683,17508703,17508685,17508707,17508709,17508684,17508680,17508699,17508691,17508682,17508703,17508693,17508701,17508704,17508706,17508705,17508705,17508702,17508705,17508706,17508706,17508699,17508704,17508706,17508706,17508707,17508708,17508703,17508714,17508704,17508707,17508708,17508708,17508711,17508705,17508707,17508689,17508691,17508704,17508709,17508709,17508711,17508711,17508707,17508709,17508709,17508711,17508692,17508711,17508712,17508713,17508714,17508713,17508714,17508714,17988538,18133430,18133432,17512251,18133433,17955503,18133436,17508725,17508724,17717551,17508745,17661326,18133432,18133440,17508727,18133441,18133441,18133442,17661329,18133442,17508732,17661330,17760534,17941905,17955512,18133435,18133442,18133443,18133467,17955512,18133435,18133443,18133444,18133444,17508733,17547940,17955514,18133445,17891975,18133437,18133445,17508735,17891970,17654574,17661335,18133438,18133446,18133470,18133447,18133450,17508767,17661338,18133454,17661342,18133455,18133460,18133463,17955542,18133497,17515804,18136986,17587158,17587295,17587436,17587427,17587437,17587442,17700691,17850814,17994873,18172804,17606279,18182225,17619252,17649155,17620019,18189098,17662343,17662475,17662604,18210416,17679055,17679123,17679188,17679203,18218681,17685643,18221908,17751101,17751103,17751248,18254628,17751395,18254773,17800430,17800430,18279301,18003795,17813931,17813946,17813946,17813947,17813945,17813947,17813948,17813933,17813948,17813947,17813949,17813950,18286058,17813961,17871594,18286051,18286059,18575016,18722714,17813963,18044367,18286059,18286059,18286060,18286060,17870174,18286061,17872018,17942184,17926395,17926395,18342282,17929237,17944410,17959630,18358946,18012349,18012349,18012349,18012350,18012351,18012352,18385260,18385261,18385261,18821917,18385254,18114187,18436177,18206300,18482234,18482289,18207155,18241190,18274791,18274791,18274795,18274795,18455866,18516483,18516484,18275223,18275227,18275227,18275229,18275229,18516699,18516699,18516723,18326798,18831453,18375104,18388718,18402295,18402296,18402370,18402306,18402372,18402312,18402381,18580236,18402364,18402398,18580276,18402444,18402446,18402448,18402469,18402562,18402645,18435411,18503187,18580293,18580301,18580354,18580302,18580304,18580325,18402748,18580487,18402920,18580576,18412448,18585307,18468390,18468391,18468392,18468393,18613282,18613283,18498683,18917385,18577015,18667591,18593844,18676000,18603941,18681056,18636922,18636958,18636995,18697576,18758149,18758172,18758156,18758157,18758158,18758158,18758159,18758159,18758161,18758163,18758166,18758166,18758167,18758168,18758169,18758176,18758179,18758179,18758180,18758180,18758181,18758181,18758182,18758182,18758181,18758181,18758181,18758181,18758182,18758182,18758183,18758183,18758183,18758185,18758187,18758176,18758176,18758178,18758191,18758191,18758254,19047129,19194822,19194847,18758191,18758192,18758218,19194823,18758192,18758193,18758200,18758202,18758203,18758203,18758203,18758204,18758204,18758205,18758209,18758223,18758230,18758235,18758257,18758205,18758206,18758206,18758207,18758207,18758208,18758208,18758210,18758211,18758214,18758215,18758216,18758216,18758218,18758220,18758220,18758221,18758221,18758222,18758222,18758223,18758224,18758224,18758225,18758230,18758230,18758231,18758232,18758233,18758234,18758235,18758236,18758237,18758240,18758245,18758256,18758257,18758206,18758207,18758207,18758208,18758208,18758209,18758210,18758211,18758212,18758212,18758213,18758215,18758217,18758218,18758220,18758221,18758223,18758223,18758224,18758224,18758225,18758225,18758226,18758226,18758227,18758228,18758228,18758231,18758231,18758233,18758233,18758234,18758234,18758235,18758236,18758245,18758249,18758257,18758257,18758207,18758208,18758208,18758209,18758209,18758211,18758213,18758213,18758216,18758217,18758218,18758221,18758222,18758223,18758223,18758224,18758224,18758225,18758226,18758226,18758227,18758230,18758231,18758232,18758233,18758234,18758235,18758245,18758250,18758256,18758257,18758257,18758258,18758208,18758209,18758209,18758210,18758212,18758212,18758213,18758214,18758222,18758222,18758223,18758224,18758224,18758225,18758226,18758227,18758232,18758232,18758235,18758236,18758256,18758257,18758258,18758258,18758209,18758212,18758218,18758226,18758226,18758227,18758229,18758231,18758233,18758235,18758254,18758255,18758257,18758258,18758258,18758211,18758215,18758223,18758224,18758226,18758227,18758230,18758233,18758258,18758211,18758213,18758219,18758226,18758227,18758227,18758228,18758228,18758230,18758231,18758234,18758253,18758259,18758260,18758213,18758215,18758215,18758224,18758226,18758227,18758227,18758228,18758229,18758232,18758234,18758260,18758229,18758217,18758221,18758229,18758230,18758230,18758235,18758236,18758239,18758243,18758250,18758229,18758243,18758227,18758227,18758231,18758240,18758263,18758227,18758228,18758232,18758220,18758228,18758232,18758233,18758238,18758263,18758233,18758230,18758236,18758235,18758266,18758241,18758232,18758233,18758234,18758236,18758237,18758242,18758244,18758246,18758264,18758268,18758268,18758241,18758244,18758238,18758245,18758240,18758240,18758246,18758250,18758252,18758240,18758240,18758241,18758241,18758246,18758248,18758250,18758259,18758265,18758271,18758272,18758272,18758241,18758250,18758255,18758273,18758242,18758247,18758251,18758242,18758242,18758246,18758248,18758250,18758252,18758273,18758241,18758243,18758248,18758252,18758257,18758258,18758260,18758274,18758243,18758243,18758249,18758251,18758274,18758275,18758243,18758244,18758244,18758249,18758249,18758250,18758255,18758256,18758276,18758244,18758245,18758249,18758250,18758250,18758252,18758253,18758253,18758254,18758276,18758245,18758246,18758247,18758247,18758248,18758248,18758249,18758249,18758250,18758250,18758251,18758252,18758253,18758254,18758254,18758256,18758257,18758264,18758264,18758267,18758275,18758276,18758277,19047158,19194856,18758246,18758248,18758248,18758249,18758250,18758250,18758251,18758251,18758253,18758254,18758255,18758258,18758259,18758269,18758273,18758276,18758276,18758277,18758277,18758278,18758252,18758253,18758257,19047162,18758254,18758252,18758252,18758253,18758254,18758255,18758250,18758253,18758256,18758258,18758253,18758254,18758255,18758257,18758260,18758254,18758257,18758258,18758254,18758255,18758256,18758255,18758255,18758258,18758255,18758256,18758256,18758257,18758271,18758281,18758256,18758258,18758259,18758259,18758260,18758260,18758266,18758277,18758277,18758281,18758281,18758282,18758282,18758257,18758258,18758259,18758260,18758260,18758261,18758262,18758263,18758264,18758264,18758265,18758265,18758268,18758269,18758270,18758270,18758271,18758273,18758273,18758274,18758275,18758276,18758278,18758278,18758280,18758281,18758282,18758282,18758283,18758259,18758283,18758279,18758260,18758261,18758261,18758262,18758262,18758263,18758263,18758264,18758265,18758265,18758266,18758267,18758270,18758272,18758272,18758276,18758276,18758277,18758280,18758283,18758283,18758284,18758284,18758262,18758266,18758267,18758272,18758276,18758284,18758262,18758263,18758264,18758265,18758266,18758268,18758269,18758270,18758274,18758277,18758277,18758284,18758285,18758285,18758263,18758264,18758265,18758267,18758268,18758268,18758269,18758277,18758280,18758281,18758284,18758285,18758285,18758286,18758264,18758265,18758265,18758266,18758267,18758268,18758268,18758269,18758269,18758270,18758272,18758273,18758274,18758275,18758275,18758276,18758277,18758278,18758278,18758279,18758279,18758280,18758280,18758281,18758282,18758284,18758285,18758285,18758286,18758286,18758287,18758265,18758266,18758268,18758269,18758281,18758286,18758286,18758287,18758266,18758270,18758277,18758280,18758282,18758268,18758269,18758270,18758270,18758274,18758276,18758277,18758277,18758279,18758282,18758283,18758283,18758287,18758287,18758288,18758288,18758288,18758272,18758274,18758278,18758284,18758288,18758288,18758289,18758277,18758288,18758272,18758272,18758278,18758279,18758282,18758282,18758285,18758288,18758289,18758289,18758290,18758273,18758276,18758278,18758285,18758289,18758290,18758273,18758276,18758280,18758283,18758286,18758286,18758290,18758290,18758291,18758274,18758277,18758279,18758286,18758290,18758291,18758291,18758278,18758291,18758291,18758292,18758278,18758283,18758286,18758287,18758288,18758291,18758292,18758292,18758285,18758293,18758294,18758294,18758294,18758281,18758283,18758285,18758289,18758294,18758294,18758295,18758290,18758294,18758295,18758284,18758287,18758294,18758295,18758296,19047180,18758286,18758287,18758289,18758289,18758291,18758292,18758292,18758295,18758296,18758297,18758296,18758297,18758295,18758296,18758298,18758297,18758297,18758298,18758298,18758292,18758298,18758299,18758299,18758299,18758291,18758300,18758295,18758295,18758299,18758299,18758300,18758300,18758295,18758296,18758299,18758300,18758300,18758301,18758296,18758301,18758301,18758302,18758301,18758301,18758302,18758302,19047187,18758297,18758302,18758303,18758302,18758303,18758303,18758302,18758302,18758303,18758303,18758304,18758301,18758302,18758303,18758303,18758304,18758304,18758303,18758303,18758304,18758304,18758305,18758304,18758306,18758305,18758306,18758306,18758307,18758307,18758307,18758308,18758332,19082602,18758308,18758309,18758327,18758331,18758332,18758332,18870328,19047191,19139377,19161340,19194888,18758309,18758310,18758310,18758314,18758318,18758321,18758322,18758322,18758324,18758326,18758327,18758329,18758330,18758330,18758331,18758331,18758332,18758332,18758333,18878251,18944463,18987341,19047192,19047192,19047193,19047193,19194888,19194913,19386484,19443266,18758310,18758316,18758316,18758317,18758321,18758324,18758326,18758327,18758328,18758328,18758329,18758330,18758330,18758331,18758331,18758332,18758332,18758333,18758333,19047192,19047194,19047194,18758312,18758319,18758325,18758331,18758331,18758332,18758332,18758333,18758333,18758334,18758334,18758331,18758338,18758339,18758337,18758339,18758339,18758340,18758341,18758341,18758344,18758344,18758344,18758346,18758336,18758346,18758345,18758347,18758348,18758348,18758349,18758344,18758348,18758349,18758350,18758351,18758349,18758350,18758351,18758351,18758352,18758350,18758351,18758351,18758352,18758352,18758353,18758353,19194909,18758354,18758352,18758353,18758353,18758354,18758354,18758353,18758354,18758354,18758355,18758354,18758355,18758355,19194911,18758355,18758356,19194911,18758356,18758357,18793679,18813072,18840333,18850819,18870352,18870353,18870354,18878273,18878275,18911068,18924046,18933783,18933843,18944487,18954987,18987365,19037475,19047212,19047212,19047214,19047215,19047216,19047216,19047217,19047217,19047218,19047218,19047219,19047219,19047220,19082624,19082627,19088148,19088149,19194907,19194909,19194912,19194912,19194937,19386508,19386535,19443261,19443290,19047217,19047218,19194913,18829026,18905700,18867800,19101945,18922323,18922324,19129206,19129206,18952344,19129207,19276903,18943296,19139697,18982360,18982360,18982360,18982361,18982361,18982362,18982362,18982364,18982366,19056495,19306919,19306920,18982373,19159224,19159224,19159225,19306920,18982374,19159224,19159225,19159225,19159226,19200158,19306921,19159225,19159226,19159227,18990284,19056499,19159229,19306924,19159229,18998203,18998204,18998205,18998205,18998215,19314841,18998217,19167143,19167148,19074924,19167147,19314843,19063794,19199943,19089750,19212922,19109209,19109235,19370364,19109345,19370414,19130630,19130630,19223618,19233359,19233360,19381055,19151629,19151632,19151640,19391555,19243861,19238101,19216385,19276236,19423932,19316628,19316637,19316671,19316690,19326377,19326389,19324560,19324562,19478020,19330324,19336085,19336069,19336071,19336073,19336073,19336074,19336073,19336091,19336074,19336076,19336090,19336075,19336076,19336076,19336077,19336077,19336078,19336078,19336079,19336088,19336090,19336091,19336091,19336092,19336092,19336093,19336076,19336077,19336077,19336078,19336079,19336091,19336092,19336092,19336093,19336077,19336078,19336078,19336079,19336079,19336091,19336092,19336092,19336093,19336093,19336094,19336078,19336079,19336079,19336080,19336080,19336081,19336090,19336090,19336092,19336092,19336093,19336093,19336094,19336079,19336080,19336080,19336092,19336093,19336093,19336094,19336094,19336095,19336093,19336094,19336094,19336095,19336095,19336096,19336096,19336094,19336094,19336095,19336096,19336082,19336095,19336095,19336096,19336096,19336095,19336096,19336095,19336096,19336103,19336105,19483786,19336106,19336107,19336107,19336107,19483787,19336107,19336108,19336108,19483787,19483812,19336108,19336109,19336109,19371503,19423855,19460297,19483788,19675384,19675410,19732166,19336109,19336110,19336110,19336112,19371503,19377023,19377024,19377025,19383912,19428279,19438034,19438138,19450747,19450751,19460297,19483785,19483788,19483788,19483813,19483817,19483818,19336110,19336111,19336117,19371503,19377022,19377023,19450750,19450751,19450752,19483789,19483813,19483815,19377024,19450238,19483789,19483789,19483790,19483790,19483791,19371511,19406912,19406897,19406912,19406913,19406914,19406915,19406913,19519198,19519198,19519199,19519201,19417951,19417951,19417938,19417949,19417953,19417952,19417954,19417953,19417954,19417954,19524714,19417967,19524717,19524717,19524717,19524718,19469487,19431730,19531606,19511618,19571550,19520460,19520461,19575971,19575995,19521019,19576250,19539977,19585731,19540180,19540291,19540400,19585939,19564380,19564385,19597932,19846334,19565400,19565402,19565408,19565398,19565408,19565409,19598441,19565419,19598441,19598445,19598469,19598446,19584499,19584499,19607990,19607990,19631463,19631464,19631467,19631468,19631469,19631470,19631470,19631471,19631471,19631472,19631472,19631477,19631478,19631479,19631479,19631480,19631486,19631488,19631489,19631489,19631490,19631491,19631491,19631492,19631492,19631524,19631543,19631546,19631490,19631492,19631493,19631471,19631472,19631473,19631493,19631494,19631492,19631493,19631493,19631494,19631494,19631494,19631495,19631495,19631495,19631495,19631496,19631496,19631496,19631501,19631503,19631503,19631503,19631504,19631511,19631513,19631511,19631511,19631514,19631512,19631513,19631514,19631514,19631568,19631513,19631514,19631515,19631541,19631515,19631515,19631530,19631515,19631516,19631516,19631534,19631538,19631542,19631542,19631567,19631568,19631517,19631518,19631518,19631519,19631519,19631520,19631520,19631521,19631521,19631522,19631524,19631524,19631525,19631525,19631527,19631527,19631528,19631529,19631530,19631530,19631531,19631531,19631532,19631533,19631534,19631535,19631535,19631536,19631537,19631538,19631538,19631539,19631539,19631540,19631540,19631541,19631541,19631542,19631542,19631543,19631543,19631544,19631545,19631545,19631546,19631546,19631547,19631547,19631548,19631549,19631554,19631556,19631558,19631563,19631567,19631568,19631518,19631519,19631519,19631521,19631521,19631522,19631529,19631530,19631535,19631535,19631537,19631538,19631538,19631539,19631540,19631540,19631541,19631542,19631543,19631543,19631544,19631544,19631546,19631549,19631568,19631522,19631523,19631531,19631532,19631536,19631537,19631542,19631543,19631544,19631552,19631569,19631522,19631522,19631531,19631544,19631544,19631550,19631542,19631544,19631545,19631570,19631524,19631532,19631543,19631543,19631544,19631545,19631545,19631538,19631539,19631543,19631543,19631547,19631526,19631534,19631541,19631542,19631544,19631545,19631547,19631547,19631549,19631561,19631572,19631533,19631541,19631542,19631543,19631546,19631549,19631532,19631540,19631541,19631542,19631543,19631544,19631544,19631545,19631546,19631547,19631573,19631544,19631545,19631546,19631551,19631575,19631548,19631548,19631541,19631544,19631539,19631546,19631550,19631550,19631578,19631549,19631549,19631550,19631552,19631554,19631554,19631555,19631579,19631551,19631553,19631555,19631547,19631550,19631558,19631548,19631550,19631554,19631555,19631555,19631556,19631562,19631549,19631549,19631557,19631559,19631584,19631552,19631555,19631557,19631557,19631558,19631560,19631561,19631561,19631562,19631566,19631583,19631585,19631588,19631553,19631555,19631558,19631558,19631559,19631560,19631561,19631562,19631563,19631564,19631567,19631570,19631580,19631585,19631586,19631556,19631557,19631561,19631561,19631566,19631567,19631586,19631557,19631559,19631564,19631565,19631571,19631587,19631588,19631581,19631558,19631559,19631560,19631560,19631561,19631563,19631563,19631564,19631564,19631566,19631566,19631567,19631568,19631568,19631569,19631588,19879861,19631560,19631560,19631561,19631562,19631563,19631564,19631567,19631570,19631574,19631588,19631589,19631561,19631561,19631562,19631562,19631563,19631564,19631565,19631565,19631566,19631567,19631570,19631570,19631571,19631573,19631589,19631590,19631590,19631562,19631563,19631564,19631565,19631565,19631566,19631566,19631567,19631567,19631568,19631570,19631571,19631589,19631590,19631591,19631563,19631564,19631565,19631565,19631566,19631566,19631567,19631567,19631568,19631568,19631569,19631570,19631572,19631578,19631591,19631564,19631565,19631566,19631566,19631567,19631567,19631568,19631569,19631589,19631591,19631566,19631566,19631567,19631567,19631568,19631569,19631570,19631573,19631592,19631567,19631568,19631568,19631567,19631568,19631568,19631569,19631570,19631570,19631571,19631593,19631568,19631569,19631569,19631570,19631570,19631571,19631571,19631572,19631572,19631574,19631575,19631578,19631586,19631587,19631590,19631590,19631593,19631569,19631570,19631570,19631571,19631571,19631572,19631572,19631573,19631574,19631575,19631578,19631579,19631588,19631589,19631591,19631592,19631594,19631570,19631571,19631572,19631572,19631573,19631573,19631574,19631574,19631575,19631575,19631578,19631579,19631579,19631582,19631586,19631588,19631590,19631593,19631593,19631594,19631571,19631572,19631572,19631573,19631573,19631574,19631574,19631576,19631576,19631578,19631579,19631580,19631585,19631587,19631587,19631589,19631592,19631593,19631594,19631595,19631572,19631573,19631574,19631578,19631586,19631587,19631595,19631595,19631573,19631574,19631574,19631575,19631575,19631577,19631577,19631581,19631582,19631584,19631586,19631594,19631596,19631574,19631575,19631575,19631576,19631577,19631578,19631579,19631581,19631583,19631589,19631590,19631592,19631594,19631595,19631596,19631596,19631575,19631576,19631576,19631577,19631578,19631590,19631596,19631596,19631597,19631576,19631577,19631577,19631578,19631581,19631582,19631582,19631588,19631589,19631593,19631594,19631595,19631597,19631597,19631579,19631582,19631582,19631584,19631591,19631592,19631594,19631597,19631598,19823145,19631578,19631579,19631580,19631582,19631591,19631596,19631597,19631598,19631598,19631579,19631580,19631596,19631598,19631599,19631580,19631581,19631599,19631582,19631583,19631585,19631585,19631586,19631589,19631590,19631590,19631592,19631593,19631593,19631594,19631594,19631595,19631597,19631598,19631598,19631599,19631599,19631600,19631602,19631584,19631587,19631595,19631596,19631597,19631598,19631600,19631591,19631601,19631602,19631588,19631600,19631602,19631600,19631603,19631590,19631596,19631599,19631600,19631602,19631603,19631591,19631596,19631601,19631602,19631603,19631604,19631597,19631604,19631605,19631597,19631603,19631605,19631605,19631604,19631606,19631607,19631607,19631608,19631601,19631601,19631602,19631603,19631609,19631602,19631610,19631603,19631605,19631607,19631609,19631610,19631611,19631606,19631611,19631606,19631606,19631608,19631612,19631608,19631612,19631612,19631612,19631613,19631613,19631613,19631610,19631613,19631613,19631614,19631611,19631614,19631614,19631612,19631614,19631615,19631615,19631615,19631615,19631616,19631615,19631616,19631616,19631615,19631617,19631619,19631617,19631617,19823164,19879920,19631617,19631618,19631620,19631618,19631619,19631620,19631620,19631621,19631621,19631622,19631624,19631625,19631628,19631629,19631630,19631631,19631632,19631634,19631637,19631637,19631638,19631639,19631640,19631640,19631641,19631641,19631642,19631642,19631643,19631643,19787752,19823139,19823139,19823166,19823193,19879921,19879946,19879986,21930687,19631620,19631621,19631621,19631622,19631622,19631624,19631625,19631629,19631631,19631634,19631638,19631639,19631640,19631641,19631641,19631642,19631642,19631643,19631643,19631644,19879922,19631622,19631643,19631643,19631644,19631622,19631645,19631623,19631626,19631627,19631631,19631639,19631643,19631643,19631644,19631644,19631645,19631645,19631624,19631627,19631630,19631643,19631644,19631645,19631645,19631646,19823142,19631627,19631632,19631644,19631645,19631646,19631630,19631647,19631647,19631641,19631643,19631644,19631645,19631646,19631647,19631647,19631648,19631648,19631649,19631650,19631646,19631652,19631649,19631649,19631650,19631651,19631652,19823177,19631653,19631645,19631655,19631654,19631655,19631657,19631658,19631659,19631659,19631660,19631660,19631661,19631661,19631660,19631661,19631661,19631661,19631662,19631663,19631661,19631662,19631662,19631663,19631663,19631663,19631664,19631663,19631664,19631664,19631665,19631663,19631664,19631664,19631665,19631664,19631665,19631665,19631666,19631665,19631666,19631666,19631666,19631667,19879915,19631667,19631668,19631669,19681627,19754038,19787778,19787782,19787782,19787784,19787785,19787787,19802464,19803381,19823163,19823164,19823190,19823218,19879916,19879967,19879969,19880010,19880518,19880555,19880556,20517909,20676722,19823164,19823164,19823165,19731642,19731721,19731820,19873277,19876423,19876424,19945548,19945549,19943900,19943910,19943916,19943915,19943917,19943918,19943919,19943919,19943922,19979314,19979296,19979296,19979298,19979298,19979298,19973274,19984513,19975149,19975222,19994949,19995765,20005225,20014659,20014660,20014661,20014662,20014662,20014664,20014668,20014669,20014670,20014671,20014685,20014686,20014686,20014687,20014735,20014686,20014686,20014687,20014686,20014687,20014688,20014689,20014690,20014694,20014696,20014696,20014697,20014758,20014711,20014712,20014712,20014713,20014714,20014714,20014715,20014715,20014716,20014716,20014717,20014718,20014718,20014720,20014721,20014722,20014723,20014724,20014724,20014725,20014725,20014726,20014726,20014728,20014728,20014729,20014730,20014730,20014731,20014731,20014732,20014732,20014733,20014733,20014734,20014734,20014735,20014735,20014736,20014736,20014737,20014737,20014738,20014738,20014739,20014739,20014740,20014740,20014741,20014742,20014744,20014746,20014747,20014749,20014761,20014762,20014714,20014715,20014715,20014718,20014729,20014730,20014731,20014731,20014732,20014734,20014735,20014735,20014736,20014736,20014738,20014738,20014739,20014739,20014740,20014741,20014762,20014716,20014717,20014727,20014732,20014733,20014736,20014737,20014737,20014738,20014739,20014740,20014742,20014763,20014716,20014728,20014733,20014735,20014737,20014750,20014717,20014719,20014730,20014733,20014735,20014736,20014737,20014738,20014740,20014734,20014735,20014736,20014737,20014738,20014738,20014740,20014745,20014735,20014737,20014738,20014739,20014737,20014735,20014737,20014737,20014738,20014738,20014739,20014740,20014740,20014742,20014742,20014743,20014766,20014736,20014738,20014741,20014749,20014767,20014753,20014744,20014752,20014772,20014747,20014773,20014749,20014748,20014751,20014751,20014740,20014749,20014745,20014746,20014750,20014746,20014755,20014777,20014752,20014748,20014750,20014747,20014748,20014748,20014750,20014751,20014753,20014754,20014755,20014756,20014757,20014757,20014749,20014752,20014753,20014754,20014755,20014756,20014759,20014767,20014780,20014751,20014752,20014754,20014756,20014757,20014780,20014751,20014752,20014754,20014755,20014755,20014757,20014758,20014758,20014759,20014781,20014752,20014753,20014755,20014756,20014757,20014753,20014754,20014754,20014756,20014757,20014758,20014758,20014760,20014764,20868265,20014755,20014755,20014756,20014756,20014757,20014758,20014759,20014759,20014760,20014761,20014764,20014765,20014767,20014782,20014782,20014756,20014756,20014757,20014758,20014759,20014760,20014761,20014762,20014762,20014757,20014758,20014759,20014760,20014762,20014758,20014759,20014760,20014760,20014761,20014771,20014758,20014760,20014761,20014762,20014763,20014764,20014765,20014768,20014784,20014784,20014759,20014760,20014760,20014761,20014761,20014762,20014762,20014763,20014763,20014764,20014764,20014765,20014766,20014767,20014769,20014771,20014772,20014773,20014781,20014782,20014782,20014784,20014785,20014760,20014761,20014761,20014762,20014762,20014763,20014763,20014764,20014764,20014765,20014762,20014762,20014762,20014763,20014764,20014764,20014765,20014766,20014769,20014770,20014774,20014783,20014786,20014763,20014764,20014764,20014765,20014765,20014766,20014767,20014768,20014768,20014773,20014784,20014787,20014764,20014765,20014765,20014766,20014766,20014767,20014767,20014769,20014770,20014772,20014773,20014774,20014775,20014778,20014779,20014784,20014785,20014786,20014786,20014787,20014787,20014765,20014766,20014766,20014767,20014767,20014768,20014769,20014770,20014773,20014775,20014778,20014782,20014785,20014787,20014788,20014766,20014767,20014767,20014768,20014768,20014769,20014771,20014772,20014775,20014776,20014777,20014781,20014787,20014788,20014788,20014767,20014768,20014768,20014769,20014770,20014770,20014771,20014776,20014777,20014779,20014783,20014786,20014786,20014787,20014789,20014768,20014769,20014769,20014771,20014772,20014776,20014778,20014782,20014789,20014789,20014769,20014770,20014771,20014772,20014773,20014774,20014777,20014783,20014784,20014786,20014789,20014790,20014770,20014772,20014773,20014777,20014785,20014788,20014790,20014772,20014773,20014774,20014775,20014776,20014777,20014778,20014779,20014787,20014790,20014791,20014791,20014774,20014778,20014787,20014791,20014792,20014777,20014792,20014792,20014793,20014777,20014779,20014780,20014780,20014781,20014786,20014787,20014789,20014789,20014791,20014791,20014792,20014793,20014793,20014793,20014794,20014778,20014783,20014788,20014794,20014782,20014783,20014794,20014795,20014795,20014796,20014796,20014795,20014784,20014789,20014794,20014797,20014786,20014787,20014792,20014795,20014795,20014796,20014796,20014797,20014797,20014798,20014787,20014798,20014791,20014792,20014793,20014795,20014795,20014798,20014799,20014799,20014794,20014800,20014801,20014801,20014802,20014795,20014802,20014797,20014800,20014803,20014798,20014799,20014804,20014804,20014803,20014805,20014803,20014805,20014805,20014802,20014803,20014806,20014806,20014807,20014807,20014807,20014806,20014807,20014808,20014808,20014808,20014809,20014809,20014809,20014810,20014810,20014811,20014812,20014813,20014813,20014815,20014818,20014821,20014823,20014824,20014825,20014825,20014826,20014826,20014827,20014832,20014835,20014835,20014836,20014836,20014837,20014837,20071488,20071517,20072032,21406677,22203959,20014812,20014813,20014813,20014818,20014822,20014824,20014825,20014829,20014830,20014831,20014834,20014835,20014835,20014836,20014836,20014837,20014837,20014838,20071518,20014818,20014822,20014826,20014832,20014837,20014838,20014838,20014839,20014829,20014838,20014839,20014828,20014841,20014843,20014839,20014844,20014847,20014848,20014849,20014850,20014851,20014851,20014841,20014852,20014843,20014853,20014853,20014854,20014855,20014856,20014856,20014857,20014859,20014860,20014861,20014860,20014861,20014861,20014862,20014862,20014862,20014863,20014863,20014864,20014865,20071448,20071514,20071514,20071544,20071546,20071562,20071608,20072058,20072058,20072154,20868320,20071515,20071515,20128098,20128164,20128165,20128166,20128166,20128167,20128167,20128169,20128174,20128182,20128187,20128188,20128191,20128193,20128193,20128194,20128194,20128209,20128166,20128167,20128190,20128191,20128193,20128194,20128194,20128195,20128195,20128195,20128192,20128195,20128196,20128196,20128196,20128196,20128198,20128198,20128203,20128211,20128212,20128216,20128217,20128215,20128219,20128220,20128220,20128222,20128222,20128222,20128223,20128223,20128224,20128225,20128225,20128226,20128226,20128227,20128227,20128228,20128228,20128229,20128229,20128230,20128230,20128231,20128231,20128232,20128233,20128234,20128235,20128235,20128236,20128236,20128237,20128237,20128238,20128239,20128240,20128240,20128241,20128242,20128242,20128243,20128243,20128244,20128244,20128245,20128245,20128246,20128246,20128247,20128247,20128248,20128248,20128249,20128250,20128251,20128251,20128252,20128253,20128269,20128270,20128288,20128299,20128225,20128226,20128226,20128227,20128228,20128229,20128230,20128230,20128231,20128231,20128233,20128233,20128237,20128239,20128242,20128243,20128244,20128244,20128245,20128245,20128247,20128247,20128249,20128270,20128270,20128226,20128227,20128227,20128228,20128230,20128230,20128231,20128232,20128238,20128238,20128243,20128246,20128247,20128249,20128271,20128228,20128229,20128230,20128243,20128244,20128246,20128228,20128229,20128231,20128231,20128233,20128236,20128240,20128244,20128246,20128246,20128247,20128252,20128272,20128229,20128230,20128232,20128239,20128240,20128241,20128245,20128247,20128247,20128249,20128230,20128242,20128245,20128245,20128232,20128232,20128233,20128233,20128241,20128246,20128247,20128247,20128248,20128251,20128273,20128234,20128246,20128247,20128233,20128241,20128247,20128252,20128235,20128236,20128241,20128244,20128247,20128247,20128249,20128250,20128251,20128251,20128252,20128257,20128265,20128275,20128238,20128240,20128241,20128243,20128247,20128247,20128248,20128250,20128250,20128252,20128257,20128239,20128242,20128244,20128245,20128247,20128248,20128251,20128253,20128256,20128276,20128249,20128251,20128254,20128276,20128244,20128248,20128249,20128258,20128250,20128252,20128277,20128244,20128250,20128250,20128251,20128253,20128255,20128278,20128244,20128251,20128253,20128254,20128244,20128252,20128254,20128246,20128253,20128281,20128247,20128254,20128256,20128256,20128258,20128249,20128254,20128255,20128256,20128257,20128259,20128259,20128253,20128255,20128257,20128252,20128255,20128255,20128257,20128263,20128252,20128255,20128255,20128256,20128256,20128257,20128259,20128261,20128262,20128275,20128255,20128256,20128257,20128260,20128261,20128266,20128257,20128260,20128258,20128262,20128261,20128259,20128261,20128260,20128262,20128262,20128264,20128279,20128260,20128261,20128262,20128263,20128264,20128264,20128265,20128276,20128261,20128262,20128262,20128263,20128263,20128264,20128264,20128265,20128265,20128266,20128266,20128267,20128268,20128269,20128269,20128270,20128279,20128288,20128262,20128263,20128264,20128269,20128264,20128264,20128265,20128266,20128268,20128289,20128264,20128265,20128267,20128267,20128271,20128308,20128265,20128266,20128266,20128267,20128267,20128268,20128268,20128269,20128269,20128271,20128272,20128272,20128273,20128274,20128289,20128290,20128266,20128267,20128267,20128268,20128268,20128269,20128269,20128270,20128270,20128271,20128271,20128272,20128272,20128273,20128273,20128279,20128281,20128285,20128286,20128289,20128290,20128291,20128267,20128268,20128269,20128269,20128270,20128273,20128286,20128268,20128269,20128269,20128270,20128270,20128271,20128272,20128272,20128273,20128292,20128269,20128270,20128270,20128271,20128272,20128273,20128273,20128274,20128283,20128286,20128290,20128292,20128292,20128270,20128271,20128271,20128272,20128273,20128273,20128274,20128274,20128275,20128276,20128288,20128292,20128293,20128271,20128272,20128272,20128273,20128273,20128274,20128274,20128275,20128275,20128277,20128278,20128279,20128283,20128284,20128284,20128288,20128290,20128291,20128293,20128293,20128272,20128273,20128273,20128274,20128274,20128275,20128275,20128276,20128276,20128278,20128279,20128281,20128283,20128284,20128287,20128288,20128290,20128293,20128294,20128273,20128274,20128274,20128275,20128275,20128276,20128276,20128277,20128278,20128279,20128281,20128284,20128288,20128291,20128292,20128294,20128275,20128275,20128276,20128276,20128278,20128281,20128293,20128295,20128275,20128276,20128276,20128277,20128277,20128279,20128281,20128282,20128283,20128288,20128294,20128295,20128276,20128277,20128277,20128278,20128278,20128281,20128286,20128290,20128291,20128292,20128295,20128296,20128277,20128278,20128278,20128283,20128285,20128286,20128290,20128291,20128292,20128293,20128294,20128294,20128296,20128296,20128278,20128279,20128280,20128281,20128283,20128284,20128284,20128286,20128287,20128287,20128288,20128291,20128294,20128295,20128296,20128296,20128297,20128279,20128280,20128281,20128281,20128282,20128284,20128285,20128287,20128289,20128291,20128292,20128292,20128293,20128295,20128296,20128297,20128297,20128280,20128281,20128281,20128284,20128284,20128285,20128286,20128289,20128291,20128291,20128293,20128295,20128295,20128297,20128297,20128298,20128289,20128292,20128295,20128298,20128299,20128283,20128291,20128292,20128293,20128295,20128296,20128299,20128286,20128300,20128299,20128300,20128287,20128292,20128296,20128301,20128288,20128292,20128295,20128301,20128302,20128299,20128293,20128295,20128299,20128299,20128300,20128302,20128303,20128293,20128299,20128303,20128299,20128304,20128304,20128305,20128295,20128300,20128300,20128305,20128306,20128301,20128304,20128306,20128306,20128306,20128307,20128307,20128304,20128307,20128308,20128309,20128309,20128305,20128306,20128307,20128308,20128308,20128310,20128310,20128307,20128309,20128310,20128311,20128307,20128311,20128308,20128309,20128310,20128312,20128311,20128312,20128312,20128311,20128313,20128313,20128312,20128314,20128313,20128314,20128314,20128315,20128315,20128316,20128317,20128317,20128318,20128319,20128321,20128322,20128325,20128325,20128329,20128329,20128330,20128331,20128333,20128334,20128334,20128335,20128338,20128339,20128340,20128340,20128341,20128342,20128342,20128343,20128343,20128344,20128344,20128345,20128345,20128784,20128785,20128814,20128815,20128815,20128819,20128827,20128831,20128835,20128837,20128879,20128880,20925046,20128317,20128318,20128318,20128319,20128322,20128325,20128328,20128328,20128329,20128330,20128331,20128334,20128335,20128336,20128339,20128340,20128341,20128342,20128342,20128343,20128343,20128344,20128344,20128345,20128345,20128346,20128330,20128334,20128340,20128344,20128345,20128345,20128346,20128346,20128323,20128326,20128335,20128344,20128346,20128347,20128342,20128345,20128346,20128347,20128348,20128339,20128345,20128351,20128351,20128342,20128353,20128353,20128354,20128354,20128355,20128357,20128354,20128353,20128356,20128358,20128354,20128356,20128355,20128358,20128361,20128353,20128356,20128357,20128359,20128361,20128361,20128362,20128362,20128363,20128363,20128354,20128360,20128363,20128363,20128364,20128359,20128363,20128365,20128363,20128358,20128365,20128367,20128363,20128366,20128368,20128365,20128367,20128368,20128368,20128369,20128866,20128369,20128370,20128367,20128368,20128368,20128369,20128370,20128368,20128369,20128370,20128371,20128371,20128370,20128371,20128372,20128370,20128371,20128371,20128372,20128372,20128371,20128372,20128372,20128373,20128812,20128372,20128373,20128373,20128373,20128374,20128374,20128375,20128376,20128813,20128814,20128843,20128843,20128844,20128845,20128845,20128846,20128847,20128848,20128864,20128865,20128872,20128908,20128910,20638446,20638446,20766264,20766265,20811993,20925076,21681247,20128814,20128814,20128815,20129252,20129253,20129254,20129254,20129255,20129255,20129256,20129257,20129260,20129264,20129272,20129273,20129275,20129280,20129281,20129281,20129282,20129282,20129283,20129283,20129284,20129284,20129285,20129328,20129254,20129257,20129282,20129282,20129283,20129283,20129284,20129256,20129257,20129274,20129282,20129283,20129283,20129284,20129284,20129285,20129284,20129284,20129285,20129284,20129285,20129286,20129287,20129287,20129291,20129293,20129293,20129302,20129302,20129302,20129304,20129306,20129309,20129311,20129310,20129311,20129311,20129312,20129312,20129313,20129313,20129312,20129313,20129313,20129314,20129314,20129316,20129324,20129329,20129332,20129333,20129334,20129337,20129358,20129313,20129314,20129314,20129316,20129316,20129320,20129321,20129330,20129332,20129333,20129333,20129334,20129335,20129336,20129337,20129341,20129342,20129348,20129358,20129314,20129315,20129315,20129316,20129316,20129328,20129330,20129333,20129334,20129335,20129337,20129353,20129359,20129315,20129316,20129316,20129317,20129318,20129318,20129319,20129322,20129325,20129330,20129331,20129333,20129333,20129334,20129334,20129335,20129335,20129336,20129337,20129338,20129342,20129359,20129316,20129317,20129317,20129318,20129318,20129319,20129320,20129321,20129322,20129323,20129323,20129325,20129325,20129326,20129326,20129327,20129328,20129331,20129331,20129334,20129334,20129335,20129336,20129336,20129337,20129337,20129338,20129339,20129339,20129340,20129340,20129341,20129341,20129342,20129348,20129359,20129360,20129317,20129318,20129318,20129320,20129320,20129321,20129321,20129322,20129323,20129323,20129324,20129324,20129325,20129325,20129326,20129326,20129327,20129329,20129330,20129331,20129332,20129333,20129334,20129335,20129335,20129336,20129336,20129337,20129337,20129338,20129338,20129340,20129340,20129342,20129356,20129358,20129360,20129318,20129319,20129319,20129320,20129321,20129322,20129323,20129326,20129328,20129329,20129330,20129332,20129332,20129333,20129334,20129335,20129335,20129336,20129337,20129337,20129338,20129339,20129340,20129350,20129361,20129319,20129320,20129321,20129321,20129322,20129325,20129327,20129328,20129329,20129333,20129335,20129335,20129336,20129336,20129339,20129339,20129361,20129320,20129321,20129321,20129322,20129322,20129323,20129323,20129324,20129325,20129327,20129327,20129329,20129329,20129330,20129333,20129336,20129336,20129337,20129337,20129338,20129338,20129339,20129340,20129342,20129343,20129344,20129361,20129362,20129328,20129333,20129337,20129337,20129362,20129334,20129338,20129342,20129363,20129323,20129328,20129328,20129331,20129334,20129337,20129337,20129338,20129338,20129329,20129330,20129331,20129332,20129335,20129338,20129339,20129339,20129340,20129329,20129333,20129335,20129340,20129330,20129332,20129336,20129331,20129333,20129334,20129340,20129341,20129341,20129344,20129332,20129341,20129342,20129347,20129331,20129332,20129338,20129338,20129367,20129338,20129344,20129345,20129346,20129340,20129343,20129344,20129333,20129340,20129343,20129334,20129338,20129340,20129344,20129345,20129349,20129369,20129336,20129337,20129338,20129341,20129343,20129343,20129344,20129344,20129345,20129346,20129347,20129349,20129355,20129369,20129344,20129344,20129346,20129346,20129348,20129350,20129339,20129342,20129345,20129345,20129346,20129347,20129353,20129371,20129342,20129346,20129346,20129347,20129368,20129346,20129343,20129344,20129345,20129346,20129347,20129347,20129348,20129348,20129352,20129347,20129348,20129349,20129352,20129349,20129352,20129366,20766750,20129346,20129349,20129350,20129351,20129355,20129373,20129375,20129348,20129349,20129349,20129350,20129350,20129351,20129352,20129353,20129356,20129357,20129358,20129375,20129351,20129351,20129352,20129351,20129353,20129357,20129352,20129353,20129356,20129358,20129377,20129352,20129353,20129354,20129354,20129356,20129357,20129359,20129360,20129360,20129377,20129378,20129353,20129354,20129355,20129355,20129356,20129356,20129357,20129358,20129358,20129359,20129359,20129360,20129361,20129361,20129377,20129378,20129354,20129355,20129355,20129356,20129356,20129357,20129357,20129358,20129358,20129359,20129359,20129360,20129360,20129361,20129361,20129362,20129363,20129367,20129369,20129370,20129371,20129371,20129378,20129378,20129379,20129355,20129356,20129357,20129360,20129360,20129361,20129379,20129356,20129357,20129358,20129359,20129359,20129360,20129360,20129361,20129361,20129362,20129362,20129371,20129372,20129379,20129380,20129357,20129358,20129358,20129359,20129360,20129360,20129361,20129361,20129362,20129362,20129363,20129364,20129372,20129375,20129377,20129379,20129380,20129380,20129358,20129359,20129359,20129361,20129362,20129373,20129377,20129378,20129381,20129359,20129360,20129360,20129361,20129361,20129362,20129363,20129363,20129364,20129364,20129368,20129376,20129381,20129381,20129360,20129361,20129361,20129362,20129362,20129363,20129363,20129364,20129364,20129378,20129379,20129380,20129382,20129361,20129363,20129364,20129365,20129379,20129382,20129362,20129363,20129363,20129364,20129365,20129365,20129372,20129375,20129376,20129380,20129381,20129381,20129383,20129363,20129364,20129364,20129365,20129365,20129366,20129371,20129375,20129376,20129377,20129379,20129381,20129382,20129383,20129364,20129365,20129365,20129366,20129366,20129367,20129375,20129376,20129379,20129380,20129382,20129383,20129384,20129365,20129366,20129366,20129367,20129367,20129368,20129370,20129372,20129374,20129376,20129379,20129379,20129380,20129382,20129384,20129366,20129367,20129367,20129368,20129368,20129370,20129373,20129375,20129376,20129377,20129378,20129381,20129384,20129385,20129367,20129368,20129368,20129369,20129372,20129374,20129377,20129377,20129380,20129385,20129385,20129368,20129369,20129369,20129371,20129372,20129374,20129376,20129377,20129378,20129378,20129379,20129382,20129383,20129383,20129384,20129384,20129385,20129385,20129386,20129369,20129370,20129370,20129371,20129372,20129373,20129373,20129377,20129378,20129378,20129379,20129381,20129381,20129382,20129382,20129383,20129384,20129385,20129385,20129386,20129386,20129370,20129371,20129373,20129373,20129374,20129375,20129376,20129378,20129379,20129385,20129386,20129387,20129374,20129379,20129385,20129387,20129374,20129376,20129380,20129386,20129386,20129387,20129387,20129388,20129378,20129387,20129389,20129389,20129381,20129383,20129387,20129390,20129383,20129386,20129388,20129390,20129385,20129389,20129391,20129383,20129385,20129390,20129384,20129390,20129392,20129392,20129393,20129387,20129389,20129393,20129393,20129391,20129394,20129387,20129392,20129394,20129395,20129395,20129395,20129389,20129391,20129392,20129394,20129395,20129395,20129396,20129390,20129396,20129393,20129397,20129395,20129396,20129397,20129392,20129397,20129398,20129393,20129395,20129398,20129395,20129398,20129399,20129395,20129397,20129399,20129396,20129397,20129397,20129398,20129400,20129397,20129399,20129400,20129400,20129400,20129401,20129401,20129401,20129401,20129402,20129402,20129402,20129403,20129403,20129404,20129405,20129405,20129406,20129406,20129407,20129408,20129410,20129410,20129411,20129411,20129412,20129412,20129413,20129413,20129414,20129415,20129415,20129416,20129416,20129417,20129417,20129418,20129418,20129419,20129422,20129422,20129423,20129423,20129424,20129424,20129427,20129429,20129430,20129431,20129432,20129433,20129433,20129434,20129434,20129435,20638960,20766780,20925590,20129405,20129406,20129406,20129408,20129409,20129409,20129410,20129410,20129411,20129411,20129412,20129413,20129414,20129415,20129416,20129417,20129417,20129418,20129418,20129419,20129419,20129423,20129423,20129424,20129425,20129427,20129431,20129433,20129433,20129434,20129434,20129435,20129435,20129407,20129408,20129409,20129410,20129410,20129411,20129412,20129412,20129413,20129414,20129416,20129417,20129418,20129418,20129419,20129421,20129423,20129433,20129434,20129434,20129435,20129436,20129418,20129419,20129419,20129436,20766780,20129426,20129437,20129417,20129426,20129437,20129420,20129421,20129427,20129427,20129437,20129438,20129418,20129422,20129439,20129417,20129418,20129417,20129422,20129424,20129419,20129421,20129421,20129423,20129440,20129422,20129423,20129430,20129441,20129422,20129424,20129429,20129429,20129430,20129431,20129441,20129442,20129424,20129425,20129431,20129436,20129438,20129421,20129442,20129443,20129435,20129422,20129424,20129424,20129425,20129427,20129432,20129438,20129444,20129424,20129425,20129426,20129426,20129427,20129425,20129426,20129427,20129429,20129429,20129430,20129434,20129440,20129442,20129445,20129446,20129428,20129429,20129430,20129434,20129444,20129446,20129429,20129446,20129447,20129429,20129430,20129431,20129436,20129445,20129447,20129447,20129430,20129431,20129436,20129442,20129446,20129447,20129448,20129431,20129432,20129436,20129443,20129444,20129446,20129446,20129447,20129448,20129448,20129432,20129433,20129437,20129437,20129438,20129439,20129443,20129445,20129446,20129447,20129447,20129448,20129448,20129449,20129437,20129438,20129445,20129447,20129449,20129449,20129434,20129438,20129450,20129438,20129450,20129451,20129453,20129443,20129450,20129451,20129452,20129453,20129442,20129443,20129443,20129454,20129443,20129444,20129446,20129451,20129453,20129453,20129454,20129454,20129444,20129454,20129455,20129445,20129446,20129447,20129452,20129453,20129454,20129455,20129455,20129446,20129455,20129455,20129456,20129453,20129455,20129456,20129457,20129455,20129456,20129458,20129458,20129458,20129460,20129460,20129461,20129460,20129461,20129460,20129461,20129462,20129462,20129463,20129461,20129462,20129463,20129463,20129462,20129463,20129463,20129464,20129464,20129464,20129464,20129465,20129465,20129466,20129486,20129488,20129504,20129534,20195257,20195258,20195258,20195260,20195261,20208648,20208688,20228000,20228001,20228002,20228003,20302056,20302057,20302058,20302074,20302075,20302081,20302279,20302291,20328315,20396384,20417712,20435251,20560370,20587301,20587302,20612498,20612499,20612499,20612501,20638986,20638988,20638988,20638989,20638989,20638990,20638991,20638991,20638992,20638992,20638993,20638993,20638994,20678028,20725426,20766808,20766808,20766809,20766809,20766810,20766810,20766811,20766811,20766812,20766813,20812539,20812539,20812540,20812541,20812543,20812545,20812546,20812547,20812547,20812548,20906320,20906320,20906323,20906324,20906325,20906327,20906327,20906328,20925621,20925621,20925653,21025298,21146728,21464004,21651000,22179611,22198006,20302075,20302075,20302279,20512329,20612498,20638986,20638989,20638990,20638992,20638992,20638993,20766809,20766810,20766811,20906326,20906331,20925622,20925654,20925642,20639013,20129617,20766878,20925735,20261064,20261065,20261065,20261067,20261068,20293810,20367881,20704798,20832617,20991428,20293811,20704795,20991428,20287841,20287881,20287922,20287921,20985551,20846044,20326536,20326548,20326549,20326552,20326551,20326554,20326553,20326554,20326554,20400622,20400629,20737539,20737535,20400624,20737539,21024171,20483898,20737542,20737540,20474665,20474665,20474685,20474686,20474688,20474688,20474689,20474690,20474683,20474706,20474708,20474708,20474709,20474707,20474707,20474708,20474709,20474709,20474716,20785129,20811621,20811621,20474910,20811623,20939442,20985170,20474732,20811623,21098253,20474733,20811624,20474733,20811624,20811625,20474734,20474913,20811624,20811625,20811625,21078904,21098255,20474913,20607886,20684963,20785134,20785136,20811621,20811621,20811622,20811623,20811623,20811624,20811625,20811626,20811627,20939443,20939443,20939444,20985174,20985181,21078953,21078954,21098256,20475114,20475126,20616758,20785331,20811826,20811826,20811827,20939643,20939644,20939645,20955532,21098456,20527175,20837852,20641240,20894886,20663358,20905962,20705968,20706152,20706335,21055250,20741049,20944789,20758412,21220821,20895204,20895208,21149685,21149689,20991286,21069909,21045154,21045155,21096843,21096844,21095548,21095550,21095544,21095551,21095550,21095552,21095550,21095552,21095552,21095554,21095554,21122037,21389379,21122041,21122042,21295597,21122043,21389238,21122043,21122044,21408673,21122044,21122044,21148510,21148510,21148512,21148512,21148525,21148513,21148513,21148528,21148528,21148514,21148515,21148528,21148529,21148514,21148529,21148514,21148515,21148525,21148527,21148528,21148529,21148515,21148516,21148529,21148530,21148516,21148516,21148518,21148531,21148517,21148518,21148518,21148519,21148520,21148527,21148528,21148530,21148530,21148531,21148532,21148532,21148518,21148519,21148519,21148520,21148520,21148532,21148532,21148533,21148533,21148534,21148534,21148535,21148519,21148520,21148520,21148522,21148533,21148534,21148534,21148535,21148535,21148536,21148520,21148521,21148521,21148522,21148532,21148533,21148534,21148535,21148535,21148521,21148522,21148534,21148534,21148535,21148535,21148536,21148522,21148534,21148536,21148535,21148536,21148538,21148537,21148536,21148538,21148542,21435157,21148543,21435159,21148545,21276349,21435160,21148545,21148546,21435161,21148546,21415861,21415866,21435161,21148547,21148548,21148548,21148549,21148549,21148550,21276348,21276348,21276349,21276349,21276350,21276350,21276351,21276351,21288969,21292237,21322080,21322080,21322082,21322083,21322084,21322087,21322087,21322088,21322089,21415727,21415805,21415858,21415860,21415860,21415862,21415863,21415865,21415865,21415866,21415868,21415869,21415870,21435161,21435162,21435194,21656268,21148548,21148549,21148549,21276349,21276349,21276351,21276351,21276352,21415862,21435162,21148549,21148550,21148551,21180646,21276350,21276351,21276351,21276352,21322081,21322082,21435163,21435210,21519767,21148550,21148551,21148551,21152288,21180645,21276352,21276352,21322081,21322081,21415792,21415864,21435163,21148551,21148552,21276351,21276351,21276352,21276352,21276353,21276353,21276354,21276354,21322082,21322082,21322083,21322084,21322085,21322089,21322089,21322090,21415797,21415872,21435164,21148552,21276352,21276353,21276354,21276355,21322082,21322082,21322088,21322089,21322090,21435164,21148554,21157340,21276352,21276353,21276353,21276354,21276354,21322082,21322083,21322084,21322086,21322087,21322089,21435165,21322090,21156039,21280103,21166142,21330892,21212758,21212759,21308465,21308465,21226608,21315390,21321402,21521597,21404164,21404152,21404152,21404165,21404165,21404166,21404151,21404152,21404152,21404153,21404166,21404166,21404167,21404167,21404168,21404168,21404169,21404152,21404153,21404153,21404154,21404167,21404168,21404170,21404153,21404154,21404168,21404169,21404170,21404171,21404154,21404155,21404156,21404156,21404167,21404168,21404169,21404170,21404171,21404171,21404155,21404156,21404156,21404157,21404165,21404168,21404169,21404170,21404171,21404171,21404172,21404172,21404173,21404156,21404157,21404157,21404158,21404169,21404171,21404172,21404172,21404172,21404173,21404158,21404170,21404171,21404173,21404173,21404174,21404171,21404172,21404173,21404173,21404174,21404174,21404174,21404175,21404176,21404182,21562978,21562978,21404184,21543544,21543592,21562979,21404183,21404185,21420055,21543680,21404183,21404184,21404185,21404185,21404186,21562980,21404186,21449905,21562980,21404186,21404186,21404187,21449899,21449905,21562981,21404187,21562981,21404187,21404188,21449901,21449907,21404188,21404189,21404190,21416789,21449900,21449901,21449901,21449904,21449907,21449908,21449908,21449909,21543615,21543623,21543632,21543677,21543682,21543686,21543688,21543689,21543692,21543693,21562982,21563014,21662659,21404189,21404190,21449900,21449901,21449901,21449902,21449903,21449903,21449906,21449908,21514895,21543614,21543688,21543694,21562983,21563015,21633918,21662662,21784089,21784142,21449901,21449902,21449903,21449904,21562983,21563015,21444685,21449901,21449902,21449902,21562984,21444667,21449909,21429410,21462523,21556299,21556310,21575603,21435943,21435944,21578867,21578868,21485158,21547302,21485195,21490413,21495612,21495613,21495616,21495616,21495617,21495618,21495619,21495620,21495627,21495629,21495634,21495613,21495614,21495614,21495615,21495618,21495619,21495620,21495621,21495628,21495628,21495629,21495629,21495630,21495630,21495631,21495632,21495633,21495634,21495615,21495615,21495617,21495618,21495619,21495620,21495620,21495621,21495628,21495629,21495629,21495630,21495630,21495631,21495631,21495632,21495633,21495633,21495634,21495636,21495616,21495621,21495633,21495618,21495619,21495622,21495623,21495630,21495631,21495631,21495634,21495635,21495637,21495637,21495631,21495632,21495632,21495637,21495619,21495623,21495638,21495621,21495623,21495638,21495637,21495638,21495639,21495640,21495622,21495634,21495639,21495640,21495624,21495635,21495626,21495633,21495634,21495640,21495640,21495633,21495641,21495626,21495638,21495641,21495634,21495636,21495638,21495642,21495642,21495627,21495635,21495639,21495642,21495629,21495637,21495639,21495640,21495641,21495642,21495643,21495643,21495644,21495638,21495639,21495644,21495644,21495644,21495645,21495644,21495646,21495645,21608741,21495644,21495647,21589421,21495645,21495646,21495648,21495651,22147093,21495650,21495652,21608711,21608743,21679646,21495652,21608711,21608743,21495649,21495649,21495650,21495651,21495652,21495652,21589415,21589416,21608712,21693316,21495648,21495650,21495651,21495653,21608712,21608744,21495650,21495651,21495653,21495654,21608713,21608767,21679648,21495652,21495654,21608713,21495654,21608714,21495655,21608714,21495656,21608715,21495656,21589344,21589417,21608715,21495656,21495657,21589279,21608716,21608775,21495657,21495658,21495659,21608717,21495658,21495659,21495659,21495661,21589282,21589346,21589351,21589353,21589362,21589415,21589416,21589421,21589422,21589423,21589424,21589427,21608717,21608717,21608752,21829824,21589359,21589416,21589418,21608718,21589419,21589421,21589422,21608718,21589351,21608719,21608721,21609453,21665626,21625640,21894834,21682920,21682982,21702356,21683069,21683084,21683087,21683087,21683088,21683089,21683051,21683094,21683099,21702417,21683101,21683102,21683103,21683109,21683107,21683109,21683152,21683140,21683162,21683164,21702455,21702456,21702457,21702458,21683153,21702459,21702459,21683167,21702461,21683170,21683191,21683176,21683193,21683184,21683197,21683198,21683188,21683191,21683192,21683193,21683185,21683191,21683195,21683176,21683194,21683182,21683192,21683196,21683197,21683199,21683197,21683196,21683196,21683196,21683198,21683204,21683206,21683186,21683199,21683205,21683206,21683206,21683186,21683198,21683199,21683187,21683188,21683200,21683200,21683201,21683202,21683203,21683204,21683205,21683206,21683207,21683205,21683207,21683190,21683205,21683203,21683203,21683208,21683209,21683204,21683207,21683208,21683209,21683203,21683206,21683209,21683210,21683209,21683210,21683207,21683210,21683212,21683211,21683210,21683205,21683213,21683206,21683213,21683214,21702490,21683212,21702493,21702494,21683221,21702494,21702495,21683215,21702495,21702495,21702496,21683221,21702496,22240879,21683223,21702497,21683221,21702497,21702498,21683225,21702498,21702557,21683221,21702499,21683226,21702499,21923606,21702500,21683227,21702501,21702502,21683229,21702502,21702503,21702535,21702503,21702535,21702504,21721776,21721777,21721778,21721778,21721779,21721779,21721780,21721787,21721787,21721788,21721797,21721806,21721806,21721807,21721807,21721808,21721808,21721809,21721825,21721851,21721852,21721787,21721808,21721809,21721809,21721809,21721810,21721810,21721810,21721810,21721811,21721811,21721797,21721818,21721818,21721819,21721798,21721810,21721818,21721819,21721822,21721832,21721836,21721846,21721884,21821464,21821464,21942915,22477950,21721820,21721820,21721829,21721832,21721837,21721838,21721837,21721839,21721839,21721840,21721840,21721841,21721842,21721842,21721843,21721843,21721844,21721844,21721845,21721845,21721846,21721846,21721847,21721847,21721848,21721848,21721849,21721849,21721850,21721851,21721851,21721852,21721853,21721854,21721855,21721855,21721856,21721857,21721857,21721858,21721858,21721859,21721859,21721860,21721860,21721861,21721861,21721862,21721862,21721863,21721865,21721867,21721867,21721868,21721870,21721871,21721873,21721877,21721877,21721881,21721883,21721883,21721884,21721842,21721843,21721843,21721844,21721845,21721845,21721846,21721847,21721850,21721850,21721851,21721852,21721852,21721853,21721854,21721855,21721857,21721858,21721859,21721859,21721860,21721860,21721861,21721861,21721862,21721863,21721865,21721866,21721883,21721884,21721885,21721843,21721844,21721844,21721846,21721848,21721860,21721863,21721868,21721884,21721844,21721845,21721846,21721846,21721847,21721847,21721849,21721850,21721851,21721856,21721858,21721859,21721860,21721861,21721862,21721863,21721864,21721869,21721885,21721886,21721845,21721846,21721846,21721849,21721852,21721859,21721859,21721860,21721863,21721866,21721885,21721846,21721847,21721847,21721848,21721848,21721849,21721849,21721851,21721852,21721853,21721853,21721860,21721860,21721861,21721861,21721862,21721863,21721866,21721866,21721867,21721867,21721870,21721887,21721848,21721861,21721862,21721864,21721871,21721887,21721848,21721849,21721850,21721851,21721854,21721857,21721861,21721862,21721863,21721865,21721849,21721850,21721854,21721855,21721859,21721859,21721861,21721862,21721863,21721864,21721866,21721868,21721868,21721872,21721887,21721850,21721851,21721856,21721863,21721863,21721864,21721865,21721888,21721851,21721852,21721853,21721856,21721862,21721863,21721866,21721873,21721888,21721853,21721855,21721856,21721863,21721864,21721865,21721865,21721877,21721882,21721888,21721854,21721857,21721869,21721889,21721856,21721862,21721863,21721864,21721865,21721868,21721855,21721860,21721864,21721866,21721863,21721865,21721866,21721867,21721891,21721866,21721860,21721867,21721872,21721892,21721860,21721864,21721866,21721866,21721867,21721868,21721882,21721888,21721867,21721867,21721867,21721868,21721868,21721869,21721870,21721884,21721894,21721866,21721877,21721878,21721867,21721868,21721870,21721869,21721870,21721871,21721895,21721869,21721872,21721872,21721875,21721885,21721871,21721872,21721872,21721871,21721871,21721872,21721873,21721871,21721874,21721874,21721876,21721899,21721873,21721874,21721875,21721876,21721878,21721879,21721881,21721883,21721899,21721874,21721875,21721875,21721876,21721877,21721878,21721879,21721880,21721880,21721881,21721882,21721883,21721884,21721893,21721899,21721900,21721875,21721876,21721877,21721879,21721884,21721876,21721877,21721877,21721878,21721878,21721879,21721879,21721880,21721881,21721881,21721882,21721883,21721883,21721884,21721885,21721885,21721890,21721893,21721894,21721900,21721901,21721877,21721878,21721879,21721879,21721880,21721880,21721881,21721882,21721882,21721883,21721885,21721885,21721886,21721889,21721895,21721896,21721901,21721901,21721902,21721878,21721879,21721879,21721880,21721881,21721881,21721882,21721883,21721883,21721885,21721886,21721886,21721890,21721891,21721891,21721892,21721892,21721895,21721901,21721902,21721879,21721880,21721880,21721881,21721882,21721884,21721886,21721887,21721892,21721902,21721880,21721881,21721881,21721882,21721883,21721883,21721884,21721884,21721886,21721887,21721887,21721893,21721899,21721902,21721903,21721881,21721882,21721882,21721883,21721884,21721885,21721886,21721887,21721887,21721894,21721900,21721903,21721882,21721883,21721884,21721884,21721885,21721885,21721886,21721887,21721888,21721894,21721902,21721903,21721904,21721904,21721905,21721883,21721884,21721885,21721886,21721886,21721888,21721888,21721890,21721901,21721902,21721904,21721885,21721885,21721886,21721886,21721887,21721888,21721889,21721889,21721892,21721894,21721904,21721904,21721905,21721906,21721887,21721886,21721887,21721887,21721888,21721889,21721890,21721890,21721903,21721905,21721906,21721907,21942938,21721887,21721888,21721888,21721890,21721890,21721891,21721893,21721906,21721889,21721889,21721890,21721891,21721891,21721893,21721906,21721907,21821509,21721889,21721891,21721891,21721892,21721894,21721897,21721898,21721900,21721901,21721907,21721890,21721891,21721892,21721905,21721908,21721891,21721892,21721893,21721892,21721893,21721893,21721894,21721896,21721896,21721897,21721897,21721900,21721902,21721908,21721909,21721909,21721910,21942941,21721894,21721895,21721895,21721896,21721897,21721897,21721898,21721900,21721900,21721901,21721902,21721903,21721905,21721905,21721906,21721907,21721908,21721909,21721910,21721910,21721911,21721895,21721897,21721898,21721900,21721901,21721901,21721902,21721903,21721905,21721906,21721906,21721907,21721907,21721908,21721910,21721910,21721911,21721896,21721911,21721904,21721911,21721905,21721912,21721912,21721900,21721902,21721903,21721905,21721907,21721912,21721913,21721913,21721913,21721912,21721913,21721914,21721908,21721913,21721914,21721914,21721905,21721911,21721915,21721909,21721915,21721915,21721916,21721910,21721916,21721916,21721909,21721917,21721918,21721912,21721914,21721913,21721918,21721918,21721915,21721918,21721916,21721919,21721919,21721920,21792780,21721918,21721920,21721920,21721921,21721917,21721921,21721921,21721921,21721922,21721922,21721922,21721921,21721922,21721923,21721922,21721923,21721924,21721922,21721923,21721924,21721924,21721924,21721925,21721924,21721925,21721925,21721926,21721927,21721928,21721929,21721929,21721930,21721930,21721933,21721947,21721948,21721948,21721951,21721952,21721954,21721956,21721958,21721958,21721959,21792787,21821528,21821528,21821529,21942958,21942979,21943011,22260234,22478014,21721927,21721928,21721929,21721929,21721930,21721930,21721931,21721932,21721933,21721934,21721936,21721936,21721937,21721938,21721942,21721943,21721944,21721947,21721948,21721949,21721952,21721952,21721953,21721953,21721954,21721956,21721957,21721957,21721958,21721958,21721959,21721959,21806456,21721928,21721929,21721930,21721931,21721931,21721939,21721941,21721942,21721943,21721945,21721948,21721948,21721949,21721952,21721953,21721954,21721954,21721955,21721956,21721956,21721957,21721958,21721959,21721959,21721960,21792788,21821527,21821529,21942959,22260235,22478028,21721931,21721932,21721938,21721942,21721951,21721959,21721960,21806457,21942959,21721930,21721961,21721947,21721961,21721933,21721950,21721958,21721934,21721945,21721961,21721947,21721951,21721956,21721963,21721949,21721951,21721955,21721961,21721962,21721963,21721963,21792790,21942984,21721945,21721950,21721966,21721967,21721966,21721968,21721957,21721969,21721970,21721971,21721965,21721973,21721974,21721974,21721961,21721975,21721963,21721975,21721976,21721970,21721974,21721977,21721965,21721972,21721978,21721972,21721969,21721974,21721975,21721978,21721979,21721979,21721980,21721974,21721980,21721970,21721981,21721980,21721981,21721981,21721983,21721984,21721977,21721980,21721984,21721978,21721981,21721982,21721984,21721985,21721981,21721981,21721983,21721984,21721985,21721985,21943006,21721985,21721985,21721986,21721982,21721986,21721986,21721986,21721986,21721987,21721987,21721988,21721988,21721988,21721987,21721988,21721989,21721990,21721990,21721990,21721990,21721991,21721991,21721992,21729048,21792819,21792820,21792826,21806489,21806489,21806490,21809391,21809392,21809392,21809393,21809394,21809395,21809395,21809396,21809397,21821560,21821560,21821561,21821561,21821562,21821562,21821565,21882370,21924548,21924550,21942989,21942990,21942991,21943012,21943012,21943040,21943043,22143485,22260267,22260304,22478046,22478060,22478061,22975874,22994269,21792820,21809394,21821561,21924549,21942991,21736114,21736181,21736248,21950124,21863647,21863648,21863650,21863651,21863656,21863668,21863669,21863670,21863671,21863675,21863652,21863653,21863656,21863671,21863672,21863672,21863672,21863677,21863677,21863687,21863688,21863689,21863689,21863690,21863691,21863692,21863744,21863745,21863742,21863693,21863696,21863697,21863746,21863695,21863697,21863747,21863747,21863747,21863745,21863745,21863750,21863751,21863795,21863795,21863797,21863798,21863799,21863800,21863801,21863804,21863813,21863803,21863813,21863803,21863815,21863807,21863817,21863825,21863829,21863830,21863831,21877403,21877406,21877406,21880310,21892477,21892478,22013908,22013929,22013959,22331184,22013911,22013912,21863838,22013913,21892479,21890995,21891000,21891000,21891000,21891001,21891001,21891002,21891002,21891003,21891005,21891001,21891002,21891002,21891001,22027500,21893904,21906072,21893905,21906075,21891016,21893903,21893905,21893906,21906073,21906075,22027503,21893906,21906073,21906074,22027503,21893906,22027504,22344781,22344782,22531780,21896808,21896809,21896816,21896808,21896795,21896796,21896797,21896810,21896810,21896811,21896811,21896813,21896814,21896815,21896815,21896817,21896802,21896804,21896811,21896811,21896812,21896812,21896816,21896814,21896813,21896818,21896813,21896816,21896818,21896821,21896822,22030406,22030407,21908978,22030408,21896829,21896829,21908978,22030407,22030408,22030466,21908979,22030409,22030430,22347685,21908980,22030409,21896834,22030410,22030411,21896836,21908980,22030411,22030412,22030413,22030414,22030414,21908985,22030415,21921140,21921128,21921129,21921129,21921143,21921129,21921144,21921130,21921131,21921132,21921142,21921142,21921143,21921144,21921145,21921145,21921133,21921134,21921143,21921143,21921144,21921144,21921145,21921146,21921144,21921146,21921147,21921148,21921147,21921149,21921150,21921149,21921148,21921151,22042598,22359885,21921157,22042572,22042573,21921158,22042573,22042596,21921159,21921159,22042574,22042595,22359850,21921160,21921161,21921161,21921162,21937154,21997436,22037896,22042573,22042574,22042575,22042596,22042624,22042628,22042632,22249794,22359850,22359851,22042575,22042597,22042576,22359889,21921164,22042576,22359853,22042577,22042599,21953164,22058584,22042760,22103381,22073786,22118925,22127180,22127110,22127184,22127258,22127283,22145625,22127385,22145725,22154705,22154782,22154860,22159462,22163988,22163989,22163990,22163991,22163991,22163992,22163992,22163996,22164001,22164008,22164009,22164010,22164010,22164011,22164011,22164065,22163992,22163993,22164011,22164011,22164012,22163997,22164012,22164012,22164013,22164013,22164013,22164012,22164013,22164017,22164017,22481276,22164030,22164030,22164031,22164030,22164031,22164032,22164060,22164032,22164033,22164034,22164037,22164053,22164060,22164064,22164065,22164066,22164087,22164033,22164034,22164034,22164037,22164038,22164038,22164040,22164041,22164043,22164044,22164044,22164045,22164048,22164049,22164050,22164051,22164051,22164053,22164054,22164054,22164055,22164055,22164056,22164056,22164057,22164058,22164059,22164059,22164060,22164060,22164061,22164061,22164063,22164063,22164064,22164064,22164065,22164066,22164066,22164067,22164068,22164069,22164069,22164070,22164079,22164080,22164086,22164087,22164035,22164043,22164045,22164052,22164054,22164056,22164058,22164059,22164059,22164060,22164060,22164061,22164063,22164065,22164066,22164068,22164070,22164087,22164087,22164041,22164044,22164060,22164060,22164067,22164061,22164109,22164058,22164091,22164049,22164058,22164059,22164063,22164064,22164065,22164070,22164071,22164092,22164064,22164064,22164066,22164070,22164050,22164064,22164064,22164064,22164066,22164069,22164058,22164060,22164068,22164069,22164070,22164080,22164071,22164071,22164072,22164086,22164090,22164098,22164070,22164102,22164069,22164074,22164083,22164075,22164076,22164076,22164103,22164097,22164077,22164079,22164079,22164079,22164080,22164081,22164085,22164085,22164107,22481308,22164077,22164080,22164086,22164087,22164088,22164082,22164080,22164087,22164088,22164083,22164086,22164081,22164082,22164084,22164086,22164087,22164088,22164089,22164089,22164091,22164099,22164100,22164102,22164102,22164110,22164092,22164082,22164085,22164087,22164083,22164084,22164084,22164085,22164085,22164086,22164086,22164088,22164088,22164089,22164090,22164090,22164092,22164094,22164112,22164113,22481350,22164085,22164087,22164089,22164090,22164091,22164113,22164086,22164087,22164088,22164088,22164089,22164091,22164091,22164092,22164093,22164095,22164101,22164105,22164106,22164106,22164113,22164113,22164088,22164090,22164095,22164114,22164088,22164092,22164089,22164090,22164090,22164091,22164091,22164092,22164092,22164093,22164093,22164094,22164094,22164095,22164095,22164096,22164097,22164099,22164101,22164104,22164104,22164106,22164106,22164107,22164107,22164108,22164110,22164114,22164114,22164115,22164091,22164093,22164093,22164115,22164115,22164094,22164116,22164094,22164095,22164094,22164094,22164095,22164096,22164096,22164097,22164100,22164100,22164106,22164107,22164112,22164116,22164117,22164095,22164095,22164117,22164095,22164096,22164097,22164108,22164117,22164118,22164096,22164097,22164098,22164098,22164101,22164104,22164107,22164109,22164112,22164113,22164116,22164118,22164097,22164098,22164098,22164099,22164100,22164101,22164101,22164102,22164103,22164104,22164107,22164108,22164109,22164110,22164111,22164111,22164113,22164117,22164118,22164118,22164119,22164119,22164099,22164111,22164119,22164099,22164100,22164108,22164109,22164110,22164112,22164116,22164119,22164120,22164120,22164100,22164101,22164102,22164104,22164110,22164117,22164118,22164118,22164120,22164120,22164121,22164102,22164103,22164110,22164113,22164116,22164121,22164103,22164117,22164121,22164121,22164105,22164113,22164120,22164122,22164122,22164123,22164108,22164115,22164122,22164123,22164123,22164114,22164124,22164124,22164125,22164125,22164126,22164126,22164127,22164128,22164122,22164129,22164125,22164129,22164129,22164123,22164130,22164130,22164131,22164131,22164130,22164131,22164132,22164132,22164132,22164132,22164133,22481333,22164133,22164133,22164134,22164134,22164135,22164132,22164136,22164136,22164137,22164137,22164138,22164138,22164138,22164139,22164139,22164139,22164140,22164140,22164141,22164142,22164146,22164147,22164148,22164151,22164151,22164157,22164159,22164160,22164160,22164161,22164161,22164162,22164162,22481342,22481379,22481379,22668337,22699121,22699134,22699135,22699137,22816255,23196948,22164142,22164143,22164144,22164147,22164148,22164149,22164149,22164152,22164157,22164159,22164160,22164161,22164161,22164162,22164162,22164163,22481342,22164143,22164145,22164161,22164162,22164163,22164163,22164163,22164164,22164163,22164165,22164163,22164167,22164168,22481384,22164168,22164169,22164159,22164169,22164170,22164170,22164172,22164172,22164173,22164178,22164177,22164179,22164180,22481360,22164179,22164181,22481398,22164181,22164181,22164182,22164182,22164182,22164182,22164183,22164183,22481363,22164184,22164185,22285464,22285471,22324523,22364600,22371306,22371308,22373140,22427910,22460062,22477837,22477838,22481362,22481363,22481363,22481400,22481401,22481416,22699152,22699155,22816183,22816210,23196997,23278646,22481364,22481365,22406816,22406823,22406889,22406947,22602773,22484926,22641767,22564990,22565010,22565043,22565044,22681806,22899585,22578440,22578440,22578441,22578441,22578448,22688497,22670056,22688498,22688535,22688498,22688499,22688503,22582109,22690332,22691711,22745165,22756006,22777307,22761676,22761721,22761753,22780149,22791506,22791507,22795032,22798541,22798542,22798542,22798543,22798544,22798544,22798545,22798545,22798546,22798550,22798554,22798564,22798566,22798567,22798567,22798568,22798569,22798573,22798573,22798576,22798578,22798579,22798579,22798580,22798565,22798570,22798580,22798580,22798546,22798570,22798580,22798547,22798581,22798571,22798572,22798582,22798582,22798583,22798577,22798591,22798654,22798590,22798601,22798603,22798604,22798603,22798605,22798597,22798600,22798605,22798606,22798606,22798607,22798610,22798610,22798610,22798612,22798613,22798615,22798615,22798615,22798616,22798616,22798617,22798618,22798618,22798619,22798619,22798620,22798621,22798621,22798622,22798622,22798623,22798624,22798624,22798625,22798626,22798627,22798627,22798628,22798628,22798629,22798629,22798630,22798631,22798632,22798632,22798633,22798633,22798634,22798634,22798635,22798636,22798637,22798638,22798638,22798639,22798639,22798640,22798640,22798642,22798642,22798643,22798645,22798649,22798653,22798654,22798655,22798655,22798618,22798619,22798619,22798623,22798624,22798627,22798628,22798630,22798630,22798632,22798632,22798633,22798633,22798638,22798639,22798644,22798645,22798651,22798653,22798655,22798656,22798621,22798626,22798628,22798629,22798632,22798633,22798620,22798621,22798623,22798624,22798629,22798631,22798631,22798633,22798634,22798634,22798656,22798626,22798627,22798629,22798631,22798633,22798635,22798640,22798634,22798640,22798658,22798627,22798631,22798654,22798633,22798637,22798632,22798632,22798636,22798637,22798638,22798643,22798660,22798630,22798633,22798637,22798631,22798633,22798634,22798643,22798637,22798639,22798640,22798640,22798663,22798637,22798641,22798664,22798638,22798639,22798639,22798641,22798642,22798643,22798648,22798640,22798643,22798640,22798641,22798642,22798642,22798643,22798644,22798649,22798654,22798656,22798656,22798657,22798661,22798666,22798644,22798652,22798666,22798642,22798644,22798645,22798645,22798646,22798648,22798649,22798649,22798650,22798651,22798651,22798653,22798653,22798655,22798656,22798665,22798666,22798667,22798667,22798668,22798705,22798644,22798645,22798646,22798647,22798651,22798652,22798656,22798656,22798668,22798668,22798647,22798646,22798647,22798647,22798649,22798649,22798652,22798652,22798653,22798655,22798657,22798658,22798670,22798647,22798648,22798653,22798657,22798667,22798670,22798648,22798649,22798649,22798650,22798650,22798651,22798652,22798652,22798653,22798654,22798654,22798655,22798655,22798656,22798656,22798657,22798657,22798658,22798659,22798660,22798665,22798666,22798667,22798667,22798668,22798669,22798670,22798671,22798649,22798650,22798650,22798651,22798651,22798652,22798652,22798653,22798653,22798654,22798654,22798655,22798655,22798656,22798656,22798657,22798658,22798659,22798659,22798661,22798662,22798664,22798666,22798666,22798667,22798667,22798669,22798669,22798670,22798670,22798671,22798671,22798672,22798653,22798661,22798671,22798672,22798654,22798655,22798655,22798672,22798672,22798654,22798657,22798657,22798658,22798659,22798660,22798666,22798668,22798673,22798657,22798661,22798673,22798655,22798656,22798659,22798673,22798674,22798656,22798658,22798662,22798674,22798656,22798657,22798657,22798658,22798675,22798657,22798658,22798658,22798659,22798660,22798663,22798663,22798665,22798670,22798673,22798675,22798675,22798658,22798659,22798663,22798675,22798676,22798659,22798660,22798660,22798661,22798661,22798664,22798664,22798665,22798666,22798670,22798671,22798675,22798676,22798676,22798660,22798661,22798662,22798664,22798665,22798666,22798667,22798673,22798675,22798677,22798661,22798662,22798662,22798663,22798663,22798665,22798665,22798666,22798667,22798667,22798672,22798672,22798675,22798677,22798662,22798663,22798665,22798666,22798678,22798666,22798667,22798668,22798675,22798678,22798666,22798666,22798672,22798672,22798673,22798677,22798678,22798679,22798667,22798668,22798669,22798679,22798667,22798669,22798668,22798678,22798680,22798668,22798681,22798669,22798670,22798671,22798671,22798672,22798673,22798674,22798675,22798680,22798680,22798681,22798681,22798670,22798671,22798672,22798673,22798676,22798680,22798681,22798681,22798682,22798672,22798676,22798679,22798681,22798682,22798682,22798673,22798677,22798680,22798681,22798682,22798683,22798683,22798683,22798684,22798675,22798684,22798685,22798686,22798686,22798686,22798687,22798681,22798686,22798687,22798688,22798683,22798688,22798686,22798687,22798688,22798689,22798688,22798688,22798689,22798690,22798690,22798690,22798689,22798691,22798690,22798691,22798691,23016395,22798692,22798691,22798692,22798692,22798692,22798693,22798693,23514224,22798694,22798695,22798696,22798697,22798698,22798699,22798699,22798700,22798701,22798703,22798704,22798704,22798706,22798713,22798715,22798717,22798719,22798720,22798721,22798724,22798725,22798726,22798726,22798727,22798728,22798728,22798729,22798729,22798730,22798730,22798731,22842139,22985614,22985615,23016395,23016397,23016397,23016398,23016404,23016408,23016410,23016410,23016417,23041788,23133493,23133531,23514225,22798695,22798696,22798697,22798697,22798698,22798698,22798700,22798701,22798701,22798702,22798702,22798705,22798706,22798710,22798714,22798716,22798719,22798721,22798724,22798725,22798726,22798726,22798727,22798727,22798728,22798728,22798729,22798729,22798730,22798730,22798731,22798731,23016398,22798704,22798732,22798728,22798730,22798732,22798733,22798725,22798701,22798705,22798719,22798730,22798734,22798701,22798718,22798731,22798705,22798731,22798735,22798736,23133472,22798736,22798722,22798734,22798711,22798720,22798723,22798738,22798724,22798735,22798737,22798738,22798739,22798719,22798740,22798724,22798731,22798725,22798741,22798735,22798743,22798747,23041803,22798750,22798745,22798747,22798747,22798749,22798751,22798749,22798752,22798751,22798752,22798752,22798741,22798751,22798753,22798753,22798754,22798748,22798753,22798756,22798753,22798756,22798755,22798757,22798748,22798757,22798758,22798758,22798759,22798755,22798755,22798759,22798761,22798758,22798761,22798762,22798763,22798763,22798764,22798761,22798762,22798764,22798763,22798764,22798765,22798764,22798765,22798765,22798765,22798766,22798765,22798766,22798767,22798767,22798768,22819792,22819793,22819795,22819804,22819883,22819909,22819911,22819911,22819913,22842176,22842177,22843968,22855405,22903372,22926180,22927297,22936811,22956601,22956602,22956602,22956603,22985639,22985640,22985643,22985646,22985647,22985650,22985651,22985652,22985652,22992680,23016430,23016431,23016431,23016432,23016432,23016433,23016433,23016434,23016434,23016435,23016436,23016437,23016437,23016438,23016438,23016439,23016440,23016441,23016441,23016442,23016442,23016443,23016443,23016444,23016444,23016445,23016445,23016446,23016446,23016447,23016447,23016448,23016448,23016449,23016449,23016450,23016451,23041823,23041823,23041824,23041824,23041825,23042569,23042582,23133475,23133502,23514262,23595938,22819913,22842177,22985652,23016431,23016435,23016442,23016448,23041824,22840825,22840827,22840828,22840831,22840832,22840948,22840949,22840949,22840950,22840851,22840950,22840951,22840952,22840952,22840952,22840961,22841008,22841040,22841067,22841069,22841070,22841069,22841071,22841069,22841070,22841071,22841073,22841073,22841073,22841073,22841074,23037593,23006808,23037591,23037604,23154631,23037592,22863336,23037605,23037606,23037591,23037592,23037592,23037593,23037593,23037604,23037605,23154633,22885599,22885600,22885603,22885605,22885603,23059857,23058798,23059858,23059860,23059869,23059870,23176900,23059861,23059869,22889236,23061714,22912073,23073099,23007987,23121061,23053634,23053695,23053790,23143996,23055878,23055949,23056025,23145098,23074863,23074933,23074996,23154547,23114450,23114452,23114457,23114454,23114459,23174279,23174285,23174286,23291330,23174291,23172523,23172513,23172524,23172521,23172524,23172528,23172526,23172531,23172529,23172531,23172533,23172535,23172536,23172546,23172555,23172537,23172548,23172554,23172556,23172558,23172557,23172539,23172555,23172557,23172556,23172558,23172567,23172568,23172574,23172574,23172576,23172578,23202279,23203334,23203337,23203338,23203338,23203339,23203339,23203347,23203348,23203348,23203350,23203350,23203351,23203351,23203356,23228728,23228729,23228730,23320379,23701166,23701194,23203340,23320381,23186607,23236494,23231993,23233050,23233053,23233053,23234096,23234096,23234097,23234105,23234106,23234108,23234096,23234097,23234098,23234112,23234097,23234098,23234098,23234099,23234110,23234115,23234116,23234099,23234099,23234111,23234111,23234112,23234116,23234100,23234109,23234111,23234112,23234116,23234117,23234100,23234100,23234107,23234110,23234111,23234112,23234112,23234114,23234118,23234119,23234100,23234101,23234106,23234109,23234110,23234111,23234112,23234112,23234113,23234114,23234115,23234115,23234117,23234101,23234102,23234102,23234105,23234105,23234106,23234107,23234108,23234110,23234110,23234111,23234111,23234112,23234112,23234113,23234113,23234114,23234114,23234115,23234116,23234116,23234117,23234117,23234118,23234120,23234102,23234104,23234105,23234106,23234106,23234107,23234107,23234108,23234109,23234110,23234110,23234111,23234111,23234112,23234112,23234113,23234113,23234114,23234114,23234115,23234115,23234116,23234116,23234117,23234117,23234118,23234118,23234119,23234119,23234120,23234121,23234122,23234122,23234123,23234128,23234133,23234106,23234109,23234111,23234113,23234114,23234113,23234116,23234109,23234116,23234114,23234113,23234113,23234114,23234115,23234134,23234112,23234113,23234115,23234120,23234136,23234116,23234118,23234119,23234124,23234118,23234119,23234124,23234115,23234121,23234136,23234118,23234119,23234126,23234117,23234118,23234117,23234119,23234119,23234120,23234116,23234117,23234118,23234118,23234119,23234119,23234121,23234126,23234139,23234141,23234117,23234119,23234119,23234120,23234122,23234119,23234119,23234120,23234120,23234121,23234121,23234122,23234123,23234125,23234126,23234127,23234119,23234120,23234120,23234121,23234121,23234122,23234122,23234123,23234142,23234120,23234121,23234121,23234122,23234122,23234125,23234129,23234130,23234132,23234141,23234141,23234121,23234122,23234122,23234123,23234123,23234124,23234125,23234127,23234128,23234131,23234122,23234123,23234123,23234124,23234124,23234126,23234127,23234127,23234129,23234132,23234142,23234123,23234124,23234124,23234125,23234126,23234127,23234130,23234133,23234143,23234124,23234125,23234125,23234126,23234126,23234127,23234128,23234129,23234129,23234141,23234144,23234125,23234126,23234126,23234127,23234128,23234128,23234130,23234143,23234144,23234145,23234126,23234127,23234127,23234128,23234128,23234129,23234130,23234132,23234144,23234144,23234145,23234127,23234128,23234128,23234129,23234129,23234130,23234130,23234131,23234132,23234133,23234137,23234144,23234145,23234146,23234128,23234129,23234129,23234130,23234130,23234131,23234131,23234133,23234133,23234145,23234145,23234146,23234129,23234130,23234130,23234131,23234132,23234145,23234146,23234147,23259504,23234130,23234131,23234131,23234132,23234132,23234133,23234135,23234146,23234146,23234147,23260227,23351156,23234131,23234132,23234132,23234133,23234133,23234135,23234135,23234136,23234137,23234140,23234146,23234147,23234148,23259505,23351156,23234132,23234133,23234133,23234134,23234134,23234135,23234136,23234137,23234139,23234142,23234146,23234147,23234147,23234148,23259505,23351157,23234133,23234134,23234134,23234135,23234135,23234136,23234136,23234137,23234137,23234138,23234139,23234140,23234145,23234147,23234148,23234149,23259506,23260253,23351157,23533137,23750340,23234134,23234135,23234135,23234136,23234137,23234138,23234147,23234148,23234148,23234149,23259506,23351158,23234135,23234136,23234136,23234137,23234138,23234139,23234139,23234140,23234141,23234143,23234147,23234148,23234148,23234149,23234150,23234150,23260266,23351158,23234137,23234138,23234139,23234141,23234149,23234149,23234150,23259507,23263650,23351159,23731946,23234138,23234139,23234142,23234149,23234150,23260260,23260267,23300416,23351159,23731946,23234138,23234139,23234140,23234146,23234150,23234150,23260267,23234139,23234140,23234141,23234142,23234150,23234150,23234151,23234152,23351160,23351214,23731947,23234140,23234141,23234151,23234151,23234152,23351161,23234141,23234142,23234151,23234152,23234153,23351161,23234142,23234143,23234145,23234152,23234153,23259510,23351162,23234143,23234145,23234152,23234153,23234154,23351162,23234145,23234146,23234153,23234153,23234154,23260270,23351163,23351163,23234147,23234154,23351164,23234154,23234155,23234156,23259513,23351164,23234154,23259513,23351165,23351165,23351166,23234156,23234157,23351168,23234159,23351169,23234160,23234161,23234162,23351171,23234162,23234163,23234163,23259520,23260279,23351171,23351172,23351265,23234163,23234164,23234164,23259521,23259522,23259523,23260280,23351172,23351223,23351226,23492547,23731959,23731987,23234164,23351173,23234165,23259522,23259523,23259523,23259524,23259524,23259525,23259525,23260245,23260274,23260276,23260281,23351173,23351201,23351201,23351202,23351203,23351231,23351233,23351267,23533145,23731960,23731988,23732011,23750356,23808888,23259522,23260281,23285762,23351174,23284893,23284880,23284880,23284892,23284893,23284893,23284894,23284894,23284895,23284895,23284881,23284882,23284883,23284895,23284896,23284895,23284895,23284896,23284896,23284897,23284895,23284896,23284897,23284897,23284896,23284897,23284898,23284907,23757358,23284908,23285652,23757359,23284909,23325451,23376545,23757393,23284909,23284910,23284911,23285617,23285648,23285652,23285653,23376545,23376575,23757332,23284910,23285647,23285649,23285653,23376482,23376546,23376573,23376595,23376639,23757333,23284911,23285649,23285652,23285652,23376546,23376604,23574926,23376547,23757361,23376641,23286336,23286341,23286341,23377265,23377269,23758056,23377269,23286394,23286396,23286390,23286401,23286390,23286407,23286403,23286408,23286409,23286411,23286405,23286409,23286410,23286411,23286412,23286414,23286415,23377295,23286417,23377300,23758088,23377302,23377302,23377303,23377304,23326211,23377304,23377304,23776489,23377307,23293181,23761505,23337413,23402825,23366010,23366012,23417103,23417105,23366711,23417454,23468118,23468181,23468182,23468183,23468183,23468184,23468184,23468185,23468185,23468187,23468192,23468194,23468195,23468208,23468209,23468209,23468210,23468210,23468211,23468183,23468209,23468209,23468210,23468210,23468211,23468209,23468210,23468210,23468211,23468211,23468212,23468212,23468213,23468212,23468215,23468203,23468219,23468243,23468285,23468286,23468222,23468224,23468235,23468236,23468236,23468237,23468256,23468257,23468237,23468238,23468238,23468239,23468247,23468251,23468256,23468256,23468258,23468259,23468260,23468260,23468261,23468261,23468262,23468267,23468284,23468285,23468238,23468239,23468242,23468259,23468260,23468260,23468262,23468285,23468285,23468239,23468240,23468251,23468257,23468257,23468259,23468259,23468260,23468262,23468264,23468266,23468267,23468268,23468281,23468286,23468240,23468241,23468241,23468245,23468254,23468256,23468257,23468257,23468258,23468260,23468261,23468261,23468262,23468262,23468263,23468264,23468264,23468265,23468266,23468267,23468282,23468286,23468286,23468241,23468242,23468243,23468243,23468245,23468246,23468247,23468250,23468254,23468258,23468259,23468259,23468260,23468260,23468261,23468262,23468262,23468263,23468263,23468264,23468264,23468265,23468265,23468267,23468269,23468269,23468270,23468272,23468281,23468284,23468286,23468287,23468242,23468243,23468243,23468244,23468244,23468246,23468246,23468251,23468252,23468253,23468255,23468255,23468256,23468257,23468258,23468259,23468260,23468260,23468261,23468262,23468262,23468263,23468264,23468265,23468266,23468266,23468268,23468270,23468274,23468276,23468280,23468282,23468285,23468287,23468287,23468246,23468247,23468251,23468255,23468260,23468261,23468262,23468263,23468264,23468266,23468271,23468288,23468264,23468288,23468260,23468262,23468264,23468248,23468289,23468249,23468290,23468256,23468266,23468267,23468288,23468291,23468259,23468265,23468266,23468267,23468268,23468269,23468274,23468280,23468291,23468268,23468267,23468261,23468267,23468270,23468287,23468269,23468270,23468272,23468272,23468275,23468270,23468273,23468275,23468275,23468276,23468277,23468275,23468281,23468297,23468302,23468278,23468280,23468282,23468277,23468279,23468280,23468287,23468278,23468279,23468283,23468284,23468287,23468287,23468304,23468278,23468280,23468305,23468278,23468280,23468284,23468287,23468289,23468279,23468282,23468282,23468284,23468301,23468306,23468281,23468281,23468282,23468283,23468283,23468284,23468284,23468285,23468286,23468287,23468288,23468289,23468289,23468292,23468294,23468302,23468303,23468306,23468282,23468283,23468283,23468284,23468284,23468285,23468286,23468286,23468287,23468287,23468288,23468298,23468299,23468302,23468303,23468307,23468307,23468283,23468284,23468284,23468285,23468285,23468286,23468286,23468287,23468288,23468288,23468290,23468290,23468294,23468295,23468302,23468307,23468308,23468284,23468285,23468286,23468286,23468287,23468288,23468289,23468290,23468292,23468295,23468297,23468302,23468305,23468308,23468308,23468285,23468286,23468287,23468288,23468288,23468289,23468291,23468292,23468296,23468300,23468304,23468305,23468306,23468309,23468286,23468287,23468287,23468288,23468289,23468290,23468291,23468298,23468302,23468309,23468287,23468288,23468290,23468292,23468301,23468307,23468309,23468310,23468289,23468290,23468290,23468291,23468291,23468297,23468298,23468306,23468310,23468289,23468293,23468294,23468309,23468311,23468291,23468292,23468294,23468298,23468302,23468304,23468305,23468306,23468311,23468311,23468309,23468312,23468292,23468293,23468295,23468295,23468309,23468310,23468312,23468312,23468293,23468295,23468295,23468302,23468308,23468310,23468311,23468313,23468296,23468297,23468313,23468313,23468314,23468314,23468306,23468307,23468312,23468314,23468315,23468307,23468310,23468311,23468313,23468315,23468307,23468310,23468314,23468315,23468316,23468316,23468317,23468318,23468319,23468319,23468309,23468319,23468316,23468320,23468321,23468321,23468322,23468323,23468315,23468316,23468317,23468318,23468324,23468318,23468320,23468324,23468319,23468321,23468325,23468326,23468322,23468325,23468326,23468326,23468327,23468327,23468328,23468328,23468349,23468326,23468329,23468327,23468328,23468329,23468330,23507771,23468330,23468330,23468348,23468330,23468331,23849070,23468331,23468331,23468332,23468332,23468333,23468334,23468334,23468336,23468336,23468337,23468342,23468344,23468347,23468351,23468354,23468355,23468358,23468358,23468359,23468359,23468360,23468360,23849044,23849072,23925968,23468334,23468336,23468337,23468338,23468343,23468347,23468356,23468358,23468358,23468359,23468359,23468360,23468360,23468361,23468337,23468359,23468360,23468361,23468344,23468345,23468346,23468346,23468350,23468364,23468362,23468364,23468359,23468365,23468367,23468367,23468368,23468368,23468369,23468369,23468370,23468370,23468372,23468370,23468372,23468373,23468374,23468377,23468378,23468379,23468381,23849065,23468382,23468383,23468383,23468382,23468384,23468385,23468383,23468384,23468385,23468384,23468385,23468385,23468386,23468385,23468386,23468386,23468386,23468387,23468387,23849099,23468388,23468389,23468415,23477486,23556861,23584291,23584298,23584298,23589405,23589409,23589518,23609659,23616643,23650199,23653342,23653342,23653343,23653344,23653344,23653353,23661719,23666605,23666607,23666608,23666609,23666663,23666663,23666664,23666665,23666665,23666666,23666667,23666667,23666669,23666670,23666670,23666671,23666671,23666672,23666673,23666675,23671365,23696927,23696928,23696929,23696929,23699928,23699929,23699929,23711558,23831761,23840530,23846010,23849071,23849072,23849086,23849088,23849093,23849098,23849099,23849099,23849119,23849127,23849900,23867467,23468390,23666675,23671369,23849072,23849099,23849100,23666666,23666668,23849073,23849101,23849099,23486623,23486697,23486744,23858284,23547249,23888519,23645406,23937617,23700224,23700231,23700232,23965005,23782601,23965033,23710457,23710472,23710460,23970123,23970123,23710548,23710621,23710724,23970212,23970305,23750947,23750946,23990358,23990360,23764932,23997360,23832014,23832026,23832038,23832085,23832156,23832138,23832168,23832148,23832150,23832171,24030971,23832191,24030973,24030975,23838324,23838324,23838299,23838326,23838326,23838335,23838438,23851571,23851590,23884910,24034054,24034081,23838533,24034149,23855073,23860016,24042425,23864801,23864877,23864837,23864839,23864840,23864845,23864897,24047304,24047331,23864902,23864953,23864953,23864954,23864942,23864955,23864955,23864955,23864957,23864958,23864956,23864956,23864958,23864958,23864961,23864967,23864950,23864957,23864959,23864968,23864958,23864968,23864960,23864968,23864971,23864969,23864968,23864973,23864972,23864963,23864971,23864975,23864977,24047362,24047389,23898220,24047362,24047389,24047390,23864978,23864980,24047363,24047390,24047364,24047392,24047365,24047392,24047368,24047397,24047371,24047399,24047372,24047373,24047373,24047374,24047401,24047402,23874355,23874357,23874360,24052089,24052064,24052116,23925484,23925483,23925486,23925487,24077655,24077629,24077629,23931480,23931481,23931482,23931482,23931483,24080652,24080652,24080653,23954789,24092303,24195147,24212458,24212713,24221255,24223675,24223744,24223816,24226809,24229755,24229756,24229757,24229760,24229761,24229762,24229778,24229782,24229783,24229783,24229784,24229831,24229757,24229760,24229761,24229764,24229765,24229765,24229766,24229766,24229767,24229771,24229774,24229781,24229784,24229785,24229785,24229786,24229786,24229787,24229787,24229766,24229766,24229767,24229787,24229787,24229767,24229787,24229788,24229788,24229767,24229787,24229788,24229788,24229773,24229781,24229783,24229788,24229789,24229776,24229789,24229789,24229790,24229794,24229796,24229797,24229797,24229799,24229800,24229804,24229804,24229805,24229805,24229807,24229807,24229808,24229808,24229808,24229808,24229809,24229809,24229810,24229810,24229811,24229812,24229812,24229813,24229813,24229814,24229814,24229815,24229815,24229816,24229816,24229817,24229819,24229820,24229821,24229821,24229822,24229823,24229825,24229826,24229826,24229827,24229827,24229828,24229828,24229829,24229829,24229830,24229830,24229831,24229831,24229832,24229832,24229833,24229833,24229834,24229834,24229835,24229835,24229836,24229837,24229838,24229838,24229839,24229844,24229851,24229853,24229855,24229856,24229859,24229812,24229813,24229813,24229814,24229814,24229815,24229815,24229817,24229817,24229818,24229819,24229820,24229821,24229821,24229822,24229823,24229823,24229824,24229824,24229825,24229826,24229826,24229827,24229827,24229828,24229829,24229829,24229830,24229830,24229831,24229831,24229832,24229832,24229833,24229834,24229834,24229835,24229835,24229836,24229837,24229837,24229838,24229839,24229842,24229844,24229845,24229859,24229814,24229814,24229815,24229821,24229827,24229829,24229829,24229830,24229832,24229832,24229833,24229834,24229834,24229835,24229815,24229815,24229816,24229830,24229832,24229832,24229833,24229834,24229835,24229815,24229816,24229816,24229818,24229823,24229825,24229827,24229830,24229831,24229836,24229836,24229858,24229816,24229817,24229817,24229818,24229819,24229825,24229827,24229829,24229831,24229831,24229832,24229833,24229833,24229834,24229836,24229836,24229818,24229825,24229827,24229829,24229829,24229832,24229833,24229836,24229838,24229818,24229819,24229820,24229820,24229821,24229823,24229823,24229825,24229826,24229828,24229828,24229829,24229830,24229833,24229833,24229834,24229834,24229836,24229837,24229837,24229838,24229839,24229840,24229863,24229820,24229820,24229826,24229829,24229835,24229838,24229825,24229836,24229838,24229839,24229821,24229824,24229837,24229838,24229839,24229822,24229827,24229831,24229836,24229836,24229839,24229840,24229841,24229824,24229826,24229827,24229834,24229835,24229839,24229840,24229826,24229829,24229838,24229842,24229843,24229828,24229831,24229828,24229837,24229840,24229842,24229829,24229831,24229835,24229837,24229838,24229842,24229855,24229831,24229832,24229832,24229835,24229836,24229841,24229843,24229836,24229839,24229833,24229834,24229836,24229837,24229839,24229840,24229841,24229841,24229842,24229842,24229845,24229846,24229834,24229836,24229840,24229841,24229844,24229870,24229838,24229838,24229840,24229841,24229843,24229843,24229845,24229841,24229846,24229846,24229839,24229843,24229846,24229840,24229842,24229840,24229841,24229843,24229844,24229844,24229846,24229848,24229849,24229850,24229841,24229843,24229843,24229844,24229845,24229845,24229847,24229849,24229849,24229858,24229842,24229845,24229845,24229846,24229848,24229849,24229849,24229850,24229865,24229844,24229845,24229846,24229847,24229847,24229849,24229851,24229853,24229846,24229847,24229845,24229846,24229847,24229848,24229849,24229850,24229850,24229851,24229846,24229847,24229847,24229848,24229848,24229849,24229850,24229850,24229851,24229851,24229852,24229852,24229853,24229854,24229854,24229876,24229847,24229848,24229849,24229852,24229848,24229849,24229849,24229850,24229850,24229851,24229851,24229852,24229852,24229853,24229854,24229856,24229857,24229858,24229861,24229849,24229850,24229850,24229851,24229851,24229852,24229852,24229853,24229853,24229854,24229854,24229850,24229851,24229851,24229852,24229853,24229853,24229854,24229854,24229855,24229856,24229851,24229852,24229853,24229853,24229854,24229854,24229855,24229855,24229856,24229867,24229852,24229853,24229853,24229854,24229854,24229855,24229855,24229856,24229857,24229859,24229872,24229854,24229854,24229855,24229855,24229858,24248200,24229855,24229855,24229856,24229857,24229855,24229856,24229856,24229857,24229857,24229858,24229856,24229857,24229857,24229858,24229859,24229859,24229861,24229862,24229864,24229865,24229881,24229882,24248230,24229857,24229858,24229858,24229859,24229859,24229860,24229861,24229861,24229862,24229862,24229866,24229858,24229859,24229859,24229860,24229860,24229861,24229862,24229862,24229863,24229864,24229864,24229865,24229865,24229866,24229866,24229867,24229868,24229877,24229878,24229882,24229859,24229860,24229860,24229861,24229862,24229862,24229866,24229883,24229860,24229861,24229861,24229862,24229862,24229863,24229863,24229864,24229865,24229865,24229866,24229866,24229867,24229867,24229868,24229869,24229870,24229872,24229872,24229874,24229875,24229877,24229877,24229878,24229879,24229881,24229884,24229861,24229862,24229862,24229863,24229864,24229866,24229867,24229862,24229863,24229864,24229864,24229865,24229866,24229866,24229867,24229867,24229868,24229869,24229871,24229872,24229873,24229874,24229885,24229863,24229864,24229864,24229865,24229865,24229866,24229866,24229867,24229867,24229868,24229868,24229869,24229869,24229870,24229870,24229871,24229873,24229874,24229874,24229875,24229876,24229877,24229883,24229884,24229885,24229885,24229864,24229865,24229865,24229866,24229866,24229867,24229865,24229866,24229866,24229867,24229867,24229868,24229868,24229869,24229869,24229871,24229874,24229874,24229883,24229886,24229886,24229866,24229867,24229867,24229868,24229868,24229869,24229869,24229870,24229870,24229871,24229871,24229872,24229874,24229875,24229883,24229884,24229886,24229887,24229867,24229868,24229868,24229869,24229869,24229870,24229870,24229871,24229871,24229872,24229872,24229873,24229875,24229875,24229876,24229887,24229887,24229868,24229869,24229869,24229870,24229870,24229871,24229871,24229872,24229872,24229873,24229873,24229876,24229877,24229878,24229880,24229880,24229884,24229884,24229886,24229887,24229888,24229869,24229870,24229870,24229871,24229871,24229872,24229872,24229873,24229876,24229876,24229880,24229888,24229870,24229871,24229871,24229872,24229872,24229873,24229873,24229874,24229874,24229875,24229876,24229877,24229877,24229878,24229879,24229880,24229883,24229883,24229885,24229887,24229888,24229888,24229889,24229871,24229872,24229872,24229873,24229873,24229874,24229874,24229875,24229875,24229876,24229877,24229879,24229889,24229889,24229872,24229873,24229873,24229874,24229874,24229875,24229875,24229877,24229878,24229883,24229884,24229885,24229886,24229889,24229889,24229890,24229873,24229874,24229874,24229875,24229875,24229878,24229878,24229879,24229880,24229880,24229881,24229882,24229883,24229885,24229885,24229886,24229888,24229888,24229889,24229889,24229890,24229890,24229874,24229875,24229875,24229876,24229876,24229877,24229877,24229878,24229878,24229879,24229879,24229881,24229881,24229885,24229886,24229887,24229890,24229890,24229891,24229875,24229876,24229876,24229877,24229878,24229878,24229879,24229879,24229880,24229880,24229881,24229881,24229882,24229883,24229884,24229886,24229886,24229887,24229888,24229889,24229890,24229891,24229891,24229876,24229877,24229877,24229878,24229879,24229879,24229880,24229880,24229881,24229882,24229882,24229883,24229884,24229886,24229889,24229891,24229891,24229892,24229877,24229878,24229880,24229880,24229884,24229887,24229889,24229890,24229892,24229892,24229878,24229879,24229879,24229880,24229880,24229881,24229881,24229882,24229883,24229884,24229884,24229885,24229885,24229888,24229888,24229889,24229889,24229890,24229891,24229892,24229892,24229893,24229879,24229881,24229882,24229882,24229885,24229886,24229890,24229893,24229893,24229881,24229882,24229882,24229883,24229884,24229893,24229894,24229883,24229886,24229886,24229888,24229894,24229882,24229883,24229887,24229895,24229883,24229884,24229884,24229885,24229886,24229887,24229887,24229888,24229890,24229890,24229891,24229892,24229892,24229893,24229894,24229895,24229895,24229884,24229885,24229885,24229886,24229886,24229887,24229888,24229889,24229889,24229890,24229890,24229892,24229892,24229893,24229894,24229895,24229895,24229896,24229885,24229886,24229887,24229888,24229888,24229889,24229890,24229891,24229891,24229892,24229893,24229895,24229896,24229896,24229887,24229887,24229888,24229889,24229889,24229890,24229891,24229893,24229895,24229895,24229896,24229897,24229888,24229889,24229897,24229888,24229889,24229890,24229890,24229892,24229893,24229894,24229896,24229897,24229898,24229889,24229890,24229890,24229891,24229892,24229893,24229894,24229895,24229896,24229897,24229897,24229898,24229898,24229891,24229893,24229896,24229897,24229898,24229899,24229891,24229892,24229892,24229893,24229893,24229894,24229894,24229895,24229896,24229896,24229897,24229899,24229899,24229892,24229893,24229894,24229895,24229896,24229896,24229897,24229897,24229898,24229898,24229899,24229900,24229894,24229894,24229896,24229896,24229897,24229898,24229900,24229900,24229895,24229897,24229898,24229899,24229901,24229895,24229896,24229897,24229899,24229900,24229901,24229901,24229896,24229897,24229897,24229898,24229898,24229899,24229901,24229902,24248221,24229900,24229901,24229902,24229902,24229898,24229899,24229899,24229900,24229900,24229902,24229902,24229903,24229899,24229900,24229903,24229903,24229900,24229901,24229901,24229902,24229903,24229903,24229904,24229901,24229902,24229902,24229903,24229903,24229904,24229904,24229902,24229903,24229904,24229904,24229905,24229903,24229904,24229904,24229905,24229905,24229904,24229905,24229905,24229906,24229905,24229906,24229906,24229906,24229907,24229907,24229934,24311507,24229908,24229909,24229909,24229910,24229911,24229911,24229914,24229915,24229919,24229920,24229920,24229922,24229923,24229924,24229924,24229925,24229925,24229926,24229926,24229927,24229927,24229928,24229929,24229930,24229931,24229931,24229932,24229932,24229933,24229934,24229934,24229935,24230657,24230659,24230660,24230660,24230661,24248170,24248227,24248227,24248256,24248256,24311508,24229909,24229910,24229910,24229911,24229912,24229912,24229913,24229913,24229914,24229915,24229916,24229917,24229917,24229918,24229919,24229919,24229920,24229920,24229921,24229922,24229923,24229924,24229925,24229925,24229926,24229927,24229928,24229929,24229930,24229930,24229931,24229932,24229932,24229933,24229933,24229934,24229935,24229935,24230661,24248228,24229911,24229911,24229912,24229913,24229914,24229916,24229918,24229918,24229921,24229923,24229929,24229932,24229933,24229933,24229934,24229936,24229933,24229936,24229936,24229913,24229915,24229921,24229927,24229929,24229937,24230662,24229914,24229930,24229937,24229914,24229917,24229929,24229938,24229915,24229924,24229930,24229930,24229932,24229938,24229923,24229927,24229933,24229934,24229923,24229933,24229922,24229927,24229935,24229921,24229937,24229940,24229941,24229922,24229924,24229942,24229924,24229925,24229939,24229942,24248235,24229933,24229927,24229928,24229935,24229942,24229927,24229936,24229940,24229944,24229929,24229935,24229940,24229945,24229936,24229936,24229939,24229940,24229943,24229944,24229944,24229946,24229945,24229936,24229944,24229945,24229947,24229938,24248239,24229947,24229945,24229937,24229939,24229940,24229942,24229939,24229948,24229948,24229946,24229940,24229941,24229941,24248243,24229941,24229944,24229942,24229943,24229944,24229946,24229947,24229948,24229951,24229952,24229946,24229948,24229949,24229952,24229948,24229952,24229953,24229945,24229946,24229947,24229947,24229949,24248246,24229947,24229951,24229952,24229954,24229947,24229948,24229951,24229948,24229949,24229950,24229951,24229953,24229949,24229950,24229951,24229952,24229953,24229954,24229955,24229951,24229953,24229954,24229954,24229955,24229956,24248248,24229952,24229953,24229955,24229956,24229955,24229954,24229954,24229955,24229955,24229956,24229957,24229957,24248250,24229955,24229956,24229958,24229955,24229956,24229957,24229957,24229958,24229956,24229957,24229957,24229959,24229957,24229958,24230684,24230685,24248252,24229958,24229959,24229959,24229960,24229959,24229960,24229960,24229960,24229961,24229961,24229962,24230001,24230685,24230685,24230686,24230686,24230687,24230687,24230688,24230690,24230691,24248139,24248246,24248254,24248254,24248283,24306786,24311535,24230686,24230687,24230688,24230688,24248254,24248255,24248284,24248307,24248348,24306788,24311535,24230727,24231422,24231410,24231411,24231424,24231411,24231412,24231412,24231413,24231416,24231426,24231427,24231412,24231427,24231427,24231414,24231415,24231424,24231425,24231426,24231426,24231427,24231427,24231428,24231428,24231429,24231430,24231430,24231427,24231429,24231418,24231428,24231430,24231429,24231430,24231431,24231429,24231430,24231431,24231439,24231440,24231562,24231562,24248992,24231439,24231441,24231441,24231564,24248993,24248993,24231442,24231442,24231443,24248994,24231442,24248994,24231443,24231444,24231445,24231446,24231566,24248879,24248994,24248995,24249024,24231446,24248995,24249024,24248996,24249025,24248996,24248997,24248997,24248998,24249027,24231698,24231699,24249110,24249128,24249157,24266391,24266490,24266507,24266529,24266538,24266538,24266546,24266547,24266548,24266548,24266549,24266549,24266550,24266550,24266551,24266551,24266552,24266553,24266554,24266554,24266555,24266556,24266557,24266557,24266559,24266562,24266564,24266567,24266568,24266569,24266570,24266573,24266574,24266574,24266575,24266575,24266576,24266549,24266552,24266556,24266557,24266569,24266575,24266575,24266576,24266576,24266550,24266554,24266555,24266556,24266576,24266550,24266552,24266555,24266576,24266576,24266577,24266577,24266577,24266578,24266578,24266578,24266560,24266579,24266579,24266560,24266580,24266581,24266581,24266582,24266582,24266583,24266583,24266584,24266584,24266579,24266585,24266585,24266585,24266586,24266587,24266585,24266591,24266592,24266596,24266597,24266597,24266598,24266598,24266599,24266601,24266602,24266602,24266603,24266603,24266603,24266604,24266604,24266605,24266606,24266606,24266607,24266607,24266608,24266608,24266609,24266610,24266610,24266611,24266611,24266612,24266612,24266613,24266613,24266614,24266614,24266615,24266616,24266616,24266617,24266617,24266618,24266618,24266619,24266620,24266620,24266621,24266622,24266622,24266623,24266623,24266624,24266624,24266625,24266625,24266626,24266626,24266627,24266628,24266628,24266629,24266630,24266631,24266631,24266633,24266633,24266634,24266635,24266643,24266651,24266651,24266606,24266607,24266607,24266608,24266608,24266609,24266610,24266611,24266611,24266613,24266614,24266615,24266615,24266616,24266617,24266620,24266620,24266621,24266622,24266623,24266624,24266624,24266625,24266626,24266626,24266627,24266628,24266629,24266631,24266632,24266646,24266647,24266652,24266607,24266608,24266608,24266611,24266614,24266615,24266620,24266625,24266626,24266627,24266612,24266614,24266624,24266625,24266625,24266626,24266621,24266625,24266625,24266626,24266628,24266611,24266616,24266617,24266620,24266625,24266625,24266626,24266627,24266627,24266634,24266654,24266617,24266623,24266629,24266617,24266618,24266619,24266623,24266627,24266629,24266630,24266628,24266630,24266618,24266629,24266631,24266620,24266620,24266622,24266629,24266630,24266632,24266634,24266618,24266620,24266620,24266621,24266621,24266625,24266627,24266630,24266631,24266630,24266633,24266620,24266631,24266632,24266638,24266621,24266627,24266631,24266633,24266634,24266628,24266634,24266636,24266623,24266624,24266632,24266632,24266634,24266635,24266639,24266623,24266631,24266626,24266629,24266630,24266631,24266632,24266632,24266633,24266633,24266637,24266634,24266634,24266635,24266636,24266636,24266627,24266635,24266636,24266637,24266637,24266638,24266645,24266631,24266634,24266635,24266635,24266638,24266639,24266640,24266629,24266635,24266638,24266636,24266636,24266637,24266634,24266637,24266640,24266638,24266637,24266638,24266639,24266641,24266639,24266641,24266641,24266639,24266639,24266641,24266642,24266639,24266640,24266640,24266640,24266641,24266643,24266643,24266648,24266668,24266640,24266641,24266641,24266643,24266644,24266645,24266646,24266650,24266641,24266642,24266642,24266643,24266643,24266644,24266644,24266646,24266669,24266642,24266643,24266644,24266645,24266646,24266647,24266650,24266643,24266644,24266644,24266645,24266645,24266646,24266646,24266647,24266647,24266648,24266649,24266649,24266650,24266652,24266653,24266662,24266666,24266670,24266670,24266644,24266645,24266645,24266646,24266647,24266648,24266648,24266649,24266654,24266671,24266645,24266646,24266646,24266647,24266648,24266648,24266649,24266651,24266651,24266652,24266646,24266647,24266648,24266648,24266649,24266652,24266647,24266648,24266649,24266649,24266650,24266651,24266651,24266652,24266652,24266653,24266654,24266663,24266667,24266669,24266672,24266672,24266648,24266649,24266649,24266650,24266650,24266651,24266651,24266652,24266652,24266653,24266653,24266654,24266654,24266655,24266658,24266664,24266664,24266665,24266669,24266670,24266671,24266672,24266673,24266649,24266650,24266654,24266650,24266651,24266651,24266652,24266652,24266653,24266653,24266654,24266654,24266656,24266664,24266665,24266665,24266666,24266668,24266669,24266671,24266673,24266674,24266651,24266652,24266652,24266653,24266653,24266654,24266654,24266656,24266656,24266671,24266674,24266652,24266653,24266653,24266654,24266654,24266655,24266655,24266656,24266657,24266658,24266658,24266661,24266665,24266670,24266674,24266675,24266653,24266654,24266654,24266655,24266656,24266656,24266658,24266669,24266671,24266672,24266674,24266675,24266675,24266654,24266655,24266655,24266656,24266656,24266659,24266666,24266672,24266675,24266655,24266656,24266656,24266657,24266657,24266658,24266658,24266659,24266662,24266666,24266667,24266669,24266671,24266673,24266674,24266675,24266676,24266676,24266656,24266657,24266657,24266658,24266658,24266659,24266660,24266660,24266662,24266666,24266666,24266667,24266667,24266672,24266673,24266674,24266674,24266676,24266676,24266677,24266677,24266657,24266658,24266658,24266659,24266659,24266660,24266661,24266662,24266664,24266665,24266667,24266668,24266676,24266677,24266677,24266658,24266659,24266659,24266660,24266660,24266661,24266661,24266663,24266664,24266665,24266666,24266667,24266668,24266669,24266669,24266671,24266672,24266673,24266673,24266674,24266674,24266675,24266676,24266676,24266677,24266677,24266678,24266659,24266660,24266660,24266661,24266661,24266662,24266663,24266667,24266668,24266669,24266670,24266673,24266674,24266675,24266676,24266678,24266678,24266660,24266661,24266662,24266662,24266664,24266674,24266676,24266678,24266679,24266661,24266662,24266662,24266663,24266667,24266668,24266668,24266670,24266671,24266671,24266676,24266676,24266679,24266679,24266662,24266663,24266663,24266664,24266665,24266667,24266667,24266669,24266670,24266670,24266671,24266672,24266673,24266674,24266675,24266675,24266676,24266677,24266678,24266679,24266680,24266665,24266665,24266671,24266679,24266680,24266664,24266665,24266666,24266666,24266668,24266670,24266671,24266672,24266672,24266673,24266673,24266674,24266676,24266677,24266679,24266680,24266681,24266671,24266674,24266677,24266680,24266681,24266681,24266678,24266682,24266682,24266678,24266680,24266682,24266683,24266674,24266682,24266683,24266675,24266683,24266681,24266685,24266676,24266682,24266684,24266685,24266686,24266676,24266679,24266686,24266687,24266680,24266683,24266685,24266686,24266686,24266687,24266687,24266679,24266687,24266688,24266679,24266683,24266685,24266688,24266684,24266685,24266687,24266688,24266689,24266685,24266685,24266689,24266689,24266684,24266685,24266685,24266686,24266687,24266690,24266687,24266690,24266690,24266686,24266688,24266690,24266691,24266691,24266692,24266688,24266692,24266692,24266691,24266692,24266693,24266690,24266691,24266692,24266693,24266693,24266690,24266691,24266693,24266693,24266694,24266691,24266692,24266694,24266694,24266692,24266694,24266695,24266694,24266694,24266695,24266695,24266695,24266696,24266696,24266696,24266696,24266697,24266697,24266698,24266699,24266699,24266704,24266711,24266715,24266716,24266716,24266718,24266720,24266722,24266724,24266725,24266725,24266726,24266726,24266727,24286781,24286782,24325147,24325148,24325149,24325151,24325153,24325156,24325157,24329903,24266699,24266700,24266700,24266701,24266701,24266702,24266703,24266707,24266709,24266711,24266711,24266712,24266712,24266713,24266716,24266717,24266719,24266720,24266721,24266722,24266723,24266723,24266725,24266725,24266726,24266726,24266727,24266727,24286782,24266700,24266701,24266705,24266710,24266713,24266720,24266722,24266723,24266725,24266726,24266726,24266727,24266727,24266728,24266726,24266726,24266727,24266728,24266728,24266717,24266725,24266727,24266727,24266728,24266729,24266728,24266727,24266730,24266731,24266723,24266733,24266733,24266730,24266737,24266729,24266740,24266739,24266740,24329916,24266741,24266735,24266741,24266739,24266742,24266741,24266743,24266734,24266745,24266735,24266742,24266745,24266745,24266746,24266745,24266742,24266746,24266747,24266747,24266747,24266749,24266745,24266749,24266750,24266748,24266749,24266751,24266748,24266749,24266750,24266750,24266751,24266748,24266750,24266751,24266752,24266751,24266751,24266752,24266752,24266753,24266753,24266752,24266753,24266753,24266754,24266753,24266754,24266754,24266754,24266755,24266755,24266756,24266757,24276771,24276773,24276773,24276776,24286807,24286810,24286810,24286811,24286811,24286812,24286813,24286815,24286815,24286819,24325176,24325176,24325177,24325177,24325178,24325178,24325180,24325181,24325181,24325182,24325182,24325183,24325183,24325184,24325184,24325185,24325185,24325186,24325186,24325187,24329932,24286811,24286812,24329932,24325178,24286801,24286801,24286803,24286807,24335206,24296841,24335215,24339963,24306861,24306863,24306864,24306865,24306881,24306883,24306883,24306884,24306865,24306866,24306866,24306877,24306880,24306880,24306881,24306881,24306882,24306882,24306883,24306883,24306884,24306885,24306887,24306866,24306867,24306872,24306874,24306875,24306876,24306877,24306880,24306881,24306881,24306882,24306882,24306883,24306883,24306884,24306884,24306885,24306885,24306886,24306886,24306889,24306889,24306867,24306880,24306881,24306882,24306882,24306883,24306884,24306887,24306874,24306878,24306881,24306882,24306882,24306883,24306883,24306884,24306884,24306885,24306885,24306886,24306886,24306887,24306888,24306888,24306889,24306889,24306890,24306891,24306895,24306896,24306896,24306888,24306895,24306893,24306901,24306894,24306899,24306892,24306895,24345243,24306896,24306896,24306896,24306900,24306900,24306901,24345246,24350001,24306896,24306897,24306897,24306898,24306899,24306902,24306904,24345246,24345253,24345255,24350002,24306897,24306901,24345246,24345247,24345248,24345250,24345256,24350002,24306898,24306899,24306900,24306900,24306901,24306902,24306903,24306904,24306908,24345247,24345247,24345248,24345248,24345249,24345251,24345251,24345254,24345256,24345257,24345257,24350003,24306899,24306900,24306901,24306901,24306902,24306903,24306905,24306906,24345249,24345254,24345255,24345255,24345256,24345257,24345258,24350003,24306900,24306901,24306901,24306902,24306902,24345248,24345249,24345253,24345256,24350004,24306901,24306902,24306903,24306905,24345250,24345256,24350004,24306902,24306903,24306903,24306904,24306905,24306906,24306906,24345249,24345249,24345250,24345253,24345254,24345255,24345256,24345259,24345259,24350005,24306904,24306905,24306906,24306911,24345249,24345250,24345251,24345256,24345259,24350005,24306904,24306905,24306906,24306907,24306911,24345251,24350006,24306906,24306910,24333239,24345252,24345253,24345256,24345257,24345257,24350006,24345252,24345257,24345260,24350007,24306908,24345252,24345253,24345257,24345260,24345261,24350007,24306908,24345253,24345254,24345256,24350008,24306914,24345253,24345254,24345257,24345261,24345261,24350008,24306910,24345261,24345263,24350009,24345255,24345263,24350009,24306916,24345255,24345255,24350010,24345255,24350010,24345255,24345256,24345267,24345257,24345258,24345259,24345263,24345266,24350013,24345259,24359588,24376355,24383597,24383598,24383602,24383604,24383604,24383605,24383605,24383611,24383612,24383612,24383613,24383614,24383598,24383598,24383599,24383599,24383602,24383604,24383604,24383605,24383605,24383606,24383607,24383612,24383612,24383613,24383613,24383614,24383617,24383598,24383602,24383606,24383606,24383607,24383613,24383617,24383622,24383599,24383600,24383601,24383601,24383602,24383602,24383603,24383604,24383604,24383605,24383605,24383606,24383606,24383607,24383607,24383608,24383612,24383613,24383613,24383614,24383614,24383615,24383615,24383616,24383616,24383617,24383617,24383618,24383618,24383619,24383619,24383620,24383621,24383622,24383623,24383603,24383603,24383605,24383607,24383608,24383608,24383614,24383602,24383603,24383606,24383610,24383614,24383619,24383624,24383615,24383608,24383605,24383607,24383609,24383625,24383625,24383605,24383609,24383610,24383611,24383626,24383606,24383607,24383607,24383609,24383610,24383611,24383607,24383608,24383609,24383610,24383611,24383618,24383620,24383627,24383608,24383609,24383610,24383610,24383611,24383612,24383627,24383627,24383609,24383610,24383610,24383612,24383628,24383610,24383611,24383611,24383612,24383613,24383613,24383620,24383621,24383628,24383629,24383611,24383612,24383612,24383613,24383613,24383614,24383620,24383621,24383628,24383629,24383612,24383613,24383613,24383614,24383614,24383619,24383619,24383620,24383620,24383629,24383613,24383614,24383614,24383615,24383621,24383622,24383624,24383629,24383630,24383614,24383615,24383615,24383620,24383621,24383630,24383630,24383631,24383615,24383616,24383622,24383624,24383625,24383627,24383630,24383630,24383631,24383616,24383617,24383622,24383622,24383623,24383623,24383625,24383627,24383631,24383631,24383632,24383635,24383617,24383619,24383622,24383623,24383623,24383624,24383625,24383626,24383630,24383631,24383631,24383632,24383632,24383636,24383623,24383632,24383633,24383634,24383625,24383627,24383636,24383627,24383629,24383632,24383637,24383637,24388367,24383628,24383629,24383632,24383637,24388368,24383629,24383630,24383631,24383634,24383637,24383638,24388368,24383630,24383631,24383633,24383637,24383638,24383638,24388369,24383632,24383632,24383635,24383637,24383638,24383639,24383639,24388369,24383633,24383639,24388370,24383633,24383635,24383638,24388370,24383635,24383637,24383640,24388371,24383639,24388371,24383638,24383638,24383641,24383641,24388372,24383637,24388372,24383643,24388373,24383642,24383643,24388373,24383644,24388374,24388374,24383645,24383645,24388376,24383645,24383646,24388376,24383646,24388377,24383647,24383648,24383648,24383651,24388377,24383651,24388378,24388378,24388379,24388381],\"xaxis\":\"x\",\"y\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,3,2,2,2,0,0,0,1,0,1,1,145,29,14,7,2,1,1,5,2,9,1,359,105,60,4,3,26,34,28,3,326,161,15,3,3,2,6,63,102,27,3,269,23,7,8,7,23,124,184,45,1,1,46,36,14,20,13,5,26,202,262,108,9,6,25,45,24,2,2,4,12,17,34,9,18,15,6,10,9,12,6,3,13,4,6,3,2,58,10,290,72,3,0,0,0,0,0,0,0,0,596,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,19,3,2,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,0,0,1,0,1,0,1,0,1,1,1,0,0,0,1,0,1,3,0,0,0,1,1,2,2,3,1,6,12,5,1,1,1,3,1,1,1,2,3,2,1,1,3,4,1,3,1,1,7,1,3,2,1,1,1,0,0,0,0,5,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,4,6,1,2,1,1,3,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,2,3,2,16,1,3,2,9,61,1,1,4,80,4,8,5,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,4,1,10,2,1,8,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,2,3,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,3,1,2,2,2,32,40,2,1,37,1,2,2,5,1,2,1,1,0,1,0,1,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,2,2,1,9,5,3,69,9,2,1,2,2,1,10,6,1,2,2,2,3,1,0,0,1,1,0,4,0,0,1,0,0,0,1,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,1,1,2,0,0,0,0,0,0,0,0,1,2,0,0,0,1,1,2,1,1,0,0,0,0,0,0,2,0,1,0,1,1,0,0,2,1,0,2,2,1,1,1,0,0,0,0,0,0,0,1,1,1,2,1,1,4,52,14,3,1,1,1,1,2,4,1,2,3,1,3,1,2,3,2,0,2,0,0,0,0,2,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,1,1,0,0,0,0,0,0,2,1,1,0,0,0,0,1,0,1,1,1,1,1,1,1,2,1,1,2,1,9,4,2,6,2,1,1,1,2,1,2,3,1,6,2,2,4,2,30,8,1,2,5,1,2,1,1,1,3,2,7,4,16,3,2,2,1,1,193,3,1,2,1,1,2,2,2,4,2,1,1,1,525,53,1,3,6,2,1,3,1,1,4,1,1,1,646,1,1,2,2,1,107,15,2,39,1,33,100,88,14,17,2,132,89,41,56,137,54,1,2,2,4,4,2,2,4,1,3,106,3,2,3,2,2,5,3,2,2,2,1,1,2,18,2,4,1,2,1,1,1,1,1,3,2,1,1,3,1,29,1,3,9,2,3,3,2,1,2,2,2,1,107,2,2,1,1,1,1,64,2,3,2,3,1,1,37,64,19,2,2,2,1,1,126,70,2,3,183,60,65,18,1,223,54,2,4,3,2,1,1,1,252,61,3,2,1,1,315,123,98,2,6,2,1,1,331,101,31,22,3,4,4,3,3,451,59,18,3,4,2,557,119,59,3,3,2,734,55,15,3,1,2,1,761,150,36,1,4,3,1,2,2,766,107,1,0,3,1,1,804,31,67,13,3,2,1,1,1,816,16,33,39,14,5,4,3,7,1,4,5,2,0,687,67,70,2,2,7,1,606,51,51,42,3,1,3,6,1,627,82,1,1,0,3,2,2,602,136,60,1,5,2,3,2,5,2,2,0,745,28,12,4,2,3,0,3,1,2,885,100,1,1,4,2,1,6,3,0,899,125,3,1,0,2,0,1,3,0,2,1,742,253,28,1,1,4,0,1,0,1,748,101,0,1,1,0,367,285,75,75,40,2,18,2,2,61,0,7,2,3,1,1,0,261,86,39,1,4,1,0,0,278,40,69,45,23,80,3,1,0,86,92,46,116,3,1,1,0,49,35,37,54,22,48,34,113,4,133,32,5,0,88,22,96,0,1,87,16,0,0,84,15,71,2,116,31,0,1,46,14,65,2,3,5,1,0,0,0,33,15,3,11,0,0,3,17,5,2,3,1,0,1,2,16,5,1,1,2,0,34,82,24,4,27,29,26,6,1,9,1,121,52,136,61,72,152,19,154,52,1217,1,14920,2,38632,201,3,1,3,4,1,1,43991,146,11,6,26,1,48292,437,141,78,53,10,49572,1587,415,122,47,43,106,94,73,4,46556,4255,105,344,51,119,193,109,383,79,18,41225,2798,1235,440,107,220,177,272,364,1176,605,822,7,20091,8732,4029,533,612,755,772,1339,1040,4151,1630,2934,226,12856,3436,434,706,226,522,1090,643,1458,696,1135,148,7968,683,1165,1121,136,2454,716,4949,1411,2719,124,843,2316,1273,75,571,591,1101,7001,1490,794,445,207,445,203,1194,68,174,849,169,130,851,425,1873,253,471,83,783,815,2507,365,76,225,170,689,175,1896,54,468,2362,4069,329,727,185,18,5606,1270,1000,20166,15363,264,64,2,27760,258,39,50905,1926,165,14,1,0,48274,1267,227,31,46053,1934,45467,81,42461,15,15,36874,177,3,13,32538,52,28,0,27495,294,10,1,0,0,0,0,23930,7,8839,581,13,12,4,0,0,0,0,0,7269,83,5,7,4,1,0,5306,84,47,17,5,2,3,2,3,2,2,1,1,1,0,0,0,3064,673,126,19,8,1,6,6,9,5,3,1,1,15,9,5,8,3,5,1,1,3,1,1,1,0,0,0,0,2306,330,40,12,24,3,1,49,16,45,47,15,2,1,3,5,5,2,5,1,2,0,0,0,0,1410,202,106,114,50,27,9,21,16,38,7,9,59,2,4,46,59,16,5,6,4,13,4,3,24,13,9,2,2,3,5,2,1,1,1,1,0,0,0,0,0,0,0,0,0,818,107,65,22,14,20,43,14,1,3,43,22,23,81,14,37,6,2,23,18,2,35,22,20,17,4,9,2,1,4,1,2,2,1,0,0,0,0,83,48,115,25,33,72,62,15,21,197,6,63,10,57,6,23,9,11,17,19,27,6,24,6,2,5,8,2,1,0,0,0,0,0,15,21,11,5,26,2,21,10,5,72,9,5,4,20,9,5,14,9,5,2,8,4,2,0,0,1,15,16,17,10,7,12,5,4,92,3,2,3,7,5,5,8,1,1,1,41,70,4,6,4,68,6,5,5,2,2,2,0,0,27,3,56,13,14,8,10,8,3,8,2,6,4,1,0,0,57,6,3,8,12,4,4,4,7,4,5,4,1,51,8,15,37,12,63,4,11,78,4,6,8,4,6,7,2,3,3,1,4,99,12,4,9,9,2,12,4,11,13,8,11,0,3,39,10,8,5,11,6,3,71,36,12,13,4,4,2,5,5,2,3,1,5,220,6,6,10,2,13,7,18,9,5,14,108,49,9,46,47,18,4,3,50,9,8,9,2,3,31,81,227,34,75,20,6,6,21,14,2,3,3,2,2,0,0,70,84,80,7,5,5,5,8,10,1,0,225,123,10,4,2,7,21,3,1,0,578,60,7,35,8,5,7,18,28,10,1,3,1,1,0,669,180,48,22,21,28,9,3,2,689,87,42,60,8,5,16,10,1,7,2,1,0,0,669,135,42,30,24,9,3,2,2,1,3,1,0,629,122,5,1,4,30,8,8,4,3,0,691,63,26,10,2,5,3,10,2,4,4,0,0,0,0,759,68,61,32,8,4,6,2,2,1,1,2,1,1,1,0,0,752,44,24,5,6,7,5,2,2,1,1,0,0,0,694,111,43,9,8,3,8,1,5,1,0,0,0,0,636,84,15,17,32,17,8,3,1,4,2,1,1,1,0,0,0,0,0,0,0,617,38,19,22,18,3,9,22,5,5,8,3,3,4,1,1,0,0,0,0,0,0,0,428,71,22,14,17,8,9,2,16,6,3,1,3,3,5,1,1,0,0,0,0,0,0,315,24,29,11,9,3,2,5,1,1,4,1,1,0,1,0,0,0,0,0,0,236,29,13,7,1,1,5,4,1,6,5,3,1,2,2,1,0,0,0,0,184,22,9,31,4,4,12,1,2,3,1,1,1,2,1,0,1,0,0,0,0,0,0,0,121,41,22,6,13,1,1,6,2,2,3,2,0,1,0,0,0,0,0,80,12,20,4,5,1,1,1,9,1,1,0,0,0,0,0,0,0,61,1,2,7,4,8,3,6,8,1,1,2,0,0,0,0,0,0,26,27,6,16,4,2,5,1,1,1,1,1,0,0,0,0,0,0,0,0,0,5,12,2,6,3,1,1,3,1,1,0,0,0,0,0,0,16,2,3,2,11,2,1,2,0,0,0,0,0,0,0,0,0,0,7,2,7,6,4,3,2,1,1,0,0,0,0,0,0,0,0,0,3,8,4,1,1,1,0,1,0,0,0,0,0,0,2,2,4,1,1,1,0,0,0,0,0,0,2,2,4,3,1,1,0,0,0,0,0,0,0,13,3,4,1,1,1,0,0,0,0,0,0,12,2,2,1,1,4,1,1,0,0,0,0,0,0,0,0,0,0,7,1,1,1,1,1,2,0,0,0,0,0,2,1,3,1,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,2,1,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,2,1,2,4,1,1,2,2,3,2,1,7,1,1,4,7,5,14,7,1,21,8,25,9,1,48,88,29,2,112,32,1,2,1,780,8,4,2,2874,456,91,16,1,6,3398,199,39,3,4746,240,49,7,1,6343,169,18,5,8633,156,2,11185,16,4,30736,22,2,1,3,39912,1,6,5,5,8,2,2,53006,217,50,68,32,118,76,57,29,11,3,42,9,10,6,52403,442,146,29,386,925,568,1495,700,526,30,20,10,22807,46,161,174,558,131,295,3707,8723,11725,3588,1520,318,168,24,22,1,218,243,76,548,269,659,1122,1136,5710,9435,3087,1009,116,102,72,148,47,162,243,77,175,598,99,28,457,368,326,319,177,302,325,1089,77,623,4477,654,323,5,13619,2785,522,26,35889,6648,344,38,40,42691,2752,1066,1,46894,4923,302,27,48478,816,62,50442,1026,6,3,1,0,48359,326,40,2,45780,482,10,42508,81,7,4,0,37536,79,4,0,32019,253,41,6,0,0,28873,111,10,3,1,4,0,24776,154,7,5,0,21342,124,2,2,0,17730,109,8,2,0,0,0,13407,437,38,16,1,3,2,1,0,0,0,0,11389,124,10,7,1,0,0,8861,114,28,2,7,8,2,1,1,1,1,0,0,6699,182,27,21,6,2,5,5,1,1,2,6,4,3,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,5050,250,72,41,19,5,12,6,6,1,2,2,2,1,1,3,0,0,0,0,0,3990,213,27,22,10,11,15,3,3,6,2,3,1,0,0,0,0,0,0,0,0,0,0,0,3124,201,20,23,15,18,10,10,4,2,5,3,4,2,1,1,1,0,0,0,0,0,0,0,0,0,0,2411,280,52,18,15,22,2,1,3,10,4,2,4,2,2,4,0,4,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1958,168,45,30,12,13,19,9,7,7,2,2,1,1,1,3,3,2,2,2,0,0,0,0,0,0,0,0,1420,363,107,25,15,4,6,4,2,2,5,5,1,4,1,1,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,1217,121,62,4,8,2,3,2,2,9,5,2,3,1,5,1,1,1,2,0,0,0,0,0,1152,174,67,25,12,4,2,5,4,2,2,4,5,1,1,3,1,0,0,0,0,0,0,0,0,0,926,179,67,19,6,15,1,9,1,4,1,5,3,2,3,2,1,1,1,0,0,0,0,0,0,0,0,872,93,42,10,18,9,9,2,0,1,5,1,1,1,1,2,2,0,0,0,0,0,0,0,0,0,0,0,680,227,56,28,22,2,1,1,4,1,3,1,1,1,2,0,0,0,0,0,562,156,31,11,3,6,6,2,4,1,2,1,2,1,1,1,0,0,0,0,0,0,0,0,533,131,55,32,10,2,8,3,1,6,1,2,2,4,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,489,92,62,37,1,9,13,1,4,9,1,1,2,0,0,0,0,0,0,391,111,64,14,34,9,9,1,2,5,1,1,1,3,7,1,0,0,0,0,0,250,107,102,25,24,11,14,6,2,2,2,9,1,0,0,0,0,0,0,0,0,0,0,179,101,53,36,25,5,19,1,1,4,1,2,1,1,2,1,0,0,0,0,0,0,0,0,171,59,41,42,10,10,13,13,1,2,1,6,2,0,0,0,0,0,179,59,28,12,39,2,21,1,7,4,2,1,0,0,0,0,144,93,21,17,6,11,15,1,5,1,2,2,2,1,0,0,0,0,0,0,0,0,0,0,0,116,47,57,27,1,5,8,2,12,8,10,0,0,0,0,97,87,76,17,6,2,1,6,7,2,0,0,0,0,0,0,0,0,72,29,17,9,18,7,3,3,7,7,1,0,0,0,0,0,0,0,0,0,0,107,61,7,15,11,19,12,1,2,1,1,16,12,6,0,0,0,0,0,0,0,0,0,0,0,89,15,18,20,10,7,1,7,10,7,13,13,1,0,0,0,0,0,0,0,0,0,0,0,67,1,40,25,20,5,1,8,1,18,6,0,0,0,0,0,0,0,0,0,23,34,21,22,3,6,1,4,0,0,0,0,23,6,22,20,6,0,0,0,0,0,6,19,21,6,4,45,18,1,0,0,0,22,1,9,2,1,17,19,0,0,0,0,0,3,10,12,6,50,29,0,0,0,9,13,3,1,9,2,0,0,0,5,1,0,0,0,6,1,2,19,1,0,0,0,0,0,0,1,13,4,0,0,1,0,0,0,3,25,6,0,0,0,0,0,0,0,0,0,0,0,149,17,0,0,0,0,0,0,0,0,0,0,0,197,1,0,0,0,0,0,0,0,15,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,0,0,0,1,0,1,1,1,1,1,3,1,0,0,0,0,0,0,0,0,4,0,0,0,1,0,1,2,1,1,1,0,0,0,0,0,0,1,0,1,2,0,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,2,3,1,2,1,1,1,2,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,1,0,1,0,1,0,2,0,0,1,1,1,2,0,0,0,0,0,2,1,1,1,1,2,2,0,0,0,0,0,0,0,0,0,1,0,2,2,1,0,0,0,0,3,2,0,0,0,0,0,1,0,1,1,2,1,1,2,1,1,2,1,8,1,1,1,4,2,26,33,1,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,0,1,0,2,6,0,1,3,2,2,1,3,1,1,1,2,3,1,2,1,2,1,3,2,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,3,3,3,1,1,1,3,56,42,7,1,1,8,12,4,4,65,80,6,1,6,1,2,8,1,3,2,4,1,1,1,2,3,3,6,0,0,2,1,0,0,0,0,3,3,0,0,0,0,0,47,4,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,2,0,0,1,1,1,1,1,1,14,5,14,1,1,1,1,56,64,1,3,7,3,1,3,5,1,1,128,3,3,2,1,2,1,1,670,12,12,56,87,78,73,28,18,15,14,16,3,8,13,1,2,1,5,6,2,1,1,1,1,1,5,38,15,67,97,185,41,86,69,44,60,60,12,23,24,17,4,2,1,3,2,11,0,4,25,13,5,8,31,12,4,6,18,1,0,101,13,14,2,11,3,0,0,136,33,91,20,30,14,9,7,10,8,7,2,1,0,0,0,0,102,61,25,20,13,5,17,13,2,3,1,0,0,0,0,0,0,0,0,0,100,61,37,23,12,16,13,0,0,0,0,0,0,123,64,36,20,13,1,16,4,4,4,1,0,0,0,0,0,0,0,142,30,15,17,3,9,5,7,2,1,0,0,0,0,0,0,118,77,49,16,36,16,20,3,1,1,3,1,0,0,0,0,0,145,25,51,4,6,9,3,7,4,2,1,2,1,0,0,0,0,0,0,141,49,23,13,5,3,8,5,5,1,2,0,0,94,71,28,19,6,1,1,7,2,3,3,2,0,0,0,0,0,0,0,0,0,0,0,91,72,34,3,7,2,1,1,1,0,0,0,109,55,30,11,10,1,7,3,5,1,1,2,0,0,0,0,0,0,0,0,127,27,9,15,2,4,1,1,3,1,1,0,0,0,0,0,0,0,90,21,45,39,10,1,1,2,3,1,2,1,1,0,0,0,0,0,0,60,17,27,8,1,5,2,1,2,1,0,0,0,0,28,10,23,6,8,3,10,1,3,1,1,0,0,0,0,0,0,0,37,16,15,6,2,7,4,2,5,3,0,0,0,0,0,0,0,0,27,30,18,3,6,5,4,8,1,1,1,0,0,0,0,24,2,9,12,5,5,3,4,1,0,0,0,0,20,19,1,2,5,10,1,4,1,0,0,7,8,4,5,4,6,4,1,0,0,0,0,0,0,1,6,4,2,5,4,3,3,2,0,0,16,8,1,2,4,3,1,0,0,0,0,0,0,0,1,10,7,7,3,1,2,2,2,0,0,0,5,3,1,7,3,1,0,0,0,0,11,5,1,2,0,0,0,6,8,8,2,2,0,0,8,2,2,1,2,4,2,1,0,13,6,3,1,0,0,0,0,0,0,7,12,1,1,0,0,0,0,1,13,4,1,0,0,0,0,4,1,2,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,1,1,0,0,0,0,0,0,0,1,1,1,1,0,0,0,1,2,1,3,1,1,1,0,0,0,0,0,0,0,0,0,0,1,0,10,0,0,0,1,1,1,1,1,1,1,1,1,2,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,0,0,0,1,1,0,0,1,1,1,2,0,0,0,0,0,1,0,1,1,1,1,3,2,1,1,1,1,2,10,3,4,2,1,3,2,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,1,2,6,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,2,2,3,1,25,1,3,1,1,1,2,4,1,1,2,1,1,1,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,4,1,3,1,5,29,3,2,8,1,1,2,1,2,12,4,1,4,1,1,1,5,3,1,6,1,2,2,1,1,1,1,1,2,2,1,2,1,1,1,2,1,1,1,0,1,1,1,1,0,0,1,0,1,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,1,2,1,5,1,1,0,0,0,1,0,0,0,0,0,2,1,2,1,1,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,3,4,11,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,0,1,10,2,3,2,2,2,1,2,2,1,2,2,2,3,2,4,1,5,2,2,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,18,3,21,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,20,14,9,1,7,5,2,13,3,14,2,11,2,2,1,5,8,4,8,2,4,3,5,10,1,8,7,7,1,16,5,11,3,1,2,2,2,5,12,8,6,16,1,3,1,17,7,4,14,3,3,16,8,25,3,1,2,8,2,4,6,8,19,2,4,1,11,2,2,11,8,20,34,13,5,2,3,8,4,8,2,14,13,14,4,1,8,9,5,12,3,6,2,3,1,1,3,4,4,3,3,1,2,1,7,0,6,4,1,9,4,2,10,2,4,0,0,4,10,7,2,2,2,0,0,0,0,12,7,10,1,1,0,0,0,0,33,2,4,2,0,0,0,0,0,17,16,7,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,12,2,1,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,86,3,9,3,5,799,40,5,8,6,2,112,9,4,2,2,3,1,14,4,6,186,16,16,44,4,1,1,0,0,0,0,2,19,22,0,0,0,0,0,4,1,1,0,0,0,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,6,4,1,1,71,3,2,2,2,4,152,77,99,7,33,70,326,25,22,2,2,35,60,107,36,15,30,90,28,49,156,3,2,4,23,54,0,0,0,0,145,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,1,1,0,0,0,0,4,0,1,0,1,1,1,1,4,0,0,0,0,0,0,14,8,11,11,6,22,12,2,4,2,1,6,4,5,3,6,8,12,2,3,2,6,4,14,5,4,2,1,2,1,5,3,1,1,1,1,1,1,5,3,1,0,0,0,3,3,4,1,0,0,0,0,0,7,1,2,0,0,0,0,0,6,1,1,0,0,0,0,0,0,0,0,0,0,0,1,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,4,1,1,1,1,1,7,3,1,4,2,7,5,1,3,3,1,3,3,5,4,3,3,2,18,21,3,9,3,1,5,5,10,3,3,7,8,4,4,13,2,2,5,2,0,3,3,0,0,0,4,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,1,0,1,1,1,0,0,0,1,1,0,0,4,1,0,0,0,0,0,1,1,1,2,1,1,1,1,25,15,7,13,6,2,1,1,1,1,0,0,6,2,2,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,1,1,2,1,1,1,1,1,1,3,1,1,2,1,1,4,7,1,1,2,1,2,4,1,2,2,2,1,5,1,2,9,5,1,7,1,3,3,4,30,1,2,2,2,4,1,0,0,2,0,0,1,0,0,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,3,1,1,1,1,9,6,9,4,2,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,7,1,16,2,1,4,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,4,2,1,2,2,3,1,1,2,2,1,2,3,2,3,3,4,1,1,1,1,3,7,2,2,1,2,1,1,2,1,2,19,25,12,8,3,4,5,1,1,1,1,2,1,1,3,0,1,0,0,1,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,5,2,1,2,0,0,0,0,0,0,0,0,0,1,7,10,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,4,2,1,1,5,1,2,3,3,3,5,1,5,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,10,1,3,1,1,1,2,1,2,3,24,2,1,2,1,21,3,4,2,1,4,8,2,1,1,2,4,3,1,1,1,3,3,1,1,1,2,2,1,2,2,2,1,1,1,1,0,0,0,0,4,2,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,1,4,0,0,0,0,1,1,0,0,1,0,1,2,1,2,1,0,0,0,0,0,0,1,1,1,3,2,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,2,3,3,1,1,1,2,2,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,2,0,0,2,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,8,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,3,1,8,2,1,4,3,28,1,1,1,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,19,1,0,0,0,0,0,0,1,4,4,8,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,1,3,1,6,3,3,2,54,57,12,12,2,2,2,2,2,1,1,100,52,23,5,6,10,2,2,1,1,1,229,59,22,17,9,7,4,1,1,1,5,3,1,374,67,24,18,20,13,15,3,3,2,7,4,15,1,5,275,165,121,57,52,20,10,2,1,19,8,23,9,166,176,67,52,20,3,8,3,4,15,21,7,2,5,238,90,48,30,10,4,3,25,20,16,9,7,320,155,99,3,7,3,7,16,33,41,43,10,3,1,1,287,164,54,9,2,3,1,2,4,4,50,54,79,18,6,1,384,52,25,36,3,4,12,5,5,3,25,94,129,23,15,119,35,36,24,30,24,10,40,6,9,15,18,5,8,163,177,99,66,29,1,22,21,12,5,17,4,9,1,8,35,53,90,12,17,1,21,20,2,11,10,19,25,13,8,1,5,17,3,15,17,34,22,25,15,14,1,4,4,19,9,6,4,7,10,24,22,2,8,3,30,20,16,10,4,9,15,17,3,2,4,40,10,10,13,18,3,5,14,8,2,8,14,6,26,37,9,0,0,16,11,1,7,20,9,2,0,280,168,33,8,0,0,687,80,25,2,0,0,0,0,0,0,0,0,726,245,8,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,630,22,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,34,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,1,1,2,1,1,1,2,2,1,3,4,1,2,4,16,3,35,1,3,2,1,2,2,0,0,0,1,1,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,0,0,0,0,1,0,1,1,2,1,1,1,1,1,1,2,1,1,2,1,1,1,1,1,2,1,2,1,1,1,1,1,1,1,1,0,2,0,1,0,0,0,1,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,1,1,1,1,3,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,2,1,2,1,1,1,1,1,1,2,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,0,1,0,0,0,0,0,1,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,0,0,2,1,2,1,1,1,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,0,1,0,0,1,1,1,0,0,0,0,1,1,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,13,2,1,2,1,1,1,1,1,0,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,1,1,1,1,2,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,2,1,0,0,0,0,0,1,1,1,3,5,1,7,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,1,0,1,0,1,1,2,2,9,1,0,0,0,0,0,0,0,0,0,1,0,1,4,0,0,0,1,0,1,1,1,0,0,0,1,0,1,1,0,0,1,0,1,1,0,0,1,1,1,0,0,0,1,0,1,0,1,2,1,1,1,1,0,0,0,0,0,1,0,1,1,142,65,22,21,18,4,2,1,75,41,21,7,5,3,1,110,25,10,13,57,50,14,6,2,1,59,32,26,4,3,95,40,23,10,3,36,22,1,4,42,22,22,7,5,1,12,3,63,49,14,3,10,2,12,2,3,67,22,13,13,6,4,1,18,3,4,2,1,3,5,3,4,2,2,3,163,69,18,6,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,38,33,11,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,58,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,9,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,0,0,0,2,0,0,1,0,1,1,0,0,4,0,0,0,0,5,4,0,0,0,0,0,0,0,0,0,1,1,1,2,12,1,2,1,1,1,2,3,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,1,0,1,0,1,0,1,0,1,2,1,2,1,5,1,3,3,1,44,9,1,3,5,1,3,1,1,2,7,2,2,0,0,3,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,6,3,1,0,0,0,0,0,0,0,0,0,0,1,1,7,3,2,4,1,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,1,1,1,1,1,1,1,3,1,1,1,1,1,2,1,1,1,1,2,2,2,1,2,2,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,2,4,2,1,0,0,0,1,0,1,0,1,4,5,1,2,1,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,3,1,0,0,0,0,0,0,1,1,0,0,1,19,1,1,2,2,1,300,82,62,35,18,11,5,1,1,1,1,1,297,90,71,40,11,4,2,3,5,434,103,45,18,6,3,1,4,565,260,49,3,13,1,1,1,882,155,46,15,8,4,3,3,1,2,1,1,1550,186,49,30,7,3,2,5,1,1,2032,276,87,36,26,11,3,4,6,2,2,2094,605,128,53,12,3,15,4,4,5,6,4,3,4,2,1,2405,326,64,35,13,18,9,4,10,12,4,11,3,3,2915,503,78,12,56,4,11,12,5,11,16,6,6,12,8,18,12,15,16,3142,423,199,84,17,2,20,19,18,12,34,15,57,34,3,2,1,1,2296,841,425,48,79,54,18,16,5,71,40,7,61,32,14,141,59,76,20,35,26,7,2,3,3,1,1448,726,102,90,81,20,27,13,33,51,54,43,35,6,154,94,92,30,22,5,1,1339,256,80,128,47,20,45,37,14,10,121,7,14,88,22,33,19,151,113,85,73,469,269,233,22,61,19,58,236,181,117,63,51,117,35,103,472,134,86,121,16,4,9,4,1,1,1,85,215,53,18,47,25,18,50,129,28,12,69,13,90,44,32,16,3,161,48,67,54,32,52,27,74,43,22,67,68,56,39,93,17,112,86,46,71,19,63,100,101,53,7,15,28,94,25,49,8,42,60,8,21,40,14,48,24,45,20,9,11,60,40,43,95,58,19,37,33,87,30,31,29,27,33,28,15,18,11,9,28,6,6,2,14,84,21,62,79,12,29,128,235,169,34,64,4,36,47,56,32,51,31,270,19,79,35,8,87,12,76,166,101,48,29,61,47,46,87,39,11,22,72,33,156,86,29,30,2,1,87,290,63,175,25,2,104,150,82,86,33,5,0,506,214,87,23,1,0,1703,969,341,36,17,5,5,3,6,1,0,0,1887,895,44,12,13,5,3204,311,49,31,3,1,2,1,1,0,0,3653,336,172,31,22,1,1,2,2,1,0,0,0,0,0,0,2729,554,102,43,13,10,1,1,4,1,0,0,0,0,0,0,2369,193,74,34,8,12,2,1,1,0,0,0,0,0,0,0,1972,376,68,37,4,10,7,5,1,2,1,0,0,0,0,0,0,0,0,0,0,0,1594,206,22,17,10,6,3,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1331,158,72,27,16,4,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,886,225,49,24,19,18,2,2,2,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,542,173,51,19,26,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,452,106,22,38,1,5,1,1,2,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,371,75,56,1,11,1,4,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,237,119,8,2,1,2,2,3,5,8,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,5,10,5,2,1,3,1,5,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,45,31,5,7,12,5,8,15,3,1,2,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,9,1,4,1,0,0,0,0,0,0,0,20,3,1,5,3,5,1,1,2,0,0,0,0,0,0,0,0,4,2,3,3,4,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,3,5,1,1,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,0,0,0,1,2,1,1,1,6,7,1,2,17,4,2,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,1,2,1,1,1,1,1,1,1,1,1,1,3,2,1,1,1,3,1,2,2,2,3,2,1,1,1,2,3,2,3,2,2,5,7,4,1,1,4,3,3,2,6,22,1,2,14,3,6,9,26,43,3,4,11,7,13,3,17,66,3,2,4,2,1,5,3,0,3,3,6,0,0,0,0,0,0,2,6,0,0,3,10,6,0,0,0,0,0,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,10,8,0,4,0,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,1,0,3,1,1,1,1,1,2,2,1,3,5,1,2,8,1,6,8,2,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,0,0,0,0,1,6,2,2,3,1,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,8,4,1,1,1,1,2,6,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,0,0,1,0,0,0,2,1,0,0,0,1,2,2,1,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,1,0,1,1,1,11,2,1,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,1,1,1,0,0,0,1,3,2,0,0,0,0,0,0,1,0,1,0,2,0,11,1,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,1,1,2,2,1,2,2,1,1,1,1,2,2,2,1,2,4,1,1,2,1,1,1,4,3,2,1,1,1,1,1,1,4,1,1,1,0,2,3,0,1,1,1,1,1,1,1,0,0,0,1,2,1,2,2,0,2,1,1,1,2,1,1,2,1,1,2,1,1,1,1,0,1,1,2,1,3,3,5,2,2,1,2,2,1,5,3,2,2,3,1,11,3,0,3,1,1,3,7,1,3,1,2,1,2,0,1,2,1,2,2,1,1,1,0,0,0,2,0,0,2,0,2,0,1,0,0,1,0,0,1,0,2,1,0,0,1,0,0,0,0,1,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,1,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,1,1,11,2,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,1,1,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,2,1,1,0,0,0,0,0,1,1,3,0,0,0,0,2,1,1,0,0,0,0,3,0,0,1,0,1,0,1,0,1,1,1,1,1,1,1,66,17,14,1,16,19,18,17,5,22,68,6,10,2,3,5,8,1,1,7,15,2,9,28,3,7,6,53,2,2,1,2,3,5,8,5,7,2,8,1,2,3,13,6,3,6,1,3,13,1,4,2,5,2,3,1,2,10,5,3,3,4,1,1,0,0,0,0,0,6,8,7,3,3,2,3,1,0,0,0,1,2,3,10,3,2,1,1,0,0,0,0,0,0,2,2,12,1,3,1,0,0,0,0,8,4,0,0,0,0,7,2,2,3,0,0,0,0,0,0,3,17,6,3,2,2,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,2,6,3,3,1,0,0,0,0,0,0,0,1,0,0,0,0,4,5,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,1,7,5,4,12,6,7,3,2,1,1,1,23,5,30,11,1,2,1,68,9,19,2,6,2,2,100,5,1,4,6,75,10,9,3,18,1,1,2,3,5,1,1,0,1,4,2,0,19,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,5,1,0,0,0,0,0,0,0,1,1,0,0,1,1,1,6,3,1,1,1,3,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,2,2,1,1,1,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,2,2,2,1,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,1,1,1,1,17,1,1,2,1,1,1,2,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,1,1,0,0,0,1,0,1,2,1,0,0,0,2,1,0,0,0,8,0,1,1,3,0,0,0,1,1,2,1,1,0,0,0,0,0,0,1,1,22,11,1,1,1,39,19,22,1,1,1,1,1,1,16,2,1,1,17,32,17,1,1,2,2,1,2,16,9,34,3,1,1,3,1,2,3,1,1,4,2,0,0,1,0,3,21,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,1,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,3,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,1,2,1,2,1,5,3,1,2,16,1,10,3,1,5,3,4,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,0,0,1,1,1,1,1,1,2,3,1,1,1,1,4,2,2,1,3,2,2,1,35,41,4,4,1,1,2,1,1,3,1,2,5,15,2,1,1,1,2,1,2,10,2,1,2,2,3,2,1,2,2,1,1,3,2,1,1,1,1,0,0,1,1,0,0,1,0,0,1,0,0,5,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,1,0,0,1,1,4,2,1,1,3,1,2,3,23,35,7,1,1,3,24,5,1,2,1,2,2,1,0,1,0,0,0,0,2,0,0,0,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,1,1,2,1,1,2,0,1,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,2,4,2,2,3,5,2,1,1,1,2,2,1,2,1,1,1,1,3,3,1,3,1,4,2,2,5,1,2,5,1,3,8,4,3,1,1,1,1,1,1,1,1,0,2,1,1,2,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,1,1,6,5,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,1,0,0,0,0,1,0,1,1,0,0,2,0,0,1,0,1,1,1,2,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,4,2,2,3,9,1,4,3,1,5,3,1,1,1,3,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,10,15,2,1,1,1,1,13,1,2,2,1,1,2,1,2,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,2,1,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,2,1,1,1,0,0,0,0,0,1,0,1,0,2,0,0,1,3,1,1,0,0,0,0,0,0,1,3,2,1,1,0,0,0,0,0,0,0,1,1,1,9,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,4,1,6,1,1,3,1,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,1,3,6,1,0,0,0,0,0,0,0,0,0,1,1,1,3,3,1,3,1,8,37,3,30,3,3,9,1,18,2,12,1,2,2,116,40,24,2,4,3,1,28,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,6,3,2,2,1,1,1,3,17,6,21,1,8,3,2,3,2,4,2,1,3,1,2,25,5,13,12,2,2,5,2,7,8,2,1,4,1,1,7,6,12,2,2,1,5,6,3,2,4,17,20,39,16,2,2,3,4,5,7,19,9,5,12,7,2,30,11,1,2,3,2,4,5,4,6,3,6,74,9,1,2,3,10,2,6,7,20,20,26,3,41,7,4,8,4,6,13,28,17,20,25,21,23,55,1,1,3,14,12,5,5,3,5,14,41,7,1,2,3,10,9,1,5,2,6,3,4,3,3,1,2,3,1,3,2,1,1,2,2,1,0,3,7,6,3,11,0,0,4,10,3,5,8,15,1,0,10,3,3,6,9,0,0,0,0,0,0,0,19,7,5,27,0,0,0,0,0,0,0,0,0,0,6,17,12,0,0,0,0,0,0,0,0,0,0,0,0,9,30,1,2,0,0,0,0,0,0,0,0,0,0,0,51,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,2,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,2,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,1,1,1,0,0,0,1,0,1,1,4,1,14,16,4,10,2,1,64,10,1,1,1,2,8,7,12,6,1,1,1,2,1,2,0,4,1,0,0,0,3,2,2,1,0,0,0,0,0,2,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,1,1,1,1,1,1,1,2,1,2,1,2,2,1,10,4,1,2,4,1,1,14,1,1,2,1,6,1,6,8,5,3,5,3,7,2,0,0,0,4,0,0,0,0,0,2,2,1,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,3,1,0,0,0,1,1,1,1,1,2,2,1,1,3,2,9,1,2,1,2,2,15,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,1,3,2,1,1,1,21,1,2,6,2,5,6,6,3,2,1,18,1,1,5,46,57,28,21,14,7,9,3,1,1,1,1,5,10,14,3,3,1,1,3,1,2,4,2,1,1,2,1,5,0,1,0,0,0,0,1,5,10,2,2,2,0,0,0,0,0,10,7,3,6,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,7,3,5,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,1,1,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,1,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,1,1,2,1,0,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0,1,0,0,1,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,0,0,0,0,0,1,1,0,0,1,1,2,0,0,0,0,1,1,0,0,2,1,1,1,0,0,0,0,1,3,1,5,15,1,1,1,1,2,2,1,3,64,4,3,11,22,6,4,5,23,24,6,8,7,20,54,129,103,25,37,4,4,3,4,9,4,15,6,8,8,7,12,9,6,9,6,2,3,1,2,1,1,0,0,0,1,8,3,0,0,5,4,2,8,0,0,15,16,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,50,16,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,0,1,0,1,1,1,1,2,1,3,1,1,1,6,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,3,1,1,2,1,2,1,5,3,1,1,2,1,14,3,6,9,1,2,3,1,4,2,1,2,2,1,2,2,1,1,0,1,0,0,0,0,2,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,1,1,12,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,0,0,2,1,0,0,0,1,1,1,1,2,1,3,1,0,0,0,0,0,0,0,0,0,0,0,1,0,4,1,1,1,0,0,0,0,0,0,0,1,4,0,1,1,0,0,1,2,1,0,3,1,1,1,0,0,0,0,0,0,1,0,1,0,2,2,1,1,2,10,4,1,2,3,1,1,1,1,3,1,1,2,2,1,1,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,2,1,5,1,2,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,1,1,1,3,0,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,1,0,0,0,1,0,1,0,1,4,1,1,1,1,2,0,0,0,0,0,0,0,0,0,2,4,2,0,1,1,1,0,0,0,1,1,1,0,0,0,1,1,1,2,2,1,1,1,1,1,9,2,1,2,2,2,9,4,1,1,1,4,2,1,4,5,4,1,3,9,13,1,4,5,2,4,1,4,7,3,5,1,6,1,13,5,5,1,1,2,1,1,1,3,3,1,1,3,1,2,1,2,0,0,0,2,4,0,0,0,2,4,1,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,7,2,0,0,0,0,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,4,1,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,2,1,1,1,1,4,1,1,22,2,1,9,1,1,14,1,55,1,1,7,1,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,1,2,2,2,1,1,2,3,1,4,1,2,2,33,2,1,1,1,6,3,1,1,5,6,0,0,0,0,0,0,0,0,3,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,1,0,0,0,0,0,2,1,1,1,4,1,5,3,2,2,1,1,1,2,1,2,1,33,30,5,3,1,1,2,11,6,3,1,1,1,2,0,1,2,1,1,4,1,1,3,2,1,2,1,1,1,2,2,2,1,2,1,1,1,0,0,2,1,1,2,1,0,0,5,1,0,1,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,1,2,3,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,2,2,3,1,2,0,0,0,0,0,0,0,1,1,1,2,2,1,1,1,2,2,3,3,2,0,4,1,2,3,1,1,1,1,1,2,2,4,2,1,1,3,1,1,1,0,2,2,0,0,0,1,1,0,0,1,0,0,0,0,0,1,0,0,1,0,1,0,1,1,1,2,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,1,1,0,0,2,0,0,0,0,0,1,0,0,0,0,1,1,0,1,1,0,1,1,0,1,1,1,1,1,1,1,1,1,0,1,1,1,0,3,1,1,1,1,0,3,1,1,2,1,0,0,0,1,0,1,0,2,1,1,1,1,0,0,1,0,2,0,2,1,0,0,0,1,1,1,1,0,0,0,1,2,0,2,2,1,1,0,1,0,1,0,0,1,1,0,0,1,0,0,0,1,0,1,0,0,1,0,1,1,1,1,0,0,0,1,1,0,1,2,0,0,1,0,0,0,0,0,1,2,2,1,0,2,0,1,0,1,1,1,1,1,3,2,1,1,0,2,1,1,2,1,1,1,0,0,1,0,2,0,0,0,0,0,1,1,1,1,1,1,1,0,2,1,1,1,1,1,0,0,1,2,1,1,0,1,0,1,1,3,1,1,0,1,1,0,0,1,1,2,0,0,1,1,0,2,3,2,0,0,1,1,0,2,1,0,2,1,2,1,1,2,6,0,1,3,1,2,2,2,0,1,0,0,1,1,2,3,1,2,1,2,3,2,2,1,1,3,4,1,2,1,1,6,3,3,3,3,2,0,1,2,1,1,2,2,3,3,1,0,2,1,2,1,1,0,2,3,2,0,1,0,1,1,0,0,1,0,0,3,1,0,0,2,1,0,0,0,2,0,0,1,0,1,0,0,3,3,1,2,0,1,2,2,1,1,1,0,1,1,1,1,2,1,0,2,0,0,1,0,0,0,1,0,1,1,0,1,0,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,0,0,0,0,0,1,1,2,1,1,5,1,1,7,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,2,8,1,0,0,0,1,1,3,1,1,0,0,0,0,1,2,0,0,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,1,0,1,0,1,0,2,4,2,11,2,5,9,6,5,1,8,1,2,1,1,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,0,0,0,1,0,1,0,1,0,1,1,0,0,1,0,1,4,1,0,0,0,0,0,1,1,1,1,1,1,1,1,2,5,6,3,2,1,2,33,33,3,2,1,1,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,1,3,1,7,4,4,3,2,12,1,1,1,3,2,3,2,2,15,13,8,7,13,10,2,1,22,19,7,26,4,2,1,1,1,35,29,43,6,9,1,1,2,44,91,21,6,1,7,4,1,1,1,167,10,8,1,4,1,846,222,31,15,1,4,14,4,1,5,1,3,2,1184,153,19,3,7,2,7,9,9,39,24,6,9,7,6,2,1,1363,188,6,19,52,29,37,63,38,94,93,49,22,13,2,2,520,22,13,11,25,246,91,107,145,288,211,120,81,30,13,4,5,2,3,5,29,26,48,42,88,110,188,163,113,18,31,8,1,3,6,23,4,7,6,33,6,3,15,14,11,25,3,0,4,53,66,82,75,27,6,14,3,1,0,0,0,49,6,68,12,12,7,87,115,72,45,2,9,2,1,1,0,256,83,55,22,13,10,2,2,0,486,265,117,39,20,3,1,6,0,0,0,0,0,0,0,669,216,69,15,7,3,3,0,0,0,0,0,0,0,0,0,0,625,349,108,6,13,3,1,1,0,0,0,0,0,0,0,0,0,642,152,18,18,10,4,4,0,0,0,0,0,0,0,0,0,0,0,0,639,58,73,26,2,7,0,0,0,0,0,0,0,0,0,0,0,0,234,206,106,7,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,45,5,9,0,0,0,0,0,0,185,46,22,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,146,1,8,114,148,22,7,103,158,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,0,0,1,0,2,0,1,0,1,1,2,1,0,0,0,0,2,0,1,1,3,2,3,4,3,1,1,1,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,1,1,2,1,1,0,0,0,0,0,1,1,0,0,7,2,8,0,1,2,1,0,1,5,3,3,0,0,0,0,0,0,0,0,0,0,1,6,2,1,1,1,2,2,3,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,2,1,0,0,1,0,1,1,0,1,1,0,0,1,0,1,0,1,1,1,1,138,36,13,6,1,1,28,11,5,4,232,76,27,3,22,46,47,13,3,1,267,49,6,43,149,20,19,3,93,11,5,12,64,206,99,24,9,2,3,6,2,13,28,55,91,35,7,1,2,19,3,13,1,0,2,9,9,29,0,99,42,5,4,3,0,0,0,0,347,49,18,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,49,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,7,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,6,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,1,2,0,0,0,1,0,1,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,1,0,1,1,2,1,0,0,0,0,0,1,2,0,0,0,1,0,2,0,2,0,1,0,1,1,0,0,1,0,1,1,0,0,1,0,1,1,0,0,3,4,2,15,2,2,1,1,1,1,8,3,6,1,8,4,2,1,1,1,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,6,4,1,0,0,0,0,0,0,1,1,1,3,0,0,0,0,0,0,1,1,1,0,0,1,1,1,1,3,1,1,1,2,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,0,1,0,1,1,2,1,1,1,1,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,3,0,0,0,1,1,2,0,0,0,1,0,16,0,1,0,1,0,1,2,1,0,1,1,1,0,0,0,1,0,1,0,1,1,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,1,0,2,0,0,1,3,1,1,310,60,11,2,1,32,31,33,5,3,6,5,1,2,2,1,277,48,8,4,84,44,37,1,4,1,1,1,1,1,1,90,18,5,159,124,58,3,10,3,1,1,2,5,90,28,43,2,1,9,1,1,8,25,7,1,20,2,1,1,168,115,6,3,0,0,0,0,253,10,8,8,7,1,1,0,0,0,0,0,0,0,0,79,46,63,35,7,10,5,1,1,0,0,0,0,0,0,0,0,0,0,0,9,35,13,1,3,1,1,2,0,0,0,20,17,2,0,0,0,0,0,0,0,0,37,9,6,11,2,1,2,0,0,0,0,0,0,0,0,0,0,8,16,6,7,1,0,0,0,0,0,0,0,0,0,0,0,0,2,4,3,0,0,0,0,0,0,3,3,3,1,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,1,1,1,1,4,2,6,1,1,2,12,18,3,1,3,2,3,50,20,1,1,1,4,2,1,2,9,1,136,16,30,24,12,8,6,4,1,2,1,8,15,4,69,65,70,25,17,6,25,3,8,9,8,62,34,7,3,1,12,1,3,113,81,10,1,2,2,3,3,2,6,5,7,218,42,19,25,7,14,16,14,196,58,38,17,8,11,18,29,19,33,26,36,43,22,16,8,107,14,58,65,21,4,16,3,9,71,28,5,17,4,4,2,20,25,8,30,5,8,22,24,9,0,7,1,3,6,10,10,22,8,11,2,0,46,118,61,11,0,0,0,0,0,0,0,0,0,0,0,0,83,57,28,0,0,215,45,0,0,0,0,0,0,303,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,10,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,2,2,8,6,10,3,6,2,1,1,1,3,2,1,1,1,0,0,0,0,1,1,0,0,0,3,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,4,7,1,9,1,1,10,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,3,1,2,0,0,0,0,0,0,0,1,0,1,1,1,1,1,1,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,3,6,1,2,4,1,1,0,0,0,0,0,2,2,1,1,0,0,0,0,1,1,0,0,1,1,1,0,0,0,1,1,1,1,2,0,0,0,0,0,0,1,0,4,4,2,0,0,0,0,0,2,1,3,10,17,27,4,14,7,2,1,2,4,1,2,0,0,0,1,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,2,2,1,0,0,0,0,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,1,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,1,4,1,1,1,1,2,7,3,3,7,1,1,2,1,10,20,3,7,27,2,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,0,0,0,0,2,0,1,2,5,0,0,0,0,5,1,1,2,2,2,153,79,3,7,4,9,8,3,3,1,0,42,1,7,1,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,5,6,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,7,3,7,8,1,3,1,1,3,4,1,2,1,1,136,25,8,33,1,3,1,1,2,1,2,4,3,1,3,1,145,73,178,10,11,7,18,9,2,5,13,4,2,2,1,1,2,2,2,26,28,13,2,4,2,3,1,84,131,6,1,3,5,2,4,10,4,3,2,3,3,26,10,1,2,175,4,6,4,8,1,6,15,3,2,3,4,3,5,3,9,1,488,243,94,39,21,42,67,50,17,16,6,10,6,2,4,21,7,34,12,7,4,2,1,31,478,90,10,17,7,4,6,4,758,101,10,28,37,16,14,4,4,3,2,1029,63,50,11,15,9,10,3,5,3,3,2,4,2,4,6,1179,54,50,80,14,12,4,11,11,16,12,5,5,2,9,3,1202,213,42,24,2,5,4,9,6,3,2,4,6,8,8,1153,326,22,5,2,8,4,9,3,13,8,27,3,1514,70,15,17,9,6,7,34,9,13,3,3,32,4,19,6,1727,93,9,8,19,8,5,10,12,34,21,62,99,87,5,33,25,2,21,19,28,44,3,521,58,11,56,37,7,11,27,15,259,297,458,9,8,26,39,75,82,87,8,145,9,51,8,12,26,10,10,33,103,171,91,10,3,5,21,26,43,16,7,5,3,16,26,106,13,3,5,43,57,10,9,7,8,6,48,6,4,11,21,11,16,44,16,57,11,5,49,33,13,6,1,9,1,6,54,5,0,7,0,15,14,10,1,4,2,3,11,9,4,9,6,8,10,16,49,2,2,29,13,9,1,0,55,64,14,22,0,46,50,27,3,34,7,0,0,215,270,34,25,27,3,55,23,27,4,0,346,105,190,25,55,3,52,99,154,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,340,334,106,108,41,40,43,32,198,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,219,14,60,12,31,66,62,2,0,0,0,0,0,0,162,35,2,37,151,158,219,38,1,0,0,0,0,0,0,58,105,25,64,49,41,30,1,0,0,0,0,0,0,5,24,194,96,19,1,0,0,0,131,7,12,5,2,0,0,0,0,0,0,0,0,39,20,58,1,378,303,30,966,150,0,0,0,0,1761,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,2,1,1,3,3,2,5,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,2,1,0,0,1,1,0,0,1,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,1,0,0,2,2,2,4,2,0,0,0,0,1,0,1,1,0,0,2,1,1,1,0,0,0,5,0,0,0,1,1,0,0,1,2,1,1,1,0,0,0,0,0,2,4,2,0,0,1,0,1,0,1,0,1,0,1,0,1,0,2,2,28,4,3,3,1,1,1,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,9,2,1,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,2,1,0,0,0,0,0,1,0,1,0,6,1,1,1,0,0,0,0,0,0,0,0,1,3,2,1,1,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,0,2,1,0,0,0,1,1,1,2,1,0,0,0,0,0,1,1,1,1,0,0,0,0,1,0,1,1,0,0,1,0,1,1,0,0,1,1,0,0,1,1,5,4,2,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,3,1,1,1,1,0,0,0,0,0,1,1,1,1,1,1,2,5,3,2,1,1,1,1,5,2,1,2,1,2,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,4,1,0,0,0,0,0,1,0,1,0,1,1,8,1,1,1,1,2,2,1,2,0,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,3,7,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,0,0,0,0,0,1,1,0,0,0,0,1,0,1,0,2,4,2,0,0,1,2,1,0,1,0,1,0,1,2,1,1,2,0,0,0,0,0,0,0,1,1,3,1,1,0,0,0,0,0,0,0,1,0,1,0,2,1,0,1,0,1,0,4,8,1,5,4,1,1,2,2,1,1,0,0,0,1,1,1,2,1,1,1,7,3,1,2,5,11,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,2,1,1,3,1,6,6,1,24,3,2,3,2,1,3,7,6,26,1,5,2,16,32,2,8,1,5,3,4,1,46,5,11,4,2,172,4,14,18,35,51,56,156,106,2,12,11,38,19,44,85,105,5,1,3,12,3,0,3,12,4,7,3,0,0,7,5,40,7,0,0,0,0,0,18,20,20,0,0,0,0,0,0,0,0,46,32,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,4,10,1,8,0,4,0,0,10,0,0,0,0,0,0,0,0,1,2,2,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,1,0,2,1,0,0,0,1,0,1,1,1,1,1,1,2,3,1,1,7,1,7,4,2,4,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,0,1,0,1,0,1,1,1,0,0,0,1,1,3,4,5,1,1,2,5,2,2,3,5,1,4,2,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,7,0,0,0,0,1,0,1,0,1,3,1,3,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,2,2,0,0,0,0,1,0,1,0,1,0,1,1,1,1,2,2,1,1,2,1,6,25,1,1,2,1,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,0,1,0,1,0,1,0,2,0,1,0,1,1,1,12,4,1,1,2,1,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,2,2,11,1,3,14,3,1,3,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,1,1,1,1,1,2,1,1,1,1,1,2,1,1,2,3,2,1,1,1,3,3,1,1,2,1,2,1,1,4,1,2,3,3,2,2,1,1,1,4,3,2,7,2,7,1,1,2,4,9,1,11,7,2,1,2,4,1,1,2,2,3,1,1,1,2,3,2,2,1,2,1,3,1,1,1,1,1,0,0,0,0,0,0,3,2,0,0,0,0,0,0,3,2,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,4,1,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,1,0,0,0,1,0,1,5,1,1,1,0,0,1,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,3,0,0,0,2,0,1,0,1,2,1,1,0,0,0,0,1,0,1,0,2,1,0,0,0,1,0,2,1,2,0,1,0,1,0,1,0,1,1,1,0,0,0,1,0,1,0,1,0,4,6,0,1,1,1,1,2,21,3,1,1,2,2,3,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,1,1,0,0,1,1,0,0,1,0,1,5,1,4,1,4,2,1,1,9,46,52,6,1,4,5,15,149,11,2,1,1,7,1,6,11,5,1,5,259,84,27,4,9,3,3,24,32,133,28,76,36,31,6,3,1,1,55,45,7,5,6,17,8,54,3,37,166,76,20,1,9,9,23,45,23,53,10,21,1,15,34,5,13,17,11,6,16,2,14,1,10,2,4,2,5,2,1,10,24,3,22,6,4,0,19,2,6,9,0,0,0,19,65,104,22,25,5,1,0,0,0,0,0,5,2,2,12,96,18,16,8,0,0,0,0,0,0,0,0,0,0,0,258,74,5,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,14,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,18,6,3,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,0,1,0,1,1,1,0,0,0,1,1,4,1,2,1,0,0,0,0,0,0,0,0,0,4,0,1,0,1,0,1,1,1,1,1,2,2,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,4,4,1,0,0,0,0,0,0,0,4,0,1,1,0,0,1,0,1,2,1,2,6,2,1,2,1,2,2,2,1,1,2,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,4,0,0,0,0,0,0,1,0,1,0,1,2,0,1,0,1,0,1,1,0,0,1,3,1,0,0,0,0,0,2,1,4,0,2,1,0,0,0,1,1,0,0,1,0,1,0,1,1,0,0,1,1,0,0,1,0,1,1,1,2,2,3,2,1,2,5,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,1,1,2,1,2,1,1,1,5,3,6,20,10,15,1,36,25,1,12,1,1,1,1,0,0,0,2,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,2,0,3,2,10,116,2,1,1,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,1,0,0,1,1,0,0,3,0,0,0,1,0,2,1,0,0,0,1,2,1,0,0,0,0,1,2,0,1,0,1,0,1,0,1,1,2,2,1,0,0,0,0,0,0,0,1,0,1,0,2,1,0,3,1,1,1,1,1,3,5,2,1,2,2,8,11,2,1,2,1,5,43,1,2,2,1,3,2,0,0,0,0,0,0,0,2,0,2,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,7,1,7,11,5,12,2,3,1,1,34,17,2,2,9,1,3,7,20,62,2,2,1,3,3,1,1,0,3,1,0,0,1,0,0,0,0,0,0,1,2,0,0,0,0,0,16,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,1,1,0,0,0,1,4,1,0,0,0,1,0,1,1,0,0,2,1,0,0,0,1,0,1,2,0,2,1,0,2,0,1,0,1,0,1,0,1,2,0,2,0,1,0,1,1,0,1,2,1,0,0,0,0,2,1,0,0,0,1,2,0,1,0,1,46,1,59076,2491,1291,1892,1396,917,332,915,3747,2,50,494,403,222,138,1,116,534,1194,169,1,2,584,1064,1164,7228,2501,11205,931,3244,2078,1954,1489,7299,9291,394,1135,170,185,449,2893,1038,837,2225,734,1344,12661,1004,8810,58,266,1776,569,395,1596,993,155,1419,662,2721,531,940,357,726,1367,267,3337,456,707,2346,1865,918,333,268,221,1030,463,384,1278,324,525,1264,270,1523,7134,2450,7282,665,395,0,1137,1,12,8,494,1,402,169,568,223,3,462,393,139,385,1501,2,2,116,2,535,394,186,917,771,1566,162,507,1319,540,536,1,1037,1,1,983,1265,836,376,440,1683,170,1565,919,2,1,3,1944,465,2336,1392,131,1543,257,999,402,15811,30765,181,25666,643,99122,1,89977,85083,15041,2037,11,7356,7,771,1188,357,4,103,23,7,8,9,463,4,5,8,9,617,130,4,1,67283,16705,741,2639,1881,382,379,123,108737,8991,5020,18366,8013,2594,755,267,27,14,11,5,1,4,8,8,10,8,20197,26994,77151,1151,6583,4779,1187,42,2475,151,9,35,10,3,28,6,36,2,16,8254,19128,13,3449,1162,34957,756,1823,958,414,12,1375,14,13,6275,70417,37040,21361,2379,7324,6297,692,3039,1903,1135,334,612,35,29,613,13,11,12,507,16,8,56,5110,1943,1151,48347,31960,255,1589,993,7,1712,629,1281,1316,20,2303,1704,515,14,13,740,52,33,14,23,5,1297,62429,2354,15814,3153,1076,1934,1329,2580,826,4143,449,877,15,10,11,268,1285,847,11,3,219,10,861,14621,35127,31983,4356,2631,5840,4087,3997,3772,1100,1085,1486,470,1061,759,701,2624,404,10,655,76,1778,46,194,512,12,31,1938,88,5726,4681,1361,2088,22,2392,492,1334,550,964,26,24808,1851,12452,7826,2575,2827,4161,94,996,1562,247,443,385,5,325,259,1180,48,650,23,538,433,1423,915,8878,9645,7970,17460,4074,5511,3334,2135,2212,622,15,2047,664,778,1921,1188,126,651,3437,622,899,5,1389,32,49,19,364,6704,6005,655,541,6,1312,586,386,693,6981,8124,8272,3487,1137,1212,298,571,933,545,1189,321,647,1394,7940,2049,6556,25,2735,6587,9,3597,23,916,776,16,14,2639,19,804,652,2009,476,630,1362,712,638,14553,9913,98,259,3251,4172,355,1028,2146,1037,2013,3600,617,3207,954,729,503,360,45,6457,2924,6715,4422,469,6,2299,1198,2718,1523,28,2522,974,1612,380,2863,720,45,1031,23,7,3559,3606,4628,3744,3176,3736,1486,453,3203,32,961,247,1106,439,4259,4322,3051,628,524,2556,20,21,1533,384,18,8,2146,116,2125,660,7,1024,3558,26,81,883,15,11,510,498,746,1023,1377,29,260,1800,14,5940,1480,1069,450,1073,1674,1063,267,1960,2985,1326,422,2673,5250,1407,1471,543,1159,2846,3150,2044,335,1296,2711,10,990,876,758,471,1131,860,470,10,268,1961,3945,255,716,14,3162,623,4690,442,760,2300,3735,3271,11,1941,100,3,1378,1487,551,24,454,1031,702,1482,1379,2217,2384,1652,4224,13,1154,386,796,3736,875,1576,2046,8,759,31,1030,2715,7,611,421,1617,9,1830,276,1802,758,2882,843,2,762,11,30,838,11951,5614,297,792,2328,1084,1090,6,13,1960,13,2680,795,829,742,1187,462,1664,1470,26,10,1974,3192,2853,545,1471,547,26,8610,5060,1514,5935,1359,2818,3735,2300,16,491,5,15,14062,4359,12052,5284,6439,753,3003,477,6329,2228,1179,3519,27706,7240,8746,4206,13,1291,1324,1170,2597,9136,948,666,25,774,621,29275,13717,6,15343,8633,13,6866,3465,21321,1956,15098,661,7953,1353,11002,317,6575,42381,3137,6286,134,4772,651,9589,1394,13,3156,5,14311,55249,1299,24949,6282,0,8600,2453,8577,3695,21518,64715,17507,0,25216,4513,155585,0,97727,953,430,944,26,145,4,209,4,18,1,2,1,6,2,5,9,3,188,2,351,165,7,1,19,1,2,1,1,19,51,55,45,1,0,0,0,0,0,0,15551,38572,9059,2503,6589,582,1162,692,1387,867,156,2242,507,3821,358,496,1,2247,854,328,4,813,297,274,240,292,738,604,281,122,219,247,326,229,86,192,127,8,170,160,375,283,245,1224,414,59,277,182,0,0,8738,984,527,1405,652,957,357,1355,216,561,284,163,267,9872,1285,11001,253,386,2168,2911,1233,334,920,243,842,1328,230,1573,398,22,849,189,1130,118,393,351,170,461,1085,441,224,532,536,459,0,8,641,302,631,880,1646,1007,346,72,0,0,1064,7133,439,393,1650,550,3,381,1147,295,410,673,5,1401,3,422,663,481,116,774,681,167,348,602,12,0,1453,454,118,229,912,708,289,0,27,435,237,1,352,274,2263,719,2464,884,2170,3114,724,1160,890,418,1708,1084,610,1227,1014,717,193,684,373,1276,838,150,1176,233,377,155,0,891,891,526,3,36,273,117,250,498,662,1,392,691,1406,627,532,2610,1076,427,988,171,119,327,570,437,215,5,212,994,227,1235,371,398,0,272,531,211,3,154,0,3970,1269,675,1406,280,373,905,548,281,1104,494,6,0,1693,947,1850,356,492,406,232,226,350,289,3091,210,1190,1078,3451,426,1131,323,685,687,1,1257,13,898,126,448,2930,650,2828,529,495,499,2359,368,2,326,582,593,486,4,446,0,332,645,3,0,855,494,209,294,170,509,0,946,674,411,370,0,525,242,2510,524,721,388,945,537,321,118,0,0,271,280,670,3101,1003,504,911,374,466,2854,346,1095,507,643,0,647,229,1,1960,4218,1056,854,2,355,910,886,684,407,961,166,410,4,498,423,590,228,492,4,4,0,228,528,425,493,278,327,523,3,493,208,1068,116,381,498,441,1845,688,417,113,3,4937,1910,483,322,1203,841,225,720,1055,377,833,566,1209,2,347,239,0,527,2,1,2464,1252,595,1571,403,409,1570,117,485,365,645,362,1563,1029,317,371,7,6,0,503,839,661,1925,3671,123,2,686,273,218,387,85,3,492,482,870,1792,426,609,547,325,289,491,188,581,1,321,268,945,288,1309,231,290,3,354,561,481,664,660,2186,1011,2630,1,996,1129,322,373,116,0,838,1,1221,440,266,214,2668,236,885,467,402,803,943,0,226,909,881,162,351,113,124,0,0,1286,410,1121,153,1015,1846,424,0,721,277,664,3,0,1068,1836,1803,419,904,494,560,2453,710,339,2921,687,708,836,449,1076,1231,3008,1033,556,238,395,201,265,350,409,243,203,0,1398,962,436,608,522,235,485,923,376,682,310,22,482,0,583,546,492,451,884,668,220,171,466,462,152,1,903,940,145,345,683,481,1397,484,282,416,480,401,364,409,440,417,246,408,225,531,961,230,325,2166,1016,491,5,465,498,115,386,644,482,441,493,363,481,450,535,394,439,460,362,561,885,12,115,941,720,872,466,2889,2292,2909,447,407,1845,1128,3,643,191,1015,697,434,663,288,886,344,530,0,497,680,642,372,447,496,484,922,1396,360,480,126,338,321,34,1016,490,479,416,1774,407,1767,374,1565,1008,962,334,920,1446,496,14,49,448,1843,1015,695,834,919,1395,686,489,350,1267,937,493,0,1871,641,1401,225,162,359,640,151,1274,667,170,1352,718,415,483,188,2076,2738,322,835,682,3292,880,26,0,2337,406,640,219,695,159,393,125,1083,1885,187,674,838,726,149,0,3382,2743,489,1972,981,4494,7796,3765,836,119,427,7039,2564,3688,724,475,23373,4966,1330,2781,515,40334,3462,10215,3346,32569,26687,4497,38162,1663,84442,0,912,1,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,1,56,13076,2017,1817,1785,8331,246,646,107,4,263,200,2754,725,776,371,1694,442,884,831,6469,19024,45067,339,1182,26,1297,48,1259,1,9,9,4,2,1,1,1,1,1590,228,2302,1984,6824,181,13,12,394,631,437,565,327,1496,394,619,259,519,5,320,560,128,5208,4089,37,395,247,649,109,0,1,0,264,201,512,246,1127,1368,58,293,430,511,775,372,463,1964,32,2,441,883,832,561,1,127,229,2576,7450,21,33001,187,321,15,15678,3496,89015,281,6,172,15741,300,234,77,3679,4132,109593,2,4141,27,5939,122900,1613,3649,4757,1891,125,213,671,9,273,131,9,13,5,11,7,2,5,8,4,5074,486,788,42963,33721,44581,5463,921,516,599,12,16,129,20006,22036,2782,173,168,56735,4268,5,225,239,6,18,8,18,6,2,118652,3760,5316,1225,17,19,91732,33620,8504,62,111,18,71,19,4,25,83995,13066,8,124499,239,12,82,14,7,85299,67563,15,130,543,274,30,12,6,2,3,2,85110,125,84,61,184,7,19,45,10,18,84995,30074,37297,4139,208,554,13,23,28,23,136,8,18,24,48,24,29,5,14,41487,40340,2672,869,11,68464,2721,552,20,16,147832,14,2922,6725,12409,132098,5850,3724,149,1174,795,5977,547,371,30,151,20,4,72,12,1418,1507,209,8078,75,13563,39,299,40,91505,33744,2020,6009,5995,16744,86,890,108,92,64,51,64,50,6,3,58,30,68319,8675,7796,11926,368,471,54,15303,57203,32592,1108,14,11822,5578,105,81727,3140,168,78,2,10,8,17156,113890,1593,2738,127,204,36,14,25,24,75,16544,408,234,123860,44608,75,1541,346,15,132,184,98,32,114,55,83,74,37,124479,1520,264,174,240,233,327,84,24,14,23517,119205,30375,501,305,270,950,373,142,169,185,46,84,61,21719,1217,95,55,22,520,141244,54,1746,394,533,571,43,163,9,17,22,3440,134795,16003,18017,1301,79,975,551,167,85,114,19,2944,188,386,85975,52375,1514,581,291,224,27,100155,1989,748,34,688,143529,1547,24426,1002,2546,17,11987,127126,3513,7622,216,37,63,3,12753,935,100421,67223,7,687,1,68,4,13,2,26,66,104681,2,522,475,342,513,3,58,23,67,81,1,51724,139167,85,687,285,391,37,38,90,188,15,85,15,51623,154,37,187,30,7,39,79235,51830,57087,1865,18,832,1974,1052,218,23,42619,33856,2025,1126,261,322,1,130,521,3,91048,692,1005,2276,932,2,14,522,187,6,98675,28421,30783,20339,660,4677,13,4,378,52,38095,37554,26387,258,1372,457,47,25,14,69,51,19,45056,22459,135,1069,34,20,44,53,66,1,23,109601,205,6390,74,119,61,112,19,12,311,239,102,10,4,23912,157497,37,947,20,150,475,14,117,24768,52,263,137,5,33429,66877,83877,9910,382,1294,92,2019,769,486,36,264,55,33,67,269,153,123,145,35,50,55,15604,16697,773,158,171,113,331,68,67,4,78434,3087,473,418,290,32,14,27,4,150870,3011,11221,705,651,7810,4329,898,1008,481,66,523,5,8,28,27724,64789,7395,2703,417,53294,5688,2380,450,368,301,53,66,4,17691,549,383,9424,2593,505,48,25,9621,4978,2222,67268,6297,4524,254,419,193,113,48,11,1064,480,15585,570,485,115,1149,7396,211,522,15,4319,824,93,170,59,2641,126506,36442,684,1168,309,730,22,2639,144025,1746,3872,915,45,443,27,39,67135,101753,1410,13356,711,1820,5183,33,28,75,52,64446,514,3601,523,1025,1610,42978,97871,3609,11494,17252,45,69,20,38433,677,2237,3673,27293,75504,53405,95,97,13,27,74,26528,6306,70,41,119124,57,476,213,8,31973,15434,48867,15608,34869,6507,57317,601,219,972,249,64,43,254,3414,10105,6655,4471,2858,4354,158,58,6087,152,3757,1060,7967,10106,26816,7206,22376,12451,615,2957,14060,42,41,100,356,170,9,666,97,20,0,2154,15963,63012,196,69,520,262,275,33,2769,36216,77,191,119,48243,104144,43989,13959,387,214,218,13,36413,10717,1170,0,112098,28545,285,71,250,292,43,165664,2074,74,207086,3341,441,29,2087,182296,5262,1268,3271,4665,15974,33704,12212,28180,43336,69925,6211,7013,13049,12712,4529,5248,10658,17023,26021,83178,1,85869,1194,353,674,772,353,545,632,450,266,10,257,162,202,942,1,801,747,551,92,2339,6682,1784,1995,3555,93,817,0,0,0,0,0,4787,2235,1696,8724,1270,319,1310,324,251,307,839,258,625,381,2269,181,290,726,294,3263,220,635,230,176,2906,330,2078,876,2053,5762,24971,4463,6853,3224,125,5,395,961,230,331,266,739,480,122,1587,859,774,246,327,1453,180,189,248,265,1530,144,929,693,589,775,371,419,243,1876,560,679,3176,224,329,348,1,441,831,320,873,439,874,354,325,252,308,588,252,440,257,890,282,631,380,231,355,342,985,1671,397,451,267,180,230,245,289,247,229,15,692,256,587,545,326,192,2,4,326,108,20,684,201,439,404,1223,2237,885,391,90,219,514,992,0,229,341,737,370,479,242,251,586,418,465,685,1680,1026,344,202,571,227,992,5309,368,19,12,605,584,2662,304,121,592,2888,480,9669,1514,2435,479,21843,35493,15662,99,26801,6366,77069,46,27724,76923,27825,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,2,0,1,1,0,0,22,8191,663,638,708,121,192,198,31,206,274,125,127,73,162,151,47,2,2673,23019,6598,142,390,427,274,242,247,1820,4122,575,74,473,122,610,34,162,343,207,143,123,193,199,391,32,105,104,276,554,80,46,75,72,273,161,241,152,48,248,4,3941,737,36108,2,12496,5949,5448,4181,220,3631,597,1005,329,730,43,257,710,4913,876,1335,330,2761,5355,18368,27,2240,120,1815,1726,2228,1322,495,855,236,197,22,282,476,20,173,27,245,217,79,47,438,81,161,639,4811,2,1997,388,613,294,318,239,157,529,359,619,4504,517,642,377,160,183,250,400,1282,710,482,419,1506,793,2181,306,1,285,1104,210,1279,546,301,327,365,229,1129,1145,281,2,5,1,15,204,901,2,303,721,1105,166,1156,711,407,252,185,242,369,107,215,218,1499,1468,1610,2,295,309,4,164,353,319,487,547,110,555,672,492,192,330,442,288,464,105,3,127,28,302,240,62,2387,94,443,675,5280,524,347,129,1539,230,627,1,873,366,595,41,1008,4385,893,229,0,243,1,1104,5754,3117,32,698,64,267,19,2,354,321,317,3622,12723,972,900,3300,7118,4076,3950,189,967,2551,588,556,909,72,142,1403,639,333,6,952,372,626,1131,885,152,39,235,453,1908,0,1219,1105,8,1286,0,26,31,2090,1669,4354,1709,989,528,283,1623,321,1194,1870,2091,700,2,860,1633,304,429,227,1412,443,33,847,1,895,369,102,781,121,2236,2285,269,3,618,1007,449,60,685,0,0,3239,6717,834,855,1610,413,380,1092,2014,100,283,604,33,51,346,254,2,1147,0,5519,849,241,148,3175,331,623,899,1550,309,2035,1736,3238,1104,1633,1994,2010,4058,489,328,167,17,295,373,1,1,818,1519,893,1382,359,221,798,992,669,1859,297,1399,79,875,1230,247,3,372,112,268,1,307,1204,1342,406,246,442,53,989,6,539,111,1238,0,2833,2118,3338,772,2,190,3,383,1026,1010,212,256,710,251,3548,803,18,674,3,969,9,330,218,631,2040,4747,457,73,1136,306,1,170,715,818,247,2150,886,1933,1432,1396,2164,1883,669,979,447,1711,487,1513,1476,725,561,48,677,129,223,395,1701,4565,1,0,230,346,3,601,103,309,1246,423,5,73,311,863,1376,199,355,33,556,158,663,2,381,296,489,2214,1,238,782,1165,1093,333,166,6,655,578,117,500,304,948,305,356,1,488,908,859,190,56,2477,412,321,264,256,257,108,2,665,363,143,1391,380,1095,1286,449,981,168,2076,533,51,244,348,485,1682,894,411,197,8,270,292,1412,320,154,302,5,248,669,2479,248,563,2327,371,926,218,410,729,303,590,217,155,296,532,693,329,786,1632,390,858,562,980,218,576,2751,371,167,1512,857,1217,654,1284,107,532,1471,10,1002,1381,1511,325,562,4,388,372,1155,245,3063,627,218,1828,0,106,676,1741,3,831,1009,389,2461,0,0,0,0,372,1472,1075,373,3171,1063,3747,18736,47936,1,3,1,1,11,94,11,24,29,618,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11018,574,208,1208,297,424,230,751,440,630,158,88,472,434,108,52,65,64,45,122,122,70,20,157,17,598,75,42,444,186,235,41,263,153,109,608,188,115,387,184,14,2122,1051,2185,2206,5202,9081,0,0,0,564,90,1183,620,64,566,286,390,490,734,171,47,2224,352,542,482,1218,941,3,162,409,0,208,908,113,145,335,211,65,294,1,238,183,89,0,163,67,267,203,106,420,159,186,492,255,425,64,143,354,204,266,29,745,158,149,424,319,162,157,114,295,89,65,202,63,241,113,115,330,102,125,107,441,54,146,354,2,65,391,46,121,147,126,123,489,735,71,19,156,18,736,246,131,224,74,105,142,353,120,112,41,488,445,355,64,234,40,125,124,137,161,419,109,185,735,70,124,390,152,294,311,157,146,382,442,164,46,187,359,597,179,171,34,41,141,23,2435,906,1671,1295,85,180,969,1400,1453,3978,1641,4600,2266,23083,19,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,1,0,1,0,1,1,0,0,1,0,1,0,2,0,7,1,1,3,14,2,2,0,1,6,1,1,3,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,0,1,0,2,1,1,1,1,2,1,0,0,0,0,0,0,0,3,1,4,25,19,1,2,1,1,3,5,15,2,1,1,1,1,1,4,2,1,1,1,2,0,1,0,0,0,2,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,0,17,0,0,0,1,0,1,2,1,1,1,1,12,19,3,4,3,1,3,66,21,4,13,16,21,8,134,4,2,6,7,24,81,92,36,1,1,2,6,2,3,13,9,49,72,123,38,1,1,2,3,1,3,4,2,3,2,0,0,8,3,0,2,5,6,0,0,0,0,19,21,14,0,0,0,0,0,0,0,0,0,0,0,0,0,62,24,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,4,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,1,2,1,0,1,0,1,1,1,0,0,0,4,0,8,0,0,0,0,0,1,5,7,10,1,4,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,3,4,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,1,1,4,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,10,1,1,11,0,0,0,2,1,0,1,1,1,1,2,1,1,0,0,0,0,0,0,0,0,3,1,1,1,0,0,0,0,0,1,0,1,0,1,1,0,0,2,1,0,0,1,1,1,0,0,0,36,0,0,1,1,126,14,5,3,1,1,2,4,1,268,30,12,1,4,9,1,1,7,269,102,32,1,4,1,4,23,58,44,171,28,1,1,15,60,150,35,47,31,6,1,2,100,34,14,14,15,130,85,29,73,18,1,3,17,22,12,5,29,93,15,20,14,1,8,26,21,5,8,6,4,5,24,27,19,2,1,3,22,19,5,3,2,5,2,6,6,68,15,1,2,0,0,388,3,5,2,0,0,69,184,19,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,17,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,90,4,7,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,6,5,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,1,0,1,2,0,1,0,1,0,2,2,1,1,1,1,0,0,0,0,0,0,0,0,3,0,3,0,1,1,0,0,1,0,1,0,9,1,4,141,3,1,1,14,2,1,3,1,2,1,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,6,4,3,0,0,0,1,0,0,0,0,1,1,5,7,0,0,0,0,0,0,0,0,1,1,2,1,1,1,1,1,1,2,12,1,1,5,2,1,3,4,1,2,1,6,2,1,6,1,2,1,1,1,1,2,1,5,1,2,1,4,1,1,4,3,4,8,3,14,5,6,14,6,16,8,9,2,7,6,6,4,1,1,1,1,1,1,1,1,0,0,0,0,0,3,0,2,0,1,1,1,0,0,0,0,1,1,2,1,0,0,0,0,0,2,2,3,2,0,1,0,0,0,1,0,0,0,0,0,1,3,1,4,0,0,0,0,0,0,1,0,1,0,0,0,0,0,2,3,1,1,0,0,0,0,0,1,1,0,3,0,0,0,0,0,3,0,0,0,0,0,1,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,1,0,0,1,1,1,0,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,2,1,1,1,2,1,1,1,1,1,1,2,2,2,2,1,3,1,4,1,2,1,2,3,1,1,1,3,0,0,0,0,0,0,0,1,1,0,1,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,1,0,1,1,2,2,0,0,0,0,1,0,2,0,1,0,3,0,3,0,4,8,4,1,0,1,0,1,1,0,0,1,0,1,1,0,0,1,9,3,1,1,6,1,1,1,2,1,1,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,1,1,0,1,0,1,0,1,1,1,2,1,1,0,0,0,0,0,1,0,2,0,0,1,0,1,1,1,1,0,0,0,1,2,1,1,1,0,0,0,1,0,1,0,1,15,73,2,25,1,2,0,1,1,0,2,1,1,1,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,3,1,1,0,0,1,0,1,0,1,0,1,0,1,2,1,0,27,2,48,1666,118,340,117,88,92,41,4,52,75,87,65,74,120,128,805,11621,3974,209,12,1,941,751,120,59,243,43,49,71,89,93,42,3,50,48,0,0,0,0,0,0,66,3,0,0,55,12,73,122,123,8,911,23,15217,6,2,1,6,2,10,23159,1510,335,488,202,176,438,246,67,2,183,54,654,1,13,101,98,87,11,315,100,12,193,1696,121,372,1656,214,54,351,188,162,22,131,185,66,1829,9288,721,358,647,668,223,890,268,463,151,127,194,107,2,35,494,684,397,9,384,364,3406,221,3,54,52,95,760,1291,254,85,161,183,310,117,339,206,1377,209,4191,966,335,218,914,418,534,217,80,421,51,90,262,52,55,40,240,156,798,515,97,110,105,625,18,56,8,24,148,50,249,48,86,706,213,185,454,220,255,51,147,432,118,92,59,110,110,34,743,143,504,68,30,103,363,175,48,755,89,128,156,344,73,104,99,73,108,88,265,128,54,74,130,756,85,277,187,399,136,180,16,154,43,70,144,66,1,134,248,128,98,85,50,24,20,112,2,244,356,131,155,56,786,118,42,260,68,3,119,44,38,794,85,113,297,62,74,188,269,221,257,52,3,68,464,152,535,245,757,128,75,120,144,148,758,3,195,184,81,55,108,96,83,129,45,524,96,259,71,24,52,1,0,12,34,2,283,89,298,100,98,357,349,196,399,151,109,106,99,60,48,8,911,93,67,22,51,1,8,55,543,1,255,184,221,54,96,270,77,0,0,0,143,195,11,316,268,95,185,8,225,305,1,252,4,150,0,0,10,367,356,83,178,600,60,2,50,64,42,1534,83,583,320,461,109,271,203,78,929,4761,849,174,198,341,74,0,42,120,39,59,317,356,0,0,43,240,1,110,161,119,994,1546,597,0,51,117,74,88,107,224,74,304,46,2,40,42,56,0,82,92,235,358,194,176,288,335,48,75,154,525,0,138,120,32,75,0,98,426,2,160,221,90,120,455,93,2,84,78,2508,629,285,191,412,183,161,114,59,99,21,130,198,190,5595,669,1137,3935,99,260,80,620,410,287,1,38,187,53,760,310,92,137,598,82,1,204,204,32,196,343,1137,667,270,10,195,203,665,458,1484,3,143,937,1,79,485,412,51,514,537,387,400,132,59,98,503,202,767,613,134,86,4,61,59,10,53,1219,143,59,124,199,109,12,3,186,7,108,173,126,771,156,186,272,50,98,1,94,208,158,303,116,211,107,486,489,732,875,758,133,9,313,188,607,430,61,186,9,89,76,163,149,84,133,94,175,134,31,95,73,209,444,1489,1395,1,153,140,182,55,98,48,92,189,214,152,274,155,142,33,249,194,181,70,3,3,91,175,150,326,139,126,661,547,1,185,81,116,131,312,130,326,210,222,80,416,85,157,223,550,123,405,226,151,280,73,329,79,68,273,54,83,142,270,48,79,4,156,417,85,295,97,198,5,141,133,646,1,96,328,189,3,132,160,221,179,98,107,80,108,115,10,142,269,37,78,69,197,513,75,644,226,77,52,101,536,4,758,83,119,0,6,156,301,534,186,67,109,372,717,177,7,4,3,84,139,222,47,272,173,91,389,75,295,162,174,3,59,34,58,114,1134,358,152,67,168,83,964,182,533,401,247,58,33,90,49,139,0,512,674,317,113,511,208,157,171,1142,666,849,108,87,103,226,397,332,264,51,42,31,107,757,2,806,756,4419,156,103,8069,1319,12,0,23015,21,12,57,24,314,0,0,0,0,0,15289,32,8,31,34,17,0,0,21,3,69,1,2,267,782,116,765,388,2012,0,0,0,0,0,0,0,0,0,0,0,952,54,110,289,36,149,26,449,215,187,433,202,66,815,684,921,1715,2875,4392,0,0,0,48,74,36,4,115,25,101,103,338,122,6,47,32,55,109,51,129,76,38,106,2,35,16,4,1,2,81,66,35,20,25,42,121,281,2,41,68,214,11,51,134,174,88,132,33,46,153,46,0,69,232,263,160,201,625,500,678,306,498,1036,650,452,0,2161,3125,0,7050,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,1,0,3,3,0,0,0,0,0,1,0,2,1,1,7,12,3,1,3,1,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,1,3,2,0,1,0,0,0,0,0,1,0,1,0,1,5,0,1,0,2,3,0,0,0,0,1,1,1,0,0,0,2,0,0,2,1,4,2,0,0,1,1,0,0,1,1,1,3,1,1,2,1,2,1,1,27,17,23,13,1,2,1,2,3,3,19,8,22,9,1,22,15,9,1,4,16,18,18,2,32,12,3,1,2,5,9,26,19,3,4,15,7,2,2,2,5,9,5,2,18,52,54,3,4,1,4,3,16,21,43,5,2,6,7,14,2,3,1,1,5,3,4,1,5,7,5,2,1,9,2,6,3,10,4,0,6,1,5,2,0,38,12,2,0,0,82,6,3,0,0,0,0,0,0,0,33,8,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,1,1,3,0,0,0,0,1,1,1,1,3,2,1,1,2,1,0,1,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,1,0,1,0,1,1,0,0,1,1,1,1,1,2,0,1,0,0,0,0,1,1,0,0,1,2,16,319,634,932,168,211,185,67,44,95,2,9,109,2,57,74,33,109,791,357,393,10060,6209,1,1,1,81,127,117,153,143,152,179,21,137,134,83,273,479,300,15,166,49,187,153,69,45,96,0,1,110,0,58,77,32,62,132,193,10,775,311,20,152,9,23,13,173,327,153,316,187,13162,63,6,2,91,12,185,6009,1152,327,356,456,523,410,1267,1095,571,217,553,73,48,8,415,622,191,619,7,257,186,179,45,1333,1046,578,149,621,705,76,981,777,1478,256,997,138,449,2400,915,1249,600,185,725,193,288,1,75,258,719,174,156,55,106,923,6817,277,419,80,145,200,115,174,388,112,851,208,67,471,270,184,129,85,88,281,6,422,148,88,194,665,141,281,109,278,168,5,84,2,132,212,36,202,56,155,72,266,1,80,81,116,163,221,143,96,134,193,155,45,146,82,245,87,203,406,127,1,23,137,344,142,101,87,201,110,358,91,260,3,165,225,183,398,2,188,4,61,3,189,141,348,92,218,271,98,137,51,74,49,182,7,190,2,47,87,94,30,289,104,206,81,191,359,93,78,64,52,223,167,144,115,110,156,284,245,108,6,255,795,82,97,46,365,94,91,10,66,162,113,147,77,164,24,208,73,253,870,573,53,243,535,58,33,124,293,48,160,61,149,617,113,252,170,90,360,10,24,60,4,207,0,1,76,12,92,29,107,249,111,145,803,390,54,306,109,167,0,40,270,38,2,0,288,113,62,27,768,192,22,73,1,89,93,75,385,129,136,366,120,141,202,260,0,0,106,55,68,150,97,5,198,180,116,251,112,244,292,2,46,239,62,73,120,199,4,38,398,78,664,651,495,103,5,281,176,315,0,21,0,53,37,250,75,0,133,219,52,28,174,148,608,634,776,305,4,139,166,244,192,351,0,87,546,216,290,502,334,237,118,56,1894,2228,1194,118,158,478,488,322,143,117,71,158,10,90,155,166,690,1209,857,156,271,869,5,278,348,164,323,137,143,93,194,321,151,643,1951,173,247,88,959,225,337,630,220,868,193,239,247,101,217,51,107,247,67,904,882,267,656,445,534,361,347,297,341,204,65,155,148,179,161,114,158,359,483,1040,595,98,155,208,123,119,302,81,299,309,378,59,590,80,2,78,166,74,229,2,244,859,248,118,473,664,4,91,168,351,88,131,99,116,10,198,808,843,51,91,118,598,112,90,340,1071,285,332,201,280,83,61,344,8,44,178,75,142,186,2189,104,58,267,57,82,167,258,277,302,0,38,428,589,285,121,215,359,131,546,122,118,39,16,1279,340,117,107,146,126,193,67,417,152,114,212,159,311,273,208,121,220,23,23,6,134,122,2660,2,3,118,89,590,245,139,116,72,148,297,223,214,745,4,59,194,5,129,266,214,267,343,246,167,192,154,142,222,145,56,565,117,135,596,1,342,173,159,351,113,147,228,211,254,43,118,245,246,349,112,56,649,244,168,227,310,221,403,272,91,63,423,789,60,673,243,193,105,88,128,589,325,242,425,120,485,1075,293,165,241,506,926,1,496,23,549,1069,0,0,119,680,161,6946,11308,122,15,621,178,38,95,302,60,253,1,48,24,76,46,57,53,145,140,361,511,237,815,3452,140,1547,0,0,0,0,0,0,0,0,0,219,140,411,586,212,51,528,172,52,177,234,224,69,96,1861,519,1178,3038,201,1140,0,10,75,210,33,139,14,134,24,138,69,61,95,70,74,432,26,28,71,36,133,67,191,296,14,70,0,39,108,11,103,57,94,65,52,40,212,271,99,56,139,109,84,36,67,134,36,22,70,139,171,55,170,0,51,47,23,95,46,80,75,39,60,118,89,35,47,170,118,94,225,234,56,36,134,192,81,6,186,37,205,261,55,149,522,595,1573,137,296,1005,111,169,3859,39,364,1218,13780,0,1863,29,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,1,1,1,1,1,1,2,1,0,0,0,0,0,0,1,0,2,1,0,1,0,15,2161,241,76,36,343,5,2,5,4,778,5196,9298,1,7,531,838,823,218,25,77,37,345,6,0,1,0,1,945,604,7494,6606,2095,701,1704,707,158,53,1230,269,397,33,629,31,63,94,62,115,49,131,124,83,99,3,178,777,296,190,435,517,769,1123,433,261,439,1186,4131,136,78,997,811,1238,373,263,577,276,1,176,90,47,43,75,250,4552,767,875,386,623,49,75,45,171,80,330,32,184,508,863,190,125,226,100,109,251,691,5,460,384,48,166,103,688,244,114,98,93,30,460,154,260,174,696,181,117,270,575,135,387,74,82,47,309,379,93,286,17,71,3,397,45,84,4,84,55,480,54,576,307,110,44,74,204,146,620,45,51,178,90,79,85,108,174,225,34,632,32,64,95,63,116,50,385,132,125,261,124,5,212,3,51,43,48,2,76,60,116,2,148,140,314,49,59,116,9,34,172,690,78,398,220,0,0,6,52,170,49,52,55,296,6,26,66,149,234,3,80,3,2,38,81,219,340,635,3,242,87,156,83,304,73,76,426,36,180,0,43,42,313,1252,53,290,49,207,12,202,106,55,23,64,139,108,206,812,67,83,46,49,189,81,49,84,44,33,212,798,71,43,109,123,60,1522,591,22,137,204,153,81,77,90,9,1684,574,2509,2504,2314,914,607,530,108,206,60,218,119,244,149,70,541,96,90,75,362,435,937,175,583,154,262,52,693,178,2,2,137,176,763,1722,1358,127,215,418,317,145,122,303,26,157,3375,1119,980,540,456,90,67,51,73,74,79,897,1654,1909,1811,976,441,234,572,307,219,115,222,409,179,19,64,203,100,74,38,34,1346,1041,825,223,100,263,230,69,5,1,795,143,84,142,91,713,1483,561,179,128,246,98,1136,90,254,47,385,58,138,235,999,402,701,1007,199,72,126,796,829,242,86,67,110,166,3,1569,695,106,1048,47,260,531,83,43,498,852,336,540,68,210,154,38,188,213,2,84,113,909,460,19,160,433,53,68,1213,327,147,121,148,2,311,213,270,49,320,2315,99,120,80,50,327,189,69,244,683,179,115,117,575,371,83,150,107,127,93,106,109,144,119,1400,80,74,120,114,89,33,121,119,148,115,197,215,262,116,310,574,73,148,652,5,309,143,88,127,205,212,476,2880,122,178,124,110,230,81,301,95,589,585,4,386,87,142,21,573,63,80,572,191,109,212,99,88,308,272,52,229,174,211,126,49,80,223,416,465,74,125,925,1023,306,399,495,79,385,4831,7952,505,37,36,24,111,84,282,112,33,58,0,0,63,9,146,127,45,439,581,7191,0,0,0,0,0,812,60,76,88,104,125,195,42,205,66,120,20,37,66,82,571,675,4429,0,68,67,128,75,70,24,870,59,19,20,75,35,25,69,112,88,66,191,283,235,360,57,3,34,10,4,18,76,41,204,65,74,119,119,19,37,142,31,158,207,30,1115,1604,20,18,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,4951,337,267,306,138,348,64,501,3,92,1556,539,515,8341,9154,1,61,488,84,718,161,46,1984,1497,74,329,149,410,204,183,128,139,244,107,63,218,289,4,93,85,150,1355,1029,555,303,145,426,13974,10123,3442,969,2388,2536,358,986,444,1174,2230,929,1521,419,228,35,954,485,326,26,972,328,481,2,110,98,110,294,2,486,1247,7549,7,484,65,2067,4414,174,12,391,411,1508,788,680,2,286,54,57,346,139,307,1176,1,1,113,285,560,252,125,927,93,1049,115,718,32,498,635,246,331,1997,215,90,516,693,89,319,46,100,150,177,122,906,227,314,152,282,115,2,2,395,197,114,482,98,234,256,178,246,128,398,2,331,200,196,148,313,27,954,1,261,410,196,54,253,407,3,608,223,283,1188,503,246,235,161,133,67,254,228,272,257,434,170,638,162,12,166,126,43,127,243,78,266,292,565,284,486,196,184,273,219,1111,224,796,107,139,107,133,266,170,270,258,4,94,95,153,463,188,19,90,10,57,394,472,769,39,1134,93,151,191,128,661,57,191,116,719,122,197,108,149,36,116,205,186,297,320,34,9,214,499,136,59,354,166,314,162,259,167,27,260,55,700,222,500,395,206,5,218,269,103,185,85,691,609,1,453,1,396,184,3,105,720,7,470,171,153,28,228,42,2,597,703,2,0,134,274,111,28,266,1,121,87,962,160,297,75,277,2052,719,338,459,7,94,124,151,1354,521,882,5527,8394,10,271,2097,374,1886,368,491,343,454,234,371,50,201,6,63,1071,218,1348,587,3,9,238,161,293,563,176,2,6,0,9469,175,644,131,863,304,873,282,58,89,277,68,106,71,19,231,726,3159,1454,3556,7771,2742,2301,589,1316,1170,765,828,1383,59,124,96,145,112,290,288,213,877,351,11,426,40,58,124,65,1056,1170,691,855,238,0,81,440,2,5,1684,1665,309,1663,44,39,269,187,225,284,3,28,308,4065,617,1905,90,205,263,77,271,118,300,3,374,566,6286,3863,366,373,105,929,1487,1679,466,29,183,666,452,168,17,296,5,10,156,1885,4590,58,556,811,647,1580,765,1202,300,110,190,261,204,128,274,46,26,256,1054,2928,2367,1369,2239,1870,1740,723,350,251,72,391,77,517,169,3,2133,602,1205,1403,467,191,57,3,68,818,458,1403,222,1,216,249,75,250,54,418,847,1036,821,1303,124,43,71,206,64,658,105,57,1218,1930,2292,490,98,16,237,134,270,439,390,46,27,509,2265,4183,762,347,325,424,567,265,172,855,131,109,369,5,258,465,476,2571,2542,93,730,159,604,98,117,175,290,1172,189,491,251,726,173,565,6819,590,134,335,87,340,233,253,167,123,164,355,289,3,153,203,3783,125,459,201,826,135,177,135,167,253,225,301,1292,160,359,131,192,491,169,71,315,70,577,490,248,813,339,174,184,165,127,232,331,567,269,251,118,152,252,110,173,203,725,202,173,2179,205,67,265,278,16,499,750,183,291,53,1050,163,549,494,722,133,614,1601,595,277,123,190,2045,415,382,250,182,414,1595,168,249,844,181,932,1003,66,898,580,687,1398,1612,5933,13684,656,643,12,80,13,8,254,17,52,60,91,92,927,52,12,191,4,138,192,102,64,136,62,570,1438,1060,1659,496,4736,0,0,0,0,0,0,0,0,0,0,0,0,0,338,243,173,204,49,359,122,156,420,59,242,1194,56,149,113,107,269,252,243,289,455,567,695,1932,770,3962,169,72,67,254,38,143,132,106,113,178,84,242,48,209,13,73,98,62,140,79,14,160,10,169,140,215,112,147,16,121,155,53,456,132,61,60,92,241,91,83,26,149,220,418,147,184,389,805,51,9,3,55,40,20,79,148,122,82,78,77,3,66,112,161,78,12,102,226,178,0,91,74,91,145,97,60,87,77,251,121,220,405,262,57,117,574,72,810,283,393,539,1311,518,1368,0,1612,317,1539,1555,6959,4756,21,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,3217,4391,335,135,371,82,134,32,10,147,144,95,45,21,979,5411,11445,6715,835,169,22,7,1,996,218,373,791,441,388,46,89,210,477,168,905,2357,1094,138,1,337,184,43,99,274,430,83,136,33,1,3,148,145,476,93,2,46,22,1698,321,8483,821,101,1,3,25615,920,147,224,6,145,41,1,73,507,10,62,398,31666,2016,90,104,302,56,138,230,121,185,436,54,134,82,169,30,119,44,495,39010,383,27,5,8,4,11,3,381,386,167,3,57,56297,101,3,29,96,40,3,2,137,4,90,489,244,257,49,55,1,209,156,113,15,263,46687,1274,430,2362,253,113,218,330,12,174,77,113,318,104,82,160,955,21,176,358,817,2469,259,359,9,62,434,75,148,13,132,87,242,230,136,70,706,14912,3358,5612,1817,972,429,519,1008,603,1201,781,934,185,116,2775,11,667,711,348,311,1345,216,458,2552,2117,169,723,360,193,311,477,96,93,4,6,146,902,3001,4938,6,157,94,893,301,1422,154,347,126,378,473,4,200,22,879,1252,319,677,47,219,229,84,58,2607,71,617,182,259,187,734,264,251,9,45,299,629,227,3,551,12,31,163,2888,577,818,1411,1184,15,120,1129,1423,336,228,166,381,1324,703,1180,129,79,98,316,268,115,231,10,358,381,254,64,116,26,7,164,2,25,17,1222,1194,239,455,245,90,180,143,1842,697,253,230,183,722,460,400,218,120,411,594,226,20,1700,260,232,2195,310,161,425,331,73,13,302,373,139,235,481,183,175,275,388,308,78,133,343,812,188,124,1195,598,482,3850,303,299,240,117,71,44,1365,1582,344,3275,238,1972,1562,1230,1063,144,226,163,532,222,12,2,42,254,104,83,669,1276,231,91,262,155,265,337,456,385,1680,101,61,311,416,278,184,89,167,1021,145,741,595,345,289,304,5,347,2,244,0,836,536,313,417,63,22,176,342,106,2714,2258,1945,1738,660,266,4,339,235,113,183,811,3,95,343,119,438,46,89,490,107,3898,2892,157,116,284,199,13,202,319,174,243,10059,2687,1092,74,383,579,117,247,159,751,98,286,399,166,89,357,1905,7421,8987,548,2014,1843,407,715,1008,998,984,570,334,199,687,1490,293,153,144,132,178,85,66,501,1234,531,272,462,618,348,219,170,5019,1873,3687,715,1079,926,1366,154,700,822,537,572,118,368,422,1825,5494,2455,576,1112,388,771,494,5,2071,613,206,177,314,184,228,127,1638,1372,382,88,76,4,194,462,10,72,3376,637,2577,1593,1382,816,238,111,272,161,191,70,141,705,3176,1564,2375,1749,1267,534,748,979,453,227,155,474,2148,1375,1284,161,104,203,1532,1278,2330,1179,1482,352,613,102,189,116,256,42,54,315,2268,2172,1138,679,1345,267,169,210,169,304,243,63,183,822,3376,417,1110,1262,816,593,69,147,242,64,202,90,2431,3702,1263,3039,1806,696,610,336,94,491,79,8,133,374,167,2658,1483,1180,1294,1961,322,81,347,147,156,250,237,105,220,1219,1306,1147,386,538,10,962,335,20,535,822,1194,3511,345,789,386,231,441,264,633,226,293,303,202,183,162,283,35,62,716,4633,924,1048,724,131,478,257,715,267,153,439,123,73,684,284,81,82,518,401,137,1098,5068,165,735,1201,131,1282,162,383,92,261,678,630,990,1036,164,323,801,471,207,312,266,308,228,118,1323,385,80,129,533,1202,157,479,181,130,230,256,479,479,1035,424,1283,95,168,280,206,472,1444,85,384,386,537,103,265,289,412,1203,276,1147,169,701,313,281,195,313,1284,311,1878,170,845,304,248,314,236,158,305,383,263,315,306,1097,240,417,778,244,282,521,196,373,385,243,1156,197,228,322,63,523,1668,2547,267,1481,2328,2627,227,2786,10141,19128,2036,304,1,203,183,94,115,93,57,209,3,107,2,136,71,467,277,856,46,925,598,217,496,82,72,89,186,3,157,521,122,49,64,20,45,484,108,285,330,4753,0,0,0,3762,1112,81,392,83,259,310,1137,71,696,183,1354,53,449,222,748,161,768,1107,43,184,177,1,390,89,44,60,288,83,212,262,463,3649,143,325,331,113,367,303,206,233,82,43,145,259,200,90,548,90,22,83,69,42,266,1789,347,416,252,401,0,0,80,86,227,37,229,239,216,86,77,57,95,332,84,260,112,78,470,133,213,588,45,401,9,304,78,2,86,137,109,56,38,98,111,110,302,106,184,130,105,105,261,83,83,108,77,91,149,388,599,57,150,110,262,137,78,96,113,126,87,589,465,338,81,31,55,49,36,501,185,113,305,150,138,478,510,189,161,167,1303,119,551,68,359,289,205,923,149,124,297,143,807,1208,430,89,108,182,129,199,216,12,593,343,635,286,169,80,512,111,170,93,186,175,2146,648,1640,334,118,264,533,98,757,636,138,251,637,82,89,124,21,638,176,37,87,458,534,148,415,158,155,148,56,71,305,199,1629,556,153,227,8059,2362,333,146,118,645,2494,2414,6531,163,1077,324,511,4460,4483,147,107,43,331,124,104,374,110,170,263,344,510,19,166,250,637,220,305,149,595,224,117,851,1139,167,1253,4931,4146,17200,93,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,3,1,2,1,1,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,2,3,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,1,1,2,1,2,1,1,1,2,1,3,5,14,3,3,2,1,31,2,0,0,0,0,0,0,0,1,0,0,1,0,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,8,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,0,1,0,1,0,5,0,1,0,1,1,0,0,1,0,1,1,0,0,1,2,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,1,1,1,3,1,2,2,1,1,1,3,1,1,5,1,1,1,3,8,1,1,1,1,24,1,10,76,21,18,7,4,2,3,3,7,14,219,2,83,10,6,3,7,12,27,4,10,2,2,1,64,14,5,2,61,7,1,7,5,1,45,6,5,8,9,34,12,12,5,26,2,40,4,17,4,2,3,41,6,23,3,1,3,9,3,1,0,2,0,2,0,0,4,8,0,20,0,0,0,46,79,21,10,1,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,13,3,0,0,0,0,0,0,0,54,22,6,0,0,0,0,0,0,0,0,0,0,37,14,7,0,0,0,0,0,0,0,0,0,11,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,0,1,1,1,1,1,1,1,2,5,2,2,1,2,3,1,2,1,1,1,3,1,1,1,1,11,9,1,1,9,1,31,3,1,4,2,4,2,3,29,4,16,8,12,11,2,6,7,6,11,72,19,1,1,1,14,3,1,2,3,4,6,4,12,12,7,3,12,1,1,15,3,3,20,2,1,2,1,1,1,0,0,1,0,0,0,3,7,0,0,3,14,2,2,1,0,2,0,0,3,16,3,0,0,0,2,0,13,4,0,0,49,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,1,2,0,0,1,0,1,0,6,5,1,1,1,2,1,1,1,3,1,7,1,2,1,1,1,2,2,1,1,4,2,7,2,1,2,1,1,2,4,2,2,1,3,2,3,3,2,3,2,4,3,3,1,1,1,1,1,1,1,2,1,1,1,1,3,1,4,1,1,2,1,2,3,3,5,1,2,5,1,1,1,2,3,2,1,3,2,2,1,1,2,4,3,2,2,1,3,3,1,2,2,3,2,2,8,1,1,3,2,4,1,3,3,2,2,2,24,3,2,5,5,1,5,2,1,2,2,2,0,2,2,0,2,1,2,2,0,1,1,0,0,0,3,0,0,1,2,3,5,1,2,0,0,0,0,1,1,1,3,0,0,1,2,1,1,0,0,0,2,1,0,3,0,5,0,1,0,2,0,0,0,4,1,0,0,0,3,1,1,0,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,5,0,1,6,1,1,1,2,1,2,1,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,2,1,1,1,1,1,1,1,1,3,4,1,1,2,1,2,1,1,1,3,2,2,2,1,1,1,1,1,5,3,1,1,1,1,3,4,2,1,3,0,1,0,0,1,0,0,2,0,0,0,1,0,0,1,0,1,0,0,1,0,0,2,0,1,0,0,0,1,0,0,1,0,0,0,0,0,0,10,2834,1571,201,371,543,53,1613,237,114,7,222,262,200,243,3639,23678,3574,4,2,38,79,1410,1346,27,1583,148,58,377,316,232,54,24,241,1015,372,5,0,2,19,0,0,0,0,0,0,0,0,0,2,113,8,1,221,261,201,447,5506,145,36478,17719,2329,6175,2604,5630,405,2129,2966,1630,2103,1761,214,217,32,123,395,829,878,288,4,399,330,1,254,58,530,1829,3747,304,4235,2389,1870,1193,244,822,66,434,1014,218,359,459,317,1418,151,526,317,4,263,239,1142,3290,883,924,2430,734,897,456,750,421,195,1590,293,736,202,545,665,57,37,661,365,2321,1438,90,55,427,161,139,47,7,112,173,836,62,571,276,484,205,493,302,239,227,468,1524,1073,453,918,668,250,184,649,444,2,2,317,1107,5,194,151,265,120,875,12,501,62,572,541,482,183,857,1135,175,631,16,1246,370,1075,338,415,342,481,336,293,678,486,176,522,135,306,277,17,231,286,1,149,392,72,784,500,1,180,63,192,1120,373,573,267,109,2,360,458,540,195,661,785,456,265,375,224,1059,1603,600,487,367,193,547,206,20,347,982,206,607,89,560,339,598,255,541,217,146,351,1501,251,37,203,458,786,177,463,598,1068,139,280,196,167,574,483,494,215,459,208,542,553,268,185,3,573,2,30,650,2,337,124,218,397,853,1092,177,303,483,228,267,607,1538,445,241,294,679,484,695,276,214,775,147,484,110,203,5,854,207,546,401,331,1151,90,58,1,1,1,2,38,96,160,605,225,57,209,855,208,753,209,2,6,541,1429,452,543,447,277,75,621,200,1219,4328,2086,656,25,158,293,13,560,133,196,46,1004,3,168,594,1285,161,305,319,416,6224,5042,462,1516,1849,1529,1286,862,5,231,1418,546,662,1564,2524,459,551,280,136,157,829,2973,525,990,1825,1380,1125,1092,119,297,796,677,790,32,257,362,318,343,817,26,1680,1881,480,542,2235,111,674,953,468,226,990,614,682,194,512,37,162,677,163,1206,324,816,390,756,148,519,229,140,256,677,649,40,704,330,4,92,370,187,1781,564,418,268,170,972,87,673,260,1491,795,367,822,180,918,538,3,11,134,419,1890,340,1,138,355,925,1071,378,74,104,252,316,2,57,240,1522,604,577,212,320,638,10,129,193,1071,2459,1131,896,1305,100,795,1685,604,270,84,298,141,1122,42,112,2002,176,1006,2,1560,526,777,367,954,1002,43,0,434,126,465,1811,1682,760,260,40,789,107,245,134,1103,742,119,1340,0,560,1893,2468,987,150,178,461,175,239,781,124,575,2036,155,1071,197,989,3,181,198,5103,3064,4,594,660,6,437,462,210,1410,3526,19,0,5611,466,486,267,524,0,694,344,58,116,375,1139,786,716,240,605,136,2861,6616,33,22,735,672,380,777,143,464,631,780,229,471,180,1526,446,93,3059,7454,66,388,817,485,396,741,268,5,114,1,352,523,149,194,1275,772,257,381,525,285,226,333,850,193,507,865,585,819,36,684,723,267,436,820,485,467,115,376,630,522,484,1718,195,464,1098,978,2291,2,0,227,789,294,1562,316,621,1415,631,663,1425,1765,154,252,192,419,664,123,92,103,937,209,509,155,367,297,20634,33280,3201,35,43,80,100,66,101,133,2,0,2,139,157,200,92,12,2462,0,0,0,0,0,0,0,0,0,10549,297,240,321,132,216,1694,230,131,57,260,58,457,72,217,521,188,524,185,482,175,169,507,501,65,209,903,557,351,296,1561,10606,0,1560,9,315,284,1015,63,270,87,99,280,693,8,22,8,259,137,117,48,3,149,476,46,300,1215,5357,0,0,0,0,0,0,40,11,53,240,65,104,998,0,0,293,42,241,292,219,42,102,131,79,314,220,86,417,142,65,86,10,367,207,673,1488,0,0,229,132,100,56,261,59,52,455,71,64,228,510,86,218,80,98,221,158,500,279,187,64,240,79,220,239,6,87,45,171,88,44,1212,184,7,39,14,6,351,176,64,9,102,238,78,227,131,168,278,643,233,183,226,158,131,118,0,248,387,78,26,116,123,68,87,44,279,444,101,486,186,366,1957,1167,246,146,696,1532,6271,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,3,165,33,59,4,11,105,4,1,1,166,34,20,177,6,79,21,1,6,176,175,27,179,1,73,1,0,0,0,12,1,1,0,1,1,0,0,0,0,0,0,0,1,4,2,6,1,243,18,2,134,175,76,20,21,176,180,20,1,1,11,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,1,1,1,11,7,1,1,1,1,1,1,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,1,7,4,1,1,1,1,1,1,1,4,1,2,2,1,2,1,1,4,1,1,2,2,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,2,0,0,0,0,0,0,0,0,1,1,1,1,2,4,1,14,4,1,2,3,5,10,172,1,1,1,3,1,3,7,25,2,2,6,2,1,2,2,2,1,2,1,0,0,3,0,0,2,0,0,4,1,0,0,0,2,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,2,0,2,1,2,1,0,0,2,0,1,0,1,0,2,5,298,94,53,707,92,42,2,16,15,40,514,4402,2356,1,36,116,18,69,67,26,71,27,28,616,146,117,93,27,43,0,17,6,11,160,654,171,2,6339,43,2,45,1,24,20,12,31,134,2270,316,38,35,542,170,150,154,89,131,445,70,73,6,87,27,49,147,151,3,169,131,794,56,68,1099,275,1661,97,299,1575,41,546,1,88,679,545,204,85,94,23,33,261,63,16,26,19,3037,76,245,41,89,146,154,16,83,167,176,184,395,99,48,108,35,42,132,114,153,35,111,21,1,39,1,77,36,63,78,27,1,142,150,55,46,38,39,49,53,33,154,2,150,46,80,31,36,246,155,90,73,60,39,81,79,64,42,252,71,35,60,9,0,1,3,247,88,28,90,50,77,26,16,83,99,0,61,0,59,122,26,26,0,2,119,3,44,68,63,14,88,78,62,0,141,63,153,20,86,38,102,43,260,57,1,23,45,15,151,211,30,206,153,606,118,179,89,0,185,8,28,20,2,0,212,618,128,8,4,28,44,903,324,22,37,122,213,76,22,355,152,97,80,55,31,417,507,12,183,50,152,300,134,6,54,338,217,207,581,611,119,137,120,36,47,98,64,234,84,136,48,30,13,1,19,35,114,193,74,1623,22,247,9,79,134,21,3,119,55,100,275,93,196,2,7,76,80,71,100,26,40,440,107,41,65,307,99,1,55,99,1,731,295,16,1,107,122,3,86,22,78,68,918,66,341,184,71,186,2,40,53,7,48,5,72,18,87,25,36,5,121,27,396,1604,1,52,65,125,113,88,84,55,35,89,64,156,765,14,41,127,13,87,31,112,68,14,191,127,77,44,62,39,42,89,69,64,36,40,69,185,10,99,184,491,266,38,59,86,43,486,62,12,287,235,8,84,123,83,151,63,4,2,54,28,135,246,121,47,294,74,29,96,12,64,115,331,0,216,54,123,134,28,77,113,114,98,111,78,67,98,202,85,73,296,2249,5323,207,48,12,131,0,37,60,1,1,52,28,22,935,1988,0,0,0,0,0,0,0,0,0,0,567,56,43,74,10,165,17,137,15,19,89,74,7,22,1270,2448,0,118,26,93,32,210,257,57,117,42,27,39,33,47,0,13,9,31,125,132,16,2,134,68,14,59,38,18,0,53,34,0,41,148,66,64,109,26,79,2728,0,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,4,0,2,0,1,0,1,1,0,0,1,4,1,1,1,0,0,0,0,0,0,0,1,0,1,0,1,0,1,2,1,0,1,1,0,44,4,52,2320,369,256,31,209,159,89,102,139,63,2,152,16,1070,84,50,251,50,335,10271,8430,53,173,852,1286,53,177,142,184,74,32,419,30,3,160,91,2,0,140,54,64,1,153,17,39,89,136,632,701,38,86,49,91,101,151,51,154,305,278,13006,8646,794,2577,182,835,188,321,3,1208,330,521,146,580,195,106,226,150,2098,94,104,5616,1090,2892,1105,6015,4625,91,7,26,242,50,164,185,779,919,98,78,169,7,17,365,29,94,223,4,366,3270,1130,577,282,435,225,501,277,465,291,970,564,870,616,272,138,124,80,225,118,206,372,150,161,76,849,284,411,532,283,183,86,65,377,266,818,61,427,76,236,298,89,27,283,15,55,394,380,64,98,284,92,151,320,4,158,232,315,184,133,375,331,87,436,129,394,226,147,508,156,237,149,332,162,495,107,498,6,77,2,559,217,90,149,1,146,608,5,924,1016,882,573,2,84,51,14,66,48,95,105,9,1361,779,1735,1046,15,93,6,140,333,56,30,76,30,138,2,16,63,222,13,1054,4,343,1919,530,46,334,23,64,6,290,78,7,481,3842,1870,67,88,6,387,251,176,691,205,68,799,596,285,399,435,56,6854,131,329,497,407,362,297,628,974,1576,499,214,20,121,461,363,281,1780,44,417,10,246,188,87,286,267,307,312,18,287,962,289,181,476,149,1412,142,1575,1640,1367,96,871,912,116,88,2338,454,269,151,131,65,1096,314,334,182,9,16,494,771,1887,1,82,16,132,30,42,191,289,98,22,217,6,299,197,208,30,340,68,232,133,409,488,34,145,278,82,94,146,173,300,51,216,296,24,122,5,370,348,284,348,3,684,173,41,62,141,32,356,368,381,143,297,5,450,1549,333,81,135,1419,257,44,167,95,125,99,705,558,1564,314,95,2057,34,288,91,149,178,1410,138,72,316,212,139,2299,357,22,222,2,92,601,288,1825,313,278,309,76,217,1253,139,19,71,245,91,1167,199,301,170,198,381,354,411,29,211,48,470,143,280,207,491,90,16,3163,636,550,683,226,238,121,108,26,952,1517,7993,513,821,378,67,131,295,395,349,2079,49,127,43,160,618,499,39,289,81,114,277,616,1870,284,571,225,628,290,237,120,130,198,300,627,94,935,91,125,332,90,600,1237,241,71,336,668,434,86,70,453,206,401,954,0,184,205,518,1369,962,2413,9958,0,15852,14,8,166,174,38,39,36,41,14,36,33,231,49,15,156,43,79,22,32,37,56,54,144,357,191,70,173,126,142,5478,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,296,298,90,318,384,336,92,284,553,158,82,61,57,11,525,240,117,140,261,138,235,141,76,68,187,689,249,297,189,146,354,8383,0,136,166,162,91,42,7,88,170,2,42,143,126,93,148,140,74,169,523,36,0,133,37,283,143,179,163,64,94,40,62,73,83,1,135,15,37,144,94,252,39,10,0,180,134,147,133,165,14,149,145,123,16,120,36,162,41,93,155,116,35,2,16,27,43,34,2,21,139,40,86,193,57,115,290,137,141,450,250,288,235,136,12,786,202,71,1316,42,48,537,102,753,122,598,789,615,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,4,4,2,0,0,0,0,1,0,0,0,0,0,0,1,0,1,1,2,1,1,1,2,1,1,1,1,3,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,1,1,1,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,2,0,3,0,1,2,1,0,1,2,1,0,1,1,1,1,1,0,0,0,0,0,1,2,3,1,2,1,3,1,4,6,13,27,2,14,1,99,2,2,25,1,1,67,10,44,58,11,7,1,56,8,54,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,0,0,0,1,1,2,1,1,1,1,1,1,1,2,1,1,2,1,1,1,1,2,1,1,1,1,2,2,1,1,1,1,3,10,2,2,2,2,1,1,1,2,8,6,1,2,3,1,1,1,1,3,6,2,1,65,2,2,1,1,1,1,3,3,2,1,8,8,9,2,3,5,1,2,1,8,6,2,2,1,6,3,7,6,3,4,2,3,1,14,20,12,9,11,16,14,13,11,17,7,4,10,16,36,22,1,5,6,4,2,6,2,2,4,1,1,2,3,2,5,2,2,2,1,1,1,4,1,1,1,1,4,6,2,3,1,3,2,4,2,1,2,4,1,5,1,2,2,3,1,2,1,1,1,6,3,3,1,1,1,9,1,2,1,1,2,6,3,1,7,2,5,3,3,5,4,7,1,3,3,3,9,20,7,2,5,1,8,1,1,3,8,8,13,4,3,3,4,3,2,1,39,14,11,8,11,6,2,2,2,4,46,49,17,11,14,1,1,3,3,1,1,95,35,16,10,3,6,3,2,2,230,64,30,6,1,1,6,1,5,3,7,357,133,13,6,10,2,3,2,2,5,578,38,27,11,10,10,4,3,6,10,4,821,138,100,73,29,39,4,11,2,6,4,12,8,8,540,275,158,73,27,3,14,3,3,10,20,6,531,170,32,54,2,11,6,8,0,683,182,102,33,40,1,7,12,4,25,0,0,555,462,70,108,4,5,15,1,2,1,25,8,6,0,0,556,98,156,12,7,13,13,5,8,6,7,6,22,17,0,0,418,554,47,2,22,20,2,2,1,3,1,1,1,67,159,40,0,0,0,0,0,341,18,1,9,6,5,24,108,136,26,0,0,86,27,25,138,18,7,13,2,2,20,6,15,371,602,49,1,0,0,23,18,11,1,26,59,18,0,0,0,0,9,1,1,3,26,0,0,0,0,0,2,3,2,2,2,47,0,4,15,2,3,75,14,62,27,0,0,0,4,4,5,34,10,0,2,3,14,19,1,0,5,3,4,1,3,0,0,2,3,15,3,1,0,2,1,14,1,1,0,0,0,1,1,0,1,4,8,0,0,3,0,0,0,0,19,5,0,1,0,7,73,43,0,637,1,84,0,0,0,0,0,27,1481,1,0,0,0,0,0,0,0,0,0,0,25,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,2,3,4,2,46,44,7,2,1,4,1,1,9,1,3,3,2,4,1,2,1,7,2,1,1,1,0,1,0,0,1,0,0,0,3,1,1,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,1,5,1,0,0,0,0,1,1,1,3,1,1,3,1,1,1,2,1,4,2,10,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,1,0,0,1,0,1,3,938,288,32,62,13,3,77,37,9,59,14,193,1352,3589,3813,1070,33,59,162,39,181,368,163,13,78,148,115,34,63,14,4,78,38,1,1,0,0,0,58,13,335,44,1843,187,1,1,5371,457,64,72,49,74,1,1,51,193,158,85,32,12,24,14,28,603,9636,195,43,33,44,168,2,69,646,13107,96,3,17,2,5,88,119,11,43,8,60,41,17,382,16650,182,77,52,75,40,10,1,43,191,102,398,86,11,12,4,54,22,14,4,8,9,713,8387,941,238,45,271,144,90,102,14,38,48,173,206,1428,824,686,109,151,59,177,152,49,22,91,42,122,138,81,46,92,379,2384,533,279,210,123,48,223,643,117,235,197,128,72,121,86,279,128,106,25,845,758,232,197,53,168,70,202,114,82,100,85,80,39,194,241,1760,155,78,64,189,81,28,222,89,73,143,114,336,82,201,130,212,110,46,124,49,44,67,158,26,103,302,66,392,53,84,80,28,47,75,150,50,91,50,103,119,65,68,163,74,198,2,126,13,0,318,67,76,71,74,49,126,1,7,104,124,16,157,0,127,1,74,129,37,0,50,41,82,116,68,32,72,18,86,69,0,164,39,26,172,1355,315,226,65,129,228,156,248,34,20,88,14,121,2,1,125,350,530,705,321,691,283,224,17,34,42,204,110,99,84,23,47,125,165,881,125,425,199,517,81,76,166,164,13,10,82,142,36,78,71,42,1055,27,83,68,120,11,51,141,19,126,64,90,128,1,63,110,1,461,144,49,80,120,194,130,56,28,76,257,101,362,130,19,56,35,22,81,27,84,163,353,168,110,171,191,94,23,326,229,138,124,327,78,106,12,39,29,415,157,96,50,121,308,204,99,5,64,158,53,116,82,73,751,41,261,53,121,73,118,205,79,33,214,111,52,55,328,54,1,16,220,215,80,845,29,79,89,54,138,192,43,365,77,35,38,74,312,214,53,1,234,487,125,169,80,1,281,55,77,2,76,40,85,558,66,83,157,53,93,212,78,82,53,81,158,303,52,79,127,52,82,282,97,380,637,1,160,138,159,186,160,309,0,75,607,0,15,390,0,185,126,131,2392,5088,155,35,24,6,5,1351,35,123,33,75,63,14,97,156,575,906,2951,0,0,0,97,78,25,118,1372,114,46,78,44,199,81,277,814,1567,46,48,33,119,33,77,23,47,7,24,119,6,41,162,69,85,65,59,507,617,1355,24,37,31,51,61,93,40,82,1,72,0,62,206,30,36,77,31,118,57,116,107,54,64,339,160,101,131,500,1328,2929,0,30,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,2,1,0,1,0,1,0,1,1,1,0,0,0,2,1,1,0,0,2,1,1,0,0,1,1,0,0,2,0,1,3,2,0,1,2,1,3,4,8,0,4,0,0,3,1,1,1,3,1,0,0,0,0,0,0,1,0,2,0,0,1,0,1,2,2,1,0,0,0,0,1,1,2,1,3,3,2,1,1,1,5,1,6,1,1,2,1,2,2,1,1,1,1,2,1,1,1,1,3,1,1,10,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,1,1,1,1,0,0,0,1,1,1,1,1,0,0,0,1,0,1,0,1,0,1,2,1,0,15,6269,898,62644,40,17,15,77,100,996,29,1,1074,5207,1974,11757,8938,10950,5162,4259,526,494,1473,7,517,1930,1887,1440,4233,16806,692,521,1990,863,6591,1806,1737,4629,2580,41,2193,608,4049,4632,2194,458,4460,3978,18,1146,1465,2519,528,2692,2082,540,1,1,459,8,4461,1,19,516,1929,458,1013,876,575,1476,38332,27,71621,121233,697,120,3637,1512,63,2658,1581,286,3,919,39,40,1599,1039,709,1087,1088,651,55,16,13,53,103,130,6,615,2050,57,835,224,64,22,279,389,469,186,12,629,2,28,2,77,3,213,3,1,5,3,82,27098,6737,20268,15898,106,10938,3,79,4061,1580,61,570,2195,2941,2599,1600,5159,2658,1114,144,2012,30,1127,128,22,159,101,2127,2488,39,46,2948,9,32,95,15,1152,15,243,1051,34,11,264,6,82,957,1112,5046,1488,17903,1008,76,94,250,8,671,63,18,82,1142,7,22,1213,4386,37,43,10,1143,12,4,9558,2022,6087,3062,2289,3778,1992,35,20,10,10,110,1975,3495,4427,7157,3981,1596,1489,1748,2321,23,11,15,37,211,16,3,2023,3190,10,10,7,8,9,25,107,6116,3496,2437,1742,3759,8921,3400,1556,2821,9,2805,2504,1000,5,1755,35,13,2121,472,17,34,4,478,4,1582,1730,4388,3353,1076,4,3497,2024,8,280,5710,1581,1442,4,9,3855,8149,3064,128,889,32,1731,80,582,3856,3481,1743,24,3,15,3760,170,1412,581,62,3761,1582,8923,7,28,8,8924,4867,1200,569,3762,3331,472,8926,2196,6532,3498,2290,923,11,708,8927,2021,5712,3858,10,13,1557,5631,2586,1079,1031,1011,3484,993,2022,4389,1830,1601,171,4862,2197,4245,2499,7310,7,994,109,2551,1115,2032,8,145,1490,2806,3507,3859,6,3361,639,1109,2024,4006,1397,3498,4,37,11,9136,11,3787,83,20,709,6,3864,1202,3,2198,11,3,2292,1120,5,10,12,96,1748,17,1,1001,25,26,72,5,12,10,2817,93,17,7,18,11969,4433,796,1582,18,12,5,80,2931,16,6,1072,1,24,74,7,22,5,113,8149,67,29,13758,9,3355,1580,1538,11,1281,9,9,0,0,38,4190,3,9261,4391,1978,3721,1632,2440,9654,2,24,40,3656,15,2622,197,605,663,27,48,127,94,5741,964,1108,1595,3674,4,5,1090,687,23,25,2151,18825,3624,13498,7,10,8,222,20,2848,13947,29,13,0,0,2147,1474,7549,2,9052,2631,1332,1602,37,1557,45213,12808,9,172,1,23,8,3,21,5,9,422,0,43526,86,10030,2023,3798,455,101,8,8,2200,1116,24257,58140,3784,6813,2163,19,1153,32,1286,1732,927,2250,17,1080,48,12,259,44,5,1204,27684,30,78,16,2,15,1601,1,9848,47742,15396,3374,98,8345,1025,132,1637,23,6246,35,1617,184,18,774,244,8,1996,54,3,16,9,109,2029,3,34,10244,2171,592,25,26,2553,14,25894,2847,19685,6017,3957,487,2,5414,88,1599,3786,1747,1,1050,11,9,3935,2849,13039,4506,3504,8972,3850,46,32,500,34,176,14,229,2117,12,1549,71,4,32,4,19,20,19,1060,44,3863,1612,22,31,23,3360,9292,60,72,27,6,29,113,3,20,3,12,11,22,139,51,10763,17747,3649,7199,52,3307,1462,1261,31,2503,17,1763,4,123,1982,9,1092,308,7907,113,2479,1013,7622,58,32,2846,43,43,21,12,331,9,24,265,10,3103,8614,5922,4446,3303,3264,155,1297,15,42,9,139,8,5,19,1268,989,2,1833,2171,172,10943,19,85,1066,921,5,2,60,29,5,2664,53,11261,10924,130,1228,3968,3398,10,1902,1495,11,1064,2520,5,15,14,6,568,44,10,12,1733,19,27,3562,141,40,2382,2227,10,991,933,8953,9,22,9,14,42,5233,1093,9066,11257,15,2644,29,3776,5276,1868,2201,20,640,1120,2238,86,1588,1374,34,1569,57,125,31,17,24,11,2040,15,9,2126,7,4,1475,8,8,1113,448,69,264,24,215,5870,7,15,1079,15,53,1600,18,23,12,4,23,14,1093,4971,90,6746,191,270,2814,3864,22,59,2364,3546,16,7,4,31,29,8,175,11,1101,11,12,33,309,149,2513,8122,5722,19,13,67,1260,1016,15,1877,38,3776,1115,45,3372,19,2946,166,161,26,57,18,12,232,2519,228,1562,97,42,4407,1730,20,3439,2765,275,11,9,2031,584,1146,96,15,483,1428,72,933,24,12,6399,414,939,21,8528,10,14,11,14,1504,36,9882,6,4401,6,14,2006,12,1080,3865,1731,473,20,39,14,21,2,1207,3775,9026,15,33,34,18,12,119,11,1014,19,56,3071,44,333,110,96,1033,19,2316,58,1218,81,4,103,2451,76,8,16,1568,688,3186,6383,259,84,5722,7,7285,16,44,3,251,1022,1997,2804,4400,1101,50,10,90,28,942,22,50,6,8945,15,1093,17,72,18,25,8,5752,8,4172,22,8,13,14,18,1121,19,5720,30,30,36,24,9,54,22,46,28,13,25,55,7745,14,3777,5,2018,12,6471,22,5,51,7,1219,34,3866,8,18,11,4087,4,30,49,2051,5720,62,10041,22,942,8,2297,1164,43,21,117,8,16,1282,18,1128,38,11,1869,15,15,33,52,52,20,8,480,47,84,94,18,7,9,19,15,7240,78,0,2222,1858,427,23,10,5747,26,9,9,14,1048,58,19,22,2500,34,94,42,12824,29,1401,15283,82,33,40,3777,1731,5305,6048,77,24,47,21,35,108,924,2164,9032,18023,413,17,3764,944,89,15,9815,188,34479,71,141495,2,0,71314,149,6,9,23,15,10,1,3,4,1,4,8,1,2,78,5,3,1,126,9,85,16,42,3,44,16,3,103,20,4,1154,0,0,0,0,0,0,0,0,0,0,0,34169,1513,1442,1737,871,104,2041,2174,440,1057,861,605,601,986,496,2043,1329,281,790,988,354,1099,0,0,289,633,3696,803,149,552,1578,932,524,540,2174,534,524,1455,0,0,6933,3555,1006,2488,5677,696,3762,2142,2669,491,914,1567,132,1,1638,605,527,462,525,2849,722,1289,798,570,2155,0,863,2191,496,502,2848,456,798,870,1005,862,6,501,7,1393,871,1095,105,513,1526,500,1676,721,4458,1217,441,9,2847,1058,698,4457,2846,323,536,0,604,4456,1883,1877,600,863,1144,1495,121,7304,1059,864,495,4458,2846,2641,799,1290,514,1884,2,1330,1924,743,282,3,1004,0,791,987,2,14,1677,492,14,870,353,1098,9,16,1923,0,19,603,4663,28,126,11,1058,23,36,1270,4456,2845,1922,217,1964,1003,31,1876,632,861,455,1143,0,1875,123,569,131,602,2190,8,5822,3268,208,631,84,600,4455,3760,1244,1738,913,860,598,1094,237,1752,2189,587,0,6326,109,1393,38,551,4623,7528,1563,597,4021,1008,1590,0,2843,630,2,2658,2630,950,2105,684,4766,8169,2977,1435,9487,1427,0,0,0,11333,5751,6610,5638,11825,11434,4707,14819,10350,36059,428,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,5,1,1,4,3,1,1,5,1,4,1,5,3,66,10,8,2,2,2,1,2,1,1,2,3,1,1,3,2,1,1,0,0,0,2,1,1,0,0,0,2,1,1,0,1,0,2,1,2,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,3,0,0,0,3,1,0,1,1,1,20,4108,1631,3168,2064,804,796,277,133,403,284,185,130,162,829,348,701,124,180,111,384,9,57,84,8,302,161,48,2465,22843,4177,128,67,140,150,396,186,464,2208,401,91,224,303,99,933,619,149,164,201,401,1550,237,2572,219,810,799,266,13,284,339,134,285,226,186,296,467,473,679,272,151,562,61,700,123,181,7,104,389,10,58,482,152,8,7,178,116,162,389,49,3490,730,41564,25313,1881,234,1709,3961,609,706,315,187,1787,3656,635,1005,1121,147,801,174,1469,520,805,664,287,40,604,1177,1549,997,565,942,933,2075,461,1969,9382,780,2846,856,4467,7518,3665,477,1464,213,353,2,800,91,196,12,10,369,387,1166,1985,1222,1290,1404,445,183,1238,750,2089,776,359,468,390,381,315,457,886,272,342,263,936,2589,329,119,1961,2498,291,39,273,266,308,118,160,5,770,824,111,147,534,738,466,106,181,279,6,664,135,382,3,771,171,206,2626,5,1487,555,417,852,270,310,733,1374,141,28,37,539,446,72,148,383,86,1106,192,190,95,279,223,752,488,188,321,298,382,1470,266,87,112,303,698,228,455,1440,1403,796,197,234,444,193,249,421,168,172,269,219,608,334,7,590,188,148,473,52,15,1700,219,360,475,1239,175,384,536,229,541,295,469,701,1493,481,690,418,138,456,384,1441,85,324,171,79,366,304,316,385,1567,553,220,33,121,271,3,14,272,892,606,10,798,374,772,125,3003,1404,1045,1010,1113,1113,230,513,212,284,280,1738,190,540,674,7,341,0,56,524,2,687,569,319,304,399,0,469,1070,663,88,262,170,932,16,156,4201,424,1643,895,289,160,16,1086,7687,1052,10433,12131,298,1768,1644,1609,3,1202,12,146,65,131,162,6,304,592,682,153,1319,1635,3,2,66,700,0,13,820,7330,3074,1926,634,71,191,68,105,61,1098,1353,676,128,164,59,18642,7560,461,1764,630,1100,313,62,224,27,84,221,89,235,294,123,432,16986,6316,9858,1674,260,5427,6332,327,1308,671,668,340,203,171,2,301,214,221,8,135,1205,1686,191,241,299,5553,12842,4147,513,4288,3138,589,778,11,17,524,123,202,194,13,23,286,262,1212,5206,1420,655,2967,501,361,1895,324,656,345,1096,6994,3996,8210,6185,1223,1483,308,732,1230,593,239,411,289,291,497,1547,1225,6996,3748,449,316,584,39,131,585,249,42,200,707,3545,775,921,221,116,132,422,177,309,20222,3370,3948,406,665,580,197,264,83,38,5,384,366,273,72,318,712,2714,8569,16986,2492,1050,1705,2075,547,264,572,113,67,164,615,469,130,266,611,353,941,4003,1,7261,804,221,618,2368,381,70,63,261,151,135,404,534,1111,1109,5948,4648,1145,3266,172,1642,1175,524,387,75,587,650,778,67,151,444,1659,10,968,281,39,132,52,510,703,4350,5594,789,1508,281,615,2150,189,72,220,193,945,486,333,943,286,221,302,2190,493,913,2841,282,318,275,596,1065,2615,731,408,24,200,447,207,328,92,3,493,195,325,588,2838,187,1701,1440,135,142,132,420,1169,547,4,1023,193,761,4,551,407,133,183,43,733,2369,306,173,311,508,470,743,326,479,4,142,574,486,9,341,670,485,1294,14,216,552,882,3070,575,744,1407,71,757,1193,327,147,305,478,174,282,833,571,5,254,412,386,260,348,419,152,446,139,447,206,112,327,219,205,648,574,279,191,706,989,525,777,1193,570,421,220,2162,590,458,418,1064,1103,340,300,569,152,111,492,473,11,669,353,484,596,936,204,760,1293,444,130,3,563,1448,526,550,491,783,393,468,1406,746,3005,586,197,299,1308,2413,248,204,492,2660,181,571,746,668,761,1334,1686,220,460,2757,2738,905,3593,30255,38398,125,378,6,1,132,1,1,84,51,255,603,771,1142,845,1519,2955,0,0,0,0,0,0,0,0,0,0,6542,633,1195,228,55,87,155,136,95,644,58,470,394,1099,74,245,139,159,183,580,131,37,1849,1592,6592,2819,3669,7930,0,132,385,300,129,421,90,118,243,265,342,1802,471,1281,637,34,401,218,147,329,384,119,237,147,466,215,226,56,88,154,299,5,135,94,130,643,57,350,120,0,392,270,149,398,705,379,133,2,80,4,642,203,48,6,300,83,138,89,50,158,93,182,269,117,181,222,174,118,181,82,495,11,36,641,118,35,494,1625,849,577,363,766,2896,1236,872,119,4547,6911,4080,5711,5781,21141,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,1,2,1,2,1,1,17,1,6,1,7,6,3,11,6,8,2,9,3,1,1,5,33,1,1,1,1,3,2,12,6,27,6,4,1,1,1,2,2,2,3,1,1,7,3,2,4,4,1,2,1,1,2,4,25,7,24,14,17,10,6,4,5,1,2,2,1,3,2,3,1,1,3,1,2,2,2,1,2,2,2,1,0,2,1,1,1,1,1,0,0,1,11,2,3,2,1,1,0,0,0,0,5,1,0,0,0,0,0,0,5,3,7,3,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,1,1,1,1,1,0,0,0,0,0,0,0,0,1,6,3,2,2,0,0,0,0,0,3,1,3,2,0,0,0,2,3,1,1,3,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,2,1,2,1,1,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,1,2,3,1,5,2,1,1,3,1,1,10,2,1,1,1,4,3,1,2,1,2,3,3,3,2,1,1,2,1,1,1,1,1,1,1,1,1,1,2,1,1,3,1,7,4,1,7,3,2,3,1,4,4,3,14,12,8,4,6,1,1,5,2,3,2,1,1,1,2,1,1,2,1,2,2,1,2,1,1,1,1,2,2,2,2,2,2,1,4,1,1,1,1,2,1,2,2,3,3,1,2,2,4,2,3,4,1,2,3,2,3,4,8,1,2,2,1,1,8,5,1,1,4,9,10,1,1,2,6,2,2,5,1,9,11,10,4,4,5,5,3,3,4,12,29,11,3,2,2,2,4,3,12,20,3,5,9,3,5,3,10,22,30,35,13,2,9,21,32,1,41,19,3,2,2,5,4,1,24,50,7,3,23,11,3,6,3,14,54,2,1,2,5,6,29,11,6,6,7,5,4,27,62,2,1,8,3,1,2,6,3,1,1,1,1,2,1,0,2,2,2,5,0,6,3,1,7,5,49,0,3,1,1,1,10,13,0,5,1,1,2,2,4,1,0,1,1,0,4,1,2,0,5,3,6,0,2,0,1,1,3,7,0,1,0,1,0,6,6,0,2,0,0,6,1,0,3,3,0,73,0,22,2,1,1,0,3,0,0,0,0],\"yaxis\":\"y\",\"type\":\"scattergl\"}],                        {\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"midpoint\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"depth\"}},\"legend\":{\"tracegroupgap\":0},\"title\":{\"text\":\"X\"},\"height\":300,\"width\":750,\"shapes\":[{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":15249653,\"x1\":15249653,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":15251489,\"x1\":15251489,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":15255320,\"x1\":15255320,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":18758299,\"x1\":18758299,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":19631624,\"x1\":19631624,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":20014695,\"x1\":20014695,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":20128327,\"x1\":20128327,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":20129287,\"x1\":20129287,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":21721800,\"x1\":21721800,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":22164042,\"x1\":22164042,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":22798647,\"x1\":22798647,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":23468267,\"x1\":23468267,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":24229845,\"x1\":24229845,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"},{\"line\":{\"dash\":\"dash\",\"width\":1},\"opacity\":0.2,\"type\":\"line\",\"x0\":24266727,\"x1\":24266727,\"xref\":\"x\",\"y0\":0,\"y1\":1,\"yref\":\"y domain\"}]},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('789d0739-af1d-4a8f-b2bb-a900fb29375e');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["for idx, contig in enumerate(contigs):\n", "    fig = px.scatter(\n", "            total_cov_df.query(\"contig == @contig\"),\n", "            x='midpoint', \n", "            y=\"depth\",\n", "            color_discrete_sequence=['lightsalmon'],\n", "            title=contig,\n", "            template='simple_white',\n", "            height=300,\n", "            width=750\n", "        )\n", "    \n", "    amp_lines = panel_metadata.query(\"contig == @contig\")[['start', 'amplicon']].drop_duplicates()\n", "    for idx2, row in amp_lines.iterrows():\n", "        fig.add_vline(x=row['start'], line_width=1, line_dash=\"dash\", opacity=0.2)\n", "        \n", "    fig.show()"]}, {"cell_type": "markdown", "id": "31e0c3a5", "metadata": {"papermill": {"duration": 0.345875, "end_time": "2024-12-04T12:14:51.602766", "exception": false, "start_time": "2024-12-04T12:14:51.256891", "status": "completed"}, "tags": []}, "source": ["#### Coverage at each target SNP"]}, {"cell_type": "code", "execution_count": 7, "id": "d7d06a15", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:52.315488Z", "iopub.status.busy": "2024-12-04T12:14:52.313832Z", "iopub.status.idle": "2024-12-04T12:14:53.349665Z", "shell.execute_reply": "2024-12-04T12:14:53.348378Z"}, "papermill": {"duration": 1.394778, "end_time": "2024-12-04T12:14:53.351906", "exception": false, "start_time": "2024-12-04T12:14:51.957128", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [], "source": ["import warnings\n", "warnings.filterwarnings('ignore')\n", "\n", "target_covs = []\n", "for sample in metadata.sample_id:\n", "    target_cov = pd.read_csv(f\"{wkdir}/results/coverage/{sample}.regions.bed.gz\", sep=\"\\t\", header=None)\n", "    target_cov = target_cov.assign(sample_id=sample)\n", "    target_covs.append(target_cov)\n", "\n", "target_cov_df = pd.concat(target_covs, axis=0)\n", "target_cov_df.columns = ['contig', 'start', 'end', 'amplicon', 'depth', 'sample_id']\n", "target_cov_df = target_cov_df.merge(panel_metadata, how='left', on=['contig', 'start', 'end', 'amplicon'])\n", "snp_targets_sorted = natural_sort(target_cov_df.amplicon.unique().astype(str))"]}, {"cell_type": "code", "execution_count": 8, "id": "1229c203", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:54.067131Z", "iopub.status.busy": "2024-12-04T12:14:54.066735Z", "iopub.status.idle": "2024-12-04T12:14:54.599201Z", "shell.execute_reply": "2024-12-04T12:14:54.598049Z"}, "papermill": {"duration": 1.090836, "end_time": "2024-12-04T12:14:54.805267", "exception": false, "start_time": "2024-12-04T12:14:53.714431", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [{"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"alignmentgroup": "True", "customdata": [["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"], ["2R", "Ace1_G280S"], ["2R", "AIM9"], ["2R", "AIM10"], ["2R", "Cyp6p3_I88T"], ["2R", "Cyp6_tag1"], ["2R", "Cyp6_tag2"], ["2R", "Cyp6p4_I236M"], ["2R", "Cyp6_tag3"], ["2R", "Cyp6_tag4"], ["2R", "Cyp6_tag5"], ["2R", "Cyp6_tag6"], ["2R", "Cyp6_tag7"], ["2R", "Cyp6_tag8"], ["2R", "DSX2"], ["2R", "DSX1"], ["2R", "AIM11"]], "hovertemplate": "contig=%{customdata[0]}<br>amplicon=%{x}<br>log_depth=%{y}<br>mutation=%{customdata[1]}<extra></extra>", "legendgroup": "2R", "marker": {"color": "#1F77B4"}, "name": "2R", "notched": false, "offsetgroup": "2R", "orientation": "v", "showlegend": true, "type": "box", "x": ["Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_43", "Agam_82", "Agam_81", "Agam_44"], "x0": " ", "xaxis": "x", "y": [7.169925001442312, 4.0, 5.285402218862249, 8.31741261376487, 4.169925001442312, 8.071462362556623, 7.417852514885898, null, 4.857980995127572, 4.700439718141092, 2.584962500721156, 8.092757140919852, 7.087462841250339, null, null, 10.199672344836364, 5.087462841250339, 1.0, 2.321928094887362, 4.392317422778761, 1.584962500721156, 4.169925001442312, 3.700439718141092, null, 3.0, 1.0, 1.0, 2.321928094887362, 1.0, null, null, 5.727920454563199, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, 2.584962500721156, 0.0, 1.0, 3.0, null, 3.169925001442312, 1.0, null, 0.0, 0.0, 0.0, null, null, 1.0, 1.0, 2.321928094887362, 3.700439718141092, 1.0, 1.584962500721156, 4.906890595608519, null, 4.754887502163468, 4.247927513443585, null, 3.0, 1.0, 0.0, 4.169925001442312, 3.169925001442312, null, null, 6.3750394313469245, 5.807354922057604, 3.0, 3.700439718141092, 4.754887502163468, 2.584962500721156, 3.807354922057604, 5.0, null, 3.807354922057604, 2.807354922057604, 1.584962500721156, 3.4594316186372973, 2.321928094887362, null, null, 6.087462841250339, 5.491853096329675, 3.169925001442312, null, 1.584962500721156, null, null, 2.321928094887362, null, 4.906890595608519, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, 0.0, null, 0.0, null, null, 0.0, null, null, null, null, null, 0.0, null, null, null, null, 0.0, null, 0.0, null, null, 0.0, null, null, null, null, 3.321928094887362, 1.0, 2.321928094887362, 4.247927513443585, 2.321928094887362, 4.459431618637297, 5.459431618637297, null, 2.321928094887362, 2.321928094887362, 1.0, 3.584962500721156, 2.584962500721156, null, null, 5.285402218862249, 2.584962500721156, 1.0, 0.0, 2.584962500721156, 0.0, 3.321928094887362, 1.0, null, 2.807354922057604, 1.0, null, null, null, null, null, 4.0, 2.584962500721156, 0.0, 1.584962500721156, 1.584962500721156, null, 1.0, null, null, 1.584962500721156, null, null, 1.584962500721156, 0.0, null, null, 2.584962500721156, 6.339850002884624, 3.321928094887362, 3.0, 5.930737337562887, 3.169925001442312, 3.4594316186372973, 5.954196310386875, 2.0, 2.807354922057604, 3.807354922057604, 3.0, 5.426264754702098, 4.392317422778761, null, null, 5.491853096329675, 6.044394119358453, 3.584962500721156, 4.0, 6.321928094887363, 2.807354922057604, 5.584962500721156, 5.321928094887363, null, 3.0, 4.392317422778761, 2.584962500721156, 5.672425341971495, 4.700439718141092, null, null, 5.584962500721156, 4.169925001442312, 0.0, 1.0, 5.0, null, 2.584962500721156, 2.321928094887362, null, 1.584962500721156, 0.0, 1.0, 2.0, 1.0, null, null, 3.9068905956085187, 3.321928094887362, null, 2.0, 4.392317422778761, 1.0, 4.523561956057013, 0.0, null, 3.700439718141092, 2.807354922057604, null, 1.0, 0.0, null, null, 5.643856189774724, 4.0, 2.321928094887362, 0.0, 5.584962500721156, 1.584962500721156, 4.459431618637297, 3.584962500721156, null, 2.807354922057604, 1.584962500721156, null, 3.584962500721156, 2.584962500721156, null, null, 4.584962500721156, 4.0, 2.321928094887362, null, 4.0, 1.584962500721156, 2.807354922057604, 3.0, null, 2.0, 1.0, 1.0, 2.321928094887362, 1.0, null, null, 5.857980995127572, 6.643856189774724, 3.321928094887362, 3.584962500721156, 6.820178962415188, 2.807354922057604, 5.954196310386875, 6.022367813028454, null, 5.169925001442312, 4.169925001442312, 2.0, 6.044394119358453, 5.044394119358453, null, null, 8.060695931687555, null, null, 1.584962500721156, 2.321928094887362, null, 0.0, 4.087462841250339, null, 0.0, null, null, 2.0, 1.0, null, null, 4.392317422778761, 6.426264754702098, 3.169925001442312, 3.700439718141092, 7.169925001442312, 3.700439718141092, 6.741466986401147, 5.491853096329675, null, 5.169925001442312, 5.20945336562895, 3.807354922057604, 3.807354922057604, 2.807354922057604, null, null, 6.066089190457772, 4.584962500721156, 2.321928094887362, 0.0, 3.0, 1.0, 1.584962500721156, 3.700439718141092, null, 1.0, 2.0, 1.0, 4.321928094887363, 3.321928094887362, null, null, 5.977279923499917, 2.0, null, null, null, null, 2.0, 1.0, null, null, null, null, 1.0, 0.0, null, null, 2.584962500721156, null, null, null, null, null, null, 1.584962500721156, null, null, null, null, 1.0, 0.0, null, null, null, 4.906890595608519, 2.0, 3.0, 3.169925001442312, 2.0, 3.807354922057604, 5.129283016944966, null, 2.584962500721156, 2.321928094887362, 2.584962500721156, 3.0, 2.0, null, null, 6.303780748177103, 7.417852514885898, 4.087462841250339, 5.584962500721156, 7.330916878114617, 3.321928094887362, 6.066089190457772, 6.845490050944375, null, 4.754887502163468, 5.129283016944966, 3.0, 6.392317422778761, 5.392317422778761, null, null, 8.968666793195208, 5.20945336562895, 2.321928094887362, 2.0, 5.321928094887363, 0.0, 4.169925001442312, 4.807354922057604, null, 4.807354922057604, 3.0, null, 4.0, 3.0, null, null, 6.022367813028454, 4.169925001442312, 0.0, 2.0, 3.169925001442312, 2.584962500721156, 3.321928094887362, 3.807354922057604, null, null, 2.0, null, 3.321928094887362, 2.321928094887362, null, null, 2.0, 5.247927513443585, 2.321928094887362, 3.700439718141092, 6.491853096329675, 1.0, 4.954196310386875, 6.129283016944966, null, 3.807354922057604, 3.4594316186372973, null, 5.459431618637297, 4.459431618637297, null, null, 5.129283016944966, 7.189824558880018, 3.9068905956085187, 5.20945336562895, 7.971543553950772, 3.700439718141092, 6.129283016944966, 7.312882955284356, null, 4.584962500721156, 6.022367813028454, 3.0, 6.643856189774724, 5.643856189774724, null, null, 7.3750394313469245, 2.0, null, null, 2.584962500721156, null, null, 1.0, null, 3.169925001442312, null, null, null, null, null, null, 2.807354922057604, 3.584962500721156, null, null, 4.700439718141092, 1.0, 2.0, 3.4594316186372973, null, 2.0, 3.0, 0.0, 4.169925001442312, 3.169925001442312, null, null, 6.169925001442312, 5.523561956057013, 3.584962500721156, 3.4594316186372973, 6.845490050944375, 2.584962500721156, 6.321928094887363, 5.954196310386875, null, 4.584962500721156, 4.584962500721156, 2.584962500721156, 5.169925001442312, 4.169925001442312, null, null, 7.672425341971495, 7.011227255423254, 4.247927513443585, 4.321928094887363, 4.954196310386875, 3.4594316186372973, 5.285402218862249, 6.459431618637297, null, 4.643856189774724, 5.044394119358453, 2.321928094887362, 4.321928094887363, 3.321928094887362, null, null, 8.228818690495881, 4.459431618637297, 2.321928094887362, 4.392317422778761, 6.22881869049588, 2.0, 5.357552004618084, 5.0, null, 3.9068905956085187, 2.321928094887362, 1.584962500721156, 5.700439718141092, 4.700439718141092, null, null, 8.103287808412022, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, 8.03342300153745, 4.906890595608519, 5.78135971352466, 8.113742166049189, 4.700439718141092, 1.0, 6.845490050944375, null, 1.0, 5.930737337562887, 5.614709844115208, 6.672425341971495, 5.672425341971495, null, null, 7.044394119358453, 7.159871336778389, 3.321928094887362, 3.4594316186372973, 6.066089190457772, null, 3.4594316186372973, 5.169925001442312, null, 4.392317422778761, 3.4594316186372973, 2.584962500721156, 4.459431618637297, 3.4594316186372973, null, null, 4.523561956057013, 5.0, 2.807354922057604, 3.169925001442312, 5.584962500721156, 1.0, 4.807354922057604, 5.459431618637297, null, 4.0, 3.321928094887362, 1.584962500721156, 3.321928094887362, 2.321928094887362, null, null, 5.554588851677638, 6.643856189774724, 3.9068905956085187, 4.247927513443585, 6.539158811108031, 2.807354922057604, 5.554588851677638, 6.475733430966398, null, 5.321928094887363, 4.321928094887363, 1.0, 6.0, 5.0, null, null, 5.906890595608519, 4.0, null, 2.321928094887362, 4.954196310386875, 1.584962500721156, 4.700439718141092, 4.754887502163468, null, 3.0, 2.0, 1.0, 3.584962500721156, 2.584962500721156, null, null, 5.0, 5.087462841250339, 2.321928094887362, 2.321928094887362, 4.754887502163468, 1.584962500721156, 2.584962500721156, 5.087462841250339, 1.584962500721156, 1.584962500721156, 2.0, 1.0, 4.321928094887363, 3.321928094887362, null, null, 4.169925001442312, 6.475733430966398, 4.247927513443585, 4.523561956057013, 6.569855608330948, 2.584962500721156, 6.022367813028454, 5.554588851677638, null, 5.392317422778761, 3.584962500721156, 3.0, 5.954196310386875, 5.0, null, null, 5.285402218862249, 5.643856189774724, 3.169925001442312, 3.169925001442312, 5.807354922057604, 1.584962500721156, 5.321928094887363, 4.584962500721156, null, 3.807354922057604, 3.584962500721156, null, 5.906890595608519, 4.906890595608519, null, null, 5.807354922057604, 5.643856189774724, 3.0, 3.0, 5.459431618637297, 0.0, 4.584962500721156, 5.285402218862249, 0.0, 4.169925001442312, 3.0, 2.0, 3.584962500721156, 2.584962500721156, null, null, 4.392317422778761, 3.584962500721156, 0.0, null, 4.459431618637297, null, 2.0, 3.700439718141092, null, 3.700439718141092, 3.321928094887362, null, 4.169925001442312, 3.169925001442312, null, null, 2.321928094887362, 5.584962500721156, 3.321928094887362, 2.0, 5.285402218862249, 2.807354922057604, 4.459431618637297, 5.643856189774724, null, 2.584962500721156, 3.169925001442312, null, 4.584962500721156, 3.584962500721156, null, null, 6.741466986401147, null, null, null, null, null, null, 0.0, null, null, null, null, 1.584962500721156, 0.0, null, null, null, 8.154818109052105, 5.169925001442312, 6.475733430966398, 8.991521846075695, 5.426264754702098, 7.303780748177103, 8.0, null, 5.700439718141092, 6.392317422778761, 5.285402218862249, 8.011227255423254, 7.011227255423254, null, null, 7.826548487290915, 8.611024797307353, 5.129283016944966, 5.554588851677638, 8.022367813028454, 4.906890595608519, 6.614709844115208, 7.219168520462161, 0.0, 6.459431618637297, 6.539158811108031, 5.0, 7.569855608330948, 6.584962500721156, null, null, 6.857980995127572, 8.813781191217037, 6.066089190457772, 7.400879436282184, 9.862637357558794, 6.087462841250339, 8.741466986401146, 9.076815597050832, null, 6.643856189774724, 7.366322214245816, 0.0, 8.804131021183318, 7.800899899920305, null, null, 7.614709844115208, 5.459431618637297, 3.4594316186372973, 3.807354922057604, 6.266786540694901, 2.807354922057604, 6.0, 6.285402218862249, null, 5.321928094887363, 3.321928094887362, 3.584962500721156, 5.754887502163468, 4.754887502163468, null, null, 6.475733430966398, 7.409390936137702, 3.584962500721156, 3.807354922057604, 7.087462841250339, 4.0, 5.930737337562887, 5.930737337562887, 0.0, 5.523561956057013, 4.700439718141092, 3.9068905956085187, 6.022367813028454, 5.0, null, null, 6.303780748177103, 5.906890595608519, 2.807354922057604, 3.4594316186372973, 5.459431618637297, 1.0, 5.169925001442312, 4.700439718141092, null, 2.0, 4.321928094887363, 2.584962500721156, 4.392317422778761, 3.321928094887362, null, null, 3.9068905956085187, 7.546894459887636, 3.9068905956085187, 5.882643049361842, 8.005624549193879, 3.169925001442312, 6.807354922057604, 6.459431618637297, null, 5.169925001442312, 5.491853096329675, null, 7.05528243550119, 6.066089190457772, null, null, 7.022367813028454, 4.169925001442312, 2.584962500721156, 3.584962500721156, 5.977279923499917, 2.807354922057604, 5.807354922057604, 6.266786540694901, null, 2.584962500721156, 3.321928094887362, 2.0, 6.700439718141092, 5.727920454563199, null, null, 8.087462841250339, 5.0, 2.584962500721156, 3.4594316186372973, 5.554588851677638, 1.0, 4.087462841250339, 3.584962500721156, null, 3.584962500721156, 3.321928094887362, 1.0, 4.459431618637297, 3.4594316186372973, null, null, 5.321928094887363, 4.0, null, 1.584962500721156, 5.523561956057013, 0.0, 2.321928094887362, 3.4594316186372973, null, 3.321928094887362, 0.0, null, 4.754887502163468, 3.700439718141092, null, null, 4.906890595608519, 4.247927513443585, 1.584962500721156, 2.807354922057604, 5.906890595608519, null, 2.584962500721156, 5.672425341971495, null, 1.584962500721156, 2.0, 1.0, 3.700439718141092, 2.807354922057604, null, null, 5.129283016944966, null, null, null, null, null, null, 0.0, null, 1.584962500721156, null, 0.0, null, null, null, null, null, 9.952741247186488, 7.643856189774724, 8.179909090014934, 9.199672344836364, 7.6865005271832185, 8.900866807980748, 8.703903573444663, 1.0, 7.845490050944375, 8.696967526234287, 6.459431618637297, 8.703903573444663, 7.714245517666122, null, null, 7.658211482751795, 8.366322214245816, 5.357552004618084, 5.672425341971495, 8.447083226209653, 4.643856189774724, 3.169925001442312, 6.20945336562895, 1.584962500721156, 5.523561956057013, 6.189824558880018, 4.523561956057013, 6.754887502163468, 5.754887502163468, null, null, 7.400879436282184, 5.857980995127572, 2.321928094887362, 2.321928094887362, 6.066089190457772, 2.807354922057604, 5.285402218862249, 6.714245517666122, null, 4.700439718141092, 3.4594316186372973, null, 5.807354922057604, 4.807354922057604, null, null, 5.285402218862249, 7.366322214245816, 4.700439718141092, 5.459431618637297, 7.22881869049588, 3.321928094887362, 6.554588851677638, 6.475733430966398, null, 5.247927513443585, 5.129283016944966, 3.807354922057604, 6.658211482751795, 5.672425341971495, null, null, 6.845490050944375, null, null, null, 3.4594316186372973, 1.0, 1.584962500721156, 2.584962500721156, null, 0.0, null, null, null, null, null, null, 2.321928094887362, 5.491853096329675, 1.0, 3.4594316186372973, 6.0, 1.0, 2.584962500721156, 3.584962500721156, null, 2.807354922057604, 3.4594316186372973, 2.0, 4.0, 3.0, null, null, 3.584962500721156, 4.523561956057013, 2.321928094887362, 3.4594316186372973, 6.658211482751795, 2.0, 5.584962500721156, 5.930737337562887, null, 2.0, 3.0, 1.0, 5.392317422778761, 4.392317422778761, null, null, 7.523561956057013, 4.169925001442312, 2.584962500721156, 1.0, 5.20945336562895, 1.584962500721156, 4.584962500721156, 3.169925001442312, null, 3.321928094887362, 1.0, null, 4.700439718141092, 3.700439718141092, null, null, 4.087462841250339, 4.169925001442312, 2.321928094887362, 1.0, 3.0, null, 2.584962500721156, 3.584962500721156, 0.0, 2.321928094887362, 2.0, 1.0, 3.4594316186372973, 2.321928094887362, null, null, 4.087462841250339, 5.523561956057013, 3.169925001442312, 2.584962500721156, 5.169925001442312, 1.584962500721156, 2.584962500721156, 1.584962500721156, null, 3.807354922057604, 2.584962500721156, 3.0, 3.0, 2.0, null, null, 3.807354922057604, null, null, 0.0, 2.0, 0.0, 0.0, 1.584962500721156, null, 1.0, 0.0, 0.0, null, null, null, null, 1.0, null, null, null, null, null, null, null, null, 0.0, null, 0.0, 0.0, null, null, null, null, 8.842350343413807, 4.906890595608519, 3.584962500721156, 4.954196310386875, 4.857980995127572, 5.129283016944966, 5.426264754702098, null, 5.285402218862249, 5.321928094887363, 4.906890595608519, 4.392317422778761, 3.321928094887362, null, null, 6.285402218862249, 7.820178962415188, 3.4594316186372973, 4.321928094887363, 6.189824558880018, 3.4594316186372973, 4.459431618637297, 5.754887502163468, null, 3.9068905956085187, 5.0, 1.0, 6.247927513443585, 5.247927513443585, null, null, 6.768184324776926, 7.870364719583405, 4.087462841250339, 3.807354922057604, 4.857980995127572, 1.0, 3.9068905956085187, 4.169925001442312, null, 6.523561956057013, 3.169925001442312, 2.807354922057604, 3.584962500721156, 2.584962500721156, null, null, 4.643856189774724, 6.930737337562887, 4.754887502163468, 5.087462841250339, 6.714245517666122, 3.700439718141092, 5.882643049361842, 5.78135971352466, 0.0, 6.339850002884624, 5.247927513443585, 1.0, 5.523561956057013, 4.523561956057013, null, null, 5.857980995127572, 5.0, 1.584962500721156, 1.584962500721156, 4.523561956057013, 2.0, 3.321928094887362, 4.169925001442312, null, 5.20945336562895, 2.807354922057604, 2.584962500721156, 3.321928094887362, 2.321928094887362, null, null, 2.807354922057604, 5.321928094887363, 2.584962500721156, 1.584962500721156, 4.954196310386875, 2.321928094887362, 3.169925001442312, 3.700439718141092, null, 2.807354922057604, 2.0, null, 4.247927513443585, 3.169925001442312, null, null, 6.022367813028454, 9.832890014164741, 6.584962500721156, 6.807354922057604, 8.379378367071261, 5.169925001442312, 6.554588851677638, 7.417852514885898, 0.0, 8.076815597050832, 7.03342300153745, 6.066089190457772, 7.169925001442312, 6.189824558880018, null, null, 9.098032082960527, 4.807354922057604, 0.0, 0.0, 2.807354922057604, null, 0.0, 3.0, null, 1.584962500721156, 1.584962500721156, 1.0, 1.584962500721156, 0.0, null, null, 1.0, 7.294620748891627, 5.882643049361842, 3.9068905956085187, 7.693486957499325, 4.700439718141092, 5.584962500721156, 6.0, null, 4.954196310386875, 5.169925001442312, 0.0, 6.20945336562895, 5.20945336562895, null, null, 7.562242424221073, 5.087462841250339, 2.0, 2.0, 4.321928094887363, 2.0, 2.584962500721156, 3.0, null, 4.643856189774724, 2.0, 1.0, 2.584962500721156, 1.584962500721156, null, null, 5.78135971352466, 6.044394119358453, 2.584962500721156, 2.807354922057604, 4.459431618637297, 0.0, 2.584962500721156, 4.321928094887363, null, 3.807354922057604, 2.0, null, 2.0, 1.0, null, null, 3.807354922057604, null, null, null, null, null, null, 1.0, null, 0.0, null, null, null, null, null, null, null, 9.283088353024002, 5.832890014164741, 7.294620748891627, 7.451211111832329, 5.643856189774724, 7.149747119504682, 5.247927513443585, 0.0, 8.219168520462162, 7.417852514885898, 5.672425341971495, 6.658211482751795, 5.672425341971495, null, null, 7.076815597050831, 11.406205005418855, 8.049848549450562, 8.113742166049189, 9.611024797307353, 7.3750394313469245, 9.071462362556623, 8.774787059601174, 2.0, 8.189824558880018, 9.224001674198105, 6.523561956057013, 8.169925001442312, 7.169925001442312, 2.584962500721156, 2.584962500721156, 8.228818690495881, 5.700439718141092, 2.807354922057604, 3.169925001442312, 3.700439718141092, null, 3.700439718141092, 3.700439718141092, null, 4.087462841250339, 2.0, null, 2.584962500721156, 1.584962500721156, null, null, 4.321928094887363, 6.672425341971495, 2.584962500721156, 2.807354922057604, 6.22881869049588, 4.169925001442312, 5.832890014164741, 4.643856189774724, 0.0, 4.700439718141092, 4.807354922057604, null, 4.0, 3.0, null, null, 6.672425341971495, 1.0, 0.0, null, null, 0.0, null, null, null, 0.0, null, null, null, null, null, null, null, 4.169925001442312, null, null, 1.0, null, null, null, null, 2.0, null, 1.0, 1.0, 0.0, null, null, 1.584962500721156, 8.066089190457772, 4.906890595608519, 4.0, 5.807354922057604, 2.584962500721156, 3.321928094887362, 3.4594316186372973, null, 6.129283016944966, 4.700439718141092, 3.807354922057604, 5.614709844115208, 4.700439718141092, null, null, 6.78135971352466, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 6.672425341971495, 3.807354922057604, 2.584962500721156, 5.321928094887363, 2.584962500721156, 4.584962500721156, 4.754887502163468, null, 5.727920454563199, 4.643856189774724, 3.700439718141092, 4.247927513443585, 3.321928094887362, null, null, 5.807354922057604, null, 0.0, null, null, null, null, null, null, 1.0, null, null, 1.0, null, null, null, null, 6.741466986401147, 4.247927513443585, 4.087462841250339, 5.614709844115208, 2.321928094887362, 4.321928094887363, 4.087462841250339, null, 5.906890595608519, 4.087462841250339, 3.0, 3.169925001442312, 2.0, null, null, 6.569855608330948, 1.0, null, null, null, null, null, 0.0, null, 1.0, null, null, 1.0, null, null, null, 0.0, null, 0.0, 0.0, 3.321928094887362, 1.584962500721156, 3.169925001442312, 2.807354922057604, null, null, null, 1.584962500721156, 3.584962500721156, 2.584962500721156, null, null, 5.459431618637297, null, null, null, 0.0, 0.0, 0.0, null, null, null, 0.0, null, 1.584962500721156, 0.0, null, null, null, 4.459431618637297, 4.169925001442312, 4.700439718141092, 6.965784284662087, 3.584962500721156, 7.22881869049588, 5.977279923499917, 0.0, 4.807354922057604, 4.247927513443585, 4.523561956057013, 6.129283016944966, 5.20945336562895, null, null, 8.839203788096944, 5.321928094887363, 3.9068905956085187, 6.741466986401147, 8.0, 4.906890595608519, 7.451211111832329, 7.330916878114617, 2.0, 3.0, 6.0, 5.087462841250339, 6.189824558880018, 5.247927513443585, null, null, 9.233619676759702, 3.321928094887362, 3.0, 5.20945336562895, 7.577428828035749, 2.321928094887362, 7.118941072723508, 7.076815597050831, null, 4.857980995127572, 3.807354922057604, 4.459431618637297, 3.9068905956085187, 2.807354922057604, null, null, 8.820178962415188, null, 2.0, 1.584962500721156, 0.0, null, 2.807354922057604, 2.0, null, 0.0, 1.0, null, 2.0, 1.0, null, null, 2.0, 1.0, 1.584962500721156, null, null, null, null, 1.0, null, 2.584962500721156, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.0, null, 2.584962500721156, 2.0, 2.807354922057604, null, 1.0, 1.584962500721156, null, null, null, 2.0, 2.0, 1.0, null, null, 4.0, null, 2.0, 1.584962500721156, 3.169925001442312, 0.0, 1.0, 3.9068905956085187, null, 2.0, 1.584962500721156, null, 1.0, 0.0, null, null, 5.044394119358453, 1.0, 1.0, 2.0, 2.0, null, 0.0, 1.584962500721156, null, 2.0, 1.584962500721156, null, 2.0, 1.0, null, null, 4.700439718141092, null, null, null, 2.0, null, 2.321928094887362, 1.0, null, 2.0, null, null, 2.584962500721156, 1.584962500721156, null, null, 5.129283016944966, 3.0, 1.0, 3.584962500721156, 6.066089190457772, 2.0, 5.247927513443585, 4.906890595608519, null, 3.700439718141092, 3.321928094887362, 2.0, 3.0, 2.0, null, null, 8.098032082960527, 4.247927513443585, 4.954196310386875, 5.357552004618084, 7.044394119358453, 3.584962500721156, 6.066089190457772, 5.906890595608519, null, 5.727920454563199, 5.357552004618084, 3.584962500721156, 6.491853096329675, 5.491853096329675, null, null, 8.184875342908283, null, null, null, 0.0, null, null, 0.0, null, null, null, null, null, null, null, null, 1.584962500721156, 1.0, 1.0, 3.700439718141092, 4.700439718141092, 2.321928094887362, 2.584962500721156, 3.584962500721156, null, 2.0, 3.321928094887362, 3.0, 3.807354922057604, 2.807354922057604, null, null, 6.569855608330948, null, null, 1.0, 1.0, null, 2.0, 1.584962500721156, null, 2.0, null, null, 3.0, 2.0, null, null, 3.584962500721156, null, null, null, 1.584962500721156, null, 0.0, 0.0, null, null, 0.0, null, 1.0, 0.0, null, null, 4.459431618637297, 2.584962500721156, 3.169925001442312, 1.584962500721156, 4.523561956057013, null, 4.700439718141092, 4.247927513443585, null, null, 3.0, 2.0, 4.643856189774724, 3.584962500721156, null, null, 6.794415866350106, null, null, 2.584962500721156, 5.169925001442312, null, 4.087462841250339, 1.584962500721156, null, 0.0, 1.584962500721156, null, null, null, null, null, 5.727920454563199, null, null, 1.0, 1.0, 0.0, 3.321928094887362, 1.584962500721156, null, 2.321928094887362, null, 1.0, 0.0, null, null, null, 4.169925001442312, null, 0.0, 2.321928094887362, 4.459431618637297, 2.321928094887362, 3.807354922057604, 4.906890595608519, null, 1.0, 1.0, 2.584962500721156, null, null, null, null, 5.247927513443585, 1.0, 0.0, 2.0, 2.584962500721156, 0.0, 3.4594316186372973, 3.0, null, 0.0, 1.584962500721156, 1.0, 2.584962500721156, 1.584962500721156, null, null, 5.672425341971495, null, 0.0, 0.0, null, 0.0, 1.0, 1.584962500721156, null, null, null, null, 1.0, 0.0, null, null, 0.0, 1.0, 2.0, 0.0, 3.169925001442312, null, 3.321928094887362, 3.169925001442312, null, 2.584962500721156, null, null, null, null, null, null, 4.643856189774724, 3.584962500721156, 3.584962500721156, 5.392317422778761, 7.285402218862249, 5.0, 6.768184324776926, 7.108524456778169, 1.0, 1.584962500721156, 4.700439718141092, 3.321928094887362, 5.087462841250339, 4.087462841250339, null, null, 8.861086905995395, 1.0, 1.584962500721156, null, 4.0, null, 3.0, 4.643856189774724, null, 2.584962500721156, 0.0, 0.0, 4.087462841250339, 3.0, null, null, 4.807354922057604, 0.0, 1.0, null, 1.0, null, 2.0, 0.0, null, 1.0, null, null, null, null, null, null, 2.807354922057604, 3.807354922057604, 2.807354922057604, 3.0, 4.247927513443585, 1.0, 4.906890595608519, 3.169925001442312, null, 2.0, 2.321928094887362, null, 2.584962500721156, 1.584962500721156, null, null, 7.870364719583405, 2.0, 1.0, 2.0, 4.392317422778761, 1.0, 4.459431618637297, 4.459431618637297, null, 1.0, 3.4594316186372973, 3.0, 2.807354922057604, 2.0, null, null, 2.807354922057604, 2.584962500721156, 0.0, 1.584962500721156, 4.643856189774724, 1.0, 2.807354922057604, 2.0, null, 2.0, 0.0, 2.0, 4.700439718141092, 3.700439718141092, null, null, 5.672425341971495, 1.0, null, 0.0, 3.0, 1.584962500721156, 3.700439718141092, 1.0, null, 1.0, 0.0, null, 3.0, 2.0, null, null, 5.906890595608519, null, 0.0, 0.0, 1.584962500721156, 1.0, 2.0, 0.0, null, null, 1.0, null, 1.584962500721156, 0.0, null, null, 5.169925001442312, null, null, null, 1.0, null, 0.0, 2.584962500721156, 0.0, 1.0, 0.0, null, 2.321928094887362, 1.0, null, null, 3.4594316186372973, 1.584962500721156, null, 2.321928094887362, 3.4594316186372973, 1.0, 3.700439718141092, 1.0, null, 2.0, 2.0, 2.0, null, null, null, null, 6.409390936137702, null, null, null, 0.0, null, 1.0, 2.584962500721156, null, null, 0.0, null, 0.0, 0.0, null, null, 4.247927513443585, 4.459431618637297, 4.247927513443585, 5.20945336562895, 6.741466986401147, 2.584962500721156, 6.087462841250339, 6.357552004618084, null, 3.169925001442312, 4.906890595608519, 4.247927513443585, 4.392317422778761, 3.584962500721156, null, null, 7.839203788096944, 4.584962500721156, 3.4594316186372973, 4.643856189774724, 5.426264754702098, 2.807354922057604, 5.523561956057013, 5.129283016944966, 1.0, 2.0, 3.807354922057604, 3.321928094887362, null, null, null, null, 7.98299357469431, 1.0, 2.584962500721156, 2.807354922057604, 5.700439718141092, 2.584962500721156, 4.321928094887363, 4.754887502163468, null, 1.0, 2.807354922057604, null, 5.087462841250339, 4.087462841250339, null, null, 6.820178962415188, 4.321928094887363, 2.807354922057604, 3.321928094887362, 5.247927513443585, 3.0, 5.426264754702098, 4.906890595608519, null, 1.0, 3.169925001442312, 3.584962500721156, null, null, null, null, 7.523561956057013, null, null, null, null, null, 2.0, null, null, 1.584962500721156, 1.584962500721156, null, 1.0, 0.0, null, null, 0.0, null, null, 1.0, 2.584962500721156, null, null, 2.0, null, 2.584962500721156, 0.0, null, 0.0, null, null, null, 4.857980995127572, 2.0, 0.0, 0.0, null, 1.0, 1.584962500721156, 2.584962500721156, null, 2.0, null, null, null, null, null, null, 2.321928094887362, 1.0, 0.0, 1.0, 0.0, 0.0, 3.0, 1.0, null, 1.0, 1.584962500721156, null, 1.0, 0.0, null, null, 1.0, 2.584962500721156, 1.584962500721156, 2.584962500721156, 3.700439718141092, 0.0, 3.700439718141092, 3.4594316186372973, null, null, 2.807354922057604, 2.0, null, null, null, null, 6.392317422778761, null, null, null, 2.0, null, 3.169925001442312, null, null, 1.0, 1.0, null, null, null, null, null, 2.321928094887362, null, null, 1.0, 2.807354922057604, 0.0, 2.807354922057604, 2.807354922057604, null, 1.0, 1.0, 1.0, null, null, null, null, 4.754887502163468, null, null, null, null, null, 0.0, 1.0, null, 0.0, null, null, null, null, null, null, 2.0, null, null, 0.0, 2.807354922057604, 0.0, null, 1.0, null, 1.0, null, 1.0, null, null, null, null, 4.643856189774724, 5.247927513443585, 4.523561956057013, 4.954196310386875, 6.643856189774724, 4.247927513443585, 6.794415866350106, 6.266786540694901, 1.584962500721156, 6.409390936137702, 5.285402218862249, 4.169925001442312, 6.475733430966398, 5.491853096329675, null, null, 8.829722735086058, 4.700439718141092, 3.700439718141092, 5.321928094887363, 7.266786540694901, 3.584962500721156, 5.584962500721156, 6.303780748177103, 0.0, 4.807354922057604, 4.087462841250339, 4.087462841250339, 5.392317422778761, 4.392317422778761, null, null, 9.566054038171092, null, 1.0, 2.0, 3.584962500721156, null, 4.247927513443585, 3.321928094887362, null, 3.0, 0.0, null, 4.0, 3.0, null, null, 5.672425341971495, null, 1.584962500721156, 1.584962500721156, 2.321928094887362, 0.0, 2.0, 0.0, null, null, 0.0, 1.584962500721156, null, null, null, null, 2.584962500721156, 1.0, 0.0, 0.0, 4.700439718141092, 2.584962500721156, 3.321928094887362, 2.321928094887362, null, 2.584962500721156, 0.0, 2.0, 4.954196310386875, 3.9068905956085187, null, null, 4.584962500721156, 1.0, 0.0, 1.0, 4.392317422778761, null, 3.169925001442312, 2.0, null, null, 0.0, null, 2.321928094887362, 1.584962500721156, null, null, 6.303780748177103, 2.0, null, 2.321928094887362, 3.4594316186372973, null, 0.0, 4.169925001442312, null, null, 0.0, null, null, null, null, null, 5.087462841250339, 3.9068905956085187, 2.584962500721156, 4.584962500721156, 6.599912842187128, 3.169925001442312, 5.426264754702098, 4.459431618637297, null, 2.584962500721156, 2.807354922057604, 1.0, 6.044394119358453, 5.044394119358453, null, null, 8.144658242831882, null, 0.0, 1.584962500721156, 2.584962500721156, 2.321928094887362, 4.643856189774724, 4.247927513443585, null, null, 2.0, null, null, null, null, null, 5.977279923499917, null, 1.584962500721156, 1.0, 3.700439718141092, 1.0, 2.807354922057604, 3.0, null, 0.0, 2.0, 1.0, 3.0, 2.0, null, null, 5.129283016944966, null, null, 1.0, 4.0, 1.584962500721156, 1.584962500721156, 3.321928094887362, 0.0, 2.0, 1.584962500721156, 1.0, 2.584962500721156, 1.584962500721156, null, null, 5.807354922057604, null, null, null, 1.0, null, null, 2.0, null, 1.0, null, 1.584962500721156, null, null, null, null, 2.0, 2.584962500721156, 3.169925001442312, 1.584962500721156, 3.584962500721156, 1.584962500721156, 4.459431618637297, 4.247927513443585, null, 2.321928094887362, 0.0, 2.0, 4.584962500721156, 3.584962500721156, null, null, 5.523561956057013, null, 1.584962500721156, 4.392317422778761, 5.0, 2.0, 5.247927513443585, 5.285402218862249, 0.0, 1.0, 2.584962500721156, 2.584962500721156, 4.906890595608519, 3.9068905956085187, null, null, 7.199672344836364, 4.584962500721156, 4.247927513443585, 6.0, 6.266786540694901, 4.459431618637297, 6.087462841250339, 6.108524456778169, 0.0, 0.0, 4.754887502163468, 4.584962500721156, 5.643856189774724, 4.700439718141092, null, null, 8.787902559391432, null, null, null, null, 0.0, null, null, null, 1.0, null, null, null, null, null, null, 2.321928094887362, null, 0.0, 2.584962500721156, 3.700439718141092, 0.0, 3.700439718141092, 4.754887502163468, null, null, 2.321928094887362, null, 1.584962500721156, 1.0, null, null, 5.857980995127572, null, 1.0, null, 2.321928094887362, null, 1.584962500721156, null, null, null, 0.0, 1.0, 2.0, 1.0, null, null, 3.584962500721156, 2.584962500721156, null, 2.321928094887362, 2.321928094887362, null, 2.0, 3.321928094887362, null, 1.0, 0.0, 1.0, 2.0, 1.0, null, null, 5.392317422778761, 2.0, 2.0, 1.0, 3.169925001442312, 1.0, 3.169925001442312, 3.807354922057604, null, null, 1.0, null, null, null, null, null, 4.754887502163468, 2.0, 1.0, null, 1.584962500721156, null, 0.0, 0.0, null, 3.321928094887362, 0.0, null, 2.0, 1.0, null, null, 4.392317422778761, null, null, 1.0, 1.584962500721156, 1.584962500721156, 0.0, null, null, 1.0, null, null, null, null, null, null, 3.0, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, 2.0, 2.807354922057604, 4.754887502163468, 4.523561956057013, 4.954196310386875, 3.321928094887362, 3.4594316186372973, 3.4594316186372973, 1.0, 5.426264754702098, 2.807354922057604, 4.321928094887363, 3.807354922057604, 2.807354922057604, null, null, 6.169925001442312, 1.0, 1.584962500721156, null, null, null, 2.0, 1.584962500721156, null, 0.0, null, null, 1.0, 0.0, null, null, 1.584962500721156, 5.0, 4.0, 0.0, 3.584962500721156, 3.169925001442312, 4.0, 4.169925001442312, 0.0, 3.584962500721156, 4.0, 2.584962500721156, null, null, null, null, 1.0, 3.584962500721156, 5.0, 3.700439718141092, 5.459431618637297, 3.0, 5.392317422778761, 5.554588851677638, null, 4.906890595608519, 4.392317422778761, 4.584962500721156, 3.9068905956085187, 2.807354922057604, null, null, 6.108524456778169, 2.584962500721156, 3.700439718141092, 3.700439718141092, 3.169925001442312, 1.0, null, 3.321928094887362, null, 4.807354922057604, 3.321928094887362, 2.807354922057604, 3.807354922057604, 2.807354922057604, null, null, 4.643856189774724, 2.0, null, null, 1.0, 1.584962500721156, 1.584962500721156, null, null, 0.0, 1.584962500721156, null, 0.0, null, null, null, 0.0, null, 1.584962500721156, 1.0, 1.584962500721156, 1.0, 0.0, 1.0, null, 4.087462841250339, 1.584962500721156, 2.0, 1.0, 0.0, null, null, 3.700439718141092, 2.0, 2.0, 1.584962500721156, 2.0, 1.0, 1.0, null, null, 1.584962500721156, 1.584962500721156, null, 2.321928094887362, 1.0, null, null, 2.584962500721156, 1.0, null, 0.0, 2.807354922057604, 0.0, 3.169925001442312, 1.0, null, 0.0, 3.169925001442312, 2.0, null, null, null, null, 5.459431618637297, null, 1.0, 1.584962500721156, 0.0, 1.0, 0.0, 0.0, null, null, 1.0, 0.0, null, null, null, null, 2.584962500721156, null, null, null, 1.0, 0.0, null, null, null, null, 1.584962500721156, null, null, null, null, null, 3.321928094887362, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 3.0, 2.0, 3.169925001442312, 1.0, 1.0, 2.807354922057604, 2.321928094887362, null, 4.700439718141092, 2.807354922057604, 1.0, 2.807354922057604, 2.0, null, null, 1.584962500721156, 8.098032082960527, 8.539158811108031, 8.933690654952233, 9.228818690495881, 7.622051819456376, 9.08214904135387, 8.826548487290914, 4.087462841250339, 9.776433032444734, 8.566054038171092, 8.535275376620802, 7.787902559391432, 6.768184324776926, null, null, 10.467605550082997, 2.0, 1.0, 0.0, 2.0, 2.321928094887362, null, 2.321928094887362, null, 2.584962500721156, 0.0, 4.169925001442312, 2.0, 1.0, null, null, 4.169925001442312, 3.0, 3.807354922057604, 4.906890595608519, 5.78135971352466, 4.392317422778761, 4.807354922057604, 4.954196310386875, 0.0, 5.169925001442312, 4.906890595608519, 3.584962500721156, 0.0, null, null, null, 6.569855608330948, 5.169925001442312, 4.087462841250339, 3.169925001442312, 5.672425341971495, 2.321928094887362, 4.857980995127572, 5.614709844115208, 0.0, 3.0, 4.643856189774724, 3.807354922057604, 1.584962500721156, 1.0, null, null, 8.139551352398794, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.584962500721156, 2.0, 2.0, 2.584962500721156, 0.0, 0.0, 2.0, 3.169925001442312, 0.0, 1.0, 2.807354922057604, 2.0, 1.0, 0.0, null, null, 4.321928094887363, null, null, 2.0, 2.584962500721156, 0.0, 1.0, 3.0, null, null, 1.0, 1.0, 1.0, 0.0, null, null, 5.357552004618084, null, null, null, null, null, 0.0, null, null, null, null, 0.0, null, null, null, null, null, 1.0, null, 1.0, null, null, 0.0, null, null, 1.0, null, null, 1.584962500721156, 0.0, null, null, 1.0, 2.0, 1.0, 2.0, 2.807354922057604, 1.0, 1.0, 3.169925001442312, null, 3.321928094887362, 2.584962500721156, 1.584962500721156, 1.0, 0.0, null, null, 4.169925001442312, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 5.129283016944966, 3.807354922057604, 4.0, 6.906890595608519, 4.321928094887363, 6.930737337562887, 6.569855608330948, null, 3.4594316186372973, 5.247927513443585, 5.20945336562895, 5.459431618637297, 4.459431618637297, null, null, 6.554588851677638, 5.614709844115208, 4.523561956057013, 6.832890014164741, 6.066089190457772, 4.584962500721156, 6.658211482751795, 6.672425341971495, null, 5.044394119358453, 6.339850002884624, 6.357552004618084, 5.129283016944966, 4.087462841250339, null, null, 6.475733430966398, 5.754887502163468, 5.491853096329675, 7.924812503605781, 8.027905996569885, 6.321928094887363, 8.63662462054365, 8.46352437327118, 1.0, 6.768184324776926, 7.539158811108031, 7.303780748177103, 7.1799090900149345, 6.169925001442312, null, null, 1.0, 4.169925001442312, 4.321928094887363, 6.169925001442312, 5.700439718141092, 3.169925001442312, 5.807354922057604, 5.614709844115208, 0.0, 4.459431618637297, 4.754887502163468, 4.584962500721156, 5.643856189774724, 4.643856189774724, null, null, null, 8.475733430966399, 6.044394119358453, null, 8.257387842692651, 5.977279923499917, 8.539158811108031, 8.531381460516313, 1.0, 6.78135971352466, 7.330916878114617, 7.409390936137702, 7.20945336562895, 6.20945336562895, null, null, 4.700439718141092, 8.169925001442312, 7.651051691178929, 5.906890595608519, 7.672425341971495, 6.727920454563199, 8.487840033823051, 8.159871336778389, 3.4594316186372973, 7.523561956057013, 8.339850002884624, 8.308339030139408, 6.894817763307944, 5.882643049361842, null, null, 9.640244936222345, null, 5.491853096329675, null, 1.584962500721156, null, null, null, null, 5.643856189774724, null, 1.0, 1.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, 0.0, 6.129283016944966, 5.247927513443585, 4.169925001442312, 5.832890014164741, 4.643856189774724, 6.285402218862249, 6.108524456778169, 0.0, 5.857980995127572, 5.954196310386875, 4.584962500721156, 5.0, 4.0, null, null, 6.3750394313469245, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 6.285402218862249, 5.357552004618084, 6.392317422778761, 7.22881869049588, 4.523561956057013, 7.60733031374961, 7.247927513443585, 0.0, 6.539158811108031, 6.189824558880018, 6.022367813028454, 6.169925001442312, 5.169925001442312, null, null, 1.584962500721156, 5.954196310386875, 5.554588851677638, 7.700439718141092, 7.159871336778389, 5.727920454563199, 7.98299357469431, 7.169925001442312, 0.0, 7.022367813028454, 6.754887502163468, 6.523561956057013, 6.266786540694901, 5.247927513443585, null, null, 7.700439718141092, 6.584962500721156, 6.554588851677638, 8.219168520462162, 7.768184324776926, 6.044394119358453, 7.813781191217037, 6.714245517666122, 2.0, 5.78135971352466, 7.467605550082998, 7.285402218862249, 6.918863237274595, 5.930737337562887, null, null, 8.954196310386875, 4.459431618637297, 4.0, 5.554588851677638, 5.321928094887363, 3.321928094887362, 5.459431618637297, 5.554588851677638, null, 4.643856189774724, 4.321928094887363, 4.700439718141092, 4.523561956057013, 3.4594316186372973, null, null, 6.339850002884624, 4.807354922057604, 4.523561956057013, 7.734709620225838, 6.247927513443585, 5.285402218862249, 7.483815777264256, 7.159871336778389, 1.584962500721156, 5.321928094887363, 6.523561956057013, 6.339850002884624, 5.977279923499917, 4.954196310386875, null, null, 8.654636028527968, 6.0, 5.930737337562887, 7.679480099505446, 7.451211111832329, 5.044394119358453, 7.491853096329675, 7.507794640198696, 0.0, 6.303780748177103, 6.584962500721156, 6.087462841250339, 5.906890595608519, 4.906890595608519, null, null, 8.129283016944967, 5.584962500721156, 5.392317422778761, 1.0, 8.308339030139408, 6.149747119504682, 8.459431618637296, 8.271463027904375, 1.0, 6.3750394313469245, 7.400879436282184, 7.076815597050831, 7.011227255423254, 6.0, null, null, 8.734709620225837, 3.807354922057604, 3.0, null, 4.584962500721156, 2.807354922057604, 4.523561956057013, 4.087462841250339, null, 2.0, 3.4594316186372973, 3.584962500721156, 4.807354922057604, 3.807354922057604, null, null, 6.266786540694901, null, 4.523561956057013, null, 6.3750394313469245, 4.169925001442312, 7.257387842692652, 7.076815597050831, 1.0, 3.700439718141092, 3.321928094887362, 5.643856189774724, 4.584962500721156, 3.584962500721156, null, null, 8.826548487290914, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.0, 5.807354922057604, 4.954196310386875, 3.321928094887362, 6.894817763307944, 5.523561956057013, 7.577428828035749, 7.672425341971495, 2.321928094887362, 5.700439718141092, 6.832890014164741, 6.714245517666122, 6.20945336562895, 5.20945336562895, null, null, 7.426264754702098, 2.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 4.459431618637297, 2.584962500721156, 4.169925001442312, 6.189824558880018, 4.169925001442312, 6.285402218862249, 6.409390936137702, 0.0, 3.807354922057604, 5.087462841250339, 4.321928094887363, 4.857980995127572, 3.9068905956085187, null, null, 7.087462841250339, 2.0, 2.0, 3.169925001442312, 1.584962500721156, null, 3.4594316186372973, 3.169925001442312, 0.0, 2.0, 2.0, 2.0, null, null, null, null, 4.643856189774724, 5.247927513443585, 3.700439718141092, 6.0, 6.087462841250339, 4.169925001442312, 6.954196310386875, 6.614709844115208, 1.0, 4.0, 5.523561956057013, 6.0, 6.247927513443585, 5.247927513443585, null, null, 7.7481928495894605, 5.643856189774724, 4.459431618637297, 6.087462841250339, 5.426264754702098, 4.321928094887363, 6.409390936137702, 6.266786540694901, 0.0, 3.584962500721156, 4.954196310386875, 4.700439718141092, 5.0, 4.0, null, null, 7.2761244052742375, 5.285402218862249, 4.321928094887363, 6.930737337562887, 6.78135971352466, 3.9068905956085187, 6.78135971352466, 6.857980995127572, 1.0, 5.977279923499917, 5.930737337562887, 5.247927513443585, 5.977279923499917, 5.0, null, null, 7.651051691178929, 4.643856189774724, 4.584962500721156, 6.169925001442312, 6.700439718141092, 4.700439718141092, 6.741466986401147, 6.169925001442312, null, 3.807354922057604, 5.832890014164741, 5.643856189774724, 5.044394119358453, 4.087462841250339, null, null, 7.499845887083206, null, 0.0, null, 1.0, null, 2.0, 1.584962500721156, null, 0.0, null, null, 0.0, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 5.0, 3.584962500721156, null, 5.954196310386875, 3.9068905956085187, 6.523561956057013, 6.22881869049588, 1.584962500721156, 5.392317422778761, 4.807354922057604, 4.700439718141092, 4.584962500721156, 3.584962500721156, null, null, 6.20945336562895, 5.857980995127572, 5.321928094887363, null, 7.189824558880018, 5.044394119358453, 7.592457037268081, 7.400879436282184, 1.0, 6.303780748177103, 6.6293566200796095, 6.169925001442312, 5.807354922057604, 4.807354922057604, null, null, 8.022367813028454, 4.807354922057604, 4.169925001442312, 4.906890595608519, 6.321928094887363, 4.459431618637297, 6.965784284662087, 6.426264754702098, null, 4.643856189774724, 6.321928094887363, 5.554588851677638, 5.700439718141092, 4.700439718141092, null, null, 7.651051691178929, null, null, null, null, null, 1.0, 2.0, null, 1.0, 1.0, null, null, null, null, null, 1.584962500721156, 5.754887502163468, 4.700439718141092, 4.807354922057604, 6.022367813028454, 4.169925001442312, 6.807354922057604, 6.569855608330948, 1.0, 4.321928094887363, 5.491853096329675, 5.754887502163468, 5.285402218862249, 4.247927513443585, null, null, 7.022367813028454, 5.954196310386875, 3.9068905956085187, 5.700439718141092, 5.247927513443585, 2.584962500721156, 6.129283016944966, 5.20945336562895, 0.0, 2.584962500721156, 4.643856189774724, 4.807354922057604, 3.807354922057604, 2.807354922057604, null, null, 6.539158811108031, 5.087462841250339, 4.0, 6.475733430966398, 6.845490050944375, 4.247927513443585, 7.159871336778389, 6.741466986401147, 0.0, 5.906890595608519, 6.066089190457772, 5.523561956057013, 5.954196310386875, 4.954196310386875, null, null, 1.584962500721156, 5.285402218862249, 5.0, 7.366322214245816, 6.108524456778169, 4.459431618637297, 7.303780748177103, 6.954196310386875, 0.0, 3.807354922057604, 6.247927513443585, 5.523561956057013, 5.584962500721156, 4.584962500721156, null, null, 7.936637939002571, 5.643856189774724, 4.906890595608519, 6.426264754702098, 5.78135971352466, 3.807354922057604, 6.491853096329675, 6.149747119504682, null, 5.584962500721156, 5.727920454563199, 5.247927513443585, 4.321928094887363, 3.321928094887362, null, null, null, 4.584962500721156, 4.700439718141092, 5.643856189774724, 5.20945336562895, 3.700439718141092, 6.087462841250339, 5.169925001442312, null, 3.9068905956085187, 5.0, 4.321928094887363, 4.087462841250339, 3.0, null, null, 8.038918989292302, null, null, null, null, null, null, 1.0, null, null, null, null, 1.0, 0.0, null, null, 4.954196310386875, 6.554588851677638, 6.087462841250339, 2.0, 7.044394119358453, 5.614709844115208, 6.658211482751795, 6.442943495848728, 2.321928094887362, 5.807354922057604, 7.285402218862249, 7.409390936137702, 5.247927513443585, 4.247927513443585, null, null, 7.693486957499325, 6.459431618637297, 5.044394119358453, null, 7.266786540694901, 4.857980995127572, 7.584962500721156, 7.643856189774724, 1.584962500721156, 6.066089190457772, 7.129283016944966, 6.977279923499917, 6.426264754702098, 5.426264754702098, null, null, 8.294620748891626, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 1.584962500721156, 7.409390936137702, 5.0, 3.9068905956085187, 6.459431618637297, 3.0, 6.584962500721156, 6.78135971352466, 0.0, 6.539158811108031, 5.857980995127572, 5.857980995127572, 5.584962500721156, 4.584962500721156, null, null, 7.149747119504682, 1.0, null, null, null, null, 0.0, null, null, 1.0, 0.0, null, null, null, null, null, 0.0, 8.247927513443585, 5.672425341971495, 6.442943495848728, 7.876516946564999, 5.285402218862249, 8.011227255423254, 8.129283016944967, 1.584962500721156, 6.0, 7.1799090900149345, 6.6865005271832185, 6.768184324776926, 5.78135971352466, null, null, 3.0, 4.906890595608519, 4.954196310386875, 6.247927513443585, 5.807354922057604, 4.169925001442312, 5.78135971352466, 5.832890014164741, null, 4.523561956057013, 5.426264754702098, 5.357552004618084, 4.584962500721156, 3.584962500721156, null, null, 6.807354922057604, 5.700439718141092, 5.169925001442312, 7.129283016944966, 6.700439718141092, 4.857980995127572, 7.076815597050831, 7.05528243550119, 0.0, 4.857980995127572, 6.303780748177103, 5.954196310386875, 5.857980995127572, 4.857980995127572, null, null, 8.471675214392045, 0.0, null, 1.584962500721156, 1.584962500721156, 0.0, 1.0, 1.0, null, 1.0, 0.0, null, null, null, null, null, 2.321928094887362, 4.247927513443585, 3.321928094887362, 6.0, 6.189824558880018, 4.169925001442312, 6.066089190457772, 6.426264754702098, null, 4.954196310386875, 5.523561956057013, 4.643856189774724, 4.857980995127572, 3.807354922057604, null, null, 7.2384047393250786, 6.0, 4.643856189774724, 5.857980995127572, 5.977279923499917, 4.392317422778761, 6.857980995127572, 6.554588851677638, null, 5.129283016944966, 5.882643049361842, 6.044394119358453, 5.754887502163468, 4.754887502163468, null, null, null, null, 1.0, 0.0, 3.0, null, 2.807354922057604, 1.584962500721156, null, null, 1.0, 1.0, 0.0, null, null, null, 4.087462841250339, 4.0, 2.321928094887362, 0.0, 5.169925001442312, 2.321928094887362, 5.169925001442312, 5.727920454563199, null, 4.087462841250339, 3.584962500721156, 3.321928094887362, 4.523561956057013, 3.4594316186372973, null, null, 6.189824558880018, 5.807354922057604, 4.700439718141092, 5.426264754702098, 7.076815597050831, 4.906890595608519, 7.930737337562887, 7.727920454563199, 1.0, 6.339850002884624, 6.794415866350106, 6.266786540694901, 5.643856189774724, 4.643856189774724, null, null, 8.550746785383243, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 6.169925001442312, 5.643856189774724, 6.599912842187128, 6.930737337562887, 3.807354922057604, 6.3750394313469245, 7.108524456778169, 1.584962500721156, 7.219168520462161, 6.149747119504682, 4.584962500721156, 6.022367813028454, 5.0, null, null, 7.417852514885898, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 6.906890595608519, 5.882643049361842, 3.321928094887362, 8.144658242831882, 6.022367813028454, 8.686500527183219, 8.447083226209653, 2.807354922057604, 6.491853096329675, 7.918863237274595, 7.636624620543649, 6.78135971352466, 5.78135971352466, null, null, 9.262094845370179, 6.426264754702098, 6.20945336562895, 8.366322214245816, 7.894817763307944, 4.954196310386875, 7.882643049361842, 7.523561956057013, 1.0, 7.199672344836364, 7.2761244052742375, 6.426264754702098, 6.189824558880018, 5.169925001442312, null, null, 8.238404739325079, 5.584962500721156, 5.426264754702098, 7.348728154231077, 6.599912842187128, 4.700439718141092, 6.94251450533924, 6.741466986401147, 1.584962500721156, 4.584962500721156, 6.321928094887363, 6.247927513443585, 6.475733430966398, 5.491853096329675, null, null, 7.383704292474052, 4.807354922057604, 4.459431618637297, 6.554588851677638, 6.108524456778169, 3.0, 6.285402218862249, 6.303780748177103, null, 3.169925001442312, 5.392317422778761, 4.321928094887363, 5.882643049361842, 4.906890595608519, null, null, 7.20945336562895, 7.294620748891627, 6.845490050944375, 8.603626344986193, 8.266786540694902, 5.882643049361842, 7.339850002884624, 8.554588851677638, 2.0, 7.442943495848728, 7.918863237274595, 6.554588851677638, 7.9886846867721655, 7.0, null, null, 9.273795599214264, null, 2.0, 2.0, 5.357552004618084, null, 5.554588851677638, 5.357552004618084, null, 2.584962500721156, 1.584962500721156, 1.0, 4.169925001442312, 3.169925001442312, null, null, 7.03342300153745, 2.0, 2.584962500721156, 2.0, 1.584962500721156, null, 2.321928094887362, 0.0, null, 1.0, 0.0, 1.0, 1.0, 0.0, null, null, 0.0, null, 0.0, 0.0, 0.0, null, 0.0, null, null, null, null, 1.0, null, null, null, null, 0.0, 5.643856189774724, 4.584962500721156, 0.0, 5.169925001442312, 4.169925001442312, 6.0, 6.066089190457772, null, 3.0, 5.643856189774724, 5.643856189774724, 5.044394119358453, 4.087462841250339, null, null, 7.643856189774724, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 5.523561956057013, 4.523561956057013, 4.584962500721156, 5.643856189774724, 4.643856189774724, 6.3750394313469245, 6.554588851677638, 2.0, 5.044394119358453, 6.554588851677638, 6.807354922057604, 4.321928094887363, 3.321928094887362, null, null, 7.459431618637297, 6.700439718141092, 5.357552004618084, 2.0, 6.475733430966398, 4.754887502163468, 7.098032082960526, 6.857980995127572, 2.321928094887362, 6.129283016944966, 6.882643049361842, 6.882643049361842, 5.523561956057013, 4.523561956057013, null, null, 0.0, 8.049848549450562, 5.247927513443585, 4.459431618637297, 5.857980995127572, 5.247927513443585, 6.523561956057013, 5.78135971352466, 2.584962500721156, 5.554588851677638, 6.6865005271832185, 6.918863237274595, 4.807354922057604, 3.700439718141092, null, null, 6.845490050944375, 5.78135971352466, 5.426264754702098, 6.285402218862249, 6.044394119358453, 4.700439718141092, 5.977279923499917, 6.0, null, 5.700439718141092, 6.3750394313469245, 6.491853096329675, 5.321928094887363, 4.321928094887363, null, null, 6.569855608330948, 6.108524456778169, 4.857980995127572, 4.459431618637297, 6.066089190457772, 4.906890595608519, 6.426264754702098, 6.339850002884624, 1.0, 5.459431618637297, 6.807354922057604, 6.584962500721156, 5.392317422778761, 4.321928094887363, null, null, 6.700439718141092, 5.78135971352466, 5.643856189774724, 5.832890014164741, 4.169925001442312, 3.0, 4.392317422778761, 5.584962500721156, null, 5.0, 5.169925001442312, 4.700439718141092, 3.700439718141092, 2.584962500721156, null, null, 5.285402218862249, 5.584962500721156, 4.584962500721156, 7.011227255423254, 5.247927513443585, 4.321928094887363, 5.832890014164741, 6.507794640198696, 2.321928094887362, 5.0, 5.754887502163468, 6.129283016944966, 4.584962500721156, 3.584962500721156, null, null, 7.118941072723508, 6.0, 5.700439718141092, 4.700439718141092, 5.78135971352466, 4.643856189774724, 6.392317422778761, 6.108524456778169, null, 5.906890595608519, 6.6293566200796095, 6.0, 4.169925001442312, 3.169925001442312, null, null, 0.0, null, null, null, 0.0, null, null, null, null, 0.0, null, null, null, null, null, null, 0.0, 8.379378367071261, 5.0, 3.9068905956085187, 5.584962500721156, 4.392317422778761, 5.727920454563199, 5.426264754702098, null, 6.20945336562895, 6.022367813028454, 5.129283016944966, 4.807354922057604, 3.807354922057604, null, null, 2.807354922057604, 5.700439718141092, 4.0, null, 5.0, 4.0, 5.700439718141092, 5.247927513443585, 0.0, 4.459431618637297, 5.614709844115208, 5.247927513443585, 2.584962500721156, 1.584962500721156, null, null, 6.303780748177103, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 5.754887502163468, 5.357552004618084, 5.643856189774724, 3.9068905956085187, 3.9068905956085187, 5.392317422778761, 5.321928094887363, null, 5.643856189774724, 5.392317422778761, 5.247927513443585, 2.0, 1.0, null, null, 6.700439718141092, 6.754887502163468, 5.321928094887363, 0.0, 6.507794640198696, 5.459431618637297, 6.599912842187128, 6.870364719583405, null, 5.832890014164741, 7.159871336778389, 6.882643049361842, 5.523561956057013, 4.523561956057013, null, null, 1.0, 5.857980995127572, 5.857980995127572, 1.0, 5.523561956057013, 5.0, 5.614709844115208, 6.066089190457772, 1.584962500721156, 4.807354922057604, 6.149747119504682, 6.022367813028454, 4.0, 3.0, null, null, 7.584962500721156, 6.643856189774724, 5.977279923499917, 7.622051819456376, 5.954196310386875, 5.129283016944966, 6.94251450533924, 6.066089190457772, 1.0, 6.321928094887363, 6.845490050944375, 6.741466986401147, 5.169925001442312, 4.169925001442312, null, null, 7.257387842692652, 5.0, 4.906890595608519, 6.569855608330948, 5.491853096329675, 4.459431618637297, 5.754887502163468, 5.554588851677638, 0.0, 4.523561956057013, 6.0, 5.321928094887363, 5.129283016944966, 4.087462841250339, null, null, 7.339850002884624, 3.0, 2.0, 3.4594316186372973, 3.584962500721156, 1.0, 2.0, 3.169925001442312, null, 3.0, 3.584962500721156, 1.0, 2.0, 1.0, null, null, 3.807354922057604, 5.906890595608519, 6.108524456778169, 6.741466986401147, 6.6865005271832185, 6.169925001442312, 7.442943495848728, 6.845490050944375, 2.321928094887362, 6.20945336562895, 7.727920454563199, 7.539158811108031, 5.977279923499917, 4.954196310386875, null, null, 0.0, 5.357552004618084, 4.584962500721156, null, 5.357552004618084, 4.321928094887363, 5.643856189774724, 5.491853096329675, null, 4.700439718141092, 6.066089190457772, 5.727920454563199, 4.584962500721156, 3.584962500721156, null, null, 5.614709844115208, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 5.523561956057013, 3.9068905956085187, null, 5.643856189774724, 4.0, 5.20945336562895, 5.523561956057013, null, 4.906890595608519, 6.321928094887363, 6.321928094887363, 3.321928094887362, 2.321928094887362, null, null, 6.672425341971495, 5.930737337562887, 5.614709844115208, null, 6.066089190457772, 4.523561956057013, 6.442943495848728, 6.539158811108031, 2.0, 5.357552004618084, 6.768184324776926, 6.409390936137702, 4.087462841250339, 3.0, null, null, 6.78135971352466, 6.754887502163468, 4.169925001442312, 0.0, 3.807354922057604, 2.584962500721156, 4.754887502163468, 4.392317422778761, 1.0, 4.392317422778761, 5.285402218862249, 4.906890595608519, 2.584962500721156, 1.584962500721156, null, null, 5.044394119358453, 4.906890595608519, 4.807354922057604, 4.169925001442312, 5.491853096329675, 3.584962500721156, 4.459431618637297, 5.727920454563199, null, 6.189824558880018, 5.426264754702098, 4.906890595608519, 4.523561956057013, 3.584962500721156, null, null, 1.0, 6.882643049361842, 5.672425341971495, 2.321928094887362, 6.247927513443585, 5.523561956057013, 6.727920454563199, 6.266786540694901, 1.584962500721156, 6.0, 7.022367813028454, 6.930737337562887, 5.523561956057013, 4.523561956057013, null, null, 6.894817763307944, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, 5.672425341971495, 7.321928094887363, 4.643856189774724, 9.287712379549449, 5.247927513443585, 8.734709620225837, 8.005624549193879, 1.0, 8.335390354693924, 7.2761244052742375, 7.7073591320808825, 8.124121311829187, 7.129283016944966, null, null, 11.34318571544788, 4.169925001442312, 5.285402218862249, 2.807354922057604, 6.727920454563199, 4.754887502163468, 6.741466986401147, 6.247927513443585, null, 6.044394119358453, 6.149747119504682, 5.426264754702098, 6.459431618637297, 5.459431618637297, null, null, 9.147204924942228, 5.169925001442312, 6.794415866350106, 3.321928094887362, 8.67595703294175, 5.832890014164741, 8.076815597050832, 7.539158811108031, null, 7.700439718141092, 6.658211482751795, 6.022367813028454, 7.442943495848728, 6.459431618637297, null, null, 10.842350343413807, 3.169925001442312, 5.727920454563199, 5.285402218862249, 6.918863237274595, 3.700439718141092, 6.78135971352466, 6.714245517666122, null, 5.459431618637297, 5.906890595608519, 5.20945336562895, 6.700439718141092, 5.727920454563199, null, null, 9.707359132080883, 4.321928094887363, 5.554588851677638, 3.807354922057604, 8.939579214314692, 5.247927513443585, 8.654636028527968, 7.727920454563199, null, 7.357552004618084, 6.087462841250339, 6.965784284662087, 7.813781191217037, 6.845490050944375, null, null, 11.257387842692651, 4.954196310386875, 6.169925001442312, 2.807354922057604, 6.78135971352466, 4.459431618637297, 6.409390936137702, 5.554588851677638, null, 7.011227255423254, 5.930737337562887, 6.820178962415188, 6.303780748177103, 5.285402218862249, null, null, 9.184875342908283, 4.459431618637297, 6.321928094887363, null, 2.321928094887362, null, 2.0, 4.754887502163468, null, 8.022367813028454, 0.0, 1.0, null, null, null, null, 4.321928094887363, 3.700439718141092, 4.643856189774724, 2.584962500721156, 7.6293566200796095, 4.954196310386875, 7.813781191217037, 6.087462841250339, null, 5.426264754702098, 4.247927513443585, 5.554588851677638, 6.3750394313469245, 5.392317422778761, null, null, 10.216745858195306, null, 0.0, null, null, null, null, 1.0, null, 0.0, null, null, null, null, null, null, 1.0, null, 4.906890595608519, 1.0, 6.78135971352466, 4.247927513443585, 6.658211482751795, 6.357552004618084, null, 5.523561956057013, 4.700439718141092, 4.906890595608519, 5.554588851677638, 4.523561956057013, null, null, 9.579315937580015, 4.754887502163468, 6.189824558880018, 1.584962500721156, 6.491853096329675, 4.459431618637297, 6.022367813028454, 5.523561956057013, 0.0, 6.700439718141092, 6.087462841250339, 6.108524456778169, 5.523561956057013, 4.523561956057013, null, null, 9.057991722759176, 4.321928094887363, 6.108524456778169, 6.727920454563199, 7.832890014164741, 4.0, 8.118941072723507, 7.303780748177103, null, 7.022367813028454, 5.807354922057604, 6.321928094887363, 7.78135971352466, 6.794415866350106, null, null, 10.522581531254831, 4.857980995127572, 7.357552004618084, 5.426264754702098, 8.03342300153745, 5.672425341971495, 7.857980995127572, 7.94251450533924, null, 8.224001674198105, 7.199672344836364, 7.066089190457772, 7.3750394313469245, 6.3750394313469245, null, null, 11.00982861736811, 6.129283016944966, 7.930737337562887, 3.321928094887362, 8.49585502688717, 6.149747119504682, 8.426264754702098, 7.658211482751795, null, 8.744833837499545, 7.754887502163468, 7.2384047393250786, 7.651051691178929, 6.658211482751795, null, null, 11.186114239541643, 4.321928094887363, 7.066089190457772, 3.700439718141092, 7.7615512324444795, 5.554588851677638, 8.252665432450248, 7.0, null, 7.807354922057604, 6.977279923499917, 6.491853096329675, 7.266786540694901, 6.285402218862249, null, null, 10.52061868055628, 3.0, 4.906890595608519, 2.584962500721156, 5.78135971352466, 4.0, 6.918863237274595, 5.727920454563199, 0.0, 6.087462841250339, 5.977279923499917, 6.321928094887363, 6.426264754702098, 5.491853096329675, null, null, 9.189824558880018, 3.0, 5.727920454563199, 1.0, 7.851749041416057, 4.754887502163468, 7.459431618637297, 7.475733430966398, null, 6.930737337562887, 5.807354922057604, 5.426264754702098, 6.658211482751795, 5.672425341971495, null, null, 10.222794902868111, 6.321928094887363, 7.734709620225838, 2.321928094887362, 9.714245517666123, 6.442943495848728, 9.20212382383046, 8.618385502258606, null, 8.686500527183219, 7.864186144654281, 8.326429487122303, 8.968666793195208, 7.98299357469431, null, null, 11.635264656539514, 5.426264754702098, 6.954196310386875, 3.584962500721156, 9.016808287686555, 4.954196310386875, 8.491853096329674, 7.888743248898259, 0.0, 8.335390354693924, 7.247927513443585, 7.714245517666122, 8.280770770130603, 7.2761244052742375, null, null, 11.007728114632254, 2.321928094887362, 4.087462841250339, 0.0, 7.366322214245816, 3.4594316186372973, 6.794415866350106, 5.857980995127572, null, 5.357552004618084, 4.523561956057013, 5.857980995127572, 5.882643049361842, 4.906890595608519, null, null, 9.649256177517314, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, 1.0, 4.459431618637297, 6.22881869049588, 2.807354922057604, 7.339850002884624, 5.491853096329675, 7.977279923499917, 7.118941072723508, null, 6.882643049361842, 5.954196310386875, 5.0, 7.108524456778169, 6.108524456778169, null, null, 10.573647187493322, 4.169925001442312, 6.3750394313469245, 1.584962500721156, 7.651051691178929, 5.357552004618084, 8.413627929024173, 7.960001932068081, null, 7.475733430966398, 6.459431618637297, 5.523561956057013, 7.219168520462161, 6.22881869049588, null, null, 10.67595703294175, 3.4594316186372973, 4.392317422778761, 1.0, 7.219168520462161, 4.392317422778761, 7.515699838284043, 7.1799090900149345, null, 6.266786540694901, 5.044394119358453, 5.169925001442312, 7.011227255423254, 6.108524456778169, null, null, 10.376125389276174, 3.807354922057604, 4.807354922057604, 2.0, 5.285402218862249, 2.321928094887362, 4.754887502163468, 5.392317422778761, 0.0, 5.523561956057013, 4.321928094887363, 4.459431618637297, 4.807354922057604, 3.807354922057604, null, null, 7.60733031374961, 3.0, 4.906890595608519, 5.321928094887363, 7.78135971352466, 3.9068905956085187, 7.599912842187128, 6.820178962415188, null, 5.129283016944966, 5.129283016944966, 5.357552004618084, 7.918863237274595, 6.918863237274595, null, null, 10.554588851677638, 3.169925001442312, 5.459431618637297, 2.321928094887362, 7.417852514885898, 3.700439718141092, 7.417852514885898, 6.554588851677638, 0.0, 6.189824558880018, 5.491853096329675, 5.285402218862249, 7.022367813028454, 6.022367813028454, null, null, 9.868822554774999, 6.727920454563199, 7.643856189774724, 6.22881869049588, 9.266786540694902, 5.857980995127572, 8.915879378835774, 8.409390936137703, 0.0, 9.071462362556623, 7.882643049361842, 8.57742882803575, 8.348728154231077, 7.392317422778761, null, null, 11.64880694972577, 3.807354922057604, 6.392317422778761, 4.087462841250339, 8.900866807980748, 5.285402218862249, 8.303780748177102, 7.577428828035749, null, 7.451211111832329, 6.475733430966398, 7.499845887083206, 8.071462362556623, 7.098032082960526, null, null, 10.933690654952233, 4.459431618637297, 6.247927513443585, 2.584962500721156, 7.434628227636725, 5.321928094887363, 7.994353436858858, 7.312882955284356, null, 6.832890014164741, 6.108524456778169, 6.044394119358453, 7.044394119358453, 6.044394119358453, null, null, 10.1357092861044, 4.169925001442312, 6.321928094887363, 2.321928094887362, 7.734709620225838, 5.426264754702098, 7.870364719583405, 8.038918989292302, null, 7.483815777264256, 6.3750394313469245, 6.022367813028454, 6.643856189774724, 5.672425341971495, null, null, 10.543998450134541, 2.584962500721156, 5.700439718141092, 0.0, 6.6865005271832185, 4.087462841250339, 7.066089190457772, 6.599912842187128, null, 6.247927513443585, 5.614709844115208, 5.247927513443585, 6.149747119504682, 5.169925001442312, null, null, 9.850186837645774, 1.0, null, null, null, null, null, 1.584962500721156, null, 1.0, null, 0.0, null, null, null, null, 0.0, 3.584962500721156, 5.672425341971495, 2.807354922057604, 6.882643049361842, 4.700439718141092, 7.022367813028454, 7.05528243550119, null, 6.339850002884624, 4.906890595608519, 5.392317422778761, 5.643856189774724, 4.643856189774724, null, null, 9.800899899920305, 3.0, 5.0, 2.321928094887362, 7.839203788096944, 4.584962500721156, 7.918863237274595, 7.159871336778389, null, 6.044394119358453, 5.584962500721156, 3.584962500721156, 7.459431618637297, 6.442943495848728, null, null, 10.679480099505446, 2.584962500721156, 4.754887502163468, 1.584962500721156, 6.539158811108031, 3.807354922057604, 6.820178962415188, 6.700439718141092, null, 6.189824558880018, 4.523561956057013, 5.247927513443585, 6.129283016944966, 5.129283016944966, null, null, 9.620219825507487, 6.700439718141092, 8.308339030139408, 5.0, 9.030667136246942, 6.339850002884624, 8.848622940429339, 8.262094845370179, 1.584962500721156, 9.419960177847889, 8.487840033823051, 8.055282435501189, 8.285402218862249, 7.285402218862249, null, null, 11.421012855779226, 3.700439718141092, 6.087462841250339, 1.584962500721156, 6.918863237274595, 4.392317422778761, 7.417852514885898, 6.507794640198696, null, 6.491853096329675, 5.882643049361842, 4.0, 5.459431618637297, 4.584962500721156, null, null, 9.684748620421626, 5.087462841250339, 6.700439718141092, 4.754887502163468, 8.7714894695006, 5.392317422778761, 8.118941072723507, 6.954196310386875, null, 7.794415866350106, 6.794415866350106, 6.741466986401147, 7.658211482751795, 6.658211482751795, null, null, 10.9901039638575, 5.807354922057604, 7.515699838284043, 3.169925001442312, 7.924812503605781, 6.357552004618084, 7.965784284662087, 7.159871336778389, null, 8.199672344836364, 7.442943495848728, 7.066089190457772, 7.741466986401147, 6.741466986401147, null, null, 10.505811553919594, 5.754887502163468, 7.303780748177103, 3.584962500721156, 7.894817763307944, 6.247927513443585, 8.303780748177102, 8.164906926675688, null, 7.800899899920305, 7.05528243550119, 6.189824558880018, 7.539158811108031, 6.539158811108031, null, null, 10.794415866350105, 4.169925001442312, 6.266786540694901, 4.087462841250339, 7.768184324776926, 4.807354922057604, 8.179909090014934, 7.679480099505446, null, 7.169925001442312, 6.584962500721156, 6.339850002884624, 6.672425341971495, 5.700439718141092, null, null, 10.44086916761087, 5.614709844115208, 7.409390936137702, 3.807354922057604, 7.977279923499917, 5.807354922057604, 8.139551352398794, 7.857980995127572, null, 7.6865005271832185, 7.636624620543649, 6.169925001442312, 7.774787059601174, 6.768184324776926, null, null, 11.080817527608327, 3.0, 4.754887502163468, 2.0, 6.741466986401147, 4.169925001442312, 6.266786540694901, 6.108524456778169, null, 5.247927513443585, 5.169925001442312, 5.0, 5.459431618637297, 4.392317422778761, null, null, 9.684748620421626, null, null, null, null, null, null, 1.0, null, 2.0, null, 1.0, null, null, null, null, null, 4.906890595608519, 6.845490050944375, 6.459431618637297, 8.800899899920305, 5.129283016944966, 8.396604781181859, 7.882643049361842, 0.0, 7.599912842187128, 7.189824558880018, 6.672425341971495, 8.651051691178928, 7.658211482751795, null, null, 11.099347810403193, 3.0, 6.044394119358453, 2.807354922057604, 7.189824558880018, 4.459431618637297, 7.839203788096944, 6.807354922057604, null, 6.6293566200796095, 6.22881869049588, 5.426264754702098, 6.94251450533924, 5.954196310386875, null, null, 10.184875342908283, 4.643856189774724, 6.285402218862249, 2.321928094887362, 8.507794640198696, 5.169925001442312, 8.43879185257826, 7.539158811108031, null, 7.20945336562895, 6.569855608330948, 6.523561956057013, 7.965784284662087, 6.977279923499917, null, null, 11.157346935362844, 5.0, 6.6293566200796095, 2.0, 8.139551352398794, 4.906890595608519, 8.238404739325079, 7.734709620225838, 0.0, 7.400879436282184, 6.569855608330948, 6.247927513443585, 7.118941072723508, 6.129283016944966, null, null, 10.73809225962049, 1.0, 4.643856189774724, 2.0, 5.672425341971495, 3.321928094887362, 6.169925001442312, 5.459431618637297, null, 5.0, 4.392317422778761, 4.321928094887363, 5.044394119358453, 4.0, null, null, 8.707359132080883, 6.554588851677638, 7.219168520462161, 3.0, 8.335390354693924, 5.832890014164741, 7.924812503605781, 7.651051691178929, 1.0, 8.184875342908283, 7.417852514885898, 7.330916878114617, 7.700439718141092, 6.700439718141092, null, null, 10.83605035505807, 5.807354922057604, 6.491853096329675, 2.321928094887362, 7.9886846867721655, 5.643856189774724, 7.7073591320808825, 7.285402218862249, null, 7.584962500721156, 7.011227255423254, 7.011227255423254, 8.149747119504681, 7.149747119504682, null, null, 10.667111542075027, 3.0, 5.614709844115208, 0.0, 6.442943495848728, 3.169925001442312, 6.643856189774724, 6.658211482751795, null, 6.409390936137702, 5.459431618637297, 5.169925001442312, 6.426264754702098, 5.426264754702098, null, null, 9.677719641641009, 5.832890014164741, 6.6293566200796095, 4.954196310386875, 7.6293566200796095, 4.700439718141092, 7.924812503605781, 7.577428828035749, 1.0, 7.426264754702098, 6.507794640198696, 6.303780748177103, 7.0, 6.022367813028454, null, null, 10.27262978497637, 4.459431618637297, 5.906890595608519, 0.0, 8.405141463136344, 5.0, 8.741466986401146, 7.906890595608519, null, 6.643856189774724, 6.321928094887363, 5.321928094887363, 8.0, 7.022367813028454, null, null, 10.897845456005511, 3.0, 3.584962500721156, 2.321928094887362, 6.426264754702098, 3.321928094887362, 7.312882955284356, 6.794415866350106, null, 4.754887502163468, 4.643856189774724, 4.0, 6.321928094887363, 5.357552004618084, null, null, 9.73640193131829, null, null, null, null, null, null, null, null, 1.0, null, null, null, null, null, null, 0.0, 4.523561956057013, 6.599912842187128, 2.321928094887362, 8.308339030139408, 5.523561956057013, 8.189824558880018, 8.011227255423254, null, 7.636624620543649, 6.954196310386875, 6.108524456778169, 7.636624620543649, 6.643856189774724, null, null, 11.04916787237217, 2.0, 5.700439718141092, 2.584962500721156, 7.800899899920305, 4.321928094887363, 7.614709844115208, 7.22881869049588, null, 6.507794640198696, 6.066089190457772, 5.426264754702098, 7.409390936137702, 6.426264754702098, null, null, 10.442943495848729, 5.0, 5.78135971352466, 2.807354922057604, 8.308339030139408, 4.700439718141092, 7.700439718141092, 7.076815597050831, null, 6.754887502163468, 5.523561956057013, 6.672425341971495, 7.392317422778761, 6.409390936137702, null, null, 10.395534135462302, 6.0, 7.546894459887636, 5.977279923499917, 8.686500527183219, 6.044394119358453, 8.741466986401146, 8.243173983472952, null, 8.507794640198696, 7.189824558880018, 7.507794640198696, 7.651051691178929, 6.643856189774724, null, null, 11.257387842692651, 4.523561956057013, 7.066089190457772, 2.807354922057604, 8.276124405274238, 5.584962500721156, 8.280770770130603, 7.6293566200796095, 1.584962500721156, 7.936637939002571, 6.768184324776926, 7.321928094887363, 7.857980995127572, 6.870364719583405, null, null, 10.82097669262124, 7.546894459887636, 8.483815777264256, 3.700439718141092, 9.071462362556623, 6.954196310386875, 8.794415866350105, 8.103287808412022, 2.584962500721156, 9.521600439723727, 8.611024797307353, 9.243173983472952, 8.257387842692651, 7.294620748891627, null, null, 11.029977346589579, 4.807354922057604, 5.672425341971495, 1.584962500721156, 6.977279923499917, 5.044394119358453, 7.087462841250339, 6.857980995127572, null, 7.159871336778389, 5.392317422778761, 5.392317422778761, 6.0, 5.0, null, null, 9.733015321685963, 1.0, null, null, 4.584962500721156, null, 4.392317422778761, 3.807354922057604, null, null, 1.0, 1.0, 3.807354922057604, 2.807354922057604, null, null, 7.294620748891627, 6.820178962415188, 7.7615512324444795, 7.651051691178929, 9.364134655008051, 6.108524456778169, 9.011227255423254, 8.348728154231077, 1.0, 8.807354922057604, 8.189824558880018, 8.413627929024173, 8.614709844115207, 7.622051819456376, null, null, 11.394462694610317, 3.584962500721156, 4.523561956057013, 2.0, 7.383704292474052, 4.700439718141092, 7.169925001442312, 6.94251450533924, null, 6.247927513443585, 5.044394119358453, 4.754887502163468, 6.94251450533924, 5.954196310386875, null, null, 10.032045726930809, 4.584962500721156, 6.491853096329675, 1.0, 7.569855608330948, 4.954196310386875, 7.507794640198696, 7.539158811108031, 0.0, 7.348728154231077, 6.539158811108031, 4.857980995127572, 7.076815597050831, 6.087462841250339, null, null, 10.5980525001616, null, null, null, 0.0, null, null, null, null, null, null, null, 0.0, null, null, null, null, 4.321928094887363, 4.954196310386875, 2.0, 6.129283016944966, 3.807354922057604, 5.930737337562887, 5.554588851677638, null, 6.22881869049588, 4.754887502163468, 5.0, 5.0, 4.0, null, null, 8.63662462054365, 5.321928094887363, 6.741466986401147, 3.0, 7.108524456778169, 4.700439718141092, 7.20945336562895, 6.475733430966398, 1.0, 7.851749041416057, 6.442943495848728, 6.857980995127572, 6.459431618637297, 5.459431618637297, null, null, 9.857980995127573, 4.0, 6.523561956057013, 3.321928094887362, 6.700439718141092, 3.807354922057604, 6.357552004618084, 5.554588851677638, 1.0, 7.0, 5.459431618637297, 6.507794640198696, 5.700439718141092, 4.700439718141092, null, null, 9.027905996569885, 7.562242424221073, 8.661778097771988, 4.754887502163468, 8.997179480937621, 6.285402218862249, 8.573647187493322, 8.379378367071261, null, 9.459431618637296, 8.348728154231077, 9.337621901992508, 8.066089190457772, 7.076815597050831, null, null, 11.07347215397646, 6.894817763307944, 8.134426320220927, 4.169925001442312, 8.129283016944967, 6.321928094887363, 8.149747119504681, 7.434628227636725, null, 9.095397022792557, 8.038918989292302, 8.092757140919852, 7.584962500721156, 6.584962500721156, null, null, 10.499845887083206, 7.507794640198696, 9.049848549450562, 3.321928094887362, 8.139551352398794, 6.554588851677638, 8.257387842692651, 8.339850002884624, null, 10.002815015607053, 8.426264754702098, 7.592457037268081, 7.467605550082998, 6.459431618637297, null, null, 10.750706986224948, 5.754887502163468, 7.442943495848728, 2.0, 7.6865005271832185, 5.727920454563199, 7.6653359171851765, 7.159871336778389, null, 8.169925001442312, 7.366322214245816, 7.483815777264256, 7.087462841250339, 6.108524456778169, 0.0, 0.0, 10.105908508571158, 6.169925001442312, 7.954196310386875, 3.169925001442312, 7.6865005271832185, 5.754887502163468, 8.011227255423254, 7.870364719583405, null, 8.78135971352466, 7.562242424221073, 7.643856189774724, 7.467605550082998, 6.475733430966398, null, null, 10.399811959325685, 6.3750394313469245, 7.426264754702098, 2.584962500721156, 7.651051691178929, 5.523561956057013, 7.546894459887636, 7.108524456778169, null, 8.224001674198105, 7.05528243550119, 7.22881869049588, 7.066089190457772, 6.066089190457772, null, null, 9.915879378835774, 5.977279923499917, 7.087462841250339, 1.0, 7.357552004618084, 5.906890595608519, 7.643856189774724, 7.507794640198696, null, 8.228818690495881, 6.882643049361842, 7.108524456778169, 6.794415866350106, 5.807354922057604, null, null, 10.019590728357882, 4.700439718141092, 5.832890014164741, 2.584962500721156, 6.584962500721156, 4.0, 6.303780748177103, 5.554588851677638, 0.0, 7.076815597050831, 5.977279923499917, 5.882643049361842, 4.906890595608519, 3.9068905956085187, null, null, 9.041659151637214, null, null, null, 0.0, null, 1.0, null, null, null, null, null, null, null, null, null, 0.0, 4.906890595608519, 5.700439718141092, 1.0, 6.189824558880018, 4.643856189774724, 6.569855608330948, 5.672425341971495, null, 6.820178962415188, 5.357552004618084, 7.05528243550119, 5.754887502163468, 4.807354922057604, null, null, 9.116343961237469, 5.129283016944966, 6.807354922057604, 3.4594316186372973, 7.129283016944966, 4.584962500721156, 6.965784284662087, 6.459431618637297, null, 7.754887502163468, 6.6865005271832185, 6.614709844115208, 6.285402218862249, 5.285402218862249, null, null, 9.663558104217273, 3.584962500721156, 5.807354922057604, 1.0, 4.523561956057013, 2.584962500721156, 5.977279923499917, 4.700439718141092, null, 5.700439718141092, 4.459431618637297, 4.0, 4.321928094887363, 3.321928094887362, null, null, 8.344295907915816, 7.78135971352466, 8.894817763307943, 6.78135971352466, 8.643856189774725, 7.129283016944966, 8.960001932068081, 8.199672344836364, 1.584962500721156, 9.954196310386875, 8.974414589805527, 8.73809225962049, 7.876516946564999, 6.906890595608519, null, null, 11.449148645375436, 4.906890595608519, 6.599912842187128, 2.584962500721156, 6.727920454563199, 4.247927513443585, 6.507794640198696, 6.0, null, 7.139551352398794, 6.247927513443585, 6.303780748177103, 5.491853096329675, 4.459431618637297, null, null, 9.118941072723507, 6.794415866350106, 7.965784284662087, 4.643856189774724, 8.219168520462162, 6.6865005271832185, 8.076815597050832, 8.164906926675688, null, 8.900866807980748, 7.392317422778761, 7.679480099505446, 7.721099188707185, 6.741466986401147, null, null, 10.62662165235837, 5.906890595608519, 7.442943495848728, 3.169925001442312, 7.714245517666122, 5.614709844115208, 7.434628227636725, 6.6293566200796095, null, 8.189824558880018, 6.954196310386875, 7.800899899920305, 6.965784284662087, 5.954196310386875, null, null, 10.154818109052105, 5.554588851677638, 7.303780748177103, 3.4594316186372973, 7.7481928495894605, 5.357552004618084, 7.499845887083206, 7.721099188707185, 0.0, 8.103287808412022, 7.129283016944966, 6.78135971352466, 6.700439718141092, 5.672425341971495, null, null, 10.361943773735241, null, 2.0, null, 0.0, 1.584962500721156, 1.0, 0.0, null, 2.584962500721156, 2.584962500721156, 2.0, 2.0, 1.0, null, null, 3.700439718141092, 5.357552004618084, 7.0, 2.321928094887362, 6.807354922057604, 5.0, 7.169925001442312, 7.011227255423254, null, 7.7073591320808825, 6.426264754702098, 5.643856189774724, 5.321928094887363, 4.321928094887363, null, null, 9.469641817239516, 4.0, 5.643856189774724, 1.584962500721156, 6.303780748177103, 4.0, 6.321928094887363, 5.392317422778761, null, 6.321928094887363, 5.672425341971495, 6.614709844115208, 4.700439718141092, 3.700439718141092, null, null, 8.611024797307353, null, null, null, null, null, null, 1.0, null, 0.0, null, 0.0, null, null, null, null, 0.0, 5.285402218862249, 6.507794640198696, 2.321928094887362, 7.03342300153745, 5.044394119358453, 6.894817763307944, 6.523561956057013, null, 7.303780748177103, 5.930737337562887, 6.442943495848728, 6.614709844115208, 5.614709844115208, null, null, 9.296916206879288, 4.247927513443585, 6.832890014164741, 3.4594316186372973, 6.614709844115208, 4.954196310386875, 6.94251450533924, 6.584962500721156, null, 7.787902559391432, 6.507794640198696, 5.554588851677638, 6.426264754702098, 5.426264754702098, null, null, 9.842350343413807, 2.584962500721156, 4.754887502163468, 1.0, 4.321928094887363, 2.321928094887362, 5.357552004618084, 3.0, null, 4.754887502163468, 4.0, 4.247927513443585, 3.584962500721156, 2.584962500721156, null, null, 7.679480099505446, 5.459431618637297, 6.321928094887363, 6.700439718141092, 8.930737337562887, 4.754887502163468, 9.038918989292302, 8.487840033823051, null, 7.087462841250339, 6.906890595608519, 7.066089190457772, 8.832890014164741, 7.845490050944375, null, null, 11.439830883981392, 4.584962500721156, 6.599912842187128, 3.169925001442312, 8.08214904135387, 4.954196310386875, 7.918863237274595, 7.426264754702098, null, 7.467605550082998, 7.312882955284356, 6.754887502163468, 7.483815777264256, 6.491853096329675, null, null, 10.580258567499788, 4.459431618637297, 5.357552004618084, 2.807354922057604, 8.08214904135387, 4.643856189774724, 8.219168520462162, 6.491853096329675, null, 7.03342300153745, 5.882643049361842, 6.022367813028454, 7.451211111832329, 6.459431618637297, null, null, 10.234817431117325, 4.584962500721156, 5.700439718141092, 1.584962500721156, 6.672425341971495, 3.700439718141092, 7.294620748891627, 6.189824558880018, 0.0, 6.700439718141092, 5.044394119358453, 5.20945336562895, 5.954196310386875, 5.0, null, null, 9.83605035505807, 4.459431618637297, 6.022367813028454, 2.584962500721156, 9.121533517340032, 5.392317422778761, 7.906890595608519, 7.643856189774724, null, 7.285402218862249, 6.321928094887363, 7.169925001442312, 8.271463027904375, 7.285402218862249, null, null, 11.124767535822473, 5.700439718141092, 6.741466986401147, 3.321928094887362, 7.366322214245816, 4.857980995127572, 7.189824558880018, 6.6293566200796095, null, 7.900866807980749, 6.475733430966398, 7.451211111832329, 6.507794640198696, 5.523561956057013, null, null, 9.661778097771988, 6.584962500721156, 7.820178962415188, null, 3.807354922057604, 1.0, 3.169925001442312, 6.0, 0.0, 9.364134655008051, 2.0, 0.0, 1.0, 0.0, null, null, 6.321928094887363, 5.392317422778761, 6.882643049361842, 2.321928094887362, 9.071462362556623, 5.129283016944966, 8.848622940429339, 8.39231742277876, null, 8.066089190457772, 6.954196310386875, 7.219168520462161, 8.45532722030456, 7.451211111832329, null, null, 11.602234901341063, 5.906890595608519, 7.383704292474052, 3.0, 7.554588851677638, 5.672425341971495, 7.700439718141092, 7.507794640198696, null, 8.851749041416058, 7.467605550082998, 7.383704292474052, 7.366322214245816, 6.3750394313469245, null, null, 10.462502272597265, 4.459431618637297, 6.321928094887363, 1.584962500721156, 7.882643049361842, 5.169925001442312, 7.330916878114617, 7.087462841250339, 0.0, 7.3750394313469245, 6.339850002884624, 6.0, 6.6293566200796095, 5.643856189774724, null, null, 10.28886607416582, 6.475733430966398, 7.994353436858858, 3.807354922057604, 7.94251450533924, 6.321928094887363, 7.643856189774724, 7.693486957499325, 0.0, 9.221587121264806, 7.787902559391432, 8.247927513443585, 7.392317422778761, 6.392317422778761, null, null, 10.310612781659529, 5.0, 6.768184324776926, 5.285402218862249, 8.665335917185176, 5.754887502163468, 8.507794640198696, 8.08214904135387, null, 7.9886846867721655, 7.294620748891627, 6.303780748177103, 8.066089190457772, 7.118941072723508, null, null, 11.197830998012197, 4.0, 6.044394119358453, 3.4594316186372973, 8.228818690495881, 5.491853096329675, 7.820178962415188, 8.066089190457772, null, 7.129283016944966, 6.523561956057013, 6.066089190457772, 7.994353436858858, 7.0, null, null, 10.469641817239516, 4.459431618637297, 6.918863237274595, 7.0, 8.055282435501189, 4.954196310386875, 8.194756854422248, 7.924812503605781, null, 7.700439718141092, 6.977279923499917, 6.658211482751795, 8.383704292474052, 7.383704292474052, null, null, 10.84313591111135, 4.584962500721156, 6.087462841250339, 1.0, 7.577428828035749, 3.9068905956085187, 7.400879436282184, 6.392317422778761, null, 7.066089190457772, 5.643856189774724, 6.392317422778761, 6.918863237274595, 5.930737337562887, null, null, 9.881113960675096, 4.906890595608519, 6.129283016944966, 3.4594316186372973, 8.459431618637296, 6.149747119504682, 7.857980995127572, 7.727920454563199, null, 8.038918989292302, 7.475733430966398, 7.483815777264256, 7.894817763307944, 6.906890595608519, null, null, 10.909893083770042, 5.643856189774724, 7.312882955284356, 3.0, 8.842350343413807, 5.832890014164741, 8.64745842645492, 8.055282435501189, null, 8.519636252843213, 7.6865005271832185, 7.2384047393250786, 8.233619676759702, 7.2384047393250786, null, null, 11.130570562805426, 5.977279923499917, 6.882643049361842, 2.321928094887362, 8.867278739709661, 6.247927513443585, 8.434628227636725, 8.144658242831882, null, 8.312882955284355, 7.451211111832329, 7.954196310386875, 8.252665432450248, 7.247927513443585, null, null, 10.877284133523196, 5.247927513443585, 7.139551352398794, 2.807354922057604, 8.038918989292302, 5.20945336562895, 7.930737337562887, 7.826548487290915, null, 7.507794640198696, 6.714245517666122, 6.94251450533924, 6.820178962415188, 5.832890014164741, null, null, 10.450180247164754, 4.906890595608519, 6.741466986401147, 4.643856189774724, 8.523561956057012, 5.491853096329675, 7.971543553950772, 7.577428828035749, null, 7.845490050944375, 6.930737337562887, 6.954196310386875, 8.087462841250339, 7.108524456778169, null, null, 10.830515206976838, 6.044394119358453, 7.787902559391432, 2.0, 8.741466986401146, 5.78135971352466, 8.700439718141093, 8.247927513443585, null, 8.78135971352466, 7.546894459887636, 7.247927513443585, 8.768184324776927, 7.774787059601174, null, null, 11.36468185586456, 6.285402218862249, 7.426264754702098, 2.0, 8.507794640198696, 5.459431618637297, 8.45532722030456, 8.276124405274238, 0.0, 8.654636028527968, 7.409390936137702, 7.087462841250339, 8.0, 7.011227255423254, null, null, 10.902375114486025, 5.044394119358453, 7.022367813028454, 1.0, 7.960001932068081, 4.857980995127572, 7.826548487290915, 7.622051819456376, null, 8.027905996569885, 6.832890014164741, 6.554588851677638, 7.076815597050831, 6.087462841250339, null, null, 10.687375683437468, 5.169925001442312, 6.954196310386875, 4.459431618637297, 9.124121311829187, 5.954196310386875, 9.038918989292302, 8.804131021183318, null, 8.124121311829187, 7.400879436282184, 7.321928094887363, 8.405141463136344, 7.434628227636725, null, null, 11.776844232402167, 1.0, 3.9068905956085187, 0.0, 4.584962500721156, null, 3.0, 4.169925001442312, null, 4.643856189774724, 3.169925001442312, 3.584962500721156, 4.0, 3.0, null, null, 6.794415866350106, 4.321928094887363, 6.523561956057013, 4.0, 8.539158811108031, 4.954196310386875, 8.43879185257826, 7.9886846867721655, null, 7.330916878114617, 6.820178962415188, 5.882643049361842, 7.900866807980749, 6.906890595608519, null, null, 11.151016538892248, 4.643856189774724, 5.554588851677638, null, 7.800899899920305, 4.584962500721156, 7.366322214245816, 7.22881869049588, null, 6.727920454563199, 5.906890595608519, 5.700439718141092, 6.977279923499917, 5.977279923499917, null, null, 10.030667136246942, 5.0, 6.247927513443585, 2.807354922057604, 7.888743248898259, 5.321928094887363, 7.960001932068081, 7.3750394313469245, null, 7.451211111832329, 6.20945336562895, 6.442943495848728, 7.6293566200796095, 6.643856189774724, null, null, 10.445014845868423, 5.584962500721156, 7.108524456778169, 4.321928094887363, 8.980139577639157, 6.149747119504682, 8.965784284662087, 8.566054038171092, 0.0, 8.339850002884624, 7.2384047393250786, 7.339850002884624, 8.271463027904375, 7.294620748891627, null, null, 11.47826403158172, 6.832890014164741, 7.930737337562887, 3.9068905956085187, 9.154818109052105, 6.357552004618084, 8.915879378835774, 8.873444112515376, 1.0, 8.668884984266247, 8.214319120800766, 8.312882955284355, 8.39231742277876, 7.383704292474052, null, null, 11.590119174107175, 5.321928094887363, 7.149747119504682, 2.321928094887362, 8.651051691178928, 5.643856189774724, 7.851749041416057, 7.636624620543649, null, 8.118941072723507, 7.499845887083206, 7.434628227636725, 7.813781191217037, 6.845490050944375, null, null, 10.703038388986418, 6.247927513443585, 7.285402218862249, 5.459431618637297, 9.20212382383046, 6.321928094887363, 8.700439718141093, 8.294620748891626, null, 8.741466986401146, 7.577428828035749, 8.098032082960527, 8.169925001442312, 7.20945336562895, null, null, 11.2940463132715, 5.882643049361842, 7.3750394313469245, 3.807354922057604, 9.184875342908283, 6.459431618637297, 8.693486957499326, 8.672425341971495, 0.0, 8.430452551665532, 7.6865005271832185, 7.569855608330948, 8.717676423066395, 7.727920454563199, null, null, 11.596655667674662, 6.845490050944375, 8.20945336562895, 3.169925001442312, 9.403012023574997, 6.409390936137702, 9.038918989292302, 8.727920454563199, 0.0, 9.147204924942228, 8.344295907915816, 8.409390936137703, 8.405141463136344, 7.409390936137702, null, null, 11.642954223480332, 5.857980995127572, 7.087462841250339, 2.0, 8.734709620225837, 5.857980995127572, 8.74819284958946, 8.159871336778389, null, 7.714245517666122, 7.2761244052742375, 6.930737337562887, 7.924812503605781, 6.965784284662087, null, null, 11.254438148267257, 4.321928094887363, 6.658211482751795, 3.9068905956085187, 8.768184324776927, 6.066089190457772, 8.303780748177102, 8.124121311829187, 1.584962500721156, 8.344295907915816, 7.22881869049588, 6.906890595608519, 7.794415866350106, 6.857980995127572, null, null, 11.025831668332026, 2.584962500721156, 5.087462841250339, 1.0, 7.339850002884624, 3.700439718141092, 6.614709844115208, 5.977279923499917, 1.0, 5.807354922057604, 5.554588851677638, 5.459431618637297, 5.285402218862249, 4.321928094887363, null, null, 9.405141463136344, 3.0, 4.247927513443585, 3.584962500721156, 6.9886846867721655, 3.807354922057604, 6.94251450533924, 6.0, 0.0, 5.285402218862249, 5.20945336562895, 4.523561956057013, 7.303780748177103, 6.321928094887363, null, null, 9.831307243802051, 3.584962500721156, 4.906890595608519, null, 7.076815597050831, 3.321928094887362, 7.20945336562895, 6.491853096329675, null, 5.78135971352466, 5.321928094887363, 4.754887502163468, 6.832890014164741, 5.832890014164741, null, null, 9.888743248898258, 3.0, 5.584962500721156, 1.0, 6.643856189774724, 3.0, 6.357552004618084, 6.22881869049588, null, 6.768184324776926, 5.426264754702098, 5.727920454563199, 6.247927513443585, 5.285402218862249, null, null, 9.207014320177532, 5.169925001442312, 6.807354922057604, 3.4594316186372973, 8.442943495848729, 6.0, 7.721099188707185, 7.894817763307944, null, 7.727920454563199, 6.9886846867721655, 6.599912842187128, 7.813781191217037, 6.832890014164741, null, null, 10.618385502258606, 5.0, 6.339850002884624, 2.807354922057604, 8.087462841250339, 5.357552004618084, 7.714245517666122, 7.651051691178929, 1.0, 7.721099188707185, 6.832890014164741, 6.700439718141092, 7.499845887083206, 6.523561956057013, null, null, 10.788718332690458, 5.247927513443585, 7.20945336562895, 3.0, 8.507794640198696, 5.977279923499917, 8.169925001442312, 7.577428828035749, null, 7.9886846867721655, 7.339850002884624, 7.94251450533924, 7.714245517666122, 6.727920454563199, null, null, 10.884933647949762, 5.169925001442312, 7.330916878114617, 4.169925001442312, 9.177419537989236, 6.087462841250339, 8.539158811108031, 8.290018846932618, null, 8.285402218862249, 7.658211482751795, 7.965784284662087, 8.668884984266247, 7.6653359171851765, null, null, 11.409390936137703, 5.523561956057013, 6.044394119358453, 3.321928094887362, 7.20945336562895, 5.20945336562895, 7.285402218862249, 7.03342300153745, null, 7.383704292474052, 6.475733430966398, 6.129283016944966, 6.930737337562887, 5.930737337562887, null, null, 10.271463027904375, 5.0, 6.022367813028454, 2.321928094887362, 7.6653359171851765, 4.584962500721156, 7.149747119504682, 7.011227255423254, null, 7.442943495848728, 5.977279923499917, 6.129283016944966, 6.491853096329675, 5.523561956057013, null, null, 10.083479327331842, 5.20945336562895, 6.554588851677638, 6.285402218862249, 8.044394119358454, 4.643856189774724, 7.882643049361842, 7.820178962415188, null, 7.22881869049588, 7.022367813028454, 6.442943495848728, 7.768184324776926, 6.768184324776926, null, null, 10.726218159332198, 4.459431618637297, 6.339850002884624, 3.807354922057604, 9.238404739325079, 6.129283016944966, 8.413627929024173, 8.471675214392045, null, 7.6865005271832185, 6.906890595608519, 7.169925001442312, 8.422064766172813, 7.442943495848728, null, null, 11.651051691178928, 3.584962500721156, 5.392317422778761, 2.807354922057604, 7.348728154231077, 4.754887502163468, 7.622051819456376, 6.870364719583405, null, 5.930737337562887, 5.807354922057604, 5.285402218862249, 7.129283016944966, 6.129283016944966, null, null, 10.51175265376738, 3.584962500721156, 5.754887502163468, 3.0, 7.6865005271832185, 3.321928094887362, 6.918863237274595, 6.507794640198696, null, 6.321928094887363, 5.807354922057604, 5.754887502163468, 6.754887502163468, 5.78135971352466, null, null, 9.90388184573618, 4.459431618637297, 6.247927513443585, 4.321928094887363, 8.632995197142957, 5.0, 8.535275376620802, 7.924812503605781, null, 7.2761244052742375, 6.794415866350106, 6.754887502163468, 7.7615512324444795, 6.820178962415188, null, null, 11.156083076288681, 3.584962500721156, 5.087462841250339, 5.614709844115208, 7.658211482751795, 3.807354922057604, 7.199672344836364, 7.20945336562895, null, 6.0, 5.832890014164741, 5.0, 7.05528243550119, 6.066089190457772, null, null, 9.909893083770042, 4.392317422778761, 5.78135971352466, 2.321928094887362, 7.562242424221073, 4.643856189774724, 7.693486957499325, 6.930737337562887, 0.0, 6.930737337562887, 5.930737337562887, 5.554588851677638, 6.954196310386875, 5.977279923499917, null, null, 10.422064766172813, 4.584962500721156, 5.832890014164741, 2.0, 8.044394119358454, 4.584962500721156, 7.643856189774724, 7.189824558880018, null, 7.366322214245816, 6.442943495848728, 6.700439718141092, 7.392317422778761, 6.409390936137702, null, null, 10.311748315004959, 4.584962500721156, 6.491853096329675, 2.321928094887362, 9.339850002884624, 6.149747119504682, 8.980139577639157, 8.459431618637296, null, 7.658211482751795, 7.087462841250339, 7.523561956057013, 8.682994583681683, 7.7073591320808825, null, null, 11.67595703294175, 4.700439718141092, 6.247927513443585, 2.0, 8.467605550082997, 5.169925001442312, 8.643856189774725, 8.46352437327118, null, 7.247927513443585, 6.539158811108031, 6.882643049361842, 8.379378367071261, 7.392317422778761, null, null, 11.519636252843213, 6.321928094887363, 7.807354922057604, 6.977279923499917, 9.603626344986193, 5.906890595608519, 9.144658242831882, 8.807354922057604, 0.0, 8.20945336562895, 7.912889336229962, 7.60733031374961, 9.211888294546004, 8.224001674198105, null, null, 11.912515144802397, 4.754887502163468, 6.820178962415188, 4.0, 8.632995197142957, 5.672425341971495, 8.312882955284355, 7.087462841250339, null, 7.7615512324444795, 6.614709844115208, 6.794415866350106, 8.276124405274238, 7.321928094887363, null, null, 11.005624549193879, 4.754887502163468, 6.906890595608519, 3.807354922057604, 8.768184324776927, 5.321928094887363, 8.326429487122303, 8.189824558880018, null, 7.622051819456376, 7.409390936137702, 7.499845887083206, 8.442943495848729, 7.459431618637297, null, null, 11.244958393151133, 4.247927513443585, 6.22881869049588, 4.321928094887363, 8.46352437327118, 5.491853096329675, 8.308339030139408, 7.768184324776926, null, 7.515699838284043, 6.247927513443585, 5.459431618637297, 7.845490050944375, 6.857980995127572, null, null, 11.078817949961978, 4.459431618637297, 6.754887502163468, 3.0, 8.098032082960527, 5.700439718141092, 7.636624620543649, 6.870364719583405, null, 7.451211111832329, 6.807354922057604, 6.321928094887363, 7.066089190457772, 6.066089190457772, null, null, 10.539158811108031, 3.0, 4.584962500721156, null, 6.954196310386875, 3.584962500721156, 6.643856189774724, 5.491853096329675, null, 5.727920454563199, 4.807354922057604, 4.584962500721156, 6.044394119358453, 5.044394119358453, null, null, 9.303780748177102, 1.0, 4.087462841250339, 2.321928094887362, 7.294620748891627, 3.807354922057604, 7.011227255423254, 6.918863237274595, null, 5.930737337562887, 5.643856189774724, 5.930737337562887, 7.189824558880018, 6.20945336562895, null, null, 10.100662339005199, 4.807354922057604, 6.727920454563199, 4.857980995127572, 8.531381460516313, 5.285402218862249, 8.087462841250339, 7.693486957499325, 0.0, 7.312882955284356, 7.05528243550119, 6.569855608330948, 7.864186144654281, 6.870364719583405, null, null, 10.98655314975666, null, 2.584962500721156, 0.0, 6.129283016944966, 2.584962500721156, 4.857980995127572, 5.491853096329675, null, 3.4594316186372973, 2.584962500721156, 1.0, 3.807354922057604, 2.807354922057604, null, null, 8.400879436282183, 4.906890595608519, 6.614709844115208, 3.584962500721156, 8.734709620225837, 5.426264754702098, 8.515699838284043, 7.1799090900149345, null, 7.754887502163468, 7.129283016944966, 7.044394119358453, 8.159871336778389, 7.199672344836364, null, null, 11.039604517953759, 3.807354922057604, 5.392317422778761, 2.321928094887362, 7.614709844115208, 5.129283016944966, 7.294620748891627, 6.491853096329675, null, 5.584962500721156, 5.614709844115208, 4.247927513443585, 6.794415866350106, 5.807354922057604, null, null, 10.233619676759702, 4.584962500721156, 6.266786540694901, 6.727920454563199, 8.159871336778389, 4.700439718141092, 7.693486957499325, 7.515699838284043, null, 7.159871336778389, 6.714245517666122, 5.930737337562887, 7.977279923499917, 7.0, null, null, 10.428360172704291, 5.321928094887363, 6.918863237274595, 0.0, 7.129283016944966, 4.584962500721156, 6.918863237274595, 6.845490050944375, null, 8.098032082960527, 6.569855608330948, 7.011227255423254, 6.507794640198696, 5.554588851677638, null, null, 9.939579214314692, 4.700439718141092, 6.539158811108031, 2.807354922057604, 7.592457037268081, 5.087462841250339, 7.7073591320808825, 7.066089190457772, 0.0, 7.7481928495894605, 6.672425341971495, 6.169925001442312, 7.03342300153745, 6.044394119358453, null, null, 10.052568050804153, 5.426264754702098, 6.794415866350106, 3.169925001442312, 7.774787059601174, 4.754887502163468, 7.599912842187128, 7.05528243550119, null, 8.098032082960527, 6.754887502163468, 7.139551352398794, 7.149747119504682, 6.189824558880018, null, null, 10.250298417906333, 5.857980995127572, 6.426264754702098, 3.0, 7.129283016944966, 5.392317422778761, 7.159871336778389, 6.754887502163468, 0.0, 8.214319120800766, 6.807354922057604, 7.491853096329675, 6.6865005271832185, 5.672425341971495, null, null, 9.935165049603695, 5.0, 6.965784284662087, 3.321928094887362, 7.321928094887363, 4.523561956057013, 6.714245517666122, 6.426264754702098, null, 7.679480099505446, 6.507794640198696, 7.219168520462161, 6.700439718141092, 5.700439718141092, null, null, 9.426264754702098, 5.392317422778761, 6.584962500721156, 3.584962500721156, 7.0, 3.807354922057604, 6.714245517666122, 6.266786540694901, 0.0, 7.584962500721156, 6.357552004618084, 6.906890595608519, 6.409390936137702, 5.426264754702098, null, null, 9.499845887083206, 3.807354922057604, 5.321928094887363, 0.0, 4.459431618637297, 2.0, 4.0, 4.0, null, 6.129283016944966, 4.169925001442312, 4.459431618637297, 3.321928094887362, 2.321928094887362, null, null, 7.139551352398794, 3.9068905956085187, 5.906890595608519, 2.0, 6.189824558880018, 3.9068905956085187, 6.247927513443585, 5.78135971352466, 0.0, 7.076815597050831, 6.0, 5.672425341971495, 5.882643049361842, 4.906890595608519, null, null, 9.12670447284319, 4.459431618637297, 6.658211482751795, 3.321928094887362, 6.3750394313469245, 4.906890595608519, 7.044394119358453, 6.523561956057013, 0.0, 7.894817763307944, 6.285402218862249, 5.807354922057604, 6.672425341971495, 5.672425341971495, null, null, 9.51175265376738, 5.285402218862249, 6.409390936137702, 2.584962500721156, 7.149747119504682, 4.643856189774724, 6.6865005271832185, 5.754887502163468, null, 7.515699838284043, 6.022367813028454, 6.768184324776926, 6.741466986401147, 5.754887502163468, null, null, 9.564149489985732, 5.0, 7.592457037268081, 3.169925001442312, 8.022367813028454, 5.882643049361842, 8.124121311829187, 7.6653359171851765, null, 8.997179480937621, 7.768184324776926, 7.366322214245816, 7.546894459887636, 6.569855608330948, null, null, 10.643856189774725, 4.459431618637297, 6.339850002884624, 2.584962500721156, 6.523561956057013, 4.392317422778761, 6.539158811108031, 5.882643049361842, 0.0, 7.7481928495894605, 6.189824558880018, 5.977279923499917, 6.108524456778169, 5.129283016944966, null, null, 9.116343961237469, 4.700439718141092, 6.321928094887363, 1.584962500721156, 6.794415866350106, 4.459431618637297, 6.700439718141092, 6.882643049361842, null, 7.768184324776926, 6.20945336562895, 6.409390936137702, 6.491853096329675, 5.523561956057013, null, null, 9.475733430966399, 5.930737337562887, 7.569855608330948, 3.169925001442312, 7.857980995127572, 5.129283016944966, 7.741466986401147, 7.0, 1.0, 8.73809225962049, 7.357552004618084, 7.03342300153745, 6.754887502163468, 5.754887502163468, null, null, 10.121533517340032, 6.247927513443585, 7.1799090900149345, 1.0, 7.303780748177103, 4.857980995127572, 6.94251450533924, 6.78135971352466, 1.0, 8.08214904135387, 6.6865005271832185, 6.584962500721156, 6.303780748177103, 5.285402218862249, null, null, 9.848622940429339, 6.0, 7.22881869049588, 2.807354922057604, 7.876516946564999, 5.169925001442312, 7.442943495848728, 7.22881869049588, 0.0, 8.247927513443585, 6.930737337562887, 7.800899899920305, 6.491853096329675, 5.554588851677638, null, null, 9.94104760634058, 5.044394119358453, 6.658211482751795, 2.807354922057604, 6.409390936137702, 4.807354922057604, 6.392317422778761, 6.614709844115208, 0.0, 7.826548487290915, 6.392317422778761, 6.475733430966398, 6.321928094887363, 5.321928094887363, null, null, 9.194756854422248, 3.807354922057604, 6.108524456778169, 1.0, 5.523561956057013, 4.584962500721156, 6.539158811108031, 5.523561956057013, null, 7.087462841250339, 5.857980995127572, 5.832890014164741, 5.584962500721156, 4.584962500721156, null, null, 9.129283016944967, 5.169925001442312, 6.22881869049588, 1.584962500721156, 6.044394119358453, 3.9068905956085187, 6.392317422778761, 5.672425341971495, 0.0, 7.149747119504682, 5.554588851677638, 6.149747119504682, 5.584962500721156, 4.643856189774724, null, null, 8.83605035505807, 4.169925001442312, 6.0, 1.584962500721156, 6.169925001442312, 4.459431618637297, 5.357552004618084, 5.643856189774724, 0.0, 7.149747119504682, 5.523561956057013, 5.954196310386875, 5.0, 4.087462841250339, null, null, 8.599912842187127, 3.584962500721156, 6.247927513443585, 1.584962500721156, 6.754887502163468, 3.700439718141092, 6.426264754702098, 5.832890014164741, 0.0, 7.531381460516312, 6.066089190457772, 6.599912842187128, 5.977279923499917, 5.0, null, null, 9.339850002884624, 2.0, 2.0, 1.0, 2.0, 0.0, 2.0, 3.169925001442312, null, 2.584962500721156, 2.807354922057604, 2.584962500721156, null, null, null, null, 4.807354922057604, 5.087462841250339, 6.965784284662087, 1.0, 7.189824558880018, 5.087462841250339, 7.189824558880018, 5.954196310386875, null, 8.233619676759702, 6.523561956057013, 6.584962500721156, 5.954196310386875, 5.044394119358453, null, null, 9.60177078840771, null, 5.614709844115208, null, 6.20945336562895, 3.321928094887362, 5.247927513443585, 3.9068905956085187, null, 6.658211482751795, 0.0, 6.149747119504682, 5.554588851677638, 4.523561956057013, null, null, 8.515699838284043, 5.247927513443585, 6.768184324776926, 2.321928094887362, 7.257387842692652, 5.044394119358453, 7.321928094887363, 6.845490050944375, null, 8.243173983472952, 6.857980995127572, 6.672425341971495, 6.599912842187128, 5.614709844115208, null, null, 9.929258408636972, 4.906890595608519, 6.6865005271832185, 3.169925001442312, 6.954196310386875, 4.700439718141092, 7.011227255423254, 6.672425341971495, null, 8.038918989292302, 6.523561956057013, 6.392317422778761, 6.954196310386875, 5.930737337562887, null, null, 9.481799431665753, 5.807354922057604, 7.523561956057013, 2.807354922057604, 7.592457037268081, 5.78135971352466, 7.1799090900149345, 6.870364719583405, 0.0, 8.330916878114618, 7.257387842692652, 7.577428828035749, 6.754887502163468, 5.754887502163468, null, null, 10.037546953962178, null, 0.0, null, 0.0, null, null, null, null, 3.0, null, null, null, null, null, null, 1.0, 3.321928094887362, 4.807354922057604, 1.0, 8.487840033823051, 4.857980995127572, 8.0, 6.599912842187128, null, 5.857980995127572, 5.169925001442312, 6.022367813028454, 7.658211482751795, 6.658211482751795, 2.0, 2.0, 10.63662462054365, 2.0, 5.247927513443585, 2.584962500721156, 7.357552004618084, 4.321928094887363, 6.977279923499917, 6.78135971352466, null, 6.285402218862249, 6.189824558880018, 6.3750394313469245, 6.9886846867721655, 5.977279923499917, null, null, 9.567956075415466, 3.0, 5.247927513443585, 2.807354922057604, 7.266786540694901, 4.321928094887363, 7.219168520462161, 6.584962500721156, null, 6.087462841250339, 5.357552004618084, 5.807354922057604, 7.426264754702098, 6.459431618637297, null, null, 9.967226258835993, 5.169925001442312, 6.247927513443585, 2.584962500721156, 8.599912842187127, 4.459431618637297, 8.011227255423254, 7.734709620225838, null, 7.366322214245816, 6.459431618637297, 7.022367813028454, 7.768184324776926, 6.768184324776926, null, null, 10.527477006060396, 2.0, 4.0, 2.0, 6.906890595608519, 4.087462841250339, 7.108524456778169, 6.9886846867721655, null, 5.954196310386875, 4.700439718141092, 3.4594316186372973, 6.658211482751795, 5.672425341971495, null, null, 9.99859042974533, 4.906890595608519, 6.20945336562895, 6.339850002884624, 6.870364719583405, 3.0, 6.409390936137702, 6.599912842187128, 2.321928094887362, 7.651051691178929, 6.930737337562887, 6.022367813028454, 6.700439718141092, 5.700439718141092, null, null, 9.52943055414615, 4.169925001442312, 5.954196310386875, null, 2.0, 0.0, 1.584962500721156, 4.169925001442312, null, 7.876516946564999, 0.0, null, 1.0, 0.0, null, null, 4.0, 4.0, 5.614709844115208, 3.169925001442312, 8.78135971352466, 5.129283016944966, 8.357552004618084, 7.434628227636725, null, 6.6293566200796095, 5.727920454563199, 6.6865005271832185, 7.78135971352466, 6.78135971352466, null, null, 11.080151309614088, 6.285402218862249, 7.442943495848728, 6.247927513443585, 7.257387842692652, 5.357552004618084, 7.499845887083206, 7.1799090900149345, null, 8.72451385311995, 7.169925001442312, 7.011227255423254, 7.087462841250339, 6.108524456778169, null, null, 9.977279923499916, 4.584962500721156, 5.954196310386875, 2.807354922057604, 7.6865005271832185, 4.754887502163468, 7.894817763307944, 7.546894459887636, null, 7.05528243550119, 6.442943495848728, 5.321928094887363, 7.339850002884624, 6.339850002884624, null, null, 10.353146825498083, 4.459431618637297, 6.357552004618084, 3.0, 7.294620748891627, 4.321928094887363, 7.434628227636725, 6.569855608330948, 0.0, 6.857980995127572, 6.129283016944966, 5.882643049361842, 7.129283016944966, 6.129283016944966, null, null, 9.896332403909941, 5.321928094887363, 6.247927513443585, 4.0, 7.592457037268081, 4.459431618637297, 7.3750394313469245, 6.894817763307944, null, 7.087462841250339, 6.357552004618084, 5.672425341971495, 7.118941072723508, 6.129283016944966, null, null, 10.12670447284319, 3.807354922057604, 5.643856189774724, 3.4594316186372973, 7.924812503605781, 5.129283016944966, 7.820178962415188, 7.499845887083206, null, 7.076815597050831, 6.930737337562887, 7.03342300153745, 7.03342300153745, 6.044394119358453, null, null, 10.332036548361652, 4.169925001442312, 6.044394119358453, 2.584962500721156, 7.60733031374961, 4.169925001442312, 7.6865005271832185, 7.169925001442312, 0.0, 7.159871336778389, 6.044394119358453, 5.523561956057013, 7.087462841250339, 6.087462841250339, null, null, 10.381542951184585, 5.044394119358453, 5.754887502163468, 4.584962500721156, 8.640244936222345, 4.700439718141092, 8.179909090014934, 7.247927513443585, null, 7.087462841250339, 6.022367813028454, 6.169925001442312, 7.807354922057604, 6.820178962415188, null, null, 10.667998535672528, 5.044394119358453, 5.930737337562887, 4.0, 7.894817763307944, 4.247927513443585, 7.714245517666122, 6.807354922057604, 0.0, 7.266786540694901, 5.906890595608519, 6.491853096329675, 7.266786540694901, 6.266786540694901, null, null, 10.333155350310616, 2.584962500721156, 4.247927513443585, 1.0, 7.303780748177103, 3.4594316186372973, 7.774787059601174, 6.475733430966398, null, 4.754887502163468, 4.754887502163468, 4.584962500721156, 7.149747119504682, 6.20945336562895, null, null, 10.205793249397157, 4.321928094887363, 5.285402218862249, 3.584962500721156, 8.554588851677638, 5.321928094887363, 8.294620748891626, 7.584962500721156, null, 7.409390936137702, 6.507794640198696, 6.882643049361842, 7.787902559391432, 6.845490050944375, null, null, 11.079484783826816, 3.321928094887362, 4.459431618637297, 0.0, 4.954196310386875, 2.0, 4.523561956057013, 4.754887502163468, null, 5.700439718141092, 3.4594316186372973, 3.9068905956085187, 3.807354922057604, 2.807354922057604, 2.0, 2.0, 7.491853096329675, 6.247927513443585, 7.022367813028454, 4.247927513443585, 8.945443836377912, 5.459431618637297, 8.531381460516313, 8.603626344986193, 1.0, 8.499845887083206, 7.813781191217037, 7.149747119504682, 8.238404739325079, 7.257387842692652, null, null, 11.500343969270403, 5.087462841250339, 6.3750394313469245, 1.0, 7.219168520462161, 4.700439718141092, 7.734709620225838, 7.247927513443585, null, 7.467605550082998, 6.266786540694901, 5.087462841250339, 7.339850002884624, 6.339850002884624, null, null, 10.293471648838134, 5.857980995127572, 6.459431618637297, 4.0, 8.087462841250339, 4.807354922057604, 7.774787059601174, 7.451211111832329, null, 7.734709620225838, 6.247927513443585, 7.0, 7.936637939002571, 6.965784284662087, null, null, 10.443979542601253, 3.4594316186372973, 5.044394119358453, 2.321928094887362, 7.199672344836364, 4.392317422778761, 7.483815777264256, 7.03342300153745, null, 6.339850002884624, 5.044394119358453, 5.247927513443585, 7.076815597050831, 6.087462841250339, null, null, 9.954196310386875, 3.807354922057604, 5.700439718141092, 3.4594316186372973, 7.906890595608519, 4.392317422778761, 7.531381460516312, 6.882643049361842, 0.0, 6.700439718141092, 6.149747119504682, 5.78135971352466, 7.2761244052742375, 6.285402218862249, null, null, 10.377210530388552, 4.321928094887363, 6.754887502163468, 2.0, 8.335390354693924, 4.643856189774724, 7.864186144654281, 7.330916878114617, 1.0, 7.6865005271832185, 6.906890595608519, 6.857980995127572, 7.614709844115208, 6.6293566200796095, null, null, 10.452241240430817, 3.584962500721156, 5.930737337562887, 1.0, 7.0, 4.247927513443585, 6.714245517666122, 6.584962500721156, null, 6.845490050944375, 5.523561956057013, 6.22881869049588, 6.965784284662087, 6.022367813028454, 2.0, 2.0, 9.731319031025064, 4.321928094887363, 4.906890595608519, 2.321928094887362, 7.475733430966398, 4.247927513443585, 7.366322214245816, 7.0, null, 5.523561956057013, 5.321928094887363, 5.727920454563199, 7.294620748891627, 6.303780748177103, null, null, 10.088788238716907, 4.169925001442312, 6.584962500721156, 0.0, 7.794415866350106, 4.459431618637297, 7.599912842187128, 7.507794640198696, null, 7.20945336562895, 6.247927513443585, 5.977279923499917, 7.383704292474052, 6.3750394313469245, null, null, 10.380461065088973, 4.321928094887363, 5.614709844115208, 5.832890014164741, 7.930737337562887, 4.523561956057013, 7.159871336778389, 7.139551352398794, null, 6.768184324776926, 6.303780748177103, 5.78135971352466, 7.451211111832329, 6.459431618637297, null, null, 10.280770770130603, 3.0, 5.321928094887363, 1.584962500721156, 7.721099188707185, 4.0, 7.531381460516312, 6.643856189774724, null, 6.409390936137702, 5.584962500721156, 5.614709844115208, 7.05528243550119, 6.066089190457772, null, null, 10.18239435340453, 5.700439718141092, 6.807354922057604, 0.0, 7.383704292474052, 5.20945336562895, 7.658211482751795, 7.247927513443585, null, 8.03342300153745, 6.768184324776926, 6.409390936137702, 7.087462841250339, 6.087462841250339, null, null, 10.023754353299417, 3.169925001442312, 5.584962500721156, 2.0, 6.426264754702098, 2.584962500721156, 6.569855608330948, 6.442943495848728, null, 6.523561956057013, 5.321928094887363, 5.321928094887363, 5.807354922057604, 4.807354922057604, null, null, 9.515699838284043, 5.321928094887363, 6.599912842187128, 2.584962500721156, 7.321928094887363, 4.523561956057013, 7.257387842692652, 6.658211482751795, 1.584962500721156, 7.459431618637297, 6.491853096329675, 6.303780748177103, 7.022367813028454, 6.044394119358453, null, null, 9.843921051289035, 5.554588851677638, 6.554588851677638, 2.321928094887362, 8.569855608330949, 5.321928094887363, 7.900866807980749, 7.087462841250339, null, 8.098032082960527, 6.672425341971495, 6.965784284662087, 7.679480099505446, 6.6865005271832185, null, null, 10.523561956057012, 4.392317422778761, 5.954196310386875, 3.584962500721156, 8.154818109052105, 4.643856189774724, 8.08214904135387, 7.562242424221073, null, 7.22881869049588, 6.189824558880018, 6.539158811108031, 7.467605550082998, 6.507794640198696, null, null, 10.711666973564347, 4.169925001442312, 5.614709844115208, 2.584962500721156, 7.169925001442312, 3.700439718141092, 6.442943495848728, 6.442943495848728, null, 6.409390936137702, 5.882643049361842, 5.643856189774724, 6.918863237274595, 5.930737337562887, null, null, 9.353146825498083, 4.807354922057604, 6.022367813028454, 3.700439718141092, 7.727920454563199, 4.754887502163468, 7.727920454563199, 7.076815597050831, null, 6.599912842187128, 6.303780748177103, 5.643856189774724, 7.554588851677638, 6.569855608330948, null, null, 10.46454575033394, 4.584962500721156, 5.930737337562887, 1.584962500721156, 7.199672344836364, 3.700439718141092, 7.7073591320808825, 7.076815597050831, null, 6.285402218862249, 6.129283016944966, 4.0, 6.768184324776926, 5.754887502163468, null, null, 9.614709844115207, 3.807354922057604, 5.044394119358453, 2.807354922057604, 7.400879436282184, 4.087462841250339, 7.108524456778169, 6.643856189774724, null, 6.022367813028454, 5.044394119358453, 5.129283016944966, 6.954196310386875, 6.0, null, null, 10.164906926675688, 4.0, 5.247927513443585, 1.0, 7.562242424221073, 4.392317422778761, 7.539158811108031, 7.870364719583405, null, 6.339850002884624, 5.672425341971495, 3.700439718141092, 6.820178962415188, 5.832890014164741, null, null, 10.339850002884624, 4.392317422778761, 6.108524456778169, 3.169925001442312, 8.184875342908283, 4.754887502163468, 7.774787059601174, 7.076815597050831, null, 7.22881869049588, 6.491853096329675, 6.6865005271832185, 7.475733430966398, 6.491853096329675, null, null, 10.62296694479051, 4.807354922057604, 5.727920454563199, 2.807354922057604, 7.636624620543649, 4.584962500721156, 7.78135971352466, 6.507794640198696, null, 7.129283016944966, 6.149747119504682, 6.321928094887363, 7.087462841250339, 6.087462841250339, null, null, 10.345405246717796, 4.0, 4.392317422778761, 2.321928094887362, 8.361943773735241, 4.754887502163468, 7.78135971352466, 7.0, null, 5.954196310386875, 6.044394119358453, 6.247927513443585, 8.03342300153745, 7.05528243550119, null, null, 10.750706986224948, 4.584962500721156, 6.066089190457772, 3.584962500721156, 8.826548487290914, 5.392317422778761, 8.426264754702098, 8.060695931687555, 0.0, 6.6865005271832185, 6.20945336562895, 6.882643049361842, 8.011227255423254, 7.03342300153745, null, null, 11.082814337672273, 3.321928094887362, 5.554588851677638, 5.20945336562895, 7.409390936137702, 4.523561956057013, 7.523561956057013, 6.820178962415188, null, 6.339850002884624, 5.426264754702098, 5.247927513443585, 7.285402218862249, 6.321928094887363, null, null, 10.326429487122303, 4.459431618637297, 5.807354922057604, 2.0, 7.562242424221073, 4.643856189774724, 7.257387842692652, 6.6865005271832185, 0.0, 7.0, 6.285402218862249, 5.392317422778761, 7.426264754702098, 6.442943495848728, null, null, 9.994353436858859, 3.584962500721156, 4.321928094887363, 1.0, 6.409390936137702, 2.807354922057604, 6.022367813028454, 6.339850002884624, null, 5.78135971352466, 4.247927513443585, 4.643856189774724, 5.727920454563199, 4.754887502163468, null, null, 9.152284842306582, 4.700439718141092, 5.129283016944966, 1.0, 6.78135971352466, 3.4594316186372973, 6.741466986401147, 6.189824558880018, null, 6.714245517666122, 5.459431618637297, 5.044394119358453, 6.189824558880018, 5.169925001442312, null, null, 9.590587049915035, 5.392317422778761, 6.539158811108031, 3.0, 8.108524456778168, 5.0, 7.554588851677638, 7.247927513443585, 0.0, 7.339850002884624, 6.658211482751795, 6.672425341971495, 7.467605550082998, 6.475733430966398, null, null, 10.429406741513981, null, 2.0, null, 3.321928094887362, 0.0, 3.700439718141092, 1.584962500721156, null, 1.584962500721156, 1.0, null, 3.169925001442312, 2.321928094887362, null, null, 6.523561956057013, 4.0, 6.087462841250339, 1.0, 8.134426320220927, 4.906890595608519, 7.900866807980749, 7.60733031374961, null, 7.330916878114617, 6.554588851677638, 6.409390936137702, 7.523561956057013, 6.539158811108031, null, null, 10.60177078840771, 2.584962500721156, 4.906890595608519, 1.0, 7.03342300153745, 3.321928094887362, 6.339850002884624, 6.584962500721156, null, 5.247927513443585, 4.247927513443585, 4.247927513443585, 6.129283016944966, 5.129283016944966, null, null, 9.533329732305834, 3.584962500721156, 4.857980995127572, 1.584962500721156, 7.366322214245816, 4.0, 6.820178962415188, 6.491853096329675, null, 6.554588851677638, 5.044394119358453, 5.882643049361842, 6.754887502163468, 5.78135971352466, null, null, 9.79603960882977, 5.321928094887363, 6.727920454563199, 3.169925001442312, 7.467605550082998, 4.247927513443585, 6.78135971352466, 6.569855608330948, null, 8.159871336778389, 6.882643049361842, 6.965784284662087, 6.20945336562895, 5.169925001442312, null, null, 9.54882190845875, 5.832890014164741, 6.714245517666122, 2.807354922057604, 7.139551352398794, 4.523561956057013, 6.78135971352466, 6.700439718141092, 1.0, 7.515699838284043, 6.22881869049588, 7.442943495848728, 6.169925001442312, 5.169925001442312, null, null, 9.546894459887637, 5.392317422778761, 6.491853096329675, 2.321928094887362, 6.149747119504682, 4.857980995127572, 6.442943495848728, 6.523561956057013, 0.0, 7.754887502163468, 6.285402218862249, 5.169925001442312, 6.321928094887363, 5.285402218862249, null, null, 9.149747119504681, 5.321928094887363, 6.339850002884624, 1.584962500721156, 5.169925001442312, 2.807354922057604, 5.044394119358453, 5.044394119358453, null, 7.2761244052742375, 5.426264754702098, 4.906890595608519, 5.169925001442312, 4.169925001442312, 1.0, 1.0, 8.03342300153745, 6.044394119358453, 6.9886846867721655, 1.584962500721156, 6.727920454563199, 4.643856189774724, 7.507794640198696, 7.189824558880018, null, 8.066089190457772, 6.845490050944375, 7.022367813028454, 6.643856189774724, 5.643856189774724, null, null, 9.407267764244732, 4.807354922057604, 6.129283016944966, 2.0, 6.321928094887363, 4.247927513443585, 6.459431618637297, 5.78135971352466, null, 7.434628227636725, 6.044394119358453, 6.0, 6.044394119358453, 5.044394119358453, null, null, 9.014020470314934, 5.087462841250339, 6.339850002884624, 0.0, 6.339850002884624, 4.321928094887363, 6.321928094887363, 5.882643049361842, 0.0, 7.1799090900149345, 5.906890595608519, 6.658211482751795, 6.0, 5.0, null, null, 8.997179480937621, 4.321928094887363, 4.906890595608519, 1.584962500721156, 5.20945336562895, 2.321928094887362, 4.906890595608519, 5.169925001442312, null, 6.129283016944966, 4.754887502163468, 5.426264754702098, 4.321928094887363, 3.321928094887362, 1.0, 1.0, 8.016808287686555, 4.0, 5.247927513443585, 1.584962500721156, 6.087462841250339, 4.087462841250339, 5.700439718141092, 5.78135971352466, null, 6.9886846867721655, 5.700439718141092, 5.672425341971495, 5.459431618637297, 4.459431618637297, null, null, 8.566054038171092, 4.857980995127572, 5.614709844115208, null, 6.149747119504682, 2.0, 6.285402218862249, 5.906890595608519, 0.0, 6.614709844115208, 5.459431618637297, 5.129283016944966, 6.129283016944966, 5.129283016944966, null, null, 8.74819284958946, 3.807354922057604, 6.20945336562895, 1.584962500721156, 5.044394119358453, 2.807354922057604, 5.357552004618084, 5.357552004618084, null, 6.78135971352466, 5.0, 4.459431618637297, 5.044394119358453, 4.0, null, null, 7.977279923499917, 5.20945336562895, 6.918863237274595, 4.392317422778761, 7.20945336562895, 4.321928094887363, 6.459431618637297, 6.044394119358453, null, 7.60733031374961, 6.882643049361842, 6.459431618637297, 5.977279923499917, 5.0, null, null, 9.394462694610317, 4.700439718141092, 6.0, 1.584962500721156, 6.459431618637297, 4.087462841250339, 5.392317422778761, 5.523561956057013, null, 6.768184324776926, 5.672425341971495, 5.426264754702098, 5.247927513443585, 4.321928094887363, null, null, 8.744833837499545, 4.906890595608519, 5.807354922057604, 4.700439718141092, 5.672425341971495, 3.700439718141092, 5.614709844115208, 4.643856189774724, null, 6.658211482751795, 5.491853096329675, 5.459431618637297, 6.149747119504682, 5.169925001442312, null, null, 8.31741261376487, 5.285402218862249, 6.584962500721156, 3.4594316186372973, 6.918863237274595, 4.857980995127572, 7.159871336778389, 6.0, null, 7.417852514885898, 6.507794640198696, 6.672425341971495, 6.169925001442312, 5.20945336562895, null, null, 9.54882190845875, null, 1.0, null, 1.0, 0.0, null, null, null, 2.321928094887362, 2.0, 1.0, null, null, null, null, 4.087462841250339, 4.459431618637297, 5.78135971352466, 3.0, 5.247927513443585, 3.9068905956085187, 5.459431618637297, 4.906890595608519, null, 6.870364719583405, 5.392317422778761, 5.78135971352466, 5.247927513443585, 4.247927513443585, null, null, 8.546894459887637, 4.700439718141092, 6.066089190457772, 3.321928094887362, 6.554588851677638, 4.584962500721156, 6.727920454563199, 6.129283016944966, null, 6.906890595608519, 5.930737337562887, 6.584962500721156, 5.584962500721156, 4.584962500721156, null, null, 8.885696373339394, 4.0, 4.857980995127572, 2.321928094887362, 5.426264754702098, 2.584962500721156, 5.672425341971495, 5.357552004618084, null, 6.303780748177103, 4.643856189774724, 5.392317422778761, 5.700439718141092, 4.700439718141092, null, null, 8.20945336562895], "y0": " ", "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"], ["3R", "AIM18"], ["3R", "AIM19"], ["3R", "AIM20"], ["3R", "AIM21"], ["3R", "AIM22"], ["3R", "AIM23"], ["3R", "AIM24"], ["3R", "D7R2"], ["3R", "Gste_tag1"], ["3R", "Gste_tag2"], ["3R", "Gste_F120L"], ["3R", "Gste_L119V"], ["3R", "Gste_I114T"], ["3R", "Gste_tag3"]], "hovertemplate": "contig=%{customdata[0]}<br>amplicon=%{x}<br>log_depth=%{y}<br>mutation=%{customdata[1]}<extra></extra>", "legendgroup": "3R", "marker": {"color": "#FF7F0E"}, "name": "3R", "notched": false, "offsetgroup": "3R", "orientation": "v", "showlegend": true, "type": "box", "x": ["Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_63", "Agam_63", "Agam_64"], "x0": " ", "xaxis": "x", "y": [9.44086916761087, 5.285402218862249, 5.087462841250339, 3.807354922057604, 5.321928094887363, 5.357552004618084, 5.169925001442312, 4.643856189774724, null, 4.906890595608519, 3.4594316186372973, 3.4594316186372973, 4.584962500721156, 6.066089190457772, 5.247927513443585, 3.321928094887362, 2.807354922057604, 1.0, 2.584962500721156, 2.0, 3.321928094887362, 3.9068905956085187, null, 2.0, 0.0, 0.0, 1.0, 2.0, 2.0, 0.0, 0.0, 2.0, null, 1.0, null, null, null, 1.0, null, null, 1.584962500721156, 1.0, 4.247927513443585, 1.0, 1.0, 2.321928094887362, 1.0, 0.0, 1.0, 2.0, null, 2.0, null, null, 0.0, null, 5.807354922057604, 2.0, 1.0, 1.584962500721156, 1.584962500721156, 1.0, 1.0, 2.0, null, null, null, null, null, null, 5.906890595608519, 5.285402218862249, 4.523561956057013, 2.584962500721156, 3.700439718141092, 4.247927513443585, 4.459431618637297, 4.700439718141092, null, null, 2.807354922057604, 2.807354922057604, 3.807354922057604, 1.0, 0.0, 4.459431618637297, null, null, null, 3.169925001442312, 1.0, 4.087462841250339, null, null, 0.0, 0.0, 1.0, 1.0, 2.0, 0.0, 0.0, 1.0, null, null, null, null, null, null, null, null, 1.0, 1.0, null, 0.0, 0.0, 0.0, null, 0.0, null, null, null, 1.0, null, null, 1.0, 1.0, 5.78135971352466, 3.0, 3.0, 2.321928094887362, 2.807354922057604, 2.584962500721156, 2.0, 2.0, null, 2.0, 0.0, 0.0, 1.584962500721156, 1.0, 1.0, 2.321928094887362, 0.0, 3.0, 3.0, 1.584962500721156, 2.321928094887362, 1.584962500721156, null, null, 0.0, 0.0, 1.584962500721156, 1.584962500721156, 2.584962500721156, 1.584962500721156, 2.0, 0.0, null, null, 2.321928094887362, null, null, 1.0, null, null, null, 1.584962500721156, 6.22881869049588, 4.807354922057604, 2.807354922057604, 3.4594316186372973, 3.321928094887362, 4.523561956057013, 2.807354922057604, 3.807354922057604, null, 4.169925001442312, null, null, null, 0.0, 7.2384047393250786, 5.20945336562895, 4.584962500721156, 4.0, 4.087462841250339, 5.044394119358453, 3.9068905956085187, 3.700439718141092, null, 1.0, 2.0, 2.0, 3.4594316186372973, 4.0, 5.554588851677638, 2.584962500721156, null, 2.321928094887362, 1.0, 2.321928094887362, 2.584962500721156, 3.321928094887362, null, null, 0.0, 0.0, 1.584962500721156, null, 5.754887502163468, 2.321928094887362, 1.0, 2.807354922057604, 2.807354922057604, 1.0, 3.4594316186372973, 2.584962500721156, null, null, 0.0, 0.0, 2.321928094887362, 1.0, 5.426264754702098, 1.584962500721156, 0.0, 1.584962500721156, 3.0, 2.584962500721156, 1.0, 2.0, null, 2.321928094887362, 1.0, 1.0, 2.321928094887362, 3.321928094887362, 4.459431618637297, 3.321928094887362, 2.321928094887362, 0.0, 1.584962500721156, 2.0, 1.584962500721156, 1.584962500721156, 3.169925001442312, null, 0.0, 0.0, 1.0, 1.0, 6.882643049361842, 5.491853096329675, 4.523561956057013, 3.4594316186372973, 4.459431618637297, 3.321928094887362, 4.392317422778761, 4.0, 5.832890014164741, 4.0, 2.584962500721156, 2.584962500721156, 3.584962500721156, 5.727920454563199, 4.523561956057013, 1.0, 1.0, 2.584962500721156, null, null, 0.0, 0.0, null, null, null, null, null, 0.0, 7.6653359171851765, 3.807354922057604, 4.459431618637297, 3.4594316186372973, 3.584962500721156, 4.807354922057604, 3.321928094887362, 5.392317422778761, null, 4.0, 2.584962500721156, 2.584962500721156, 3.321928094887362, 3.700439718141092, 5.643856189774724, 2.0, null, 1.0, 3.0, 2.807354922057604, 2.0, 2.807354922057604, null, 2.584962500721156, null, null, 0.0, null, 3.321928094887362, 0.0, null, 2.0, null, null, 1.584962500721156, null, null, null, null, null, 0.0, 2.584962500721156, null, null, null, 1.584962500721156, null, 0.0, 1.584962500721156, null, null, null, 0.0, 0.0, 1.0, 1.0, 5.459431618637297, 3.0, 2.584962500721156, 5.20945336562895, 6.303780748177103, 2.0, 1.0, 4.0, null, 4.0, 2.0, 2.0, 3.0, null, 7.851749041416057, 6.247927513443585, 5.906890595608519, 3.0, 6.044394119358453, 5.321928094887363, 3.321928094887362, 5.426264754702098, null, 4.584962500721156, 2.0, 2.0, 3.321928094887362, 4.0, 6.285402218862249, 4.906890595608519, 3.0, 3.584962500721156, 4.169925001442312, 4.523561956057013, 1.0, 3.0, null, null, 2.321928094887362, 2.321928094887362, 3.321928094887362, 3.321928094887362, 4.807354922057604, 2.0, 3.584962500721156, 1.584962500721156, 2.807354922057604, 1.0, 1.0, 2.321928094887362, null, null, null, null, 0.0, 2.584962500721156, 7.011227255423254, 3.321928094887362, 3.169925001442312, 3.584962500721156, 4.459431618637297, null, 2.584962500721156, 3.700439718141092, null, 1.584962500721156, null, null, 1.0, null, 8.543031820255237, 6.882643049361842, 5.321928094887363, 4.584962500721156, 6.087462841250339, 5.906890595608519, 5.285402218862249, 5.357552004618084, null, 4.807354922057604, 3.584962500721156, 3.584962500721156, 4.584962500721156, 0.0, 2.807354922057604, 0.0, null, 1.584962500721156, null, null, null, 0.0, 0.0, null, 2.0, 2.0, 3.169925001442312, null, 5.584962500721156, 2.807354922057604, 3.584962500721156, 0.0, 0.0, 2.584962500721156, 2.0, 3.584962500721156, null, 3.0, null, null, null, 2.0, 7.6293566200796095, 5.285402218862249, 3.584962500721156, 3.321928094887362, 3.0, 5.087462841250339, 2.0, 4.459431618637297, null, 4.584962500721156, null, null, 1.0, 0.0, 7.149747119504682, 6.044394119358453, 4.906890595608519, 3.0, 4.392317422778761, 2.807354922057604, 4.0, 4.700439718141092, 0.0, 2.0, 3.169925001442312, 3.169925001442312, 4.247927513443585, 2.584962500721156, 7.159871336778389, 4.459431618637297, 3.321928094887362, 2.0, 3.584962500721156, 2.0, null, 2.0, null, 3.700439718141092, null, null, 0.0, null, 1.584962500721156, null, null, 1.0, null, null, null, null, null, null, null, null, 0.0, null, 8.930737337562887, 6.22881869049588, 5.906890595608519, 4.906890595608519, 6.303780748177103, 5.882643049361842, 4.857980995127572, 6.129283016944966, null, 4.906890595608519, 3.9068905956085187, 3.9068905956085187, 4.906890595608519, 5.0, 5.392317422778761, 4.807354922057604, 2.321928094887362, 3.700439718141092, 5.087462841250339, 4.643856189774724, 3.807354922057604, 4.0, 2.807354922057604, 4.0, 3.4594316186372973, 3.4594316186372973, 4.700439718141092, 3.169925001442312, 6.857980995127572, 1.584962500721156, 3.700439718141092, 2.807354922057604, 3.169925001442312, 3.9068905956085187, 2.0, 3.584962500721156, null, 1.0, 2.0, 2.0, 3.0, 2.321928094887362, 6.794415866350106, 5.906890595608519, 4.906890595608519, 3.9068905956085187, 5.247927513443585, 3.4594316186372973, 4.584962500721156, 4.459431618637297, null, null, 3.321928094887362, 3.321928094887362, 4.392317422778761, 4.459431618637297, 5.930737337562887, 3.0, 3.0, 2.321928094887362, 3.0, 3.584962500721156, 2.321928094887362, 2.584962500721156, null, 3.0, 1.0, 1.0, 2.0, null, 5.643856189774724, 2.584962500721156, 1.584962500721156, 2.0, 3.169925001442312, null, 2.584962500721156, 3.584962500721156, null, 1.584962500721156, 0.0, 0.0, 1.0, 3.321928094887362, 7.577428828035749, 4.857980995127572, 4.169925001442312, 4.169925001442312, 4.523561956057013, 4.754887502163468, 4.0, 1.584962500721156, null, 4.0, 3.0, 3.0, 4.087462841250339, 2.321928094887362, 5.700439718141092, 4.321928094887363, 3.4594316186372973, 3.0, 4.169925001442312, 3.9068905956085187, 3.807354922057604, 4.247927513443585, null, 2.584962500721156, null, null, null, null, 6.569855608330948, 4.169925001442312, 3.4594316186372973, 2.584962500721156, 3.700439718141092, 3.0, 2.584962500721156, 3.321928094887362, null, 0.0, 3.0, 3.0, 4.0, 2.0, 4.857980995127572, 2.584962500721156, null, 1.0, null, 2.0, 1.0, 1.584962500721156, null, 1.0, null, null, null, null, 6.285402218862249, 4.169925001442312, 3.169925001442312, 3.169925001442312, 3.9068905956085187, 3.4594316186372973, 3.700439718141092, 3.321928094887362, null, 2.321928094887362, null, null, 0.0, 0.0, null, null, 1.584962500721156, 1.584962500721156, null, 0.0, null, null, null, null, null, null, 1.0, 1.0, 9.614709844115207, 6.507794640198696, 5.906890595608519, 4.700439718141092, 6.727920454563199, 5.906890595608519, 5.954196310386875, 6.129283016944966, null, 5.247927513443585, 4.247927513443585, 4.247927513443585, 5.285402218862249, 6.044394119358453, 8.92481250360578, 7.108524456778169, 6.357552004618084, 5.584962500721156, 6.303780748177103, 6.321928094887363, 5.857980995127572, 6.3750394313469245, null, 4.459431618637297, 4.087462841250339, 4.087462841250339, 5.087462841250339, null, 10.083479327331842, 7.7481928495894605, 7.515699838284043, 8.169925001442312, 7.348728154231077, 7.066089190457772, 7.523561956057013, 7.3750394313469245, null, 6.0, 5.169925001442312, 5.169925001442312, 6.189824558880018, 5.700439718141092, 7.554588851677638, 4.700439718141092, 3.584962500721156, 3.584962500721156, 4.459431618637297, 4.459431618637297, 3.321928094887362, 4.807354922057604, null, 3.321928094887362, 2.321928094887362, 2.321928094887362, 3.584962500721156, 3.321928094887362, 8.066089190457772, 5.459431618637297, 4.459431618637297, 3.0, 5.0, 3.807354922057604, 5.129283016944966, 5.523561956057013, null, 4.584962500721156, 2.0, 2.0, 3.0, 0.0, 6.392317422778761, 4.459431618637297, 2.584962500721156, 2.807354922057604, 3.321928094887362, 2.584962500721156, 4.321928094887363, 4.0, null, null, 2.321928094887362, 2.321928094887362, 3.584962500721156, 3.0, 8.344295907915816, 6.129283016944966, 4.700439718141092, 4.584962500721156, 5.285402218862249, 5.129283016944966, 4.321928094887363, 6.0, null, 2.584962500721156, 2.0, 2.0, 3.4594316186372973, 3.169925001442312, 8.098032082960527, 3.0, 4.807354922057604, 3.584962500721156, 4.523561956057013, 3.584962500721156, 2.0, 3.807354922057604, null, 3.807354922057604, 0.0, 0.0, 1.0, 1.584962500721156, 7.011227255423254, 3.9068905956085187, 2.584962500721156, 2.321928094887362, 3.169925001442312, 2.0, 3.321928094887362, 3.9068905956085187, null, 2.0, 1.0, 1.0, 2.321928094887362, 0.0, 6.392317422778761, 3.321928094887362, 2.321928094887362, 1.584962500721156, 2.321928094887362, 3.0, 2.0, 3.4594316186372973, null, 1.584962500721156, null, null, null, 3.584962500721156, 6.285402218862249, 3.169925001442312, null, 2.584962500721156, 1.584962500721156, 3.169925001442312, 2.321928094887362, 1.584962500721156, null, 1.0, 1.0, 1.0, 2.0, 1.0, null, 1.0, 1.0, 1.584962500721156, null, null, 0.0, null, null, null, null, null, 1.0, 2.584962500721156, 9.92035285541508, 8.761551232444479, 8.618385502258606, 7.022367813028454, 8.731319031025064, 8.471675214392045, 8.383704292474052, 8.405141463136344, null, 5.357552004618084, 5.954196310386875, 5.954196310386875, 6.965784284662087, 4.954196310386875, 8.954196310386875, 6.584962500721156, 6.087462841250339, 4.523561956057013, 5.754887502163468, 6.247927513443585, 4.906890595608519, 6.189824558880018, null, 2.0, 4.906890595608519, 4.906890595608519, 5.906890595608519, null, 6.149747119504682, 3.807354922057604, 3.0, 2.807354922057604, 4.0, 3.0, 3.584962500721156, 3.807354922057604, null, 2.584962500721156, 2.321928094887362, 2.321928094887362, 3.321928094887362, 2.0, 8.243173983472952, 5.727920454563199, 5.643856189774724, 4.584962500721156, 5.700439718141092, 5.459431618637297, 5.20945336562895, 6.066089190457772, null, 4.087462841250339, 2.0, 2.0, 3.169925001442312, 4.0, 3.584962500721156, 2.0, 1.0, null, 1.0, null, 2.0, 1.584962500721156, null, null, null, null, null, null, 5.087462841250339, 2.584962500721156, 1.584962500721156, 2.321928094887362, 3.0, 3.9068905956085187, 1.584962500721156, 3.584962500721156, null, null, 1.0, 1.0, 2.0, null, 7.1799090900149345, 3.321928094887362, 3.0, 2.584962500721156, 3.700439718141092, 3.321928094887362, 1.0, 3.700439718141092, 3.0, 2.0, 1.584962500721156, 1.584962500721156, 2.584962500721156, 3.321928094887362, 6.426264754702098, 3.807354922057604, 2.584962500721156, 2.321928094887362, 2.584962500721156, 2.584962500721156, 3.0, 4.0, null, null, 1.0, 1.0, 2.0, 1.584962500721156, 3.9068905956085187, 3.584962500721156, 4.087462841250339, 2.584962500721156, 2.807354922057604, 3.321928094887362, null, 1.0, null, 2.0, 1.0, 1.0, 2.0, null, 4.906890595608519, 4.321928094887363, 3.584962500721156, 2.321928094887362, 3.4594316186372973, 3.0, 3.700439718141092, 2.0, null, null, 1.0, 1.0, 2.321928094887362, null, 0.0, 2.321928094887362, 1.0, 1.584962500721156, 0.0, null, 2.584962500721156, 1.584962500721156, null, null, null, null, 1.584962500721156, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, 1.0, null, 6.409390936137702, 5.857980995127572, 5.807354922057604, 5.169925001442312, 6.22881869049588, 6.507794640198696, 6.20945336562895, 6.129283016944966, null, 3.0, 2.807354922057604, 2.807354922057604, 3.9068905956085187, 4.169925001442312, 6.523561956057013, 6.303780748177103, 3.4594316186372973, 4.321928094887363, 5.20945336562895, 5.882643049361842, 5.459431618637297, 5.426264754702098, 5.247927513443585, 1.0, 4.392317422778761, 4.392317422778761, 5.357552004618084, 3.584962500721156, 5.523561956057013, 6.339850002884624, 3.807354922057604, 3.321928094887362, 5.087462841250339, 5.459431618637297, 4.169925001442312, 4.0, null, 2.0, 2.321928094887362, 2.321928094887362, 3.584962500721156, 1.0, 7.321928094887363, 6.169925001442312, 6.0, 4.247927513443585, 5.954196310386875, 5.754887502163468, 5.672425341971495, 5.954196310386875, null, 3.584962500721156, null, null, null, 3.584962500721156, 4.807354922057604, 4.459431618637297, 3.0, 2.584962500721156, 3.321928094887362, 3.321928094887362, 3.321928094887362, 3.9068905956085187, null, 1.0, null, null, null, 1.584962500721156, 5.754887502163468, 4.392317422778761, 3.0, 3.0, 3.9068905956085187, 3.807354922057604, 3.584962500721156, 4.807354922057604, null, null, 2.807354922057604, 2.807354922057604, 3.9068905956085187, 3.584962500721156, 9.047123912114026, 8.076815597050832, 7.348728154231077, 5.643856189774724, 7.1799090900149345, 7.577428828035749, 6.6293566200796095, 7.357552004618084, null, 4.807354922057604, 4.700439718141092, 4.700439718141092, 5.700439718141092, 3.807354922057604, 3.9068905956085187, 3.169925001442312, 1.584962500721156, 2.0, 1.0, 2.0, 1.0, 2.0, null, null, 1.584962500721156, 1.584962500721156, 3.169925001442312, 1.0, 7.199672344836364, 6.672425341971495, 5.807354922057604, 4.807354922057604, 5.614709844115208, 6.22881869049588, 5.700439718141092, 5.78135971352466, null, 4.087462841250339, 3.4594316186372973, 3.4594316186372973, 4.523561956057013, 2.0, 4.857980995127572, 4.700439718141092, 3.0, 1.584962500721156, 3.321928094887362, 4.247927513443585, null, 2.584962500721156, null, 1.0, 1.0, 1.0, 2.321928094887362, 2.584962500721156, 5.169925001442312, 4.459431618637297, 1.584962500721156, 2.584962500721156, 3.169925001442312, 4.169925001442312, 3.321928094887362, 3.807354922057604, null, 2.584962500721156, 1.584962500721156, 1.584962500721156, 3.0, 3.4594316186372973, null, 0.0, 1.584962500721156, 1.0, null, null, 0.0, null, null, null, null, null, 1.0, 1.0, 8.417852514885897, 7.924812503605781, 7.348728154231077, 5.832890014164741, 7.475733430966398, 7.417852514885898, 7.2384047393250786, 7.321928094887363, null, 4.700439718141092, null, null, null, 5.169925001442312, 9.832890014164741, 9.409390936137703, 9.152284842306582, 7.6293566200796095, 9.169925001442312, 8.64745842645492, 9.152284842306582, 8.72451385311995, null, 6.20945336562895, 7.149747119504682, 7.149747119504682, 8.164906926675688, 6.189824558880018, 5.20945336562895, 4.807354922057604, 2.807354922057604, 2.0, 3.0, 1.0, 0.0, 3.700439718141092, null, 1.0, 2.807354922057604, 2.807354922057604, 4.0, 1.584962500721156, 6.022367813028454, 5.832890014164741, 6.0, 4.700439718141092, 5.357552004618084, 5.357552004618084, 5.087462841250339, 4.954196310386875, null, 3.0, 2.0, 2.0, 3.4594316186372973, null, null, 0.0, null, 2.0, null, null, null, null, null, null, null, null, 0.0, null, 1.584962500721156, 1.0, null, 0.0, 1.584962500721156, 1.0, null, 1.0, null, null, 1.0, 1.0, 2.0, null, 6.285402218862249, 6.149747119504682, 5.614709844115208, 3.807354922057604, 5.882643049361842, 5.20945336562895, 5.491853096329675, 5.857980995127572, 5.392317422778761, 3.807354922057604, 4.169925001442312, 4.169925001442312, 5.20945336562895, 3.169925001442312, null, 1.0, 0.0, 0.0, null, null, null, 1.584962500721156, null, null, null, null, 0.0, 0.0, 5.78135971352466, 4.906890595608519, 4.906890595608519, 4.087462841250339, 3.9068905956085187, 4.459431618637297, 4.0, 4.321928094887363, null, 2.0, 3.700439718141092, 3.700439718141092, 4.754887502163468, 2.584962500721156, null, 0.0, 1.584962500721156, 2.321928094887362, null, 0.0, null, null, null, null, null, null, 1.0, 1.584962500721156, 6.321928094887363, 5.129283016944966, 4.247927513443585, 3.807354922057604, 4.807354922057604, 5.491853096329675, 4.906890595608519, 5.247927513443585, null, 3.4594316186372973, 3.169925001442312, 3.169925001442312, 4.169925001442312, null, null, 0.0, 1.0, 1.584962500721156, null, null, 1.584962500721156, null, null, null, null, null, 0.0, 1.584962500721156, 4.954196310386875, 1.584962500721156, 1.584962500721156, 2.807354922057604, null, null, 1.0, 0.0, 0.0, null, null, null, 1.584962500721156, 3.700439718141092, 1.584962500721156, null, 0.0, null, null, null, 1.0, null, null, null, null, null, null, 2.0, 8.471675214392045, 5.643856189774724, 4.700439718141092, 7.0, 4.857980995127572, 5.321928094887363, 5.426264754702098, 5.247927513443585, 1.584962500721156, 5.129283016944966, 3.584962500721156, 3.584962500721156, 4.754887502163468, 4.643856189774724, 9.259743263690781, 6.672425341971495, 6.78135971352466, 4.643856189774724, 6.247927513443585, 2.0, 6.523561956057013, 6.539158811108031, null, 5.426264754702098, 6.599912842187128, 6.599912842187128, 7.622051819456376, 5.0, 9.098032082960527, 5.0, 5.285402218862249, 1.0, 5.087462841250339, null, 4.247927513443585, 3.321928094887362, 4.459431618637297, 5.0, 0.0, 0.0, 1.584962500721156, 4.459431618637297, 3.584962500721156, 2.584962500721156, null, 2.0, 2.0, null, null, 1.584962500721156, null, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0, 4.247927513443585, null, 1.584962500721156, 0.0, 3.0, null, 1.584962500721156, null, null, null, null, null, null, 3.0, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, 3.169925001442312, 2.321928094887362, 3.807354922057604, 3.4594316186372973, 1.0, 3.321928094887362, 1.0, 2.807354922057604, null, 2.584962500721156, 1.584962500721156, 1.584962500721156, 2.584962500721156, 0.0, 3.584962500721156, 3.169925001442312, 1.0, 4.321928094887363, 2.0, 1.0, null, 1.584962500721156, 0.0, 0.0, null, null, null, null, 4.0, 3.584962500721156, 1.584962500721156, 0.0, 3.169925001442312, null, 2.807354922057604, 2.807354922057604, null, 2.0, null, null, null, null, 5.044394119358453, 2.0, null, 2.0, 2.321928094887362, 1.0, 1.0, 2.0, null, null, null, null, null, 1.0, 7.459431618637297, 4.392317422778761, 4.0, 3.169925001442312, 3.807354922057604, null, 4.169925001442312, 3.700439718141092, null, 4.087462841250339, 3.4594316186372973, 3.4594316186372973, 4.459431618637297, 2.0, 8.134426320220927, 6.599912842187128, 5.044394119358453, 6.658211482751795, 6.169925001442312, 5.087462841250339, 5.392317422778761, 6.247927513443585, 0.0, 4.392317422778761, 3.169925001442312, 3.169925001442312, 4.321928094887363, null, 2.584962500721156, 1.0, 0.0, null, 0.0, null, 1.0, null, null, null, null, null, null, null, 6.087462841250339, 2.0, 3.807354922057604, 2.321928094887362, 0.0, 0.0, 3.700439718141092, 2.0, 4.087462841250339, 3.0, null, null, null, 3.169925001442312, 3.584962500721156, null, 1.0, 0.0, 0.0, 2.584962500721156, null, 1.0, null, 1.0, null, null, null, null, 3.4594316186372973, null, null, 3.0, null, 0.0, null, null, null, 1.0, null, null, null, null, 7.066089190457772, 3.169925001442312, 3.0, null, 3.4594316186372973, null, 3.321928094887362, 2.807354922057604, null, 2.584962500721156, null, null, null, 3.0, 5.882643049361842, 2.584962500721156, 1.0, 2.0, 2.0, null, 1.0, 2.584962500721156, null, 3.0, 1.0, 1.0, 2.321928094887362, 3.169925001442312, 4.169925001442312, null, 1.584962500721156, 1.0, 0.0, null, 2.584962500721156, 2.0, 1.0, 1.0, null, null, null, 0.0, 5.044394119358453, 2.0, 2.0, 1.0, 2.0, null, null, 2.0, null, 2.584962500721156, null, null, null, 3.0, 5.087462841250339, 3.169925001442312, 1.0, 3.169925001442312, 1.584962500721156, null, null, 2.0, 2.321928094887362, 1.0, null, null, 0.0, 1.0, 4.0, 1.584962500721156, 1.0, 2.0, null, 0.0, null, null, null, null, null, null, 1.584962500721156, null, 4.807354922057604, 2.0, 1.0, 5.857980995127572, 4.643856189774724, null, null, 3.4594316186372973, 0.0, 3.321928094887362, 0.0, 0.0, 1.0, null, 9.14210705730255, 5.832890014164741, 6.321928094887363, 3.807354922057604, 5.426264754702098, 2.0, 5.954196310386875, 5.285402218862249, null, 5.754887502163468, 4.321928094887363, 4.321928094887363, 5.321928094887363, 4.459431618637297, 3.584962500721156, 1.0, null, 3.0, 2.0, 3.0, 1.0, 0.0, null, 1.0, 0.0, 0.0, 1.584962500721156, null, 3.700439718141092, 2.321928094887362, null, 1.584962500721156, null, 1.0, 1.0, 0.0, 0.0, null, null, null, null, 1.0, 7.129283016944966, 4.169925001442312, 4.643856189774724, 3.321928094887362, 3.169925001442312, 1.0, 2.807354922057604, 3.807354922057604, 0.0, 3.584962500721156, 3.169925001442312, 3.169925001442312, 4.321928094887363, 5.247927513443585, 6.9886846867721655, 3.0, 2.321928094887362, 3.169925001442312, 3.807354922057604, 2.0, 3.321928094887362, 2.807354922057604, null, 4.906890595608519, 1.0, 1.0, 2.321928094887362, 0.0, 5.754887502163468, null, null, 4.087462841250339, 1.584962500721156, 1.0, 2.0, 1.0, 1.0, 1.584962500721156, 1.584962500721156, 1.584962500721156, 2.584962500721156, null, 5.459431618637297, 1.584962500721156, 1.0, 2.0, 2.0, null, 3.4594316186372973, 2.584962500721156, null, 1.0, 2.807354922057604, 2.807354922057604, 3.807354922057604, null, 5.169925001442312, null, null, 2.0, 1.0, 1.0, 1.0, 1.0, null, 3.321928094887362, null, null, null, null, 3.9068905956085187, null, 2.0, null, null, null, 1.0, 1.584962500721156, 0.0, 2.0, 0.0, 0.0, 1.0, 1.0, 5.169925001442312, 2.321928094887362, 2.807354922057604, null, 2.0, null, 2.0, 0.0, 2.321928094887362, null, null, null, 2.0, 1.584962500721156, 3.321928094887362, 2.0, 2.584962500721156, null, null, null, 1.0, null, null, null, null, null, 0.0, 1.0, 8.08214904135387, 6.189824558880018, 5.20945336562895, 2.584962500721156, 5.672425341971495, null, 2.584962500721156, 5.392317422778761, 5.087462841250339, 3.9068905956085187, 3.321928094887362, 3.321928094887362, 4.321928094887363, 3.807354922057604, 7.247927513443585, 4.857980995127572, 4.906890595608519, 2.584962500721156, 5.285402218862249, 0.0, 4.643856189774724, 4.954196310386875, 4.169925001442312, 3.0, 4.0, 4.0, 5.044394119358453, 3.169925001442312, 6.794415866350106, 3.169925001442312, 3.4594316186372973, 2.807354922057604, 4.169925001442312, 3.321928094887362, 3.0, 2.584962500721156, null, 4.321928094887363, 0.0, 0.0, 1.0, null, 6.569855608330948, 4.584962500721156, 4.754887502163468, 2.0, 4.523561956057013, null, 3.321928094887362, 5.20945336562895, 4.0, 4.0, 3.9068905956085187, 3.9068905956085187, 4.906890595608519, 3.9068905956085187, 2.0, 0.0, 0.0, null, null, null, 1.0, 1.0, null, null, 0.0, 0.0, 1.584962500721156, null, 5.459431618637297, 2.0, null, 1.0, 2.0, null, 1.0, 1.0, 1.584962500721156, null, null, null, 1.0, null, 4.584962500721156, null, 0.0, null, 1.0, 1.0, null, 1.0, null, 1.0, null, null, null, 1.0, 4.247927513443585, 1.0, 1.0, 1.0, 3.169925001442312, 0.0, 1.0, 0.0, 0.0, 2.0, null, null, null, null, 6.321928094887363, 2.584962500721156, 3.9068905956085187, 2.0, 2.807354922057604, 1.0, 1.0, 3.169925001442312, 2.807354922057604, 2.321928094887362, 1.0, 1.0, 2.0, null, 3.584962500721156, null, 1.0, 0.0, 0.0, null, 0.0, 0.0, null, 1.584962500721156, 0.0, 0.0, 2.0, null, 3.0, 2.807354922057604, 1.0, 0.0, 1.584962500721156, null, null, 2.321928094887362, null, null, null, null, null, null, 2.321928094887362, null, 0.0, 0.0, null, null, 1.0, null, null, 1.0, null, null, 0.0, null, 3.9068905956085187, 0.0, null, 2.321928094887362, 0.0, null, null, 0.0, 1.584962500721156, 0.0, null, null, null, null, 8.49585502688717, 6.426264754702098, 6.266786540694901, 4.087462841250339, 5.584962500721156, null, 5.614709844115208, 6.475733430966398, 6.714245517666122, 5.285402218862249, 1.0, 1.0, 2.0, 4.700439718141092, 8.611024797307353, 6.108524456778169, 5.426264754702098, 3.4594316186372973, 4.700439718141092, 0.0, 4.0, 5.321928094887363, 4.584962500721156, 4.392317422778761, 1.584962500721156, 1.584962500721156, 2.584962500721156, 4.700439718141092, 6.022367813028454, 3.807354922057604, 2.0, 4.584962500721156, null, null, 0.0, null, null, 1.0, null, null, null, 2.0, 5.554588851677638, 2.0, 1.0, 2.321928094887362, 2.321928094887362, null, 1.0, 2.0, 1.0, 2.584962500721156, null, null, null, null, 5.044394119358453, 1.0, 3.0, 2.0, 1.0, null, 2.0, 2.321928094887362, 2.0, 3.0, null, null, 0.0, 3.0, 5.930737337562887, 2.0, 0.0, 2.0, 2.0, null, 0.0, 0.0, 0.0, 2.0, null, null, null, 2.584962500721156, 6.087462841250339, null, 2.321928094887362, null, 0.0, null, null, 1.0, null, 4.169925001442312, null, null, null, null, 7.577428828035749, 4.459431618637297, 5.285402218862249, 3.4594316186372973, 4.392317422778761, 2.0, 2.584962500721156, 3.4594316186372973, null, 3.169925001442312, 3.169925001442312, 3.169925001442312, 4.169925001442312, 5.321928094887363, 6.022367813028454, 3.321928094887362, 2.584962500721156, null, 1.584962500721156, 0.0, 2.584962500721156, 2.321928094887362, null, 1.0, null, null, null, null, 5.247927513443585, 2.321928094887362, 2.0, 3.0, 2.321928094887362, null, null, 1.584962500721156, 1.0, 2.0, 2.321928094887362, 2.321928094887362, 3.4594316186372973, null, 4.954196310386875, 1.0, 2.584962500721156, 3.169925001442312, 1.584962500721156, null, null, 1.0, 2.0, null, 0.0, 0.0, 1.584962500721156, null, 2.321928094887362, 1.0, null, 1.0, null, null, 0.0, 0.0, null, 0.0, null, null, 0.0, null, 5.523561956057013, 3.321928094887362, 0.0, 4.643856189774724, 3.584962500721156, 1.0, 2.807354922057604, 2.321928094887362, null, 3.584962500721156, 0.0, 0.0, 1.0, 1.0, 6.507794640198696, 3.807354922057604, 3.584962500721156, 3.0, 3.700439718141092, null, 1.0, 3.0, null, 3.807354922057604, 3.700439718141092, 3.700439718141092, 4.754887502163468, 3.4594316186372973, 8.366322214245816, 6.426264754702098, 5.857980995127572, 0.0, 5.169925001442312, 2.0, 5.523561956057013, 5.78135971352466, 5.357552004618084, 5.0, null, null, 1.0, 3.807354922057604, 2.807354922057604, null, null, 0.0, null, null, null, null, null, null, null, null, null, 1.0, 5.727920454563199, 3.0, 2.321928094887362, 2.321928094887362, 0.0, 0.0, 1.0, 2.321928094887362, null, 3.807354922057604, 1.584962500721156, 1.584962500721156, 2.321928094887362, null, 3.9068905956085187, 2.0, null, null, 0.0, null, null, 0.0, 0.0, null, null, null, null, null, 5.807354922057604, 2.807354922057604, 0.0, 0.0, 3.169925001442312, null, 3.321928094887362, 2.321928094887362, 1.0, 1.0, 1.0, 1.0, 2.321928094887362, 3.584962500721156, 4.459431618637297, 3.9068905956085187, null, 0.0, 4.0, null, 2.584962500721156, 3.700439718141092, 1.0, null, 1.0, 1.0, 2.321928094887362, null, 4.247927513443585, 2.584962500721156, 2.321928094887362, 4.321928094887363, 1.584962500721156, 2.584962500721156, null, 2.321928094887362, 2.584962500721156, 3.321928094887362, null, null, null, null, 2.0, 2.0, 2.0, 1.584962500721156, 0.0, 1.0, 2.0, 1.0, null, 1.0, 0.0, 0.0, 1.0, null, null, null, 1.0, null, null, null, null, 0.0, 0.0, null, null, null, null, null, 6.20945336562895, 5.459431618637297, 4.857980995127572, 5.882643049361842, 4.643856189774724, 4.0, 5.357552004618084, 4.906890595608519, 1.0, 1.584962500721156, 3.169925001442312, 3.169925001442312, 4.392317422778761, 3.700439718141092, 3.4594316186372973, 3.584962500721156, 3.321928094887362, 1.0, null, 2.0, 1.584962500721156, 0.0, null, 1.584962500721156, null, null, null, null, 5.169925001442312, 6.3750394313469245, 4.169925001442312, null, 5.169925001442312, null, 2.321928094887362, 5.857980995127572, 0.0, null, null, null, null, 3.0, 6.894817763307944, 6.0, 5.247927513443585, 6.357552004618084, 4.954196310386875, 5.321928094887363, 4.169925001442312, 4.807354922057604, 3.807354922057604, 2.0, 3.807354922057604, 3.807354922057604, 4.807354922057604, 2.0, 5.857980995127572, 5.392317422778761, 3.9068905956085187, 3.9068905956085187, 5.169925001442312, 4.700439718141092, 3.700439718141092, 5.044394119358453, 1.0, 2.584962500721156, 3.321928094887362, 3.321928094887362, 4.321928094887363, 3.169925001442312, 3.321928094887362, 2.321928094887362, null, 0.0, 2.584962500721156, null, 1.0, 1.0, 1.584962500721156, null, null, null, 0.0, null, 4.700439718141092, 4.0, 3.9068905956085187, 2.321928094887362, 1.584962500721156, 2.584962500721156, 2.0, 3.584962500721156, null, 2.584962500721156, 0.0, 0.0, 1.0, null, 3.321928094887362, 4.247927513443585, 2.321928094887362, 2.807354922057604, 3.700439718141092, 2.0, 1.0, 2.807354922057604, null, 1.0, 0.0, 0.0, 1.0, 1.0, 4.459431618637297, 4.643856189774724, null, null, 2.321928094887362, 2.0, 2.0, 3.807354922057604, 2.584962500721156, 2.0, null, null, 0.0, null, 3.0, 3.4594316186372973, 1.0, 1.0, 1.0, null, 3.0, 2.0, null, null, 1.0, 1.0, 2.0, 1.0, 3.4594316186372973, 2.0, 3.0, null, 0.0, null, 2.584962500721156, null, 0.0, 1.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 3.4594316186372973, 4.643856189774724, 3.807354922057604, 3.0, 3.584962500721156, 2.321928094887362, 2.0, 3.321928094887362, null, 4.169925001442312, 2.584962500721156, 2.584962500721156, 3.700439718141092, null, 10.016808287686555, 9.071462362556623, 9.18239435340453, 10.314016703901357, 8.965784284662087, 7.888743248898259, 8.731319031025064, 9.052568050804153, 4.754887502163468, 7.219168520462161, 7.845490050944375, 7.845490050944375, 8.861086905995395, 2.0, 4.247927513443585, 2.321928094887362, 3.321928094887362, 1.584962500721156, 2.0, 0.0, 3.4594316186372973, 2.321928094887362, 1.584962500721156, 1.0, null, null, null, 1.584962500721156, 6.882643049361842, 6.426264754702098, 5.977279923499917, 0.0, 5.727920454563199, 2.584962500721156, 4.0, 5.754887502163468, 0.0, 5.321928094887363, 5.857980995127572, 5.857980995127572, 6.894817763307944, 2.321928094887362, 7.294620748891627, 5.285402218862249, 5.523561956057013, 4.087462841250339, 5.554588851677638, 2.807354922057604, 5.357552004618084, 5.954196310386875, null, 5.643856189774724, 4.643856189774724, 4.643856189774724, 5.700439718141092, 3.321928094887362, 2.321928094887362, null, null, 0.0, 0.0, null, null, 0.0, null, null, null, null, null, null, 3.9068905956085187, 3.807354922057604, 3.0, 0.0, 3.4594316186372973, null, null, 2.584962500721156, 2.321928094887362, null, 2.807354922057604, 2.807354922057604, 3.807354922057604, 1.0, 4.0, 3.321928094887362, 2.0, 0.0, 1.584962500721156, null, 2.584962500721156, 2.321928094887362, null, 2.584962500721156, null, null, null, 2.0, 0.0, null, null, 1.584962500721156, null, 0.0, null, 0.0, null, null, null, null, null, null, 1.0, null, null, 1.0, 1.0, null, null, null, null, null, null, null, null, null, 3.9068905956085187, 3.321928094887362, 3.4594316186372973, 3.584962500721156, 1.584962500721156, 1.0, 1.0, 2.321928094887362, null, 0.0, 3.700439718141092, 3.700439718141092, 4.700439718141092, 2.584962500721156, 0.0, 0.0, 1.0, 0.0, null, null, null, null, null, null, 0.0, 0.0, 1.0, 1.0, 7.348728154231077, 4.754887502163468, 5.044394119358453, 5.700439718141092, 3.807354922057604, 3.321928094887362, 5.459431618637297, 4.247927513443585, null, 4.169925001442312, 5.129283016944966, 5.129283016944966, 6.149747119504682, 6.087462841250339, 7.339850002884624, 4.459431618637297, 6.129283016944966, 6.442943495848728, 5.285402218862249, 2.584962500721156, 6.247927513443585, 4.169925001442312, null, 3.0, 5.321928094887363, 5.321928094887363, 6.321928094887363, 4.807354922057604, 9.071462362556623, 6.266786540694901, 7.0, 7.870364719583405, 2.584962500721156, 6.794415866350106, 7.159871336778389, 6.820178962415188, null, 4.906890595608519, 6.643856189774724, 6.643856189774724, 7.636624620543649, 6.78135971352466, 7.6865005271832185, 5.285402218862249, 4.906890595608519, 6.741466986401147, 4.169925001442312, 5.169925001442312, 5.357552004618084, 5.0, null, 3.4594316186372973, 5.044394119358453, 5.044394119358453, 6.044394119358453, 4.523561956057013, 9.854868383260236, 7.0, 7.169925001442312, 8.546894459887637, 6.022367813028454, 6.321928094887363, 7.483815777264256, 6.94251450533924, null, 5.807354922057604, 6.569855608330948, 6.584962500721156, 7.577428828035749, 5.169925001442312, 9.375039431346925, 8.344295907915816, 8.523561956057012, 9.177419537989236, 7.076815597050831, 7.820178962415188, 8.654636028527968, 7.592457037268081, null, 6.658211482751795, 7.2384047393250786, 7.257387842692652, 8.257387842692651, 5.614709844115208, 1.584962500721156, 6.977279923499917, 1.0, 1.0, 0.0, 5.882643049361842, 1.0, 5.087462841250339, null, null, 5.614709844115208, 5.614709844115208, 6.614709844115208, null, null, null, null, null, null, null, null, null, null, null, 0.0, 0.0, 1.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 7.734709620225838, 5.0, 5.906890595608519, 7.169925001442312, 2.807354922057604, 5.169925001442312, 6.0, 4.584962500721156, null, 3.807354922057604, 5.129283016944966, 5.129283016944966, 6.149747119504682, 3.9068905956085187, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, 8.832890014164741, 6.807354922057604, 6.569855608330948, 7.515699838284043, 1.0, 6.357552004618084, 7.189824558880018, 6.392317422778761, 5.672425341971495, 4.954196310386875, 6.442943495848728, 6.442943495848728, 7.451211111832329, 5.087462841250339, 8.312882955284355, 6.409390936137702, 6.599912842187128, 7.515699838284043, null, 5.727920454563199, 6.491853096329675, 4.906890595608519, null, 4.754887502163468, 5.78135971352466, 5.807354922057604, 6.807354922057604, 4.906890595608519, 8.885696373339394, 7.417852514885898, 7.636624620543649, 8.499845887083206, 6.044394119358453, 6.9886846867721655, 7.409390936137702, 6.285402218862249, null, 5.087462841250339, 7.22881869049588, 7.22881869049588, 8.228818690495881, 5.727920454563199, 6.614709844115208, 4.906890595608519, 4.321928094887363, 5.954196310386875, 3.807354922057604, 4.954196310386875, 4.392317422778761, 3.321928094887362, null, 2.0, 2.584962500721156, 2.584962500721156, 3.584962500721156, 3.584962500721156, 8.379378367071261, 5.78135971352466, 6.321928094887363, 6.672425341971495, 1.0, 4.807354922057604, 6.491853096329675, 5.285402218862249, null, 3.584962500721156, 3.0, 3.0, 4.0, 3.807354922057604, 8.64745842645492, 6.022367813028454, 6.20945336562895, 7.409390936137702, 0.0, 5.584962500721156, 6.285402218862249, 4.643856189774724, null, 4.700439718141092, 6.339850002884624, 6.339850002884624, 7.348728154231077, 6.285402218862249, 8.257387842692651, 6.129283016944966, 5.882643049361842, 7.491853096329675, 0.0, 5.754887502163468, 6.475733430966398, 5.882643049361842, null, 5.247927513443585, 5.523561956057013, 5.523561956057013, 6.507794640198696, 5.20945336562895, 6.930737337562887, 5.044394119358453, 4.0, 5.426264754702098, 0.0, 2.584962500721156, 3.9068905956085187, 3.169925001442312, null, 4.0, 3.9068905956085187, 3.9068905956085187, 4.906890595608519, 3.584962500721156, 8.39231742277876, 6.266786540694901, 6.066089190457772, 7.741466986401147, 5.357552004618084, 5.247927513443585, 7.266786540694901, 4.0, 4.459431618637297, 4.169925001442312, 4.459431618637297, 4.459431618637297, 5.459431618637297, 4.857980995127572, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, 8.066089190457772, 6.044394119358453, 6.022367813028454, 7.491853096329675, 5.554588851677638, 6.087462841250339, 6.442943495848728, 4.857980995127572, null, 4.700439718141092, 6.189824558880018, 6.189824558880018, 7.1799090900149345, 5.882643049361842, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, 7.562242424221073, 5.169925001442312, 5.584962500721156, 6.794415866350106, 4.247927513443585, 4.857980995127572, 5.906890595608519, 4.247927513443585, 1.584962500721156, 4.459431618637297, 5.554588851677638, 5.554588851677638, 6.584962500721156, 5.285402218862249, 4.392317422778761, 3.807354922057604, 2.0, 6.700439718141092, 4.857980995127572, 3.0, 3.0, 2.321928094887362, 1.584962500721156, 2.807354922057604, 1.584962500721156, 1.584962500721156, 2.584962500721156, 1.0, 7.693486957499325, 4.906890595608519, 4.954196310386875, 6.658211482751795, 3.584962500721156, 4.459431618637297, 3.584962500721156, 4.0, null, 4.321928094887363, 4.807354922057604, 4.807354922057604, 5.807354922057604, 4.523561956057013, 7.118941072723508, 4.754887502163468, 4.857980995127572, 5.700439718141092, 4.459431618637297, 2.584962500721156, 4.087462841250339, 3.4594316186372973, null, 3.584962500721156, 4.247927513443585, 4.247927513443585, 5.321928094887363, 4.584962500721156, 8.016808287686555, 6.169925001442312, 6.22881869049588, 7.139551352398794, 6.0, 4.954196310386875, 6.672425341971495, 5.392317422778761, null, 4.169925001442312, 5.392317422778761, 5.392317422778761, 6.392317422778761, 4.392317422778761, 7.787902559391432, 5.977279923499917, 6.022367813028454, 6.22881869049588, 4.643856189774724, 5.321928094887363, 5.285402218862249, 4.0, null, 4.0, 4.523561956057013, 4.523561956057013, 5.614709844115208, 4.584962500721156, 1.584962500721156, 1.584962500721156, 0.0, 2.0, null, null, null, null, null, null, null, null, null, 2.584962500721156, null, 1.0, null, null, null, null, null, null, 0.0, 1.0, null, null, null, 1.0, 7.087462841250339, 4.857980995127572, 5.20945336562895, 6.857980995127572, 0.0, 3.807354922057604, 5.807354922057604, 3.321928094887362, null, 3.9068905956085187, 3.169925001442312, 3.169925001442312, 4.392317422778761, 3.0, 8.400879436282183, 6.672425341971495, 6.727920454563199, 7.754887502163468, 2.321928094887362, 6.169925001442312, 7.022367813028454, 6.044394119358453, 1.0, 4.700439718141092, 6.700439718141092, 6.700439718141092, 7.700439718141092, 6.22881869049588, 7.467605550082998, 5.882643049361842, 5.643856189774724, 7.011227255423254, 5.78135971352466, 4.321928094887363, 6.149747119504682, 3.807354922057604, null, 4.0, 5.832890014164741, 5.832890014164741, 6.820178962415188, 3.584962500721156, 0.0, null, 1.0, 3.0, null, null, null, 0.0, null, null, null, null, null, null, 7.870364719583405, 6.0, 4.700439718141092, 7.149747119504682, 4.857980995127572, 5.754887502163468, 6.714245517666122, 4.954196310386875, null, 4.584962500721156, 5.459431618637297, 5.459431618637297, 6.442943495848728, 5.700439718141092, 7.219168520462161, 4.0, 4.700439718141092, 6.169925001442312, 0.0, 4.169925001442312, 6.0, 4.643856189774724, null, 3.807354922057604, 5.0, 5.0, 6.022367813028454, 3.807354922057604, 7.531381460516312, 5.285402218862249, 5.554588851677638, 6.6293566200796095, 4.321928094887363, 5.0, 5.700439718141092, 4.523561956057013, null, 4.459431618637297, 5.392317422778761, 5.392317422778761, 6.392317422778761, 5.169925001442312, 7.734709620225838, 5.672425341971495, 5.285402218862249, 6.6293566200796095, null, 4.807354922057604, 5.247927513443585, 5.169925001442312, 5.0, 3.807354922057604, 5.169925001442312, 5.169925001442312, 6.20945336562895, 5.882643049361842, 7.409390936137702, 5.20945336562895, 4.700439718141092, 6.954196310386875, null, 5.169925001442312, 6.129283016944966, 4.459431618637297, null, 2.584962500721156, 4.321928094887363, 4.321928094887363, 5.357552004618084, 1.0, 7.507794640198696, 5.169925001442312, 5.643856189774724, 6.584962500721156, 4.807354922057604, 4.906890595608519, 5.0, 5.554588851677638, null, 3.0, 4.392317422778761, 4.392317422778761, 5.426264754702098, 4.584962500721156, 4.169925001442312, null, 1.0, 1.0, null, 1.0, null, 0.0, null, 2.0, 1.0, 1.0, 2.584962500721156, null, 8.339850002884624, 7.076815597050831, 7.643856189774724, 8.550746785383243, 2.584962500721156, 6.169925001442312, 7.754887502163468, 7.108524456778169, null, 5.169925001442312, 7.2384047393250786, 7.2384047393250786, 8.238404739325079, 5.614709844115208, 8.194756854422248, 6.285402218862249, 6.392317422778761, 7.727920454563199, 2.0, 5.857980995127572, 6.507794640198696, 5.491853096329675, null, 4.321928094887363, 6.459431618637297, 6.459431618637297, 7.475733430966398, 4.754887502163468, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 7.714245517666122, 5.392317422778761, 5.285402218862249, 7.330916878114617, 4.754887502163468, 5.20945336562895, 6.491853096329675, 5.882643049361842, null, 4.584962500721156, 4.523561956057013, 4.523561956057013, 5.554588851677638, 4.0, 0.0, null, null, null, null, null, 1.0, null, null, null, null, null, null, null, 8.810571634741146, 6.906890595608519, 6.94251450533924, 7.994353436858858, 6.845490050944375, 6.491853096329675, 7.554588851677638, 5.491853096329675, 5.614709844115208, 4.321928094887363, 6.832890014164741, 6.832890014164741, 7.832890014164741, 5.954196310386875, 7.451211111832329, 4.906890595608519, 5.129283016944966, 6.554588851677638, 4.247927513443585, 4.643856189774724, 6.0, 3.0, null, 3.4594316186372973, 4.807354922057604, 4.807354922057604, 5.807354922057604, 2.0, 7.906890595608519, 6.066089190457772, 6.303780748177103, 7.383704292474052, 0.0, 6.459431618637297, 6.247927513443585, 4.523561956057013, null, 4.700439718141092, 6.20945336562895, 6.20945336562895, 7.199672344836364, 5.247927513443585, 3.4594316186372973, 2.584962500721156, 2.321928094887362, 2.584962500721156, null, 1.584962500721156, 0.0, 1.0, null, 2.0, 2.0, 2.0, 3.169925001442312, 2.584962500721156, 7.05528243550119, 4.169925001442312, 5.285402218862249, 6.491853096329675, 0.0, 4.169925001442312, 6.087462841250339, 3.169925001442312, null, 3.169925001442312, 5.247927513443585, 5.247927513443585, 6.247927513443585, 4.754887502163468, 7.636624620543649, 5.727920454563199, 5.392317422778761, 7.159871336778389, 4.643856189774724, 5.169925001442312, 5.977279923499917, 4.523561956057013, null, 2.807354922057604, 4.584962500721156, 4.584962500721156, 5.584962500721156, 5.087462841250339, 3.9068905956085187, 1.0, 0.0, 1.0, 0.0, 2.0, 1.0, 1.0, null, null, null, null, null, null, 6.954196310386875, 4.0, 2.584962500721156, 5.044394119358453, null, 1.0, 3.700439718141092, 2.584962500721156, null, 3.321928094887362, 3.321928094887362, 3.321928094887362, 4.459431618637297, 1.584962500721156, 8.243173983472952, 6.149747119504682, 6.357552004618084, 7.546894459887636, 4.954196310386875, 5.906890595608519, 6.3750394313469245, 5.700439718141092, 5.357552004618084, 5.044394119358453, 5.882643049361842, 5.882643049361842, 6.894817763307944, 5.754887502163468, 0.0, null, null, 2.0, null, null, null, null, null, null, null, null, null, null, 8.219168520462162, 6.475733430966398, 6.918863237274595, 7.693486957499325, 5.754887502163468, 4.906890595608519, 7.266786540694901, 4.087462841250339, 5.285402218862249, 4.321928094887363, 6.357552004618084, 6.357552004618084, 7.357552004618084, 5.0, null, null, null, 1.0, null, 1.0, null, null, null, null, null, null, null, null, 8.948367231584678, 7.515699838284043, 7.066089190457772, 8.257387842692651, 3.321928094887362, 6.643856189774724, 7.60733031374961, 5.977279923499917, 2.807354922057604, 5.584962500721156, 5.0, 5.0, 5.977279923499917, 4.857980995127572, 8.936637939002571, 6.820178962415188, 7.044394119358453, 8.164906926675688, 6.189824558880018, 5.977279923499917, 7.247927513443585, 6.714245517666122, null, 5.087462841250339, 6.954196310386875, 6.954196310386875, 7.960001932068081, 6.357552004618084, 8.442943495848729, 6.129283016944966, 6.321928094887363, 7.257387842692652, 5.247927513443585, 5.754887502163468, 6.6865005271832185, 5.20945336562895, null, 4.169925001442312, 6.20945336562895, 6.20945336562895, 7.189824558880018, 5.700439718141092, 7.569855608330948, 4.857980995127572, 5.0, 6.569855608330948, 1.0, 4.954196310386875, 5.426264754702098, 5.169925001442312, null, 4.247927513443585, 5.392317422778761, 5.392317422778761, 6.409390936137702, 5.247927513443585, 8.98299357469431, 8.31741261376487, 8.224001674198105, 8.326429487122303, 6.6293566200796095, 6.714245517666122, 8.370687406807217, 6.459431618637297, 6.507794640198696, 4.700439718141092, 7.383704292474052, 7.383704292474052, 8.383704292474052, 6.459431618637297, 6.6293566200796095, 1.0, 2.0, 1.0, 0.0, 1.0, 1.0, 1.0, null, null, 0.0, 0.0, 1.0, 3.807354922057604, 5.087462841250339, 1.0, 1.0, 3.700439718141092, null, 3.0, null, null, null, 2.0, null, null, null, 2.584962500721156, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, 7.426264754702098, 4.700439718141092, 6.022367813028454, 7.011227255423254, 4.643856189774724, 4.392317422778761, 5.977279923499917, 3.321928094887362, null, 3.321928094887362, 5.087462841250339, 5.087462841250339, 6.087462841250339, 5.087462841250339, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 7.169925001442312, 5.882643049361842, 5.643856189774724, 6.507794640198696, 0.0, 5.614709844115208, 6.392317422778761, 4.754887502163468, null, 4.584962500721156, 5.523561956057013, 5.523561956057013, 6.523561956057013, 3.9068905956085187, 7.442943495848728, 6.149747119504682, 5.882643049361842, 7.622051819456376, 0.0, 5.906890595608519, 6.6293566200796095, 4.584962500721156, null, 4.169925001442312, 6.0, 6.0, 7.0, 4.906890595608519, 7.6293566200796095, 6.392317422778761, 6.794415866350106, 7.734709620225838, 6.066089190457772, 5.523561956057013, 7.2761244052742375, 6.169925001442312, null, 4.584962500721156, 5.832890014164741, 5.832890014164741, 6.845490050944375, 3.4594316186372973, 7.219168520462161, 6.266786540694901, 6.569855608330948, 7.7481928495894605, 1.0, 5.700439718141092, 6.523561956057013, 5.807354922057604, null, 5.0, 6.409390936137702, 6.409390936137702, 7.400879436282184, 5.0, 6.906890595608519, 5.247927513443585, 6.266786540694901, 7.159871336778389, 4.523561956057013, 5.0, 6.714245517666122, 4.0, null, 4.087462841250339, 5.857980995127572, 5.857980995127572, 6.857980995127572, 4.169925001442312, 6.266786540694901, 5.832890014164741, 5.087462841250339, 7.05528243550119, 4.643856189774724, 5.321928094887363, 4.087462841250339, 5.554588851677638, null, 4.0, 6.044394119358453, 6.044394119358453, 7.011227255423254, 3.321928094887362, 7.066089190457772, 5.554588851677638, 5.584962500721156, 6.794415866350106, 4.087462841250339, 6.087462841250339, 6.149747119504682, 4.643856189774724, 0.0, 2.0, 5.523561956057013, 5.523561956057013, 6.523561956057013, 4.754887502163468, 7.554588851677638, 6.087462841250339, 6.584962500721156, 7.741466986401147, 5.882643049361842, 6.20945336562895, 6.832890014164741, 6.169925001442312, null, 4.392317422778761, 6.78135971352466, 6.78135971352466, 7.787902559391432, 5.584962500721156, 0.0, null, null, 0.0, null, 1.0, null, null, null, null, null, null, null, null, 7.169925001442312, 6.247927513443585, 6.087462841250339, 7.159871336778389, 5.285402218862249, 5.954196310386875, 6.977279923499917, 5.044394119358453, null, 5.0, 5.954196310386875, 5.954196310386875, 6.954196310386875, 3.9068905956085187, 6.409390936137702, 5.357552004618084, 5.285402218862249, 6.882643049361842, 2.321928094887362, 4.392317422778761, 6.087462841250339, 5.20945336562895, 4.906890595608519, 4.0, 5.554588851677638, 5.554588851677638, 6.614709844115208, 3.0, null, 1.0, null, null, null, null, null, null, null, null, null, null, null, null, 6.569855608330948, 5.554588851677638, 5.087462841250339, 6.78135971352466, 0.0, 5.491853096329675, 5.584962500721156, 3.807354922057604, null, 4.0, 5.672425341971495, 5.672425341971495, 6.714245517666122, 3.807354922057604, 7.434628227636725, 6.78135971352466, 6.569855608330948, 7.912889336229962, 5.584962500721156, 5.584962500721156, 7.05528243550119, 5.672425341971495, null, 4.392317422778761, 6.523561956057013, 6.523561956057013, 7.523561956057013, 5.169925001442312, 7.417852514885898, 6.357552004618084, 7.22881869049588, 7.98299357469431, 1.0, 6.129283016944966, 7.108524456778169, 6.507794640198696, null, 4.169925001442312, 6.845490050944375, 6.845490050944375, 7.839203788096944, 4.807354922057604, 7.832890014164741, 6.894817763307944, 7.05528243550119, 8.43879185257826, 2.0, 6.94251450533924, 7.247927513443585, 6.768184324776926, 0.0, 4.857980995127572, 3.169925001442312, 3.169925001442312, 4.321928094887363, 2.0, 6.94251450533924, 5.459431618637297, 5.857980995127572, 7.076815597050831, 5.169925001442312, 6.044394119358453, 6.189824558880018, 5.20945336562895, null, 3.0, 5.857980995127572, 5.857980995127572, 6.882643049361842, 4.247927513443585, 5.0, 3.321928094887362, 4.0, 4.643856189774724, 2.584962500721156, 2.0, 4.0, 3.700439718141092, null, 2.0, 3.0, 3.0, 4.087462841250339, 2.321928094887362, 7.721099188707185, 6.672425341971495, 6.977279923499917, 8.113742166049189, 5.906890595608519, 5.554588851677638, 7.357552004618084, 6.820178962415188, null, 4.584962500721156, 6.965784284662087, 6.965784284662087, 7.960001932068081, 5.0, 6.247927513443585, 4.643856189774724, 5.247927513443585, 6.6865005271832185, 5.169925001442312, 4.0, 5.807354922057604, 3.9068905956085187, null, 4.392317422778761, 5.044394119358453, 5.044394119358453, 6.022367813028454, 3.0, 0.0, null, 1.0, null, null, null, null, null, null, 1.0, null, null, null, null, 6.672425341971495, 5.491853096329675, 5.426264754702098, 7.076815597050831, 0.0, 4.754887502163468, 6.643856189774724, 5.392317422778761, null, 4.321928094887363, 3.807354922057604, 3.807354922057604, 4.906890595608519, 2.321928094887362, 6.794415866350106, 6.321928094887363, 6.266786540694901, 7.592457037268081, 0.0, 5.727920454563199, 7.066089190457772, 5.857980995127572, null, 3.0, 4.700439718141092, 4.807354922057604, 5.832890014164741, 2.807354922057604, 5.727920454563199, 4.954196310386875, 5.044394119358453, 6.129283016944966, 4.392317422778761, 3.807354922057604, 4.906890595608519, 3.9068905956085187, null, 3.321928094887362, 5.087462841250339, 5.087462841250339, 6.087462841250339, 2.584962500721156, 6.965784284662087, 5.584962500721156, 5.807354922057604, 7.426264754702098, 4.321928094887363, 5.807354922057604, 6.357552004618084, 5.044394119358453, null, 4.247927513443585, 6.20945336562895, 6.22881869049588, 7.247927513443585, 4.169925001442312, 7.577428828035749, 6.714245517666122, 7.044394119358453, 8.022367813028454, 7.0, 6.491853096329675, 7.539158811108031, 6.754887502163468, null, 4.0, 7.189824558880018, 7.189824558880018, 8.189824558880018, 4.584962500721156, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 10.687375683437468, 8.308339030139408, 7.483815777264256, 9.131856960608793, 7.139551352398794, 7.562242424221073, 7.643856189774724, 7.507794640198696, 8.383704292474052, 6.426264754702098, 6.087462841250339, 6.087462841250339, 7.118941072723508, 7.321928094887363, 8.79766152585376, 6.977279923499917, 6.3750394313469245, 6.794415866350106, 5.614709844115208, 5.78135971352466, 6.22881869049588, 6.169925001442312, 7.800899899920305, 5.321928094887363, 4.087462841250339, 4.087462841250339, 5.20945336562895, 4.643856189774724, 10.029287226968245, 8.087462841250339, 7.199672344836364, 7.906890595608519, 6.554588851677638, 6.554588851677638, 6.845490050944375, 6.714245517666122, 8.370687406807217, 6.357552004618084, 5.954196310386875, 5.954196310386875, 6.954196310386875, 5.954196310386875, 8.693486957499326, 6.672425341971495, 5.882643049361842, 7.562242424221073, 5.459431618637297, 5.78135971352466, 5.357552004618084, 5.285402218862249, 7.022367813028454, 3.321928094887362, 4.857980995127572, 4.857980995127572, 5.882643049361842, 4.643856189774724, 10.277287400130357, 6.977279923499917, 6.754887502163468, 7.022367813028454, 6.129283016944966, 5.906890595608519, 6.087462841250339, 6.6865005271832185, 7.577428828035749, 6.285402218862249, 5.20945336562895, 5.20945336562895, 6.285402218862249, 7.554588851677638, 8.447083226209653, 7.599912842187128, 6.9886846867721655, 8.290018846932618, 6.491853096329675, 6.491853096329675, 6.807354922057604, 6.714245517666122, 7.2761244052742375, 4.700439718141092, 5.491853096329675, 5.491853096329675, 6.539158811108031, 4.169925001442312, null, 7.400879436282184, null, 4.392317422778761, 2.584962500721156, 6.857980995127572, null, 6.930737337562887, 0.0, 3.584962500721156, 5.584962500721156, 5.584962500721156, 6.584962500721156, null, 9.280770770130603, 5.857980995127572, 5.129283016944966, 6.426264754702098, 5.321928094887363, 5.426264754702098, 5.087462841250339, 4.857980995127572, 6.321928094887363, 4.643856189774724, 3.321928094887362, 3.321928094887362, 4.321928094887363, 5.129283016944966, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, null, null, null, null, null, null, 1.0, 8.59618975614441, 6.266786540694901, 5.584962500721156, 7.483815777264256, 5.20945336562895, 5.357552004618084, 5.0, 4.807354922057604, 6.6293566200796095, 4.906890595608519, 4.0, 4.0, 5.044394119358453, 4.906890595608519, 8.108524456778168, 7.459431618637297, 6.820178962415188, 7.400879436282184, 6.643856189774724, 6.727920454563199, 6.189824558880018, 6.820178962415188, 7.383704292474052, 5.044394119358453, 5.20945336562895, 5.20945336562895, 6.266786540694901, 4.523561956057013, 9.517669388133811, 7.159871336778389, 6.614709844115208, 7.467605550082998, 6.169925001442312, 6.087462841250339, 5.78135971352466, 6.169925001442312, 7.459431618637297, 6.087462841250339, 4.906890595608519, 4.906890595608519, 5.906890595608519, 6.882643049361842, 9.977279923499916, 8.588714635582264, 7.539158811108031, 9.131856960608793, 7.159871336778389, 7.383704292474052, 7.2761244052742375, 7.219168520462161, 8.417852514885897, 6.3750394313469245, 5.832890014164741, 5.832890014164741, 6.845490050944375, 6.614709844115208, 10.224001674198105, 9.044394119358454, 8.103287808412022, 8.842350343413807, 8.022367813028454, 7.864186144654281, 8.055282435501189, 8.20945336562895, 9.207014320177532, 7.199672344836364, 6.977279923499917, 6.977279923499917, 8.0, 7.60733031374961, 9.812177305514448, 8.20945336562895, 7.392317422778761, 8.519636252843213, 6.78135971352466, 7.451211111832329, 6.700439718141092, 7.098032082960526, 8.703903573444663, 5.700439718141092, 6.149747119504682, 6.149747119504682, 7.169925001442312, 6.392317422778761, 8.252665432450248, 5.882643049361842, 6.022367813028454, 5.523561956057013, 5.044394119358453, 4.754887502163468, 6.22881869049588, 5.129283016944966, 7.417852514885898, 5.321928094887363, 3.4594316186372973, 3.4594316186372973, 4.754887502163468, 3.9068905956085187, 9.273795599214264, 6.584962500721156, 6.357552004618084, 7.734709620225838, 5.727920454563199, 6.392317422778761, 6.066089190457772, 5.614709844115208, 7.1799090900149345, 5.882643049361842, 4.321928094887363, 4.321928094887363, 5.392317422778761, 6.0, 10.808159772868375, 8.721099188707186, 8.238404739325079, 9.661778097771988, 7.870364719583405, 7.857980995127572, 7.954196310386875, 8.134426320220927, 9.219168520462162, 6.614709844115208, 7.118941072723508, 7.118941072723508, 8.139551352398794, 7.076815597050831, 10.253847484987404, 8.335390354693924, 7.531381460516312, 8.344295907915816, 7.584962500721156, 7.20945336562895, 7.426264754702098, 7.672425341971495, 8.519636252843213, 6.108524456778169, 6.108524456778169, 6.108524456778169, 7.149747119504682, 6.894817763307944, 8.523561956057012, 5.882643049361842, 4.857980995127572, 6.700439718141092, 5.459431618637297, 4.321928094887363, 5.0, 4.700439718141092, 6.392317422778761, 5.247927513443585, 3.169925001442312, 3.169925001442312, 4.321928094887363, 3.807354922057604, null, null, null, 1.584962500721156, null, null, null, null, null, null, null, null, null, null, 9.426264754702098, 7.321928094887363, 6.658211482751795, 8.066089190457772, 6.303780748177103, 6.554588851677638, 6.459431618637297, 5.977279923499917, 7.774787059601174, 6.599912842187128, 5.357552004618084, 5.357552004618084, 6.392317422778761, 5.459431618637297, 9.842350343413807, 7.651051691178929, 7.199672344836364, 8.519636252843213, 7.044394119358453, 6.754887502163468, 7.149747119504682, 6.129283016944966, 8.060695931687555, 5.523561956057013, 5.321928094887363, 5.321928094887363, 6.357552004618084, 7.076815597050831, 9.46352437327118, 6.189824558880018, 6.022367813028454, 6.129283016944966, 5.554588851677638, 4.643856189774724, 5.044394119358453, 5.392317422778761, 7.05528243550119, 6.442943495848728, 4.087462841250339, 4.087462841250339, 5.129283016944966, 7.011227255423254, 6.672425341971495, 4.954196310386875, 3.584962500721156, 8.038918989292302, 7.118941072723508, 5.0, 3.0, 5.807354922057604, 5.832890014164741, 6.700439718141092, 2.807354922057604, 2.807354922057604, 3.9068905956085187, 4.392317422778761, 9.290018846932618, 6.285402218862249, 5.78135971352466, 7.622051819456376, 6.0, 5.0, 5.20945336562895, 5.129283016944966, 7.149747119504682, 5.977279923499917, 3.4594316186372973, 3.4594316186372973, 4.459431618637297, 5.754887502163468, 9.092757140919852, 6.658211482751795, 6.066089190457772, 7.499845887083206, 5.727920454563199, 5.754887502163468, 5.807354922057604, 5.584962500721156, 7.108524456778169, 5.0, 4.523561956057013, 4.523561956057013, 5.523561956057013, 5.554588851677638, 10.62844554013718, 9.312882955284355, 8.224001674198105, 8.79766152585376, 7.965784284662087, 8.169925001442312, 7.636624620543649, 8.430452551665532, 9.398743691938193, 7.303780748177103, 7.294620748891627, 7.294620748891627, 8.312882955284355, 7.2384047393250786, 9.987264012072538, 7.965784284662087, 7.03342300153745, 7.912889336229962, 6.820178962415188, 6.169925001442312, 6.491853096329675, 6.845490050944375, 8.294620748891626, 6.6865005271832185, 5.392317422778761, 5.392317422778761, 6.426264754702098, 6.339850002884624, 9.290018846932618, 7.451211111832329, 6.569855608330948, 7.554588851677638, 6.614709844115208, 6.247927513443585, 6.392317422778761, 6.491853096329675, 7.426264754702098, 4.954196310386875, 5.087462841250339, 5.087462841250339, 6.169925001442312, 6.22881869049588, 9.588714635582264, 7.366322214245816, 7.022367813028454, 8.016808287686555, 6.475733430966398, 6.523561956057013, 6.339850002884624, 6.523561956057013, 7.894817763307944, 6.066089190457772, 5.459431618637297, 5.459431618637297, 6.523561956057013, 6.321928094887363, 8.829722735086058, 6.539158811108031, 5.426264754702098, 7.577428828035749, 5.357552004618084, 5.392317422778761, 5.20945336562895, 5.930737337562887, 6.882643049361842, 5.321928094887363, 4.807354922057604, 4.807354922057604, 5.906890595608519, 4.321928094887363, 0.0, null, 1.0, 2.0, null, 0.0, null, null, null, 1.0, null, null, 0.0, null, 9.019590728357882, 6.954196310386875, 5.882643049361842, 4.954196310386875, 6.169925001442312, 5.977279923499917, 5.977279923499917, 6.22881869049588, 7.426264754702098, 5.523561956057013, 4.643856189774724, 4.643856189774724, 5.672425341971495, 5.882643049361842, 9.689997971419446, 6.599912842187128, 6.247927513443585, 7.467605550082998, 6.189824558880018, 5.426264754702098, 5.857980995127572, 5.700439718141092, 7.434628227636725, 6.129283016944966, 3.807354922057604, 3.807354922057604, 4.857980995127572, 5.169925001442312, 8.791162888555018, 6.727920454563199, 5.491853096329675, 6.9886846867721655, 5.357552004618084, 4.523561956057013, 5.672425341971495, 5.78135971352466, 6.6293566200796095, 3.4594316186372973, 3.584962500721156, 3.584962500721156, 4.643856189774724, 4.459431618637297, 10.46352437327118, 9.326429487122303, 8.566054038171092, 9.216745858195306, 8.39231742277876, 8.271463027904375, 7.906890595608519, 8.727920454563199, 9.62935662007961, 7.285402218862249, 7.321928094887363, 7.321928094887363, 8.31741261376487, 6.906890595608519, 8.813781191217037, 7.199672344836364, 6.22881869049588, 5.977279923499917, 6.087462841250339, 6.247927513443585, 5.643856189774724, 5.754887502163468, 7.392317422778761, 6.20945336562895, 5.523561956057013, 5.523561956057013, 6.599912842187128, 6.303780748177103, 10.030667136246942, 8.144658242831882, 7.108524456778169, 8.016808287686555, 7.129283016944966, 7.199672344836364, 6.6865005271832185, 7.129283016944966, 8.348728154231077, 6.285402218862249, 5.727920454563199, 5.727920454563199, 6.741466986401147, 6.845490050944375, 9.759888183221834, 8.51175265376738, 7.515699838284043, 8.262094845370179, 7.330916878114617, 7.266786540694901, 6.741466986401147, 7.6293566200796095, 9.098032082960527, 6.658211482751795, 6.426264754702098, 6.426264754702098, 7.442943495848728, 6.954196310386875, 9.799281621521923, 8.326429487122303, 7.3750394313469245, 9.095397022792557, 7.321928094887363, 7.22881869049588, 6.794415866350106, 7.076815597050831, 8.603626344986193, 6.044394119358453, 6.0, 6.0, 7.0, 7.247927513443585, 9.403012023574997, 7.434628227636725, 6.741466986401147, 7.2761244052742375, 6.794415866350106, 6.569855608330948, 6.426264754702098, 6.954196310386875, 7.7073591320808825, 5.459431618637297, 5.247927513443585, 5.247927513443585, 6.357552004618084, 5.954196310386875, 10.019590728357882, 8.353146825498083, 7.94251450533924, 9.154818109052105, 7.592457037268081, 7.169925001442312, 7.727920454563199, 7.658211482751795, 8.599912842187127, 6.247927513443585, 6.266786540694901, 6.266786540694901, 7.266786540694901, 6.906890595608519, 8.451211111832329, 6.658211482751795, 3.700439718141092, 6.3750394313469245, 5.672425341971495, 5.044394119358453, 4.906890595608519, 5.20945336562895, 6.475733430966398, 5.285402218862249, 4.0, 4.0, 5.129283016944966, 5.426264754702098, 1.0, null, 1.0, 1.0, null, 1.0, null, null, null, null, null, null, 0.0, null, 10.220378327695228, 7.971543553950772, 7.266786540694901, 7.94251450533924, 7.098032082960526, 6.9886846867721655, 6.714245517666122, 7.011227255423254, 8.479780264029099, 6.169925001442312, 5.643856189774724, 5.643856189774724, 6.672425341971495, 5.906890595608519, 9.483815777264256, 7.05528243550119, 6.247927513443585, 7.727920454563199, 6.285402218862249, 5.392317422778761, 6.22881869049588, 6.022367813028454, 7.741466986401147, 5.459431618637297, 5.129283016944966, 5.129283016944966, 6.129283016944966, 4.954196310386875, 10.265615046484458, 7.658211482751795, 6.3750394313469245, 7.523561956057013, 6.643856189774724, 6.266786540694901, 6.794415866350106, 6.857980995127572, 7.936637939002571, 5.247927513443585, 5.0, 5.0, 6.0, 7.0, 9.746514321138463, 7.894817763307944, 6.643856189774724, 8.379378367071261, 6.6293566200796095, 6.741466986401147, 6.614709844115208, 6.539158811108031, 8.169925001442312, 6.044394119358453, 5.20945336562895, 5.20945336562895, 6.247927513443585, 6.285402218862249, 7.721099188707185, 5.643856189774724, 5.523561956057013, 6.108524456778169, 4.523561956057013, 4.584962500721156, 4.584962500721156, 4.459431618637297, 6.321928094887363, 4.906890595608519, 3.9068905956085187, 3.9068905956085187, 4.906890595608519, 5.044394119358453, 9.76983784362944, 8.581200581924957, 7.409390936137702, 8.546894459887637, 7.348728154231077, 7.700439718141092, 7.483815777264256, 7.531381460516312, 8.909893083770042, 6.845490050944375, 6.087462841250339, 6.087462841250339, 7.087462841250339, 7.22881869049588, 9.873444112515376, 7.727920454563199, 6.918863237274595, 8.59245703726808, 6.857980995127572, 6.459431618637297, 5.554588851677638, 7.022367813028454, 8.290018846932618, 5.954196310386875, 5.614709844115208, 5.614709844115208, 6.643856189774724, 5.247927513443585, 8.693486957499326, 6.303780748177103, 5.523561956057013, 7.285402218862249, 5.285402218862249, 5.169925001442312, 5.491853096329675, 5.392317422778761, 6.442943495848728, 5.459431618637297, 3.9068905956085187, 3.9068905956085187, 4.954196310386875, 5.169925001442312, 9.400879436282183, 7.2384047393250786, 7.22881869049588, 7.672425341971495, 6.6865005271832185, 6.643856189774724, 6.599912842187128, 6.870364719583405, 7.882643049361842, 5.491853096329675, 5.285402218862249, 5.285402218862249, 6.321928094887363, 7.247927513443585, 10.043027283594547, 7.159871336778389, 6.700439718141092, 8.149747119504681, 6.643856189774724, 6.247927513443585, 6.584962500721156, 6.189824558880018, 7.820178962415188, 5.930737337562887, 5.357552004618084, 5.357552004618084, 6.392317422778761, 6.820178962415188, 8.7714894695006, 5.727920454563199, 3.807354922057604, 6.266786540694901, 4.321928094887363, 4.523561956057013, 4.700439718141092, 4.754887502163468, 6.066089190457772, 5.523561956057013, 3.169925001442312, 3.169925001442312, 4.169925001442312, 3.0, null, 1.0, 1.0, 1.584962500721156, null, null, null, 0.0, null, null, null, null, null, 0.0, 10.34318571544788, 7.700439718141092, 7.266786540694901, 7.857980995127572, 6.832890014164741, 7.066089190457772, 6.442943495848728, 7.383704292474052, 8.294620748891626, 6.442943495848728, 5.357552004618084, 5.357552004618084, 6.392317422778761, 6.643856189774724, 9.656424863277781, 7.044394119358453, 6.409390936137702, 7.832890014164741, 5.930737337562887, 5.491853096329675, 6.303780748177103, 5.906890595608519, 7.087462841250339, 6.0, 4.754887502163468, 4.754887502163468, 5.754887502163468, 5.554588851677638, 9.505811553919594, 7.022367813028454, 6.491853096329675, 7.044394119358453, 6.129283016944966, 5.700439718141092, 6.247927513443585, 6.169925001442312, 7.417852514885898, 5.906890595608519, 4.857980995127572, 4.857980995127572, 5.857980995127572, 6.569855608330948, 10.443979542601253, 8.744833837499545, 7.499845887083206, 9.303780748177102, 7.636624620543649, 7.906890595608519, 7.651051691178929, 7.599912842187128, 8.86418614465428, 6.491853096329675, 6.78135971352466, 6.78135971352466, 7.851749041416057, 6.894817763307944, 9.86418614465428, 7.954196310386875, 6.906890595608519, 7.882643049361842, 7.022367813028454, 7.189824558880018, 7.219168520462161, 6.9886846867721655, 8.51175265376738, 5.643856189774724, 6.0, 6.0, 7.05528243550119, 5.954196310386875, 10.213104219641906, 9.257387842692651, 8.842350343413807, 10.001408194392809, 8.668884984266247, 8.581200581924957, 8.447083226209653, 8.353146825498083, 9.5980525001616, 7.2384047393250786, 7.417852514885898, 7.417852514885898, 8.430452551665532, 7.285402218862249, 8.851749041416058, 7.357552004618084, 6.643856189774724, 7.78135971352466, 5.643856189774724, 6.022367813028454, 6.022367813028454, 6.392317422778761, 7.312882955284356, 4.807354922057604, 4.643856189774724, 4.643856189774724, 5.700439718141092, 5.977279923499917, 5.954196310386875, null, null, null, null, null, 1.0, 1.0, 2.321928094887362, null, 0.0, 0.0, 1.0, 3.0, 10.63117705570398, 8.778077129535358, 7.826548487290915, 8.73809225962049, 7.954196310386875, 8.285402218862249, 7.199672344836364, 8.262094845370179, 9.03342300153745, 6.554588851677638, 6.672425341971495, 6.672425341971495, 7.6865005271832185, 7.108524456778169, 9.03342300153745, 5.754887502163468, 5.247927513443585, 5.554588851677638, 4.754887502163468, 4.754887502163468, 4.700439718141092, 5.614709844115208, 6.523561956057013, 4.321928094887363, 4.321928094887363, 4.321928094887363, 5.357552004618084, 5.584962500721156, 9.625708843064466, 7.348728154231077, 6.954196310386875, 6.906890595608519, 6.643856189774724, 6.523561956057013, 6.087462841250339, 6.459431618637297, 7.569855608330948, 4.954196310386875, 4.584962500721156, 4.584962500721156, 5.614709844115208, 5.857980995127572, null, 1.0, null, 1.584962500721156, null, 0.0, null, null, null, 1.0, 0.0, 0.0, 1.0, null, 7.851749041416057, 6.523561956057013, 5.129283016944966, 6.247927513443585, 5.321928094887363, 5.614709844115208, 5.554588851677638, 5.392317422778761, 6.303780748177103, 4.459431618637297, 4.0, 4.0, 5.0, 5.20945336562895, 8.879583249612784, 8.016808287686555, 7.108524456778169, 8.614709844115207, 7.03342300153745, 6.409390936137702, 6.807354922057604, 6.965784284662087, 7.78135971352466, 5.087462841250339, 5.754887502163468, 5.754887502163468, 6.794415866350106, 5.523561956057013, 8.39231742277876, 7.507794640198696, 6.303780748177103, 7.888743248898259, 6.475733430966398, 6.0, 6.426264754702098, 6.475733430966398, 7.321928094887363, 5.426264754702098, 5.044394119358453, 5.087462841250339, 6.129283016944966, 4.584962500721156, 10.395534135462302, 9.537218400538595, 9.027905996569885, 10.246740598493144, 8.43879185257826, 8.62935662007961, 8.81698362325538, 8.845490050944376, 9.779719355143405, 7.129283016944966, 7.546894459887636, 7.562242424221073, 8.569855608330949, 7.523561956057013, 9.698704666770345, 9.118941072723507, 8.654636028527968, 9.839203788096944, 8.08214904135387, 8.515699838284043, 8.523561956057012, 8.29920801838728, 9.139551352398794, 6.491853096329675, 7.491853096329675, 7.491853096329675, 8.499845887083206, 5.954196310386875, 9.640244936222345, 9.870364719583405, 8.734709620225837, 10.200898605038445, 8.569855608330949, 9.00842862207058, 8.144658242831882, 9.517669388133811, 9.622051819456376, 6.965784284662087, 8.027905996569885, 8.027905996569885, 9.036173612553485, 7.03342300153745, 9.44086916761087, 8.467605550082997, 7.266786540694901, 8.842350343413807, 7.066089190457772, 7.434628227636725, 7.169925001442312, 8.055282435501189, 8.554588851677638, 5.357552004618084, 6.569855608330948, 6.584962500721156, 7.614709844115208, 5.0, 9.579315937580015, 8.654636028527968, 7.787902559391432, 9.149747119504681, 7.426264754702098, 7.98299357469431, 7.6653359171851765, 7.700439718141092, 8.76487159073609, 6.22881869049588, 6.741466986401147, 6.741466986401147, 7.7481928495894605, 6.0, 8.994353436858859, 8.247927513443585, 7.924812503605781, 8.011227255423254, 7.159871336778389, 7.05528243550119, 7.2384047393250786, 7.400879436282184, 8.326429487122303, 5.247927513443585, 6.459431618637297, 6.459431618637297, 7.467605550082998, 6.20945336562895, 9.285402218862249, 8.134426320220927, 7.22881869049588, 8.974414589805527, 7.266786540694901, 7.6293566200796095, 6.714245517666122, 7.491853096329675, 8.396604781181859, 4.523561956057013, 5.930737337562887, 5.930737337562887, 6.965784284662087, 5.554588851677638, 7.918863237274595, 7.339850002884624, 6.108524456778169, 7.247927513443585, 6.357552004618084, 6.459431618637297, 6.129283016944966, 6.087462841250339, 7.022367813028454, 5.169925001442312, 5.321928094887363, 5.321928094887363, 6.3750394313469245, 5.044394119358453, 1.0, 1.0, null, 0.0, 0.0, 0.0, 0.0, null, null, null, null, null, null, null, 8.038918989292302, 7.199672344836364, 6.20945336562895, 7.700439718141092, 6.266786540694901, 6.584962500721156, 6.044394119358453, 6.392317422778761, 7.2761244052742375, 5.285402218862249, 4.459431618637297, 4.459431618637297, 5.459431618637297, 4.321928094887363, 8.686500527183219, 7.936637939002571, 7.622051819456376, 8.845490050944376, 7.149747119504682, 6.9886846867721655, 7.434628227636725, 6.954196310386875, 8.005624549193879, 5.977279923499917, 5.977279923499917, 5.977279923499917, 6.9886846867721655, 5.129283016944966, 7.118941072723508, 6.906890595608519, 5.584962500721156, 7.2761244052742375, 4.807354922057604, 5.700439718141092, 5.882643049361842, 5.754887502163468, 6.22881869049588, 4.584962500721156, 5.0, 5.0, 6.022367813028454, 3.584962500721156, 10.458406613236532, 10.00842862207058, 9.216745858195306, 10.591522346570734, 8.845490050944376, 9.294620748891626, 9.219168520462162, 9.221587121264806, 9.939579214314692, 7.9886846867721655, 8.03342300153745, 8.03342300153745, 9.038918989292302, 7.6865005271832185, 8.049848549450562, 7.6653359171851765, 6.459431618637297, 7.562242424221073, 6.459431618637297, 6.845490050944375, 6.906890595608519, 6.459431618637297, 7.539158811108031, 4.247927513443585, 5.247927513443585, 5.247927513443585, 6.266786540694901, 4.857980995127572, 9.729620743553038, 8.997179480937621, 7.9886846867721655, 9.179909090014934, 8.049848549450562, 8.243173983472952, 7.734709620225838, 8.118941072723507, 8.939579214314692, 6.266786540694901, 7.1799090900149345, 7.1799090900149345, 8.184875342908283, 6.714245517666122, 9.074141462752506, 8.280770770130603, 7.491853096329675, 9.074141462752506, 7.467605550082998, 7.400879436282184, 7.330916878114617, 7.7073591320808825, 8.614709844115207, 5.614709844115208, 6.584962500721156, 6.584962500721156, 7.60733031374961, 5.882643049361842, 9.259743263690781, 8.603626344986193, 7.539158811108031, 9.231221180711186, 7.2384047393250786, 7.554588851677638, 7.149747119504682, 7.60733031374961, 8.413627929024173, 5.321928094887363, 5.977279923499917, 5.977279923499917, 6.9886846867721655, 6.022367813028454, 2.584962500721156, 3.0, 2.0, 1.0, 2.584962500721156, 2.584962500721156, 2.0, 2.807354922057604, 2.807354922057604, null, 1.0, 1.0, 1.584962500721156, null, 8.682994583681683, 8.03342300153745, 6.94251450533924, 8.654636028527968, 7.011227255423254, 6.807354922057604, 7.05528243550119, 7.199672344836364, 7.882643049361842, 5.523561956057013, 6.044394119358453, 6.044394119358453, 7.066089190457772, 5.672425341971495, 7.6865005271832185, 6.658211482751795, 6.087462841250339, 6.882643049361842, 5.700439718141092, 6.022367813028454, 5.807354922057604, 5.954196310386875, 7.022367813028454, 3.4594316186372973, 4.906890595608519, 4.906890595608519, 5.954196310386875, 4.700439718141092, null, 1.584962500721156, 0.0, 0.0, null, 1.0, null, null, 0.0, null, null, null, null, null, 8.330916878114618, 7.813781191217037, 6.569855608330948, 6.426264754702098, 6.507794640198696, 6.6293566200796095, 6.78135971352466, 7.139551352398794, 7.554588851677638, 4.754887502163468, 5.672425341971495, 5.672425341971495, 6.6865005271832185, 4.857980995127572, 8.562242424221072, 8.194756854422248, 7.219168520462161, 8.614709844115207, 6.965784284662087, 7.189824558880018, 7.257387842692652, 7.693486957499325, 8.134426320220927, 6.459431618637297, 6.108524456778169, 6.108524456778169, 7.139551352398794, 5.20945336562895, 6.22881869049588, 5.523561956057013, 4.0, 5.977279923499917, 4.0, 4.807354922057604, 4.954196310386875, 4.643856189774724, 5.754887502163468, 3.807354922057604, 3.9068905956085187, 3.9068905956085187, 5.0, null, 10.499845887083206, 7.491853096329675, 6.523561956057013, 8.744833837499545, 6.820178962415188, 6.870364719583405, 6.357552004618084, 6.94251450533924, 8.169925001442312, 6.303780748177103, 5.807354922057604, 5.807354922057604, 6.807354922057604, 7.475733430966398, 9.566054038171092, 7.303780748177103, 7.1799090900149345, 8.214319120800766, 6.491853096329675, 6.459431618637297, 7.076815597050831, 6.569855608330948, 8.370687406807217, 6.357552004618084, 5.807354922057604, 5.807354922057604, 6.820178962415188, 6.507794640198696, 9.306061689428342, 6.614709844115208, 6.108524456778169, 7.754887502163468, 6.22881869049588, 6.169925001442312, 6.044394119358453, 6.442943495848728, 7.434628227636725, 6.066089190457772, 4.807354922057604, 4.807354922057604, 5.882643049361842, 6.643856189774724, 8.682994583681683, 6.247927513443585, 5.807354922057604, 6.3750394313469245, 5.930737337562887, 5.357552004618084, 5.882643049361842, 5.554588851677638, 6.727920454563199, 5.426264754702098, 4.584962500721156, 4.584962500721156, 5.584962500721156, 6.129283016944966, 10.151016538892248, 7.467605550082998, 6.754887502163468, 7.303780748177103, 6.149747119504682, 5.906890595608519, 6.247927513443585, 6.523561956057013, 7.6865005271832185, 6.599912842187128, 5.321928094887363, 5.321928094887363, 6.339850002884624, 7.531381460516312, 8.703903573444663, 7.330916878114617, 7.118941072723508, 8.581200581924957, 7.0, 7.044394119358453, 7.434628227636725, 6.754887502163468, 7.832890014164741, 5.321928094887363, 6.0, 6.0, 6.977279923499917, 4.906890595608519, 3.4594316186372973, 9.116343961237469, null, 7.03342300153745, 4.392317422778761, 7.94251450533924, null, 7.906890595608519, 1.584962500721156, 5.584962500721156, 7.20945336562895, 7.20945336562895, 8.204571144249204, 2.0, 10.53818893205242, 7.960001932068081, 7.266786540694901, 9.005624549193879, 7.409390936137702, 7.312882955284356, 7.087462841250339, 7.531381460516312, 8.430452551665532, 6.78135971352466, 5.672425341971495, 5.672425341971495, 6.714245517666122, 7.930737337562887, 9.335390354693924, 8.88264304936184, 7.800899899920305, 8.64745842645492, 7.954196310386875, 7.965784284662087, 7.539158811108031, 8.108524456778168, 8.78135971352466, 6.149747119504682, 6.906890595608519, 6.906890595608519, 7.924812503605781, 6.266786540694901, 9.35974956032233, 6.918863237274595, 6.0, 8.134426320220927, 6.523561956057013, 6.247927513443585, 6.643856189774724, 6.768184324776926, 7.60733031374961, 6.022367813028454, 4.954196310386875, 4.954196310386875, 5.930737337562887, 6.149747119504682, 9.131856960608793, 8.906890595608518, 8.108524456778168, 8.727920454563199, 8.233619676759702, 8.174925682500678, 7.721099188707185, 8.426264754702098, 8.888743248898258, 6.569855608330948, 7.011227255423254, 7.044394119358453, 8.071462362556623, 5.832890014164741, 10.037546953962178, 7.539158811108031, 7.366322214245816, 6.087462841250339, 7.076815597050831, 7.159871336778389, 6.9886846867721655, 7.3750394313469245, 8.134426320220927, 6.3750394313469245, 5.857980995127572, 5.857980995127572, 6.857980995127572, 7.247927513443585, 9.79603960882977, 7.546894459887636, 6.339850002884624, 7.3750394313469245, 6.475733430966398, 6.022367813028454, 6.247927513443585, 6.584962500721156, 7.906890595608519, 6.569855608330948, 5.129283016944966, 5.129283016944966, 6.129283016944966, 6.643856189774724, 9.870364719583405, 8.092757140919852, 7.266786540694901, 8.867278739709661, 7.348728154231077, 7.636624620543649, 7.05528243550119, 7.2384047393250786, 8.59618975614441, 6.832890014164741, 6.285402218862249, 6.285402218862249, 7.285402218862249, 6.6865005271832185, 8.930737337562887, 7.05528243550119, 5.491853096329675, 7.562242424221073, 6.149747119504682, 6.22881869049588, 5.807354922057604, 6.108524456778169, 7.832890014164741, 6.169925001442312, 4.087462841250339, 4.087462841250339, 5.087462841250339, 4.857980995127572, 9.914385132155443, 7.569855608330948, 7.189824558880018, 8.228818690495881, 6.584962500721156, 7.400879436282184, 6.820178962415188, 7.266786540694901, 8.968666793195208, 6.409390936137702, 5.087462841250339, 5.087462841250339, 6.169925001442312, 7.303780748177103, 10.147204924942228, 8.375039431346925, 7.392317422778761, 8.997179480937621, 7.442943495848728, 7.6865005271832185, 7.312882955284356, 7.6293566200796095, 8.651051691178928, 6.599912842187128, 5.672425341971495, 5.672425341971495, 6.700439718141092, 5.614709844115208, 10.057991722759176, 8.546894459887637, 7.199672344836364, 9.189824558880018, 7.303780748177103, 7.2761244052742375, 7.339850002884624, 7.562242424221073, 8.535275376620802, 6.672425341971495, 6.599912842187128, 6.599912842187128, 7.6653359171851765, 7.20945336562895, 9.60917873814198, 8.0, 7.562242424221073, 8.731319031025064, 7.066089190457772, 7.098032082960526, 6.9886846867721655, 7.523561956057013, 8.204571144249204, 6.108524456778169, 5.857980995127572, 5.857980995127572, 6.857980995127572, 6.0, 9.746514321138463, 7.417852514885898, 6.442943495848728, 7.800899899920305, 7.05528243550119, 6.658211482751795, 6.584962500721156, 7.475733430966398, 8.252665432450248, 6.20945336562895, 5.321928094887363, 5.321928094887363, 6.321928094887363, 5.523561956057013, 10.246740598493144, 8.303780748177102, 7.577428828035749, 8.326429487122303, 7.700439718141092, 7.800899899920305, 7.451211111832329, 8.087462841250339, 8.845490050944376, 6.906890595608519, 6.539158811108031, 6.539158811108031, 7.546894459887636, 6.9886846867721655, 10.129283016944967, 8.08214904135387, 7.592457037268081, 8.668884984266247, 7.392317422778761, 7.636624620543649, 7.169925001442312, 7.614709844115208, 8.658211482751796, 6.149747119504682, 6.820178962415188, 6.820178962415188, 7.807354922057604, 6.906890595608519, 9.64745842645492, 7.60733031374961, 7.357552004618084, 8.83605035505807, 6.832890014164741, 7.515699838284043, 7.149747119504682, 7.149747119504682, 8.266786540694902, 6.475733430966398, 5.906890595608519, 5.906890595608519, 6.918863237274595, 6.6865005271832185, 10.77066389291676, 8.027905996569885, 7.614709844115208, 8.906890595608518, 7.400879436282184, 7.294620748891627, 6.977279923499917, 6.954196310386875, 8.854868383260236, 7.562242424221073, 6.044394119358453, 6.044394119358453, 7.022367813028454, 8.016808287686555, 5.554588851677638, 3.807354922057604, 2.0, 8.303780748177102, 6.426264754702098, 3.321928094887362, 3.0, 4.954196310386875, 4.169925001442312, 6.129283016944966, 1.584962500721156, 1.584962500721156, 2.584962500721156, 3.807354922057604, 9.88264304936184, 7.434628227636725, 6.614709844115208, 5.832890014164741, 7.044394119358453, 6.066089190457772, 6.965784284662087, 6.507794640198696, 8.257387842692651, 6.426264754702098, 4.584962500721156, 4.584962500721156, 5.700439718141092, 7.1799090900149345, 9.03342300153745, 6.754887502163468, 5.882643049361842, 5.614709844115208, 6.22881869049588, 5.930737337562887, 5.247927513443585, 6.392317422778761, 7.139551352398794, 5.977279923499917, 4.807354922057604, 4.807354922057604, 5.832890014164741, 6.022367813028454, 9.493855449240822, 7.149747119504682, 5.857980995127572, 8.280770770130603, 6.3750394313469245, 6.285402218862249, 6.741466986401147, 6.672425341971495, 7.499845887083206, 6.507794640198696, 5.044394119358453, 5.044394119358453, 6.087462841250339, 6.754887502163468, 10.296916206879288, 8.108524456778168, 7.392317422778761, 6.569855608330948, 7.882643049361842, 7.383704292474052, 7.257387842692652, 7.888743248898259, 8.92184093707449, 7.531381460516312, 6.044394119358453, 6.044394119358453, 7.066089190457772, 7.22881869049588, 10.61654884377899, 8.994353436858859, 8.422064766172813, 9.749869427396844, 8.357552004618084, 8.184875342908283, 7.94251450533924, 8.257387842692651, 9.405141463136344, 7.507794640198696, 6.507794640198696, 6.507794640198696, 7.531381460516312, 7.78135971352466, 9.768184324776927, 8.087462841250339, 7.199672344836364, 8.703903573444663, 7.189824558880018, 7.339850002884624, 7.409390936137702, 7.554588851677638, 8.535275376620802, 6.459431618637297, 6.321928094887363, 6.321928094887363, 7.339850002884624, 6.94251450533924, 10.428360172704291, 8.266786540694902, 7.592457037268081, 9.262094845370179, 7.539158811108031, 7.531381460516312, 7.451211111832329, 7.977279923499917, 8.977279923499916, 6.820178962415188, 6.357552004618084, 6.357552004618084, 7.409390936137702, 7.483815777264256, 10.57742882803575, 8.174925682500678, 7.693486957499325, 9.194756854422248, 7.900866807980749, 7.584962500721156, 7.539158811108031, 8.03342300153745, 8.832890014164741, 6.643856189774724, 6.442943495848728, 6.442943495848728, 7.491853096329675, 7.321928094887363, 10.531381460516313, 9.283088353024002, 8.330916878114618, 9.92184093707449, 8.353146825498083, 8.31741261376487, 8.016808287686555, 8.632995197142957, 9.62935662007961, 7.366322214245816, 7.044394119358453, 7.044394119358453, 8.044394119358454, 7.7073591320808825, 10.221587121264806, 7.845490050944375, 7.219168520462161, 6.129283016944966, 7.357552004618084, 6.918863237274595, 6.714245517666122, 7.1799090900149345, 8.573647187493322, 6.857980995127572, 6.247927513443585, 6.247927513443585, 7.285402218862249, 7.491853096329675, 10.059344460824425, 7.994353436858858, 6.794415866350106, 8.588714635582264, 7.257387842692652, 7.3750394313469245, 7.066089190457772, 6.965784284662087, 8.39231742277876, 7.05528243550119, 5.614709844115208, 5.614709844115208, 6.614709844115208, 7.266786540694901, 8.515699838284043, 6.491853096329675, 5.247927513443585, 6.78135971352466, 5.754887502163468, 4.584962500721156, 6.0, 5.169925001442312, 6.614709844115208, 5.727920454563199, 4.643856189774724, 4.643856189774724, 5.672425341971495, 6.491853096329675, 8.810571634741146, 6.303780748177103, 5.700439718141092, 6.357552004618084, 5.584962500721156, 4.954196310386875, 5.044394119358453, 5.0, 6.321928094887363, 5.643856189774724, 3.700439718141092, 3.700439718141092, 4.754887502163468, 5.247927513443585, 8.885696373339394, 6.108524456778169, 4.700439718141092, 5.491853096329675, 5.727920454563199, 5.0, 5.247927513443585, 6.20945336562895, 6.6865005271832185, 5.285402218862249, 4.087462841250339, 4.169925001442312, 5.129283016944966, 5.20945336562895, 8.330916878114618, 7.022367813028454, 5.392317422778761, 6.930737337562887, 5.754887502163468, 5.78135971352466, 4.857980995127572, 6.169925001442312, 7.483815777264256, 5.20945336562895, 4.169925001442312, 4.169925001442312, 5.20945336562895, 5.554588851677638, 9.703903573444663, 7.832890014164741, 7.22881869049588, 8.562242424221072, 7.108524456778169, 7.3750394313469245, 6.392317422778761, 7.303780748177103, 8.361943773735241, 6.491853096329675, 5.584962500721156, 5.584962500721156, 6.599912842187128, 5.954196310386875, 9.661778097771988, 7.658211482751795, 7.087462841250339, 6.409390936137702, 7.312882955284356, 6.965784284662087, 6.672425341971495, 7.459431618637297, 8.03342300153745, 6.459431618637297, 5.700439718141092, 5.700439718141092, 6.714245517666122, 6.870364719583405, 9.712527000439824, 7.768184324776926, 7.285402218862249, 6.539158811108031, 7.643856189774724, 6.94251450533924, 6.94251450533924, 7.400879436282184, 8.357552004618084, 6.108524456778169, 6.0, 6.0, 7.011227255423254, 6.832890014164741, 10.24436383512051, 8.467605550082997, 8.011227255423254, 8.326429487122303, 8.055282435501189, 7.734709620225838, 7.442943495848728, 7.851749041416057, 9.030667136246942, 6.882643049361842, 6.357552004618084, 6.357552004618084, 7.357552004618084, 6.965784284662087, 9.027905996569885, 7.467605550082998, 6.339850002884624, 7.727920454563199, 6.768184324776926, 6.247927513443585, 6.189824558880018, 6.475733430966398, 7.857980995127572, 5.906890595608519, 5.321928094887363, 5.321928094887363, 6.339850002884624, 5.882643049361842, 9.250298417906333, 6.9886846867721655, 6.357552004618084, 7.087462841250339, 6.507794640198696, 6.554588851677638, 6.321928094887363, 6.339850002884624, 7.475733430966398, 5.247927513443585, 5.087462841250339, 5.087462841250339, 6.087462841250339, 5.857980995127572, 9.96289600533726, 7.768184324776926, 6.569855608330948, 8.39231742277876, 7.321928094887363, 6.807354922057604, 6.965784284662087, 7.05528243550119, 8.303780748177102, 6.321928094887363, 5.285402218862249, 5.285402218862249, 6.303780748177103, 6.714245517666122, 10.207014320177532, 7.483815777264256, 6.6293566200796095, 8.59245703726808, 7.2761244052742375, 6.768184324776926, 6.857980995127572, 6.857980995127572, 8.400879436282183, 6.643856189774724, 6.0, 6.0, 7.022367813028454, 6.965784284662087, 9.29920801838728, 6.820178962415188, 6.321928094887363, 7.78135971352466, 6.409390936137702, 6.149747119504682, 6.426264754702098, 5.930737337562887, 7.294620748891627, 6.066089190457772, 4.584962500721156, 4.584962500721156, 5.643856189774724, 5.643856189774724, 8.804131021183318, 6.169925001442312, 5.832890014164741, 6.9886846867721655, 6.20945336562895, 5.643856189774724, 5.78135971352466, 5.954196310386875, 7.2761244052742375, 4.954196310386875, 4.392317422778761, 4.392317422778761, 5.459431618637297, 5.247927513443585, 10.098032082960527, 7.159871336778389, 6.768184324776926, 8.807354922057604, 7.05528243550119, 6.614709844115208, 6.965784284662087, 6.584962500721156, 7.857980995127572, 6.523561956057013, 5.169925001442312, 5.169925001442312, 6.169925001442312, 6.857980995127572, 9.111135670234708, 5.584962500721156, 5.357552004618084, 6.643856189774724, 6.285402218862249, 5.491853096329675, 5.700439718141092, 5.807354922057604, 6.768184324776926, 6.339850002884624, 4.643856189774724, 4.643856189774724, 5.727920454563199, 6.022367813028454, 9.276124405274238, 7.066089190457772, 6.087462841250339, 7.03342300153745, 6.507794640198696, 6.044394119358453, 6.491853096329675, 6.022367813028454, 7.491853096329675, 5.807354922057604, 4.321928094887363, 4.321928094887363, 5.321928094887363, 5.857980995127572, 9.39231742277876, 7.285402218862249, 6.321928094887363, 7.918863237274595, 6.658211482751795, 6.321928094887363, 6.832890014164741, 6.022367813028454, 7.643856189774724, 5.523561956057013, 4.906890595608519, 4.906890595608519, 5.954196310386875, 6.906890595608519, 10.582141981658777, 7.7073591320808825, 7.118941072723508, 8.800899899920305, 7.400879436282184, 7.169925001442312, 7.303780748177103, 7.139551352398794, 8.689997971419446, 6.9886846867721655, 5.491853096329675, 5.491853096329675, 6.539158811108031, 7.417852514885898, 10.35974956032233, 7.562242424221073, 6.906890595608519, 7.839203788096944, 7.330916878114617, 6.6865005271832185, 6.9886846867721655, 6.741466986401147, 8.219168520462162, 6.794415866350106, 5.392317422778761, 5.392317422778761, 6.409390936137702, 7.523561956057013, 10.688250309133178, 8.672425341971495, 7.78135971352466, 8.761551232444479, 8.224001674198105, 7.820178962415188, 7.515699838284043, 7.813781191217037, 9.074141462752506, 7.285402218862249, 6.523561956057013, 6.523561956057013, 7.569855608330948, 7.614709844115208, 9.977279923499916, 7.741466986401147, 6.930737337562887, 8.312882955284355, 7.169925001442312, 7.022367813028454, 6.977279923499917, 7.098032082960526, 8.353146825498083, 6.392317422778761, 5.930737337562887, 5.954196310386875, 7.011227255423254, 6.727920454563199, 10.20945336562895, 7.672425341971495, 6.894817763307944, 7.483815777264256, 7.451211111832329, 7.366322214245816, 6.845490050944375, 7.2384047393250786, 8.584962500721156, 6.754887502163468, 5.930737337562887, 5.930737337562887, 6.94251450533924, 7.066089190457772, 9.915879378835774, 7.483815777264256, 6.794415866350106, 8.59245703726808, 6.894817763307944, 6.906890595608519, 6.475733430966398, 6.658211482751795, 7.888743248898259, 6.918863237274595, 5.614709844115208, 5.643856189774724, 6.643856189774724, 6.845490050944375, 9.515699838284043, 7.3750394313469245, 6.392317422778761, 8.312882955284355, 6.94251450533924, 6.149747119504682, 6.643856189774724, 6.727920454563199, 8.016808287686555, 6.554588851677638, 5.523561956057013, 5.523561956057013, 6.569855608330948, 6.599912842187128, 8.266786540694902, 5.523561956057013, 5.169925001442312, 6.741466986401147, 4.754887502163468, 5.087462841250339, 5.0, 5.129283016944966, 6.357552004618084, 5.169925001442312, 3.807354922057604, 3.807354922057604, 4.807354922057604, 5.044394119358453, 9.100662339005199, 5.807354922057604, 5.087462841250339, 7.0, 5.78135971352466, 5.643856189774724, 5.643856189774724, 5.643856189774724, 6.614709844115208, 6.0, 4.247927513443585, 4.247927513443585, 5.247927513443585, 5.930737337562887, 9.556506054671928, 7.7073591320808825, 6.768184324776926, 7.6293566200796095, 7.1799090900149345, 7.2384047393250786, 6.954196310386875, 7.2384047393250786, 8.467605550082997, 6.918863237274595, 6.189824558880018, 6.189824558880018, 7.219168520462161, 6.426264754702098, 7.149747119504682, null, 2.0, 2.584962500721156, 3.0, 1.0, null, null, 4.321928094887363, 4.0, 0.0, 0.0, 1.0, 4.169925001442312, 10.193525360501216, 7.475733430966398, 6.894817763307944, 8.523561956057012, 7.129283016944966, 6.643856189774724, 6.569855608330948, 7.044394119358453, 8.451211111832329, 6.614709844115208, 5.857980995127572, 5.857980995127572, 6.870364719583405, 6.129283016944966, 9.308339030139408, 6.108524456778169, 5.321928094887363, 6.930737337562887, 5.357552004618084, 4.807354922057604, 5.169925001442312, 4.754887502163468, 6.78135971352466, 5.857980995127572, 4.247927513443585, 4.247927513443585, 5.321928094887363, 5.523561956057013, 9.63662462054365, 7.20945336562895, 6.741466986401147, 6.22881869049588, 6.6293566200796095, 6.266786540694901, 6.108524456778169, 7.257387842692652, 7.845490050944375, 6.339850002884624, 5.426264754702098, 5.426264754702098, 6.426264754702098, 5.392317422778761, 9.002815015607053, 7.546894459887636, 6.794415866350106, 8.696967526234287, 6.820178962415188, 7.011227255423254, 6.857980995127572, 7.294620748891627, 7.960001932068081, 6.339850002884624, 6.129283016944966, 6.129283016944966, 7.139551352398794, 5.523561956057013, 9.049848549450562, 7.727920454563199, 6.459431618637297, 7.864186144654281, 6.930737337562887, 6.794415866350106, 6.78135971352466, 6.820178962415188, 8.124121311829187, 6.044394119358453, 5.78135971352466, 5.78135971352466, 6.794415866350106, 5.857980995127572, 8.988684686772165, 7.888743248898259, 7.011227255423254, 7.820178962415188, 7.129283016944966, 7.569855608330948, 6.700439718141092, 7.912889336229962, 8.113742166049189, 6.584962500721156, 6.20945336562895, 6.20945336562895, 7.22881869049588, 5.954196310386875, 8.829722735086058, 7.6865005271832185, 7.139551352398794, 9.0, 7.426264754702098, 7.693486957499325, 7.357552004618084, 7.515699838284043, 8.379378367071261, 6.20945336562895, 6.303780748177103, 6.303780748177103, 7.294620748891627, 6.066089190457772, 8.479780264029099, 7.693486957499325, 6.9886846867721655, 7.584962500721156, 7.05528243550119, 7.467605550082998, 6.409390936137702, 7.60733031374961, 8.144658242831882, 6.303780748177103, 5.727920454563199, 5.727920454563199, 6.727920454563199, 5.247927513443585, 8.487840033823051, 7.562242424221073, 6.882643049361842, 8.335390354693924, 7.044394119358453, 6.918863237274595, 6.894817763307944, 7.011227255423254, 7.6865005271832185, 5.930737337562887, 6.108524456778169, 6.108524456778169, 7.118941072723508, 4.392317422778761, 6.247927513443585, 6.149747119504682, 4.321928094887363, 6.285402218862249, 5.523561956057013, 5.700439718141092, 4.247927513443585, 5.832890014164741, 5.78135971352466, 4.169925001442312, 4.321928094887363, 4.321928094887363, 5.357552004618084, 2.584962500721156, 8.066089190457772, 6.930737337562887, 6.357552004618084, 6.918863237274595, 6.392317422778761, 5.754887502163468, 6.149747119504682, 6.554588851677638, 7.312882955284356, 5.20945336562895, 5.087462841250339, 5.087462841250339, 6.108524456778169, 5.20945336562895, 8.379378367071261, 7.577428828035749, 6.6865005271832185, 8.20945336562895, 6.807354922057604, 6.977279923499917, 6.845490050944375, 6.954196310386875, 7.807354922057604, 6.129283016944966, 5.727920454563199, 5.78135971352466, 6.794415866350106, 5.321928094887363, 8.330916878114618, 7.087462841250339, 7.139551352398794, 8.668884984266247, 7.129283016944966, 7.03342300153745, 6.832890014164741, 7.169925001442312, 7.679480099505446, 5.643856189774724, 5.643856189774724, 5.643856189774724, 6.643856189774724, 5.459431618637297, 9.57742882803575, 8.479780264029099, 8.0, 9.375039431346925, 8.027905996569885, 7.622051819456376, 7.483815777264256, 8.0, 8.89178370321831, 6.6865005271832185, 6.794415866350106, 6.794415866350106, 7.787902559391432, 6.643856189774724, 8.149747119504681, 7.483815777264256, 6.321928094887363, 8.233619676759702, 6.569855608330948, 5.977279923499917, 6.614709844115208, 6.672425341971495, 7.6293566200796095, 5.392317422778761, 6.022367813028454, 6.022367813028454, 7.066089190457772, 5.169925001442312, 8.826548487290914, 7.426264754702098, 6.658211482751795, 8.0, 6.727920454563199, 7.076815597050831, 7.098032082960526, 7.357552004618084, 7.768184324776926, 5.727920454563199, 4.857980995127572, 4.857980995127572, 5.882643049361842, 6.266786540694901, 9.108524456778168, 8.49585502688717, 7.774787059601174, 8.375039431346925, 7.592457037268081, 7.622051819456376, 7.011227255423254, 7.754887502163468, 8.566054038171092, 6.727920454563199, 6.539158811108031, 6.539158811108031, 7.569855608330948, 5.426264754702098, 8.72451385311995, 8.08214904135387, 6.894817763307944, 8.703903573444663, 7.531381460516312, 7.531381460516312, 7.199672344836364, 7.285402218862249, 7.882643049361842, 6.894817763307944, 5.807354922057604, 5.807354922057604, 6.832890014164741, 6.189824558880018, 9.12670447284319, 8.266786540694902, 7.2761244052742375, 8.98299357469431, 7.294620748891627, 7.599912842187128, 6.539158811108031, 7.60733031374961, 8.266786540694902, 6.6293566200796095, 6.20945336562895, 6.20945336562895, 7.2384047393250786, 6.044394119358453, 8.118941072723507, 7.400879436282184, 6.672425341971495, 8.848622940429339, 7.139551352398794, 7.087462841250339, 6.906890595608519, 7.199672344836364, 7.6293566200796095, 6.087462841250339, 5.78135971352466, 5.78135971352466, 6.794415866350106, 5.78135971352466, 7.768184324776926, 7.294620748891627, 6.247927513443585, 7.20945336562895, 6.554588851677638, 6.507794640198696, 6.189824558880018, 6.6865005271832185, 7.159871336778389, 5.754887502163468, 5.554588851677638, 5.554588851677638, 6.584962500721156, 4.0, 8.199672344836364, 6.672425341971495, 5.882643049361842, 7.366322214245816, 6.149747119504682, 6.768184324776926, 5.807354922057604, 6.539158811108031, 6.714245517666122, 5.643856189774724, 4.954196310386875, 4.954196310386875, 5.977279923499917, 4.807354922057604, 7.507794640198696, 6.523561956057013, 5.614709844115208, 7.219168520462161, 6.392317422778761, 6.392317422778761, 6.339850002884624, 6.066089190457772, 6.794415866350106, 5.321928094887363, 4.643856189774724, 4.643856189774724, 5.700439718141092, 4.584962500721156, 8.459431618637296, 7.108524456778169, 6.266786540694901, 7.820178962415188, 7.022367813028454, 6.022367813028454, 6.539158811108031, 6.339850002884624, 7.442943495848728, 5.357552004618084, 5.169925001442312, 5.169925001442312, 6.22881869049588, 4.321928094887363, 3.807354922057604, 4.0, 2.0, 4.247927513443585, 2.0, 2.584962500721156, 3.321928094887362, 3.0, 4.321928094887363, null, 1.584962500721156, 1.584962500721156, 2.584962500721156, 1.0, 8.686500527183219, 7.614709844115208, 6.554588851677638, 8.588714635582264, 7.22881869049588, 7.303780748177103, 7.357552004618084, 7.149747119504682, 8.113742166049189, 5.247927513443585, 5.906890595608519, 5.930737337562887, 6.94251450533924, 4.459431618637297, 7.459431618637297, 6.78135971352466, 6.303780748177103, 7.285402218862249, 6.108524456778169, 6.129283016944966, 5.523561956057013, 5.78135971352466, 7.022367813028454, 5.491853096329675, 4.700439718141092, 4.700439718141092, 5.727920454563199, 4.807354922057604, 8.861086905995395, 7.693486957499325, 7.515699838284043, 8.312882955284355, 7.434628227636725, 7.312882955284356, 6.977279923499917, 7.539158811108031, 8.108524456778168, 6.066089190457772, 6.285402218862249, 6.285402218862249, 7.285402218862249, 5.169925001442312, 8.550746785383243, 7.643856189774724, 7.0, 8.632995197142957, 7.129283016944966, 7.011227255423254, 7.044394119358453, 6.954196310386875, 7.845490050944375, 5.906890595608519, 5.78135971352466, 5.78135971352466, 6.820178962415188, 4.459431618637297, 8.81698362325538, 8.46352437327118, 7.417852514885898, 7.894817763307944, 7.569855608330948, 7.577428828035749, 7.339850002884624, 7.577428828035749, 8.285402218862249, 6.700439718141092, 6.599912842187128, 6.599912842187128, 7.599912842187128, 5.727920454563199, 0.0, 0.0, 2.0, 1.0, null, null, null, 0.0, null, null, null, null, null, null, 9.733015321685963, 5.20945336562895, 5.491853096329675, 6.022367813028454, 5.169925001442312, 5.584962500721156, 5.584962500721156, 5.285402218862249, 6.845490050944375, 5.754887502163468, 4.584962500721156, 4.584962500721156, 5.643856189774724, 5.614709844115208, 8.562242424221072, 6.321928094887363, 5.807354922057604, 7.076815597050831, 5.700439718141092, 5.459431618637297, 6.247927513443585, 5.754887502163468, 7.658211482751795, 5.0, 4.584962500721156, 4.584962500721156, 5.584962500721156, 5.169925001442312, 8.977279923499916, 5.930737337562887, 5.247927513443585, 6.965784284662087, 5.754887502163468, 5.727920454563199, 5.087462841250339, 5.700439718141092, 6.965784284662087, 5.491853096329675, 4.0, 4.0, 5.044394119358453, 6.0, 9.505811553919594, 7.169925001442312, 6.357552004618084, 8.016808287686555, 6.94251450533924, 6.392317422778761, 6.303780748177103, 6.599912842187128, 7.78135971352466, 5.643856189774724, 4.754887502163468, 4.754887502163468, 5.832890014164741, 6.426264754702098, 8.951284714966972, 5.727920454563199, 4.392317422778761, 6.727920454563199, 5.247927513443585, 4.906890595608519, 5.523561956057013, 4.754887502163468, 6.189824558880018, 6.087462841250339, 3.321928094887362, 3.321928094887362, 4.392317422778761, 4.857980995127572, 8.622051819456376, 7.554588851677638, 6.714245517666122, 8.20945336562895, 6.672425341971495, 7.20945336562895, 6.507794640198696, 7.1799090900149345, 7.721099188707185, 6.392317422778761, 6.087462841250339, 6.087462841250339, 7.076815597050831, 4.247927513443585, 1.584962500721156, 6.491853096329675, null, null, 2.0, 6.459431618637297, null, 6.820178962415188, 1.0, 4.0, 5.426264754702098, 5.426264754702098, 6.426264754702098, null, 10.00982861736811, 6.523561956057013, 5.727920454563199, 7.087462841250339, 6.108524456778169, 5.672425341971495, 4.523561956057013, 5.882643049361842, 7.076815597050831, 6.339850002884624, 5.0, 5.0, 6.044394119358453, 7.066089190457772, 9.041659151637214, 7.9886846867721655, 7.569855608330948, 8.954196310386875, 7.584962500721156, 7.774787059601174, 7.392317422778761, 7.366322214245816, 8.388017285345136, 6.714245517666122, 6.539158811108031, 6.539158811108031, 7.569855608330948, 5.087462841250339, 9.419960177847889, 7.483815777264256, 6.475733430966398, 7.965784284662087, 6.459431618637297, 6.087462841250339, 6.339850002884624, 6.554588851677638, 7.417852514885898, 5.754887502163468, 5.129283016944966, 5.169925001442312, 6.169925001442312, 6.044394119358453, 9.134426320220927, 6.820178962415188, 5.807354922057604, 7.6865005271832185, 6.672425341971495, 6.794415866350106, 6.3750394313469245, 6.584962500721156, 7.383704292474052, 5.754887502163468, 5.044394119358453, 5.044394119358453, 6.129283016944966, 5.954196310386875, 8.826548487290914, 6.918863237274595, 5.857980995127572, 7.515699838284043, 6.614709844115208, 6.6293566200796095, 6.303780748177103, 6.169925001442312, 7.754887502163468, 6.22881869049588, 4.584962500721156, 4.584962500721156, 5.700439718141092, 5.700439718141092, 9.411510988012072, 6.569855608330948, 6.965784284662087, 7.330916878114617, 6.247927513443585, 6.044394119358453, 6.882643049361842, 6.569855608330948, 8.308339030139408, 5.882643049361842, 4.700439718141092, 4.700439718141092, 5.754887502163468, 5.78135971352466, 9.113742166049189, 6.857980995127572, 6.285402218862249, 7.011227255423254, 6.539158811108031, 6.491853096329675, 6.108524456778169, 6.6293566200796095, 7.392317422778761, 5.882643049361842, 5.044394119358453, 5.044394119358453, 6.066089190457772, 6.169925001442312, 9.79766152585376, 6.569855608330948, 5.930737337562887, 7.94251450533924, 6.3750394313469245, 5.643856189774724, 6.266786540694901, 6.266786540694901, 7.693486957499325, 5.832890014164741, 5.0, 5.0, 6.044394119358453, 6.870364719583405, 9.271463027904375, 7.076815597050831, 6.22881869049588, 7.098032082960526, 6.614709844115208, 6.044394119358453, 6.20945336562895, 6.3750394313469245, 7.499845887083206, 5.727920454563199, 4.754887502163468, 4.754887502163468, 5.78135971352466, 6.189824558880018, 9.283088353024002, 4.857980995127572, 3.584962500721156, 6.894817763307944, 5.044394119358453, 5.247927513443585, 4.906890595608519, 5.0, 6.78135971352466, 5.523561956057013, 3.0, 3.0, 4.169925001442312, 5.832890014164741, 9.948367231584678, 6.94251450533924, 5.754887502163468, 8.159871336778389, 7.139551352398794, 6.700439718141092, 6.044394119358453, 6.087462841250339, 7.727920454563199, 6.643856189774724, 5.0, 5.0, 6.0, 6.807354922057604, 6.426264754702098, 3.9068905956085187, 4.169925001442312, 7.721099188707185, 6.954196310386875, 4.169925001442312, 2.0, 4.906890595608519, 4.954196310386875, 6.475733430966398, 2.0, 2.0, 3.0, 3.584962500721156, 10.355351096424812, 8.43879185257826, 7.499845887083206, 8.326429487122303, 7.539158811108031, 7.584962500721156, 7.554588851677638, 7.7615512324444795, 8.985841937003341, 7.303780748177103, 5.977279923499917, 5.977279923499917, 6.965784284662087, 7.383704292474052, 9.507794640198696, 6.807354922057604, 6.247927513443585, 7.948367231584678, 6.409390936137702, 6.599912842187128, 6.357552004618084, 6.820178962415188, 7.826548487290915, 6.491853096329675, 5.584962500721156, 5.584962500721156, 6.569855608330948, 6.820178962415188, 9.428360172704291, 7.442943495848728, 6.409390936137702, 8.312882955284355, 6.475733430966398, 6.977279923499917, 5.832890014164741, 6.965784284662087, 8.076815597050832, 6.303780748177103, 5.584962500721156, 5.584962500721156, 6.584962500721156, 6.599912842187128, 9.055282435501189, 5.832890014164741, 5.357552004618084, 6.392317422778761, 5.882643049361842, 5.426264754702098, 5.321928094887363, 5.247927513443585, 6.894817763307944, 6.0, 4.087462841250339, 4.087462841250339, 5.20945336562895, 5.700439718141092, 9.271463027904375, 6.918863237274595, 6.189824558880018, 6.820178962415188, 6.247927513443585, 6.129283016944966, 5.807354922057604, 6.321928094887363, 7.044394119358453, 5.672425341971495, 4.321928094887363, 4.392317422778761, 5.426264754702098, 5.672425341971495, 9.428360172704291, 7.7073591320808825, 6.409390936137702, 7.330916878114617, 6.741466986401147, 6.768184324776926, 6.169925001442312, 7.149747119504682, 8.038918989292302, 6.189824558880018, 5.426264754702098, 5.426264754702098, 6.491853096329675, 6.539158811108031, 8.751544059089099, 5.727920454563199, 5.20945336562895, 6.845490050944375, 5.727920454563199, 5.882643049361842, 5.523561956057013, 5.754887502163468, 6.643856189774724, 5.247927513443585, 4.247927513443585, 4.247927513443585, 5.247927513443585, 5.392317422778761, 9.087462841250339, 5.554588851677638, 4.700439718141092, 6.643856189774724, 6.066089190457772, 5.459431618637297, 5.321928094887363, 5.0, 6.870364719583405, 6.022367813028454, 3.9068905956085187, 3.9068905956085187, 4.954196310386875, 6.539158811108031, 9.368506461507693, 6.954196310386875, 5.977279923499917, 8.164906926675688, 6.807354922057604, 6.882643049361842, 6.108524456778169, 6.894817763307944, 7.727920454563199, 5.832890014164741, 5.392317422778761, 5.392317422778761, 6.426264754702098, 6.087462841250339, 9.204571144249204, 6.727920454563199, 5.672425341971495, 7.076815597050831, 6.807354922057604, 6.22881869049588, 5.459431618637297, 6.22881869049588, 7.129283016944966, 5.672425341971495, 4.459431618637297, 4.459431618637297, 5.459431618637297, 6.108524456778169, 9.20945336562895, 6.339850002884624, 5.321928094887363, 7.2384047393250786, 6.321928094887363, 5.0, 5.392317422778761, 5.169925001442312, 6.94251450533924, 5.954196310386875, 4.169925001442312, 4.169925001442312, 5.20945336562895, 5.643856189774724, 9.422064766172813, 7.357552004618084, 7.0, 7.900866807980749, 7.247927513443585, 6.754887502163468, 6.584962500721156, 7.392317422778761, 8.487840033823051, 6.321928094887363, 5.832890014164741, 5.832890014164741, 6.832890014164741, 5.727920454563199, 8.442943495848729, 5.832890014164741, 4.954196310386875, 7.076815597050831, 5.906890595608519, 5.700439718141092, 4.700439718141092, 5.247927513443585, 6.569855608330948, 4.906890595608519, 3.9068905956085187, 3.9068905956085187, 4.857980995127572, 4.807354922057604, 9.030667136246942, 7.2384047393250786, 6.022367813028454, 7.294620748891627, 6.599912842187128, 6.108524456778169, 5.727920454563199, 6.741466986401147, 7.774787059601174, 6.459431618637297, 5.584962500721156, 5.584962500721156, 6.584962500721156, 5.285402218862249, 9.4241662888181, 7.584962500721156, 6.977279923499917, 8.573647187493322, 7.2761244052742375, 7.087462841250339, 6.820178962415188, 7.108524456778169, 7.924812503605781, 5.614709844115208, 5.672425341971495, 5.672425341971495, 6.672425341971495, 5.754887502163468, 9.663558104217273, 6.906890595608519, 6.22881869049588, 5.129283016944966, 7.108524456778169, 6.339850002884624, 6.426264754702098, 6.392317422778761, 7.754887502163468, 6.357552004618084, 5.0, 5.0, 6.0, 6.954196310386875, 8.388017285345136, 5.930737337562887, 5.857980995127572, 7.0, 5.977279923499917, 5.523561956057013, 5.954196310386875, 5.643856189774724, 6.94251450533924, 5.0, 4.321928094887363, 4.321928094887363, 5.357552004618084, 4.906890595608519, 9.513727595952437, 6.768184324776926, 6.459431618637297, 7.870364719583405, 6.700439718141092, 6.569855608330948, 6.22881869049588, 6.442943495848728, 7.523561956057013, 5.672425341971495, 4.321928094887363, 4.321928094887363, 5.392317422778761, 6.475733430966398, 8.731319031025064, 6.930737337562887, 5.700439718141092, 6.882643049361842, 6.339850002884624, 6.426264754702098, 5.357552004618084, 6.3750394313469245, 7.643856189774724, 5.321928094887363, 4.523561956057013, 4.523561956057013, 5.584962500721156, 6.321928094887363, 8.86418614465428, 6.266786540694901, 5.643856189774724, 7.22881869049588, 6.3750394313469245, 5.129283016944966, 5.977279923499917, 5.285402218862249, 6.894817763307944, 5.426264754702098, 4.321928094887363, 4.321928094887363, 5.392317422778761, 5.78135971352466, 9.430452551665532, 6.129283016944966, 5.832890014164741, 6.754887502163468, 6.357552004618084, 6.149747119504682, 5.614709844115208, 5.832890014164741, 7.339850002884624, 5.807354922057604, 4.247927513443585, 4.247927513443585, 5.321928094887363, 5.882643049361842, 9.64745842645492, 7.366322214245816, 6.066089190457772, 7.392317422778761, 6.794415866350106, 6.044394119358453, 5.614709844115208, 6.954196310386875, 7.539158811108031, 5.643856189774724, 5.357552004618084, 5.357552004618084, 6.3750394313469245, 6.714245517666122, 9.353146825498083, 6.6865005271832185, 5.700439718141092, 7.721099188707185, 6.6293566200796095, 6.303780748177103, 5.754887502163468, 5.78135971352466, 7.266786540694901, 5.584962500721156, 4.807354922057604, 4.807354922057604, 5.882643049361842, 5.754887502163468, 9.643856189774725, 5.700439718141092, 5.392317422778761, 7.426264754702098, 6.169925001442312, 5.754887502163468, 6.149747119504682, 5.554588851677638, 7.169925001442312, 5.807354922057604, 3.807354922057604, 3.807354922057604, 4.807354922057604, 6.247927513443585, 10.131856960608793, 7.022367813028454, 6.6293566200796095, 7.339850002884624, 6.672425341971495, 6.285402218862249, 6.672425341971495, 6.672425341971495, 7.965784284662087, 6.426264754702098, 4.523561956057013, 4.523561956057013, 5.554588851677638, 7.044394119358453, 9.199672344836364, 6.303780748177103, 5.554588851677638, 7.294620748891627, 6.108524456778169, 5.672425341971495, 5.832890014164741, 5.321928094887363, 6.832890014164741, 5.930737337562887, 4.643856189774724, 4.643856189774724, 5.672425341971495, 6.20945336562895, 9.154818109052105, 7.339850002884624, 5.643856189774724, 7.357552004618084, 6.0, 6.0, 5.357552004618084, 5.882643049361842, 7.409390936137702, 5.247927513443585, 4.906890595608519, 4.906890595608519, 5.954196310386875, 6.189824558880018, 8.247927513443585, 5.930737337562887, 4.700439718141092, 6.475733430966398, 5.087462841250339, 5.357552004618084, 4.643856189774724, 3.807354922057604, 5.754887502163468, 4.0, 3.169925001442312, 3.169925001442312, 4.169925001442312, 5.392317422778761, 8.447083226209653, 6.108524456778169, 5.491853096329675, 6.977279923499917, 5.954196310386875, 6.339850002884624, 5.754887502163468, 6.22881869049588, 6.965784284662087, 5.087462841250339, 4.754887502163468, 4.754887502163468, 5.754887502163468, 5.357552004618084, 9.564149489985732, 7.459431618637297, 6.78135971352466, 8.262094845370179, 6.954196310386875, 6.794415866350106, 6.569855608330948, 6.768184324776926, 7.98299357469431, 5.129283016944966, 5.857980995127572, 5.857980995127572, 6.870364719583405, 7.0, 5.584962500721156, 1.0, null, 2.584962500721156, 0.0, null, 1.0, 2.0, 3.169925001442312, 1.0, null, null, null, 2.0, 9.569855608330949, 6.754887502163468, 6.247927513443585, 7.459431618637297, 6.965784284662087, 6.614709844115208, 5.882643049361842, 6.754887502163468, 7.584962500721156, 6.303780748177103, 5.321928094887363, 5.321928094887363, 6.321928094887363, 6.442943495848728, 8.566054038171092, 5.044394119358453, 3.807354922057604, 6.3750394313469245, 4.807354922057604, 4.807354922057604, 4.169925001442312, 5.321928094887363, 5.807354922057604, 3.807354922057604, 3.0, 3.0, 4.0, 5.523561956057013, 8.73809225962049, 5.882643049361842, 4.857980995127572, 6.554588851677638, 6.066089190457772, 6.339850002884624, 5.129283016944966, 5.643856189774724, 6.539158811108031, 5.954196310386875, 4.0, 4.0, 5.0, 5.614709844115208, 8.430452551665532, 7.6865005271832185, 6.599912842187128, 7.554588851677638, 6.918863237274595, 6.870364719583405, 6.714245517666122, 7.475733430966398, 8.066089190457772, 5.392317422778761, 5.930737337562887, 5.930737337562887, 6.94251450533924, 5.643856189774724, 8.39231742277876, 7.714245517666122, 6.22881869049588, 8.49585502688717, 6.6293566200796095, 7.2761244052742375, 7.044394119358453, 7.357552004618084, 7.794415866350106, 6.087462841250339, 5.523561956057013, 5.523561956057013, 6.569855608330948, 6.20945336562895, 8.066089190457772, 7.531381460516312, 7.339850002884624, 8.321928094887362, 6.539158811108031, 7.303780748177103, 6.523561956057013, 7.022367813028454, 7.507794640198696, 4.584962500721156, 5.643856189774724, 5.643856189774724, 6.672425341971495, 5.491853096329675, 7.523561956057013, 7.483815777264256, 5.247927513443585, 7.383704292474052, 6.189824558880018, 6.741466986401147, 5.672425341971495, 7.05528243550119, 6.491853096329675, 5.087462841250339, 5.614709844115208, 5.614709844115208, 6.614709844115208, 5.321928094887363, 8.625708843064466, 7.864186144654281, 6.339850002884624, 7.294620748891627, 7.1799090900149345, 7.417852514885898, 6.189824558880018, 7.129283016944966, 7.78135971352466, 5.247927513443585, 5.643856189774724, 5.643856189774724, 6.714245517666122, 4.584962500721156, 8.219168520462162, 7.05528243550119, 6.392317422778761, 8.011227255423254, 6.539158811108031, 6.754887502163468, 6.044394119358453, 7.169925001442312, 7.2761244052742375, 4.954196310386875, 4.954196310386875, 4.954196310386875, 5.954196310386875, 4.459431618637297, 7.857980995127572, 6.392317422778761, 6.149747119504682, 7.6293566200796095, 6.108524456778169, 6.459431618637297, 5.832890014164741, 6.539158811108031, 7.129283016944966, 4.643856189774724, 5.087462841250339, 5.087462841250339, 6.108524456778169, 4.459431618637297, 6.507794640198696, 5.78135971352466, 4.459431618637297, 6.491853096329675, 4.807354922057604, 5.491853096329675, 5.20945336562895, 5.321928094887363, 6.087462841250339, 4.700439718141092, 3.4594316186372973, 3.4594316186372973, 4.523561956057013, 3.321928094887362, 7.459431618637297, 6.954196310386875, 5.554588851677638, 7.266786540694901, 5.954196310386875, 6.20945336562895, 5.285402218862249, 6.392317422778761, 6.554588851677638, 4.857980995127572, 4.754887502163468, 4.754887502163468, 5.857980995127572, 3.807354922057604, 7.539158811108031, 6.977279923499917, 5.727920454563199, 6.6293566200796095, 6.321928094887363, 6.087462841250339, 5.78135971352466, 6.569855608330948, 7.022367813028454, 4.169925001442312, 4.906890595608519, 4.906890595608519, 5.977279923499917, 4.392317422778761, 7.285402218862249, 6.426264754702098, 5.614709844115208, 7.475733430966398, 6.087462841250339, 6.285402218862249, 5.882643049361842, 5.882643049361842, 6.6293566200796095, 4.169925001442312, 4.523561956057013, 4.523561956057013, 5.491853096329675, 2.0, 8.243173983472952, 7.2384047393250786, 6.965784284662087, 8.535275376620802, 6.894817763307944, 6.658211482751795, 6.845490050944375, 6.741466986401147, 7.700439718141092, 5.247927513443585, 6.0, 6.0, 7.044394119358453, 4.392317422778761, 7.721099188707185, 6.78135971352466, 6.189824558880018, 6.658211482751795, 5.930737337562887, 6.087462841250339, 5.906890595608519, 6.129283016944966, 6.965784284662087, 3.584962500721156, 5.392317422778761, 5.392317422778761, 6.409390936137702, 4.321928094887363, 7.658211482751795, 6.247927513443585, 5.906890595608519, 7.3750394313469245, 6.044394119358453, 5.857980995127572, 6.149747119504682, 6.357552004618084, 6.3750394313469245, 4.169925001442312, 4.954196310386875, 4.954196310386875, 5.977279923499917, 4.392317422778761, 8.535275376620802, 7.7615512324444795, 5.584962500721156, 8.696967526234287, 6.882643049361842, 6.930737337562887, 6.523561956057013, 6.882643049361842, 7.851749041416057, 5.20945336562895, 5.357552004618084, 5.357552004618084, 6.392317422778761, 4.321928094887363, 3.0, 2.584962500721156, 1.0, 4.0, 2.0, null, 1.0, 1.584962500721156, 2.321928094887362, 1.0, 1.0, 1.0, 1.584962500721156, null, 7.303780748177103, 6.507794640198696, 6.087462841250339, 7.577428828035749, 5.977279923499917, 5.700439718141092, 5.727920454563199, 6.022367813028454, 6.870364719583405, 3.807354922057604, 4.857980995127572, 4.857980995127572, 5.882643049361842, 3.0, 7.820178962415188, 6.857980995127572, 6.108524456778169, 7.22881869049588, 6.539158811108031, 6.392317422778761, 6.087462841250339, 6.442943495848728, 7.098032082960526, 5.857980995127572, 4.700439718141092, 4.700439718141092, 5.727920454563199, 5.459431618637297, 7.076815597050831, 6.475733430966398, 5.906890595608519, 6.672425341971495, 5.807354922057604, 5.954196310386875, 5.459431618637297, 5.459431618637297, 6.523561956057013, 4.584962500721156, 4.584962500721156, 4.584962500721156, 5.584962500721156, 3.807354922057604], "y0": " ", "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"], ["2L", null], ["2L", "AIM2"], ["2L", "AIM3"], ["2L", "AIM4"], ["2L", "AIM5"], ["2L", "AIM6"], ["2L", "AIM7"], ["2L", "Vgsc_tag1"], ["2L", "Vgsc_tag2"], ["2L", "Vgsc_tag3"], ["2L", "Vgsc_V402L"], ["2L", "Vgsc_D466H"], ["2L", "Vgsc_tag4"], ["2L", "Vgsc_tag5"], ["2L", "Vgsc_tag6"], ["2L", "Vgsc_tag7"], ["2L", "Vgsc_T791M"], ["2L", "Vgsc_L995S"], ["2L", "Vgsc_L995F"], ["2L", "Vgsc_tag8"], ["2L", "Vgsc_tag9"], ["2L", "Vgsc_I1527T"], ["2L", "Vgsc_N1570Y"], ["2L", "Vgsc_E1597G"], ["2L", "Vgsc_A1746S"], ["2L", "Vgsc_V1853I"], ["2L", "Vgsc_I1868T"], ["2L", "Vgsc_P1874S"], ["2L", "Vgsc_P1874L"], ["2L", "Vgsc_Y1882C"], ["2L", "AIM8"], ["2L", "Vgsc_A1934V"], ["2L", "Vgsc_tag10"], ["2L", "Vgsc_tag11"], ["2L", "Coeae1d_tag"], ["2L", "Rdl_A296S"], ["2L", "Rdl_A296G"], ["2L", "Cyp4j5_L43F"], ["2L", "34mb_tag1"], ["2L", "34mb_tag2"], ["2L", "34mb_tag3"], ["2L", "34mb_tag4"]], "hovertemplate": "contig=%{customdata[0]}<br>amplicon=%{x}<br>log_depth=%{y}<br>mutation=%{customdata[1]}<extra></extra>", "legendgroup": "2L", "marker": {"color": "#2CA02C"}, "name": "2L", "notched": false, "offsetgroup": "2L", "orientation": "v", "showlegend": true, "type": "box", "x": ["Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31", "Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_79", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_17", "Agam_18", "Agam_19", "Agam_80", "Agam_20", "Agam_20", "Agam_21", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_22", "Agam_23", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_31"], "x0": " ", "xaxis": "x", "y": [5.0, 4.857980995127572, 2.0, 3.700439718141092, 4.392317422778761, 4.906890595608519, 4.392317422778761, 3.807354922057604, 6.357552004618084, 7.787902559391432, 5.727920454563199, 1.0, 5.285402218862249, 5.459431618637297, 4.643856189774724, 4.247927513443585, 3.9068905956085187, 3.9068905956085187, 3.9068905956085187, 9.066089190457772, 9.682994583681683, 6.954196310386875, 5.392317422778761, 6.266786540694901, 5.754887502163468, 5.672425341971495, 4.700439718141092, 4.700439718141092, 4.700439718141092, 4.643856189774724, 5.459431618637297, 6.584962500721156, 6.321928094887363, 5.169925001442312, 0.0, 4.584962500721156, 4.584962500721156, 8.603626344986193, 6.22881869049588, 6.392317422778761, 6.507794640198696, 6.459431618637297, 4.087462841250339, 2.0, 2.0, 2.321928094887362, 2.584962500721156, 2.321928094887362, 2.584962500721156, 1.584962500721156, 2.584962500721156, 3.321928094887362, 2.584962500721156, null, 2.584962500721156, 3.0, 2.807354922057604, 0.0, 1.0, 0.0, 0.0, 5.554588851677638, 5.643856189774724, 4.807354922057604, 4.169925001442312, 5.169925001442312, 4.247927513443585, 3.4594316186372973, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 3.700439718141092, 4.807354922057604, 2.584962500721156, 3.321928094887362, null, 2.584962500721156, 2.584962500721156, 5.0, 3.169925001442312, 4.0, 3.4594316186372973, 3.4594316186372973, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 3.169925001442312, 1.0, null, null, null, 1.584962500721156, null, null, null, null, null, 2.321928094887362, null, 2.0, 1.584962500721156, null, null, 1.0, null, null, null, null, 1.0, 1.0, null, null, null, null, null, null, 0.0, 3.9068905956085187, null, 1.584962500721156, null, null, null, 0.0, null, 0.0, 0.0, 3.169925001442312, 4.584962500721156, 2.584962500721156, 1.584962500721156, 2.0, 2.321928094887362, 2.0, 1.0, 1.0, 1.0, 1.0, 1.0, 3.169925001442312, 2.0, 2.321928094887362, 0.0, null, null, 4.247927513443585, 1.0, 1.0, 1.0, 1.584962500721156, 2.807354922057604, 1.0, 1.0, 0.0, 1.0, null, 1.0, 2.0, 2.0, 4.584962500721156, 3.584962500721156, 1.0, 1.584962500721156, 1.0, 2.321928094887362, 2.584962500721156, null, 0.0, 0.0, 5.044394119358453, 6.285402218862249, 2.807354922057604, 0.0, 1.584962500721156, 2.321928094887362, 3.700439718141092, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.321928094887362, 1.584962500721156, 3.169925001442312, 3.0, 1.0, 1.584962500721156, 2.0, 2.0, 5.832890014164741, 3.169925001442312, 2.0, 3.4594316186372973, 3.4594316186372973, 4.321928094887363, 4.643856189774724, 4.087462841250339, 3.4594316186372973, 3.584962500721156, 3.807354922057604, 3.584962500721156, 3.0, 3.321928094887362, 4.807354922057604, 4.321928094887363, 2.584962500721156, 3.9068905956085187, 1.584962500721156, 3.0, 3.700439718141092, 1.0, 3.4594316186372973, 3.4594316186372973, 6.0, 6.741466986401147, 5.906890595608519, 4.857980995127572, 5.754887502163468, 5.357552004618084, 5.0, 3.807354922057604, 3.700439718141092, 3.700439718141092, 3.700439718141092, 5.491853096329675, 6.584962500721156, 3.321928094887362, 5.0, 2.0, 3.0, 3.0, 5.247927513443585, 4.247927513443585, 3.807354922057604, 4.807354922057604, 4.807354922057604, null, 1.0, 2.0, 1.0, 3.584962500721156, null, 0.0, null, null, null, null, null, null, null, 0.0, 2.584962500721156, null, 0.0, 0.0, null, 0.0, null, 0.0, 0.0, 1.0, 2.0, null, null, null, null, 4.459431618637297, 5.584962500721156, null, null, null, null, null, null, 2.0, null, 1.0, 1.584962500721156, null, null, null, null, null, 1.0, null, null, null, null, null, null, 2.0, null, null, null, null, null, null, 0.0, 3.700439718141092, 0.0, null, null, null, null, null, null, null, null, null, 3.169925001442312, null, null, 2.321928094887362, 2.0, 2.0, 1.584962500721156, null, 0.0, null, null, null, null, null, null, null, 0.0, null, null, null, null, 1.0, null, 1.584962500721156, null, null, 0.0, null, null, null, null, 3.9068905956085187, null, null, null, null, 1.0, null, null, null, null, null, 3.0, null, 2.321928094887362, 2.321928094887362, 2.807354922057604, 2.807354922057604, 1.0, 0.0, 0.0, null, null, 2.0, 1.0, 1.0, 2.321928094887362, null, null, 1.584962500721156, 1.584962500721156, 3.0, 4.584962500721156, 1.0, null, 2.807354922057604, 2.321928094887362, 0.0, 1.0, 1.584962500721156, null, null, 5.523561956057013, 6.247927513443585, 3.700439718141092, 3.321928094887362, 4.087462841250339, 3.700439718141092, 3.0, 2.0, 2.0, 2.0, 2.0, 2.0, 3.4594316186372973, 5.0, 2.0, 1.584962500721156, 2.0, 2.0, 5.857980995127572, 2.807354922057604, 3.0, 2.807354922057604, 2.807354922057604, 2.321928094887362, 1.0, 1.0, 1.0, 1.584962500721156, null, 1.584962500721156, 1.0, 1.584962500721156, 3.321928094887362, 2.584962500721156, null, 2.321928094887362, null, 1.584962500721156, 1.0, 0.0, 1.584962500721156, 1.584962500721156, 2.321928094887362, 4.754887502163468, 3.169925001442312, 2.807354922057604, 3.4594316186372973, 1.584962500721156, 1.584962500721156, null, null, null, null, 3.0, 4.906890595608519, null, null, 2.584962500721156, 1.584962500721156, 2.0, 2.0, 3.321928094887362, 2.0, 2.807354922057604, 2.807354922057604, null, null, null, null, null, null, null, 0.0, 1.0, 1.584962500721156, 2.584962500721156, null, 1.0, 1.584962500721156, null, null, null, null, null, 0.0, 4.584962500721156, 1.584962500721156, null, null, 0.0, 2.584962500721156, 1.0, 1.0, 1.0, 1.0, 1.584962500721156, 3.700439718141092, 0.0, 1.0, 0.0, null, null, 2.0, 1.0, 2.807354922057604, 0.0, 0.0, 3.700439718141092, 3.700439718141092, 2.0, 2.584962500721156, 4.247927513443585, 3.807354922057604, 2.321928094887362, 2.321928094887362, 4.906890595608519, 5.426264754702098, 4.0, 1.584962500721156, 2.807354922057604, 4.087462841250339, 3.4594316186372973, 2.584962500721156, 1.584962500721156, 2.321928094887362, 2.321928094887362, 6.672425341971495, 6.977279923499917, 4.754887502163468, 3.807354922057604, 4.754887502163468, 4.247927513443585, 3.807354922057604, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 4.643856189774724, 5.78135971352466, 4.169925001442312, 4.169925001442312, 2.584962500721156, 3.321928094887362, 3.321928094887362, 4.700439718141092, 3.584962500721156, 4.700439718141092, 4.584962500721156, 4.584962500721156, 4.321928094887363, 3.700439718141092, 2.584962500721156, 2.0, 2.807354922057604, 2.807354922057604, 3.0, 3.4594316186372973, 4.247927513443585, 5.672425341971495, 3.584962500721156, 3.0, 4.459431618637297, 5.0, 2.584962500721156, 2.584962500721156, 3.0, 3.169925001442312, 3.169925001442312, 6.754887502163468, 7.118941072723508, 6.303780748177103, 5.491853096329675, 6.247927513443585, 5.554588851677638, 4.247927513443585, 3.0, 3.0, 3.0, 3.0, 4.700439718141092, 5.882643049361842, 4.247927513443585, 5.357552004618084, 0.0, 3.700439718141092, 3.700439718141092, 5.954196310386875, 4.754887502163468, 3.807354922057604, 5.754887502163468, 5.754887502163468, null, 1.584962500721156, 2.0, 1.584962500721156, 1.584962500721156, null, 0.0, 1.0, 1.584962500721156, 4.643856189774724, 2.0, null, 2.0, 1.584962500721156, 1.584962500721156, 1.0, 2.0, 0.0, 0.0, 5.20945336562895, 5.491853096329675, 3.807354922057604, 3.169925001442312, 4.169925001442312, 3.0, 1.0, null, null, null, null, 3.169925001442312, 4.321928094887363, null, 4.247927513443585, 2.321928094887362, 2.0, 2.0, 4.584962500721156, 4.087462841250339, 2.0, 4.0, 3.9068905956085187, 3.0, 1.0, null, 1.0, 0.0, 2.0, 1.584962500721156, 2.807354922057604, 4.857980995127572, 4.754887502163468, 3.0, null, 1.0, 3.807354922057604, 0.0, 1.0, 2.321928094887362, null, null, 5.321928094887363, 5.392317422778761, 4.754887502163468, 3.169925001442312, 4.247927513443585, 3.4594316186372973, 3.700439718141092, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.0, 3.0, 1.0, 3.0, 1.0, 1.0, 1.0, 1.0, 1.584962500721156, 4.0, 3.321928094887362, 3.321928094887362, 1.0, 2.0, null, 0.0, 1.584962500721156, 2.0, null, 2.0, 3.169925001442312, 5.0, 2.584962500721156, null, 2.807354922057604, 2.321928094887362, 2.0, 3.9068905956085187, 1.584962500721156, null, null, 4.857980995127572, 6.022367813028454, 4.0, 4.523561956057013, 4.754887502163468, 4.392317422778761, 3.807354922057604, 2.807354922057604, 2.807354922057604, 2.807354922057604, 2.584962500721156, 3.584962500721156, 4.857980995127572, 3.0, 3.0, 1.0, 1.0, 1.0, 5.087462841250339, null, 3.584962500721156, 4.0, 4.0, 0.0, 0.0, 2.0, null, 1.0, null, 1.584962500721156, 0.0, 1.0, 3.0, 2.584962500721156, null, null, 1.584962500721156, null, 1.0, 2.0, null, null, 3.584962500721156, 5.807354922057604, 4.906890595608519, 3.4594316186372973, 4.169925001442312, 2.584962500721156, 3.4594316186372973, 2.0, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.169925001442312, 4.807354922057604, null, 2.321928094887362, 0.0, null, null, 2.0, 3.169925001442312, 4.247927513443585, 2.807354922057604, 2.584962500721156, 4.392317422778761, 4.584962500721156, 2.584962500721156, 3.0, 4.700439718141092, 4.0, 2.584962500721156, 3.700439718141092, 5.554588851677638, 6.768184324776926, 5.0, 2.807354922057604, 3.807354922057604, 3.807354922057604, 3.169925001442312, 4.0, 3.321928094887362, 4.459431618637297, 4.459431618637297, 7.219168520462161, 8.204571144249204, 6.523561956057013, 5.614709844115208, 6.3750394313469245, 5.882643049361842, 4.392317422778761, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.169925001442312, 5.129283016944966, 6.266786540694901, 4.906890595608519, 3.700439718141092, 1.0, 4.0, 4.0, 6.807354922057604, 5.426264754702098, 5.169925001442312, 5.954196310386875, 5.954196310386875, 2.0, 0.0, 1.0, null, 0.0, null, null, null, 0.0, 2.321928094887362, null, 0.0, null, 2.584962500721156, null, null, 1.584962500721156, null, null, 3.169925001442312, 4.169925001442312, 1.0, 1.0, 1.0, 2.0, 2.0, 0.0, 0.0, 0.0, null, null, 2.584962500721156, null, 2.321928094887362, 0.0, 2.584962500721156, 2.584962500721156, 1.0, null, 3.0, 2.0, 2.0, 4.169925001442312, 4.523561956057013, 2.584962500721156, 2.321928094887362, 4.584962500721156, 4.0, 4.087462841250339, 3.700439718141092, 5.832890014164741, 6.22881869049588, 4.584962500721156, 1.0, 3.0, 4.906890595608519, 3.807354922057604, 3.321928094887362, 2.0, 2.807354922057604, 2.807354922057604, 7.2761244052742375, 8.139551352398794, 6.321928094887363, 5.614709844115208, 6.339850002884624, 5.906890595608519, 4.321928094887363, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 3.169925001442312, 5.087462841250339, 6.189824558880018, 5.044394119358453, 5.321928094887363, 0.0, 4.321928094887363, 4.321928094887363, 6.523561956057013, 2.807354922057604, 4.321928094887363, 5.754887502163468, 5.700439718141092, 2.584962500721156, null, 1.0, 1.584962500721156, 2.0, 3.0, 1.584962500721156, 0.0, 0.0, 4.0, 3.0, 1.0, 2.0, 1.584962500721156, 2.0, null, 1.584962500721156, null, null, 5.700439718141092, 5.700439718141092, 4.087462841250339, 3.169925001442312, 4.087462841250339, 3.807354922057604, 1.584962500721156, 1.0, 1.0, 1.0, 1.0, 3.321928094887362, 4.523561956057013, 4.643856189774724, 3.0, 2.321928094887362, 1.0, 1.0, 5.643856189774724, 0.0, 3.9068905956085187, 3.584962500721156, 3.584962500721156, null, null, null, 0.0, 0.0, null, null, null, 1.584962500721156, 2.0, null, null, 1.584962500721156, 0.0, null, null, null, null, null, 1.0, 3.9068905956085187, null, 1.584962500721156, 1.584962500721156, 1.0, null, null, null, null, null, 0.0, 3.0, null, 3.584962500721156, 1.584962500721156, null, null, 1.0, 0.0, 0.0, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, 3.169925001442312, 0.0, null, 0.0, null, 2.0, null, null, null, null, null, 3.9068905956085187, 0.0, 2.0, 1.0, null, null, 1.0, null, null, null, 0.0, 2.807354922057604, 6.285402218862249, 2.0, 3.169925001442312, 3.321928094887362, 2.584962500721156, 1.0, 2.0, 3.169925001442312, 4.754887502163468, 1.0, 4.321928094887363, 2.0, 3.0, 5.700439718141092, 1.0, 0.0, 4.954196310386875, 4.954196310386875, 4.700439718141092, 6.087462841250339, 4.954196310386875, 5.459431618637297, 4.700439718141092, 7.826548487290915, 3.4594316186372973, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 4.0, 5.129283016944966, 3.0, 3.0, 0.0, 6.20945336562895, 6.20945336562895, 4.321928094887363, null, 3.321928094887362, 7.768184324776926, 7.727920454563199, 5.78135971352466, 5.247927513443585, 4.321928094887363, 4.392317422778761, 4.954196310386875, 4.169925001442312, 4.459431618637297, 3.9068905956085187, 5.426264754702098, 6.6293566200796095, 5.832890014164741, 2.321928094887362, 4.459431618637297, 5.392317422778761, 4.169925001442312, 4.700439718141092, 3.169925001442312, 3.169925001442312, 3.169925001442312, 7.851749041416057, 8.108524456778168, 6.247927513443585, 5.614709844115208, 6.247927513443585, 6.129283016944966, 4.754887502163468, 3.700439718141092, 3.700439718141092, 3.700439718141092, 3.700439718141092, 5.700439718141092, 6.768184324776926, 6.087462841250339, 5.643856189774724, 1.0, 5.169925001442312, 5.169925001442312, 6.845490050944375, 5.459431618637297, 6.044394119358453, 6.392317422778761, 6.392317422778761, 2.807354922057604, 2.321928094887362, 2.0, 3.0, 3.700439718141092, 2.321928094887362, 1.584962500721156, 2.584962500721156, 4.321928094887363, 4.807354922057604, 3.807354922057604, 1.584962500721156, 2.321928094887362, 3.321928094887362, 2.321928094887362, 1.584962500721156, 1.0, 2.584962500721156, 2.584962500721156, 5.459431618637297, 6.539158811108031, 4.954196310386875, 4.523561956057013, 4.906890595608519, 4.754887502163468, 3.4594316186372973, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.700439718141092, 5.044394119358453, 3.321928094887362, 2.0, 2.584962500721156, 2.0, 2.0, 6.108524456778169, 4.392317422778761, 4.169925001442312, 4.754887502163468, 4.754887502163468, 1.584962500721156, 2.321928094887362, 2.0, 0.0, 1.0, 0.0, 1.0, null, 1.0, 3.4594316186372973, 2.0, null, null, 1.584962500721156, null, 1.0, null, 0.0, 0.0, 4.087462841250339, 4.754887502163468, 3.700439718141092, 2.0, 3.0, 2.584962500721156, 2.321928094887362, 0.0, 0.0, 0.0, 0.0, 2.321928094887362, 3.9068905956085187, 0.0, 2.0, 1.0, 1.0, 1.0, 3.321928094887362, 2.807354922057604, 2.584962500721156, 3.321928094887362, 3.321928094887362, 4.392317422778761, 3.700439718141092, 2.0, 2.584962500721156, 3.321928094887362, 3.321928094887362, 2.0, 1.584962500721156, 3.700439718141092, 5.614709844115208, 4.459431618637297, 2.584962500721156, 3.169925001442312, 3.4594316186372973, 1.0, 1.584962500721156, 2.584962500721156, 2.0, 2.0, 4.954196310386875, 6.820178962415188, 5.491853096329675, 4.087462841250339, 5.0, 4.321928094887363, 4.0, 3.321928094887362, 3.169925001442312, 3.169925001442312, 3.169925001442312, 4.0, 5.087462841250339, 3.584962500721156, 4.0, 2.0, 3.4594316186372973, 3.4594316186372973, 6.22881869049588, 2.321928094887362, 3.4594316186372973, 5.0, 5.0, 5.754887502163468, 5.285402218862249, 5.20945336562895, 4.807354922057604, 5.392317422778761, 5.523561956057013, 5.321928094887363, 4.643856189774724, 6.129283016944966, 7.936637939002571, 6.129283016944966, 3.4594316186372973, 5.754887502163468, 5.754887502163468, 4.392317422778761, 5.392317422778761, 3.700439718141092, 4.321928094887363, 4.321928094887363, 8.581200581924957, 9.019590728357882, 7.426264754702098, 6.6293566200796095, 7.442943495848728, 7.05528243550119, 5.78135971352466, 5.0, 5.0, 5.0, 5.0, 6.768184324776926, 7.845490050944375, 5.584962500721156, 6.066089190457772, 2.0, 5.321928094887363, 5.321928094887363, 7.651051691178929, 6.189824558880018, 6.507794640198696, 6.882643049361842, 6.857980995127572, null, null, null, 0.0, 1.0, 0.0, 0.0, null, 1.0, 0.0, null, null, 1.584962500721156, null, null, 0.0, null, 0.0, 0.0, 3.4594316186372973, 3.700439718141092, 0.0, 0.0, 0.0, 2.0, 1.584962500721156, 0.0, 0.0, 0.0, 0.0, 1.0, 2.321928094887362, null, 1.0, 1.0, 1.0, 1.0, 3.321928094887362, 0.0, 2.0, 1.584962500721156, 1.584962500721156, 3.0, 2.0, null, 1.0, 2.321928094887362, 1.0, 2.584962500721156, 2.584962500721156, 2.807354922057604, 4.643856189774724, 2.0, null, 3.169925001442312, 0.0, 1.0, 1.0, null, 1.584962500721156, 1.584962500721156, 5.0, 6.022367813028454, 4.857980995127572, 3.584962500721156, 4.392317422778761, 3.9068905956085187, 2.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.700439718141092, 4.857980995127572, 4.459431618637297, 4.169925001442312, 2.0, 2.0, 2.0, 3.807354922057604, 1.0, 3.584962500721156, 4.169925001442312, 4.169925001442312, 4.643856189774724, 4.087462841250339, 3.0, 3.807354922057604, 4.584962500721156, 3.0, 2.807354922057604, 3.807354922057604, 4.754887502163468, 6.392317422778761, 4.459431618637297, 2.0, 3.584962500721156, 4.643856189774724, 3.584962500721156, 4.247927513443585, 3.321928094887362, 3.4594316186372973, 3.4594316186372973, 7.22881869049588, 7.459431618637297, 6.614709844115208, 5.20945336562895, 6.285402218862249, 5.523561956057013, 4.857980995127572, 4.0, 4.0, 4.0, 4.0, 5.700439718141092, 6.754887502163468, 5.584962500721156, 4.906890595608519, 1.584962500721156, 3.9068905956085187, 3.9068905956085187, 6.392317422778761, 3.321928094887362, 6.087462841250339, 5.977279923499917, 5.977279923499917, 5.044394119358453, 3.807354922057604, 3.807354922057604, 3.807354922057604, 4.087462841250339, 3.584962500721156, 3.4594316186372973, 3.700439718141092, 5.357552004618084, 6.442943495848728, 4.321928094887363, 2.584962500721156, 4.169925001442312, 3.807354922057604, 3.4594316186372973, 3.0, 3.700439718141092, 4.0, 4.0, 7.247927513443585, 7.741466986401147, 6.672425341971495, 5.426264754702098, 6.539158811108031, 5.977279923499917, 5.584962500721156, 4.857980995127572, 4.807354922057604, 4.807354922057604, 4.807354922057604, 5.247927513443585, 6.3750394313469245, 4.700439718141092, 4.169925001442312, 0.0, 3.700439718141092, 3.700439718141092, 6.6865005271832185, 4.523561956057013, 3.584962500721156, 5.285402218862249, 5.285402218862249, 3.0, 1.584962500721156, null, 3.0, 3.4594316186372973, 3.169925001442312, 3.321928094887362, 2.321928094887362, 4.643856189774724, 6.321928094887363, 4.523561956057013, 2.0, 4.169925001442312, 3.584962500721156, 2.0, 1.0, 1.0, 1.584962500721156, 1.584962500721156, 7.266786540694901, 7.294620748891627, 5.554588851677638, 4.700439718141092, 5.700439718141092, 4.807354922057604, 3.169925001442312, 2.0, 2.0, 2.0, 2.0, 4.392317422778761, 5.554588851677638, 3.584962500721156, 4.321928094887363, null, 2.584962500721156, 2.584962500721156, 4.584962500721156, 3.4594316186372973, 3.807354922057604, 4.857980995127572, 4.807354922057604, null, null, null, null, null, null, null, null, null, null, 2.0, null, 1.0, null, null, 1.0, null, null, null, null, 2.321928094887362, 2.0, null, null, null, 2.0, null, null, null, null, null, 2.0, null, null, 1.584962500721156, 2.0, 2.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.78135971352466, 5.523561956057013, 4.857980995127572, 4.807354922057604, 4.906890595608519, 5.700439718141092, 5.0, 4.321928094887363, 6.977279923499917, 7.888743248898259, 6.3750394313469245, 4.169925001442312, 5.727920454563199, 6.022367813028454, 5.357552004618084, 5.321928094887363, 4.087462841250339, 5.087462841250339, 5.087462841250339, 8.89178370321831, 9.144658242831882, 7.554588851677638, 6.584962500721156, 7.434628227636725, 7.159871336778389, 6.459431618637297, 5.700439718141092, 5.700439718141092, 5.700439718141092, 5.614709844115208, 6.491853096329675, 7.546894459887636, 5.392317422778761, 6.022367813028454, 2.0, 5.285402218862249, 5.285402218862249, 6.754887502163468, 4.169925001442312, 6.554588851677638, 7.129283016944966, 7.098032082960526, 4.0, 2.584962500721156, 1.0, 2.807354922057604, 3.4594316186372973, 2.584962500721156, 3.807354922057604, 0.0, 2.584962500721156, 5.459431618637297, 4.643856189774724, 2.0, 1.0, 3.169925001442312, 2.0, 2.321928094887362, 2.0, 1.0, 1.0, 5.426264754702098, 5.554588851677638, 4.807354922057604, 4.523561956057013, 4.754887502163468, 4.392317422778761, 4.321928094887363, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 4.0, 5.247927513443585, 3.700439718141092, 4.0, 1.584962500721156, 3.700439718141092, 3.700439718141092, 5.392317422778761, 3.700439718141092, 5.20945336562895, 3.321928094887362, 3.321928094887362, 3.169925001442312, 0.0, 2.0, 1.584962500721156, 3.0, 1.0, 1.584962500721156, 2.321928094887362, 4.459431618637297, 5.0, 3.0, null, 3.0, 3.321928094887362, 1.584962500721156, 0.0, 2.321928094887362, 1.584962500721156, 1.584962500721156, 6.569855608330948, 6.754887502163468, 5.426264754702098, 4.169925001442312, 4.954196310386875, 4.169925001442312, 3.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 4.169925001442312, 5.169925001442312, 3.0, 3.584962500721156, 0.0, 3.0, 3.0, 5.807354922057604, 2.807354922057604, 3.4594316186372973, 5.0, 5.0, 4.584962500721156, 4.321928094887363, 3.807354922057604, 3.9068905956085187, 4.807354922057604, 3.321928094887362, 3.9068905956085187, 3.169925001442312, 5.169925001442312, 6.459431618637297, 4.321928094887363, 2.321928094887362, 3.807354922057604, 4.906890595608519, 3.0, 3.169925001442312, 3.9068905956085187, 4.247927513443585, 4.247927513443585, 6.614709844115208, 7.392317422778761, 6.22881869049588, 5.426264754702098, 6.189824558880018, 6.087462841250339, 5.129283016944966, 4.247927513443585, 4.247927513443585, 4.247927513443585, 4.247927513443585, 5.0, 6.22881869049588, 4.0, 4.906890595608519, null, 4.169925001442312, 4.169925001442312, 6.066089190457772, 6.339850002884624, 4.169925001442312, 6.066089190457772, 6.066089190457772, 3.584962500721156, 3.321928094887362, null, 2.321928094887362, 3.584962500721156, null, 1.0, 2.584962500721156, 3.700439718141092, 4.0, 3.584962500721156, null, 2.584962500721156, 3.0, 2.584962500721156, 1.0, 1.584962500721156, 2.321928094887362, 2.321928094887362, 5.614709844115208, 6.78135971352466, 4.807354922057604, 4.087462841250339, 4.857980995127572, 3.584962500721156, 3.169925001442312, 2.0, 2.0, 2.0, 2.0, 3.807354922057604, 4.857980995127572, 2.321928094887362, 3.584962500721156, 2.0, 2.0, 2.0, 4.321928094887363, 4.0, 4.169925001442312, 4.392317422778761, 4.247927513443585, 3.0, 3.0, null, 2.584962500721156, 3.169925001442312, 2.807354922057604, 1.0, 2.584962500721156, 3.807354922057604, 3.4594316186372973, 2.584962500721156, 2.584962500721156, 3.0, 3.321928094887362, 3.0, 1.584962500721156, 2.807354922057604, 2.0, 2.0, 4.857980995127572, 5.906890595608519, 4.321928094887363, 3.584962500721156, 4.459431618637297, 4.807354922057604, 3.807354922057604, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 4.523561956057013, 5.754887502163468, 2.0, 3.4594316186372973, 0.0, null, null, 5.285402218862249, 4.392317422778761, 5.169925001442312, 4.392317422778761, 4.321928094887363, 4.954196310386875, 3.584962500721156, 3.321928094887362, 2.0, 4.459431618637297, 3.169925001442312, 3.807354922057604, 4.169925001442312, 5.392317422778761, 6.066089190457772, 5.0, 2.584962500721156, 4.906890595608519, 4.700439718141092, 3.700439718141092, 4.0, 2.584962500721156, 4.087462841250339, 4.087462841250339, 7.2761244052742375, 7.266786540694901, 6.507794640198696, 5.169925001442312, 6.108524456778169, 5.882643049361842, 4.807354922057604, 4.087462841250339, 4.087462841250339, 4.0, 4.0, 5.523561956057013, 6.554588851677638, 4.523561956057013, 4.700439718141092, 2.0, 3.807354922057604, 3.807354922057604, 6.977279923499917, 4.459431618637297, 4.857980995127572, 5.0, 5.0, 3.807354922057604, 3.321928094887362, 2.807354922057604, 2.807354922057604, 3.169925001442312, 3.169925001442312, 2.584962500721156, 3.0, 4.459431618637297, 5.169925001442312, 3.4594316186372973, 2.0, 3.584962500721156, 3.9068905956085187, 2.584962500721156, 1.0, 2.321928094887362, 2.321928094887362, 2.321928094887362, 6.321928094887363, 7.554588851677638, 5.672425341971495, 4.392317422778761, 5.523561956057013, 5.169925001442312, 3.169925001442312, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 4.087462841250339, 5.129283016944966, 2.321928094887362, 4.459431618637297, 1.584962500721156, 2.584962500721156, 2.584962500721156, 6.108524456778169, 3.9068905956085187, 2.807354922057604, 5.357552004618084, 5.285402218862249, 4.247927513443585, 3.584962500721156, 2.0, 2.0, 3.0, 2.584962500721156, 2.807354922057604, 2.807354922057604, 4.169925001442312, 6.044394119358453, 4.0, 1.0, 3.584962500721156, 4.0, 2.584962500721156, 3.807354922057604, 2.807354922057604, 2.321928094887362, 2.321928094887362, 6.285402218862249, 6.554588851677638, 5.584962500721156, 4.754887502163468, 5.247927513443585, 4.321928094887363, 3.9068905956085187, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.169925001442312, 4.247927513443585, 5.247927513443585, 4.0, 3.584962500721156, 0.0, 2.584962500721156, 2.584962500721156, 5.906890595608519, 4.169925001442312, 2.584962500721156, 4.643856189774724, 4.523561956057013, 1.584962500721156, null, 1.0, 1.584962500721156, 2.321928094887362, 1.0, null, 0.0, 2.584962500721156, 4.087462841250339, null, 0.0, 3.169925001442312, 1.0, 1.0, 2.584962500721156, 2.0, 1.584962500721156, 1.584962500721156, 4.906890595608519, 5.357552004618084, 3.807354922057604, 2.584962500721156, 3.169925001442312, 3.321928094887362, 2.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.584962500721156, 3.584962500721156, 2.0, 1.0, 1.0, 1.0, 2.584962500721156, 2.0, 4.169925001442312, 2.807354922057604, 2.807354922057604, 3.700439718141092, 3.0, 0.0, 2.584962500721156, 3.321928094887362, 3.0, 2.584962500721156, 3.169925001442312, 4.087462841250339, 5.285402218862249, 3.807354922057604, 1.0, 2.321928094887362, 3.807354922057604, 2.321928094887362, 2.584962500721156, 0.0, 2.321928094887362, 2.321928094887362, 6.108524456778169, 7.2384047393250786, 5.044394119358453, 4.807354922057604, 5.247927513443585, 4.906890595608519, 2.584962500721156, 2.0, 2.0, 2.0, 2.0, 4.643856189774724, 5.807354922057604, 1.0, 3.807354922057604, 2.321928094887362, null, null, 6.189824558880018, 2.807354922057604, 4.169925001442312, 4.807354922057604, 4.807354922057604, null, null, null, null, null, null, null, null, null, null, null, 0.0, 0.0, null, null, 0.0, null, null, null, null, 2.321928094887362, 1.584962500721156, null, null, null, null, null, null, null, null, null, 1.0, null, null, 0.0, 1.0, 1.0, 0.0, null, 0.0, null, null, 6.321928094887363, 5.882643049361842, 5.285402218862249, 5.0, 5.523561956057013, 5.832890014164741, 5.643856189774724, 5.20945336562895, 7.2384047393250786, 8.426264754702098, 7.118941072723508, 3.0, 5.672425341971495, 6.426264754702098, 5.491853096329675, 4.700439718141092, 4.906890595608519, 4.906890595608519, 4.906890595608519, 9.20945336562895, 9.957102041562287, 8.071462362556623, 7.098032082960526, 8.011227255423254, 7.348728154231077, 6.754887502163468, 5.906890595608519, 5.906890595608519, 5.906890595608519, 5.882643049361842, 6.584962500721156, 7.727920454563199, 6.614709844115208, 6.149747119504682, 1.584962500721156, 5.459431618637297, 5.459431618637297, 8.459431618637296, 6.672425341971495, 6.599912842187128, 7.965784284662087, 7.948367231584678, 6.129283016944966, 6.129283016944966, 5.700439718141092, 5.20945336562895, 6.303780748177103, 5.392317422778761, 4.643856189774724, 5.247927513443585, 6.475733430966398, 7.592457037268081, 6.129283016944966, 4.643856189774724, 5.426264754702098, 6.741466986401147, 4.459431618637297, 4.906890595608519, 4.954196310386875, 5.087462841250339, 5.087462841250339, 8.219168520462162, 9.019590728357882, 7.851749041416057, 6.965784284662087, 8.060695931687555, 7.118941072723508, 6.523561956057013, 5.672425341971495, 5.643856189774724, 5.643856189774724, 5.614709844115208, 7.149747119504682, 8.214319120800766, 6.087462841250339, 6.392317422778761, 1.0, 5.643856189774724, 5.643856189774724, 7.930737337562887, 6.475733430966398, 6.0, 7.451211111832329, 7.434628227636725, 7.149747119504682, 6.700439718141092, 5.700439718141092, 6.087462841250339, 7.400879436282184, 6.247927513443585, 6.539158811108031, 6.22881869049588, 7.857980995127572, 9.177419537989236, 7.906890595608519, 4.906890595608519, 6.475733430966398, 7.515699838284043, 6.727920454563199, 6.357552004618084, 6.20945336562895, 6.20945336562895, 6.20945336562895, 9.667111542075027, 10.651051691178928, 8.945443836377912, 8.326429487122303, 9.095397022792557, 8.430452551665532, 7.721099188707185, 6.930737337562887, 6.918863237274595, 6.918863237274595, 6.918863237274595, 7.894817763307944, 8.965784284662087, 7.312882955284356, 6.918863237274595, 3.169925001442312, 6.599912842187128, 6.599912842187128, 9.319672120946995, null, 7.918863237274595, 8.51175265376738, 8.49585502688717, 4.0, 4.169925001442312, 1.0, 3.169925001442312, 4.392317422778761, 2.584962500721156, 2.584962500721156, 3.584962500721156, 5.554588851677638, 6.507794640198696, 4.459431618637297, 2.321928094887362, 4.807354922057604, 3.4594316186372973, 3.0, 3.807354922057604, 2.584962500721156, 4.087462841250339, 4.087462841250339, 6.857980995127572, 7.774787059601174, 6.357552004618084, 4.906890595608519, 6.0, 4.807354922057604, 3.700439718141092, 2.807354922057604, 2.807354922057604, 2.807354922057604, 2.807354922057604, 4.857980995127572, 6.022367813028454, 5.523561956057013, 4.087462841250339, 0.0, 3.4594316186372973, 3.4594316186372973, 7.066089190457772, 5.754887502163468, 5.169925001442312, 5.087462841250339, 5.044394119358453, 4.523561956057013, 4.807354922057604, 5.0, 3.0, 4.247927513443585, 4.169925001442312, 4.247927513443585, 4.0, 5.672425341971495, 6.392317422778761, 4.700439718141092, 1.584962500721156, 4.392317422778761, 5.247927513443585, 4.087462841250339, 4.523561956057013, 4.247927513443585, 3.321928094887362, 3.321928094887362, 7.434628227636725, 8.071462362556623, 6.584962500721156, 5.807354922057604, 6.672425341971495, 6.169925001442312, 5.614709844115208, 4.643856189774724, 4.584962500721156, 4.584962500721156, 4.523561956057013, 5.523561956057013, 6.614709844115208, 4.906890595608519, 4.392317422778761, 3.169925001442312, 5.0, 5.0, 5.807354922057604, 3.807354922057604, 5.906890595608519, 6.044394119358453, 6.022367813028454, 3.584962500721156, 4.754887502163468, 3.584962500721156, 2.807354922057604, 3.169925001442312, 3.807354922057604, 2.584962500721156, 3.321928094887362, 4.807354922057604, 4.857980995127572, 4.584962500721156, 1.0, 1.584962500721156, 3.4594316186372973, 2.807354922057604, 3.169925001442312, 1.0, 1.0, 1.0, 5.78135971352466, 6.523561956057013, 4.321928094887363, 3.169925001442312, 3.700439718141092, 3.9068905956085187, 4.0, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 4.459431618637297, 5.523561956057013, 3.0, 2.584962500721156, 1.0, 3.584962500721156, 3.584962500721156, 5.392317422778761, 2.584962500721156, 5.087462841250339, 5.392317422778761, 5.357552004618084, 5.247927513443585, 4.906890595608519, 3.584962500721156, 3.700439718141092, 5.129283016944966, 4.169925001442312, 4.392317422778761, 4.169925001442312, 6.339850002884624, 6.6865005271832185, 6.247927513443585, 3.584962500721156, 4.584962500721156, 6.022367813028454, 5.169925001442312, 5.0, 3.700439718141092, 3.807354922057604, 3.807354922057604, 8.184875342908283, 8.686500527183219, 7.219168520462161, 6.643856189774724, 7.2384047393250786, 6.357552004618084, 5.882643049361842, 5.0, 4.954196310386875, 4.954196310386875, 4.954196310386875, 5.930737337562887, 7.03342300153745, 5.357552004618084, 6.0, 2.0, 5.491853096329675, 5.491853096329675, 6.584962500721156, 5.727920454563199, 6.554588851677638, 6.357552004618084, 6.339850002884624, 3.584962500721156, 3.169925001442312, null, 1.0, 2.0, 4.459431618637297, 4.169925001442312, 3.169925001442312, 5.727920454563199, 6.569855608330948, 3.321928094887362, 1.0, 4.087462841250339, 4.087462841250339, 3.584962500721156, 2.807354922057604, 2.584962500721156, 2.584962500721156, 2.584962500721156, 7.383704292474052, 8.632995197142957, 5.78135971352466, 4.754887502163468, 5.643856189774724, 5.491853096329675, 4.700439718141092, 4.0, 3.9068905956085187, 3.9068905956085187, 3.807354922057604, 2.807354922057604, 4.584962500721156, 6.129283016944966, 3.700439718141092, 1.0, 2.584962500721156, 2.584962500721156, 7.614709844115208, 1.584962500721156, 4.857980995127572, 5.392317422778761, 5.357552004618084, 3.700439718141092, 3.169925001442312, 2.584962500721156, 1.0, 1.584962500721156, 2.807354922057604, 1.584962500721156, 1.584962500721156, 3.321928094887362, 4.857980995127572, 4.459431618637297, 1.0, null, 3.584962500721156, 2.584962500721156, 2.0, 2.321928094887362, 1.584962500721156, 1.584962500721156, 6.066089190457772, 6.882643049361842, 5.044394119358453, 3.584962500721156, 4.523561956057013, 3.169925001442312, 3.4594316186372973, 2.0, 2.0, 2.0, 2.0, 3.584962500721156, 4.857980995127572, 4.321928094887363, 3.0, 1.0, 3.9068905956085187, 3.9068905956085187, 4.754887502163468, 1.584962500721156, 3.584962500721156, 4.523561956057013, 4.459431618637297, 3.0, 1.0, 2.0, 0.0, 1.584962500721156, 2.0, 1.0, 1.0, 3.9068905956085187, 4.857980995127572, 4.584962500721156, null, 2.584962500721156, 3.169925001442312, 2.0, 1.0, null, null, null, 5.392317422778761, 6.426264754702098, 4.700439718141092, 4.0, 4.643856189774724, 4.087462841250339, 2.321928094887362, 1.0, 1.0, 1.0, 1.0, 2.321928094887362, 3.9068905956085187, 2.807354922057604, 2.321928094887362, 2.584962500721156, 1.0, 1.0, 4.169925001442312, 2.584962500721156, 3.584962500721156, 4.0, 4.0, 3.0, 2.584962500721156, 1.0, 1.0, 2.0, 2.584962500721156, 0.0, 2.0, 3.4594316186372973, 3.807354922057604, 3.321928094887362, null, 2.584962500721156, 2.807354922057604, 2.321928094887362, 3.0, 1.0, 1.0, 1.0, 5.584962500721156, 6.658211482751795, 4.754887502163468, 4.087462841250339, 4.906890595608519, 3.700439718141092, 2.807354922057604, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.169925001442312, 4.643856189774724, 3.4594316186372973, 1.0, 1.0, 3.4594316186372973, 3.4594316186372973, 5.357552004618084, 2.321928094887362, 3.807354922057604, 4.247927513443585, 4.247927513443585, 0.0, null, null, null, null, 0.0, null, null, null, null, null, 0.0, 1.584962500721156, null, null, null, null, null, null, null, 3.4594316186372973, 0.0, null, null, null, 1.584962500721156, null, null, null, null, null, 2.807354922057604, null, null, 2.584962500721156, null, null, 1.0, null, null, null, null, 7.948367231584678, 7.679480099505446, 7.076815597050831, 7.467605550082998, 8.164906926675688, 7.339850002884624, 7.189824558880018, 6.754887502163468, 8.134426320220927, 8.948367231584678, 9.238404739325079, 6.930737337562887, 6.906890595608519, 7.6865005271832185, 7.199672344836364, 7.417852514885898, 6.754887502163468, 6.672425341971495, 6.672425341971495, 9.837627933171404, 9.850186837645774, 9.388017285345136, 8.72451385311995, 9.199672344836364, 9.172427508645482, 8.804131021183318, 7.807354922057604, 7.794415866350106, 7.794415866350106, 7.794415866350106, 9.038918989292302, 10.08214904135387, 6.658211482751795, 7.948367231584678, 3.807354922057604, 7.820178962415188, 7.820178962415188, 8.62935662007961, 8.366322214245816, 8.149747119504681, 9.027905996569885, 9.027905996569885, 6.087462841250339, 5.807354922057604, 4.700439718141092, 5.129283016944966, 5.78135971352466, 5.0, 5.0, 4.857980995127572, 6.614709844115208, 7.78135971352466, 6.20945336562895, 3.584962500721156, 5.672425341971495, 5.727920454563199, 4.954196310386875, 5.20945336562895, 4.906890595608519, 4.857980995127572, 4.857980995127572, 8.658211482751796, 9.30149619498255, 7.714245517666122, 6.539158811108031, 7.577428828035749, 7.219168520462161, 6.475733430966398, 5.554588851677638, 5.554588851677638, 5.554588851677638, 5.491853096329675, 6.523561956057013, 7.679480099505446, 6.044394119358453, 6.169925001442312, null, 5.584962500721156, 5.584962500721156, 8.43879185257826, 6.357552004618084, 5.906890595608519, 7.294620748891627, 7.294620748891627, 2.584962500721156, 3.321928094887362, 2.0, 1.0, 3.584962500721156, null, 1.584962500721156, 2.321928094887362, 4.0, 5.554588851677638, 3.807354922057604, null, 3.321928094887362, 2.321928094887362, 2.584962500721156, 2.0, 3.169925001442312, 3.321928094887362, 3.321928094887362, 6.3750394313469245, 7.159871336778389, 5.954196310386875, 4.247927513443585, 5.491853096329675, 4.700439718141092, 3.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.0, 4.584962500721156, 5.754887502163468, 3.169925001442312, 2.584962500721156, 1.0, 2.0, 2.0, 5.977279923499917, 1.584962500721156, 4.584962500721156, 5.169925001442312, 5.129283016944966, 5.554588851677638, 5.700439718141092, 4.321928094887363, 4.523561956057013, 5.321928094887363, 3.9068905956085187, 4.523561956057013, 5.044394119358453, 5.285402218862249, 7.011227255423254, 6.0, 2.0, 5.426264754702098, 5.584962500721156, 4.0, 5.247927513443585, 3.4594316186372973, 5.129283016944966, 5.129283016944966, 7.339850002884624, 8.257387842692651, 6.965784284662087, 6.539158811108031, 7.303780748177103, 6.569855608330948, 5.727920454563199, 4.857980995127572, 4.857980995127572, 4.857980995127572, 4.857980995127572, 6.108524456778169, 7.219168520462161, 5.169925001442312, 5.044394119358453, 2.321928094887362, 5.129283016944966, 5.129283016944966, 5.614709844115208, 5.523561956057013, 5.954196310386875, 7.011227255423254, 6.9886846867721655, 1.0, null, null, null, null, null, 1.584962500721156, null, 1.0, 2.584962500721156, 1.0, null, null, null, null, null, null, 0.0, 0.0, 0.0, 3.700439718141092, 2.0, null, 0.0, null, null, null, null, null, null, 0.0, 1.0, 1.0, null, null, null, null, 3.0, null, 1.0, 0.0, 0.0, 2.584962500721156, 2.0, 1.0, 2.321928094887362, 2.807354922057604, 3.321928094887362, 2.807354922057604, 2.807354922057604, 3.700439718141092, 3.807354922057604, 2.584962500721156, 1.0, 2.584962500721156, 2.0, 1.0, 2.321928094887362, null, 1.0, 1.0, 4.643856189774724, 5.554588851677638, 2.321928094887362, 4.0, 4.392317422778761, 4.087462841250339, 4.0, 3.0, 3.0, 3.0, 3.0, 3.700439718141092, 4.857980995127572, 2.584962500721156, 4.087462841250339, 1.584962500721156, 3.0, 3.0, 4.700439718141092, 3.700439718141092, 3.0, 4.321928094887363, 4.321928094887363, 3.321928094887362, 3.0, 2.584962500721156, 1.0, 1.584962500721156, 3.584962500721156, 2.807354922057604, 1.584962500721156, 4.584962500721156, 5.807354922057604, 3.700439718141092, 2.584962500721156, 2.321928094887362, 3.584962500721156, 2.807354922057604, 3.0, 2.321928094887362, 1.0, 1.0, 6.169925001442312, 7.417852514885898, 5.044394119358453, 4.807354922057604, 5.459431618637297, 4.247927513443585, 3.9068905956085187, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 3.9068905956085187, 4.906890595608519, 4.321928094887363, 3.0, 0.0, 2.0, 2.0, 6.426264754702098, 1.0, 4.169925001442312, 4.700439718141092, 4.643856189774724, 3.169925001442312, 2.584962500721156, 1.0, 0.0, 2.807354922057604, 3.0, 3.0, 1.0, 3.4594316186372973, 5.087462841250339, 3.0, null, 1.0, 1.584962500721156, 1.584962500721156, 3.321928094887362, 2.0, 0.0, 0.0, 5.700439718141092, 6.741466986401147, 4.523561956057013, 3.584962500721156, 4.700439718141092, 2.807354922057604, 3.4594316186372973, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.807354922057604, 4.584962500721156, null, 2.584962500721156, null, 1.584962500721156, 1.584962500721156, 6.285402218862249, 1.0, 1.0, 3.321928094887362, 3.169925001442312, 2.321928094887362, 3.0, null, null, 2.321928094887362, 1.0, 2.321928094887362, 1.0, 1.584962500721156, 3.4594316186372973, 2.807354922057604, 1.0, 2.807354922057604, 3.0, 0.0, null, 0.0, 1.0, 1.0, 2.807354922057604, 4.247927513443585, 5.247927513443585, 3.321928094887362, 4.169925001442312, 3.321928094887362, 1.0, 0.0, 0.0, 0.0, 0.0, 3.321928094887362, 4.700439718141092, null, 2.584962500721156, 2.807354922057604, 1.584962500721156, 1.584962500721156, 4.0, 2.0, 2.0, 3.169925001442312, 3.169925001442312, 3.321928094887362, 2.321928094887362, null, 1.0, 4.247927513443585, 2.0, 2.0, 2.321928094887362, 3.584962500721156, 4.392317422778761, 3.0, null, 2.584962500721156, 2.321928094887362, 1.584962500721156, 4.247927513443585, 2.807354922057604, 2.321928094887362, 2.321928094887362, 5.285402218862249, 6.044394119358453, 5.426264754702098, 4.754887502163468, 5.614709844115208, 4.247927513443585, 4.321928094887363, 3.321928094887362, 3.321928094887362, 3.321928094887362, 3.321928094887362, 4.954196310386875, 6.022367813028454, 2.584962500721156, 2.584962500721156, 2.0, 1.0, 1.0, 5.321928094887363, 4.087462841250339, 3.700439718141092, 4.857980995127572, 4.857980995127572, 1.584962500721156, 0.0, 1.0, 0.0, 0.0, 0.0, null, null, null, 0.0, 1.0, null, null, null, 1.584962500721156, null, 0.0, null, null, 2.584962500721156, 3.700439718141092, null, null, null, 1.0, 2.321928094887362, 0.0, 0.0, 0.0, 0.0, 1.0, 2.807354922057604, 0.0, 2.584962500721156, 0.0, 3.0, 3.0, 2.0, null, null, 1.0, 1.0, null, null, null, null, null, 1.0, null, null, null, null, null, null, null, 0.0, null, 0.0, null, null, null, null, 3.700439718141092, 1.584962500721156, null, null, null, 1.0, null, null, null, null, null, 2.321928094887362, null, null, 2.0, 1.0, 1.0, 1.0, null, 0.0, null, null, 5.321928094887363, 5.357552004618084, 4.0, 5.044394119358453, 5.357552004618084, 4.247927513443585, 4.523561956057013, 4.247927513443585, 4.906890595608519, 5.807354922057604, 6.507794640198696, 4.584962500721156, 3.807354922057604, 4.392317422778761, 4.584962500721156, 4.906890595608519, 4.392317422778761, 4.0, 4.0, 5.906890595608519, 6.894817763307944, 6.894817763307944, 5.930737337562887, 6.247927513443585, 6.044394119358453, 5.584962500721156, 4.459431618637297, 4.459431618637297, 4.459431618637297, 4.459431618637297, 6.599912842187128, 7.651051691178929, 3.807354922057604, 5.727920454563199, 3.700439718141092, 4.584962500721156, 4.584962500721156, 6.523561956057013, 3.0, 5.832890014164741, 6.643856189774724, 6.643856189774724, 4.643856189774724, 4.807354922057604, 3.321928094887362, 4.321928094887363, 5.087462841250339, 3.4594316186372973, 3.321928094887362, 3.321928094887362, 5.0, 4.954196310386875, 5.087462841250339, 4.0, 4.459431618637297, 4.700439718141092, 4.0, 4.321928094887363, 3.700439718141092, 3.807354922057604, 3.807354922057604, 6.459431618637297, 7.159871336778389, 6.523561956057013, 5.614709844115208, 6.149747119504682, 5.977279923499917, 5.357552004618084, 4.247927513443585, 4.247927513443585, 4.247927513443585, 4.247927513443585, 6.442943495848728, 7.507794640198696, 2.0, 5.357552004618084, 1.0, 5.087462841250339, 5.087462841250339, 5.930737337562887, 5.807354922057604, 6.266786540694901, 6.247927513443585, 6.266786540694901, 4.459431618637297, 4.0, 3.807354922057604, 4.0, 5.247927513443585, 4.459431618637297, 2.584962500721156, 3.0, 4.247927513443585, 4.954196310386875, 4.0, 2.584962500721156, 3.321928094887362, 3.9068905956085187, 3.0, 4.0, 1.584962500721156, 2.584962500721156, 2.584962500721156, 5.247927513443585, 5.357552004618084, 5.247927513443585, 4.643856189774724, 5.044394119358453, 5.584962500721156, 3.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 6.129283016944966, 7.129283016944966, 1.0, 4.523561956057013, null, 4.584962500721156, 4.584962500721156, 4.0, 5.426264754702098, 5.0, 5.491853096329675, 5.491853096329675, 5.672425341971495, 4.807354922057604, 5.0, 4.906890595608519, 5.087462841250339, 4.754887502163468, 4.584962500721156, 4.247927513443585, 5.285402218862249, 5.906890595608519, 5.906890595608519, 3.807354922057604, 5.129283016944966, 5.554588851677638, 4.754887502163468, 5.0, 4.169925001442312, 3.807354922057604, 3.807354922057604, 6.658211482751795, 7.721099188707185, 6.94251450533924, 6.129283016944966, 6.845490050944375, 6.3750394313469245, 5.754887502163468, 4.906890595608519, 4.906890595608519, 4.906890595608519, 4.906890595608519, 6.20945336562895, 7.2384047393250786, 3.584962500721156, 4.643856189774724, 1.584962500721156, 5.20945336562895, 5.20945336562895, 6.768184324776926, 5.857980995127572, 6.303780748177103, 5.754887502163468, 5.700439718141092, 4.0, 2.321928094887362, 1.584962500721156, 1.0, 3.169925001442312, 3.169925001442312, 1.584962500721156, 2.807354922057604, 4.169925001442312, 4.523561956057013, 3.700439718141092, 2.0, 2.584962500721156, 2.807354922057604, 0.0, 2.321928094887362, 1.0, null, null, 4.169925001442312, 4.807354922057604, 4.643856189774724, 3.807354922057604, 4.584962500721156, 4.459431618637297, 4.392317422778761, 3.169925001442312, 3.0, 3.0, 3.0, 4.523561956057013, 5.78135971352466, 3.0, 3.321928094887362, 0.0, 3.807354922057604, 3.807354922057604, 3.700439718141092, null, 3.700439718141092, 4.584962500721156, 4.523561956057013, 3.321928094887362, 3.0, 3.4594316186372973, 3.0, 3.584962500721156, 3.700439718141092, 3.0, 3.4594316186372973, 4.321928094887363, 5.285402218862249, 2.584962500721156, 1.0, 3.0, 3.807354922057604, 1.584962500721156, 3.0, 3.0, 2.584962500721156, 2.584962500721156, 4.954196310386875, 5.882643049361842, 5.247927513443585, 4.459431618637297, 5.554588851677638, 5.044394119358453, 4.392317422778761, 3.321928094887362, 3.321928094887362, 3.321928094887362, 3.321928094887362, 4.169925001442312, 5.491853096329675, 3.584962500721156, 3.0, 1.584962500721156, 4.584962500721156, 4.584962500721156, 3.807354922057604, 4.247927513443585, 1.0, 5.426264754702098, 5.357552004618084, 6.794415866350106, 6.857980995127572, 5.426264754702098, 6.247927513443585, 7.434628227636725, 6.727920454563199, 5.491853096329675, 5.78135971352466, 7.6653359171851765, 7.459431618637297, 7.622051819456376, 5.321928094887363, 6.614709844115208, 7.257387842692652, 6.491853096329675, 6.700439718141092, 5.754887502163468, 6.442943495848728, 6.442943495848728, 8.734709620225837, 9.174925682500678, 8.679480099505446, 7.774787059601174, 8.515699838284043, 8.308339030139408, 7.876516946564999, 7.044394119358453, 7.03342300153745, 7.03342300153745, 7.03342300153745, 8.005624549193879, 9.08214904135387, 6.3750394313469245, 7.794415866350106, 1.0, 7.129283016944966, 7.129283016944966, 7.05528243550119, 7.257387842692652, 7.60733031374961, 8.184875342908283, 8.164906926675688, 1.0, 2.584962500721156, 1.0, null, 2.321928094887362, 2.0, 1.584962500721156, 2.0, 2.321928094887362, 2.584962500721156, null, 1.0, 1.0, 0.0, 1.584962500721156, 1.0, null, null, null, 2.807354922057604, 3.584962500721156, 3.807354922057604, null, 2.584962500721156, 3.4594316186372973, 1.0, null, null, null, null, 3.169925001442312, 4.523561956057013, 2.321928094887362, 3.4594316186372973, 0.0, 1.0, 1.0, 2.0, 1.0, 4.247927513443585, 2.0, 2.0, 5.285402218862249, 5.044394119358453, 3.4594316186372973, 4.392317422778761, 5.807354922057604, 4.247927513443585, 4.0, 4.754887502163468, 5.78135971352466, 6.129283016944966, 5.906890595608519, 3.584962500721156, 5.857980995127572, 5.129283016944966, 4.807354922057604, 5.977279923499917, 3.807354922057604, 4.643856189774724, 4.643856189774724, 6.794415866350106, 7.285402218862249, 7.076815597050831, 5.754887502163468, 6.820178962415188, 6.285402218862249, 6.409390936137702, 5.523561956057013, 5.523561956057013, 5.523561956057013, 5.491853096329675, 6.426264754702098, 7.491853096329675, 3.584962500721156, 5.614709844115208, 0.0, 5.087462841250339, 5.087462841250339, 5.643856189774724, 6.78135971352466, 5.977279923499917, 6.614709844115208, 6.614709844115208, 3.321928094887362, 2.584962500721156, 3.321928094887362, 1.0, 3.4594316186372973, 1.584962500721156, 2.0, 2.321928094887362, 3.584962500721156, 2.807354922057604, 2.0, 2.584962500721156, 3.0, 2.807354922057604, null, 3.0, 2.0, 1.0, 1.0, 4.857980995127572, 5.169925001442312, 4.321928094887363, 3.4594316186372973, 4.392317422778761, 3.321928094887362, 2.807354922057604, 2.0, 2.0, 2.0, 2.0, 3.700439718141092, 4.857980995127572, 3.321928094887362, 3.169925001442312, 2.584962500721156, 2.584962500721156, 2.584962500721156, 4.247927513443585, 4.807354922057604, 4.0, 4.169925001442312, 4.169925001442312, 3.4594316186372973, 2.321928094887362, 3.0, 2.0, 3.321928094887362, 3.321928094887362, 1.584962500721156, 2.321928094887362, 4.169925001442312, 4.169925001442312, 4.169925001442312, 3.807354922057604, 3.584962500721156, 3.584962500721156, 3.321928094887362, 4.0, 2.321928094887362, 2.0, 2.0, 4.584962500721156, 5.643856189774724, 5.044394119358453, 4.247927513443585, 4.807354922057604, 4.700439718141092, 4.584962500721156, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 4.643856189774724, 5.727920454563199, 3.807354922057604, 4.459431618637297, 0.0, 3.321928094887362, 3.321928094887362, 4.169925001442312, 4.584962500721156, 3.9068905956085187, 5.044394119358453, 5.044394119358453, 0.0, null, null, null, null, 0.0, null, null, null, null, null, 0.0, 1.584962500721156, null, null, 2.0, null, null, null, null, 3.9068905956085187, 2.321928094887362, null, null, null, 0.0, null, null, null, null, null, 1.584962500721156, null, 2.321928094887362, 2.584962500721156, 0.0, 0.0, 1.0, null, 1.0, null, null, 6.94251450533924, 6.409390936137702, 6.044394119358453, 6.285402218862249, 6.870364719583405, 6.459431618637297, 6.357552004618084, 5.672425341971495, 6.807354922057604, 7.199672344836364, 8.071462362556623, 5.977279923499917, 6.768184324776926, 6.6865005271832185, 5.977279923499917, 6.20945336562895, 5.727920454563199, 5.857980995127572, 5.857980995127572, 8.179909090014934, 8.335390354693924, 8.164906926675688, 7.426264754702098, 7.954196310386875, 7.614709844115208, 7.434628227636725, 6.409390936137702, 6.392317422778761, 6.392317422778761, 6.357552004618084, 8.011227255423254, 9.044394119358454, 6.044394119358453, 7.159871336778389, 2.584962500721156, 6.857980995127572, 6.857980995127572, 7.426264754702098, 6.741466986401147, 7.614709844115208, 7.948367231584678, 7.948367231584678, 8.487840033823051, 7.876516946564999, 7.400879436282184, 7.912889336229962, 8.618385502258606, 7.900866807980749, 7.523561956057013, 7.6293566200796095, 8.774787059601174, 9.084808387804362, 9.840777923595054, 7.6293566200796095, 8.257387842692651, 8.491853096329674, 7.960001932068081, 8.103287808412022, 7.409390936137702, 7.577428828035749, 7.577428828035749, 9.693486957499326, 10.29117069932186, 9.917372079476841, 9.139551352398794, 9.702172685365548, 9.623881490013458, 9.335390354693924, 8.294620748891626, 8.285402218862249, 8.280770770130603, 8.280770770130603, 9.594324603924848, 10.654636028527968, 7.614709844115208, 9.068778277985412, 3.321928094887362, 8.50382573799575, 8.50382573799575, 9.513727595952437, 8.487840033823051, 9.247927513443585, 9.791162888555018, 9.787902559391432, 2.321928094887362, 0.0, 2.0, 1.0, 3.0, 2.807354922057604, 2.0, 2.807354922057604, 2.584962500721156, 2.584962500721156, 3.0, null, 2.807354922057604, 3.321928094887362, 2.0, 2.0, 2.0, 1.0, 1.0, 4.169925001442312, 5.754887502163468, 4.459431618637297, 3.4594316186372973, 4.169925001442312, 3.584962500721156, 3.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 4.321928094887363, 5.523561956057013, 1.0, 2.584962500721156, 1.584962500721156, 3.169925001442312, 3.169925001442312, 4.392317422778761, 3.584962500721156, 4.0, 4.754887502163468, 4.754887502163468, 5.169925001442312, 4.700439718141092, 4.459431618637297, 4.700439718141092, 5.321928094887363, 3.0, 3.169925001442312, 4.459431618637297, 5.392317422778761, 5.78135971352466, 5.857980995127572, 3.169925001442312, 5.321928094887363, 4.906890595608519, 3.700439718141092, 5.087462841250339, 3.0, 4.169925001442312, 4.169925001442312, 6.0, 7.022367813028454, 6.459431618637297, 5.78135971352466, 6.169925001442312, 5.643856189774724, 4.392317422778761, 3.321928094887362, 3.321928094887362, 3.321928094887362, 3.321928094887362, 6.066089190457772, 7.118941072723508, 4.169925001442312, 5.087462841250339, 2.0, 4.807354922057604, 4.807354922057604, 5.357552004618084, 3.807354922057604, 5.087462841250339, 6.22881869049588, 6.22881869049588, 0.0, null, null, null, null, 1.0, null, null, null, null, null, 0.0, 0.0, null, null, null, null, null, null, 0.0, 4.700439718141092, 1.0, null, null, null, 1.584962500721156, null, null, null, null, null, 2.321928094887362, null, 2.0, 2.0, 1.0, 1.0, 0.0, null, null, 0.0, 1.0, 1.0, null, null, 0.0, null, null, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 1.0, 1.0, null, 1.584962500721156, 0.0, null, null, 0.0, 2.0, 3.169925001442312, null, 0.0, 1.584962500721156, 2.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 2.321928094887362, 3.169925001442312, null, 1.0, null, null, null, 2.0, 1.0, null, 2.0, 2.0, 4.807354922057604, 4.754887502163468, 4.459431618637297, 4.584962500721156, 5.247927513443585, 4.169925001442312, 4.247927513443585, 4.392317422778761, 5.129283016944966, 5.754887502163468, 4.906890595608519, 3.321928094887362, 4.584962500721156, 4.954196310386875, 4.523561956057013, 4.459431618637297, 4.247927513443585, 4.0, 4.0, 6.321928094887363, 7.2761244052742375, 6.554588851677638, 5.700439718141092, 6.409390936137702, 6.303780748177103, 5.614709844115208, 4.700439718141092, 4.700439718141092, 4.700439718141092, 4.700439718141092, 6.3750394313469245, 7.426264754702098, 4.169925001442312, 5.554588851677638, 1.584962500721156, 4.807354922057604, 4.807354922057604, 6.714245517666122, 3.169925001442312, 6.0, 6.339850002884624, 6.339850002884624, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, 4.459431618637297, 1.0, null, null, null, 0.0, null, null, null, null, 0.0, 3.0, null, null, 1.584962500721156, 2.321928094887362, 2.584962500721156, 0.0, null, null, null, null, 4.392317422778761, 3.321928094887362, 4.0, 3.4594316186372973, 4.321928094887363, 2.321928094887362, 3.0, 3.0, 4.0, 4.087462841250339, 4.954196310386875, 2.0, 3.0, 3.9068905956085187, 2.807354922057604, 3.4594316186372973, 2.321928094887362, 3.321928094887362, 3.321928094887362, 5.672425341971495, 5.906890595608519, 5.392317422778761, 4.807354922057604, 5.554588851677638, 5.285402218862249, 4.247927513443585, 3.700439718141092, 3.584962500721156, 3.584962500721156, 3.584962500721156, 4.754887502163468, 5.906890595608519, null, 4.807354922057604, 2.807354922057604, 3.584962500721156, 3.700439718141092, 5.169925001442312, 4.392317422778761, 4.523561956057013, 5.044394119358453, 5.044394119358453, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 4.087462841250339, 2.321928094887362, null, null, null, 2.807354922057604, null, null, null, null, null, 3.9068905956085187, null, 2.584962500721156, 1.0, 1.0, 1.0, null, null, null, null, null, 4.169925001442312, 4.754887502163468, 3.0, 3.584962500721156, 4.857980995127572, 4.954196310386875, 2.807354922057604, 3.4594316186372973, 4.247927513443585, 4.954196310386875, 4.700439718141092, 3.0, 1.584962500721156, 4.392317422778761, 4.392317422778761, 4.321928094887363, 3.169925001442312, 3.0, 3.0, 5.882643049361842, 6.189824558880018, 6.20945336562895, 5.169925001442312, 6.149747119504682, 5.247927513443585, 5.700439718141092, 4.643856189774724, 4.584962500721156, 4.584962500721156, 4.584962500721156, 5.832890014164741, 6.94251450533924, 3.807354922057604, 5.20945336562895, 2.807354922057604, 4.643856189774724, 4.643856189774724, 5.357552004618084, 5.807354922057604, 5.700439718141092, 5.459431618637297, 5.459431618637297, null, null, null, null, null, 0.0, null, null, null, null, null, null, 0.0, null, null, 1.0, null, null, null, null, 4.523561956057013, 1.0, null, null, null, 1.584962500721156, null, null, null, null, null, 2.321928094887362, 0.0, 1.0, 2.0, 1.0, 1.0, 1.0, null, null, null, null, 0.0, 1.0, null, null, null, 1.0, 0.0, 0.0, null, 4.459431618637297, null, null, 2.0, null, 2.0, 2.0, 1.584962500721156, null, null, 4.0, 5.357552004618084, 0.0, 0.0, 0.0, null, 1.0, null, null, null, null, null, 1.0, 5.857980995127572, 2.584962500721156, 1.0, null, null, 6.409390936137702, 2.321928094887362, 0.0, 1.584962500721156, 2.0, null, null, null, 0.0, null, 0.0, null, null, null, 0.0, 0.0, null, 0.0, null, null, 0.0, null, null, null, 2.0, 3.4594316186372973, 1.0, null, null, null, 3.169925001442312, 0.0, 0.0, 0.0, 0.0, null, 1.584962500721156, 2.807354922057604, null, 1.584962500721156, 1.0, 1.0, 2.0, null, null, null, 0.0, 4.700439718141092, 6.78135971352466, 4.807354922057604, 3.584962500721156, 4.087462841250339, 5.044394119358453, 2.807354922057604, 2.0, 5.977279923499917, 6.285402218862249, 6.129283016944966, 4.169925001442312, 5.044394119358453, 1.584962500721156, 4.906890595608519, 3.807354922057604, 3.4594316186372973, 3.0, 3.0, 8.294620748891626, 8.807354922057604, 6.832890014164741, 5.977279923499917, 6.614709844115208, 5.523561956057013, 4.906890595608519, 3.807354922057604, 3.807354922057604, 3.807354922057604, 3.584962500721156, 5.78135971352466, 6.820178962415188, 8.124121311829187, 5.614709844115208, 1.0, 4.523561956057013, 4.523561956057013, 7.247927513443585, 5.169925001442312, 5.584962500721156, 5.20945336562895, 5.321928094887363, 6.247927513443585, 8.487840033823051, 5.554588851677638, 5.523561956057013, 6.189824558880018, 5.523561956057013, 4.643856189774724, null, 7.2761244052742375, 5.807354922057604, 7.727920454563199, 1.0, 3.700439718141092, 6.087462841250339, 3.4594316186372973, 4.754887502163468, null, 5.20945336562895, 5.20945336562895, 9.252665432450248, 9.554588851677638, 8.447083226209653, 7.20945336562895, 8.022367813028454, 7.159871336778389, 6.832890014164741, 5.754887502163468, 5.754887502163468, 5.754887502163468, 5.727920454563199, 7.108524456778169, 8.092757140919852, 9.820178962415188, 6.857980995127572, 3.0, 6.0, 6.0, 8.876516946565, null, 5.78135971352466, 8.087462841250339, 8.049848549450562, 6.189824558880018, 7.1799090900149345, 3.807354922057604, 4.247927513443585, 5.087462841250339, 5.285402218862249, 3.807354922057604, null, 6.584962500721156, 6.0, 6.954196310386875, 1.0, 2.807354922057604, 4.807354922057604, 4.247927513443585, 4.169925001442312, 0.0, 3.9068905956085187, 3.9068905956085187, 9.108524456778168, 9.39231742277876, 7.339850002884624, 5.700439718141092, 6.285402218862249, 5.754887502163468, 5.554588851677638, 4.643856189774724, 4.643856189774724, 4.643856189774724, 4.584962500721156, 6.087462841250339, 7.108524456778169, 9.546894459887637, 4.523561956057013, 1.584962500721156, 4.700439718141092, 4.700439718141092, 8.434628227636725, 0.0, 5.882643049361842, 6.066089190457772, 5.954196310386875, 1.584962500721156, 2.807354922057604, null, null, null, null, 0.0, 1.584962500721156, 2.321928094887362, 1.584962500721156, 2.0, 0.0, null, null, 0.0, null, 1.584962500721156, null, null, 1.584962500721156, 3.700439718141092, 2.321928094887362, 1.584962500721156, 2.0, 2.321928094887362, 2.584962500721156, 1.0, 1.0, 1.0, 1.0, 2.0, 2.807354922057604, 4.0, 1.0, 0.0, null, null, 2.584962500721156, null, 2.0, 1.0, 1.584962500721156, 0.0, 0.0, 0.0, 1.0, 2.807354922057604, null, null, null, null, null, null, null, null, null, 1.584962500721156, 3.584962500721156, null, 0.0, 0.0, null, 2.0, null, 1.0, 0.0, 0.0, 2.321928094887362, 0.0, 0.0, 0.0, 0.0, 3.807354922057604, 4.906890595608519, null, null, null, 1.0, 1.0, null, 1.584962500721156, null, 1.0, 1.0, null, null, null, null, 0.0, null, null, null, null, 0.0, 2.584962500721156, null, 1.0, null, null, null, null, null, null, null, 2.807354922057604, 1.0, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, 2.0, null, null, null, null, 3.0, 5.0, 1.0, 1.0, 1.0, 1.0, 1.0, 2.807354922057604, 3.4594316186372973, 2.584962500721156, 3.4594316186372973, 1.0, 2.0, 0.0, 2.321928094887362, null, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.0, 4.321928094887363, 3.9068905956085187, 3.0, 3.807354922057604, 3.169925001442312, 3.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.584962500721156, 4.523561956057013, 3.0, 2.0, 4.087462841250339, null, null, 2.584962500721156, 2.0, 2.0, 3.700439718141092, 3.4594316186372973, 0.0, 2.584962500721156, 1.0, 1.0, 0.0, 3.0, 0.0, 1.0, 2.0, 2.584962500721156, 1.0, null, 1.584962500721156, 1.0, 0.0, null, null, 0.0, 0.0, 3.4594316186372973, 3.807354922057604, 0.0, 3.169925001442312, 3.169925001442312, 2.807354922057604, 2.0, 1.0, 1.0, 1.0, 1.0, 2.584962500721156, 3.584962500721156, 2.0, 2.584962500721156, null, null, null, 3.169925001442312, 1.0, 1.0, 2.584962500721156, 2.584962500721156, 1.584962500721156, 4.584962500721156, 2.807354922057604, 3.169925001442312, 2.0, 3.0, 0.0, null, 1.584962500721156, 2.0, 2.321928094887362, null, null, 1.584962500721156, null, 2.0, null, 0.0, 0.0, 4.169925001442312, 4.807354922057604, 3.584962500721156, 4.247927513443585, 4.392317422778761, 3.0, 2.584962500721156, 1.0, 1.0, 1.0, 1.0, 4.0, 5.129283016944966, 4.169925001442312, 4.0, 1.0, 2.0, 2.0, 2.584962500721156, null, 3.0, 3.9068905956085187, 4.0, 2.321928094887362, 3.169925001442312, 1.0, null, 1.0, null, null, null, 2.321928094887362, 2.807354922057604, null, null, 0.0, 1.584962500721156, null, 1.0, null, 0.0, 0.0, 4.754887502163468, 5.169925001442312, 2.0, 2.321928094887362, 2.807354922057604, 2.584962500721156, 2.321928094887362, 1.0, 1.0, 1.0, 1.0, 2.321928094887362, 4.169925001442312, 5.169925001442312, 2.584962500721156, null, null, null, 5.554588851677638, null, 3.0, 2.0, 2.321928094887362, 4.321928094887363, 6.507794640198696, 2.584962500721156, 2.321928094887362, 3.0, 2.321928094887362, 2.807354922057604, null, 5.087462841250339, 3.700439718141092, 4.857980995127572, 1.0, 2.584962500721156, 4.459431618637297, 2.321928094887362, 1.0, 0.0, 3.321928094887362, 3.321928094887362, 7.577428828035749, 7.977279923499917, 5.727920454563199, 4.643856189774724, 5.044394119358453, 4.807354922057604, 4.523561956057013, 3.321928094887362, 3.321928094887362, 3.321928094887362, 3.321928094887362, 4.754887502163468, 5.78135971352466, 8.312882955284355, 3.0, 1.0, 4.0, 4.0, 7.20945336562895, 0.0, 4.0, 5.807354922057604, 5.78135971352466, 4.459431618637297, 7.658211482751795, 3.9068905956085187, 4.523561956057013, 5.129283016944966, 5.727920454563199, 5.247927513443585, 4.459431618637297, 6.554588851677638, 7.2761244052742375, 6.392317422778761, 4.169925001442312, 5.357552004618084, 4.0, 4.321928094887363, 4.643856189774724, 3.700439718141092, 4.247927513443585, 4.247927513443585, 8.326429487122303, 8.7714894695006, 7.700439718141092, 6.658211482751795, 7.03342300153745, 6.714245517666122, 5.882643049361842, 4.906890595608519, 4.906890595608519, 4.906890595608519, 4.906890595608519, 6.643856189774724, 7.679480099505446, 9.273795599214264, 5.169925001442312, 1.0, 4.700439718141092, 4.700439718141092, 6.807354922057604, 4.459431618637297, 6.3750394313469245, 7.087462841250339, 7.044394119358453, null, 0.0, null, null, null, 1.0, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, 2.0, 2.584962500721156, null, null, 1.0, 1.584962500721156, null, null, null, null, null, 1.0, 2.584962500721156, null, 1.0, 1.0, 1.0, 3.4594316186372973, null, 1.0, null, null, 4.700439718141092, 4.700439718141092, null, 2.0, 2.584962500721156, 4.754887502163468, 2.807354922057604, 1.0, 4.321928094887363, 4.392317422778761, 5.169925001442312, 0.0, 3.169925001442312, 3.584962500721156, 0.0, 2.584962500721156, null, 1.584962500721156, 1.584962500721156, 4.700439718141092, 5.906890595608519, 5.554588851677638, 4.523561956057013, 5.169925001442312, 3.9068905956085187, 4.459431618637297, 3.700439718141092, 3.700439718141092, 3.700439718141092, 3.700439718141092, 3.321928094887362, 4.392317422778761, 6.129283016944966, 4.321928094887363, 2.321928094887362, 2.584962500721156, 2.584962500721156, 4.700439718141092, null, 4.643856189774724, 3.9068905956085187, 3.9068905956085187, 0.0, 1.584962500721156, null, null, 1.584962500721156, 1.584962500721156, null, 0.0, 3.321928094887362, 0.0, 2.0, 1.0, 0.0, 1.0, 2.0, 0.0, null, null, null, 4.169925001442312, 3.807354922057604, 3.321928094887362, 1.0, 1.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 2.0, 3.321928094887362, 3.0, 0.0, 1.584962500721156, 1.584962500721156, 2.584962500721156, null, 0.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.0, null, null, null, null, 0.0, 2.321928094887362, 1.0, null, 2.807354922057604, 1.584962500721156, null, null, null, null, null, 4.807354922057604, 5.044394119358453, 2.584962500721156, 0.0, 1.0, 1.0, 2.584962500721156, 1.0, 1.0, 1.0, 1.0, 0.0, 2.584962500721156, 0.0, 1.0, null, 2.584962500721156, 2.584962500721156, 2.584962500721156, null, 0.0, null, null, 3.584962500721156, 5.321928094887363, 3.584962500721156, 1.0, 1.0, 2.584962500721156, 3.0, null, 4.523561956057013, 1.0, 4.906890595608519, null, 0.0, 3.0, 2.321928094887362, 1.0, null, 2.0, 2.0, 6.539158811108031, 6.6865005271832185, 5.614709844115208, 4.392317422778761, 5.0, 3.321928094887362, 2.807354922057604, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.0, 3.584962500721156, 4.857980995127572, 6.918863237274595, 3.584962500721156, 1.0, 2.0, 2.0, 6.409390936137702, null, 4.807354922057604, 4.643856189774724, 4.584962500721156, 3.0, 3.321928094887362, null, 1.0, null, 1.0, null, null, 4.321928094887363, 3.0, 4.087462841250339, null, null, 1.0, 0.0, null, null, 1.584962500721156, 1.584962500721156, 5.977279923499917, 6.754887502163468, 3.4594316186372973, 2.321928094887362, 2.584962500721156, 2.584962500721156, 2.584962500721156, 1.0, 1.0, 1.0, 1.0, 2.321928094887362, 3.4594316186372973, 6.507794640198696, 1.0, 0.0, 1.0, 1.0, 5.672425341971495, null, 1.0, 3.169925001442312, 3.169925001442312, 0.0, 2.807354922057604, null, 1.0, 1.0, null, null, 1.0, 3.0, 3.321928094887362, 1.584962500721156, null, null, null, 1.584962500721156, 2.0, 1.0, 0.0, 0.0, 3.700439718141092, 4.169925001442312, 3.169925001442312, 1.0, 0.0, 2.807354922057604, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.807354922057604, 5.523561956057013, 1.584962500721156, 1.584962500721156, 2.0, 2.0, 3.321928094887362, null, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.0, 3.807354922057604, 2.584962500721156, null, 1.584962500721156, 3.321928094887362, 2.807354922057604, null, 3.700439718141092, 4.459431618637297, 3.0, null, 1.584962500721156, 3.169925001442312, 2.0, 1.0, null, 0.0, 0.0, 5.930737337562887, 6.066089190457772, 4.643856189774724, 3.700439718141092, 4.459431618637297, 2.584962500721156, 3.0, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 3.0, 4.0, 6.285402218862249, 1.0, 0.0, 3.0, 3.0, 6.066089190457772, null, 4.169925001442312, 3.700439718141092, 3.584962500721156, 2.321928094887362, 4.857980995127572, null, 1.0, 1.0, 1.584962500721156, 1.0, null, 2.584962500721156, 2.807354922057604, 2.584962500721156, null, null, 0.0, 1.584962500721156, 0.0, 1.0, null, null, 5.357552004618084, 4.392317422778761, 3.807354922057604, 3.169925001442312, 3.321928094887362, 3.321928094887362, 3.169925001442312, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.0, 4.0, 6.044394119358453, 2.0, 1.584962500721156, null, null, 5.247927513443585, null, 3.321928094887362, 2.807354922057604, 2.807354922057604, null, 2.321928094887362, null, 0.0, null, 1.0, null, null, 0.0, null, null, null, null, 1.584962500721156, 0.0, 1.0, null, 0.0, 0.0, 4.169925001442312, 4.392317422778761, 3.169925001442312, 1.0, 2.0, 0.0, 2.0, 0.0, 0.0, 0.0, 0.0, 1.0, 2.321928094887362, 2.0, 1.0, 0.0, 1.0, 1.0, 4.0, null, 1.584962500721156, 2.321928094887362, 2.321928094887362, 2.0, 6.906890595608519, 2.0, 2.321928094887362, 0.0, 1.0, null, null, 1.584962500721156, 2.584962500721156, 2.0, 3.9068905956085187, null, 2.0, 4.459431618637297, null, null, 3.700439718141092, 3.700439718141092, 4.0, 3.807354922057604, 3.584962500721156, 3.700439718141092, 3.9068905956085187, 5.977279923499917, 1.0, 0.0, 0.0, 0.0, 0.0, 2.584962500721156, 3.807354922057604, 4.0, 2.584962500721156, null, 5.247927513443585, 5.247927513443585, 2.0, null, 2.584962500721156, 6.266786540694901, 6.189824558880018, 5.643856189774724, 7.741466986401147, 4.0, 3.807354922057604, 4.754887502163468, 4.700439718141092, null, null, 6.700439718141092, 6.0, 6.357552004618084, 1.0, 3.584962500721156, 5.426264754702098, 4.700439718141092, 3.9068905956085187, null, 4.584962500721156, 4.584962500721156, 8.67595703294175, 9.019590728357882, 7.348728154231077, 6.108524456778169, 6.832890014164741, 6.409390936137702, 6.285402218862249, 5.426264754702098, 5.426264754702098, 5.426264754702098, 5.285402218862249, 5.857980995127572, 6.845490050944375, 9.396604781181859, 5.954196310386875, 4.584962500721156, 5.643856189774724, 5.643856189774724, 8.405141463136344, null, 5.807354922057604, 6.845490050944375, 6.78135971352466, 2.321928094887362, 3.169925001442312, null, 0.0, 2.321928094887362, 3.584962500721156, null, 0.0, 1.584962500721156, 2.584962500721156, 2.807354922057604, null, 3.0, 1.0, 1.0, 1.0, 2.0, 0.0, 0.0, 4.954196310386875, 5.491853096329675, 3.169925001442312, 1.0, 2.0, 3.169925001442312, 3.169925001442312, 1.0, 1.0, 1.0, 1.0, 2.807354922057604, 4.169925001442312, 4.754887502163468, 2.584962500721156, 0.0, 2.0, 2.0, 5.169925001442312, 0.0, 1.0, 2.0, 2.321928094887362, null, 1.0, null, null, null, null, 0.0, null, null, null, null, null, 0.0, null, null, null, null, null, null, 2.0, 2.807354922057604, 2.584962500721156, null, null, 1.0, 1.0, null, null, null, null, null, 0.0, 3.584962500721156, 1.0, null, 2.321928094887362, 2.321928094887362, 2.807354922057604, 0.0, 0.0, 1.0, 1.0, 4.0, 5.0, 1.0, 2.321928094887362, 4.169925001442312, 4.700439718141092, 3.321928094887362, null, 4.954196310386875, 4.523561956057013, 5.247927513443585, null, 0.0, 2.584962500721156, 1.584962500721156, null, null, 2.321928094887362, 2.321928094887362, 6.022367813028454, 7.098032082960526, 5.392317422778761, 5.129283016944966, 5.357552004618084, 4.584962500721156, 3.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 4.087462841250339, 5.321928094887363, 7.159871336778389, 4.906890595608519, 1.584962500721156, 2.321928094887362, 2.321928094887362, 6.658211482751795, 0.0, 4.906890595608519, 5.169925001442312, 5.169925001442312, 2.321928094887362, 5.491853096329675, 2.0, 3.0, 1.0, 2.807354922057604, null, null, 3.807354922057604, 2.807354922057604, 4.700439718141092, 1.0, 1.584962500721156, 4.169925001442312, 2.0, 1.0, null, 3.169925001442312, 3.169925001442312, 6.066089190457772, 6.882643049361842, 4.321928094887363, 4.321928094887363, 4.643856189774724, 4.906890595608519, 3.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.700439718141092, 4.584962500721156, 6.285402218862249, 3.0, 1.0, 3.4594316186372973, 3.4594316186372973, 5.977279923499917, null, 4.700439718141092, 4.584962500721156, 4.584962500721156, 0.0, 2.321928094887362, null, null, 1.0, null, null, 1.0, 2.0, 3.700439718141092, null, 1.0, 0.0, 1.584962500721156, null, null, 0.0, null, null, 3.807354922057604, 5.857980995127572, 1.0, null, null, 1.584962500721156, 2.321928094887362, 1.0, 1.0, 1.0, 1.0, 1.0, 2.0, 5.285402218862249, 2.0, 1.0, 0.0, 1.0, 6.965784284662087, 1.584962500721156, 2.807354922057604, 3.0, 3.0, 1.0, 4.0, null, 2.807354922057604, 2.0, 2.584962500721156, 0.0, null, 3.807354922057604, 4.321928094887363, 3.584962500721156, null, null, 3.169925001442312, 0.0, null, null, 0.0, 0.0, 3.584962500721156, 5.78135971352466, 4.247927513443585, 2.584962500721156, 3.700439718141092, 3.169925001442312, 3.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.169925001442312, 4.169925001442312, 5.169925001442312, 3.0, 0.0, 1.0, 1.0, 5.491853096329675, null, 4.0, 2.584962500721156, 2.584962500721156, 1.0, 0.0, 0.0, null, null, 0.0, 2.321928094887362, null, 3.169925001442312, 3.321928094887362, null, 0.0, null, 1.584962500721156, 1.584962500721156, 0.0, 1.584962500721156, 0.0, 0.0, 3.807354922057604, 5.491853096329675, 2.584962500721156, 2.321928094887362, 3.0, 1.584962500721156, null, null, null, null, null, 1.0, 2.0, 3.321928094887362, 1.0, 1.0, 1.0, 1.0, 4.169925001442312, null, 2.0, 3.584962500721156, 3.584962500721156, 1.584962500721156, 1.0, null, 0.0, 1.0, 1.0, 1.0, null, 1.584962500721156, 2.0, 2.0, null, 1.0, null, 1.0, 1.0, null, 1.0, 1.0, 3.4594316186372973, 1.584962500721156, 2.807354922057604, 1.0, 2.321928094887362, null, 2.0, 1.0, 1.0, 1.0, 1.0, 1.0, 2.584962500721156, null, 1.0, null, 0.0, 0.0, 3.807354922057604, null, 1.0, 1.584962500721156, 1.0, 2.0, 2.0, null, null, 0.0, 1.0, null, null, 2.584962500721156, 3.584962500721156, 2.584962500721156, null, 1.0, 1.584962500721156, null, 1.0, null, 1.0, 1.0, 3.700439718141092, 5.614709844115208, 3.807354922057604, 2.807354922057604, 3.584962500721156, 2.0, 1.584962500721156, 0.0, 0.0, 0.0, 0.0, 3.169925001442312, 4.247927513443585, 5.754887502163468, 2.0, 0.0, 1.0, 1.0, 5.129283016944966, null, 3.584962500721156, 3.321928094887362, 3.321928094887362, 1.584962500721156, 3.321928094887362, 1.0, 0.0, null, null, null, 0.0, 2.321928094887362, 1.0, 2.584962500721156, null, 0.0, 0.0, 1.0, null, null, null, null, 4.523561956057013, 2.807354922057604, 3.584962500721156, 1.584962500721156, 1.584962500721156, 0.0, 2.0, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, null, 1.0, 4.321928094887363, 2.584962500721156, 0.0, null, null, 1.0, null, null, 2.584962500721156, 2.584962500721156, 5.169925001442312, 7.679480099505446, 4.0, 4.906890595608519, 5.087462841250339, 4.700439718141092, null, null, 6.357552004618084, 4.087462841250339, 6.672425341971495, 2.0, 2.584962500721156, 5.584962500721156, 4.169925001442312, 3.169925001442312, null, 3.700439718141092, 3.700439718141092, 8.169925001442312, 8.475733430966399, 7.285402218862249, 6.392317422778761, 7.20945336562895, 6.409390936137702, 6.20945336562895, 5.0, 5.0, 5.0, 5.0, 6.930737337562887, 7.9886846867721655, 8.357552004618084, 5.426264754702098, null, 4.857980995127572, 4.857980995127572, 7.523561956057013, 1.584962500721156, 5.459431618637297, 6.475733430966398, 6.459431618637297, 5.129283016944966, 6.022367813028454, 3.807354922057604, 3.169925001442312, 3.584962500721156, 4.643856189774724, 0.0, null, 5.357552004618084, 3.0, 5.930737337562887, 2.584962500721156, 1.0, 4.459431618637297, 2.0, 3.4594316186372973, null, 3.321928094887362, 3.321928094887362, 7.864186144654281, 8.388017285345136, 6.832890014164741, 5.169925001442312, 5.882643049361842, 5.954196310386875, 5.954196310386875, 4.954196310386875, 4.954196310386875, 4.954196310386875, 4.954196310386875, 5.727920454563199, 6.845490050944375, 7.882643049361842, 5.491853096329675, 3.0, 4.321928094887363, 4.321928094887363, 7.321928094887363, null, 1.0, 6.285402218862249, 6.266786540694901, 3.169925001442312, 3.321928094887362, 2.584962500721156, 2.807354922057604, 2.807354922057604, 4.459431618637297, 2.321928094887362, 1.584962500721156, 4.392317422778761, 5.357552004618084, 3.807354922057604, 1.0, 3.584962500721156, 4.0, 2.0, 2.584962500721156, 2.0, 2.807354922057604, 2.807354922057604, 6.700439718141092, 6.614709844115208, 4.584962500721156, 4.247927513443585, 4.392317422778761, 4.087462841250339, 2.321928094887362, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 4.247927513443585, 5.20945336562895, 4.169925001442312, 4.0, null, 3.321928094887362, 3.321928094887362, 6.0, null, 4.321928094887363, 5.129283016944966, 5.087462841250339, 5.087462841250339, 6.554588851677638, 3.4594316186372973, 3.584962500721156, 4.169925001442312, 4.0, 4.643856189774724, null, 5.0, null, 4.643856189774724, 0.0, 1.0, 4.321928094887363, 2.807354922057604, 2.0, null, 3.584962500721156, 3.584962500721156, 6.303780748177103, 6.3750394313469245, 5.882643049361842, 5.129283016944966, 5.882643049361842, 5.554588851677638, 5.614709844115208, 4.643856189774724, 4.643856189774724, 4.643856189774724, 4.643856189774724, 5.491853096329675, 6.569855608330948, 7.169925001442312, 4.906890595608519, null, 2.584962500721156, 2.584962500721156, 6.0, 0.0, 5.523561956057013, 5.807354922057604, 5.78135971352466, 0.0, 3.0, null, 0.0, 0.0, null, null, null, 2.0, 0.0, null, null, null, 1.0, 1.0, null, null, 0.0, 0.0, 1.0, 0.0, 3.4594316186372973, 1.0, 1.0, null, 0.0, null, null, null, null, 2.0, 3.0, 3.169925001442312, null, null, 1.0, 1.0, 3.4594316186372973, null, null, 0.0, 0.0, 2.0, 2.321928094887362, 2.0, 0.0, 1.0, 2.0, 0.0, null, 2.321928094887362, 1.0, 2.584962500721156, null, 1.0, 0.0, null, 1.0, 1.0, null, null, 4.247927513443585, 4.459431618637297, 3.700439718141092, 2.321928094887362, 2.807354922057604, 3.169925001442312, 4.0, 2.807354922057604, 2.807354922057604, 2.807354922057604, 2.807354922057604, 2.321928094887362, 3.321928094887362, 4.0, 1.0, 1.584962500721156, 3.169925001442312, 3.169925001442312, 3.584962500721156, null, 1.0, 2.0, 2.584962500721156, 1.584962500721156, 1.0, null, 0.0, null, null, null, 1.0, 1.584962500721156, 1.584962500721156, 1.0, 1.0, null, null, 0.0, null, null, null, null, 3.584962500721156, 4.523561956057013, 2.321928094887362, 1.584962500721156, 2.584962500721156, 0.0, null, null, null, null, null, 1.0, 2.0, 2.584962500721156, 1.0, 0.0, null, null, 2.584962500721156, null, 1.584962500721156, 2.807354922057604, 2.807354922057604, 1.0, 3.169925001442312, null, 0.0, null, 1.0, 0.0, null, 2.321928094887362, 1.584962500721156, null, null, 0.0, 2.807354922057604, 0.0, null, null, 1.584962500721156, 1.584962500721156, 4.584962500721156, 4.954196310386875, 3.169925001442312, 1.584962500721156, 2.584962500721156, 2.0, 2.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.0, null, 2.321928094887362, 4.584962500721156, 2.584962500721156, 0.0, 0.0, 0.0, 2.0, null, 1.0, 2.321928094887362, 2.321928094887362, 3.0, 4.584962500721156, 2.0, 2.0, 3.0, 2.584962500721156, null, null, 4.392317422778761, 3.321928094887362, 4.392317422778761, null, 0.0, 4.247927513443585, 1.584962500721156, 3.0, null, 2.0, 2.0, 6.066089190457772, 6.129283016944966, 4.807354922057604, 3.807354922057604, 4.392317422778761, 3.9068905956085187, 4.523561956057013, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.169925001442312, 4.169925001442312, 5.20945336562895, 6.727920454563199, 3.4594316186372973, 1.0, 2.321928094887362, 2.584962500721156, 5.754887502163468, null, 3.4594316186372973, 5.0, 4.857980995127572, 0.0, 2.0, 2.0, 0.0, null, null, null, null, null, 0.0, 1.0, null, 0.0, null, 0.0, 1.0, null, 1.0, 1.0, 2.584962500721156, 2.321928094887362, 2.807354922057604, 1.584962500721156, 2.321928094887362, 0.0, 1.584962500721156, null, null, null, null, 1.584962500721156, 2.807354922057604, 4.0, 0.0, 0.0, null, null, 3.700439718141092, null, null, null, 0.0, null, 3.0, 1.584962500721156, null, null, 1.0, null, null, 2.0, 1.0, 1.0, null, 0.0, 0.0, 0.0, null, null, 0.0, 0.0, 3.321928094887362, 4.169925001442312, 1.0, 0.0, 1.584962500721156, 1.0, 1.584962500721156, 0.0, 0.0, 0.0, 0.0, 2.0, 3.169925001442312, 3.807354922057604, 2.0, null, null, null, 3.0, null, 1.0, 2.321928094887362, 2.321928094887362, null, 1.0, null, null, null, 0.0, null, null, null, 0.0, null, null, 0.0, 1.0, null, null, null, null, null, 2.321928094887362, 2.584962500721156, null, null, null, 2.0, 1.0, null, null, null, null, 0.0, 1.0, 2.0, 0.0, null, null, null, 4.087462841250339, null, null, null, null, null, 0.0, 1.0, null, null, 2.0, null, null, 2.0, null, 4.643856189774724, null, 1.0, null, null, null, null, null, null, 0.0, 5.357552004618084, null, null, null, 0.0, 3.169925001442312, 2.0, 2.0, 2.0, 2.0, null, 2.584962500721156, 3.0, 1.0, 1.0, 3.807354922057604, 3.807354922057604, 5.700439718141092, null, null, 0.0, 1.0, 6.169925001442312, 7.965784284662087, 5.554588851677638, 5.247927513443585, 6.20945336562895, 5.247927513443585, null, 1.584962500721156, 6.754887502163468, 4.523561956057013, 6.523561956057013, 4.169925001442312, 4.087462841250339, 6.22881869049588, 3.4594316186372973, 3.584962500721156, 0.0, 5.614709844115208, 5.614709844115208, 8.405141463136344, 9.211888294546004, 8.312882955284355, 6.599912842187128, 7.924812503605781, 7.108524456778169, 6.727920454563199, 6.0, 6.0, 6.0, 5.977279923499917, 6.539158811108031, 7.584962500721156, 8.927777962082342, 6.266786540694901, 1.0, 5.491853096329675, 5.491853096329675, 7.6653359171851765, null, 7.159871336778389, 7.577428828035749, 7.562242424221073, 5.882643049361842, 7.247927513443585, 3.807354922057604, 4.523561956057013, 5.20945336562895, 5.357552004618084, 5.247927513443585, null, 6.768184324776926, 4.459431618637297, 5.643856189774724, null, 2.807354922057604, 5.321928094887363, 4.643856189774724, 3.169925001442312, null, 3.9068905956085187, 3.9068905956085187, 8.312882955284355, 9.030667136246942, 7.459431618637297, 6.22881869049588, 7.257387842692652, 6.672425341971495, 5.700439718141092, 4.857980995127572, 4.807354922057604, 4.807354922057604, 4.807354922057604, 6.087462841250339, 7.118941072723508, 8.550746785383243, 4.954196310386875, 0.0, 5.392317422778761, 5.426264754702098, 7.906890595608519, 0.0, 5.727920454563199, 6.768184324776926, 6.754887502163468, 2.0, 4.0, null, 1.584962500721156, 1.0, 1.0, 2.321928094887362, 1.0, 3.9068905956085187, 1.0, 2.584962500721156, 2.807354922057604, 2.584962500721156, null, 2.321928094887362, 3.321928094887362, 2.0, 1.584962500721156, 1.584962500721156, 5.882643049361842, 6.6293566200796095, 3.169925001442312, 3.700439718141092, 3.9068905956085187, 2.584962500721156, 2.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 2.321928094887362, 3.700439718141092, 5.754887502163468, 2.0, 1.0, 2.0, 2.0, 5.754887502163468, 0.0, 3.321928094887362, 2.807354922057604, 3.0, 3.4594316186372973, 4.700439718141092, 1.584962500721156, 1.584962500721156, 1.0, 2.584962500721156, 1.0, null, 4.0, null, 3.807354922057604, null, 0.0, 2.584962500721156, 1.584962500721156, null, null, 2.321928094887362, 2.321928094887362, 5.044394119358453, 5.459431618637297, 4.906890595608519, 2.321928094887362, 3.9068905956085187, 3.9068905956085187, 3.807354922057604, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 3.321928094887362, 4.700439718141092, 5.247927513443585, 2.321928094887362, 0.0, 1.0, 1.0, 4.169925001442312, null, 3.169925001442312, 4.643856189774724, 4.643856189774724, 3.0, 1.0, 0.0, 1.584962500721156, 2.584962500721156, null, 0.0, 0.0, 3.321928094887362, 4.247927513443585, 2.0, 1.0, 3.169925001442312, 2.321928094887362, 2.0, 2.807354922057604, 1.584962500721156, null, null, 4.459431618637297, 5.321928094887363, 2.807354922057604, 2.584962500721156, 3.0, 3.0, 4.169925001442312, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.169925001442312, 2.321928094887362, 3.4594316186372973, 4.700439718141092, 2.321928094887362, 1.0, 3.807354922057604, 3.807354922057604, 5.754887502163468, 2.0, 2.807354922057604, 2.0, 2.0, 0.0, 4.392317422778761, null, null, 0.0, 4.169925001442312, null, null, 3.700439718141092, 2.807354922057604, 2.584962500721156, 1.0, 0.0, null, null, 0.0, 0.0, 2.584962500721156, 2.584962500721156, 4.807354922057604, 6.149747119504682, 4.700439718141092, 1.584962500721156, 2.0, 2.584962500721156, 2.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 2.807354922057604, 7.05528243550119, 3.0, 0.0, 2.584962500721156, 2.584962500721156, 6.087462841250339, 0.0, 3.0, 2.584962500721156, 2.321928094887362, 2.584962500721156, 2.0, 1.0, 0.0, null, 2.0, 2.807354922057604, null, 3.321928094887362, 2.807354922057604, 3.584962500721156, null, null, 2.321928094887362, 0.0, null, null, null, null, 5.491853096329675, 5.285402218862249, 3.584962500721156, 2.321928094887362, 3.0, 3.0, 2.0, 1.0, 1.0, 1.0, 1.0, 2.0, 3.4594316186372973, 5.882643049361842, null, 0.0, 1.0, 1.0, 5.392317422778761, 0.0, 2.807354922057604, 4.087462841250339, 4.087462841250339, 4.321928094887363, 6.044394119358453, 3.0, 3.321928094887362, 2.321928094887362, 4.459431618637297, 3.4594316186372973, 0.0, 4.906890595608519, 4.906890595608519, 4.700439718141092, null, 3.169925001442312, 4.169925001442312, 0.0, 3.807354922057604, 1.584962500721156, 4.0, 4.0, 6.807354922057604, 7.011227255423254, 4.857980995127572, 2.584962500721156, 3.169925001442312, 5.247927513443585, 4.459431618637297, 3.807354922057604, 3.807354922057604, 3.807354922057604, 3.700439718141092, 4.392317422778761, 5.491853096329675, 8.199672344836364, 4.754887502163468, 2.807354922057604, 4.807354922057604, 4.857980995127572, 7.199672344836364, 2.584962500721156, 4.700439718141092, 4.643856189774724, 4.523561956057013, 3.700439718141092, 4.169925001442312, 1.0, 0.0, 2.0, 1.0, 1.0, null, 4.247927513443585, 2.321928094887362, 4.0, null, null, 1.584962500721156, null, 0.0, null, 2.0, 2.0, 5.614709844115208, 6.554588851677638, 4.857980995127572, 4.087462841250339, 4.700439718141092, 3.807354922057604, 3.4594316186372973, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 3.584962500721156, 5.857980995127572, 2.584962500721156, null, null, null, 5.754887502163468, 0.0, 3.0, 4.523561956057013, 4.459431618637297, 2.584962500721156, 3.4594316186372973, 1.0, 0.0, 1.0, 0.0, 0.0, null, 3.4594316186372973, 1.584962500721156, 2.0, null, 0.0, 1.0, null, null, null, null, null, 3.9068905956085187, 5.247927513443585, 4.0, 2.321928094887362, 3.169925001442312, 2.584962500721156, 3.0, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 2.321928094887362, 3.321928094887362, 5.643856189774724, 2.0, 0.0, null, 0.0, 4.247927513443585, null, 1.0, 2.807354922057604, 2.807354922057604, 1.0, 3.700439718141092, null, 0.0, 0.0, 0.0, null, null, 2.807354922057604, 1.584962500721156, 3.321928094887362, 1.584962500721156, 0.0, 2.0, 1.0, 1.0, null, null, null, 3.9068905956085187, 6.0, 3.4594316186372973, 2.584962500721156, 3.4594316186372973, 3.0, 1.0, 0.0, 0.0, 0.0, 0.0, 2.321928094887362, 3.4594316186372973, 5.169925001442312, 2.0, 2.0, null, null, 4.321928094887363, 0.0, 2.584962500721156, 3.0, 3.0, null, 0.0, null, null, null, 0.0, null, null, 0.0, null, null, 1.584962500721156, null, null, null, 0.0, null, null, null, 0.0, 4.087462841250339, 1.0, null, 0.0, 1.0, 2.0, null, null, null, null, 0.0, 2.584962500721156, 3.584962500721156, 3.169925001442312, 1.584962500721156, 1.0, 1.0, 3.9068905956085187, null, 2.0, null, null, 2.321928094887362, 4.906890595608519, 2.321928094887362, 1.584962500721156, 2.321928094887362, 4.169925001442312, 3.0, 1.584962500721156, 4.087462841250339, 3.321928094887362, 3.4594316186372973, 2.584962500721156, 1.0, 0.0, 3.4594316186372973, 3.4594316186372973, 3.0, 2.321928094887362, 2.321928094887362, 6.0, 6.475733430966398, 4.523561956057013, 3.4594316186372973, 4.0, 3.321928094887362, 1.584962500721156, 0.0, 0.0, 0.0, 0.0, 3.9068905956085187, 5.0, 6.569855608330948, 3.700439718141092, 1.0, 1.584962500721156, 1.584962500721156, 4.0, 4.523561956057013, 2.584962500721156, 4.321928094887363, 4.392317422778761, 3.700439718141092, 3.0, 2.584962500721156, 1.584962500721156, 2.807354922057604, 2.584962500721156, 2.807354922057604, null, 5.129283016944966, 4.807354922057604, 4.321928094887363, null, 2.321928094887362, 4.584962500721156, 2.584962500721156, null, 0.0, 2.321928094887362, 2.321928094887362, 6.614709844115208, 7.562242424221073, 4.523561956057013, 3.700439718141092, 4.0, 4.087462841250339, 4.754887502163468, 3.807354922057604, 3.807354922057604, 3.807354922057604, 3.700439718141092, 3.807354922057604, 4.857980995127572, 7.774787059601174, 3.0, 1.584962500721156, 1.0, 1.0, 6.870364719583405, null, 4.169925001442312, 4.321928094887363, 4.169925001442312, 6.0, 7.03342300153745, 4.459431618637297, 4.459431618637297, 5.044394119358453, 4.807354922057604, 3.169925001442312, null, 6.6293566200796095, 5.672425341971495, 6.475733430966398, 2.0, 1.584962500721156, 5.584962500721156, 4.392317422778761, 4.392317422778761, 0.0, 4.169925001442312, 4.169925001442312, 8.625708843064466, 8.778077129535358, 7.599912842187128, 6.442943495848728, 7.044394119358453, 6.129283016944966, 6.044394119358453, 4.954196310386875, 4.954196310386875, 4.954196310386875, 4.954196310386875, 6.189824558880018, 7.22881869049588, 9.63117705570398, 5.882643049361842, 0.0, 5.357552004618084, 5.357552004618084, 7.2761244052742375, 0.0, 4.954196310386875, 7.149747119504682, 7.108524456778169, 0.0, null, 1.0, 0.0, 1.0, null, null, null, 1.584962500721156, null, 1.0, 1.0, null, 0.0, null, null, null, null, null, 2.321928094887362, 3.321928094887362, 1.0, 1.0, 1.0, 1.584962500721156, null, null, null, null, null, null, null, 3.321928094887362, null, null, null, null, 3.0, null, null, null, null, 1.584962500721156, 4.321928094887363, null, 1.584962500721156, 2.584962500721156, 2.584962500721156, 1.0, null, 4.247927513443585, 3.4594316186372973, null, null, 0.0, 2.584962500721156, 0.0, null, 0.0, 2.0, 2.0, 5.78135971352466, 5.129283016944966, 3.9068905956085187, 2.321928094887362, 3.584962500721156, 3.584962500721156, 4.0, 2.807354922057604, 2.807354922057604, 2.807354922057604, 2.807354922057604, 2.321928094887362, 3.700439718141092, 5.523561956057013, 3.0, null, 2.584962500721156, 2.584962500721156, 4.169925001442312, 2.807354922057604, 3.807354922057604, 3.9068905956085187, 3.9068905956085187, null, 2.321928094887362, null, 0.0, 0.0, null, null, null, 2.321928094887362, 1.584962500721156, 2.0, null, null, null, null, null, null, null, null, 3.0, 4.584962500721156, 3.0, 1.0, 1.0, 2.0, 1.584962500721156, 1.0, 1.0, 1.0, 1.0, 2.0, 2.807354922057604, 4.459431618637297, null, 1.584962500721156, null, null, 4.523561956057013, null, 1.0, 2.584962500721156, 2.584962500721156, 1.584962500721156, 4.0, null, 0.0, 1.0, 2.0, null, null, 3.4594316186372973, 1.0, 1.0, null, 1.0, 1.584962500721156, 0.0, null, null, 0.0, 0.0, 3.4594316186372973, 5.930737337562887, 3.807354922057604, 3.4594316186372973, 3.9068905956085187, 3.4594316186372973, 2.0, 0.0, 0.0, 0.0, 0.0, 1.584962500721156, 2.584962500721156, 5.584962500721156, 2.584962500721156, 0.0, 2.0, 2.0, 1.0, null, 1.0, 2.584962500721156, 2.584962500721156, 2.584962500721156, 4.643856189774724, 1.0, 0.0, 2.0, 2.584962500721156, 0.0, null, 2.807354922057604, null, 3.584962500721156, null, null, 0.0, 1.0, null, null, 1.584962500721156, 1.584962500721156, 4.087462841250339, 5.357552004618084, 4.459431618637297, 3.169925001442312, 3.4594316186372973, 3.584962500721156, 3.169925001442312, 2.0, 2.0, 2.0, 2.0, 3.807354922057604, 4.906890595608519, 4.584962500721156, 3.169925001442312, null, 1.0, 1.0, 4.807354922057604, 0.0, 4.0, 4.169925001442312, 4.087462841250339, 1.0, 4.169925001442312, 1.0, 1.0, 2.0, 1.0, null, 0.0, 2.321928094887362, 0.0, 2.584962500721156, null, 1.0, 0.0, 2.807354922057604, 2.0, 0.0, 0.0, 0.0, 1.584962500721156, 3.807354922057604, 3.321928094887362, 2.584962500721156, 3.169925001442312, 3.321928094887362, 3.169925001442312, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.584962500721156, 4.754887502163468, 2.807354922057604, 2.807354922057604, null, 3.0, 3.0, 2.0, 2.321928094887362, 3.169925001442312, 3.169925001442312, 2.807354922057604, 1.0, 1.0, 2.584962500721156, 0.0, 1.0, 2.0, null, 1.584962500721156, 1.584962500721156, 1.0, null, null, 2.0, null, 0.0, 2.0, 1.0, 1.0, 1.0, 2.321928094887362, 3.9068905956085187, 2.584962500721156, 1.0, 2.0, 2.321928094887362, 2.0, 0.0, 0.0, 0.0, 0.0, 2.0, 3.321928094887362, null, null, null, 1.584962500721156, 1.584962500721156, 3.4594316186372973, null, 1.0, 2.321928094887362, 2.0, null, 0.0, null, null, 1.0, null, 0.0, null, 1.0, null, null, null, null, null, null, null, null, null, null, null, 2.321928094887362, 1.0, null, 1.0, 1.0, 1.584962500721156, 1.0, 1.0, 1.0, 1.0, 0.0, 1.584962500721156, null, null, null, 2.0, 2.0, 2.0, null, null, 0.0, 0.0, 4.459431618637297, 5.906890595608519, 3.807354922057604, 4.523561956057013, 4.087462841250339, 4.700439718141092, 4.087462841250339, 3.4594316186372973, 4.807354922057604, 4.523561956057013, 5.554588851677638, 3.584962500721156, 4.584962500721156, 3.584962500721156, 3.807354922057604, 4.954196310386875, 2.584962500721156, 3.0, 3.0, 6.426264754702098, 6.6293566200796095, 6.672425341971495, 5.044394119358453, 5.807354922057604, 5.392317422778761, 5.321928094887363, 4.169925001442312, 4.169925001442312, 4.169925001442312, 4.169925001442312, 5.754887502163468, 6.930737337562887, 7.321928094887363, 5.357552004618084, 1.584962500721156, 4.807354922057604, 4.807354922057604, 4.247927513443585, null, 5.247927513443585, 5.754887502163468, 5.700439718141092, 0.0, 3.169925001442312, 1.0, 1.584962500721156, 1.584962500721156, 2.584962500721156, null, null, 3.169925001442312, 1.0, 1.0, null, null, 2.321928094887362, null, 2.321928094887362, null, 0.0, 0.0, 2.807354922057604, 5.044394119358453, 4.754887502163468, 1.0, 2.0, 2.0, 3.584962500721156, 0.0, 0.0, 0.0, 0.0, 2.321928094887362, 3.584962500721156, 3.9068905956085187, 3.584962500721156, 2.0, 1.0, 1.0, 3.700439718141092, 1.584962500721156, null, 2.807354922057604, 2.807354922057604, 3.584962500721156, 6.22881869049588, 3.321928094887362, 5.0, 5.169925001442312, 1.0, 1.0, null, 4.0, 0.0, 5.321928094887363, 1.0, 2.0, 2.807354922057604, 2.0, 3.0, 0.0, 3.321928094887362, 3.321928094887362, 5.554588851677638, 5.357552004618084, 5.672425341971495, 4.247927513443585, 5.044394119358453, 5.882643049361842, 4.700439718141092, 3.584962500721156, 3.584962500721156, 3.584962500721156, 3.584962500721156, 6.409390936137702, 7.392317422778761, 6.169925001442312, 4.0, 3.169925001442312, 4.169925001442312, 4.169925001442312, 5.20945336562895, 0.0, 5.169925001442312, 6.169925001442312, 6.066089190457772, 4.643856189774724, 6.442943495848728, 4.954196310386875, 4.087462841250339, 4.643856189774724, 4.954196310386875, 2.321928094887362, 3.0, 5.247927513443585, 3.584962500721156, 4.807354922057604, 3.321928094887362, 4.247927513443585, 0.0, 5.0, 4.392317422778761, 3.0, 4.247927513443585, 4.247927513443585, 5.78135971352466, 6.845490050944375, 6.475733430966398, 5.044394119358453, 5.882643049361842, 5.930737337562887, 4.321928094887363, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.169925001442312, 5.392317422778761, 6.459431618637297, 5.523561956057013, 4.523561956057013, 3.4594316186372973, 5.247927513443585, 5.247927513443585, 6.303780748177103, 1.584962500721156, 5.392317422778761, 6.189824558880018, 6.189824558880018, 4.584962500721156, 4.392317422778761, 4.754887502163468, 3.700439718141092, 4.459431618637297, 3.169925001442312, 3.807354922057604, 3.700439718141092, 5.044394119358453, 4.392317422778761, 4.321928094887363, 1.0, 4.392317422778761, 3.9068905956085187, 3.807354922057604, 3.9068905956085187, 3.584962500721156, 2.807354922057604, 2.807354922057604, 5.285402218862249, 5.857980995127572, 6.442943495848728, 4.954196310386875, 5.643856189774724, 5.426264754702098, 4.857980995127572, 3.9068905956085187, 3.9068905956085187, 3.9068905956085187, 3.807354922057604, 5.554588851677638, 6.569855608330948, 5.087462841250339, 4.906890595608519, 1.584962500721156, 4.169925001442312, 4.169925001442312, 4.392317422778761, null, 4.247927513443585, 5.754887502163468, 5.614709844115208, 2.321928094887362, 4.087462841250339, 1.0, 1.584962500721156, 0.0, 1.0, null, 0.0, 1.0, 2.0, 1.0, 1.0, null, 1.0, null, null, null, 0.0, 0.0, 3.807354922057604, 4.169925001442312, 3.700439718141092, 2.807354922057604, 3.0, 2.321928094887362, 2.0, null, null, null, null, 2.807354922057604, 4.087462841250339, 5.129283016944966, null, null, 2.0, 2.0, 3.169925001442312, 0.0, 3.0, 3.0, 3.0, 3.321928094887362, 3.0, 3.0, 2.321928094887362, 2.584962500721156, 1.584962500721156, 2.584962500721156, 1.0, 3.584962500721156, 2.807354922057604, 3.807354922057604, null, 3.807354922057604, 0.0, 2.807354922057604, 3.807354922057604, 1.0, 1.0, 1.0, 2.584962500721156, 4.643856189774724, 3.807354922057604, 4.0, 4.584962500721156, 3.807354922057604, 3.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 4.0, 4.906890595608519, null, 2.0, null, 1.584962500721156, 1.584962500721156, 2.321928094887362, null, 3.169925001442312, 4.321928094887363, 4.169925001442312, 2.807354922057604, 2.321928094887362, 1.0, 0.0, 1.0, 2.321928094887362, 1.584962500721156, null, 1.584962500721156, 2.584962500721156, 3.169925001442312, 2.0, null, 2.584962500721156, 1.0, 3.0, 1.584962500721156, 0.0, 0.0, 3.0, 3.321928094887362, 4.247927513443585, 3.0, 3.807354922057604, 3.321928094887362, 4.0, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.700439718141092, 4.584962500721156, 2.0, 2.584962500721156, null, 1.0, 1.0, 4.169925001442312, null, 2.584962500721156, 3.9068905956085187, 4.0, 3.0, 4.857980995127572, 2.584962500721156, 2.0, 3.0, 3.0, null, null, 3.4594316186372973, 1.0, 3.169925001442312, null, 1.0, 3.584962500721156, 2.584962500721156, null, 0.0, 1.584962500721156, 1.584962500721156, 4.523561956057013, 4.954196310386875, 3.807354922057604, 3.584962500721156, 3.807354922057604, 3.4594316186372973, 3.4594316186372973, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.321928094887362, 4.169925001442312, 5.247927513443585, 4.700439718141092, 3.584962500721156, 0.0, 2.584962500721156, 2.584962500721156, 3.9068905956085187, 0.0, 3.169925001442312, 3.169925001442312, 3.169925001442312, 2.0, 3.584962500721156, 1.0, 0.0, 0.0, 0.0, 0.0, null, 2.0, null, 3.321928094887362, null, null, null, 1.584962500721156, 1.0, null, 0.0, 0.0, 2.0, 3.169925001442312, 2.584962500721156, 2.0, 2.321928094887362, 1.584962500721156, null, null, null, null, null, 1.584962500721156, 2.584962500721156, 3.4594316186372973, 2.321928094887362, null, 2.0, 2.0, 3.807354922057604, null, null, 2.807354922057604, 2.584962500721156, 2.807354922057604, 1.584962500721156, null, null, 1.0, null, null, 0.0, 2.584962500721156, 1.584962500721156, 2.584962500721156, null, 0.0, 0.0, 1.0, 0.0, null, 1.0, 1.0, 2.584962500721156, 3.584962500721156, 3.700439718141092, 2.321928094887362, 3.0, 1.584962500721156, 1.584962500721156, 0.0, 0.0, 0.0, 0.0, 2.807354922057604, 4.0, 2.584962500721156, 0.0, 0.0, 2.0, 2.0, 3.321928094887362, 0.0, 1.0, 1.0, 0.0, null, null, null, null, null, null, null, null, null, 0.0, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, 0.0, 1.584962500721156, null, 1.0, 0.0, 2.0, 2.0, 1.0, null, null, null, null, 3.807354922057604, 5.643856189774724, 2.0, 3.321928094887362, 3.700439718141092, 3.584962500721156, 3.4594316186372973, null, 3.9068905956085187, 2.0, 5.169925001442312, 2.0, 2.321928094887362, 3.807354922057604, 2.321928094887362, 1.584962500721156, null, 2.584962500721156, 2.584962500721156, 5.426264754702098, 6.189824558880018, 5.392317422778761, 4.0, 4.643856189774724, 3.9068905956085187, 4.459431618637297, 3.0, 3.0, 3.0, 2.807354922057604, 4.584962500721156, 5.832890014164741, 5.672425341971495, 4.700439718141092, 2.584962500721156, 2.584962500721156, 2.584962500721156, 3.0, null, 4.906890595608519, 4.906890595608519, 4.954196310386875, 8.758223214726724, 10.537218400538595, 7.954196310386875, 8.348728154231077, 8.60733031374961, 8.159871336778389, null, 7.599912842187128, 9.044394119358454, 8.62935662007961, 9.758223214726724, 8.027905996569885, 8.08214904135387, 8.038918989292302, 8.262094845370179, 7.787902559391432, 7.294620748891627, 7.392317422778761, 7.392317422778761, 10.029287226968245, 10.489847960439297, 10.28886607416582, 9.491853096329674, 10.064742764750257, 9.62935662007961, 9.505811553919594, 8.471675214392045, 8.471675214392045, 8.471675214392045, 8.451211111832329, 9.768184324776927, 10.810571634741146, 10.022367813028454, 9.139551352398794, 4.087462841250339, 8.383704292474052, 8.383704292474052, 8.888743248898258, 9.370687406807217, 9.588714635582264, 9.815383295813538, 9.820178962415188, 1.584962500721156, 3.169925001442312, 2.0, 2.321928094887362, 3.321928094887362, 3.0, null, null, 3.807354922057604, 3.9068905956085187, 1.584962500721156, 1.0, 0.0, 2.584962500721156, 1.0, 3.700439718141092, null, 3.0, 3.0, 4.247927513443585, 4.247927513443585, 3.4594316186372973, 2.321928094887362, 3.4594316186372973, 3.4594316186372973, 3.321928094887362, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.807354922057604, 5.044394119358453, 4.807354922057604, 1.584962500721156, 3.0, 1.584962500721156, 1.584962500721156, 3.700439718141092, 0.0, 3.321928094887362, 3.169925001442312, 3.169925001442312, 5.584962500721156, 7.417852514885898, 5.0, 4.700439718141092, 5.285402218862249, 5.459431618637297, null, 0.0, 5.700439718141092, 3.584962500721156, 5.700439718141092, 2.0, 2.321928094887362, 5.044394119358453, 4.0, 4.459431618637297, null, 4.700439718141092, 4.700439718141092, 6.523561956057013, 6.832890014164741, 6.9886846867721655, 6.22881869049588, 6.794415866350106, 6.087462841250339, 6.303780748177103, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.169925001442312, 6.475733430966398, 7.434628227636725, 7.129283016944966, 5.584962500721156, 0.0, 5.700439718141092, 5.700439718141092, 6.266786540694901, null, 5.882643049361842, 5.807354922057604, 5.78135971352466, 5.906890595608519, 7.7481928495894605, 5.20945336562895, 4.700439718141092, 5.857980995127572, 5.426264754702098, null, 1.0, 5.727920454563199, 3.700439718141092, 5.554588851677638, 0.0, 2.0, 5.357552004618084, 5.044394119358453, 3.0, 1.0, 3.9068905956085187, 3.9068905956085187, 6.3750394313469245, 7.507794640198696, 7.076815597050831, 6.087462841250339, 7.022367813028454, 6.714245517666122, 6.303780748177103, 5.357552004618084, 5.357552004618084, 5.357552004618084, 5.357552004618084, 6.409390936137702, 7.491853096329675, 7.491853096329675, 4.906890595608519, 1.584962500721156, 4.584962500721156, 4.584962500721156, 6.78135971352466, 0.0, 5.044394119358453, 6.087462841250339, 6.022367813028454, null, 0.0, 2.321928094887362, 1.0, null, null, null, null, 1.584962500721156, null, 1.0, null, null, 1.584962500721156, 0.0, 1.0, null, 0.0, 0.0, null, 1.0, 3.169925001442312, 0.0, 0.0, 1.584962500721156, 0.0, null, null, null, null, 0.0, 0.0, 2.321928094887362, null, 0.0, 1.0, 1.0, 2.0, null, null, 2.0, 1.0, 2.807354922057604, 5.247927513443585, 3.0, 2.807354922057604, null, 2.0, null, null, 3.584962500721156, 1.584962500721156, 3.9068905956085187, null, null, 3.584962500721156, 2.807354922057604, 2.0, 0.0, 1.584962500721156, 1.584962500721156, 3.9068905956085187, 4.584962500721156, 4.321928094887363, 4.087462841250339, 4.700439718141092, 4.169925001442312, 3.4594316186372973, 2.0, 2.0, 2.0, 2.0, 4.392317422778761, 5.357552004618084, 4.700439718141092, 4.392317422778761, 0.0, 2.0, 2.0, 3.584962500721156, null, 3.584962500721156, 3.700439718141092, 3.700439718141092, 3.0, 4.906890595608519, 3.0, null, 2.0, null, 1.584962500721156, null, 2.807354922057604, 2.321928094887362, 3.321928094887362, 1.584962500721156, 1.584962500721156, 2.321928094887362, 1.0, 1.584962500721156, null, 1.0, 1.0, 4.087462841250339, 5.087462841250339, 3.9068905956085187, 3.321928094887362, 4.0, 3.169925001442312, 3.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.807354922057604, 3.807354922057604, 4.0, 2.584962500721156, null, 2.584962500721156, 2.584962500721156, 4.247927513443585, 0.0, 3.4594316186372973, 2.0, 2.0, null, 0.0, 0.0, null, null, 1.0, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 2.584962500721156, null, 0.0, 0.0, null, null, null, null, null, null, 0.0, 1.0, null, 1.584962500721156, null, null, null, null, null, 0.0, null, 0.0, 1.0, 1.584962500721156, 1.0, null, null, 0.0, null, null, 0.0, null, null, null, null, null, 0.0, null, null, null, null, null, null, 2.807354922057604, 1.0, 2.584962500721156, null, 1.584962500721156, 0.0, 0.0, 0.0, 0.0, null, 0.0, 2.584962500721156, 1.0, null, 1.0, 1.0, 1.0, null, null, null, 0.0, 2.321928094887362, 3.9068905956085187, 1.0, 1.0, 0.0, 2.584962500721156, null, null, 3.4594316186372973, null, 1.0, null, 0.0, 1.0, 1.584962500721156, 1.0, null, 2.0, 2.0, 3.169925001442312, 4.754887502163468, 4.087462841250339, 3.169925001442312, 3.700439718141092, 2.321928094887362, 3.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 2.584962500721156, 3.700439718141092, 4.857980995127572, 4.169925001442312, 3.169925001442312, null, 3.0, 3.0, 4.247927513443585, null, 2.0, 2.584962500721156, 2.321928094887362, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, 0.0, null, null, null, null, null, 0.0, null, null, null, null, null, 1.584962500721156, null, null, null, 1.0, 1.0, null, null, null, 0.0, 0.0, 4.643856189774724, 2.0, 2.807354922057604, 3.4594316186372973, 4.247927513443585, 3.9068905956085187, 3.4594316186372973, 2.584962500721156, 5.0, 6.409390936137702, 6.303780748177103, 4.0, 4.087462841250339, 4.700439718141092, 5.247927513443585, 3.807354922057604, 4.247927513443585, 3.4594316186372973, 3.4594316186372973, 6.906890595608519, 7.22881869049588, 5.700439718141092, 4.584962500721156, 4.754887502163468, 4.643856189774724, 5.523561956057013, 4.392317422778761, 4.392317422778761, 4.392317422778761, 4.392317422778761, 5.129283016944966, 6.20945336562895, 4.0, 4.643856189774724, 2.0, 4.321928094887363, 4.321928094887363, 6.523561956057013, null, 3.584962500721156, 4.754887502163468, 4.700439718141092, 5.392317422778761, 3.4594316186372973, 3.9068905956085187, 4.087462841250339, 4.523561956057013, 4.523561956057013, 3.700439718141092, 3.9068905956085187, 5.491853096329675, 6.189824558880018, 6.700439718141092, 4.584962500721156, 4.643856189774724, 5.20945336562895, 3.9068905956085187, 3.321928094887362, 4.754887502163468, 2.807354922057604, 2.807354922057604, 6.768184324776926, 7.1799090900149345, 6.9886846867721655, 6.108524456778169, 6.392317422778761, 4.700439718141092, 6.266786540694901, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.247927513443585, 6.247927513443585, 2.0, 5.754887502163468, 1.584962500721156, 3.807354922057604, 3.807354922057604, 6.20945336562895, null, 5.584962500721156, 3.700439718141092, 3.700439718141092, 6.247927513443585, 5.321928094887363, 5.700439718141092, 5.930737337562887, 6.20945336562895, 6.247927513443585, 5.832890014164741, 5.426264754702098, 6.906890595608519, 7.98299357469431, 8.383704292474052, 6.507794640198696, 6.066089190457772, 6.554588851677638, 6.475733430966398, 6.129283016944966, 5.321928094887363, 5.357552004618084, 5.357552004618084, 8.632995197142957, 9.400879436282183, 8.294620748891626, 7.491853096329675, 8.071462362556623, 7.294620748891627, 7.515699838284043, 6.426264754702098, 6.426264754702098, 6.392317422778761, 6.321928094887363, 7.417852514885898, 8.467605550082997, 6.22881869049588, 7.05528243550119, 3.0, 5.906890595608519, 5.906890595608519, 7.7073591320808825, 4.754887502163468, 6.475733430966398, 7.491853096329675, 7.467605550082998, 5.0, 4.169925001442312, 4.459431618637297, 3.4594316186372973, 4.700439718141092, 4.700439718141092, 4.321928094887363, 3.169925001442312, 5.129283016944966, 6.584962500721156, 6.303780748177103, 4.247927513443585, 4.247927513443585, 5.459431618637297, 5.087462841250339, 4.459431618637297, 3.700439718141092, 3.584962500721156, 3.584962500721156, 7.417852514885898, 7.930737337562887, 6.569855608330948, 6.247927513443585, 6.442943495848728, 5.727920454563199, 5.882643049361842, 4.754887502163468, 4.754887502163468, 4.754887502163468, 4.754887502163468, 5.882643049361842, 6.906890595608519, 5.523561956057013, 5.169925001442312, 2.0, 4.392317422778761, 4.392317422778761, 5.857980995127572, null, 5.087462841250339, 4.754887502163468, 4.754887502163468, 6.6293566200796095, 5.426264754702098, 6.169925001442312, 6.507794640198696, 6.918863237274595, 6.569855608330948, 6.0, 5.727920454563199, 7.515699838284043, 8.447083226209653, 8.734709620225837, 6.78135971352466, 6.339850002884624, 7.247927513443585, 6.832890014164741, 6.614709844115208, 6.247927513443585, 5.672425341971495, 5.672425341971495, 9.688250309133178, 9.893301530860564, 8.252665432450248, 7.2384047393250786, 7.813781191217037, 7.577428828035749, 7.924812503605781, 6.845490050944375, 6.820178962415188, 6.820178962415188, 6.820178962415188, 8.118941072723507, 9.162391328756906, 6.977279923499917, 7.199672344836364, 4.087462841250339, 6.700439718141092, 6.700439718141092, 8.005624549193879, null, 7.312882955284356, 7.507794640198696, 7.467605550082998, 7.451211111832329, 6.3750394313469245, 6.9886846867721655, 7.569855608330948, 7.845490050944375, 7.2761244052742375, 6.807354922057604, 6.392317422778761, 7.9886846867721655, 8.179909090014934, 9.445014845868423, 7.483815777264256, 7.0, 8.027905996569885, 7.442943495848728, 7.2384047393250786, 6.409390936137702, 6.672425341971495, 6.672425341971495, 9.105908508571158, 9.308339030139408, 9.31741261376487, 8.523561956057012, 8.945443836377912, 8.370687406807217, 8.813781191217037, 7.7615512324444795, 7.754887502163468, 7.754887502163468, 7.7481928495894605, 8.936637939002571, 9.970105890612182, 5.247927513443585, 8.45532722030456, 3.321928094887362, 7.357552004618084, 7.357552004618084, 8.179909090014934, 2.584962500721156, 8.169925001442312, 8.654636028527968, 8.625708843064466, null, null, 6.392317422778761, 5.044394119358453, 5.426264754702098, null, null, null, 1.0, null, 3.0, null, null, 0.0, 2.0, 5.906890595608519, null, null, null, 2.0, 1.0, 1.0, null, null, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 6.491853096329675, 7.491853096329675, null, null, null, null, null, 1.0, null, 0.0, 1.584962500721156, 1.584962500721156, null, null, null, null, null, null, null, null, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 0.0, null, null, 1.0, null, null, null, null, null, null, null, 1.0, null, null, null, null, null, null, null, null, null, null, 1.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 4.906890595608519, 3.4594316186372973, 4.169925001442312, 4.700439718141092, 4.857980995127572, 4.857980995127572, 4.807354922057604, 4.169925001442312, 5.554588851677638, 6.357552004618084, 7.357552004618084, 5.087462841250339, 4.459431618637297, 5.832890014164741, 5.392317422778761, 5.700439718141092, 3.9068905956085187, 4.0, 4.0, 6.906890595608519, 7.139551352398794, 7.139551352398794, 5.554588851677638, 5.954196310386875, 5.392317422778761, 6.539158811108031, 5.523561956057013, 5.523561956057013, 5.523561956057013, 5.491853096329675, 6.339850002884624, 7.348728154231077, 4.0, 6.129283016944966, 2.321928094887362, 4.906890595608519, 4.906890595608519, 6.78135971352466, null, 5.392317422778761, 2.807354922057604, 2.807354922057604, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 0.0, null, 1.0, 0.0, 0.0, 0.0, 0.0, null, null, 1.0, null, null, null, null, null, null, null, null, null, 5.977279923499917, 4.169925001442312, 5.643856189774724, 6.108524456778169, 6.169925001442312, 5.700439718141092, 5.754887502163468, 5.285402218862249, 6.409390936137702, 7.577428828035749, 8.303780748177102, 5.882643049361842, 6.0, 6.643856189774724, 6.303780748177103, 6.22881869049588, 5.357552004618084, 5.321928094887363, 5.321928094887363, 8.622051819456376, 8.810571634741146, 8.005624549193879, 6.700439718141092, 7.159871336778389, 6.285402218862249, 7.483815777264256, 6.3750394313469245, 6.357552004618084, 6.357552004618084, 6.357552004618084, 7.507794640198696, 8.531381460516313, 7.20945336562895, 6.845490050944375, 2.321928094887362, 5.554588851677638, 5.554588851677638, 7.531381460516312, 4.087462841250339, 6.700439718141092, 7.066089190457772, 7.0, 5.584962500721156, 4.906890595608519, 4.857980995127572, 5.491853096329675, 5.882643049361842, 4.857980995127572, 5.247927513443585, 4.754887502163468, 6.108524456778169, 7.129283016944966, 7.813781191217037, 5.392317422778761, 5.426264754702098, 6.22881869049588, 5.977279923499917, 5.930737337562887, 5.169925001442312, 4.700439718141092, 4.700439718141092, 8.199672344836364, 8.430452551665532, 7.475733430966398, 7.108524456778169, 7.475733430966398, 6.658211482751795, 6.857980995127572, 5.857980995127572, 5.857980995127572, 5.857980995127572, 5.857980995127572, 7.1799090900149345, 8.214319120800766, 3.807354922057604, 6.442943495848728, 1.584962500721156, 5.643856189774724, 5.643856189774724, 7.348728154231077, null, 6.169925001442312, 6.303780748177103, 6.266786540694901, 6.475733430966398, 4.807354922057604, 5.906890595608519, 5.930737337562887, 6.459431618637297, 6.507794640198696, 5.643856189774724, 5.954196310386875, 7.149747119504682, 7.569855608330948, 8.447083226209653, 6.321928094887363, 6.169925001442312, 6.392317422778761, 6.700439718141092, 5.857980995127572, 5.087462841250339, 5.523561956057013, 5.523561956057013, 8.194756854422248, 8.997179480937621, 8.554588851677638, 7.139551352398794, 7.651051691178929, 7.741466986401147, 7.851749041416057, 6.820178962415188, 6.807354922057604, 6.820178962415188, 6.820178962415188, 7.599912842187128, 8.614709844115207, 4.321928094887363, 7.807354922057604, 2.584962500721156, 7.189824558880018, 7.189824558880018, 7.339850002884624, null, 6.870364719583405, 7.800899899920305, 7.7615512324444795, 4.321928094887363, 3.584962500721156, 3.0, 4.0, 4.0, 4.321928094887363, 3.700439718141092, 3.169925001442312, 5.044394119358453, 5.857980995127572, 5.357552004618084, 3.0, 3.4594316186372973, 4.643856189774724, 3.584962500721156, 2.807354922057604, 2.807354922057604, 3.169925001442312, 3.169925001442312, 6.727920454563199, 6.569855608330948, 5.906890595608519, 5.044394119358453, 5.554588851677638, 4.857980995127572, 4.700439718141092, 3.169925001442312, 3.0, 3.0, 3.0, 5.247927513443585, 6.339850002884624, 4.0, 4.392317422778761, 0.0, 4.584962500721156, 4.584962500721156, 5.357552004618084, null, 3.700439718141092, 3.4594316186372973, 3.321928094887362, 5.78135971352466, 4.0, 3.0, 4.643856189774724, 4.857980995127572, 5.426264754702098, 5.392317422778761, 4.754887502163468, 6.658211482751795, 7.108524456778169, 7.614709844115208, 4.392317422778761, 6.20945336562895, 6.20945336562895, 4.906890595608519, 5.169925001442312, 5.321928094887363, 3.584962500721156, 3.584962500721156, 8.154818109052105, 8.294620748891626, 7.643856189774724, 6.658211482751795, 7.247927513443585, 5.643856189774724, 6.741466986401147, 5.672425341971495, 5.672425341971495, 5.672425341971495, 5.672425341971495, 6.409390936137702, 7.426264754702098, 4.954196310386875, 6.442943495848728, 3.584962500721156, 4.906890595608519, 4.906890595608519, 6.409390936137702, null, 6.22881869049588, 4.807354922057604, 4.807354922057604, 5.754887502163468, 5.20945336562895, 5.321928094887363, 4.807354922057604, 5.807354922057604, 5.321928094887363, 5.754887502163468, 4.392317422778761, 6.714245517666122, 7.20945336562895, 7.426264754702098, 5.554588851677638, 5.044394119358453, 6.169925001442312, 5.491853096329675, 5.672425341971495, 4.754887502163468, 5.087462841250339, 5.087462841250339, 8.581200581924957, 8.820178962415188, 7.857980995127572, 7.129283016944966, 7.499845887083206, 6.584962500721156, 6.794415866350106, 5.78135971352466, 5.754887502163468, 5.754887502163468, 5.727920454563199, 6.6293566200796095, 7.672425341971495, 5.807354922057604, 6.129283016944966, 3.321928094887362, 4.584962500721156, 4.584962500721156, 6.930737337562887, null, 5.906890595608519, 7.312882955284356, 7.294620748891627, 5.832890014164741, 5.285402218862249, 3.807354922057604, 5.044394119358453, 5.727920454563199, 5.0, 5.285402218862249, 4.321928094887363, 6.129283016944966, 7.219168520462161, 7.3750394313469245, 4.906890595608519, 4.392317422778761, 5.643856189774724, 5.857980995127572, 5.930737337562887, 4.584962500721156, 4.643856189774724, 4.643856189774724, 8.169925001442312, 8.643856189774725, 7.6653359171851765, 6.741466986401147, 7.149747119504682, 6.539158811108031, 6.965784284662087, 5.857980995127572, 5.832890014164741, 5.832890014164741, 5.832890014164741, 6.357552004618084, 7.409390936137702, 5.321928094887363, 6.087462841250339, 2.0, 5.0, 5.0, 7.2761244052742375, null, 5.614709844115208, 6.169925001442312, 6.149747119504682, 4.459431618637297, 3.9068905956085187, 3.807354922057604, 3.0, 4.087462841250339, 4.0, 3.584962500721156, 1.0, 4.700439718141092, 5.584962500721156, 5.523561956057013, 1.0, 4.321928094887363, 4.169925001442312, 3.584962500721156, 4.321928094887363, 2.807354922057604, 1.584962500721156, 1.584962500721156, 6.426264754702098, 6.754887502163468, 5.087462841250339, 4.392317422778761, 4.906890595608519, 4.392317422778761, 4.754887502163468, 3.584962500721156, 3.584962500721156, 3.584962500721156, 3.4594316186372973, 4.321928094887363, 5.491853096329675, 4.584962500721156, 4.523561956057013, 1.0, 3.321928094887362, 3.321928094887362, 5.78135971352466, null, 4.0, 2.807354922057604, 2.807354922057604, 4.954196310386875, 4.087462841250339, 4.807354922057604, 5.20945336562895, 4.523561956057013, 4.584962500721156, 5.129283016944966, 4.321928094887363, 5.78135971352466, 7.294620748891627, 7.285402218862249, 5.523561956057013, 4.807354922057604, 5.357552004618084, 6.0, 5.392317422778761, 4.459431618637297, 4.0, 4.0, 8.124121311829187, 8.467605550082997, 7.108524456778169, 5.977279923499917, 6.339850002884624, 5.930737337562887, 6.6865005271832185, 5.614709844115208, 5.584962500721156, 5.584962500721156, 5.554588851677638, 6.6293566200796095, 7.643856189774724, 7.20945336562895, 6.022367813028454, 2.0, 3.700439718141092, 3.700439718141092, 7.257387842692652, null, 5.954196310386875, 6.129283016944966, 6.066089190457772, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 5.491853096329675, 4.087462841250339, 5.129283016944966, 5.087462841250339, 5.321928094887363, 4.643856189774724, 4.754887502163468, 4.169925001442312, 5.754887502163468, 7.118941072723508, 7.357552004618084, 4.700439718141092, 5.0, 5.727920454563199, 5.614709844115208, 4.754887502163468, 4.459431618637297, 4.584962500721156, 4.584962500721156, 7.954196310386875, 8.113742166049189, 7.426264754702098, 6.727920454563199, 6.965784284662087, 6.266786540694901, 6.491853096329675, 5.357552004618084, 5.357552004618084, 5.321928094887363, 5.285402218862249, 6.807354922057604, 7.832890014164741, 4.700439718141092, 6.303780748177103, 4.087462841250339, 5.392317422778761, 5.392317422778761, 7.03342300153745, null, 6.066089190457772, 4.392317422778761, 4.392317422778761, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 4.247927513443585, 3.584962500721156, 3.584962500721156, 4.523561956057013, 3.807354922057604, 4.643856189774724, 4.584962500721156, 3.321928094887362, 5.643856189774724, 6.569855608330948, 7.22881869049588, 4.584962500721156, 5.129283016944966, 5.357552004618084, 4.807354922057604, 4.392317422778761, 3.700439718141092, 3.9068905956085187, 3.9068905956085187, 7.0, 8.113742166049189, 6.643856189774724, 5.700439718141092, 5.882643049361842, 4.857980995127572, 5.807354922057604, 4.643856189774724, 4.584962500721156, 4.584962500721156, 4.584962500721156, 5.523561956057013, 6.569855608330948, 5.584962500721156, 5.523561956057013, 2.807354922057604, 4.643856189774724, 4.643856189774724, 5.727920454563199, 3.169925001442312, 5.285402218862249, 5.20945336562895, 5.20945336562895, 1.0, 3.4594316186372973, 1.0, 2.0, 3.321928094887362, 2.0, 1.584962500721156, 1.584962500721156, 1.0, 3.700439718141092, 2.584962500721156, 5.0, 1.0, 3.321928094887362, 4.584962500721156, null, null, 3.584962500721156, 3.584962500721156, 4.087462841250339, 4.459431618637297, 3.169925001442312, 4.169925001442312, 4.321928094887363, 5.357552004618084, 3.4594316186372973, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.0, 2.584962500721156, 3.700439718141092, 2.0, 2.321928094887362, 1.0, 4.321928094887363, 4.321928094887363, 2.0, null, 2.807354922057604, 6.20945336562895, 6.149747119504682, 4.807354922057604, 3.169925001442312, 3.321928094887362, 3.4594316186372973, 4.169925001442312, 4.584962500721156, 4.0, 2.584962500721156, 5.129283016944966, 6.339850002884624, 5.857980995127572, 3.321928094887362, 4.643856189774724, 4.169925001442312, 5.044394119358453, 4.392317422778761, 0.0, 3.584962500721156, 3.584962500721156, 7.044394119358453, 7.643856189774724, 6.321928094887363, 5.044394119358453, 5.554588851677638, 5.357552004618084, 5.727920454563199, 4.643856189774724, 4.643856189774724, 4.643856189774724, 4.643856189774724, 5.129283016944966, 6.169925001442312, 5.247927513443585, 5.321928094887363, 3.4594316186372973, 4.169925001442312, 4.169925001442312, 6.357552004618084, null, 4.857980995127572, 5.426264754702098, 5.426264754702098, 4.0, 2.807354922057604, 3.0, 2.584962500721156, 3.4594316186372973, 3.807354922057604, 3.700439718141092, 3.169925001442312, 4.392317422778761, 5.523561956057013, 5.754887502163468, 4.169925001442312, 3.807354922057604, 4.247927513443585, 4.087462841250339, 3.0, 3.700439718141092, 2.584962500721156, 2.584962500721156, 6.78135971352466, 7.330916878114617, 5.977279923499917, 4.087462841250339, 5.044394119358453, 4.906890595608519, 5.20945336562895, 4.169925001442312, 4.087462841250339, 4.087462841250339, 4.087462841250339, 4.906890595608519, 6.0, 3.584962500721156, 4.643856189774724, 3.584962500721156, 3.4594316186372973, 3.4594316186372973, 6.20945336562895, 0.0, 4.169925001442312, 3.700439718141092, 3.584962500721156, 5.614709844115208, 3.700439718141092, 5.321928094887363, 5.20945336562895, 5.321928094887363, 5.426264754702098, 4.643856189774724, 4.523561956057013, 6.321928094887363, 6.894817763307944, 7.467605550082998, 5.426264754702098, 5.584962500721156, 5.392317422778761, 5.754887502163468, 5.491853096329675, 4.392317422778761, 4.321928094887363, 4.321928094887363, 7.888743248898259, 8.46352437327118, 7.247927513443585, 6.459431618637297, 6.807354922057604, 6.044394119358453, 6.672425341971495, 5.491853096329675, 5.491853096329675, 5.491853096329675, 5.491853096329675, 6.507794640198696, 7.592457037268081, 4.700439718141092, 5.930737337562887, 1.0, 4.857980995127572, 4.857980995127572, 6.643856189774724, null, 6.087462841250339, 6.108524456778169, 6.0, 4.321928094887363, 4.392317422778761, 4.392317422778761, 4.087462841250339, 4.700439718141092, 4.321928094887363, 4.0, 4.0, 5.672425341971495, 6.714245517666122, 7.044394119358453, 5.169925001442312, 4.169925001442312, 4.906890595608519, 4.954196310386875, 5.0, 3.700439718141092, 4.392317422778761, 4.392317422778761, 7.515699838284043, 7.994353436858858, 6.569855608330948, 6.087462841250339, 6.392317422778761, 5.643856189774724, 6.22881869049588, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.20945336562895, 6.129283016944966, 7.20945336562895, 4.584962500721156, 5.426264754702098, 2.321928094887362, 4.857980995127572, 4.857980995127572, 5.78135971352466, null, 4.643856189774724, 5.977279923499917, 5.954196310386875, 0.0, null, null, null, null, null, 0.0, 0.0, null, null, null, 1.0, 0.0, null, null, null, null, null, null, 1.584962500721156, 2.321928094887362, 2.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, null, 0.0, null, 0.0, 0.0, null, null, null, null, null, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, 1.0, null, null, null, null, null, null, null, 0.0, 2.0, null, null, null, null, 1.0, null, null, null, null, null, 1.0, null, null, 0.0, null, null, 0.0, null, null, null, null, 4.087462841250339, 2.807354922057604, 3.584962500721156, 4.321928094887363, 4.087462841250339, 4.392317422778761, 3.9068905956085187, 2.807354922057604, 4.523561956057013, 6.108524456778169, 6.672425341971495, 3.700439718141092, 3.584962500721156, 4.169925001442312, 4.807354922057604, 4.169925001442312, 2.0, 3.321928094887362, 3.321928094887362, 6.303780748177103, 7.118941072723508, 6.285402218862249, 5.584962500721156, 5.584962500721156, 5.044394119358453, 5.906890595608519, 4.807354922057604, 4.807354922057604, 4.807354922057604, 4.807354922057604, 5.554588851677638, 6.614709844115208, 4.906890595608519, 5.087462841250339, 1.584962500721156, 2.584962500721156, 2.584962500721156, 5.584962500721156, null, 5.20945336562895, 3.169925001442312, 3.169925001442312, 5.700439718141092, 5.0, 5.247927513443585, 5.554588851677638, 5.727920454563199, 5.930737337562887, 5.20945336562895, 4.459431618637297, 6.392317422778761, 7.417852514885898, 8.066089190457772, 5.857980995127572, 5.672425341971495, 5.954196310386875, 6.066089190457772, 5.247927513443585, 4.700439718141092, 4.523561956057013, 4.523561956057013, 8.179909090014934, 8.73809225962049, 7.658211482751795, 6.491853096329675, 6.845490050944375, 6.672425341971495, 7.0, 5.954196310386875, 5.954196310386875, 5.954196310386875, 5.906890595608519, 7.189824558880018, 8.199672344836364, 5.700439718141092, 6.857980995127572, 3.321928094887362, 5.129283016944966, 5.129283016944966, 7.0, null, 6.339850002884624, 6.523561956057013, 6.491853096329675, 4.700439718141092, 4.087462841250339, 4.459431618637297, 4.643856189774724, 4.700439718141092, 4.523561956057013, 3.9068905956085187, 4.0, 5.357552004618084, 6.303780748177103, 6.882643049361842, 4.954196310386875, 4.807354922057604, 4.754887502163468, 4.754887502163468, 5.285402218862249, 4.392317422778761, 3.4594316186372973, 3.4594316186372973, 7.139551352398794, 7.60733031374961, 7.348728154231077, 5.700439718141092, 6.022367813028454, 5.930737337562887, 6.20945336562895, 5.087462841250339, 5.087462841250339, 5.087462841250339, 5.087462841250339, 6.20945336562895, 7.257387842692652, 4.392317422778761, 5.672425341971495, 0.0, 4.906890595608519, 4.906890595608519, 5.727920454563199, null, 5.285402218862249, 3.0, 3.0, null, null, null, null, null, null, null, null, null, 1.584962500721156, 1.0, null, null, null, 1.0, null, null, null, null, 0.0, null, 1.0, 0.0, 0.0, null, 1.0, 0.0, 0.0, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, 0.0, 0.0, 5.584962500721156, 4.0, 4.700439718141092, 4.643856189774724, 5.169925001442312, 5.044394119358453, 4.523561956057013, 4.643856189774724, 5.700439718141092, 6.672425341971495, 6.714245517666122, 5.20945336562895, 5.247927513443585, 5.357552004618084, 4.459431618637297, 5.20945336562895, 4.087462841250339, 4.169925001442312, 4.169925001442312, 7.330916878114617, 7.672425341971495, 6.727920454563199, 6.066089190457772, 6.409390936137702, 6.022367813028454, 6.044394119358453, 4.857980995127572, 4.857980995127572, 4.857980995127572, 4.857980995127572, 6.108524456778169, 7.098032082960526, 5.392317422778761, 5.672425341971495, 2.584962500721156, 4.169925001442312, 4.169925001442312, 6.727920454563199, 0.0, 5.614709844115208, 3.9068905956085187, 3.700439718141092, 4.523561956057013, 3.0, 4.087462841250339, 4.0, 3.700439718141092, 4.459431618637297, 3.700439718141092, 3.169925001442312, 4.906890595608519, 5.727920454563199, 6.303780748177103, 4.643856189774724, 3.584962500721156, 4.807354922057604, 5.0, 4.392317422778761, 4.087462841250339, 3.700439718141092, 3.700439718141092, 6.918863237274595, 7.199672344836364, 6.321928094887363, 5.523561956057013, 5.807354922057604, 5.20945336562895, 5.357552004618084, 4.321928094887363, 4.247927513443585, 4.247927513443585, 4.169925001442312, 5.491853096329675, 6.507794640198696, 4.087462841250339, 5.044394119358453, 2.321928094887362, 4.807354922057604, 4.807354922057604, 6.149747119504682, null, 5.169925001442312, 5.584962500721156, 5.459431618637297, 5.087462841250339, 3.9068905956085187, 3.807354922057604, 4.321928094887363, 4.643856189774724, 4.643856189774724, 4.700439718141092, 4.0, 5.459431618637297, 6.741466986401147, 6.129283016944966, 4.584962500721156, 3.807354922057604, 5.643856189774724, 5.523561956057013, 4.321928094887363, 4.169925001442312, 4.247927513443585, 4.247927513443585, 7.6653359171851765, 8.038918989292302, 7.129283016944966, 5.78135971352466, 6.321928094887363, 5.906890595608519, 6.087462841250339, 5.044394119358453, 5.044394119358453, 5.044394119358453, 5.044394119358453, 5.930737337562887, 6.906890595608519, 5.129283016944966, 5.754887502163468, 0.0, 3.807354922057604, 3.807354922057604, 5.459431618637297, null, 5.247927513443585, 4.169925001442312, 4.087462841250339, 4.584962500721156, 3.700439718141092, 4.321928094887363, 4.700439718141092, 4.584962500721156, 4.169925001442312, 4.459431618637297, 4.643856189774724, 5.727920454563199, 6.539158811108031, 7.357552004618084, 5.0, 4.857980995127572, 5.129283016944966, 5.044394119358453, 4.643856189774724, 4.321928094887363, 4.247927513443585, 4.247927513443585, 7.592457037268081, 7.826548487290915, 6.845490050944375, 5.882643049361842, 6.409390936137702, 5.807354922057604, 5.614709844115208, 4.523561956057013, 4.523561956057013, 4.459431618637297, 4.459431618637297, 6.087462841250339, 7.098032082960526, 3.807354922057604, 5.906890595608519, 1.584962500721156, 4.169925001442312, 4.169925001442312, 6.794415866350106, null, 4.906890595608519, 5.426264754702098, 5.20945336562895, 5.643856189774724, 4.169925001442312, 4.584962500721156, 4.700439718141092, 4.807354922057604, 4.906890595608519, 5.087462841250339, 3.321928094887362, 5.392317422778761, 6.266786540694901, 6.700439718141092, 4.087462841250339, 5.169925001442312, 5.584962500721156, 5.247927513443585, 5.087462841250339, 3.321928094887362, 4.523561956057013, 4.523561956057013, 7.076815597050831, 7.339850002884624, 7.1799090900149345, 5.906890595608519, 6.339850002884624, 5.491853096329675, 5.977279923499917, 4.754887502163468, 4.754887502163468, 4.754887502163468, 4.754887502163468, 6.339850002884624, 7.383704292474052, 2.584962500721156, 5.700439718141092, 1.584962500721156, 5.247927513443585, 5.247927513443585, 5.832890014164741, null, 6.066089190457772, 5.977279923499917, 5.930737337562887, 4.392317422778761, 4.169925001442312, 4.321928094887363, 4.906890595608519, 4.700439718141092, 5.0, 5.20945336562895, 2.807354922057604, 5.754887502163468, 6.303780748177103, 6.442943495848728, 5.20945336562895, 4.087462841250339, 5.584962500721156, 5.357552004618084, 5.129283016944966, 4.321928094887363, 4.169925001442312, 4.169925001442312, 7.400879436282184, 7.622051819456376, 6.491853096329675, 5.807354922057604, 6.392317422778761, 6.066089190457772, 6.20945336562895, 4.954196310386875, 4.954196310386875, 4.954196310386875, 4.954196310386875, 5.906890595608519, 6.977279923499917, 5.0, 4.954196310386875, 0.0, 4.169925001442312, 4.169925001442312, 5.554588851677638, null, 5.426264754702098, 5.523561956057013, 5.426264754702098, 2.0, null, null, null, null, null, null, null, 1.0, 2.584962500721156, 0.0, 0.0, 1.0, null, 0.0, null, 2.0, 0.0, 0.0, 2.321928094887362, 4.392317422778761, 0.0, null, 0.0, null, 0.0, null, null, null, null, 1.584962500721156, 3.169925001442312, 1.0, null, 1.0, 1.0, 1.0, 3.321928094887362, null, null, 0.0, 0.0, 6.6293566200796095, 4.700439718141092, 6.044394119358453, 6.129283016944966, 6.321928094887363, 6.247927513443585, 5.285402218862249, 5.169925001442312, 6.807354922057604, 7.108524456778169, 8.539158811108031, 6.614709844115208, 5.491853096329675, 6.6293566200796095, 6.6293566200796095, 6.129283016944966, 5.129283016944966, 5.614709844115208, 5.614709844115208, 7.851749041416057, 8.189824558880018, 8.164906926675688, 7.348728154231077, 7.592457037268081, 7.285402218862249, 8.139551352398794, 7.05528243550119, 7.05528243550119, 7.05528243550119, 7.044394119358453, 7.700439718141092, 8.734709620225837, 4.523561956057013, 7.357552004618084, 2.0, 6.285402218862249, 6.285402218862249, 7.312882955284356, null, 6.714245517666122, 6.870364719583405, 6.870364719583405, 5.20945336562895, 4.700439718141092, 4.857980995127572, 5.169925001442312, 5.285402218862249, 4.807354922057604, 5.044394119358453, 4.643856189774724, 5.906890595608519, 6.714245517666122, 7.60733031374961, 5.285402218862249, 5.491853096329675, 5.857980995127572, 5.357552004618084, 5.285402218862249, 4.0, 4.459431618637297, 4.459431618637297, 7.569855608330948, 8.0, 7.451211111832329, 6.78135971352466, 7.0, 6.087462841250339, 6.78135971352466, 5.614709844115208, 5.614709844115208, 5.614709844115208, 5.584962500721156, 6.857980995127572, 7.924812503605781, 4.857980995127572, 5.807354922057604, 2.807354922057604, 6.22881869049588, 6.22881869049588, 6.672425341971495, null, 5.832890014164741, 7.011227255423254, 7.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 4.523561956057013, 4.754887502163468, 3.9068905956085187, 4.700439718141092, 4.807354922057604, 4.857980995127572, 4.321928094887363, 3.169925001442312, 5.426264754702098, 6.768184324776926, 6.870364719583405, 4.807354922057604, 5.247927513443585, 5.357552004618084, 4.807354922057604, 4.523561956057013, 3.9068905956085187, 4.169925001442312, 4.169925001442312, 7.515699838284043, 7.864186144654281, 6.977279923499917, 5.857980995127572, 6.22881869049588, 5.754887502163468, 6.247927513443585, 5.129283016944966, 5.087462841250339, 5.087462841250339, 5.0, 6.20945336562895, 7.266786540694901, 4.392317422778761, 5.285402218862249, 2.0, 4.459431618637297, 4.459431618637297, 6.700439718141092, null, 5.614709844115208, 5.727920454563199, 5.754887502163468, null, null, null, null, null, null, null, null, 1.0, 0.0, 1.0, null, null, 0.0, null, null, null, null, null, 0.0, 1.0, null, null, null, 0.0, 1.0, null, null, null, null, null, null, null, null, null, null, null, 1.0, null, null, 0.0, 0.0, 5.882643049361842, 3.9068905956085187, 4.954196310386875, 5.727920454563199, 5.700439718141092, 5.832890014164741, 4.700439718141092, 4.906890595608519, 6.845490050944375, 7.569855608330948, 8.344295907915816, 6.442943495848728, 5.857980995127572, 6.409390936137702, 6.459431618637297, 6.044394119358453, 5.285402218862249, 5.0, 5.0, 8.005624549193879, 8.791162888555018, 8.149747119504681, 7.219168520462161, 7.499845887083206, 7.044394119358453, 7.546894459887636, 6.475733430966398, 6.459431618637297, 6.459431618637297, 6.459431618637297, 7.339850002884624, 8.370687406807217, 5.643856189774724, 6.965784284662087, 3.321928094887362, 5.78135971352466, 5.78135971352466, 8.238404739325079, null, 6.442943495848728, 6.392317422778761, 6.357552004618084, 5.321928094887363, 3.700439718141092, 5.087462841250339, 4.459431618637297, 4.459431618637297, 3.321928094887362, 4.523561956057013, 3.321928094887362, 5.392317422778761, 5.491853096329675, 6.357552004618084, 5.321928094887363, 4.0, 5.554588851677638, 5.169925001442312, 4.700439718141092, 4.169925001442312, 4.321928094887363, 4.321928094887363, 6.768184324776926, 7.6293566200796095, 6.6293566200796095, 5.857980995127572, 6.247927513443585, 5.700439718141092, 6.426264754702098, 5.392317422778761, 5.392317422778761, 5.392317422778761, 5.392317422778761, 6.108524456778169, 7.139551352398794, 4.169925001442312, 5.459431618637297, 2.0, 3.807354922057604, 3.807354922057604, 5.857980995127572, null, 5.0, 5.554588851677638, 5.491853096329675, 5.832890014164741, 4.169925001442312, 4.643856189774724, 5.129283016944966, 5.584962500721156, 5.392317422778761, 4.0, 4.169925001442312, 5.857980995127572, 6.523561956057013, 7.554588851677638, 5.727920454563199, 5.247927513443585, 6.189824558880018, 5.584962500721156, 5.672425341971495, 4.169925001442312, 4.807354922057604, 4.807354922057604, 7.599912842187128, 8.113742166049189, 7.1799090900149345, 6.409390936137702, 6.882643049361842, 6.22881869049588, 6.94251450533924, 5.832890014164741, 5.832890014164741, 5.832890014164741, 5.807354922057604, 6.554588851677638, 7.569855608330948, 4.321928094887363, 5.906890595608519, 2.321928094887362, 5.321928094887363, 5.321928094887363, 6.569855608330948, null, 5.832890014164741, 5.807354922057604, 5.78135971352466, 1.0, 0.0, null, 0.0, 1.0, 0.0, 1.0, 0.0, 1.584962500721156, 2.584962500721156, 0.0, null, 2.321928094887362, 1.584962500721156, 0.0, 1.0, null, null, null, 3.584962500721156, 3.700439718141092, 2.807354922057604, 1.584962500721156, 1.584962500721156, 1.0, 2.807354922057604, 1.0, 0.0, 0.0, 1.584962500721156, 1.584962500721156, 3.4594316186372973, null, 3.169925001442312, 0.0, null, null, 3.321928094887362, null, null, null, null, 4.321928094887363, 4.0, 3.807354922057604, 4.087462841250339, 4.0, 4.643856189774724, 3.584962500721156, 2.0, 4.459431618637297, 5.129283016944966, 6.321928094887363, 4.321928094887363, 3.584962500721156, 4.906890595608519, 4.459431618637297, 4.459431618637297, 3.584962500721156, 4.392317422778761, 4.392317422778761, 6.599912842187128, 7.475733430966398, 6.108524456778169, 5.129283016944966, 5.392317422778761, 5.392317422778761, 5.459431618637297, 4.523561956057013, 4.523561956057013, 4.523561956057013, 4.523561956057013, 5.754887502163468, 6.794415866350106, 4.247927513443585, 4.954196310386875, 2.321928094887362, 4.0, 4.0, 6.149747119504682, null, 4.857980995127572, 5.807354922057604, 5.807354922057604, 4.459431618637297, 3.321928094887362, 4.906890595608519, 4.321928094887363, 4.459431618637297, 4.857980995127572, 3.807354922057604, 2.584962500721156, 5.20945336562895, 5.930737337562887, 7.011227255423254, 4.700439718141092, 4.584962500721156, 5.169925001442312, 4.643856189774724, 4.807354922057604, 4.321928094887363, 3.9068905956085187, 3.9068905956085187, 7.0, 7.400879436282184, 6.599912842187128, 5.832890014164741, 6.20945336562895, 5.491853096329675, 5.906890595608519, 4.857980995127572, 4.857980995127572, 4.857980995127572, 4.807354922057604, 6.0, 7.108524456778169, 4.700439718141092, 5.0, 3.169925001442312, 4.321928094887363, 4.321928094887363, 5.930737337562887, null, 5.78135971352466, 5.523561956057013, 5.523561956057013, 1.584962500721156, null, null, 1.0, 0.0, 2.0, null, 2.0, 0.0, 3.4594316186372973, 2.584962500721156, null, 1.584962500721156, 1.584962500721156, 0.0, 2.584962500721156, 0.0, null, null, 4.0, 5.169925001442312, 2.0, 1.584962500721156, 1.584962500721156, 2.807354922057604, 2.321928094887362, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 2.584962500721156, 1.0, 1.0, 1.584962500721156, 1.0, 1.0, 1.0, null, 2.584962500721156, 0.0, 0.0, 3.321928094887362, 2.584962500721156, 1.0, 3.4594316186372973, 3.0, 3.807354922057604, 3.169925001442312, 0.0, 4.247927513443585, 5.357552004618084, 5.392317422778761, 3.807354922057604, 4.087462841250339, 4.0, 3.700439718141092, 3.584962500721156, 2.321928094887362, 1.584962500721156, 1.584962500721156, 6.189824558880018, 6.700439718141092, 5.0, 4.0, 4.169925001442312, 4.459431618637297, 4.169925001442312, 2.807354922057604, 2.807354922057604, 2.807354922057604, 2.807354922057604, 4.087462841250339, 5.247927513443585, 3.584962500721156, 3.4594316186372973, 2.807354922057604, 2.584962500721156, 2.584962500721156, 5.321928094887363, null, 3.807354922057604, 4.0, 4.0, 5.643856189774724, 3.169925001442312, 4.0, 4.906890595608519, 5.754887502163468, 5.672425341971495, 5.392317422778761, 4.392317422778761, 6.108524456778169, 7.118941072723508, 7.876516946564999, 5.584962500721156, 5.087462841250339, 5.727920454563199, 5.857980995127572, 6.087462841250339, 5.044394119358453, 5.044394119358453, 5.044394119358453, 7.754887502163468, 8.164906926675688, 7.219168520462161, 6.539158811108031, 6.727920454563199, 6.539158811108031, 7.118941072723508, 6.066089190457772, 6.044394119358453, 6.044394119358453, 6.044394119358453, 6.554588851677638, 7.60733031374961, 5.700439718141092, 5.977279923499917, 3.169925001442312, 5.700439718141092, 5.700439718141092, 6.700439718141092, null, 6.129283016944966, 3.4594316186372973, 3.321928094887362, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 1.584962500721156, null, 0.0, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 6.266786540694901, 4.643856189774724, 5.247927513443585, 5.78135971352466, 5.321928094887363, 5.523561956057013, 5.129283016944966, 4.700439718141092, 6.392317422778761, 7.139551352398794, 7.807354922057604, 5.857980995127572, 5.857980995127572, 6.392317422778761, 6.108524456778169, 5.977279923499917, 5.392317422778761, 4.857980995127572, 4.857980995127572, 7.7481928495894605, 8.280770770130603, 7.554588851677638, 6.906890595608519, 7.247927513443585, 6.643856189774724, 7.348728154231077, 6.247927513443585, 6.22881869049588, 6.22881869049588, 6.20945336562895, 7.189824558880018, 8.194756854422248, 4.857980995127572, 6.78135971352466, 2.807354922057604, 5.523561956057013, 5.523561956057013, 6.882643049361842, 3.700439718141092, 6.741466986401147, 7.3750394313469245, 7.357552004618084, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.0, null, null, null, null, null, null, null, null, 6.6865005271832185, 4.807354922057604, 5.906890595608519, 6.569855608330948, 6.539158811108031, 6.108524456778169, 6.108524456778169, 5.087462841250339, 6.918863237274595, 7.734709620225838, 8.588714635582264, 6.754887502163468, 5.954196310386875, 6.700439718141092, 6.820178962415188, 6.599912842187128, 5.459431618637297, 5.554588851677638, 5.554588851677638, 8.584962500721156, 9.005624549193879, 8.224001674198105, 7.366322214245816, 7.636624620543649, 6.965784284662087, 7.971543553950772, 6.918863237274595, 6.894817763307944, 6.894817763307944, 6.882643049361842, 7.7481928495894605, 8.76487159073609, 6.266786540694901, 6.94251450533924, 3.584962500721156, 6.303780748177103, 6.321928094887363, 7.721099188707185, null, 6.3750394313469245, 5.392317422778761, 5.321928094887363, 6.714245517666122, 5.285402218862249, 5.857980995127572, 5.700439718141092, 6.491853096329675, 6.442943495848728, 5.614709844115208, 5.491853096329675, 6.930737337562887, 7.700439718141092, 8.285402218862249, 5.832890014164741, 6.108524456778169, 6.820178962415188, 6.475733430966398, 6.459431618637297, 5.459431618637297, 5.584962500721156, 5.584962500721156, 8.78135971352466, 8.794415866350105, 8.228818690495881, 7.499845887083206, 8.022367813028454, 7.357552004618084, 7.6865005271832185, 6.727920454563199, 6.714245517666122, 6.714245517666122, 6.700439718141092, 7.357552004618084, 8.375039431346925, 5.392317422778761, 6.870364719583405, 4.087462841250339, 5.977279923499917, 5.977279923499917, 7.22881869049588, null, 6.672425341971495, 7.1799090900149345, 7.118941072723508, 5.554588851677638, 4.169925001442312, 4.584962500721156, 4.584962500721156, 5.357552004618084, 4.643856189774724, 4.392317422778761, 4.321928094887363, 5.523561956057013, 6.539158811108031, 7.434628227636725, 5.169925001442312, 5.044394119358453, 5.832890014164741, 5.643856189774724, 4.584962500721156, 4.857980995127572, 4.754887502163468, 4.754887502163468, 7.870364719583405, 8.396604781181859, 7.219168520462161, 6.700439718141092, 6.965784284662087, 6.339850002884624, 6.965784284662087, 5.882643049361842, 5.832890014164741, 5.832890014164741, 5.832890014164741, 6.569855608330948, 7.651051691178929, 4.700439718141092, 6.0, 2.584962500721156, 4.807354922057604, 4.807354922057604, 6.554588851677638, null, 5.727920454563199, 4.087462841250339, 4.087462841250339, 4.754887502163468, 3.169925001442312, 3.321928094887362, 3.584962500721156, 5.044394119358453, 5.0, 4.321928094887363, 3.700439718141092, 5.321928094887363, 6.475733430966398, 6.426264754702098, 5.321928094887363, 4.807354922057604, 5.247927513443585, 5.0, 4.807354922057604, 4.700439718141092, 4.087462841250339, 4.087462841250339, 7.721099188707185, 7.845490050944375, 6.906890595608519, 5.930737337562887, 6.523561956057013, 5.672425341971495, 5.754887502163468, 4.700439718141092, 4.700439718141092, 4.700439718141092, 4.700439718141092, 5.129283016944966, 6.303780748177103, 3.807354922057604, 5.247927513443585, 2.0, 4.392317422778761, 4.459431618637297, 6.303780748177103, null, 5.247927513443585, 6.066089190457772, 6.022367813028454, 7.339850002884624, 5.169925001442312, 6.700439718141092, 6.643856189774724, 7.285402218862249, 7.2384047393250786, 6.569855608330948, 6.714245517666122, 7.159871336778389, 8.321928094887362, 8.851749041416058, 7.266786540694901, 7.894817763307944, 7.2384047393250786, 7.434628227636725, 7.400879436282184, 6.392317422778761, 6.442943495848728, 6.442943495848728, 8.038918989292302, 8.977279923499916, 9.149747119504681, 7.426264754702098, 7.813781191217037, 7.936637939002571, 8.348728154231077, 7.303780748177103, 7.294620748891627, 7.294620748891627, 7.285402218862249, 8.076815597050832, 9.079484783826816, 6.569855608330948, 7.754887502163468, 3.0, 7.087462841250339, 7.087462841250339, 8.625708843064466, null, 7.022367813028454, 7.303780748177103, 7.266786540694901, 2.584962500721156, null, null, null, 1.0, 1.0, 2.807354922057604, 0.0, 3.169925001442312, 4.459431618637297, 2.584962500721156, 2.584962500721156, 2.807354922057604, 2.321928094887362, 0.0, 2.0, null, null, null, 5.930737337562887, 6.714245517666122, 4.247927513443585, 2.807354922057604, 3.584962500721156, 2.584962500721156, 3.4594316186372973, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.321928094887362, 1.584962500721156, 2.807354922057604, 3.0, 1.0, null, 1.0, 1.0, 4.459431618637297, null, 2.0, 1.0, 1.0, 2.0, 1.584962500721156, null, 0.0, null, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.807354922057604, 4.247927513443585, 3.0, null, 2.584962500721156, null, 1.584962500721156, 1.584962500721156, 0.0, 0.0, 0.0, 3.169925001442312, 5.321928094887363, 3.807354922057604, 2.807354922057604, 3.584962500721156, 1.584962500721156, 2.0, 1.0, 1.0, 1.0, 1.0, 2.807354922057604, 3.700439718141092, 1.0, 2.584962500721156, 0.0, 2.0, 2.0, 3.0, null, null, 3.321928094887362, 3.169925001442312, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, 0.0, null, null, null, null, 0.0, 1.0, null, 0.0, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 0.0, 0.0, 4.700439718141092, 4.0, 4.169925001442312, 4.247927513443585, 4.392317422778761, 4.321928094887363, 4.321928094887363, 3.4594316186372973, 5.044394119358453, 6.459431618637297, 6.832890014164741, 4.807354922057604, 5.087462841250339, 5.285402218862249, 5.087462841250339, 5.247927513443585, 3.807354922057604, 3.4594316186372973, 3.4594316186372973, 6.977279923499917, 7.6293566200796095, 6.894817763307944, 5.554588851677638, 6.044394119358453, 5.426264754702098, 6.149747119504682, 5.087462841250339, 5.044394119358453, 5.044394119358453, 5.044394119358453, 6.108524456778169, 7.199672344836364, 4.0, 5.169925001442312, 2.321928094887362, 4.0, 4.0, 6.169925001442312, 4.169925001442312, 4.523561956057013, 5.459431618637297, 5.459431618637297, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, null, null, null, null, null, null, null, null, null, null, 5.169925001442312, 3.700439718141092, 4.754887502163468, 5.087462841250339, 4.857980995127572, 3.700439718141092, 4.0, 3.9068905956085187, 5.426264754702098, 5.832890014164741, 6.741466986401147, 5.169925001442312, 4.857980995127572, 5.087462841250339, 4.700439718141092, 5.491853096329675, 4.643856189774724, 3.584962500721156, 3.584962500721156, 6.3750394313469245, 6.643856189774724, 6.741466986401147, 5.882643049361842, 6.129283016944966, 6.149747119504682, 6.426264754702098, 5.357552004618084, 5.357552004618084, 5.357552004618084, 5.357552004618084, 6.523561956057013, 7.531381460516312, 3.0, 5.727920454563199, 2.0, 3.807354922057604, 3.807354922057604, 5.426264754702098, null, 4.754887502163468, 3.700439718141092, 3.700439718141092, 5.392317422778761, 3.9068905956085187, 4.584962500721156, 5.392317422778761, 5.554588851677638, 4.700439718141092, 4.087462841250339, 3.9068905956085187, 6.0, 6.321928094887363, 7.515699838284043, 4.0, 5.321928094887363, 5.392317422778761, 5.321928094887363, 5.643856189774724, 4.247927513443585, 4.247927513443585, 4.247927513443585, 6.754887502163468, 7.199672344836364, 7.3750394313469245, 6.044394119358453, 6.321928094887363, 5.700439718141092, 6.614709844115208, 5.554588851677638, 5.491853096329675, 5.491853096329675, 5.491853096329675, 6.768184324776926, 7.813781191217037, 4.0, 5.754887502163468, 1.0, 5.0, 5.0, 6.426264754702098, null, 6.108524456778169, 5.78135971352466, 5.78135971352466, 6.129283016944966, 4.247927513443585, 5.672425341971495, 5.614709844115208, 6.20945336562895, 5.614709844115208, 5.321928094887363, 4.643856189774724, 6.22881869049588, 6.189824558880018, 8.194756854422248, 6.321928094887363, 5.832890014164741, 6.507794640198696, 6.303780748177103, 6.584962500721156, 5.087462841250339, 4.906890595608519, 4.906890595608519, 6.965784284662087, 7.6865005271832185, 7.787902559391432, 6.918863237274595, 7.20945336562895, 6.539158811108031, 7.554588851677638, 6.491853096329675, 6.491853096329675, 6.491853096329675, 6.491853096329675, 7.467605550082998, 8.491853096329674, 5.0, 6.658211482751795, 4.0, 5.247927513443585, 5.247927513443585, 6.044394119358453, null, 7.044394119358453, 6.820178962415188, 6.754887502163468, 5.285402218862249, 4.392317422778761, 4.807354922057604, 5.0, 5.554588851677638, 4.906890595608519, 4.584962500721156, 4.0, 6.022367813028454, 4.857980995127572, 7.392317422778761, 5.459431618637297, 4.584962500721156, 5.807354922057604, 5.357552004618084, 5.807354922057604, 4.087462841250339, 4.321928094887363, 4.321928094887363, 6.894817763307944, 6.894817763307944, 7.451211111832329, 6.303780748177103, 6.768184324776926, 6.022367813028454, 6.977279923499917, 5.832890014164741, 5.832890014164741, 5.832890014164741, 5.832890014164741, 6.845490050944375, 7.851749041416057, 4.321928094887363, 6.442943495848728, 2.321928094887362, 4.906890595608519, 4.906890595608519, 5.954196310386875, 1.0, 6.22881869049588, 6.169925001442312, 6.189824558880018, 5.087462841250339, 4.321928094887363, 4.459431618637297, 4.906890595608519, 4.906890595608519, 5.129283016944966, 4.584962500721156, 3.584962500721156, 5.247927513443585, 4.954196310386875, 6.870364719583405, 5.169925001442312, 5.169925001442312, 5.727920454563199, 5.523561956057013, 5.321928094887363, 3.9068905956085187, 4.523561956057013, 4.523561956057013, 6.087462841250339, 6.857980995127572, 6.94251450533924, 6.066089190457772, 6.321928094887363, 6.266786540694901, 6.491853096329675, 5.357552004618084, 5.357552004618084, 5.357552004618084, 5.357552004618084, 6.108524456778169, 7.159871336778389, 3.584962500721156, 6.108524456778169, 2.321928094887362, 4.321928094887363, 4.321928094887363, 4.857980995127572, null, 6.0, 5.491853096329675, 5.426264754702098, 4.459431618637297, 4.087462841250339, 5.169925001442312, 4.700439718141092, 5.285402218862249, 4.169925001442312, 4.169925001442312, 2.584962500721156, 4.087462841250339, 5.20945336562895, 6.285402218862249, 4.321928094887363, 3.321928094887362, 4.169925001442312, 4.954196310386875, 6.303780748177103, 3.584962500721156, 3.807354922057604, 3.807354922057604, 5.584962500721156, 6.087462841250339, 6.149747119504682, 5.044394119358453, 5.584962500721156, 5.78135971352466, 5.491853096329675, 4.523561956057013, 4.523561956057013, 4.523561956057013, 4.459431618637297, 6.714245517666122, 7.700439718141092, 2.0, 4.700439718141092, 2.0, 5.0, 5.0, 4.700439718141092, null, 4.321928094887363, 5.643856189774724, 5.554588851677638, 5.78135971352466, 4.0, 4.321928094887363, 4.857980995127572, 5.614709844115208, 4.321928094887363, 4.584962500721156, 3.700439718141092, 5.584962500721156, 5.807354922057604, 7.539158811108031, 5.357552004618084, 5.392317422778761, 5.700439718141092, 5.20945336562895, 5.087462841250339, 4.857980995127572, 4.459431618637297, 4.459431618637297, 6.523561956057013, 7.149747119504682, 6.6865005271832185, 6.189824558880018, 6.409390936137702, 5.832890014164741, 6.845490050944375, 5.807354922057604, 5.78135971352466, 5.78135971352466, 5.78135971352466, 6.523561956057013, 7.539158811108031, 3.807354922057604, 6.285402218862249, 2.0, 5.20945336562895, 5.20945336562895, 6.108524456778169, null, 6.022367813028454, 5.554588851677638, 5.523561956057013, 6.189824558880018, 4.857980995127572, 5.491853096329675, 5.584962500721156, 6.339850002884624, 5.857980995127572, 5.614709844115208, 5.321928094887363, 6.108524456778169, 6.22881869049588, 8.060695931687555, 5.321928094887363, 6.066089190457772, 6.442943495848728, 6.507794640198696, 6.149747119504682, 5.700439718141092, 5.357552004618084, 5.357552004618084, 7.321928094887363, 7.491853096329675, 7.7481928495894605, 7.087462841250339, 7.475733430966398, 7.05528243550119, 7.392317422778761, 6.392317422778761, 6.3750394313469245, 6.3750394313469245, 6.3750394313469245, 7.409390936137702, 8.426264754702098, 4.906890595608519, 6.918863237274595, 2.0, 6.0, 6.0, 5.906890595608519, null, 6.584962500721156, 7.507794640198696, 7.434628227636725, 0.0, null, 0.0, null, null, null, null, null, null, null, 2.0, null, null, 0.0, null, null, null, null, null, 1.0, 2.321928094887362, null, 1.0, 1.584962500721156, null, 0.0, null, null, null, null, null, null, null, 2.0, null, null, null, null, null, null, 0.0, 0.0, 5.426264754702098, 4.247927513443585, 4.807354922057604, 5.044394119358453, 5.20945336562895, 4.807354922057604, 4.700439718141092, 3.584962500721156, 5.584962500721156, 5.700439718141092, 7.366322214245816, 5.392317422778761, 5.392317422778761, 5.672425341971495, 5.357552004618084, 6.0, 4.906890595608519, 4.169925001442312, 4.169925001442312, 6.727920454563199, 7.066089190457772, 6.906890595608519, 6.189824558880018, 6.491853096329675, 6.491853096329675, 6.6293566200796095, 5.523561956057013, 5.523561956057013, 5.523561956057013, 5.523561956057013, 6.643856189774724, 7.651051691178929, 4.807354922057604, 5.426264754702098, 2.0, 5.523561956057013, 5.523561956057013, 5.977279923499917, null, 6.169925001442312, 5.977279923499917, 5.930737337562887, 4.643856189774724, 3.9068905956085187, 4.0, 4.459431618637297, 4.321928094887363, 3.807354922057604, 3.321928094887362, 3.807354922057604, 4.523561956057013, 5.044394119358453, 6.539158811108031, 4.523561956057013, 4.523561956057013, 4.643856189774724, 5.087462841250339, 4.321928094887363, 3.584962500721156, 4.459431618637297, 4.459431618637297, 6.189824558880018, 6.149747119504682, 6.303780748177103, 5.523561956057013, 5.672425341971495, 5.584962500721156, 5.78135971352466, 4.700439718141092, 4.700439718141092, 4.700439718141092, 4.700439718141092, 5.832890014164741, 6.857980995127572, 4.459431618637297, 5.20945336562895, 2.0, 4.459431618637297, 4.459431618637297, 4.700439718141092, null, 5.554588851677638, 6.149747119504682, 6.087462841250339, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 1.0, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 5.523561956057013, 3.807354922057604, 4.392317422778761, 4.0, 4.523561956057013, 4.392317422778761, 3.321928094887362, 3.584962500721156, 5.584962500721156, 5.044394119358453, 6.918863237274595, 4.700439718141092, 4.857980995127572, 4.643856189774724, 5.0, 5.0, 4.247927513443585, 3.4594316186372973, 3.4594316186372973, 5.643856189774724, 6.554588851677638, 6.523561956057013, 5.044394119358453, 5.357552004618084, 5.832890014164741, 6.266786540694901, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.20945336562895, 6.169925001442312, 7.139551352398794, 3.0, 5.584962500721156, 1.0, 4.906890595608519, 4.906890595608519, 5.321928094887363, 2.321928094887362, 4.807354922057604, 5.807354922057604, 5.754887502163468, 5.977279923499917, 4.523561956057013, 5.554588851677638, 5.087462841250339, 5.614709844115208, 5.392317422778761, 5.321928094887363, 4.643856189774724, 5.672425341971495, 6.169925001442312, 7.768184324776926, 5.523561956057013, 5.169925001442312, 5.857980995127572, 6.129283016944966, 6.339850002884624, 5.247927513443585, 4.807354922057604, 4.807354922057604, 7.357552004618084, 7.285402218862249, 7.643856189774724, 6.643856189774724, 7.011227255423254, 6.754887502163468, 7.592457037268081, 6.6293566200796095, 6.599912842187128, 6.599912842187128, 6.599912842187128, 7.066089190457772, 8.087462841250339, 4.523561956057013, 6.442943495848728, 2.584962500721156, 6.169925001442312, 6.169925001442312, 5.954196310386875, null, 6.044394119358453, 4.643856189774724, 4.584962500721156, 5.643856189774724, 4.247927513443585, 4.906890595608519, 5.643856189774724, 5.78135971352466, 5.523561956057013, 5.491853096329675, 4.169925001442312, 6.087462841250339, 6.169925001442312, 7.948367231584678, 5.426264754702098, 5.459431618637297, 5.78135971352466, 6.266786540694901, 6.392317422778761, 5.087462841250339, 4.584962500721156, 4.584962500721156, 7.022367813028454, 7.383704292474052, 7.614709844115208, 6.672425341971495, 6.9886846867721655, 6.392317422778761, 7.554588851677638, 6.491853096329675, 6.491853096329675, 6.491853096329675, 6.491853096329675, 7.118941072723508, 8.139551352398794, 3.584962500721156, 6.523561956057013, 3.169925001442312, 5.643856189774724, 5.643856189774724, 6.044394119358453, null, 6.409390936137702, 6.247927513443585, 6.22881869049588, 6.554588851677638, 5.285402218862249, 5.807354922057604, 6.108524456778169, 6.768184324776926, 6.149747119504682, 5.930737337562887, 5.0, 7.1799090900149345, 6.507794640198696, 8.471675214392045, 6.303780748177103, 6.475733430966398, 7.05528243550119, 6.507794640198696, 6.614709844115208, 5.78135971352466, 5.882643049361842, 5.882643049361842, 7.820178962415188, 8.118941072723507, 8.400879436282183, 7.459431618637297, 7.924812503605781, 7.303780748177103, 7.826548487290915, 6.832890014164741, 6.820178962415188, 6.820178962415188, 6.807354922057604, 7.832890014164741, 8.876516946565, 4.584962500721156, 7.169925001442312, 3.4594316186372973, 6.321928094887363, 6.321928094887363, 6.459431618637297, null, 6.658211482751795, 7.741466986401147, 7.6653359171851765, 5.672425341971495, 4.0, 4.857980995127572, 5.20945336562895, 5.807354922057604, 4.754887502163468, 5.20945336562895, 4.321928094887363, 5.727920454563199, 6.0, 7.312882955284356, 5.614709844115208, 5.129283016944966, 5.426264754702098, 5.285402218862249, 5.832890014164741, 5.129283016944966, 5.087462841250339, 5.087462841250339, 6.9886846867721655, 7.011227255423254, 7.098032082960526, 6.392317422778761, 6.78135971352466, 6.459431618637297, 6.643856189774724, 5.584962500721156, 5.554588851677638, 5.554588851677638, 5.554588851677638, 6.794415866350106, 7.800899899920305, 4.0, 6.3750394313469245, 2.0, 5.129283016944966, 5.129283016944966, 5.554588851677638, null, 5.584962500721156, 4.700439718141092, 4.700439718141092, 2.321928094887362, 2.0, null, 3.169925001442312, 2.584962500721156, 3.321928094887362, 2.321928094887362, 1.0, 3.169925001442312, 3.0, 5.129283016944966, 3.169925001442312, 2.807354922057604, 3.321928094887362, 3.4594316186372973, 3.9068905956085187, 1.0, 2.321928094887362, 2.321928094887362, 4.087462841250339, 5.491853096329675, 4.906890595608519, 4.392317422778761, 4.754887502163468, 3.169925001442312, 4.584962500721156, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 3.321928094887362, 4.584962500721156, 3.0, 2.584962500721156, 1.584962500721156, 2.584962500721156, 2.584962500721156, 2.807354922057604, null, 3.321928094887362, 3.0, 3.0, 5.930737337562887, 4.754887502163468, 5.857980995127572, 5.906890595608519, 6.357552004618084, 6.426264754702098, 4.906890595608519, 5.426264754702098, 6.741466986401147, 6.426264754702098, 8.204571144249204, 5.930737337562887, 6.149747119504682, 6.459431618637297, 6.459431618637297, 6.266786540694901, 6.087462841250339, 5.247927513443585, 5.247927513443585, 7.636624620543649, 7.948367231584678, 7.851749041416057, 7.189824558880018, 7.6865005271832185, 7.383704292474052, 7.894817763307944, 6.870364719583405, 6.870364719583405, 6.870364719583405, 6.870364719583405, 7.876516946564999, 8.909893083770042, 4.523561956057013, 7.20945336562895, 3.0, 6.087462841250339, 6.108524456778169, 5.977279923499917, null, 6.523561956057013, 6.741466986401147, 6.727920454563199, 4.700439718141092, 3.9068905956085187, 3.584962500721156, 3.584962500721156, 4.0, 3.9068905956085187, 4.169925001442312, 2.807354922057604, 4.523561956057013, 5.247927513443585, 6.6293566200796095, 4.392317422778761, 4.0, 4.523561956057013, 4.584962500721156, 4.169925001442312, 2.807354922057604, 3.584962500721156, 3.584962500721156, 6.087462841250339, 5.78135971352466, 6.087462841250339, 5.321928094887363, 5.584962500721156, 5.247927513443585, 5.882643049361842, 4.857980995127572, 4.857980995127572, 4.857980995127572, 4.807354922057604, 5.321928094887363, 6.3750394313469245, 2.584962500721156, 5.129283016944966, 1.584962500721156, 4.321928094887363, 4.321928094887363, 5.584962500721156, null, 5.459431618637297, 3.584962500721156, 3.4594316186372973, null, null, null, 0.0, null, null, null, null, null, null, null, 1.0, null, null, null, null, null, 0.0, 0.0, null, null, 1.0, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 4.754887502163468, 3.700439718141092, 4.807354922057604, 4.643856189774724, 4.906890595608519, 4.247927513443585, 4.0, 3.9068905956085187, 5.087462841250339, 5.459431618637297, 6.918863237274595, 4.700439718141092, 5.169925001442312, 4.954196310386875, 4.857980995127572, 5.0, 3.584962500721156, 3.4594316186372973, 3.4594316186372973, 6.087462841250339, 6.339850002884624, 6.820178962415188, 5.554588851677638, 5.807354922057604, 5.554588851677638, 6.149747119504682, 5.044394119358453, 5.044394119358453, 5.044394119358453, 5.044394119358453, 6.022367813028454, 7.05528243550119, 3.584962500721156, 5.20945336562895, 0.0, 4.906890595608519, 4.906890595608519, 5.672425341971495, null, 5.807354922057604, 5.643856189774724, 5.614709844115208, 5.614709844115208, 3.584962500721156, 5.247927513443585, 5.523561956057013, 5.523561956057013, 5.0, 4.700439718141092, 4.247927513443585, 5.954196310386875, 5.930737337562887, 7.321928094887363, 5.169925001442312, 5.672425341971495, 5.78135971352466, 6.066089190457772, 5.700439718141092, 5.20945336562895, 4.807354922057604, 4.807354922057604, 7.03342300153745, 7.491853096329675, 7.491853096329675, 6.321928094887363, 6.741466986401147, 6.285402218862249, 7.139551352398794, 6.044394119358453, 6.044394119358453, 6.044394119358453, 6.044394119358453, 7.076815597050831, 8.113742166049189, 4.584962500721156, 6.149747119504682, 3.321928094887362, 5.087462841250339, 5.087462841250339, 5.044394119358453, null, 6.339850002884624, 6.266786540694901, 6.22881869049588, 4.643856189774724, 2.807354922057604, 3.321928094887362, 4.0, 3.807354922057604, 3.321928094887362, 2.584962500721156, 2.584962500721156, 3.700439718141092, 4.169925001442312, 6.459431618637297, 3.807354922057604, 4.906890595608519, 4.523561956057013, 4.459431618637297, 4.906890595608519, 2.0, 3.0, 3.0, 5.614709844115208, 5.672425341971495, 6.022367813028454, 4.807354922057604, 4.906890595608519, 4.857980995127572, 6.066089190457772, 5.0, 5.0, 5.0, 5.0, 5.129283016944966, 6.20945336562895, 3.169925001442312, 4.857980995127572, null, 3.321928094887362, 3.321928094887362, 4.247927513443585, 0.0, 4.807354922057604, 5.247927513443585, 5.247927513443585, 5.426264754702098, 4.392317422778761, 4.700439718141092, 5.285402218862249, 4.754887502163468, 4.321928094887363, 4.087462841250339, 3.321928094887362, 5.20945336562895, 5.491853096329675, 7.434628227636725, 4.807354922057604, 4.247927513443585, 5.584962500721156, 5.614709844115208, 5.614709844115208, 4.392317422778761, 4.087462841250339, 4.087462841250339, 6.409390936137702, 6.9886846867721655, 7.087462841250339, 5.807354922057604, 5.954196310386875, 5.930737337562887, 6.523561956057013, 5.392317422778761, 5.392317422778761, 5.392317422778761, 5.392317422778761, 6.569855608330948, 7.577428828035749, 3.0, 5.459431618637297, 2.321928094887362, 5.247927513443585, 5.247927513443585, 4.906890595608519, null, 6.189824558880018, 5.930737337562887, 5.857980995127572, 6.0, 4.700439718141092, 5.700439718141092, 5.523561956057013, 6.087462841250339, 5.906890595608519, 5.20945336562895, 4.906890595608519, 6.614709844115208, 6.321928094887363, 8.339850002884624, 6.266786540694901, 5.727920454563199, 6.339850002884624, 6.584962500721156, 6.0, 5.584962500721156, 4.954196310386875, 4.954196310386875, 6.820178962415188, 7.339850002884624, 7.918863237274595, 7.199672344836364, 7.459431618637297, 6.794415866350106, 7.6293566200796095, 6.569855608330948, 6.569855608330948, 6.569855608330948, 6.569855608330948, 7.554588851677638, 8.59618975614441, 3.807354922057604, 6.954196310386875, 1.584962500721156, 5.906890595608519, 5.906890595608519, 5.727920454563199, 0.0, 6.554588851677638, 6.459431618637297, 6.426264754702098, null, null, null, null, 0.0, 0.0, null, null, null, null, null, null, null, 0.0, null, null, 0.0, null, null, null, 2.0, 1.0, null, 1.0, null, 1.0, 0.0, 0.0, 0.0, 0.0, null, null, null, null, 0.0, 0.0, 0.0, null, null, null, null, null, 7.622051819456376, 7.491853096329675, 6.523561956057013, 6.658211482751795, 7.2761244052742375, 6.832890014164741, 6.906890595608519, 6.539158811108031, 8.228818690495881, 9.152284842306582, 8.361943773735241, 5.857980995127572, 6.954196310386875, 7.409390936137702, 6.918863237274595, 7.03342300153745, 6.614709844115208, 6.658211482751795, 6.658211482751795, 10.096715154488535, 10.800090987624994, 9.350939181546432, 8.308339030139408, 9.174925682500678, 8.459431618637296, 7.894817763307944, 6.954196310386875, 6.954196310386875, 6.954196310386875, 6.94251450533924, 8.285402218862249, 9.368506461507693, 5.20945336562895, 7.451211111832329, 11.03823313473178, 6.539158811108031, 6.539158811108031, 9.076815597050832, 8.285402218862249, 8.022367813028454, 8.62935662007961, 8.622051819456376, 6.339850002884624, 5.807354922057604, 4.700439718141092, 4.459431618637297, 5.930737337562887, 6.189824558880018, 5.954196310386875, 5.672425341971495, 7.20945336562895, 7.294620748891627, 7.159871336778389, 0.0, 6.459431618637297, 6.108524456778169, 4.0, 5.584962500721156, 5.321928094887363, 4.321928094887363, 4.321928094887363, 8.071462362556623, 8.761551232444479, 8.179909090014934, 7.366322214245816, 8.139551352398794, 6.6293566200796095, 6.614709844115208, 5.857980995127572, 5.832890014164741, 5.832890014164741, 5.807354922057604, 6.539158811108031, 7.658211482751795, 6.169925001442312, 6.906890595608519, 4.087462841250339, 4.857980995127572, 4.857980995127572, 7.592457037268081, 0.0, 7.417852514885898, 6.754887502163468, 6.768184324776926, 6.768184324776926, 6.569855608330948, 5.727920454563199, 6.169925001442312, 6.845490050944375, 6.087462841250339, 6.044394119358453, 5.857980995127572, 7.832890014164741, 8.262094845370179, 7.672425341971495, 5.087462841250339, 7.044394119358453, 7.011227255423254, 6.459431618637297, 6.22881869049588, 5.643856189774724, 6.247927513443585, 6.247927513443585, 8.794415866350105, 10.156083076288681, 8.693486957499326, 7.714245517666122, 8.618385502258606, 8.326429487122303, 7.721099188707185, 6.894817763307944, 6.882643049361842, 6.882643049361842, 6.857980995127572, 7.636624620543649, 8.710806433699352, 7.303780748177103, 7.483815777264256, 10.843921051289035, 5.700439718141092, 5.727920454563199, 8.73809225962049, 7.658211482751795, 7.044394119358453, 8.113742166049189, 8.098032082960527, 6.087462841250339, 5.584962500721156, 3.807354922057604, 4.523561956057013, 5.129283016944966, 5.426264754702098, 4.087462841250339, 4.169925001442312, 6.700439718141092, 7.247927513443585, 5.930737337562887, 4.247927513443585, 5.832890014164741, 5.832890014164741, 4.906890595608519, 5.643856189774724, 5.247927513443585, 5.129283016944966, 5.129283016944966, 8.353146825498083, 9.139551352398794, 7.754887502163468, 6.569855608330948, 7.459431618637297, 6.807354922057604, 6.129283016944966, 5.426264754702098, 5.426264754702098, 5.426264754702098, 5.426264754702098, 6.247927513443585, 7.321928094887363, 1.0, 6.357552004618084, 9.693486957499326, 4.906890595608519, 4.906890595608519, 7.499845887083206, 5.426264754702098, 6.129283016944966, 6.857980995127572, 6.794415866350106, 6.189824558880018, 5.977279923499917, 4.700439718141092, 5.087462841250339, 6.108524456778169, 5.857980995127572, 5.584962500721156, 5.087462841250339, 7.569855608330948, 8.939579214314692, 7.2761244052742375, 4.700439718141092, 5.832890014164741, 6.087462841250339, 5.977279923499917, 5.392317422778761, 5.643856189774724, 5.357552004618084, 5.357552004618084, 9.894817763307943, 10.508785162064513, 8.179909090014934, 7.03342300153745, 7.78135971352466, 7.507794640198696, 6.78135971352466, 5.977279923499917, 5.977279923499917, 5.977279923499917, 5.954196310386875, 7.011227255423254, 8.08214904135387, 4.0, 6.658211482751795, 10.184875342908283, 5.426264754702098, 5.426264754702098, 8.60733031374961, 5.857980995127572, 6.930737337562887, 7.392317422778761, 7.357552004618084, 6.108524456778169, 6.129283016944966, 5.930737337562887, 5.357552004618084, 6.459431618637297, 6.266786540694901, 4.584962500721156, 5.20945336562895, 6.614709844115208, 6.930737337562887, 7.434628227636725, 4.087462841250339, 6.169925001442312, 6.149747119504682, 6.189824558880018, 6.087462841250339, 5.426264754702098, 5.554588851677638, 5.554588851677638, 8.055282435501189, 8.344295907915816, 8.087462841250339, 7.011227255423254, 7.658211482751795, 7.794415866350106, 6.9886846867721655, 6.129283016944966, 6.108524456778169, 6.108524456778169, 6.066089190457772, 7.05528243550119, 8.124121311829187, 0.0, 6.22881869049588, 10.281930026955443, 6.285402218862249, 6.285402218862249, 7.936637939002571, 6.539158811108031, 7.05528243550119, 7.348728154231077, 7.321928094887363, 0.0, 0.0, 5.129283016944966, 4.700439718141092, 5.906890595608519, null, 0.0, null, 1.584962500721156, null, null, null, null, null, 3.0, 6.20945336562895, null, 2.584962500721156, 2.584962500721156, 1.0, null, 0.0, 0.0, null, 3.807354922057604, 4.0, 1.0, 1.0, 1.0, 1.0, 7.741466986401147, 8.774787059601174, null, null, 2.321928094887362, 2.0, 2.0, null, 6.714245517666122, null, 3.700439718141092, 3.4594316186372973, 5.906890595608519, 5.614709844115208, 4.321928094887363, 4.0, 4.459431618637297, 4.700439718141092, 5.087462841250339, 4.087462841250339, 7.011227255423254, 7.734709620225838, 6.894817763307944, 3.807354922057604, 4.954196310386875, 4.700439718141092, 4.954196310386875, 3.0, 4.392317422778761, 4.392317422778761, 4.392317422778761, 8.879583249612784, 9.283088353024002, 6.643856189774724, 5.832890014164741, 6.409390936137702, 6.409390936137702, 5.906890595608519, 4.954196310386875, 4.954196310386875, 4.954196310386875, 4.906890595608519, 5.857980995127572, 6.918863237274595, 3.4594316186372973, 5.754887502163468, 9.197216693110052, 4.247927513443585, 4.247927513443585, 7.60733031374961, 4.087462841250339, 5.857980995127572, 6.569855608330948, 6.523561956057013, 0.0, null, 0.0, null, null, 0.0, null, null, 0.0, null, null, null, 1.584962500721156, 1.0, null, null, null, null, null, 0.0, 4.643856189774724, 1.0, null, null, null, 3.169925001442312, 0.0, 0.0, 0.0, 0.0, null, 3.169925001442312, null, 1.0, 1.584962500721156, null, null, 1.584962500721156, null, 1.0, 0.0, 0.0, 4.754887502163468, 4.754887502163468, 4.584962500721156, 3.9068905956085187, 4.523561956057013, 4.754887502163468, 4.584962500721156, 3.9068905956085187, 6.189824558880018, 7.679480099505446, 6.392317422778761, 4.0, 5.169925001442312, 5.523561956057013, 4.954196310386875, 5.614709844115208, 4.169925001442312, 4.643856189774724, 4.643856189774724, 8.169925001442312, 8.778077129535358, 7.1799090900149345, 6.087462841250339, 7.022367813028454, 6.491853096329675, 5.977279923499917, 5.044394119358453, 5.044394119358453, 5.044394119358453, 5.044394119358453, 5.906890595608519, 7.03342300153745, 3.321928094887362, 5.491853096329675, 8.087462841250339, 4.643856189774724, 4.643856189774724, 8.108524456778168, 5.321928094887363, 5.614709844115208, 6.614709844115208, 6.539158811108031, 6.087462841250339, 6.285402218862249, 5.614709844115208, 5.584962500721156, 5.807354922057604, 5.700439718141092, 5.584962500721156, 4.807354922057604, 6.845490050944375, 6.845490050944375, 7.011227255423254, 4.700439718141092, 5.392317422778761, 6.303780748177103, 6.0, 6.584962500721156, 4.523561956057013, 5.169925001442312, 5.169925001442312, 7.60733031374961, 7.7615512324444795, 8.076815597050832, 7.098032082960526, 7.584962500721156, 7.774787059601174, 6.930737337562887, 6.129283016944966, 6.129283016944966, 6.129283016944966, 6.129283016944966, 6.906890595608519, 8.022367813028454, null, 7.03342300153745, 9.159871336778389, 6.149747119504682, 6.149747119504682, 6.475733430966398, 6.087462841250339, 7.20945336562895, 7.0, 7.011227255423254, 5.857980995127572, 5.807354922057604, 4.523561956057013, 5.0, 6.189824558880018, 6.129283016944966, 5.247927513443585, 5.169925001442312, 7.159871336778389, 7.864186144654281, 7.066089190457772, 5.285402218862249, 5.930737337562887, 6.022367813028454, 5.247927513443585, 5.129283016944966, 4.754887502163468, 5.930737337562887, 5.930737337562887, 9.199672344836364, 9.848622940429339, 7.864186144654281, 6.870364719583405, 7.584962500721156, 7.2761244052742375, 6.442943495848728, 5.643856189774724, 5.614709844115208, 5.614709844115208, 5.614709844115208, 7.05528243550119, 8.144658242831882, 2.0, 6.339850002884624, 9.958552715431011, 6.022367813028454, 6.022367813028454, 8.63662462054365, 7.409390936137702, 7.366322214245816, 6.965784284662087, 6.977279923499917, 7.108524456778169, 7.087462841250339, 5.321928094887363, 6.044394119358453, 7.066089190457772, 7.339850002884624, 6.169925001442312, 6.426264754702098, 8.044394119358454, 8.707359132080883, 7.60733031374961, 5.554588851677638, 6.727920454563199, 7.266786540694901, 6.523561956057013, 6.539158811108031, 6.149747119504682, 6.442943495848728, 6.442943495848728, 9.794415866350105, 10.0, 8.873444112515376, 8.118941072723507, 8.717676423066395, 8.603626344986193, 7.7615512324444795, 6.870364719583405, 6.870364719583405, 6.870364719583405, 6.870364719583405, 7.851749041416057, 8.954196310386875, 4.459431618637297, 7.643856189774724, 10.015415052386688, 6.539158811108031, 6.539158811108031, 8.72451385311995, 7.219168520462161, 7.467605550082998, 8.228818690495881, 8.238404739325079, 8.027905996569885, 7.906890595608519, 6.584962500721156, 6.882643049361842, 8.0, 7.2384047393250786, 6.303780748177103, 6.78135971352466, 8.734709620225837, 9.08214904135387, 8.703903573444663, 6.247927513443585, 7.7615512324444795, 7.714245517666122, 7.442943495848728, 6.285402218862249, 6.894817763307944, 7.159871336778389, 7.159871336778389, 10.10459875356437, 10.494855584491198, 9.620219825507487, 8.83605035505807, 9.618385502258606, 9.197216693110052, 8.321928094887362, 7.442943495848728, 7.434628227636725, 7.434628227636725, 7.417852514885898, 8.92184093707449, 9.975847968006784, 0.0, 8.550746785383243, 11.496853777388042, 7.813781191217037, 7.813781191217037, 9.611024797307353, 8.734709620225837, 8.543031820255237, 9.214319120800766, 9.20945336562895, 7.169925001442312, 6.845490050944375, 5.857980995127572, 5.977279923499917, 6.882643049361842, 6.794415866350106, 5.554588851677638, 5.727920454563199, 7.539158811108031, 8.124121311829187, 7.149747119504682, 4.700439718141092, 6.285402218862249, 7.312882955284356, 6.266786540694901, 5.614709844115208, 6.523561956057013, 5.672425341971495, 5.672425341971495, 9.507794640198696, 9.430452551665532, 8.668884984266247, 7.672425341971495, 8.405141463136344, 8.103287808412022, 7.523561956057013, 6.714245517666122, 6.714245517666122, 6.714245517666122, 6.714245517666122, 7.6865005271832185, 8.751544059089099, 2.807354922057604, 7.417852514885898, 10.754887502163468, 6.3750394313469245, 6.3750394313469245, 8.682994583681683, 7.098032082960526, 7.409390936137702, 7.906890595608519, 7.876516946564999, 6.022367813028454, 4.643856189774724, 3.321928094887362, 4.321928094887363, 4.459431618637297, 5.392317422778761, 5.392317422778761, 5.321928094887363, 6.954196310386875, 7.159871336778389, 7.022367813028454, 3.807354922057604, 5.977279923499917, 6.614709844115208, 3.9068905956085187, 3.584962500721156, 4.643856189774724, 3.584962500721156, 3.584962500721156, 7.599912842187128, 8.087462841250339, 7.357552004618084, 6.94251450533924, 7.651051691178929, 6.266786540694901, 6.894817763307944, 6.087462841250339, 6.087462841250339, 6.087462841250339, 6.044394119358453, 5.906890595608519, 7.0, null, 6.339850002884624, 9.13699111208023, 4.807354922057604, 4.807354922057604, 6.807354922057604, 5.20945336562895, 6.807354922057604, 6.129283016944966, 6.108524456778169, 5.584962500721156, 5.672425341971495, 4.321928094887363, 4.754887502163468, 4.754887502163468, 5.491853096329675, 5.554588851677638, 5.087462841250339, 7.129283016944966, 7.714245517666122, 6.614709844115208, 4.459431618637297, 5.727920454563199, 5.954196310386875, 5.906890595608519, 5.807354922057604, 4.523561956057013, 4.584962500721156, 4.584962500721156, 8.696967526234287, 9.357552004618084, 7.7615512324444795, 6.794415866350106, 7.3750394313469245, 7.294620748891627, 5.832890014164741, 4.954196310386875, 4.954196310386875, 4.954196310386875, 4.906890595608519, 6.599912842187128, 7.636624620543649, 2.321928094887362, 6.569855608330948, 9.938109326219239, 5.672425341971495, 5.672425341971495, 7.554588851677638, 5.044394119358453, 6.977279923499917, 7.0, 6.94251450533924, 7.807354922057604, 7.475733430966398, 6.794415866350106, 6.857980995127572, 7.6293566200796095, 7.523561956057013, 7.199672344836364, 6.700439718141092, 8.960001932068081, 9.355351096424812, 9.052568050804153, 6.20945336562895, 7.700439718141092, 8.055282435501189, 7.357552004618084, 6.741466986401147, 7.076815597050831, 6.714245517666122, 6.714245517666122, 10.43879185257826, 10.968666793195208, 9.684748620421626, 8.867278739709661, 9.62935662007961, 9.154818109052105, 8.507794640198696, 7.6293566200796095, 7.6293566200796095, 7.6293566200796095, 7.584962500721156, 8.546894459887637, 9.618385502258606, 0.0, 8.405141463136344, 10.78135971352466, 7.392317422778761, 7.392317422778761, 9.605479518061669, 7.807354922057604, 8.566054038171092, 9.044394119358454, 9.038918989292302, 6.794415866350106, 6.977279923499917, 5.857980995127572, 6.285402218862249, 7.1799090900149345, 6.727920454563199, 6.426264754702098, 5.807354922057604, 7.98299357469431, 8.92184093707449, 8.228818690495881, 5.78135971352466, 6.643856189774724, 7.348728154231077, 6.658211482751795, 6.426264754702098, 6.189824558880018, 6.266786540694901, 6.266786540694901, 9.992938336165814, 10.396604781181859, 9.250298417906333, 8.139551352398794, 8.839203788096944, 8.527477006060396, 7.857980995127572, 6.977279923499917, 6.977279923499917, 6.977279923499917, 6.965784284662087, 8.03342300153745, 9.147204924942228, 3.4594316186372973, 7.977279923499917, 11.165535141377925, 6.491853096329675, 6.491853096329675, 9.108524456778168, 8.344295907915816, 7.599912842187128, 8.357552004618084, 8.339850002884624, 5.20945336562895, 4.643856189774724, 4.321928094887363, 3.584962500721156, 3.584962500721156, 4.857980995127572, 5.247927513443585, 3.169925001442312, 6.22881869049588, 7.400879436282184, 5.523561956057013, 2.321928094887362, 4.857980995127572, 4.643856189774724, 4.459431618637297, 3.807354922057604, 3.169925001442312, 4.0, 4.0, 8.228818690495881, 8.794415866350105, 6.614709844115208, 5.807354922057604, 6.409390936137702, 6.3750394313469245, 4.700439718141092, 4.0, 4.0, 4.0, 3.9068905956085187, 4.954196310386875, 6.247927513443585, null, 5.392317422778761, 8.930737337562887, 4.392317422778761, 4.392317422778761, 7.339850002884624, 5.426264754702098, 4.523561956057013, 6.022367813028454, 6.0, null, null, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, 0.0, 1.0, null, 0.0, 0.0, 0.0, 0.0, null, null, null, null, null, 0.0, 1.0, 0.0, 1.584962500721156, null, null, null, null, null, 0.0, 0.0, 6.149747119504682, 6.339850002884624, 4.906890595608519, 5.20945336562895, 5.754887502163468, 6.066089190457772, 6.149747119504682, 5.321928094887363, 7.442943495848728, 7.912889336229962, 7.044394119358453, 4.643856189774724, 6.357552004618084, 6.087462841250339, 5.643856189774724, 6.266786540694901, 5.523561956057013, 5.643856189774724, 5.643856189774724, 9.471675214392045, 9.688250309133178, 8.285402218862249, 7.562242424221073, 8.103287808412022, 7.700439718141092, 6.807354922057604, 5.930737337562887, 5.882643049361842, 5.882643049361842, 5.857980995127572, 7.011227255423254, 8.092757140919852, 0.0, 6.918863237274595, 4.954196310386875, 6.0, 6.0, 8.727920454563199, 2.807354922057604, 6.714245517666122, 7.523561956057013, 7.515699838284043, 6.794415866350106, 6.475733430966398, 5.426264754702098, 5.426264754702098, 6.285402218862249, 6.584962500721156, 5.977279923499917, 5.491853096329675, 7.6865005271832185, 8.76487159073609, 7.924812503605781, 4.807354922057604, 6.727920454563199, 6.672425341971495, 5.78135971352466, 6.266786540694901, 5.321928094887363, 5.584962500721156, 5.584962500721156, 9.49585502688717, 10.036173612553485, 8.703903573444663, 7.434628227636725, 8.098032082960527, 7.924812503605781, 7.3750394313469245, 6.539158811108031, 6.539158811108031, 6.539158811108031, 6.491853096329675, 7.3750394313469245, 8.413627929024173, 6.523561956057013, 7.169925001442312, 9.696967526234287, 6.129283016944966, 6.129283016944966, 8.968666793195208, 6.3750394313469245, 7.189824558880018, 7.94251450533924, 7.900866807980749, 5.954196310386875, 5.20945336562895, 3.807354922057604, 4.247927513443585, 5.285402218862249, 4.857980995127572, 5.357552004618084, 3.9068905956085187, 6.906890595608519, 7.924812503605781, 6.129283016944966, 4.0, 5.857980995127572, 5.614709844115208, 5.285402218862249, 4.169925001442312, 5.087462841250339, 5.129283016944966, 5.129283016944966, 8.569855608330949, 9.426264754702098, 7.442943495848728, 6.714245517666122, 7.392317422778761, 7.22881869049588, 6.754887502163468, 5.857980995127572, 5.857980995127572, 5.857980995127572, 5.857980995127572, 5.727920454563199, 6.820178962415188, 3.0, 5.882643049361842, 8.632995197142957, 4.954196310386875, 4.954196310386875, 7.768184324776926, 5.357552004618084, 6.321928094887363, 6.6865005271832185, 6.672425341971495, 4.087462841250339, 7.108524456778169, 3.0, 3.9068905956085187, 5.044394119358453, 4.0, 3.584962500721156, 3.584962500721156, 4.523561956057013, 5.321928094887363, 3.9068905956085187, 5.0, 4.169925001442312, 4.392317422778761, 6.741466986401147, 4.643856189774724, 2.0, 6.22881869049588, 6.22881869049588, 6.409390936137702, 6.882643049361842, 6.741466986401147, 6.754887502163468, 6.599912842187128, 8.758223214726724, 5.491853096329675, 4.643856189774724, 4.643856189774724, 4.643856189774724, 4.169925001442312, 5.930737337562887, 6.9886846867721655, null, 4.700439718141092, 0.0, 6.754887502163468, 6.754887502163468, 5.129283016944966, 0.0, 5.0, 8.442943495848729, 8.417852514885897, 5.882643049361842, 5.700439718141092, 4.0, 4.247927513443585, 3.9068905956085187, 5.672425341971495, 4.643856189774724, 4.906890595608519, 7.05528243550119, 8.184875342908283, 6.741466986401147, 4.321928094887363, 6.044394119358453, 5.614709844115208, 5.247927513443585, 4.754887502163468, 4.584962500721156, 4.643856189774724, 4.643856189774724, 9.197216693110052, 9.513727595952437, 7.672425341971495, 6.714245517666122, 7.129283016944966, 7.266786540694901, 6.169925001442312, 5.044394119358453, 5.044394119358453, 5.044394119358453, 5.044394119358453, 6.108524456778169, 7.247927513443585, 4.087462841250339, 6.459431618637297, 9.76487159073609, 4.700439718141092, 4.700439718141092, 8.491853096329674, 5.930737337562887, 6.6865005271832185, 6.832890014164741, 6.832890014164741, 6.022367813028454, 4.954196310386875, 4.169925001442312, 4.169925001442312, 4.906890595608519, 5.584962500721156, 4.906890595608519, 4.523561956057013, 6.643856189774724, 7.459431618637297, 6.554588851677638, 4.321928094887363, 6.129283016944966, 5.129283016944966, 4.754887502163468, 4.584962500721156, 4.392317422778761, 4.857980995127572, 4.857980995127572, 8.7714894695006, 9.036173612553485, 7.531381460516312, 6.303780748177103, 6.94251450533924, 6.965784284662087, 6.20945336562895, 5.459431618637297, 5.459431618637297, 5.459431618637297, 5.459431618637297, 5.906890595608519, 6.965784284662087, null, 5.129283016944966, 9.29920801838728, 5.0, 5.0, 7.409390936137702, 4.954196310386875, 5.977279923499917, 6.807354922057604, 6.727920454563199, 7.882643049361842, 7.930737337562887, 7.011227255423254, 7.475733430966398, 8.124121311829187, 7.700439718141092, 7.066089190457772, 7.189824558880018, 8.826548487290914, 9.29232163280204, 8.717676423066395, 5.882643049361842, 7.734709620225838, 8.08214904135387, 7.357552004618084, 7.294620748891627, 7.294620748891627, 7.076815597050831, 7.076815597050831, 10.361943773735241, 10.855647166027266, 9.776433032444734, 8.971543553950772, 9.746514321138463, 9.228818690495881, 8.64745842645492, 7.787902559391432, 7.787902559391432, 7.787902559391432, 7.78135971352466, 9.044394119358454, 10.11504365016171, 5.523561956057013, 8.710806433699352, 11.741466986401146, 7.098032082960526, 7.108524456778169, 9.632995197142957, 8.888743248898258, 8.50382573799575, 9.177419537989236, 9.162391328756906, 7.129283016944966, 6.475733430966398, 5.426264754702098, 5.78135971352466, 6.247927513443585, 6.3750394313469245, 6.189824558880018, 5.930737337562887, 7.965784284662087, 8.731319031025064, 7.813781191217037, 5.392317422778761, 6.845490050944375, 6.754887502163468, 6.022367813028454, 5.857980995127572, 5.426264754702098, 6.189824558880018, 6.189824558880018, 9.172427508645482, 10.213104219641906, 8.491853096329674, 7.882643049361842, 8.396604781181859, 8.066089190457772, 7.330916878114617, 6.491853096329675, 6.475733430966398, 6.475733430966398, 6.475733430966398, 7.60733031374961, 8.651051691178928, 1.584962500721156, 7.199672344836364, 10.615629636968098, 6.149747119504682, 6.149747119504682, 8.228818690495881, 6.6865005271832185, 7.108524456778169, 7.94251450533924, 7.924812503605781, 6.189824558880018, 5.78135971352466, 5.321928094887363, 5.584962500721156, 5.754887502163468, 5.491853096329675, 5.491853096329675, 4.459431618637297, 7.266786540694901, 8.038918989292302, 7.392317422778761, 4.906890595608519, 5.169925001442312, 6.459431618637297, 6.0, 5.882643049361842, 4.700439718141092, 5.523561956057013, 5.523561956057013, 8.930737337562887, 9.721099188707186, 8.179909090014934, 6.906890595608519, 7.6653359171851765, 7.554588851677638, 7.129283016944966, 6.189824558880018, 6.169925001442312, 6.169925001442312, 6.129283016944966, 6.832890014164741, 7.906890595608519, 0.0, 6.569855608330948, 10.311748315004959, 6.129283016944966, 6.129283016944966, 8.134426320220927, 6.965784284662087, 6.820178962415188, 7.20945336562895, 7.159871336778389, 6.6293566200796095, 6.459431618637297, 4.321928094887363, 5.584962500721156, 6.459431618637297, 6.20945336562895, 5.614709844115208, 6.044394119358453, 7.442943495848728, 8.027905996569885, 7.3750394313469245, 4.700439718141092, 6.584962500721156, 6.554588851677638, 5.247927513443585, 5.882643049361842, 5.832890014164741, 5.977279923499917, 5.977279923499917, 9.375039431346925, 9.842350343413807, 8.348728154231077, 7.546894459887636, 8.164906926675688, 7.864186144654281, 7.312882955284356, 6.409390936137702, 6.409390936137702, 6.409390936137702, 6.3750394313469245, 7.475733430966398, 8.531381460516313, 3.4594316186372973, 6.832890014164741, 10.290018846932618, 5.087462841250339, 5.087462841250339, 7.965784284662087, 6.303780748177103, 6.857980995127572, 7.554588851677638, 7.531381460516312, 5.832890014164741, 5.672425341971495, 4.584962500721156, 4.0, 5.20945336562895, 5.906890595608519, 3.321928094887362, 4.906890595608519, 6.820178962415188, 7.247927513443585, 5.78135971352466, 3.9068905956085187, 4.754887502163468, 5.321928094887363, 5.129283016944966, 3.0, 4.584962500721156, 5.169925001442312, 5.169925001442312, 8.618385502258606, 9.211888294546004, 7.658211482751795, 7.03342300153745, 7.651051691178929, 6.930737337562887, 6.22881869049588, 5.285402218862249, 5.247927513443585, 5.247927513443585, 5.20945336562895, 6.741466986401147, 7.794415866350106, null, 6.087462841250339, 9.62935662007961, 4.857980995127572, 4.857980995127572, 7.499845887083206, 5.700439718141092, 5.857980995127572, 6.599912842187128, 6.554588851677638, null, null, null, null, null, 0.0, null, null, null, null, null, 0.0, 0.0, null, null, null, null, null, null, 1.584962500721156, 4.169925001442312, 0.0, null, 1.0, 0.0, 2.321928094887362, null, null, null, null, null, 3.0, null, 2.584962500721156, 1.0, 2.0, 2.0, 0.0, 0.0, 2.0, null, null, 5.954196310386875, 5.832890014164741, 4.584962500721156, 4.392317422778761, 5.491853096329675, 5.78135971352466, 5.954196310386875, 4.954196310386875, 6.965784284662087, 7.584962500721156, 6.700439718141092, 4.321928094887363, 5.554588851677638, 6.022367813028454, 5.247927513443585, 6.087462841250339, 4.247927513443585, 4.857980995127572, 4.857980995127572, 8.348728154231077, 9.074141462752506, 7.930737337562887, 6.727920454563199, 7.515699838284043, 7.2384047393250786, 6.189824558880018, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.20945336562895, 6.169925001442312, 7.366322214245816, null, 6.357552004618084, 8.92184093707449, 5.247927513443585, 5.247927513443585, 7.6293566200796095, 5.672425341971495, 6.321928094887363, 7.108524456778169, 7.044394119358453, 5.857980995127572, 6.044394119358453, 4.321928094887363, 4.459431618637297, 5.491853096329675, 5.807354922057604, 4.392317422778761, 4.807354922057604, 7.266786540694901, 8.303780748177102, 7.118941072723508, 4.459431618637297, 6.409390936137702, 5.930737337562887, 4.906890595608519, 4.807354922057604, 4.906890595608519, 4.754887502163468, 4.754887502163468, 9.221587121264806, 9.805743872151618, 7.98299357469431, 6.857980995127572, 7.734709620225838, 7.483815777264256, 6.754887502163468, 6.022367813028454, 6.0, 6.0, 5.954196310386875, 6.392317422778761, 7.434628227636725, 3.321928094887362, 6.357552004618084, 9.847057346091336, 5.321928094887363, 5.321928094887363, 7.94251450533924, 5.459431618637297, 6.285402218862249, 7.044394119358453, 7.0, 5.700439718141092, 5.285402218862249, 3.584962500721156, 4.169925001442312, 4.954196310386875, 4.954196310386875, 4.0, 4.087462841250339, 6.392317422778761, 7.459431618637297, 6.3750394313469245, 2.321928094887362, 4.392317422778761, 5.20945336562895, 4.247927513443585, 4.392317422778761, 4.700439718141092, 4.584962500721156, 4.584962500721156, 8.103287808412022, 9.189824558880018, 7.139551352398794, 6.3750394313469245, 7.149747119504682, 6.658211482751795, 5.700439718141092, 4.857980995127572, 4.857980995127572, 4.857980995127572, 4.857980995127572, 5.807354922057604, 6.918863237274595, 2.321928094887362, 5.321928094887363, 9.451211111832329, 4.700439718141092, 4.700439718141092, 7.129283016944966, 6.108524456778169, 5.857980995127572, 6.459431618637297, 6.426264754702098, 8.285402218862249, 8.39231742277876, 7.247927513443585, 7.6293566200796095, 8.507794640198696, 8.124121311829187, 7.076815597050831, 7.768184324776926, 8.930737337562887, 9.005624549193879, 9.167418145831737, 7.266786540694901, 8.108524456778168, 8.826548487290914, 7.539158811108031, 7.426264754702098, 7.499845887083206, 7.554588851677638, 7.554588851677638, 10.318542809702723, 10.749031382040204, 10.156083076288681, 9.543031820255237, 10.274960472140602, 9.566054038171092, 9.036173612553485, 8.103287808412022, 8.098032082960527, 8.098032082960527, 8.087462841250339, 9.219168520462162, 10.293471648838134, 4.0, 8.945443836377912, 10.949097155729207, 7.727920454563199, 7.727920454563199, 9.400879436282183, 8.64745842645492, 8.857980995127573, 9.403012023574997, 9.396604781181859, 6.044394119358453, 5.523561956057013, 4.700439718141092, 5.321928094887363, 5.700439718141092, 4.700439718141092, 5.672425341971495, 5.0, 7.169925001442312, 7.483815777264256, 6.169925001442312, 3.700439718141092, 5.643856189774724, 5.700439718141092, 4.754887502163468, 5.857980995127572, 4.523561956057013, 4.754887502163468, 4.754887502163468, 8.335390354693924, 9.324180546618742, 7.826548487290915, 6.599912842187128, 7.592457037268081, 7.383704292474052, 6.321928094887363, 5.426264754702098, 5.426264754702098, 5.426264754702098, 5.426264754702098, 6.6293566200796095, 7.7615512324444795, 6.491853096329675, 6.392317422778761, 3.9068905956085187, 5.491853096329675, 5.491853096329675, 7.515699838284043, null, 6.6293566200796095, 6.554588851677638, 6.569855608330948, 7.199672344836364, 6.741466986401147, 5.584962500721156, 6.066089190457772, 6.599912842187128, 6.658211482751795, 6.247927513443585, 5.807354922057604, 8.049848549450562, 8.804131021183318, 7.977279923499917, 5.129283016944966, 6.94251450533924, 7.066089190457772, 6.044394119358453, 6.977279923499917, 6.108524456778169, 6.442943495848728, 6.442943495848728, 9.79603960882977, 10.31741261376487, 8.885696373339394, 7.826548487290915, 8.581200581924957, 8.285402218862249, 7.60733031374961, 6.727920454563199, 6.727920454563199, 6.727920454563199, 6.727920454563199, 8.016808287686555, 9.108524456778168, 7.2761244052742375, 7.03342300153745, 9.710806433699352, 6.189824558880018, 6.189824558880018, 8.487840033823051, 6.857980995127572, 7.546894459887636, 8.370687406807217, 8.348728154231077, 7.554588851677638, 7.651051691178929, 6.614709844115208, 6.442943495848728, 7.257387842692652, 7.098032082960526, 7.169925001442312, 6.584962500721156, 8.098032082960527, 8.164906926675688, 7.845490050944375, 6.247927513443585, 7.199672344836364, 7.507794640198696, 6.491853096329675, 7.098032082960526, 6.459431618637297, 6.807354922057604, 6.807354922057604, 9.64745842645492, 9.945443836377912, 9.236014191900084, 8.483815777264256, 9.31741261376487, 9.014020470314934, 8.189824558880018, 7.366322214245816, 7.357552004618084, 7.357552004618084, 7.348728154231077, 8.308339030139408, 9.388017285345136, 2.584962500721156, 8.164906926675688, 10.00982861736811, 7.169925001442312, 7.169925001442312, 7.832890014164741, 7.434628227636725, 7.7481928495894605, 8.588714635582264, 8.588714635582264, 7.499845887083206, 7.312882955284356, 5.672425341971495, 5.977279923499917, 7.294620748891627, 6.741466986401147, 6.285402218862249, 6.357552004618084, 8.066089190457772, 8.679480099505446, 7.800899899920305, 5.954196310386875, 6.475733430966398, 7.409390936137702, 6.169925001442312, 6.108524456778169, 6.523561956057013, 6.768184324776926, 6.768184324776926, 9.611024797307353, 10.281930026955443, 9.179909090014934, 8.321928094887362, 9.038918989292302, 8.92481250360578, 8.071462362556623, 7.1799090900149345, 7.1799090900149345, 7.1799090900149345, 7.1799090900149345, 8.055282435501189, 9.157346935362844, null, 7.434628227636725, 9.90839262077375, 6.672425341971495, 6.672425341971495, 8.321928094887362, 7.357552004618084, 7.622051819456376, 8.417852514885897, 8.388017285345136, 6.599912842187128, 6.3750394313469245, 5.554588851677638, 4.954196310386875, 6.22881869049588, 5.754887502163468, 5.285402218862249, 5.044394119358453, 7.149747119504682, 7.954196310386875, 7.321928094887363, 4.954196310386875, 5.954196310386875, 6.6293566200796095, 5.930737337562887, 5.247927513443585, 5.584962500721156, 6.108524456778169, 6.108524456778169, 9.087462841250339, 9.46352437327118, 8.467605550082997, 7.400879436282184, 8.108524456778168, 7.954196310386875, 7.3750394313469245, 6.658211482751795, 6.643856189774724, 6.643856189774724, 6.6293566200796095, 7.330916878114617, 8.366322214245816, 2.584962500721156, 6.918863237274595, 9.357552004618084, 6.169925001442312, 6.169925001442312, 7.60733031374961, 6.149747119504682, 7.3750394313469245, 7.531381460516312, 7.499845887083206, 7.159871336778389, 7.247927513443585, 5.584962500721156, 6.20945336562895, 7.189824558880018, 7.483815777264256, 7.219168520462161, 6.285402218862249, 8.487840033823051, 8.562242424221072, 8.451211111832329, 5.727920454563199, 7.011227255423254, 7.330916878114617, 6.965784284662087, 7.011227255423254, 6.475733430966398, 6.658211482751795, 6.658211482751795, 9.497851836951117, 10.46454575033394, 9.326429487122303, 8.228818690495881, 8.857980995127573, 9.041659151637214, 8.515699838284043, 7.651051691178929, 7.651051691178929, 7.651051691178929, 7.651051691178929, 8.247927513443585, 9.346513733165635, 1.584962500721156, 7.813781191217037, 10.266786540694902, 7.011227255423254, 7.011227255423254, 9.41574176829009, 7.451211111832329, 8.011227255423254, 8.539158811108031, 8.507794640198696, 5.20945336562895, 5.20945336562895, 4.523561956057013, 4.169925001442312, 4.0, 3.807354922057604, 4.321928094887363, 4.0, 6.614709844115208, 7.189824558880018, 5.459431618637297, 4.392317422778761, 5.357552004618084, 4.857980995127572, 4.954196310386875, 5.087462841250339, 4.643856189774724, 3.700439718141092, 3.700439718141092, 8.228818690495881, 9.187352073200497, 7.366322214245816, 5.954196310386875, 6.6293566200796095, 6.321928094887363, 5.643856189774724, 4.807354922057604, 4.807354922057604, 4.807354922057604, 4.754887502163468, 5.459431618637297, 6.599912842187128, 0.0, 5.954196310386875, 8.108524456778168, 5.129283016944966, 5.129283016944966, 7.467605550082998, 4.954196310386875, 5.643856189774724, 6.392317422778761, 6.357552004618084, null, null, null, null, 0.0, null, null, null, null, 0.0, null, null, 1.0, null, null, 0.0, null, null, null, null, 3.0, null, null, null, null, null, null, null, null, null, null, 2.0, null, 2.0, 2.584962500721156, 0.0, 0.0, 2.321928094887362, null, null, 0.0, 0.0, 7.108524456778169, 6.94251450533924, 4.807354922057604, 5.754887502163468, 6.832890014164741, 6.845490050944375, 5.832890014164741, 6.087462841250339, 8.243173983472952, 8.89178370321831, 7.643856189774724, 5.357552004618084, 6.918863237274595, 6.94251450533924, 5.930737337562887, 5.857980995127572, 5.426264754702098, 6.475733430966398, 6.475733430966398, 9.751544059089099, 10.508785162064513, 8.98299357469431, 8.011227255423254, 8.86418614465428, 8.519636252843213, 7.693486957499325, 6.820178962415188, 6.807354922057604, 6.807354922057604, 6.78135971352466, 7.693486957499325, 8.800899899920305, 3.700439718141092, 7.303780748177103, 10.825753832883112, 6.392317422778761, 6.392317422778761, 8.665335917185176, 6.930737337562887, 7.636624620543649, 8.43879185257826, 8.430452551665532, 6.247927513443585, 5.614709844115208, 5.554588851677638, 4.954196310386875, 5.954196310386875, 4.807354922057604, 5.087462841250339, 5.087462841250339, 7.189824558880018, 7.459431618637297, 6.507794640198696, 4.321928094887363, 5.807354922057604, 5.977279923499917, 5.584962500721156, 5.392317422778761, 4.523561956057013, 4.954196310386875, 4.954196310386875, 9.030667136246942, 9.449148645375436, 7.888743248898259, 6.614709844115208, 7.531381460516312, 7.392317422778761, 6.266786540694901, 5.321928094887363, 5.285402218862249, 5.285402218862249, 5.285402218862249, 7.03342300153745, 8.092757140919852, null, 6.523561956057013, 8.848622940429339, 6.022367813028454, 6.022367813028454, 8.59245703726808, 5.832890014164741, 6.845490050944375, 7.066089190457772, 7.044394119358453, 7.044394119358453, 6.426264754702098, 5.169925001442312, 5.584962500721156, 6.321928094887363, 6.409390936137702, 6.044394119358453, 5.727920454563199, 7.6293566200796095, 8.622051819456376, 7.7073591320808825, 5.247927513443585, 6.845490050944375, 6.3750394313469245, 5.857980995127572, 5.977279923499917, 5.754887502163468, 6.22881869049588, 6.22881869049588, 9.485829308701904, 10.358651200892886, 8.703903573444663, 7.851749041416057, 8.527477006060396, 8.184875342908283, 6.857980995127572, 6.169925001442312, 6.169925001442312, 6.169925001442312, 6.149747119504682, 7.2384047393250786, 8.339850002884624, 1.0, 7.189824558880018, 9.784634845557521, 6.169925001442312, 6.169925001442312, 9.055282435501189, 6.643856189774724, 7.475733430966398, 7.813781191217037, 7.800899899920305, 6.614709844115208, 6.643856189774724, 4.643856189774724, 5.832890014164741, 6.149747119504682, 6.507794640198696, 6.22881869049588, 5.169925001442312, 7.7615512324444795, 8.219168520462162, 7.417852514885898, 4.807354922057604, 5.78135971352466, 6.285402218862249, 5.882643049361842, 5.807354922057604, 5.554588851677638, 5.857980995127572, 5.857980995127572, 8.98299357469431, 9.965784284662087, 8.651051691178928, 7.475733430966398, 8.308339030139408, 7.888743248898259, 7.339850002884624, 6.539158811108031, 6.539158811108031, 6.539158811108031, 6.539158811108031, 7.330916878114617, 8.434628227636725, 3.9068905956085187, 6.614709844115208, 9.556506054671928, 6.357552004618084, 6.357552004618084, 8.933690654952233, 6.189824558880018, 6.977279923499917, 7.794415866350106, 7.741466986401147, 4.754887502163468, 4.321928094887363, 4.459431618637297, 3.700439718141092, 4.169925001442312, 3.807354922057604, 3.584962500721156, 3.700439718141092, 5.20945336562895, 6.442943495848728, 5.357552004618084, 3.169925001442312, 5.044394119358453, 5.087462841250339, 3.9068905956085187, 5.20945336562895, 3.584962500721156, 4.169925001442312, 4.169925001442312, 6.965784284662087, 7.651051691178929, 6.409390936137702, 5.20945336562895, 6.0, 5.954196310386875, 4.954196310386875, 3.9068905956085187, 3.9068905956085187, 3.9068905956085187, 3.9068905956085187, 5.285402218862249, 6.426264754702098, 1.0, 5.426264754702098, 2.807354922057604, 3.807354922057604, 3.807354922057604, 7.294620748891627, null, 5.0, 5.321928094887363, 5.285402218862249, 7.6293566200796095, 7.22881869049588, 5.584962500721156, 6.700439718141092, 7.636624620543649, 7.022367813028454, 6.870364719583405, 6.894817763307944, 8.139551352398794, 8.405141463136344, 7.794415866350106, 4.459431618637297, 7.118941072723508, 7.774787059601174, 7.098032082960526, 6.857980995127572, 6.426264754702098, 6.977279923499917, 6.977279923499917, 9.348728154231077, 10.187352073200497, 9.357552004618084, 8.348728154231077, 9.211888294546004, 8.842350343413807, 7.700439718141092, 6.754887502163468, 6.754887502163468, 6.754887502163468, 6.754887502163468, 8.422064766172813, 9.475733430966399, 4.247927513443585, 7.912889336229962, 10.17617314910749, 6.857980995127572, 6.857980995127572, 8.957102041562287, 7.507794640198696, 7.614709844115208, 8.643856189774725, 8.62935662007961, 6.741466986401147, 6.108524456778169, 5.727920454563199, 5.700439718141092, 6.832890014164741, 6.894817763307944, 6.044394119358453, 5.672425341971495, 7.794415866350106, 8.519636252843213, 7.467605550082998, 5.247927513443585, 6.569855608330948, 6.727920454563199, 6.129283016944966, 5.523561956057013, 5.882643049361842, 5.78135971352466, 5.78135971352466, 9.428360172704291, 10.156083076288681, 8.754887502163468, 7.813781191217037, 8.434628227636725, 8.092757140919852, 7.087462841250339, 6.22881869049588, 6.22881869049588, 6.22881869049588, 6.20945336562895, 7.577428828035749, 8.62935662007961, 0.0, 7.169925001442312, 10.430452551665532, 6.714245517666122, 6.727920454563199, 9.134426320220927, 6.507794640198696, 7.129283016944966, 8.479780264029099, 8.467605550082997, 5.954196310386875, 4.906890595608519, 3.321928094887362, 3.807354922057604, 4.954196310386875, 5.392317422778761, 5.426264754702098, 4.247927513443585, 6.584962500721156, 7.303780748177103, 6.285402218862249, 4.321928094887363, 5.554588851677638, 5.20945336562895, 4.584962500721156, 5.523561956057013, 4.857980995127572, 3.169925001442312, 3.169925001442312, 7.483815777264256, 8.997179480937621, 7.651051691178929, 6.066089190457772, 6.794415866350106, 6.820178962415188, 6.087462841250339, 5.285402218862249, 5.285402218862249, 5.285402218862249, 5.20945336562895, 6.22881869049588, 7.285402218862249, 3.169925001442312, 5.614709844115208, 7.9886846867721655, 5.247927513443585, 5.247927513443585, 6.930737337562887, 5.20945336562895, 5.78135971352466, 6.614709844115208, 6.539158811108031, 6.303780748177103, 6.392317422778761, 6.266786540694901, 5.727920454563199, 6.554588851677638, 6.894817763307944, 6.149747119504682, 5.700439718141092, 7.348728154231077, 7.906890595608519, 7.475733430966398, 5.523561956057013, 6.554588851677638, 6.357552004618084, 6.285402218862249, 6.044394119358453, 5.754887502163468, 5.700439718141092, 5.700439718141092, 9.154818109052105, 9.873444112515376, 8.483815777264256, 7.584962500721156, 8.144658242831882, 8.154818109052105, 7.219168520462161, 6.303780748177103, 6.303780748177103, 6.303780748177103, 6.303780748177103, 7.622051819456376, 8.661778097771988, null, 7.348728154231077, 9.513727595952437, 6.357552004618084, 6.3750394313469245, 8.86418614465428, 6.930737337562887, 7.3750394313469245, 7.409390936137702, 7.392317422778761, 6.700439718141092, 5.754887502163468, 5.523561956057013, 4.807354922057604, 6.108524456778169, 6.507794640198696, 5.977279923499917, 5.491853096329675, 7.7615512324444795, 8.271463027904375, 7.219168520462161, 4.643856189774724, 5.700439718141092, 6.768184324776926, 5.832890014164741, 5.523561956057013, 4.754887502163468, 5.882643049361842, 5.882643049361842, 8.96289600533726, 10.310612781659529, 8.447083226209653, 7.515699838284043, 8.098032082960527, 8.214319120800766, 7.022367813028454, 6.303780748177103, 6.303780748177103, 6.303780748177103, 6.22881869049588, 6.9886846867721655, 8.08214904135387, 2.321928094887362, 6.882643049361842, 9.321928094887362, 6.108524456778169, 6.108524456778169, 8.897845456005511, 6.285402218862249, 6.918863237274595, 7.459431618637297, 7.459431618637297, 4.643856189774724, 4.169925001442312, 3.807354922057604, 2.807354922057604, 4.087462841250339, 4.392317422778761, 4.700439718141092, 4.584962500721156, 6.523561956057013, 6.94251450533924, 5.614709844115208, 3.807354922057604, 4.523561956057013, 4.700439718141092, 4.643856189774724, 4.169925001442312, 3.584962500721156, 4.321928094887363, 4.321928094887363, 7.924812503605781, 9.149747119504681, 7.285402218862249, 5.392317422778761, 6.392317422778761, 6.584962500721156, 5.554588851677638, 4.584962500721156, 4.584962500721156, 4.584962500721156, 4.584962500721156, 5.044394119358453, 6.169925001442312, 3.169925001442312, 4.857980995127572, 7.820178962415188, 3.9068905956085187, 3.9068905956085187, 7.98299357469431, 4.392317422778761, 5.087462841250339, 6.285402218862249, 6.247927513443585, 0.0, null, null, null, 0.0, 1.0, null, null, null, null, null, null, null, 0.0, null, 0.0, null, null, null, 0.0, 2.0, 1.0, null, null, 0.0, 0.0, null, null, null, null, null, 3.0, null, null, 2.0, null, null, 1.584962500721156, null, null, null, null, 7.159871336778389, 6.870364719583405, 6.0, 6.087462841250339, 6.754887502163468, 6.700439718141092, 6.303780748177103, 5.930737337562887, 8.252665432450248, 8.379378367071261, 7.499845887083206, 5.754887502163468, 7.20945336562895, 6.930737337562887, 6.247927513443585, 6.727920454563199, 5.807354922057604, 5.672425341971495, 5.672425341971495, 9.60733031374961, 10.41679752760606, 8.954196310386875, 7.754887502163468, 8.599912842187127, 8.467605550082997, 7.312882955284356, 6.554588851677638, 6.554588851677638, 6.554588851677638, 6.554588851677638, 7.651051691178929, 8.679480099505446, 6.247927513443585, 7.554588851677638, 10.264442600226602, 6.906890595608519, 6.918863237274595, 8.144658242831882, 6.6293566200796095, 7.507794640198696, 8.139551352398794, 8.118941072723507, 5.977279923499917, 5.459431618637297, 4.906890595608519, 4.321928094887363, 4.857980995127572, 5.832890014164741, 5.727920454563199, 4.857980995127572, 6.6865005271832185, 7.721099188707185, 6.491853096329675, 2.321928094887362, 5.807354922057604, 5.614709844115208, 5.247927513443585, 5.523561956057013, 5.129283016944966, 5.087462841250339, 5.087462841250339, 8.689997971419446, 9.649256177517314, 7.60733031374961, 6.807354922057604, 7.483815777264256, 7.475733430966398, 6.459431618637297, 5.584962500721156, 5.584962500721156, 5.584962500721156, 5.554588851677638, 6.491853096329675, 7.475733430966398, 2.0, 6.247927513443585, 9.7714894695006, 5.807354922057604, 5.807354922057604, 8.290018846932618, 6.442943495848728, 6.169925001442312, 7.20945336562895, 7.169925001442312, 6.087462841250339, 5.78135971352466, 5.0, 4.392317422778761, 5.491853096329675, 6.247927513443585, 5.0, 4.754887502163468, 7.294620748891627, 8.20945336562895, 7.022367813028454, 3.807354922057604, 6.392317422778761, 6.22881869049588, 5.672425341971495, 5.392317422778761, 4.754887502163468, 5.044394119358453, 5.044394119358453, 8.515699838284043, 9.85642552862553, 7.787902559391432, 7.129283016944966, 7.693486957499325, 7.451211111832329, 6.507794640198696, 5.700439718141092, 5.700439718141092, 5.700439718141092, 5.672425341971495, 6.584962500721156, 7.636624620543649, null, 6.339850002884624, 10.040289721025717, 5.807354922057604, 5.807354922057604, 8.375039431346925, 5.832890014164741, 6.599912842187128, 7.491853096329675, 7.467605550082998, 7.700439718141092, 7.554588851677638, 6.357552004618084, 6.754887502163468, 7.6865005271832185, 6.554588851677638, 6.714245517666122, 6.714245517666122, 8.169925001442312, 8.974414589805527, 8.179909090014934, 6.044394119358453, 7.531381460516312, 7.321928094887363, 6.643856189774724, 6.78135971352466, 6.303780748177103, 6.3750394313469245, 6.3750394313469245, 10.204571144249204, 10.829722735086058, 9.552669097514272, 8.396604781181859, 9.269126679149418, 8.977279923499916, 8.087462841250339, 7.1799090900149345, 7.1799090900149345, 7.1799090900149345, 7.1799090900149345, 8.643856189774725, 9.731319031025064, 4.169925001442312, 8.129283016944967, 10.46352437327118, 7.118941072723508, 7.118941072723508, 9.605479518061669, 7.434628227636725, 8.189824558880018, 8.679480099505446, 8.668884984266247, 7.199672344836364, 6.672425341971495, 5.523561956057013, 6.0, 6.3750394313469245, 6.475733430966398, 5.426264754702098, 5.906890595608519, 7.531381460516312, 8.39231742277876, 7.475733430966398, 4.754887502163468, 6.392317422778761, 6.714245517666122, 6.108524456778169, 6.539158811108031, 5.857980995127572, 6.20945336562895, 6.20945336562895, 9.473705749619416, 10.029287226968245, 8.686500527183219, 7.977279923499917, 8.569855608330949, 8.618385502258606, 7.189824558880018, 6.3750394313469245, 6.3750394313469245, 6.3750394313469245, 6.3750394313469245, 7.6653359171851765, 8.744833837499545, 4.459431618637297, 7.467605550082998, 9.804131021183318, 6.3750394313469245, 6.3750394313469245, 8.46352437327118, 7.108524456778169, 7.339850002884624, 8.124121311829187, 8.103287808412022, 8.46352437327118, 8.044394119358454, 7.467605550082998, 7.851749041416057, 8.804131021183318, 7.876516946564999, 6.507794640198696, 7.339850002884624, 8.86418614465428, 9.149747119504681, 8.888743248898258, 7.554588851677638, 7.882643049361842, 7.954196310386875, 7.531381460516312, 8.113742166049189, 7.118941072723508, 7.727920454563199, 7.727920454563199, 9.952741247186488, 10.560332834212442, 10.164906926675688, 9.344295907915816, 9.971543553950772, 9.709083812550343, 8.879583249612784, 7.94251450533924, 7.930737337562887, 7.930737337562887, 7.924812503605781, 9.449148645375436, 10.482807956726667, 4.700439718141092, 8.936637939002571, 11.806549621985962, 7.467605550082998, 7.475733430966398, 8.980139577639157, 8.294620748891626, 9.084808387804362, 9.509775004326936, 9.505811553919594, 5.584962500721156, 5.357552004618084, 5.247927513443585, 5.20945336562895, 6.087462841250339, 5.523561956057013, 4.643856189774724, 4.584962500721156, 6.918863237274595, 7.592457037268081, 6.832890014164741, 4.700439718141092, 6.066089190457772, 5.882643049361842, 5.426264754702098, 5.700439718141092, 5.169925001442312, 5.044394119358453, 5.044394119358453, 7.845490050944375, 9.375039431346925, 8.159871336778389, 7.066089190457772, 7.727920454563199, 7.491853096329675, 6.459431618637297, 5.672425341971495, 5.672425341971495, 5.672425341971495, 5.672425341971495, 6.554588851677638, 7.679480099505446, 0.0, 5.906890595608519, 8.682994583681683, 5.754887502163468, 5.754887502163468, 7.357552004618084, 6.169925001442312, 6.357552004618084, 7.2761244052742375, 7.247927513443585, 0.0, null, null, 0.0, null, 2.0, 1.0, 0.0, 1.584962500721156, 4.0, 1.0, null, 1.0, 1.0, 0.0, null, null, 1.584962500721156, 1.584962500721156, 5.129283016944966, 6.129283016944966, 2.321928094887362, 2.807354922057604, 3.169925001442312, 2.807354922057604, 1.0, 0.0, 0.0, 0.0, 0.0, 2.0, 3.0, 2.0, 1.0, 3.0, 1.0, 1.0, 5.0, null, 2.584962500721156, null, null, 8.118941072723507, 7.531381460516312, 6.507794640198696, 6.954196310386875, 7.636624620543649, 7.577428828035749, 6.409390936137702, 7.149747119504682, 8.447083226209653, 8.804131021183318, 8.661778097771988, 6.22881869049588, 7.475733430966398, 7.820178962415188, 7.294620748891627, 6.149747119504682, 6.768184324776926, 6.930737337562887, 6.930737337562887, 9.733015321685963, 10.885696373339394, 10.00842862207058, 9.164906926675688, 9.994353436858859, 9.319672120946995, 8.562242424221072, 7.906890595608519, 7.906890595608519, 7.906890595608519, 7.894817763307944, 8.710806433699352, 9.799281621521923, null, 8.308339030139408, 11.432019846812493, 7.118941072723508, 7.118941072723508, 9.485829308701904, 8.867278739709661, 8.43879185257826, 8.879583249612784, 8.851749041416058, 5.523561956057013, 3.321928094887362, 3.321928094887362, 3.9068905956085187, 4.906890595608519, 3.9068905956085187, 5.700439718141092, 4.087462841250339, 6.189824558880018, 7.357552004618084, 5.857980995127572, 2.0, 4.459431618637297, 5.169925001442312, 4.392317422778761, 4.459431618637297, 3.321928094887362, 3.700439718141092, 3.700439718141092, 8.375039431346925, 9.194756854422248, 7.266786540694901, 6.321928094887363, 7.066089190457772, 6.523561956057013, 5.285402218862249, 4.523561956057013, 4.523561956057013, 4.523561956057013, 4.459431618637297, 5.832890014164741, 6.918863237274595, null, 5.807354922057604, 8.491853096329674, 5.285402218862249, 5.285402218862249, 7.483815777264256, 6.22881869049588, 5.0, 6.321928094887363, 6.247927513443585, 6.768184324776926, 5.169925001442312, 4.906890595608519, 5.857980995127572, 5.857980995127572, 5.882643049361842, 5.584962500721156, 5.129283016944966, 7.312882955284356, 8.214319120800766, 6.857980995127572, 4.906890595608519, 6.169925001442312, 5.906890595608519, 6.044394119358453, 5.78135971352466, 5.491853096329675, 5.906890595608519, 5.906890595608519, 9.216745858195306, 9.86418614465428, 8.285402218862249, 7.531381460516312, 8.224001674198105, 7.98299357469431, 6.870364719583405, 6.087462841250339, 6.066089190457772, 6.066089190457772, 6.044394119358453, 6.894817763307944, 8.022367813028454, null, 6.882643049361842, 9.108524456778168, 5.906890595608519, 5.906890595608519, 8.754887502163468, 6.108524456778169, 7.05528243550119, 7.679480099505446, 7.658211482751795, 0.0, null, null, null, null, null, null, null, 0.0, null, null, null, 1.0, null, null, 0.0, null, null, null, null, 3.0, 0.0, null, 1.0, null, 0.0, null, null, null, null, 0.0, 2.584962500721156, null, 1.0, 2.0, 2.0, 2.0, 2.321928094887362, null, 0.0, 0.0, 0.0, 5.044394119358453, 5.247927513443585, 4.807354922057604, 4.643856189774724, 4.807354922057604, 5.169925001442312, 3.9068905956085187, 3.807354922057604, 5.754887502163468, 6.426264754702098, 5.78135971352466, 4.321928094887363, 4.700439718141092, 4.523561956057013, 4.247927513443585, 4.700439718141092, 3.584962500721156, 4.392317422778761, 4.392317422778761, 7.2384047393250786, 7.807354922057604, 6.930737337562887, 6.20945336562895, 6.882643049361842, 6.569855608330948, 6.169925001442312, 5.247927513443585, 5.247927513443585, 5.247927513443585, 5.247927513443585, 6.266786540694901, 7.2761244052742375, null, 4.321928094887363, 8.829722735086058, 4.643856189774724, 4.643856189774724, 6.569855608330948, 6.087462841250339, 5.426264754702098, 5.882643049361842, 5.727920454563199, 6.820178962415188, 6.554588851677638, 5.584962500721156, 6.044394119358453, 6.727920454563199, 5.727920454563199, 5.672425341971495, 5.169925001442312, 7.0, 7.247927513443585, 7.721099188707185, 5.357552004618084, 6.599912842187128, 6.339850002884624, 5.554588851677638, 6.491853096329675, 5.584962500721156, 5.930737337562887, 5.930737337562887, 8.326429487122303, 9.25502856981873, 8.479780264029099, 7.366322214245816, 8.055282435501189, 7.930737337562887, 7.257387842692652, 6.409390936137702, 6.409390936137702, 6.409390936137702, 6.392317422778761, 7.392317422778761, 8.400879436282183, 1.0, 7.1799090900149345, 3.700439718141092, 6.442943495848728, 6.442943495848728, 7.022367813028454, 0.0, 7.434628227636725, 7.679480099505446, 7.643856189774724, 6.321928094887363, 5.977279923499917, 4.584962500721156, 5.459431618637297, 5.930737337562887, 5.807354922057604, 4.906890595608519, 5.129283016944966, 6.491853096329675, 6.584962500721156, 7.011227255423254, 3.9068905956085187, 6.149747119504682, 5.78135971352466, 5.807354922057604, 5.672425341971495, 5.285402218862249, 5.247927513443585, 5.247927513443585, 7.7073591320808825, 8.330916878114618, 7.857980995127572, 6.906890595608519, 7.622051819456376, 7.531381460516312, 6.672425341971495, 5.832890014164741, 5.832890014164741, 5.832890014164741, 5.832890014164741, 7.118941072723508, 8.179909090014934, null, 6.247927513443585, 9.005624549193879, 4.954196310386875, 4.954196310386875, 6.965784284662087, 6.339850002884624, 6.643856189774724, 7.20945336562895, 7.199672344836364, 8.543031820255237, 8.262094845370179, 7.6293566200796095, 7.882643049361842, 8.842350343413807, 8.060695931687555, 7.622051819456376, 7.515699838284043, 8.774787059601174, 9.139551352398794, 8.915879378835774, 6.870364719583405, 8.353146825498083, 8.375039431346925, 7.727920454563199, 8.550746785383243, 7.562242424221073, 7.539158811108031, 7.539158811108031, 9.851749041416058, 10.480790201095816, 10.323054760341646, 9.35974956032233, 10.192292814470767, 9.654636028527968, 8.86418614465428, 7.918863237274595, 7.918863237274595, 7.918863237274595, 7.918863237274595, 9.513727595952437, 10.566054038171092, 7.108524456778169, 8.991521846075695, 12.044735626056909, 7.643856189774724, 7.643856189774724, 9.339850002884624, 9.59245703726808, 9.296916206879288, 9.78953364497036, 9.787902559391432, 8.290018846932618, 7.60733031374961, 6.643856189774724, 7.247927513443585, 7.870364719583405, 7.820178962415188, 6.930737337562887, 7.303780748177103, 8.654636028527968, 8.64745842645492, 8.57742882803575, 6.754887502163468, 7.672425341971495, 7.721099188707185, 7.459431618637297, 7.78135971352466, 7.312882955284356, 7.442943495848728, 7.442943495848728, 9.162391328756906, 9.896332403909941, 9.912889336229961, 8.918863237274595, 9.583082767502933, 9.560332834212442, 8.257387842692651, 7.330916878114617, 7.330916878114617, 7.330916878114617, 7.330916878114617, 9.113742166049189, 10.161131882984307, 3.584962500721156, 8.672425341971495, 10.746514321138463, 8.184875342908283, 8.184875342908283, 9.14210705730255, 8.103287808412022, 8.62935662007961, 9.172427508645482, 9.144658242831882, 7.845490050944375, 7.845490050944375, 7.734709620225838, 8.43879185257826, 9.044394119358454, 8.199672344836364, 6.870364719583405, 7.357552004618084, 8.668884984266247, 8.569855608330949, 8.870364719583405, 6.614709844115208, 7.584962500721156, 7.807354922057604, 7.459431618637297, 8.63662462054365, 7.2761244052742375, 7.266786540694901, 7.266786540694901, 9.111135670234708, 9.862637357558794, 9.754887502163468, 9.002815015607053, 9.668884984266247, 9.876516946565, 8.689997971419446, 7.679480099505446, 7.672425341971495, 7.672425341971495, 7.672425341971495, 9.911391987843459, 10.940313597145968, 4.169925001442312, 8.550746785383243, 10.700439718141093, 7.78135971352466, 7.78135971352466, 8.335390354693924, 9.076815597050832, 8.78135971352466, 9.584962500721156, 9.586839787961827, 6.954196310386875, 6.845490050944375, 6.129283016944966, 6.539158811108031, 7.434628227636725, 6.599912842187128, 4.754887502163468, 6.189824558880018, 7.948367231584678, 7.900866807980749, 7.839203788096944, 5.247927513443585, 7.257387842692652, 7.22881869049588, 6.870364719583405, 5.643856189774724, 6.491853096329675, 6.643856189774724, 6.643856189774724, 8.92481250360578, 9.590587049915035, 9.060695931687555, 8.20945336562895, 8.870364719583405, 8.721099188707186, 7.592457037268081, 6.714245517666122, 6.714245517666122, 6.714245517666122, 6.700439718141092, 8.189824558880018, 9.252665432450248, 1.584962500721156, 7.734709620225838, 9.826548487290914, 7.022367813028454, 7.022367813028454, 8.257387842692651, 7.149747119504682, 7.727920454563199, 8.303780748177102, 8.280770770130603, 7.523561956057013, 7.149747119504682, 6.459431618637297, 6.918863237274595, 7.658211482751795, 7.257387842692652, 5.906890595608519, 6.643856189774724, 8.179909090014934, 8.0, 8.139551352398794, 5.882643049361842, 7.066089190457772, 7.149747119504682, 6.918863237274595, 6.845490050944375, 6.539158811108031, 6.569855608330948, 6.569855608330948, 8.951284714966972, 9.659995892429977, 9.4241662888181, 8.603626344986193, 9.187352073200497, 8.991521846075695, 8.049848549450562, 7.285402218862249, 7.285402218862249, 7.285402218862249, 7.266786540694901, 8.640244936222345, 9.702172685365548, 3.321928094887362, 8.189824558880018, 10.30035256032822, 6.870364719583405, 6.870364719583405, 8.459431618637296, 7.930737337562887, 7.98299357469431, 8.59618975614441, 8.562242424221072, 7.1799090900149345, 6.149747119504682, 6.523561956057013, 6.22881869049588, 7.1799090900149345, 6.727920454563199, 5.459431618637297, 5.954196310386875, 7.546894459887636, 7.658211482751795, 7.888743248898259, 5.392317422778761, 6.491853096329675, 6.523561956057013, 6.3750394313469245, 6.189824558880018, 6.0, 6.303780748177103, 6.303780748177103, 8.614709844115207, 9.159871336778389, 8.894817763307943, 8.124121311829187, 8.72451385311995, 8.751544059089099, 7.584962500721156, 6.754887502163468, 6.754887502163468, 6.754887502163468, 6.741466986401147, 7.930737337562887, 9.002815015607053, null, 7.721099188707185, 9.78953364497036, 6.087462841250339, 6.087462841250339, 8.447083226209653, 7.539158811108031, 7.693486957499325, 8.159871336778389, 8.134426320220927, 7.05528243550119, 6.169925001442312, 6.169925001442312, 6.714245517666122, 7.20945336562895, 6.754887502163468, 5.727920454563199, 5.857980995127572, 7.614709844115208, 7.636624620543649, 7.60733031374961, 5.491853096329675, 6.857980995127572, 6.794415866350106, 6.339850002884624, 6.409390936137702, 5.426264754702098, 6.066089190457772, 6.066089190457772, 8.475733430966399, 9.339850002884624, 9.057991722759176, 7.977279923499917, 8.632995197142957, 8.64745842645492, 7.832890014164741, 6.906890595608519, 6.906890595608519, 6.894817763307944, 6.882643049361842, 7.977279923499917, 9.08214904135387, 2.0, 7.870364719583405, 10.635718120331047, 6.303780748177103, 6.303780748177103, 7.774787059601174, 8.169925001442312, 7.247927513443585, 8.224001674198105, 8.204571144249204, 6.0, 5.700439718141092, 5.087462841250339, 5.044394119358453, 6.0, 5.700439718141092, 5.169925001442312, 5.129283016944966, 6.108524456778169, 6.392317422778761, 7.022367813028454, 2.807354922057604, 5.832890014164741, 5.321928094887363, 5.700439718141092, 5.954196310386875, 4.754887502163468, 5.087462841250339, 5.087462841250339, 7.820178962415188, 8.247927513443585, 7.679480099505446, 6.820178962415188, 7.339850002884624, 7.693486957499325, 6.930737337562887, 5.930737337562887, 5.930737337562887, 5.930737337562887, 5.906890595608519, 7.139551352398794, 8.169925001442312, 0.0, 6.409390936137702, 8.754887502163468, 4.954196310386875, 4.954196310386875, 7.483815777264256, 5.523561956057013, 6.672425341971495, 7.169925001442312, 7.139551352398794, null, null, null, null, null, 0.0, null, null, null, null, null, null, null, 0.0, null, null, null, null, null, 0.0, 2.0, null, null, 0.0, null, 1.0, null, null, null, null, null, 0.0, null, 1.0, null, null, null, 0.0, 0.0, null, 0.0, 0.0, 6.169925001442312, 6.044394119358453, 5.087462841250339, 5.169925001442312, 5.754887502163468, 5.129283016944966, 5.426264754702098, 4.906890595608519, 6.700439718141092, 6.409390936137702, 6.845490050944375, 3.584962500721156, 5.247927513443585, 5.754887502163468, 5.357552004618084, 6.599912842187128, 5.672425341971495, 5.727920454563199, 5.727920454563199, 7.539158811108031, 8.224001674198105, 7.864186144654281, 6.845490050944375, 7.562242424221073, 7.22881869049588, 6.584962500721156, 5.643856189774724, 5.643856189774724, 5.643856189774724, 5.643856189774724, 6.965784284662087, 7.977279923499917, 0.0, 6.491853096329675, 9.804131021183318, 5.906890595608519, 5.906890595608519, 6.569855608330948, 7.0, 6.977279923499917, 7.400879436282184, 7.312882955284356, 6.94251450533924, 6.491853096329675, 5.906890595608519, 6.247927513443585, 6.426264754702098, 6.906890595608519, 5.614709844115208, 5.459431618637297, 7.523561956057013, 7.266786540694901, 7.266786540694901, 4.700439718141092, 6.392317422778761, 6.768184324776926, 6.392317422778761, 6.0, 5.643856189774724, 6.149747119504682, 6.149747119504682, 8.124121311829187, 8.96289600533726, 8.710806433699352, 7.768184324776926, 8.303780748177102, 8.361943773735241, 7.3750394313469245, 6.614709844115208, 6.614709844115208, 6.614709844115208, 6.614709844115208, 8.016808287686555, 9.016808287686555, 2.321928094887362, 7.321928094887363, 10.752380646552893, 6.507794640198696, 6.507794640198696, 7.6653359171851765, 7.592457037268081, 7.60733031374961, 7.6293566200796095, 7.562242424221073, 5.614709844115208, 5.0, 4.754887502163468, 4.754887502163468, 5.426264754702098, 4.643856189774724, 3.321928094887362, 4.247927513443585, 5.906890595608519, 6.768184324776926, 6.022367813028454, 2.584962500721156, 4.857980995127572, 5.247927513443585, 4.906890595608519, 4.584962500721156, 4.523561956057013, 4.643856189774724, 4.643856189774724, 7.022367813028454, 7.507794640198696, 7.199672344836364, 6.169925001442312, 6.807354922057604, 6.754887502163468, 5.954196310386875, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.169925001442312, 5.906890595608519, 6.954196310386875, null, 5.426264754702098, 8.405141463136344, 5.087462841250339, 5.087462841250339, 5.954196310386875, 5.392317422778761, 6.643856189774724, 6.129283016944966, 6.087462841250339, 8.948367231584678, 8.768184324776927, 7.658211482751795, 8.375039431346925, 8.861086905995395, 8.50382573799575, 7.60733031374961, 7.507794640198696, 9.326429487122303, 9.283088353024002, 9.622051819456376, 7.066089190457772, 8.471675214392045, 8.791162888555018, 8.224001674198105, 8.055282435501189, 7.679480099505446, 7.870364719583405, 7.870364719583405, 10.233619676759702, 10.639340708652231, 10.468624042918018, 9.674192268145683, 10.383704292474052, 9.868822554774999, 9.400879436282183, 8.45532722030456, 8.451211111832329, 8.451211111832329, 8.413627929024173, 9.905387005018131, 10.95492329203032, 4.169925001442312, 9.192292814470767, 11.597121428789569, 8.049848549450562, 8.049848549450562, 9.859534786382653, 1.0, 9.703903573444663, 9.90388184573618, 9.897845456005511, 6.189824558880018, 5.882643049361842, 5.672425341971495, 5.426264754702098, 6.22881869049588, 6.129283016944966, 6.022367813028454, 5.491853096329675, 7.044394119358453, 7.189824558880018, 7.219168520462161, 4.169925001442312, 5.857980995127572, 5.614709844115208, 5.285402218862249, 6.643856189774724, 5.426264754702098, 5.247927513443585, 5.247927513443585, 7.6865005271832185, 8.262094845370179, 8.0, 7.108524456778169, 7.787902559391432, 7.507794640198696, 6.965784284662087, 6.087462841250339, 6.087462841250339, 6.087462841250339, 6.022367813028454, 6.807354922057604, 7.912889336229962, 0.0, 6.918863237274595, 9.022367813028454, 5.857980995127572, 5.857980995127572, 6.965784284662087, 5.906890595608519, 6.845490050944375, 7.22881869049588, 7.22881869049588, 7.870364719583405, 7.754887502163468, 6.727920454563199, 7.199672344836364, 7.6293566200796095, 7.6293566200796095, 6.794415866350106, 6.906890595608519, 8.243173983472952, 8.184875342908283, 8.285402218862249, 5.643856189774724, 7.515699838284043, 7.658211482751795, 6.727920454563199, 7.636624620543649, 6.672425341971495, 7.169925001442312, 7.169925001442312, 9.422064766172813, 9.862637357558794, 9.638435913990472, 8.682994583681683, 9.428360172704291, 9.174925682500678, 8.43879185257826, 7.507794640198696, 7.499845887083206, 7.499845887083206, 7.491853096329675, 8.778077129535358, 9.86573327085176, 0.0, 7.741466986401147, 10.382624026574916, 7.139551352398794, 7.139551352398794, 9.00842862207058, 7.912889336229962, 8.08214904135387, 8.829722735086058, 8.823367240046235, 7.330916878114617, 7.189824558880018, 6.643856189774724, 6.741466986401147, 7.400879436282184, 6.741466986401147, 6.741466986401147, 6.475733430966398, 7.924812503605781, 8.092757140919852, 8.344295907915816, 5.832890014164741, 6.894817763307944, 6.554588851677638, 6.459431618637297, 7.20945336562895, 6.22881869049588, 6.554588851677638, 6.554588851677638, 8.842350343413807, 9.285402218862249, 9.31741261376487, 7.994353436858858, 8.791162888555018, 8.554588851677638, 7.864186144654281, 6.820178962415188, 6.807354922057604, 6.807354922057604, 6.807354922057604, 8.257387842692651, 9.364134655008051, 2.584962500721156, 8.092757140919852, 11.025139562278508, 6.794415866350106, 6.794415866350106, 8.076815597050832, 8.409390936137703, 7.643856189774724, 8.388017285345136, 8.375039431346925, 7.2384047393250786, 7.066089190457772, 6.022367813028454, 6.339850002884624, 7.339850002884624, 6.820178962415188, 6.6865005271832185, 6.6293566200796095, 7.78135971352466, 8.252665432450248, 8.294620748891626, 6.22881869049588, 5.930737337562887, 7.1799090900149345, 6.426264754702098, 7.348728154231077, 6.303780748177103, 6.700439718141092, 6.700439718141092, 8.727920454563199, 9.774787059601174, 9.328674927327947, 8.184875342908283, 8.971543553950772, 8.936637939002571, 8.044394119358454, 7.339850002884624, 7.339850002884624, 7.339850002884624, 7.330916878114617, 8.189824558880018, 9.273795599214264, 1.584962500721156, 7.643856189774724, 11.054604317960672, 7.339850002884624, 7.339850002884624, 8.344295907915816, 8.379378367071261, 7.672425341971495, 8.339850002884624, 8.31741261376487, 2.321928094887362, 1.0, 1.0, 0.0, 2.321928094887362, 1.0, 1.584962500721156, 0.0, 1.584962500721156, 1.0, 1.0, 0.0, null, 1.584962500721156, 0.0, null, 0.0, 1.0, 1.0, 2.321928094887362, 2.0, 2.584962500721156, 2.807354922057604, 3.169925001442312, 3.4594316186372973, 1.584962500721156, 1.0, 0.0, 0.0, 0.0, 1.0, 1.584962500721156, null, null, 4.247927513443585, 1.0, 1.0, 2.584962500721156, 2.0, 2.0, 2.584962500721156, 2.321928094887362, 6.870364719583405, 6.339850002884624, 5.20945336562895, 5.906890595608519, 7.066089190457772, 6.459431618637297, 5.672425341971495, 6.022367813028454, 7.383704292474052, 7.321928094887363, 7.6653359171851765, 5.584962500721156, 6.658211482751795, 6.491853096329675, 6.357552004618084, 5.954196310386875, 5.882643049361842, 5.727920454563199, 5.727920454563199, 8.339850002884624, 8.848622940429339, 8.707359132080883, 7.754887502163468, 8.467605550082997, 8.219168520462162, 7.357552004618084, 6.599912842187128, 6.584962500721156, 6.584962500721156, 6.584962500721156, 7.813781191217037, 8.879583249612784, null, 7.321928094887363, 9.481799431665753, 6.459431618637297, 6.459431618637297, 7.515699838284043, 6.475733430966398, 7.189824558880018, 7.839203788096944, 7.820178962415188, 5.643856189774724, 5.20945336562895, 5.285402218862249, 5.459431618637297, 5.523561956057013, 5.321928094887363, 4.459431618637297, 4.643856189774724, 6.459431618637297, 6.3750394313469245, 6.0, 3.169925001442312, 5.672425341971495, 5.807354922057604, 5.247927513443585, 5.285402218862249, 4.857980995127572, 4.584962500721156, 4.584962500721156, 6.977279923499917, 8.016808287686555, 7.330916878114617, 6.569855608330948, 7.159871336778389, 7.076815597050831, 6.357552004618084, 5.459431618637297, 5.459431618637297, 5.459431618637297, 5.426264754702098, 6.189824558880018, 7.2761244052742375, 0.0, 6.303780748177103, 9.552669097514272, 4.459431618637297, 4.459431618637297, 6.94251450533924, 6.807354922057604, 6.303780748177103, 6.6865005271832185, 6.643856189774724, null, null, null, null, null, null, null, null, null, null, null, null, 1.0, 0.0, null, null, null, 0.0, 0.0, null, 2.321928094887362, 0.0, 1.0, 1.584962500721156, null, null, null, null, null, null, null, 2.0, 0.0, 2.584962500721156, null, null, null, null, null, null, 0.0, 1.0, 6.321928094887363, 6.266786540694901, 5.129283016944966, 5.672425341971495, 6.426264754702098, 6.129283016944966, 5.672425341971495, 5.523561956057013, 7.011227255423254, 7.199672344836364, 7.0, 5.247927513443585, 5.857980995127572, 5.672425341971495, 5.807354922057604, 6.409390936137702, 5.523561956057013, 5.672425341971495, 5.672425341971495, 7.515699838284043, 8.59245703726808, 8.247927513443585, 7.1799090900149345, 7.78135971352466, 7.714245517666122, 6.954196310386875, 5.954196310386875, 5.930737337562887, 5.930737337562887, 5.906890595608519, 7.139551352398794, 8.214319120800766, 4.392317422778761, 7.0, 10.171176797651771, 6.149747119504682, 6.149747119504682, 7.900866807980749, 7.139551352398794, 7.1799090900149345, 7.467605550082998, 7.426264754702098, 7.189824558880018, 6.794415866350106, 5.129283016944966, 6.044394119358453, 6.672425341971495, 6.768184324776926, 5.857980995127572, 6.20945336562895, 7.679480099505446, 7.20945336562895, 7.303780748177103, 5.044394119358453, 7.257387842692652, 6.614709844115208, 6.339850002884624, 6.426264754702098, 6.247927513443585, 6.044394119358453, 6.044394119358453, 7.693486957499325, 8.734709620225837, 8.531381460516313, 7.672425341971495, 8.285402218862249, 8.098032082960527, 7.076815597050831, 6.285402218862249, 6.266786540694901, 6.266786540694901, 6.266786540694901, 7.787902559391432, 8.829722735086058, 0.0, 7.451211111832329, 9.63117705570398, 6.108524456778169, 6.108524456778169, 6.741466986401147, 6.832890014164741, 7.357552004618084, 8.076815597050832, 8.027905996569885, 4.247927513443585, 4.392317422778761, 4.0, 3.807354922057604, 4.392317422778761, 4.584962500721156, 3.321928094887362, 3.0, 5.247927513443585, 5.087462841250339, 4.906890595608519, 2.584962500721156, 3.807354922057604, 4.169925001442312, 3.169925001442312, 2.321928094887362, 3.700439718141092, 3.0, 3.0, 5.906890595608519, 6.599912842187128, 5.426264754702098, 5.247927513443585, 5.672425341971495, 5.977279923499917, 5.392317422778761, 4.392317422778761, 4.392317422778761, 4.392317422778761, 4.392317422778761, 5.087462841250339, 6.22881869049588, null, 5.20945336562895, 6.906890595608519, 3.700439718141092, 3.700439718141092, 5.727920454563199, 0.0, 5.491853096329675, 5.643856189774724, 5.672425341971495, 6.845490050944375, 7.03342300153745, 5.700439718141092, 5.754887502163468, 6.954196310386875, 5.977279923499917, 6.357552004618084, 6.409390936137702, 7.851749041416057, 8.774787059601174, 7.539158811108031, 5.0, 5.954196310386875, 7.159871336778389, 6.357552004618084, 6.321928094887363, 5.807354922057604, 5.857980995127572, 5.857980995127572, 9.9901039638575, 10.661778097771988, 8.74819284958946, 7.787902559391432, 8.703903573444663, 7.774787059601174, 7.651051691178929, 6.894817763307944, 6.857980995127572, 6.857980995127572, 6.794415866350106, 7.787902559391432, 8.876516946565, 3.584962500721156, 6.614709844115208, 10.369597346278677, 6.087462841250339, 6.087462841250339, 8.451211111832329, 6.954196310386875, 7.257387842692652, 7.882643049361842, 7.851749041416057, 7.219168520462161, 6.3750394313469245, 5.20945336562895, 6.149747119504682, 6.303780748177103, 6.870364719583405, 6.459431618637297, 6.768184324776926, 7.851749041416057, 7.912889336229962, 7.900866807980749, 4.169925001442312, 7.044394119358453, 7.339850002884624, 5.78135971352466, 5.78135971352466, 6.22881869049588, 5.321928094887363, 5.321928094887363, 9.342074667999139, 9.60733031374961, 9.169925001442312, 8.339850002884624, 9.238404739325079, 7.864186144654281, 7.523561956057013, 6.906890595608519, 6.906890595608519, 6.906890595608519, 6.894817763307944, 7.507794640198696, 8.588714635582264, 1.584962500721156, 6.906890595608519, 9.88264304936184, 5.643856189774724, 5.643856189774724, 8.665335917185176, 6.714245517666122, 7.794415866350106, 7.768184324776926, 7.7481928495894605, 6.459431618637297, 5.807354922057604, 3.4594316186372973, 5.087462841250339, 5.807354922057604, 5.087462841250339, 4.954196310386875, 5.426264754702098, 7.159871336778389, 7.562242424221073, 6.108524456778169, 4.0, 5.807354922057604, 6.845490050944375, 5.700439718141092, 5.357552004618084, 4.523561956057013, 5.392317422778761, 5.392317422778761, 8.618385502258606, 9.67595703294175, 8.228818690495881, 7.098032082960526, 8.022367813028454, 7.451211111832329, 6.584962500721156, 5.807354922057604, 5.78135971352466, 5.78135971352466, 5.78135971352466, 6.965784284662087, 8.049848549450562, 0.0, 6.392317422778761, 8.94251450533924, 5.392317422778761, 5.392317422778761, 6.845490050944375, 6.022367813028454, 7.523561956057013, 7.118941072723508, 7.098032082960526, 6.285402218862249, 5.643856189774724, 5.169925001442312, 4.584962500721156, 4.754887502163468, 5.321928094887363, 4.523561956057013, 5.247927513443585, 6.584962500721156, 7.139551352398794, 6.22881869049588, 4.523561956057013, 5.20945336562895, 5.930737337562887, 4.754887502163468, 4.392317422778761, 5.247927513443585, 4.392317422778761, 4.392317422778761, 8.276124405274238, 8.960001932068081, 7.845490050944375, 6.870364719583405, 7.6865005271832185, 6.930737337562887, 6.108524456778169, 5.20945336562895, 5.20945336562895, 5.20945336562895, 5.20945336562895, 6.491853096329675, 7.592457037268081, 2.0, 5.78135971352466, 9.489847960439297, 5.169925001442312, 5.169925001442312, 7.339850002884624, 5.459431618637297, 6.643856189774724, 6.6293566200796095, 6.599912842187128, 6.754887502163468, 6.108524456778169, 4.584962500721156, 5.700439718141092, 6.087462841250339, 6.247927513443585, 6.129283016944966, 5.392317422778761, 7.658211482751795, 8.59245703726808, 7.266786540694901, 5.044394119358453, 6.569855608330948, 6.727920454563199, 5.857980995127572, 5.321928094887363, 5.129283016944966, 5.459431618637297, 5.459431618637297, 9.709083812550343, 10.388017285345136, 8.527477006060396, 7.467605550082998, 8.531381460516313, 7.6293566200796095, 7.539158811108031, 6.768184324776926, 6.768184324776926, 6.768184324776926, 6.754887502163468, 7.442943495848728, 8.491853096329674, 3.321928094887362, 6.768184324776926, 9.08214904135387, 5.906890595608519, 5.906890595608519, 8.703903573444663, 6.614709844115208, 6.930737337562887, 7.614709844115208, 7.592457037268081, 6.714245517666122, 6.794415866350106, 5.954196310386875, 6.189824558880018, 6.930737337562887, 5.832890014164741, 5.129283016944966, 5.832890014164741, 7.169925001442312, 7.400879436282184, 7.294620748891627, 5.0, 6.442943495848728, 6.882643049361842, 6.066089190457772, 6.066089190457772, 5.807354922057604, 5.523561956057013, 5.523561956057013, 8.233619676759702, 8.640244936222345, 8.804131021183318, 8.098032082960527, 8.67595703294175, 8.179909090014934, 7.569855608330948, 6.727920454563199, 6.727920454563199, 6.727920454563199, 6.727920454563199, 7.977279923499917, 9.025139562278508, 0.0, 7.149747119504682, 10.35974956032233, 6.321928094887363, 6.339850002884624, 6.599912842187128, 7.011227255423254, 7.636624620543649, 7.839203788096944, 7.794415866350106, 1.0, 4.321928094887363, 6.523561956057013, 7.392317422778761, 8.174925682500678, null, null, 2.0, 3.807354922057604, 1.584962500721156, 1.584962500721156, 3.807354922057604, 1.0, null, 5.392317422778761, 6.754887502163468, 0.0, 3.169925001442312, 3.169925001442312, 1.584962500721156, 3.169925001442312, 2.584962500721156, 3.9068905956085187, 2.0, 6.22881869049588, 6.247927513443585, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.0, 9.20945336562895, 10.287712379549449, null, 1.584962500721156, 0.0, 4.459431618637297, 4.459431618637297, 1.0, 1.0, 1.0, 6.321928094887363, 6.266786540694901, 7.507794640198696, 7.044394119358453, 5.459431618637297, 5.930737337562887, 6.768184324776926, 6.599912842187128, 7.149747119504682, 6.357552004618084, 8.113742166049189, 9.011227255423254, 7.94251450533924, 5.977279923499917, 6.643856189774724, 7.303780748177103, 6.539158811108031, 6.442943495848728, 6.044394119358453, 5.882643049361842, 5.882643049361842, 10.211888294546004, 10.831307243802051, 9.228818690495881, 8.335390354693924, 9.108524456778168, 8.46352437327118, 8.134426320220927, 7.383704292474052, 7.383704292474052, 7.383704292474052, 7.357552004618084, 7.971543553950772, 9.079484783826816, 2.0, 7.383704292474052, 9.689997971419446, 6.741466986401147, 6.741466986401147, 9.52552080909507, 7.434628227636725, 8.087462841250339, 8.308339030139408, 8.29920801838728, 7.839203788096944, 7.257387842692652, 6.357552004618084, 6.94251450533924, 7.7073591320808825, 6.794415866350106, 7.2384047393250786, 6.807354922057604, 8.016808287686555, 8.124121311829187, 8.184875342908283, 5.882643049361842, 6.954196310386875, 7.679480099505446, 7.076815597050831, 7.366322214245816, 6.491853096329675, 6.569855608330948, 6.569855608330948, 8.603626344986193, 9.461479447286155, 9.622051819456376, 8.774787059601174, 9.432541900388259, 9.076815597050832, 8.159871336778389, 7.417852514885898, 7.409390936137702, 7.409390936137702, 7.400879436282184, 8.651051691178928, 9.719388820942083, 1.584962500721156, 7.994353436858858, 10.1357092861044, 6.894817763307944, 6.894817763307944, 8.430452551665532, 7.794415866350106, 8.194756854422248, 8.74819284958946, 8.721099188707186, 6.727920454563199, 6.022367813028454, 5.285402218862249, 5.614709844115208, 6.108524456778169, 5.584962500721156, 5.954196310386875, 5.087462841250339, 7.442943495848728, 8.060695931687555, 7.098032082960526, 4.169925001442312, 6.20945336562895, 6.22881869049588, 5.906890595608519, 5.672425341971495, 5.044394119358453, 5.491853096329675, 5.491853096329675, 8.90388184573618, 9.620219825507487, 8.519636252843213, 7.60733031374961, 8.285402218862249, 7.839203788096944, 7.149747119504682, 6.285402218862249, 6.285402218862249, 6.285402218862249, 6.266786540694901, 6.977279923499917, 8.113742166049189, 2.321928094887362, 6.768184324776926, 9.12670447284319, 5.754887502163468, 5.754887502163468, 8.055282435501189, 6.149747119504682, 7.434628227636725, 7.434628227636725, 7.451211111832329, 7.936637939002571, 7.60733031374961, 6.643856189774724, 7.577428828035749, 7.994353436858858, 7.20945336562895, 6.491853096329675, 7.22881869049588, 8.271463027904375, 8.071462362556623, 8.108524456778168, 6.727920454563199, 7.303780748177103, 8.08214904135387, 7.169925001442312, 7.3750394313469245, 6.285402218862249, 7.011227255423254, 7.011227255423254, 9.310612781659529, 9.481799431665753, 9.813781191217037, 8.873444112515376, 9.54882190845875, 9.002815015607053, 8.03342300153745, 7.219168520462161, 7.219168520462161, 7.219168520462161, 7.169925001442312, 8.857980995127573, 9.955649907528374, 2.0, 8.330916878114618, 11.347067657165871, 7.442943495848728, 7.451211111832329, 7.592457037268081, 7.7615512324444795, 8.731319031025064, 8.820178962415188, 8.845490050944376, 7.409390936137702, 6.918863237274595, 6.409390936137702, 6.022367813028454, 6.918863237274595, 6.507794640198696, 6.539158811108031, 6.409390936137702, 7.9886846867721655, 8.184875342908283, 8.022367813028454, 5.554588851677638, 6.6293566200796095, 7.139551352398794, 6.392317422778761, 6.672425341971495, 5.78135971352466, 5.930737337562887, 5.930737337562887, 9.99859042974533, 10.486835021563051, 9.238404739325079, 8.262094845370179, 8.94251450533924, 8.174925682500678, 7.936637939002571, 7.098032082960526, 7.098032082960526, 7.098032082960526, 7.098032082960526, 8.098032082960527, 9.194756854422248, 4.169925001442312, 7.330916878114617, 9.831307243802051, 6.189824558880018, 6.189824558880018, 9.0, 7.285402218862249, 7.918863237274595, 7.894817763307944, 7.900866807980749, 6.845490050944375, 6.845490050944375, 5.392317422778761, 5.807354922057604, 6.409390936137702, 5.807354922057604, 5.807354922057604, 5.523561956057013, 7.672425341971495, 8.257387842692651, 6.906890595608519, 4.169925001442312, 6.409390936137702, 6.507794640198696, 5.977279923499917, 5.491853096329675, 5.491853096329675, 5.357552004618084, 5.357552004618084, 9.44086916761087, 9.981567281903015, 8.854868383260236, 7.727920454563199, 8.558420713268664, 8.066089190457772, 7.022367813028454, 6.189824558880018, 6.189824558880018, 6.189824558880018, 6.169925001442312, 7.108524456778169, 8.228818690495881, 6.754887502163468, 7.219168520462161, 3.169925001442312, 5.78135971352466, 5.78135971352466, 8.027905996569885, 1.584962500721156, 7.03342300153745, 7.741466986401147, 7.754887502163468, 7.400879436282184, 6.954196310386875, 6.066089190457772, 6.22881869049588, 7.199672344836364, 6.392317422778761, 6.672425341971495, 5.906890595608519, 7.882643049361842, 8.499845887083206, 7.499845887083206, 5.20945336562895, 6.554588851677638, 7.219168520462161, 6.247927513443585, 6.442943495848728, 6.066089190457772, 6.149747119504682, 6.149747119504682, 9.57553924683453, 9.997179480937621, 9.159871336778389, 8.405141463136344, 9.144658242831882, 8.46352437327118, 7.6865005271832185, 7.011227255423254, 7.011227255423254, 7.011227255423254, 7.011227255423254, 8.134426320220927, 9.192292814470767, 2.584962500721156, 7.622051819456376, 10.697836357962377, 6.9886846867721655, 6.9886846867721655, 8.661778097771988, 8.076815597050832, 7.7073591320808825, 8.546894459887637, 8.50382573799575, 6.087462841250339, 5.700439718141092, 5.357552004618084, 5.321928094887363, 6.149747119504682, 4.906890595608519, 4.247927513443585, 5.20945336562895, 6.714245517666122, 7.622051819456376, 6.727920454563199, 4.392317422778761, 5.727920454563199, 6.129283016944966, 5.426264754702098, 4.0, 4.523561956057013, 5.0, 5.0, 8.79766152585376, 9.057991722759176, 8.03342300153745, 6.9886846867721655, 7.741466986401147, 7.294620748891627, 6.491853096329675, 5.614709844115208, 5.584962500721156, 5.584962500721156, 5.584962500721156, 6.643856189774724, 7.741466986401147, null, 5.857980995127572, 9.469641817239516, 4.700439718141092, 4.700439718141092, 7.1799090900149345, 5.584962500721156, 6.9886846867721655, 6.820178962415188, 6.727920454563199, 7.651051691178929, 6.807354922057604, 5.247927513443585, 5.78135971352466, 6.832890014164741, 7.011227255423254, 6.599912842187128, 7.129283016944966, 8.451211111832329, 8.611024797307353, 8.149747119504681, 4.807354922057604, 7.20945336562895, 7.894817763307944, 6.022367813028454, 5.727920454563199, 6.845490050944375, 5.285402218862249, 5.285402218862249, 9.726218159332198, 9.946906274456397, 9.668884984266247, 8.417852514885897, 9.605479518061669, 8.247927513443585, 8.20945336562895, 7.569855608330948, 7.569855608330948, 7.569855608330948, 7.562242424221073, 7.7615512324444795, 8.839203788096944, 4.392317422778761, 7.7481928495894605, 11.015415052386688, 5.832890014164741, 5.832890014164741, 7.918863237274595, 6.523561956057013, 8.066089190457772, 8.339850002884624, 8.326429487122303, 7.546894459887636, 7.139551352398794, 6.584962500721156, 6.614709844115208, 7.392317422778761, 6.894817763307944, 6.807354922057604, 6.672425341971495, 8.076815597050832, 8.581200581924957, 7.888743248898259, 4.954196310386875, 6.754887502163468, 7.392317422778761, 6.584962500721156, 6.22881869049588, 6.554588851677638, 5.930737337562887, 5.930737337562887, 9.717676423066395, 10.287712379549449, 9.509775004326936, 8.700439718141093, 9.523561956057012, 8.826548487290914, 7.851749041416057, 7.159871336778389, 7.149747119504682, 7.149747119504682, 7.149747119504682, 8.257387842692651, 9.364134655008051, null, 7.918863237274595, 10.134426320220927, 6.870364719583405, 6.870364719583405, 8.703903573444663, 7.531381460516312, 8.113742166049189, 8.50382573799575, 8.487840033823051, 7.807354922057604, 7.0, 6.044394119358453, 6.539158811108031, 7.2384047393250786, 6.954196310386875, 6.0, 6.3750394313469245, 8.011227255423254, 8.20945336562895, 8.113742166049189, 5.832890014164741, 6.78135971352466, 7.820178962415188, 6.857980995127572, 6.539158811108031, 6.523561956057013, 6.22881869049588, 6.22881869049588, 9.567956075415466, 10.108524456778168, 9.477758266443889, 8.717676423066395, 9.390168956200183, 8.81698362325538, 8.280770770130603, 7.507794640198696, 7.499845887083206, 7.499845887083206, 7.483815777264256, 8.271463027904375, 9.372865060112588, null, 7.569855608330948, 10.92851837525789, 7.159871336778389, 7.159871336778389, 8.614709844115207, 8.710806433699352, 7.864186144654281, 8.558420713268664, 8.554588851677638, 7.467605550082998, 6.475733430966398, 6.149747119504682, 6.20945336562895, 6.965784284662087, 6.906890595608519, 6.22881869049588, 6.20945336562895, 7.98299357469431, 8.238404739325079, 7.900866807980749, 5.672425341971495, 6.266786540694901, 7.199672344836364, 6.022367813028454, 6.426264754702098, 5.247927513443585, 6.266786540694901, 6.266786540694901, 9.3151495622563, 9.828136484194108, 9.174925682500678, 8.426264754702098, 9.041659151637214, 8.409390936137703, 7.734709620225838, 7.03342300153745, 7.022367813028454, 7.022367813028454, 7.0, 8.108524456778168, 9.172427508645482, 2.0, 7.78135971352466, 9.76487159073609, 6.087462841250339, 6.087462841250339, 7.960001932068081, 0.0, 7.754887502163468, 8.257387842692651, 8.285402218862249, 7.139551352398794, 6.087462841250339, 5.392317422778761, 6.149747119504682, 6.20945336562895, 6.129283016944966, 5.169925001442312, 6.266786540694901, 7.800899899920305, 8.59245703726808, 7.459431618637297, 4.807354922057604, 6.22881869049588, 6.832890014164741, 6.285402218862249, 5.727920454563199, 5.672425341971495, 5.727920454563199, 5.727920454563199, 9.459431618637296, 10.051208940914766, 8.927777962082342, 8.016808287686555, 8.86418614465428, 8.400879436282183, 7.727920454563199, 7.022367813028454, 7.022367813028454, 7.011227255423254, 6.965784284662087, 7.584962500721156, 8.668884984266247, 0.0, 6.977279923499917, 9.49585502688717, 6.22881869049588, 6.22881869049588, 7.539158811108031, null, 7.392317422778761, 7.971543553950772, 7.94251450533924, 7.832890014164741, 7.2384047393250786, 5.857980995127572, 6.6865005271832185, 8.044394119358454, 7.199672344836364, 6.6293566200796095, 7.0, 8.459431618637296, 8.83605035505807, 8.214319120800766, 5.78135971352466, 7.011227255423254, 7.7073591320808825, 6.9886846867721655, 7.011227255423254, 6.392317422778761, 7.087462841250339, 7.087462841250339, 9.906890595608518, 10.66622400280318, 9.874981347653774, 8.948367231584678, 9.734709620225837, 9.147204924942228, 8.357552004618084, 7.6293566200796095, 7.6293566200796095, 7.6293566200796095, 7.599912842187128, 8.599912842187127, 9.698704666770345, 0.0, 7.651051691178929, 10.381542951184585, 7.05528243550119, 7.05528243550119, 8.78135971352466, 7.900866807980749, 8.087462841250339, 8.948367231584678, 8.933690654952233, 7.539158811108031, 6.727920454563199, 7.011227255423254, 6.554588851677638, 7.219168520462161, 7.169925001442312, 5.832890014164741, 6.475733430966398, 8.189824558880018, 8.861086905995395, 8.430452551665532, 5.426264754702098, 6.523561956057013, 7.475733430966398, 6.475733430966398, 6.754887502163468, 6.189824558880018, 6.3750394313469245, 6.3750394313469245, 9.622051819456376, 10.134426320220927, 9.493855449240822, 8.731319031025064, 9.39231742277876, 8.76487159073609, 8.199672344836364, 7.330916878114617, 7.303780748177103, 7.303780748177103, 7.294620748891627, 8.247927513443585, 9.333155350310616, 5.459431618637297, 7.643856189774724, 10.172427508645482, 6.820178962415188, 6.820178962415188, 9.100662339005199, 7.554588851677638, 8.189824558880018, 8.475733430966399, 8.442943495848729, 7.011227255423254, 6.614709844115208, 5.357552004618084, 6.22881869049588, 6.727920454563199, 5.906890595608519, 6.3750394313469245, 6.149747119504682, 7.599912842187128, 8.531381460516313, 7.820178962415188, 4.459431618637297, 6.044394119358453, 7.05528243550119, 6.066089190457772, 6.303780748177103, 6.22881869049588, 5.754887502163468, 5.754887502163468, 9.116343961237469, 9.815383295813538, 9.111135670234708, 8.257387842692651, 8.985841937003341, 8.388017285345136, 7.515699838284043, 6.807354922057604, 6.807354922057604, 6.807354922057604, 6.794415866350106, 8.005624549193879, 9.090112419664289, 2.584962500721156, 6.9886846867721655, 9.682994583681683, 5.857980995127572, 5.857980995127572, 8.643856189774725, 7.2761244052742375, 7.467605550082998, 8.357552004618084, 8.339850002884624, 7.643856189774724, 7.392317422778761, 5.700439718141092, 6.149747119504682, 6.857980995127572, 7.357552004618084, 7.539158811108031, 6.643856189774724, 8.57742882803575, 9.174925682500678, 8.233619676759702, 4.321928094887363, 7.066089190457772, 7.6293566200796095, 6.794415866350106, 6.870364719583405, 6.357552004618084, 6.523561956057013, 6.523561956057013, 10.12023787734196, 11.020285500844647, 9.59618975614441, 8.758223214726724, 9.57742882803575, 8.930737337562887, 8.076815597050832, 7.3750394313469245, 7.3750394313469245, 7.3750394313469245, 7.348728154231077, 8.076815597050832, 9.18239435340453, 4.954196310386875, 7.7481928495894605, 10.186114239541643, 6.6293566200796095, 6.6293566200796095, 8.86418614465428, 7.366322214245816, 8.413627929024173, 8.672425341971495, 8.658211482751796, 2.584962500721156, 6.539158811108031, 1.0, 2.807354922057604, 3.321928094887362, 1.0, 1.584962500721156, 1.0, 3.4594316186372973, 4.0, 2.0, 4.584962500721156, 2.584962500721156, 3.0, 6.087462841250339, 3.700439718141092, 2.321928094887362, 5.584962500721156, 5.584962500721156, 5.523561956057013, 6.022367813028454, 4.857980995127572, 6.0, 5.044394119358453, 8.290018846932618, 4.247927513443585, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 3.169925001442312, 4.857980995127572, 5.906890595608519, null, 2.584962500721156, 1.0, 5.643856189774724, 5.643856189774724, 4.0, null, 3.584962500721156, 7.60733031374961, 7.554588851677638, 7.139551352398794, 6.614709844115208, 5.554588851677638, 5.491853096329675, 5.930737337562887, 6.247927513443585, 6.442943495848728, 5.491853096329675, 7.807354922057604, 8.479780264029099, 7.149747119504682, 5.087462841250339, 6.700439718141092, 6.475733430966398, 5.977279923499917, 6.22881869049588, 4.954196310386875, 6.129283016944966, 6.129283016944966, 9.417852514885897, 10.321928094887362, 8.768184324776927, 8.103287808412022, 8.758223214726724, 8.228818690495881, 7.022367813028454, 6.339850002884624, 6.339850002884624, 6.339850002884624, 6.303780748177103, 7.159871336778389, 8.271463027904375, 5.087462841250339, 7.257387842692652, 9.233619676759702, 6.247927513443585, 6.247927513443585, 8.957102041562287, 6.6865005271832185, 7.339850002884624, 7.924812503605781, 7.900866807980749, 5.832890014164741, 6.087462841250339, 4.584962500721156, 5.20945336562895, 5.554588851677638, 5.832890014164741, 5.285402218862249, 4.523561956057013, 7.159871336778389, 7.643856189774724, 6.727920454563199, 3.584962500721156, 6.0, 6.108524456778169, 5.0, 5.321928094887363, 4.087462841250339, 5.169925001442312, 5.169925001442312, 8.686500527183219, 9.285402218862249, 7.882643049361842, 7.044394119358453, 7.7073591320808825, 7.321928094887363, 6.584962500721156, 5.727920454563199, 5.727920454563199, 5.727920454563199, 5.727920454563199, 6.357552004618084, 7.491853096329675, 3.807354922057604, 6.658211482751795, 9.638435913990472, 5.523561956057013, 5.523561956057013, 8.124121311829187, 6.977279923499917, 6.78135971352466, 7.129283016944966, 7.087462841250339, 6.022367813028454, 6.087462841250339, 5.0, 4.807354922057604, 6.149747119504682, 6.169925001442312, 5.523561956057013, 4.700439718141092, 7.339850002884624, 8.276124405274238, 7.03342300153745, 4.584962500721156, 5.832890014164741, 6.599912842187128, 5.459431618637297, 5.247927513443585, 5.20945336562895, 5.459431618637297, 5.459431618637297, 9.076815597050832, 9.800899899920305, 8.238404739325079, 7.348728154231077, 8.144658242831882, 7.434628227636725, 7.066089190457772, 6.189824558880018, 6.189824558880018, 6.189824558880018, 6.169925001442312, 7.219168520462161, 8.335390354693924, 3.807354922057604, 6.700439718141092, 9.945443836377912, 5.247927513443585, 5.247927513443585, 7.247927513443585, 0.0, 6.94251450533924, 7.400879436282184, 7.3750394313469245, 7.554588851677638, 7.483815777264256, 6.266786540694901, 6.409390936137702, 7.312882955284356, 7.011227255423254, 6.741466986401147, 6.409390936137702, 8.672425341971495, 9.044394119358454, 7.900866807980749, 5.672425341971495, 6.700439718141092, 7.592457037268081, 6.658211482751795, 6.357552004618084, 6.303780748177103, 6.584962500721156, 6.584962500721156, 9.78135971352466, 10.830515206976838, 9.791162888555018, 8.430452551665532, 9.445014845868423, 8.60733031374961, 7.994353436858858, 7.2761244052742375, 7.2761244052742375, 7.2761244052742375, 7.2384047393250786, 8.118941072723507, 9.236014191900084, 5.426264754702098, 7.700439718141092, 10.07815080773465, 6.700439718141092, 6.700439718141092, 9.513727595952437, 7.2761244052742375, 7.9886846867721655, 8.584962500721156, 8.562242424221072, 8.290018846932618, 7.6653359171851765, 6.523561956057013, 7.475733430966398, 8.071462362556623, 7.721099188707185, 6.906890595608519, 7.348728154231077, 8.81698362325538, 9.370687406807217, 8.951284714966972, 7.098032082960526, 7.087462841250339, 8.487840033823051, 7.383704292474052, 7.139551352398794, 6.9886846867721655, 6.9886846867721655, 6.9886846867721655, 10.544964432789238, 10.768184324776927, 10.145932145820515, 9.361943773735241, 10.131856960608793, 9.531381460516313, 8.873444112515376, 8.134426320220927, 8.134426320220927, 8.134426320220927, 8.134426320220927, 9.052568050804153, 10.161131882984307, 3.4594316186372973, 8.625708843064466, 10.694357887221452, 7.383704292474052, 7.383704292474052, 8.527477006060396, 2.0, 8.842350343413807, 9.240791332161956, 9.231221180711186, 7.2761244052742375, 6.599912842187128, 5.857980995127572, 6.658211482751795, 7.266786540694901, 6.149747119504682, 5.672425341971495, 6.807354922057604, 7.971543553950772, 8.413627929024173, 7.554588851677638, 5.906890595608519, 6.321928094887363, 7.400879436282184, 6.523561956057013, 6.087462841250339, 5.700439718141092, 6.022367813028454, 6.022367813028454, 9.588714635582264, 10.211888294546004, 9.079484783826816, 8.475733430966399, 9.129283016944967, 8.76487159073609, 7.658211482751795, 6.832890014164741, 6.820178962415188, 6.820178962415188, 6.794415866350106, 8.285402218862249, 9.388017285345136, 3.4594316186372973, 7.554588851677638, 10.703038388986418, 6.507794640198696, 6.507794640198696, 7.754887502163468, 7.467605550082998, 7.800899899920305, 8.344295907915816, 8.31741261376487, 7.918863237274595, 7.05528243550119, 6.392317422778761, 6.741466986401147, 7.426264754702098, 6.845490050944375, 6.523561956057013, 6.794415866350106, 8.499845887083206, 9.087462841250339, 8.366322214245816, 6.0, 6.906890595608519, 7.6653359171851765, 7.044394119358453, 6.569855608330948, 6.20945336562895, 6.554588851677638, 6.554588851677638, 10.084808387804362, 10.79766152585376, 9.554588851677638, 8.751544059089099, 9.436711542137214, 8.83605035505807, 8.479780264029099, 7.6865005271832185, 7.6865005271832185, 7.6865005271832185, 7.6653359171851765, 8.434628227636725, 9.517669388133811, 4.459431618637297, 7.864186144654281, 10.060695931687555, 7.044394119358453, 7.044394119358453, 8.199672344836364, 2.807354922057604, 8.326429487122303, 8.51175265376738, 8.515699838284043, 7.813781191217037, 7.159871336778389, 6.321928094887363, 6.78135971352466, 7.434628227636725, 7.0, 6.357552004618084, 6.599912842187128, 8.665335917185176, 9.231221180711186, 8.257387842692651, 6.044394119358453, 6.727920454563199, 7.906890595608519, 6.954196310386875, 6.303780748177103, 6.614709844115208, 6.507794640198696, 6.507794640198696, 10.363039630256514, 10.972261848733291, 9.77313920671969, 8.971543553950772, 9.731319031025064, 8.974414589805527, 8.290018846932618, 7.507794640198696, 7.507794640198696, 7.507794640198696, 7.442943495848728, 8.523561956057012, 9.588714635582264, 5.0, 7.813781191217037, 11.21006248324023, 6.882643049361842, 6.882643049361842, 9.129283016944967, 7.562242424221073, 8.335390354693924, 8.854868383260236, 8.832890014164741, 8.366322214245816, 7.930737337562887, 7.247927513443585, 7.467605550082998, 8.348728154231077, 7.9886846867721655, 7.285402218862249, 7.409390936137702, 8.74819284958946, 9.124121311829187, 8.968666793195208, 6.491853096329675, 7.614709844115208, 8.62935662007961, 7.426264754702098, 7.011227255423254, 7.129283016944966, 7.562242424221073, 7.562242424221073, 10.321928094887362, 10.90839262077375, 10.296916206879288, 9.394462694610317, 10.203348002979762, 9.569855608330949, 9.105908508571158, 8.471675214392045, 8.467605550082997, 8.467605550082997, 8.447083226209653, 9.273795599214264, 10.319672120946995, 4.807354922057604, 8.535275376620802, 11.5980525001616, 7.6653359171851765, 7.6653359171851765, 8.848622940429339, 8.434628227636725, 8.988684686772165, 9.485829308701904, 9.473705749619416, 7.523561956057013, 6.882643049361842, 5.754887502163468, 6.409390936137702, 6.832890014164741, 6.714245517666122, 6.820178962415188, 6.108524456778169, 8.257387842692651, 8.92184093707449, 8.303780748177102, 5.78135971352466, 6.087462841250339, 7.392317422778761, 6.3750394313469245, 6.714245517666122, 5.906890595608519, 6.044394119358453, 6.044394119358453, 9.975847968006784, 10.543998450134541, 9.375039431346925, 8.400879436282183, 9.071462362556623, 8.707359132080883, 7.832890014164741, 7.2384047393250786, 7.2384047393250786, 7.2384047393250786, 7.199672344836364, 7.918863237274595, 8.96289600533726, 1.0, 7.900866807980749, 9.67065624911844, 7.189824558880018, 7.189824558880018, 9.076815597050832, 7.392317422778761, 8.238404739325079, 8.29920801838728, 8.262094845370179, 7.2761244052742375, 6.643856189774724, 5.129283016944966, 6.129283016944966, 6.714245517666122, 6.714245517666122, 5.727920454563199, 6.22881869049588, 8.076815597050832, 8.668884984266247, 7.679480099505446, 5.357552004618084, 6.569855608330948, 7.348728154231077, 6.569855608330948, 6.22881869049588, 5.643856189774724, 5.643856189774724, 5.643856189774724, 9.519636252843213, 10.570804437724497, 9.095397022792557, 8.375039431346925, 9.087462841250339, 8.471675214392045, 7.614709844115208, 6.894817763307944, 6.894817763307944, 6.894817763307944, 6.845490050944375, 7.7615512324444795, 8.832890014164741, 0.0, 7.3750394313469245, 2.584962500721156, 6.507794640198696, 6.507794640198696, 8.558420713268664, 0.0, 7.714245517666122, 8.169925001442312, 8.159871336778389, 5.357552004618084, 4.807354922057604, 5.0, 4.906890595608519, 5.321928094887363, 4.754887502163468, 5.523561956057013, 4.459431618637297, 6.442943495848728, 7.011227255423254, 5.906890595608519, 4.321928094887363, 5.700439718141092, 5.754887502163468, 4.643856189774724, 4.906890595608519, 4.321928094887363, 4.523561956057013, 4.523561956057013, 8.326429487122303, 8.794415866350105, 7.614709844115208, 6.6293566200796095, 7.357552004618084, 6.6865005271832185, 6.507794640198696, 5.614709844115208, 5.614709844115208, 5.614709844115208, 5.584962500721156, 6.303780748177103, 7.321928094887363, 4.0, 5.459431618637297, 9.068778277985412, 4.807354922057604, 4.807354922057604, 7.483815777264256, 6.285402218862249, 6.044394119358453, 6.539158811108031, 6.507794640198696, 5.643856189774724, 4.954196310386875, 4.0, 4.321928094887363, 4.392317422778761, 4.392317422778761, 4.857980995127572, 4.321928094887363, 6.357552004618084, 7.459431618637297, 5.906890595608519, 4.0, 5.523561956057013, 5.357552004618084, 4.584962500721156, 4.087462841250339, 4.321928094887363, 4.584962500721156, 4.584962500721156, 8.348728154231077, 8.948367231584678, 7.076815597050831, 6.6865005271832185, 7.159871336778389, 6.9886846867721655, 6.169925001442312, 5.523561956057013, 5.523561956057013, 5.523561956057013, 5.523561956057013, 5.882643049361842, 6.965784284662087, null, 5.954196310386875, 8.08214904135387, 5.129283016944966, 5.129283016944966, 7.599912842187128, 0.0, 6.108524456778169, 6.459431618637297, 6.426264754702098, 5.832890014164741, 5.672425341971495, 4.700439718141092, 4.169925001442312, 5.247927513443585, 5.321928094887363, 4.700439718141092, 4.584962500721156, 6.569855608330948, 7.787902559391432, 6.022367813028454, 3.700439718141092, 5.20945336562895, 5.20945336562895, 4.321928094887363, 5.0, 3.4594316186372973, 4.392317422778761, 4.392317422778761, 8.361943773735241, 8.957102041562287, 7.636624620543649, 6.614709844115208, 7.330916878114617, 6.754887502163468, 6.149747119504682, 5.247927513443585, 5.247927513443585, 5.247927513443585, 5.247927513443585, 5.882643049361842, 7.03342300153745, null, 5.807354922057604, 7.9886846867721655, 4.321928094887363, 4.321928094887363, 8.005624549193879, 5.459431618637297, 6.599912842187128, 6.94251450533924, 6.882643049361842, 6.189824558880018, 6.129283016944966, 4.584962500721156, 4.584962500721156, 5.584962500721156, 5.754887502163468, 4.321928094887363, 5.087462841250339, 6.475733430966398, 6.658211482751795, 6.523561956057013, 4.0, 5.523561956057013, 6.303780748177103, 5.426264754702098, 5.0, 4.247927513443585, 4.954196310386875, 4.954196310386875, 7.721099188707185, 8.523561956057012, 7.734709620225838, 7.219168520462161, 7.851749041416057, 7.189824558880018, 6.965784284662087, 6.0, 6.0, 6.0, 5.977279923499917, 6.741466986401147, 7.820178962415188, 1.0, 6.22881869049588, 8.417852514885897, 5.169925001442312, 5.169925001442312, 6.491853096329675, 5.614709844115208, 6.569855608330948, 6.741466986401147, 6.672425341971495, 7.129283016944966, 6.9886846867721655, 5.754887502163468, 5.954196310386875, 6.965784284662087, 6.584962500721156, 6.3750394313469245, 6.303780748177103, 7.741466986401147, 8.39231742277876, 7.294620748891627, 5.169925001442312, 6.794415866350106, 7.066089190457772, 5.832890014164741, 6.20945336562895, 6.22881869049588, 6.426264754702098, 6.426264754702098, 9.407267764244732, 10.032045726930809, 9.121533517340032, 8.344295907915816, 9.152284842306582, 8.668884984266247, 7.768184324776926, 7.118941072723508, 7.108524456778169, 7.108524456778169, 7.108524456778169, 7.948367231584678, 8.991521846075695, 5.584962500721156, 7.321928094887363, 9.394462694610317, 6.475733430966398, 6.475733430966398, 8.86418614465428, 6.6293566200796095, 7.693486957499325, 8.113742166049189, 8.098032082960527, 7.303780748177103, 6.442943495848728, 6.066089190457772, 6.3750394313469245, 6.832890014164741, 6.930737337562887, 6.584962500721156, 6.108524456778169, 7.965784284662087, 8.294620748891626, 7.366322214245816, 5.672425341971495, 6.247927513443585, 7.05528243550119, 6.20945336562895, 6.442943495848728, 5.807354922057604, 5.807354922057604, 5.807354922057604, 9.285402218862249, 9.906890595608518, 8.945443836377912, 8.294620748891626, 8.804131021183318, 8.409390936137703, 7.483815777264256, 6.643856189774724, 6.643856189774724, 6.643856189774724, 6.6293566200796095, 7.700439718141092, 8.78135971352466, 2.584962500721156, 7.149747119504682, 9.684748620421626, 6.554588851677638, 6.554588851677638, 8.199672344836364, 6.930737337562887, 7.636624620543649, 7.954196310386875, 7.948367231584678, 6.977279923499917, 7.087462841250339, 5.554588851677638, 6.392317422778761, 6.870364719583405, 6.539158811108031, 6.94251450533924, 6.357552004618084, 7.977279923499917, 8.761551232444479, 7.6653359171851765, 5.78135971352466, 6.870364719583405, 7.1799090900149345, 6.169925001442312, 6.599912842187128, 5.930737337562887, 6.022367813028454, 6.022367813028454, 9.668884984266247, 9.92035285541508, 9.245552706255681, 8.321928094887362, 9.047123912114026, 8.519636252843213, 7.912889336229962, 7.108524456778169, 7.108524456778169, 7.108524456778169, 7.108524456778169, 7.960001932068081, 9.011227255423254, 5.584962500721156, 7.2384047393250786, 9.828136484194108, 6.6293566200796095, 6.6293566200796095, 8.909893083770042, 7.05528243550119, 7.864186144654281, 8.573647187493322, 8.566054038171092, 8.005624549193879, 7.426264754702098, 6.066089190457772, 6.672425341971495, 7.2761244052742375, 6.832890014164741, 7.011227255423254, 6.870364719583405, 8.543031820255237, 9.025139562278508, 8.434628227636725, 6.426264754702098, 6.94251450533924, 7.658211482751795, 6.741466986401147, 7.159871336778389, 6.672425341971495, 7.022367813028454, 7.022367813028454, 10.264442600226602, 10.812979471251483, 9.643856189774725, 8.79766152585376, 9.564149489985732, 9.044394119358454, 8.51175265376738, 7.721099188707185, 7.721099188707185, 7.721099188707185, 7.714245517666122, 8.531381460516313, 9.623881490013458, 3.807354922057604, 7.888743248898259, 10.247927513443585, 7.1799090900149345, 7.1799090900149345, 8.308339030139408, 7.672425341971495, 8.459431618637296, 8.845490050944376, 8.813781191217037, 6.584962500721156, 6.149747119504682, 5.357552004618084, 5.727920454563199, 6.044394119358453, 5.700439718141092, 5.491853096329675, 5.614709844115208, 7.139551352398794, 7.930737337562887, 6.741466986401147, 4.584962500721156, 5.807354922057604, 6.832890014164741, 5.906890595608519, 6.129283016944966, 5.0, 5.321928094887363, 5.321928094887363, 8.888743248898258, 9.187352073200497, 8.276124405274238, 7.459431618637297, 8.266786540694902, 7.569855608330948, 6.977279923499917, 6.247927513443585, 6.247927513443585, 6.247927513443585, 6.20945336562895, 6.965784284662087, 8.092757140919852, null, 6.870364719583405, 9.945443836377912, 5.832890014164741, 5.832890014164741, 7.651051691178929, 6.6865005271832185, 6.965784284662087, 7.569855608330948, 7.546894459887636, 6.426264754702098, 5.643856189774724, 4.807354922057604, 5.392317422778761, 6.247927513443585, 5.426264754702098, 5.357552004618084, 5.392317422778761, 7.339850002884624, 8.027905996569885, 7.05528243550119, 5.0, 5.247927513443585, 6.614709844115208, 5.491853096329675, 6.044394119358453, 5.20945336562895, 4.906890595608519, 4.906890595608519, 8.820178962415188, 9.44086916761087, 8.194756854422248, 7.577428828035749, 8.271463027904375, 7.651051691178929, 7.044394119358453, 6.22881869049588, 6.22881869049588, 6.22881869049588, 6.22881869049588, 7.087462841250339, 8.179909090014934, null, 6.247927513443585, 8.912889336229961, 5.087462841250339, 5.087462841250339, 7.912889336229962, 5.727920454563199, 7.189824558880018, 7.562242424221073, 7.546894459887636, 6.845490050944375, 6.672425341971495, 5.857980995127572, 6.409390936137702, 6.475733430966398, 6.741466986401147, 6.266786540694901, 5.930737337562887, 7.60733031374961, 8.266786540694902, 7.562242424221073, 5.78135971352466, 6.321928094887363, 6.906890595608519, 6.442943495848728, 6.584962500721156, 5.672425341971495, 6.149747119504682, 6.149747119504682, 9.111135670234708, 10.157346935362844, 8.754887502163468, 8.092757140919852, 8.751544059089099, 8.108524456778168, 7.247927513443585, 6.3750394313469245, 6.3750394313469245, 6.3750394313469245, 6.3750394313469245, 7.693486957499325, 8.731319031025064, 3.0, 7.159871336778389, 10.576484346796851, 6.523561956057013, 6.523561956057013, 8.535275376620802, 7.924812503605781, 7.599912842187128, 7.857980995127572, 7.845490050944375, 7.523561956057013, 7.169925001442312, 5.392317422778761, 5.727920454563199, 6.392317422778761, 6.768184324776926, 6.044394119358453, 6.285402218862249, 8.303780748177102, 9.152284842306582, 7.971543553950772, 5.129283016944966, 6.78135971352466, 7.651051691178929, 6.426264754702098, 5.906890595608519, 5.807354922057604, 6.426264754702098, 6.426264754702098, 9.918863237274595, 10.843921051289035, 9.098032082960527, 8.129283016944967, 8.939579214314692, 8.562242424221072, 7.857980995127572, 7.149747119504682, 7.149747119504682, 7.149747119504682, 7.118941072723508, 7.693486957499325, 8.758223214726724, 4.857980995127572, 7.285402218862249, 10.892542816648552, 6.768184324776926, 6.768184324776926, 9.531381460516313, 6.906890595608519, 8.092757140919852, 8.39231742277876, 8.375039431346925, 6.643856189774724, 6.0, 4.643856189774724, 5.357552004618084, 5.643856189774724, 5.392317422778761, 6.087462841250339, 5.672425341971495, 7.139551352398794, 7.826548487290915, 6.94251450533924, 4.459431618637297, 5.857980995127572, 6.022367813028454, 5.584962500721156, 5.700439718141092, 4.807354922057604, 5.491853096329675, 5.491853096329675, 8.31741261376487, 9.566054038171092, 7.864186144654281, 7.199672344836364, 7.794415866350106, 7.348728154231077, 6.285402218862249, 5.523561956057013, 5.523561956057013, 5.523561956057013, 5.491853096329675, 6.507794640198696, 7.599912842187128, null, 6.169925001442312, 8.800899899920305, 4.643856189774724, 4.643856189774724, 7.768184324776926, 5.614709844115208, 6.977279923499917, 7.118941072723508, 7.108524456778169, 6.0, 5.169925001442312, 4.169925001442312, 4.523561956057013, 5.087462841250339, 5.727920454563199, 5.285402218862249, 5.0, 6.700439718141092, 6.965784284662087, 6.599912842187128, 3.584962500721156, 5.044394119358453, 6.044394119358453, 5.392317422778761, 5.807354922057604, 4.807354922057604, 4.906890595608519, 4.906890595608519, 7.721099188707185, 8.857980995127573, 7.754887502163468, 7.044394119358453, 7.714245517666122, 7.169925001442312, 6.475733430966398, 5.672425341971495, 5.643856189774724, 5.643856189774724, 5.614709844115208, 6.643856189774724, 7.6653359171851765, null, 5.78135971352466, 8.51175265376738, 4.857980995127572, 4.857980995127572, 7.149747119504682, 5.754887502163468, 6.357552004618084, 6.930737337562887, 6.882643049361842, 7.044394119358453, 6.768184324776926, 4.321928094887363, 5.700439718141092, 6.108524456778169, 6.614709844115208, 5.882643049361842, 6.066089190457772, 8.044394119358454, 8.603626344986193, 7.515699838284043, 5.285402218862249, 6.569855608330948, 6.870364719583405, 6.247927513443585, 5.78135971352466, 5.977279923499917, 5.832890014164741, 5.832890014164741, 9.449148645375436, 10.550746785383243, 8.73809225962049, 7.7481928495894605, 8.426264754702098, 8.005624549193879, 7.294620748891627, 6.599912842187128, 6.599912842187128, 6.599912842187128, 6.569855608330948, 7.417852514885898, 8.515699838284043, 3.584962500721156, 7.266786540694901, 10.51175265376738, 5.285402218862249, 5.285402218862249, 9.060695931687555, 6.700439718141092, 7.599912842187128, 7.876516946564999, 7.851749041416057, 6.20945336562895, 6.022367813028454, 4.0, 5.247927513443585, 5.554588851677638, 5.044394119358453, 4.584962500721156, 5.554588851677638, 7.129283016944966, 7.864186144654281, 6.459431618637297, 4.584962500721156, 5.129283016944966, 5.930737337562887, 5.523561956057013, 4.523561956057013, 4.584962500721156, 4.906890595608519, 4.906890595608519, 8.67595703294175, 9.06339508128851, 7.569855608330948, 6.845490050944375, 7.562242424221073, 7.03342300153745, 6.491853096329675, 5.614709844115208, 5.614709844115208, 5.614709844115208, 5.491853096329675, 6.426264754702098, 7.562242424221073, null, 5.857980995127572, 9.353146825498083, 5.754887502163468, 5.754887502163468, 7.7481928495894605, 5.954196310386875, 6.584962500721156, 7.011227255423254, 6.94251450533924, 6.409390936137702, 6.3750394313469245, 4.523561956057013, 4.584962500721156, 5.672425341971495, 6.266786540694901, 5.392317422778761, 5.392317422778761, 7.0, 7.7481928495894605, 6.727920454563199, 5.0, 5.882643049361842, 6.599912842187128, 5.882643049361842, 5.857980995127572, 5.087462841250339, 4.321928094887363, 4.321928094887363, 8.81698362325538, 9.67065624911844, 8.276124405274238, 7.20945336562895, 7.965784284662087, 7.392317422778761, 6.6865005271832185, 5.672425341971495, 5.672425341971495, 5.672425341971495, 5.614709844115208, 6.820178962415188, 7.960001932068081, 4.700439718141092, 6.426264754702098, 9.06339508128851, 5.643856189774724, 5.643856189774724, 8.022367813028454, null, 7.139551352398794, 7.087462841250339, 7.066089190457772, 6.832890014164741, 6.108524456778169, 5.392317422778761, 5.584962500721156, 6.066089190457772, 6.149747119504682, 5.247927513443585, 5.357552004618084, 7.22881869049588, 7.888743248898259, 7.643856189774724, 5.169925001442312, 6.357552004618084, 6.643856189774724, 5.977279923499917, 5.643856189774724, 5.584962500721156, 5.523561956057013, 5.523561956057013, 8.813781191217037, 9.689997971419446, 8.50382573799575, 7.693486957499325, 8.442943495848729, 7.734709620225838, 6.754887502163468, 5.930737337562887, 5.930737337562887, 5.906890595608519, 5.906890595608519, 7.257387842692652, 8.312882955284355, 3.0, 6.918863237274595, 10.277287400130357, 6.044394119358453, 6.044394119358453, 7.900866807980749, 6.22881869049588, 7.643856189774724, 7.539158811108031, 7.491853096329675, 7.592457037268081, 7.066089190457772, 5.832890014164741, 6.066089190457772, 6.727920454563199, 6.614709844115208, 6.247927513443585, 6.189824558880018, 8.499845887083206, 9.174925682500678, 8.353146825498083, 5.930737337562887, 7.03342300153745, 7.577428828035749, 6.658211482751795, 6.044394119358453, 6.149747119504682, 6.539158811108031, 6.539158811108031, 10.080817527608327, 11.067434360756522, 9.432541900388259, 8.59245703726808, 9.189824558880018, 8.813781191217037, 7.888743248898259, 7.076815597050831, 7.066089190457772, 7.066089190457772, 7.03342300153745, 7.599912842187128, 8.686500527183219, 4.584962500721156, 7.467605550082998, 11.057991722759176, 6.894817763307944, 6.894817763307944, 8.90388184573618, 7.108524456778169, 7.888743248898259, 8.413627929024173, 8.405141463136344, 7.139551352398794, 6.894817763307944, 5.459431618637297, 5.930737337562887, 6.189824558880018, 6.169925001442312, 6.643856189774724, 5.643856189774724, 8.321928094887362, 8.614709844115207, 7.721099188707185, 5.247927513443585, 6.247927513443585, 7.2384047393250786, 6.3750394313469245, 5.882643049361842, 6.189824558880018, 6.108524456778169, 6.108524456778169, 9.485829308701904, 10.679480099505446, 8.980139577639157, 8.247927513443585, 8.997179480937621, 8.257387842692651, 7.507794640198696, 6.820178962415188, 6.820178962415188, 6.820178962415188, 6.820178962415188, 7.426264754702098, 8.515699838284043, 3.700439718141092, 7.321928094887363, 9.63117705570398, 6.3750394313469245, 6.3750394313469245, 9.095397022792557, 6.554588851677638, 7.787902559391432, 8.252665432450248, 8.233619676759702, 8.330916878114618, 7.700439718141092, 6.894817763307944, 6.930737337562887, 7.366322214245816, 7.149747119504682, 7.546894459887636, 7.076815597050831, 8.957102041562287, 9.144658242831882, 8.50382573799575, 6.22881869049588, 7.357552004618084, 7.672425341971495, 6.965784284662087, 7.348728154231077, 6.894817763307944, 6.845490050944375, 6.845490050944375, 10.217957697864113, 11.032734528586714, 10.011227255423254, 9.231221180711186, 9.888743248898258, 9.179909090014934, 8.479780264029099, 7.826548487290915, 7.826548487290915, 7.826548487290915, 7.813781191217037, 8.57742882803575, 9.638435913990472, 4.700439718141092, 8.087462841250339, 11.458406613236532, 7.098032082960526, 7.108524456778169, 9.20212382383046, 7.900866807980749, 8.731319031025064, 9.098032082960527, 9.06339508128851, 7.05528243550119, 6.9886846867721655, 5.459431618637297, 5.882643049361842, 6.392317422778761, 5.392317422778761, 6.285402218862249, 6.0, 7.894817763307944, 8.219168520462162, 7.257387842692652, 5.459431618637297, 6.539158811108031, 7.087462841250339, 6.285402218862249, 6.087462841250339, 5.807354922057604, 5.882643049361842, 5.882643049361842, 9.499845887083206, 10.35974956032233, 8.784634845557521, 8.271463027904375, 8.951284714966972, 8.417852514885897, 7.651051691178929, 6.807354922057604, 6.794415866350106, 6.794415866350106, 6.78135971352466, 7.6865005271832185, 8.807354922057604, 4.087462841250339, 7.312882955284356, 9.668884984266247, 6.22881869049588, 6.22881869049588, 8.011227255423254, 7.05528243550119, 7.554588851677638, 8.005624549193879, 8.0, 7.22881869049588, 6.894817763307944, 6.0, 6.339850002884624, 6.523561956057013, 6.741466986401147, 6.3750394313469245, 6.022367813028454, 8.189824558880018, 8.603626344986193, 7.78135971352466, 5.392317422778761, 6.507794640198696, 7.22881869049588, 5.807354922057604, 6.285402218862249, 5.754887502163468, 6.20945336562895, 6.20945336562895, 9.667111542075027, 10.54978466794786, 8.980139577639157, 8.519636252843213, 9.111135670234708, 8.499845887083206, 7.60733031374961, 6.94251450533924, 6.94251450533924, 6.94251450533924, 6.918863237274595, 7.768184324776926, 8.83605035505807, 1.0, 6.845490050944375, 9.988684686772165, 6.475733430966398, 6.475733430966398, 8.88264304936184, 7.169925001442312, 7.930737337562887, 8.139551352398794, 8.124121311829187, 6.94251450533924, 6.794415866350106, 5.459431618637297, 5.78135971352466, 6.129283016944966, 6.459431618637297, 6.20945336562895, 6.321928094887363, 7.721099188707185, 8.651051691178928, 7.523561956057013, 4.459431618637297, 6.584962500721156, 6.768184324776926, 6.129283016944966, 6.6865005271832185, 5.584962500721156, 5.906890595608519, 5.906890595608519, 9.417852514885897, 10.31741261376487, 8.829722735086058, 7.754887502163468, 8.672425341971495, 7.971543553950772, 7.483815777264256, 6.714245517666122, 6.714245517666122, 6.714245517666122, 6.714245517666122, 7.643856189774724, 8.72451385311995, 5.0, 7.159871336778389, 9.368506461507693, 6.321928094887363, 6.321928094887363, 8.930737337562887, 6.507794640198696, 7.700439718141092, 8.071462362556623, 8.076815597050832, 6.768184324776926, 6.727920454563199, 5.357552004618084, 5.700439718141092, 6.392317422778761, 6.6293566200796095, 5.930737337562887, 5.426264754702098, 7.426264754702098, 8.366322214245816, 7.03342300153745, 4.700439718141092, 6.247927513443585, 7.05528243550119, 5.584962500721156, 6.149747119504682, 5.857980995127572, 5.882643049361842, 5.882643049361842, 9.055282435501189, 10.002815015607053, 8.800899899920305, 7.876516946564999, 8.566054038171092, 8.098032082960527, 7.451211111832329, 6.6865005271832185, 6.672425341971495, 6.672425341971495, 6.643856189774724, 7.507794640198696, 8.566054038171092, 5.247927513443585, 7.1799090900149345, 10.277287400130357, 5.554588851677638, 5.584962500721156, 7.658211482751795, 6.857980995127572, 7.366322214245816, 8.0, 7.977279923499917, 4.584962500721156, 4.906890595608519, 4.0, 3.169925001442312, 4.169925001442312, 4.807354922057604, 3.9068905956085187, 4.247927513443585, 6.339850002884624, 6.409390936137702, 5.087462841250339, 4.0, 4.169925001442312, 5.392317422778761, 4.807354922057604, 2.807354922057604, 3.584962500721156, 4.523561956057013, 4.523561956057013, 7.813781191217037, 8.985841937003341, 7.2761244052742375, 6.20945336562895, 6.906890595608519, 6.129283016944966, 5.754887502163468, 4.857980995127572, 4.857980995127572, 4.857980995127572, 4.857980995127572, 5.523561956057013, 6.599912842187128, null, 5.459431618637297, 8.588714635582264, 3.584962500721156, 3.584962500721156, 7.199672344836364, 4.754887502163468, 5.285402218862249, 5.727920454563199, 5.727920454563199, 6.20945336562895, 5.754887502163468, 4.321928094887363, 4.807354922057604, 5.0, 4.807354922057604, 5.20945336562895, 4.0, 6.6865005271832185, 7.794415866350106, 6.285402218862249, 3.807354922057604, 5.247927513443585, 5.614709844115208, 4.857980995127572, 4.754887502163468, 4.169925001442312, 5.129283016944966, 5.129283016944966, 8.906890595608518, 9.231221180711186, 7.6865005271832185, 7.098032082960526, 7.679480099505446, 7.0, 5.882643049361842, 5.087462841250339, 5.087462841250339, 5.087462841250339, 5.087462841250339, 6.321928094887363, 7.348728154231077, 0.0, 6.247927513443585, 9.426264754702098, 4.906890595608519, 4.906890595608519, 7.820178962415188, 6.108524456778169, 6.930737337562887, 6.754887502163468, 6.6293566200796095, 7.066089190457772, 6.643856189774724, 5.882643049361842, 5.554588851677638, 6.768184324776926, 6.554588851677638, 5.857980995127572, 5.857980995127572, 7.658211482751795, 8.45532722030456, 7.569855608330948, 4.906890595608519, 6.266786540694901, 7.303780748177103, 6.523561956057013, 6.087462841250339, 6.022367813028454, 5.392317422778761, 5.392317422778761, 9.259743263690781, 9.967226258835993, 8.94251450533924, 8.396604781181859, 9.139551352398794, 8.357552004618084, 7.643856189774724, 6.954196310386875, 6.954196310386875, 6.954196310386875, 6.918863237274595, 8.159871336778389, 9.219168520462162, null, 7.05528243550119, 9.567956075415466, 6.129283016944966, 6.129283016944966, 8.422064766172813, 6.930737337562887, 7.787902559391432, 7.960001932068081, 7.954196310386875, 2.584962500721156, 2.584962500721156, null, null, 0.0, 2.584962500721156, 4.0, 1.584962500721156, 3.9068905956085187, 5.643856189774724, 3.700439718141092, null, 4.169925001442312, 3.321928094887362, 2.0, 0.0, 2.0, 2.807354922057604, 2.807354922057604, 6.459431618637297, 7.459431618637297, 5.247927513443585, 4.169925001442312, 5.0, 4.584962500721156, 2.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.0, null, 3.584962500721156, 4.906890595608519, null, null, 5.321928094887363, 2.584962500721156, 3.0, 3.321928094887362, 3.321928094887362, 6.832890014164741, 6.794415866350106, 5.426264754702098, 6.066089190457772, 6.794415866350106, 6.507794640198696, 6.321928094887363, 6.247927513443585, 7.787902559391432, 8.108524456778168, 7.459431618637297, 5.129283016944966, 6.643856189774724, 7.303780748177103, 6.6865005271832185, 5.554588851677638, 5.832890014164741, 5.754887502163468, 5.754887502163468, 9.224001674198105, 10.376125389276174, 9.226412192788786, 8.546894459887637, 9.100662339005199, 8.321928094887362, 7.754887502163468, 6.977279923499917, 6.977279923499917, 6.977279923499917, 6.94251450533924, 7.531381460516312, 8.599912842187127, null, 7.3750394313469245, 9.733015321685963, 6.569855608330948, 6.569855608330948, 7.507794640198696, 0.0, 7.499845887083206, 8.129283016944967, 8.118941072723507, 5.491853096329675, 5.459431618637297, 3.321928094887362, 4.321928094887363, 5.20945336562895, 5.169925001442312, 6.066089190457772, 4.584962500721156, 6.94251450533924, 7.845490050944375, 6.426264754702098, 4.169925001442312, 5.0, 5.584962500721156, 4.523561956057013, 4.523561956057013, 3.169925001442312, 5.087462841250339, 5.087462841250339, 8.451211111832329, 9.52552080909507, 7.693486957499325, 6.6293566200796095, 7.6653359171851765, 6.954196310386875, 6.643856189774724, 5.930737337562887, 5.930737337562887, 5.930737337562887, 5.906890595608519, 6.189824558880018, 7.303780748177103, null, 5.392317422778761, 9.113742166049189, 4.247927513443585, 4.247927513443585, 7.6865005271832185, 6.247927513443585, 6.392317422778761, 6.614709844115208, 6.599912842187128, 6.768184324776926, 6.475733430966398, 6.022367813028454, 5.672425341971495, 6.169925001442312, 5.906890595608519, 5.882643049361842, 5.285402218862249, 7.459431618637297, 8.098032082960527, 6.930737337562887, 5.0, 5.954196310386875, 6.554588851677638, 5.954196310386875, 6.392317422778761, 5.426264754702098, 5.459431618637297, 5.459431618637297, 8.873444112515376, 9.63662462054365, 8.562242424221072, 7.7615512324444795, 8.442943495848729, 7.918863237274595, 7.303780748177103, 6.491853096329675, 6.475733430966398, 6.475733430966398, 6.459431618637297, 7.3750394313469245, 8.519636252843213, 2.321928094887362, 6.614709844115208, 10.30720080914081, 5.954196310386875, 5.954196310386875, 8.475733430966399, 7.330916878114617, 7.1799090900149345, 7.651051691178929, 7.643856189774724, 7.129283016944966, 7.2761244052742375, 6.189824558880018, 6.169925001442312, 6.882643049361842, 6.129283016944966, 5.087462841250339, 5.832890014164741, 7.451211111832329, 7.554588851677638, 7.562242424221073, 5.523561956057013, 6.523561956057013, 7.108524456778169, 5.977279923499917, 6.303780748177103, 5.882643049361842, 5.832890014164741, 5.832890014164741, 8.573647187493322, 9.066089190457772, 8.88264304936184, 8.08214904135387, 8.717676423066395, 8.060695931687555, 7.515699838284043, 6.832890014164741, 6.832890014164741, 6.832890014164741, 6.832890014164741, 7.98299357469431, 9.057991722759176, null, 7.1799090900149345, 10.481799431665753, 6.321928094887363, 6.321928094887363, 6.9886846867721655, 7.0, 7.774787059601174, 7.98299357469431, 7.94251450533924, 6.882643049361842, 6.754887502163468, 5.554588851677638, 6.149747119504682, 6.507794640198696, 6.044394119358453, 6.285402218862249, 5.832890014164741, 7.022367813028454, 7.409390936137702, 6.906890595608519, 5.129283016944966, 6.169925001442312, 6.727920454563199, 6.022367813028454, 6.599912842187128, 5.643856189774724, 5.584962500721156, 5.584962500721156, 8.383704292474052, 9.124121311829187, 8.810571634741146, 7.727920454563199, 8.59618975614441, 7.845490050944375, 7.434628227636725, 6.643856189774724, 6.643856189774724, 6.643856189774724, 6.643856189774724, 7.554588851677638, 8.63662462054365, 4.247927513443585, 7.022367813028454, 3.0, 6.169925001442312, 6.169925001442312, 8.076815597050832, null, 7.366322214245816, 8.129283016944967, 8.038918989292302, 7.189824558880018, 6.820178962415188, 5.357552004618084, 6.658211482751795, 6.807354922057604, 6.954196310386875, 5.954196310386875, 6.189824558880018, 7.6865005271832185, 7.546894459887636, 7.546894459887636, 5.0, 6.189824558880018, 6.643856189774724, 6.392317422778761, 6.977279923499917, 5.727920454563199, 6.0, 6.0, 8.784634845557521, 9.259743263690781, 9.060695931687555, 8.022367813028454, 8.787902559391432, 8.290018846932618, 7.7481928495894605, 6.930737337562887, 6.930737337562887, 6.930737337562887, 6.906890595608519, 7.994353436858858, 9.076815597050832, 2.0, 7.434628227636725, 9.409390936137703, 5.882643049361842, 5.882643049361842, 7.960001932068081, 7.20945336562895, 7.774787059601174, 8.055282435501189, 8.022367813028454, 7.011227255423254, 7.2761244052742375, 5.857980995127572, 6.129283016944966, 7.159871336778389, 6.20945336562895, 6.149747119504682, 6.523561956057013, 7.845490050944375, 7.366322214245816, 8.108524456778168, 5.906890595608519, 6.539158811108031, 7.20945336562895, 6.339850002884624, 6.700439718141092, 6.129283016944966, 5.727920454563199, 5.727920454563199, 8.344295907915816, 8.915879378835774, 8.930737337562887, 7.936637939002571, 8.778077129535358, 8.405141463136344, 7.994353436858858, 7.22881869049588, 7.219168520462161, 7.219168520462161, 7.20945336562895, 8.326429487122303, 9.383704292474052, 1.0, 7.6653359171851765, 10.826548487290914, 6.820178962415188, 6.820178962415188, 7.876516946564999, 7.383704292474052, 8.098032082960527, 8.285402218862249, 8.294620748891626, 7.2384047393250786, 6.754887502163468, 5.930737337562887, 6.066089190457772, 6.754887502163468, 6.189824558880018, 5.700439718141092, 5.977279923499917, 7.417852514885898, 7.149747119504682, 7.22881869049588, 4.584962500721156, 5.643856189774724, 6.554588851677638, 5.977279923499917, 6.285402218862249, 6.108524456778169, 5.906890595608519, 5.906890595608519, 8.044394119358454, 8.569855608330949, 8.554588851677638, 7.839203788096944, 8.546894459887637, 8.022367813028454, 7.303780748177103, 6.442943495848728, 6.426264754702098, 6.426264754702098, 6.426264754702098, 7.876516946564999, 8.927777962082342, 2.807354922057604, 6.832890014164741, 9.4655664048094, 6.20945336562895, 6.20945336562895, 7.734709620225838, 6.820178962415188, 7.219168520462161, 7.857980995127572, 7.807354922057604, 6.882643049361842, 6.614709844115208, 5.857980995127572, 5.954196310386875, 6.3750394313469245, 6.044394119358453, 5.700439718141092, 5.554588851677638, 7.159871336778389, 7.149747119504682, 7.366322214245816, 4.643856189774724, 6.087462841250339, 6.672425341971495, 5.672425341971495, 6.584962500721156, 5.169925001442312, 5.357552004618084, 5.357552004618084, 8.022367813028454, 8.546894459887637, 8.535275376620802, 7.523561956057013, 8.271463027904375, 8.022367813028454, 7.366322214245816, 6.584962500721156, 6.584962500721156, 6.584962500721156, 6.584962500721156, 7.820178962415188, 8.876516946565, 2.0, 7.011227255423254, 9.154818109052105, 6.087462841250339, 6.087462841250339, 7.139551352398794, 6.700439718141092, 7.693486957499325, 7.599912842187128, 7.569855608330948, 4.169925001442312, 5.087462841250339, 4.459431618637297, 4.321928094887363, 5.247927513443585, 4.584962500721156, 4.0, 4.321928094887363, 5.087462841250339, 4.169925001442312, 4.392317422778761, 2.321928094887362, 4.584962500721156, 4.169925001442312, 4.754887502163468, 5.491853096329675, 2.807354922057604, 3.321928094887362, 3.321928094887362, 5.247927513443585, 6.584962500721156, 6.392317422778761, 5.807354922057604, 6.321928094887363, 6.087462841250339, 4.807354922057604, 3.9068905956085187, 3.9068905956085187, 3.9068905956085187, 3.9068905956085187, 6.247927513443585, 7.312882955284356, 0.0, 4.906890595608519, 6.584962500721156, 3.807354922057604, 3.807354922057604, 5.044394119358453, 5.392317422778761, 5.392317422778761, 6.169925001442312, 6.129283016944966, 6.266786540694901, 6.0, 5.247927513443585, 5.882643049361842, 5.977279923499917, 5.930737337562887, 5.321928094887363, 5.321928094887363, 6.857980995127572, 6.599912842187128, 6.087462841250339, 3.584962500721156, 5.614709844115208, 5.614709844115208, 5.044394119358453, 6.20945336562895, 4.392317422778761, 5.044394119358453, 5.044394119358453, 7.417852514885898, 8.326429487122303, 8.108524456778168, 7.159871336778389, 7.839203788096944, 7.409390936137702, 6.794415866350106, 6.0, 5.977279923499917, 5.977279923499917, 5.954196310386875, 7.169925001442312, 8.243173983472952, 2.321928094887362, 6.491853096329675, 8.539158811108031, 5.754887502163468, 5.754887502163468, 7.303780748177103, 6.22881869049588, 7.076815597050831, 7.098032082960526, 7.087462841250339, 6.247927513443585, 6.6293566200796095, 5.285402218862249, 6.149747119504682, 6.599912842187128, 5.832890014164741, 5.832890014164741, 5.614709844115208, 6.954196310386875, 6.643856189774724, 7.05528243550119, 4.523561956057013, 5.584962500721156, 6.426264754702098, 5.584962500721156, 6.554588851677638, 5.727920454563199, 5.727920454563199, 5.727920454563199, 7.539158811108031, 8.686500527183219, 8.233619676759702, 7.592457037268081, 8.169925001442312, 7.807354922057604, 7.426264754702098, 6.727920454563199, 6.727920454563199, 6.727920454563199, 6.714245517666122, 7.539158811108031, 8.60733031374961, 0.0, 6.491853096329675, 9.157346935362844, 6.108524456778169, 6.108524456778169, 6.845490050944375, 6.584962500721156, 7.011227255423254, 7.475733430966398, 7.417852514885898, 6.643856189774724, 6.339850002884624, 5.459431618637297, 6.066089190457772, 6.554588851677638, 6.022367813028454, 4.754887502163468, 5.614709844115208, 7.22881869049588, 7.247927513443585, 7.584962500721156, 5.129283016944966, 6.189824558880018, 6.965784284662087, 6.087462841250339, 6.303780748177103, 5.491853096329675, 5.20945336562895, 5.20945336562895, 7.94251450533924, 8.603626344986193, 8.31741261376487, 7.807354922057604, 8.396604781181859, 8.011227255423254, 7.383704292474052, 6.643856189774724, 6.6293566200796095, 6.6293566200796095, 6.6293566200796095, 7.546894459887636, 8.611024797307353, 2.0, 6.339850002884624, 10.303780748177102, 5.906890595608519, 5.906890595608519, 7.960001932068081, 6.918863237274595, 7.409390936137702, 7.679480099505446, 7.651051691178929, 7.918863237274595, 7.357552004618084, 6.832890014164741, 6.9886846867721655, 7.643856189774724, 7.05528243550119, 6.554588851677638, 6.643856189774724, 8.31741261376487, 8.243173983472952, 8.531381460516313, 6.247927513443585, 7.475733430966398, 7.800899899920305, 7.066089190457772, 6.658211482751795, 6.977279923499917, 6.906890595608519, 6.906890595608519, 9.35974956032233, 9.834471049984222, 9.590587049915035, 8.894817763307943, 9.556506054671928, 8.971543553950772, 8.39231742277876, 7.584962500721156, 7.584962500721156, 7.584962500721156, 7.577428828035749, 8.74819284958946, 9.786269627648466, 2.0, 7.7481928495894605, 10.386940245324311, 7.22881869049588, 7.22881869049588, 8.422064766172813, 7.971543553950772, 8.573647187493322, 8.870364719583405, 8.832890014164741, 6.614709844115208, 6.22881869049588, 5.169925001442312, 5.930737337562887, 5.977279923499917, 5.727920454563199, 5.906890595608519, 5.491853096329675, 6.539158811108031, 6.857980995127572, 7.20945336562895, 4.459431618637297, 5.930737337562887, 5.906890595608519, 5.643856189774724, 5.954196310386875, 5.357552004618084, 4.906890595608519, 4.906890595608519, 7.651051691178929, 8.353146825498083, 8.20945336562895, 7.491853096329675, 8.038918989292302, 7.672425341971495, 7.098032082960526, 6.285402218862249, 6.285402218862249, 6.285402218862249, 6.189824558880018, 7.357552004618084, 8.430452551665532, 4.584962500721156, 6.658211482751795, 3.4594316186372973, 6.044394119358453, 6.044394119358453, 7.066089190457772, 1.0, 6.820178962415188, 7.442943495848728, 7.383704292474052, 6.857980995127572, 6.321928094887363, 6.0, 6.129283016944966, 6.6865005271832185, 5.614709844115208, 5.247927513443585, 5.426264754702098, 6.658211482751795, 6.9886846867721655, 7.417852514885898, 4.906890595608519, 5.882643049361842, 6.741466986401147, 5.857980995127572, 5.247927513443585, 5.321928094887363, 4.857980995127572, 4.857980995127572, 8.179909090014934, 8.550746785383243, 8.562242424221072, 7.614709844115208, 8.303780748177102, 7.700439718141092, 7.339850002884624, 6.459431618637297, 6.459431618637297, 6.459431618637297, 6.442943495848728, 7.400879436282184, 8.479780264029099, 0.0, 6.727920454563199, 9.092757140919852, 5.882643049361842, 5.930737337562887, 7.139551352398794, 6.906890595608519, 7.392317422778761, 7.451211111832329, 7.459431618637297, 7.459431618637297, 7.339850002884624, 6.584962500721156, 7.022367813028454, 7.149747119504682, 6.857980995127572, 6.714245517666122, 5.906890595608519, 7.832890014164741, 7.894817763307944, 7.807354922057604, 5.700439718141092, 6.599912842187128, 7.285402218862249, 6.569855608330948, 7.118941072723508, 6.108524456778169, 5.954196310386875, 5.954196310386875, 8.60733031374961, 9.257387842692651, 9.219168520462162, 8.348728154231077, 9.08214904135387, 8.672425341971495, 7.94251450533924, 7.189824558880018, 7.1799090900149345, 7.1799090900149345, 7.169925001442312, 8.442943495848729, 9.517669388133811, 2.807354922057604, 7.912889336229962, 9.873444112515376, 7.066089190457772, 7.066089190457772, 8.515699838284043, 7.643856189774724, 8.252665432450248, 8.519636252843213, 8.49585502688717, 7.076815597050831, 6.6865005271832185, 5.614709844115208, 6.539158811108031, 6.658211482751795, 6.539158811108031, 6.189824558880018, 6.247927513443585, 7.400879436282184, 7.348728154231077, 8.011227255423254, 5.044394119358453, 6.087462841250339, 6.918863237274595, 6.599912842187128, 6.599912842187128, 5.906890595608519, 5.807354922057604, 5.807354922057604, 8.252665432450248, 8.86418614465428, 8.668884984266247, 7.679480099505446, 8.451211111832329, 8.0, 7.219168520462161, 6.523561956057013, 6.523561956057013, 6.523561956057013, 6.507794640198696, 8.224001674198105, 9.243173983472952, 1.0, 7.321928094887363, 9.61654884377899, 6.129283016944966, 6.129283016944966, 8.103287808412022, 7.022367813028454, 7.888743248898259, 7.800899899920305, 7.7481928495894605, 7.6865005271832185, 7.098032082960526, 5.807354922057604, 6.491853096329675, 7.451211111832329, 6.918863237274595, 6.491853096329675, 6.475733430966398, 7.658211482751795, 7.774787059601174, 8.228818690495881, 5.129283016944966, 6.918863237274595, 7.321928094887363, 6.832890014164741, 6.700439718141092, 5.584962500721156, 5.954196310386875, 5.954196310386875, 8.658211482751796, 9.087462841250339, 9.019590728357882, 8.262094845370179, 8.912889336229961, 8.519636252843213, 7.98299357469431, 7.149747119504682, 7.139551352398794, 7.139551352398794, 7.118941072723508, 8.339850002884624, 9.368506461507693, 2.0, 7.515699838284043, 9.831307243802051, 6.6865005271832185, 6.6865005271832185, 7.159871336778389, 7.392317422778761, 8.118941072723507, 8.247927513443585, 8.228818690495881, 6.523561956057013, 6.672425341971495, 5.643856189774724, 5.930737337562887, 6.658211482751795, 5.906890595608519, 5.554588851677638, 5.672425341971495, 7.03342300153745, 6.78135971352466, 7.599912842187128, 5.321928094887363, 5.930737337562887, 6.794415866350106, 6.189824558880018, 5.78135971352466, 5.78135971352466, 5.832890014164741, 5.832890014164741, 7.7481928495894605, 8.558420713268664, 8.625708843064466, 7.584962500721156, 8.276124405274238, 7.721099188707185, 7.169925001442312, 6.20945336562895, 6.20945336562895, 6.20945336562895, 6.20945336562895, 7.60733031374961, 8.693486957499326, 0.0, 7.294620748891627, 10.29232163280204, 6.044394119358453, 6.044394119358453, 6.78135971352466, 6.303780748177103, 7.531381460516312, 7.754887502163468, 7.721099188707185, 6.584962500721156, 5.954196310386875, 5.044394119358453, 5.78135971352466, 6.169925001442312, 5.78135971352466, 5.491853096329675, 5.285402218862249, 6.539158811108031, 6.614709844115208, 6.554588851677638, 5.087462841250339, 5.700439718141092, 6.044394119358453, 5.832890014164741, 6.149747119504682, 5.044394119358453, 5.0, 5.0, 7.554588851677638, 8.276124405274238, 8.016808287686555, 7.0, 7.807354922057604, 7.118941072723508, 6.727920454563199, 5.882643049361842, 5.882643049361842, 5.882643049361842, 5.882643049361842, 7.108524456778169, 8.164906926675688, 0.0, 6.149747119504682, 8.957102041562287, 5.807354922057604, 5.807354922057604, 6.507794640198696, 6.339850002884624, 6.832890014164741, 7.149747119504682, 7.118941072723508, 6.321928094887363, 6.149747119504682, 4.700439718141092, 5.727920454563199, 6.0, 5.584962500721156, 4.584962500721156, 4.857980995127572, 6.754887502163468, 6.339850002884624, 6.727920454563199, 4.807354922057604, 5.426264754702098, 5.523561956057013, 5.20945336562895, 5.832890014164741, 4.247927513443585, 4.392317422778761, 4.392317422778761, 7.94251450533924, 8.262094845370179, 7.971543553950772, 6.741466986401147, 7.515699838284043, 7.20945336562895, 6.807354922057604, 5.954196310386875, 5.954196310386875, 5.954196310386875, 5.954196310386875, 7.03342300153745, 8.134426320220927, 5.614709844115208, 5.954196310386875, 3.807354922057604, 4.954196310386875, 5.0, 7.483815777264256, null, 7.076815597050831, 7.129283016944966, 7.087462841250339, 6.169925001442312, 5.832890014164741, 5.0, 5.554588851677638, 5.643856189774724, 5.044394119358453, 4.807354922057604, 4.523561956057013, 6.357552004618084, 6.426264754702098, 6.442943495848728, 2.584962500721156, 5.0, 5.459431618637297, 5.087462841250339, 5.459431618637297, 4.584962500721156, 4.857980995127572, 4.857980995127572, 6.6865005271832185, 7.912889336229962, 7.839203788096944, 6.918863237274595, 7.636624620543649, 7.05528243550119, 6.442943495848728, 5.643856189774724, 5.643856189774724, 5.643856189774724, 5.614709844115208, 6.906890595608519, 7.954196310386875, 0.0, 6.108524456778169, 9.499845887083206, 5.247927513443585, 5.247927513443585, 6.022367813028454, 6.022367813028454, 6.357552004618084, 6.894817763307944, 6.845490050944375, 6.807354922057604, 6.087462841250339, 5.426264754702098, 5.954196310386875, 5.930737337562887, 5.906890595608519, 5.285402218862249, 5.285402218862249, 6.832890014164741, 7.022367813028454, 6.857980995127572, 4.247927513443585, 5.930737337562887, 6.285402218862249, 5.700439718141092, 5.832890014164741, 4.807354922057604, 4.954196310386875, 4.954196310386875, 8.060695931687555, 8.668884984266247, 8.344295907915816, 7.3750394313469245, 8.087462841250339, 7.693486957499325, 7.022367813028454, 6.266786540694901, 6.266786540694901, 6.266786540694901, 6.20945336562895, 7.087462841250339, 8.124121311829187, 5.20945336562895, 6.94251450533924, 8.857980995127573, 5.584962500721156, 5.614709844115208, 6.0, 6.6865005271832185, 7.507794640198696, 7.247927513443585, 7.20945336562895, 3.321928094887362, 2.807354922057604, null, 2.0, null, 2.584962500721156, 1.584962500721156, 2.0, 2.807354922057604, 2.321928094887362, 3.321928094887362, 2.0, 1.584962500721156, 1.0, 1.584962500721156, null, 2.321928094887362, 2.584962500721156, 2.584962500721156, 3.807354922057604, 3.807354922057604, 4.754887502163468, 3.584962500721156, 4.0, 3.700439718141092, 3.9068905956085187, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 4.643856189774724, 5.491853096329675, null, 2.584962500721156, 5.754887502163468, 2.0, 2.0, 2.807354922057604, 3.0, 2.807354922057604, 3.321928094887362, 3.169925001442312, 6.832890014164741, 6.794415866350106, 6.303780748177103, 6.129283016944966, 6.491853096329675, 6.727920454563199, 6.169925001442312, 5.491853096329675, 7.139551352398794, 7.515699838284043, 7.727920454563199, 6.044394119358453, 6.087462841250339, 6.6865005271832185, 6.247927513443585, 6.149747119504682, 5.491853096329675, 5.754887502163468, 5.754887502163468, 8.442943495848729, 8.370687406807217, 8.92184093707449, 7.727920454563199, 8.569855608330949, 8.098032082960527, 7.357552004618084, 6.643856189774724, 6.643856189774724, 6.643856189774724, 6.643856189774724, 7.727920454563199, 8.807354922057604, 2.807354922057604, 7.149747119504682, 9.594324603924848, 6.357552004618084, 6.357552004618084, 7.159871336778389, 7.219168520462161, 7.851749041416057, 7.888743248898259, 7.845490050944375, 5.554588851677638, 5.78135971352466, 4.459431618637297, 4.906890595608519, 5.491853096329675, 5.0, 4.906890595608519, 4.807354922057604, 6.108524456778169, 5.807354922057604, 5.78135971352466, 3.321928094887362, 4.807354922057604, 5.614709844115208, 4.392317422778761, 4.087462841250339, 4.459431618637297, 4.754887502163468, 4.754887502163468, 7.098032082960526, 7.507794640198696, 7.3750394313469245, 6.794415866350106, 7.539158811108031, 6.94251450533924, 6.614709844115208, 5.857980995127572, 5.857980995127572, 5.857980995127572, 5.832890014164741, 6.727920454563199, 7.826548487290915, null, 5.954196310386875, 9.113742166049189, 5.129283016944966, 5.129283016944966, 5.523561956057013, 5.906890595608519, 6.507794640198696, 6.727920454563199, 6.6293566200796095, 7.0, 6.754887502163468, 5.754887502163468, 6.539158811108031, 6.820178962415188, 6.507794640198696, 6.129283016944966, 5.954196310386875, 7.409390936137702, 7.523561956057013, 7.839203788096944, 4.169925001442312, 5.857980995127572, 6.78135971352466, 6.392317422778761, 6.954196310386875, 5.954196310386875, 6.149747119504682, 6.149747119504682, 8.154818109052105, 8.92184093707449, 8.832890014164741, 8.071462362556623, 8.727920454563199, 8.103287808412022, 7.60733031374961, 6.870364719583405, 6.870364719583405, 6.870364719583405, 6.870364719583405, 7.94251450533924, 8.980139577639157, 1.0, 7.022367813028454, 9.642051692927977, 6.672425341971495, 6.672425341971495, 7.7073591320808825, 6.977279923499917, 7.918863237274595, 7.900866807980749, 7.870364719583405, 6.807354922057604, 6.768184324776926, 5.906890595608519, 6.321928094887363, 6.857980995127572, 6.727920454563199, 6.066089190457772, 5.614709844115208, 7.087462841250339, 6.857980995127572, 7.189824558880018, 4.643856189774724, 6.714245517666122, 6.78135971352466, 6.672425341971495, 5.584962500721156, 5.491853096329675, 5.20945336562895, 5.20945336562895, 8.113742166049189, 8.665335917185176, 8.523561956057012, 7.7073591320808825, 8.388017285345136, 7.930737337562887, 7.554588851677638, 6.643856189774724, 6.643856189774724, 6.643856189774724, 6.6293566200796095, 7.794415866350106, 8.894817763307943, 6.643856189774724, 6.78135971352466, 9.477758266443889, 5.523561956057013, 5.523561956057013, 7.499845887083206, 6.930737337562887, 7.700439718141092, 7.894817763307944, 7.894817763307944, 7.3750394313469245, 7.2384047393250786, 6.266786540694901, 6.507794640198696, 7.189824558880018, 6.882643049361842, 6.459431618637297, 6.303780748177103, 7.839203788096944, 7.584962500721156, 8.233619676759702, 5.906890595608519, 6.539158811108031, 6.930737337562887, 6.832890014164741, 7.20945336562895, 5.882643049361842, 6.169925001442312, 6.169925001442312, 8.076815597050832, 8.96289600533726, 9.022367813028454, 8.430452551665532, 9.049848549450562, 8.491853096329674, 8.044394119358454, 7.189824558880018, 7.189824558880018, 7.189824558880018, 7.1799090900149345, 8.285402218862249, 9.337621901992508, 1.0, 7.643856189774724, 9.933690654952233, 6.614709844115208, 6.614709844115208, 7.247927513443585, 7.643856189774724, 8.118941072723507, 8.285402218862249, 8.252665432450248, null, null, null, null, null, null, null, null, null, 0.0, 1.0, null, 1.0, null, null, null, null, null, null, null, 2.807354922057604, 1.584962500721156, 0.0, 0.0, 0.0, 1.0, null, null, null, null, 0.0, 3.169925001442312, null, null, 2.321928094887362, 0.0, 0.0, 1.0, null, null, null, 0.0, 5.584962500721156, 5.700439718141092, 2.807354922057604, 3.584962500721156, 4.857980995127572, 5.459431618637297, 5.392317422778761, 5.285402218862249, 7.098032082960526, 8.199672344836364, 6.539158811108031, 3.700439718141092, 5.285402218862249, 5.321928094887363, 4.857980995127572, 4.584962500721156, 4.392317422778761, 4.807354922057604, 4.807354922057604, 9.377210530388552, 10.127994320976393, 7.643856189774724, 6.599912842187128, 7.426264754702098, 6.930737337562887, 6.459431618637297, 5.727920454563199, 5.727920454563199, 5.727920454563199, 5.672425341971495, 6.0, 7.149747119504682, 3.584962500721156, 5.426264754702098, 9.002815015607053, 5.357552004618084, 5.357552004618084, 8.507794640198696, 6.426264754702098, 6.066089190457772, 7.03342300153745, 7.03342300153745, 6.266786540694901, 4.954196310386875, 4.459431618637297, 4.247927513443585, 5.392317422778761, 5.807354922057604, 4.857980995127572, 5.321928094887363, 7.03342300153745, 7.044394119358453, 6.700439718141092, 3.700439718141092, 6.285402218862249, 5.906890595608519, 4.523561956057013, 3.169925001442312, 4.954196310386875, 3.9068905956085187, 3.9068905956085187, 8.558420713268664, 8.954196310386875, 8.405141463136344, 7.523561956057013, 8.361943773735241, 6.658211482751795, 6.977279923499917, 6.357552004618084, 6.357552004618084, 6.357552004618084, 6.339850002884624, 6.321928094887363, 7.383704292474052, 2.321928094887362, 6.523561956057013, 8.787902559391432, 4.169925001442312, 4.169925001442312, 7.636624620543649, 5.321928094887363, 7.03342300153745, 6.672425341971495, 6.658211482751795, 5.727920454563199, 5.584962500721156, 3.700439718141092, 3.584962500721156, 5.0, 4.643856189774724, 3.807354922057604, 3.9068905956085187, 6.882643049361842, 7.507794640198696, 5.247927513443585, 3.0, 4.857980995127572, 5.357552004618084, 5.0, 4.392317422778761, 4.247927513443585, 4.392317422778761, 4.392317422778761, 8.339850002884624, 9.29920801838728, 7.483815777264256, 6.727920454563199, 7.499845887083206, 6.894817763307944, 6.066089190457772, 5.357552004618084, 5.357552004618084, 5.357552004618084, 5.357552004618084, 6.442943495848728, 7.491853096329675, 2.321928094887362, 6.266786540694901, 9.350939181546432, 4.700439718141092, 4.700439718141092, 7.339850002884624, 5.169925001442312, 6.247927513443585, 6.882643049361842, 6.857980995127572, 6.794415866350106, 6.491853096329675, 5.044394119358453, 5.426264754702098, 6.491853096329675, 5.321928094887363, 4.954196310386875, 5.614709844115208, 7.348728154231077, 8.228818690495881, 7.20945336562895, 4.700439718141092, 6.149747119504682, 6.807354922057604, 5.392317422778761, 5.523561956057013, 4.523561956057013, 5.643856189774724, 5.643856189774724, 9.409390936137703, 9.799281621521923, 8.550746785383243, 7.7481928495894605, 8.467605550082997, 7.577428828035749, 6.845490050944375, 6.108524456778169, 6.108524456778169, 6.108524456778169, 6.108524456778169, 7.622051819456376, 8.658211482751796, 3.169925001442312, 6.700439718141092, 9.337621901992508, 4.906890595608519, 4.906890595608519, 8.098032082960527, 6.266786540694901, 7.20945336562895, 7.614709844115208, 7.562242424221073, 5.169925001442312, 4.906890595608519, 3.807354922057604, 3.9068905956085187, 4.584962500721156, 5.087462841250339, 3.700439718141092, 4.584962500721156, 6.066089190457772, 7.366322214245816, 5.523561956057013, 2.584962500721156, 4.584962500721156, 4.523561956057013, 4.584962500721156, 4.087462841250339, 3.321928094887362, 3.584962500721156, 3.584962500721156, 8.60733031374961, 8.832890014164741, 6.768184324776926, 5.754887502163468, 6.475733430966398, 6.108524456778169, 5.491853096329675, 4.954196310386875, 4.954196310386875, 4.954196310386875, 4.807354922057604, 5.491853096329675, 6.523561956057013, null, 4.857980995127572, 7.400879436282184, 3.0, 3.0, 7.924812503605781, 4.700439718141092, 5.807354922057604, 6.247927513443585, 6.22881869049588, 6.741466986401147, 6.475733430966398, 5.672425341971495, 6.066089190457772, 6.918863237274595, 5.672425341971495, 4.906890595608519, 5.832890014164741, 7.2384047393250786, 6.894817763307944, 6.714245517666122, 4.321928094887363, 5.906890595608519, 6.672425341971495, 6.044394119358453, 5.523561956057013, 5.700439718141092, 5.882643049361842, 5.882643049361842, 8.247927513443585, 8.951284714966972, 8.79766152585376, 7.651051691178929, 8.471675214392045, 7.954196310386875, 7.22881869049588, 6.426264754702098, 6.426264754702098, 6.426264754702098, 6.409390936137702, 7.977279923499917, 9.022367813028454, 1.0, 6.523561956057013, 10.24198314969433, 5.584962500721156, 5.584962500721156, 7.139551352398794, 7.05528243550119, 7.169925001442312, 7.714245517666122, 7.658211482751795, null, 2.807354922057604, 5.523561956057013, 5.392317422778761, 6.658211482751795, null, null, 0.0, null, 0.0, null, 1.0, null, 1.0, 3.584962500721156, 5.754887502163468, null, 2.584962500721156, 2.584962500721156, null, 1.0, 0.0, 0.0, null, 2.584962500721156, 4.0, 0.0, 0.0, 0.0, 0.0, 7.426264754702098, 8.467605550082997, null, 1.0, 3.0, 2.584962500721156, 2.584962500721156, null, 6.643856189774724, null, 4.459431618637297, 4.392317422778761, 6.357552004618084, 6.285402218862249, 3.807354922057604, 4.523561956057013, 5.044394119358453, 5.930737337562887, 5.357552004618084, 5.285402218862249, 7.794415866350106, 8.820178962415188, 6.94251450533924, 3.9068905956085187, 6.303780748177103, 6.22881869049588, 5.807354922057604, 3.807354922057604, 4.857980995127572, 5.129283016944966, 5.129283016944966, 9.643856189774725, 10.333155350310616, 8.066089190457772, 7.149747119504682, 7.900866807980749, 7.285402218862249, 7.066089190457772, 6.247927513443585, 6.247927513443585, 6.247927513443585, 6.189824558880018, 6.459431618637297, 7.475733430966398, 4.857980995127572, 6.169925001442312, 8.661778097771988, 5.087462841250339, 5.087462841250339, 8.0, 5.672425341971495, 6.882643049361842, 7.266786540694901, 7.189824558880018, 7.357552004618084, 7.357552004618084, 5.906890595608519, 6.442943495848728, 7.392317422778761, 6.409390936137702, 6.339850002884624, 6.918863237274595, 7.977279923499917, 7.734709620225838, 7.734709620225838, 5.672425341971495, 6.426264754702098, 7.22881869049588, 6.459431618637297, 6.6293566200796095, 5.672425341971495, 6.247927513443585, 6.247927513443585, 8.654636028527968, 9.432541900388259, 9.116343961237469, 8.519636252843213, 9.219168520462162, 8.625708843064466, 7.994353436858858, 7.2384047393250786, 7.22881869049588, 7.22881869049588, 7.219168520462161, 8.330916878114618, 9.396604781181859, 3.321928094887362, 7.491853096329675, 9.917372079476841, 6.6865005271832185, 6.6865005271832185, 7.734709620225838, 7.7615512324444795, 8.060695931687555, 8.285402218862249, 8.257387842692651, 6.442943495848728, 6.022367813028454, 5.491853096329675, 5.554588851677638, 6.247927513443585, 5.727920454563199, 4.857980995127572, 5.643856189774724, 7.108524456778169, 8.134426320220927, 6.643856189774724, 4.459431618637297, 5.754887502163468, 6.22881869049588, 5.357552004618084, 5.20945336562895, 5.129283016944966, 5.392317422778761, 5.392317422778761, 8.839203788096944, 9.684748620421626, 8.499845887083206, 7.199672344836364, 8.194756854422248, 7.491853096329675, 6.714245517666122, 5.930737337562887, 5.930737337562887, 5.930737337562887, 5.906890595608519, 7.0, 8.087462841250339, null, 6.9886846867721655, 9.90839262077375, 6.523561956057013, 6.523561956057013, 8.611024797307353, 7.459431618637297, 6.918863237274595, 7.499845887083206, 7.483815777264256, 6.569855608330948, 6.321928094887363, 2.584962500721156, 5.321928094887363, 6.339850002884624, 5.357552004618084, 4.754887502163468, 5.285402218862249, 6.6865005271832185, 7.643856189774724, 6.475733430966398, 5.169925001442312, 5.523561956057013, 6.554588851677638, 5.285402218862249, 4.754887502163468, 4.807354922057604, 5.321928094887363, 5.321928094887363, 8.744833837499545, 9.550746785383243, 8.321928094887362, 7.22881869049588, 8.055282435501189, 7.614709844115208, 6.807354922057604, 5.930737337562887, 5.930737337562887, 5.930737337562887, 5.906890595608519, 7.467605550082998, 8.573647187493322, 1.0, 6.303780748177103, 9.915879378835774, 5.0, 5.0, 7.832890014164741, 6.6865005271832185, 7.189824558880018, 7.312882955284356, 7.321928094887363, 6.20945336562895, 6.066089190457772, 5.0, 4.643856189774724, 6.189824558880018, 5.832890014164741, 4.0, 5.247927513443585, 6.977279923499917, 7.794415866350106, 6.321928094887363, 5.0, 5.857980995127572, 6.584962500721156, 5.169925001442312, 3.321928094887362, 4.754887502163468, 4.906890595608519, 4.906890595608519, 8.761551232444479, 9.319672120946995, 8.118941072723507, 7.118941072723508, 8.022367813028454, 7.523561956057013, 6.643856189774724, 5.882643049361842, 5.882643049361842, 5.882643049361842, 5.882643049361842, 7.189824558880018, 8.233619676759702, 3.584962500721156, 6.392317422778761, 9.709083812550343, 5.392317422778761, 5.392317422778761, 8.03342300153745, 6.285402218862249, 6.882643049361842, 7.20945336562895, 7.189824558880018, 6.832890014164741, 5.954196310386875, 4.807354922057604, 4.754887502163468, 6.20945336562895, 6.459431618637297, 6.044394119358453, 6.392317422778761, 7.800899899920305, 8.098032082960527, 7.312882955284356, 3.700439718141092, 6.614709844115208, 7.348728154231077, 5.523561956057013, 4.643856189774724, 5.727920454563199, 4.584962500721156, 4.584962500721156, 9.159871336778389, 9.567956075415466, 8.918863237274595, 8.118941072723507, 9.071462362556623, 7.426264754702098, 7.614709844115208, 7.0, 7.0, 7.0, 6.9886846867721655, 6.930737337562887, 8.08214904135387, 3.4594316186372973, 7.022367813028454, 9.684748620421626, 5.426264754702098, 5.426264754702098, 8.169925001442312, 5.930737337562887, 7.900866807980749, 7.044394119358453, 7.03342300153745, 6.357552004618084, 5.700439718141092, 5.129283016944966, 5.554588851677638, 5.882643049361842, 4.906890595608519, 5.614709844115208, 5.169925001442312, 7.409390936137702, 7.714245517666122, 6.894817763307944, 3.4594316186372973, 5.954196310386875, 5.807354922057604, 4.643856189774724, 5.392317422778761, 4.087462841250339, 5.169925001442312, 5.169925001442312, 9.116343961237469, 9.4655664048094, 7.994353436858858, 7.417852514885898, 8.03342300153745, 7.515699838284043, 6.584962500721156, 5.832890014164741, 5.832890014164741, 5.832890014164741, 5.832890014164741, 6.768184324776926, 7.876516946564999, 1.0, 6.491853096329675, 8.731319031025064, 5.807354922057604, 5.832890014164741, 8.103287808412022, 5.954196310386875, 6.930737337562887, 7.303780748177103, 7.22881869049588, 6.599912842187128, 6.149747119504682, 4.584962500721156, 4.857980995127572, 6.149747119504682, 5.727920454563199, 5.857980995127572, 5.491853096329675, 7.199672344836364, 8.262094845370179, 7.321928094887363, 4.0, 6.3750394313469245, 6.3750394313469245, 5.554588851677638, 5.930737337562887, 4.584962500721156, 4.700439718141092, 4.700439718141092, 9.353146825498083, 9.850186837645774, 8.370687406807217, 7.357552004618084, 8.124121311829187, 7.651051691178929, 6.954196310386875, 6.129283016944966, 6.129283016944966, 6.129283016944966, 6.108524456778169, 6.9886846867721655, 8.098032082960527, 3.0, 6.741466986401147, 10.084808387804362, 5.426264754702098, 5.426264754702098, 8.721099188707186, 6.357552004618084, 6.754887502163468, 7.6293566200796095, 7.614709844115208, 6.426264754702098, 6.0, 5.523561956057013, 5.129283016944966, 5.954196310386875, 6.0, 4.954196310386875, 5.087462841250339, 7.118941072723508, 7.787902559391432, 6.78135971352466, 5.0, 5.700439718141092, 6.392317422778761, 5.285402218862249, 4.754887502163468, 4.857980995127572, 5.392317422778761, 5.392317422778761, 9.18239435340453, 9.77313920671969, 8.199672344836364, 7.312882955284356, 7.936637939002571, 7.643856189774724, 6.754887502163468, 5.906890595608519, 5.906890595608519, 5.906890595608519, 5.832890014164741, 6.794415866350106, 7.912889336229962, 0.0, 6.169925001442312, 8.980139577639157, 5.523561956057013, 5.523561956057013, 7.400879436282184, null, 6.965784284662087, 7.2384047393250786, 7.20945336562895, 5.523561956057013, 5.129283016944966, 3.584962500721156, 4.0, 4.523561956057013, 4.392317422778761, 4.523561956057013, 3.807354922057604, 6.727920454563199, 7.569855608330948, 5.0, 3.584962500721156, 5.285402218862249, 5.523561956057013, 4.169925001442312, 2.321928094887362, 3.4594316186372973, 3.4594316186372973, 3.4594316186372973, 9.066089190457772, 8.927777962082342, 7.2384047393250786, 6.247927513443585, 7.098032082960526, 6.247927513443585, 5.857980995127572, 5.169925001442312, 5.169925001442312, 5.169925001442312, 5.129283016944966, 5.426264754702098, 6.599912842187128, 1.0, 5.357552004618084, 8.098032082960527, 3.584962500721156, 3.700439718141092, 7.539158811108031, null, 5.857980995127572, 6.066089190457772, 6.022367813028454, 6.965784284662087, 6.569855608330948, 5.459431618637297, 5.930737337562887, 6.266786540694901, 6.189824558880018, 5.672425341971495, 5.392317422778761, 7.721099188707185, 8.467605550082997, 7.1799090900149345, 5.20945336562895, 6.658211482751795, 6.906890595608519, 5.727920454563199, 5.78135971352466, 5.169925001442312, 5.643856189774724, 5.643856189774724, 9.829722735086058, 10.199672344836364, 8.51175265376738, 7.672425341971495, 8.370687406807217, 7.906890595608519, 7.483815777264256, 6.507794640198696, 6.507794640198696, 6.507794640198696, 6.409390936137702, 7.303780748177103, 8.366322214245816, 0.0, 6.539158811108031, 10.330916878114618, 5.754887502163468, 5.754887502163468, 8.531381460516313, 7.199672344836364, 7.05528243550119, 7.727920454563199, 7.643856189774724, 2.584962500721156, 6.807354922057604, 3.321928094887362, 3.9068905956085187, 3.584962500721156, 3.0, 3.4594316186372973, 3.700439718141092, 4.0, 5.0, 4.459431618637297, 5.643856189774724, 3.807354922057604, 3.0, 6.044394119358453, 3.584962500721156, 3.169925001442312, 6.066089190457772, 6.066089190457772, 6.044394119358453, 6.882643049361842, 6.303780748177103, 6.569855608330948, 5.754887502163468, 8.906890595608518, 4.643856189774724, 4.0, 4.0, 4.0, 3.9068905956085187, 5.614709844115208, 6.614709844115208, null, 3.0, 6.539158811108031, 6.700439718141092, 6.700439718141092, 5.169925001442312, 4.523561956057013, 4.321928094887363, 8.483815777264256, 8.451211111832329, 7.794415866350106, 7.257387842692652, 6.022367813028454, 6.3750394313469245, 7.2761244052742375, 7.1799090900149345, 7.129283016944966, 6.658211482751795, 8.519636252843213, 9.113742166049189, 7.507794640198696, 6.6293566200796095, 6.714245517666122, 7.475733430966398, 6.303780748177103, 6.794415866350106, 6.149747119504682, 6.539158811108031, 6.539158811108031, 9.952741247186488, 10.621136113274641, 9.50382573799575, 8.894817763307943, 9.612868497291041, 9.108524456778168, 8.339850002884624, 7.727920454563199, 7.727920454563199, 7.727920454563199, 7.721099188707185, 8.434628227636725, 9.519636252843213, 3.700439718141092, 7.700439718141092, 10.25502856981873, 6.820178962415188, 6.820178962415188, 9.20212382383046, 7.787902559391432, 8.087462841250339, 8.900866807980748, 8.879583249612784, 6.247927513443585, 6.357552004618084, 4.807354922057604, 5.554588851677638, 6.189824558880018, 6.0, 5.754887502163468, 5.321928094887363, 7.383704292474052, 7.7481928495894605, 6.754887502163468, 3.807354922057604, 5.832890014164741, 6.303780748177103, 5.129283016944966, 6.303780748177103, 4.392317422778761, 5.087462841250339, 5.087462841250339, 9.060695931687555, 9.632995197142957, 8.353146825498083, 7.357552004618084, 8.247927513443585, 7.643856189774724, 6.78135971352466, 6.0, 6.0, 6.0, 5.977279923499917, 7.219168520462161, 8.330916878114618, 5.426264754702098, 6.554588851677638, 8.906890595608518, 5.700439718141092, 5.700439718141092, 8.271463027904375, 6.426264754702098, 7.022367813028454, 7.562242424221073, 7.554588851677638, 6.727920454563199, 6.303780748177103, 4.807354922057604, 5.977279923499917, 6.569855608330948, 5.321928094887363, 3.9068905956085187, 5.357552004618084, 7.159871336778389, 8.113742166049189, 6.78135971352466, 4.392317422778761, 6.189824558880018, 7.044394119358453, 5.727920454563199, 4.584962500721156, 5.426264754702098, 5.129283016944966, 5.129283016944966, 9.250298417906333, 9.656424863277781, 8.426264754702098, 7.467605550082998, 8.370687406807217, 7.971543553950772, 7.139551352398794, 6.303780748177103, 6.285402218862249, 6.285402218862249, 6.285402218862249, 7.562242424221073, 8.661778097771988, null, 6.614709844115208, 9.978710459106358, 6.087462841250339, 6.087462841250339, 7.876516946564999, 7.6865005271832185, 6.906890595608519, 7.6653359171851765, 7.658211482751795, 5.672425341971495, 5.426264754702098, 3.321928094887362, 4.459431618637297, 4.754887502163468, 4.700439718141092, 4.392317422778761, 3.584962500721156, 6.554588851677638, 7.554588851677638, 6.0, 3.807354922057604, 5.357552004618084, 6.022367813028454, 4.857980995127572, 4.0, 4.169925001442312, 4.754887502163468, 4.754887502163468, 8.451211111832329, 9.247927513443585, 7.554588851677638, 6.584962500721156, 7.294620748891627, 7.05528243550119, 6.022367813028454, 5.087462841250339, 5.087462841250339, 5.087462841250339, 5.087462841250339, 6.643856189774724, 7.721099188707185, null, 5.882643049361842, 4.523561956057013, 4.857980995127572, 4.857980995127572, 7.459431618637297, 0.0, 6.700439718141092, 6.442943495848728, 6.3750394313469245, 6.339850002884624, 5.672425341971495, 3.4594316186372973, 5.285402218862249, 5.614709844115208, 5.614709844115208, 5.285402218862249, 5.0, 7.139551352398794, 7.936637939002571, 7.129283016944966, 4.700439718141092, 5.727920454563199, 6.169925001442312, 5.392317422778761, 5.169925001442312, 5.247927513443585, 5.087462841250339, 5.087462841250339, 9.250298417906333, 9.552669097514272, 7.857980995127572, 7.1799090900149345, 7.794415866350106, 7.189824558880018, 6.672425341971495, 5.882643049361842, 5.857980995127572, 5.857980995127572, 5.832890014164741, 6.965784284662087, 8.08214904135387, 1.0, 6.392317422778761, 8.918863237274595, 5.426264754702098, 5.426264754702098, 8.060695931687555, 5.930737337562887, 7.076815597050831, 7.0, 6.954196310386875, 6.832890014164741, 6.714245517666122, 5.459431618637297, 5.807354922057604, 6.658211482751795, 5.321928094887363, 5.754887502163468, 5.672425341971495, 7.491853096329675, 8.199672344836364, 6.741466986401147, 5.357552004618084, 5.882643049361842, 7.076815597050831, 5.643856189774724, 5.954196310386875, 5.20945336562895, 5.614709844115208, 5.614709844115208, 9.312882955284355, 9.733015321685963, 8.515699838284043, 7.741466986401147, 8.569855608330949, 7.98299357469431, 7.339850002884624, 6.658211482751795, 6.643856189774724, 6.643856189774724, 6.599912842187128, 7.6865005271832185, 8.734709620225837, 2.584962500721156, 7.149747119504682, 10.243173983472952, 5.643856189774724, 5.643856189774724, 8.108524456778168, 7.888743248898259, 7.159871336778389, 7.839203788096944, 7.813781191217037, 5.700439718141092, 4.584962500721156, 5.0, 4.643856189774724, 5.459431618637297, 5.321928094887363, 4.321928094887363, 4.392317422778761, 6.491853096329675, 7.05528243550119, 5.807354922057604, 3.321928094887362, 4.857980995127572, 5.78135971352466, 4.169925001442312, 4.169925001442312, 4.169925001442312, 4.754887502163468, 4.754887502163468, 8.290018846932618, 8.758223214726724, 7.499845887083206, 6.832890014164741, 7.483815777264256, 6.870364719583405, 5.882643049361842, 5.169925001442312, 5.169925001442312, 5.169925001442312, 5.169925001442312, 6.0, 7.149747119504682, 2.0, 5.727920454563199, 9.233619676759702, 4.169925001442312, 4.169925001442312, 7.507794640198696, 5.285402218862249, 6.6293566200796095, 6.569855608330948, 6.491853096329675, 5.754887502163468, 5.129283016944966, 3.321928094887362, 4.0, 5.0, 5.882643049361842, 4.643856189774724, 4.0, 6.426264754702098, 7.614709844115208, 5.754887502163468, 3.700439718141092, 5.357552004618084, 5.882643049361842, 5.321928094887363, 3.0, 4.247927513443585, 4.0, 4.0, 8.603626344986193, 9.129283016944967, 7.562242424221073, 6.044394119358453, 6.845490050944375, 6.539158811108031, 5.832890014164741, 5.087462841250339, 5.087462841250339, 5.087462841250339, 4.906890595608519, 6.108524456778169, 7.199672344836364, 4.321928094887363, 5.087462841250339, 9.03342300153745, 4.906890595608519, 4.906890595608519, 7.7073591320808825, 5.321928094887363, 6.475733430966398, 6.357552004618084, 6.357552004618084, 6.409390936137702, 5.906890595608519, 5.392317422778761, 5.754887502163468, 6.491853096329675, 6.22881869049588, 5.954196310386875, 5.643856189774724, 7.491853096329675, 7.845490050944375, 6.894817763307944, 4.459431618637297, 6.022367813028454, 6.569855608330948, 5.247927513443585, 5.807354922057604, 5.129283016944966, 5.700439718141092, 5.700439718141092, 9.204571144249204, 9.46352437327118, 8.515699838284043, 7.679480099505446, 8.405141463136344, 8.016808287686555, 7.076815597050831, 6.303780748177103, 6.303780748177103, 6.303780748177103, 6.303780748177103, 7.499845887083206, 8.584962500721156, 2.0, 6.741466986401147, 9.044394119358454, 6.409390936137702, 6.409390936137702, 7.813781191217037, 6.6293566200796095, 7.383704292474052, 7.584962500721156, 7.531381460516312, 6.442943495848728, 6.3750394313469245, 5.044394119358453, 5.426264754702098, 5.882643049361842, 5.614709844115208, 4.459431618637297, 5.459431618637297, 7.066089190457772, 7.727920454563199, 6.20945336562895, 3.700439718141092, 5.554588851677638, 5.584962500721156, 5.321928094887363, 5.0, 4.807354922057604, 5.129283016944966, 5.129283016944966, 8.804131021183318, 9.843921051289035, 7.960001932068081, 7.22881869049588, 7.936637939002571, 7.357552004618084, 6.78135971352466, 6.044394119358453, 6.044394119358453, 6.044394119358453, 6.022367813028454, 6.807354922057604, 7.954196310386875, 1.0, 5.832890014164741, 9.834471049984222, 5.20945336562895, 5.20945336562895, 8.044394119358454, 7.076815597050831, 6.845490050944375, 7.321928094887363, 7.294620748891627, 5.977279923499917, 5.584962500721156, 4.807354922057604, 4.754887502163468, 5.357552004618084, 5.357552004618084, 4.857980995127572, 4.754887502163468, 6.906890595608519, 7.906890595608519, 6.022367813028454, 4.584962500721156, 5.614709844115208, 5.459431618637297, 4.643856189774724, 4.169925001442312, 3.807354922057604, 4.857980995127572, 4.857980995127572, 8.997179480937621, 9.449148645375436, 7.60733031374961, 6.882643049361842, 7.584962500721156, 7.0, 6.108524456778169, 5.247927513443585, 5.247927513443585, 5.247927513443585, 5.20945336562895, 6.357552004618084, 7.499845887083206, null, 6.108524456778169, 8.434628227636725, 5.087462841250339, 5.087462841250339, 7.839203788096944, 5.523561956057013, 6.357552004618084, 6.820178962415188, 6.807354922057604, 7.03342300153745, 6.820178962415188, 6.022367813028454, 5.614709844115208, 6.807354922057604, 6.303780748177103, 6.149747119504682, 6.066089190457772, 7.266786540694901, 7.672425341971495, 7.1799090900149345, 5.129283016944966, 6.108524456778169, 7.011227255423254, 5.857980995127572, 5.906890595608519, 5.727920454563199, 5.954196310386875, 5.954196310386875, 9.052568050804153, 9.375039431346925, 8.751544059089099, 8.044394119358454, 8.861086905995395, 8.247927513443585, 7.475733430966398, 6.6293566200796095, 6.6293566200796095, 6.6293566200796095, 6.614709844115208, 7.882643049361842, 8.991521846075695, 5.954196310386875, 7.199672344836364, 9.294620748891626, 5.906890595608519, 5.906890595608519, 6.700439718141092, 7.257387842692652, 7.467605550082998, 7.787902559391432, 7.754887502163468, 4.392317422778761, 4.392317422778761, 4.459431618637297, 4.584962500721156, 5.426264754702098, 5.700439718141092, 4.954196310386875, 4.643856189774724, 6.189824558880018, 7.266786540694901, 5.700439718141092, 3.321928094887362, 4.857980995127572, 5.321928094887363, 4.523561956057013, 3.9068905956085187, 3.584962500721156, 4.700439718141092, 4.700439718141092, 8.060695931687555, 8.79766152585376, 7.2384047393250786, 6.894817763307944, 7.392317422778761, 7.044394119358453, 6.247927513443585, 5.459431618637297, 5.459431618637297, 5.459431618637297, 5.459431618637297, 6.459431618637297, 7.531381460516312, null, 6.247927513443585, 9.011227255423254, 5.247927513443585, 5.247927513443585, 6.569855608330948, 6.20945336562895, 6.22881869049588, 6.569855608330948, 6.491853096329675, 6.741466986401147, 5.807354922057604, 5.129283016944966, 5.459431618637297, 6.6293566200796095, 5.426264754702098, 5.087462841250339, 5.857980995127572, 7.098032082960526, 7.383704292474052, 6.768184324776926, 4.584962500721156, 6.554588851677638, 6.409390936137702, 5.807354922057604, 5.584962500721156, 5.554588851677638, 4.906890595608519, 4.906890595608519, 8.622051819456376, 9.303780748177102, 8.308339030139408, 7.577428828035749, 8.396604781181859, 7.693486957499325, 7.219168520462161, 6.392317422778761, 6.392317422778761, 6.392317422778761, 6.3750394313469245, 7.312882955284356, 8.383704292474052, null, 6.78135971352466, 9.799281621521923, 6.087462841250339, 6.087462841250339, 6.820178962415188, 6.714245517666122, 7.199672344836364, 7.348728154231077, 7.348728154231077, 7.392317422778761, 6.754887502163468, 5.906890595608519, 6.022367813028454, 6.599912842187128, 6.658211482751795, 5.247927513443585, 6.022367813028454, 7.864186144654281, 8.487840033823051, 7.108524456778169, 5.247927513443585, 6.357552004618084, 7.149747119504682, 6.044394119358453, 5.807354922057604, 5.672425341971495, 5.954196310386875, 5.954196310386875, 9.342074667999139, 9.810571634741146, 8.879583249612784, 8.184875342908283, 8.829722735086058, 8.405141463136344, 7.199672344836364, 6.459431618637297, 6.459431618637297, 6.459431618637297, 6.426264754702098, 7.679480099505446, 8.787902559391432, 4.857980995127572, 7.108524456778169, 10.357552004618084, 5.643856189774724, 5.643856189774724, 8.741466986401146, 7.247927513443585, 7.826548487290915, 8.139551352398794, 8.076815597050832, 6.643856189774724, 6.475733430966398, 4.857980995127572, 5.832890014164741, 5.807354922057604, 6.22881869049588, 6.247927513443585, 5.491853096329675, 7.392317422778761, 8.531381460516313, 7.087462841250339, 5.614709844115208, 5.727920454563199, 6.768184324776926, 5.643856189774724, 5.554588851677638, 5.0, 5.321928094887363, 5.321928094887363, 9.54882190845875, 9.67065624911844, 8.357552004618084, 7.584962500721156, 8.257387842692651, 7.6293566200796095, 7.139551352398794, 6.303780748177103, 6.303780748177103, 6.303780748177103, 6.266786540694901, 7.011227255423254, 8.076815597050832, 0.0, 6.741466986401147, 10.312882955284355, 5.672425341971495, 5.672425341971495, 8.46352437327118, 7.442943495848728, 7.392317422778761, 7.636624620543649, 7.592457037268081, 6.108524456778169, 5.459431618637297, 4.459431618637297, 4.700439718141092, 5.20945336562895, 5.169925001442312, 4.754887502163468, 5.129283016944966, 6.3750394313469245, 7.700439718141092, 6.523561956057013, 3.0, 4.807354922057604, 6.044394119358453, 4.807354922057604, 4.700439718141092, 4.087462841250339, 5.087462841250339, 5.087462841250339, 8.45532722030456, 8.787902559391432, 7.569855608330948, 6.584962500721156, 7.357552004618084, 6.94251450533924, 6.044394119358453, 5.285402218862249, 5.285402218862249, 5.285402218862249, 5.20945336562895, 6.523561956057013, 7.599912842187128, 1.0, 6.149747119504682, 9.344295907915816, 4.754887502163468, 4.754887502163468, 6.768184324776926, 5.491853096329675, 5.930737337562887, 6.643856189774724, 6.539158811108031, 6.426264754702098, 6.022367813028454, 5.727920454563199, 5.554588851677638, 5.857980995127572, 5.954196310386875, 6.20945336562895, 5.584962500721156, 7.459431618637297, 7.6865005271832185, 6.741466986401147, 4.523561956057013, 5.584962500721156, 6.266786540694901, 5.78135971352466, 5.523561956057013, 5.392317422778761, 4.807354922057604, 4.807354922057604, 8.965784284662087, 9.787902559391432, 8.51175265376738, 7.562242424221073, 8.247927513443585, 7.672425341971495, 6.930737337562887, 6.303780748177103, 6.303780748177103, 6.303780748177103, 6.285402218862249, 7.129283016944966, 8.184875342908283, 0.0, 6.672425341971495, 10.186114239541643, 5.672425341971495, 5.672425341971495, 8.233619676759702, 7.491853096329675, 6.954196310386875, 7.577428828035749, 7.539158811108031, 5.672425341971495, 5.321928094887363, 3.807354922057604, 5.129283016944966, 5.882643049361842, 5.129283016944966, 4.321928094887363, 5.321928094887363, 6.569855608330948, 7.400879436282184, 6.321928094887363, 4.459431618637297, 5.882643049361842, 6.087462841250339, 5.614709844115208, 4.247927513443585, 4.954196310386875, 5.20945336562895, 5.20945336562895, 8.321928094887362, 9.057991722759176, 7.679480099505446, 6.894817763307944, 7.562242424221073, 7.159871336778389, 6.491853096329675, 5.672425341971495, 5.672425341971495, 5.672425341971495, 5.643856189774724, 6.857980995127572, 7.960001932068081, 4.523561956057013, 5.700439718141092, 8.59618975614441, 4.523561956057013, 4.523561956057013, 8.204571144249204, 5.754887502163468, 6.658211482751795, 7.087462841250339, 7.044394119358453, 5.930737337562887, 5.523561956057013, 4.087462841250339, 4.807354922057604, 5.491853096329675, 5.087462841250339, 3.807354922057604, 4.169925001442312, 6.9886846867721655, 7.409390936137702, 6.20945336562895, 4.321928094887363, 5.643856189774724, 5.807354922057604, 5.129283016944966, 2.807354922057604, 4.169925001442312, 4.807354922057604, 4.807354922057604, 8.721099188707186, 9.342074667999139, 7.531381460516312, 6.954196310386875, 7.60733031374961, 7.066089190457772, 6.169925001442312, 5.357552004618084, 5.357552004618084, 5.357552004618084, 5.357552004618084, 5.930737337562887, 7.011227255423254, null, 5.285402218862249, 9.523561956057012, 5.0, 5.0, 7.6653359171851765, 5.554588851677638, 6.507794640198696, 6.754887502163468, 6.672425341971495, 6.409390936137702, 5.584962500721156, 3.807354922057604, 4.857980995127572, 5.357552004618084, 5.954196310386875, 5.78135971352466, 5.285402218862249, 7.2384047393250786, 8.257387842692651, 6.94251450533924, 4.0, 5.247927513443585, 6.149747119504682, 5.044394119358453, 5.584962500721156, 4.247927513443585, 5.523561956057013, 5.523561956057013, 9.13699111208023, 9.753216749178955, 8.108524456778168, 7.098032082960526, 7.768184324776926, 7.348728154231077, 6.442943495848728, 5.832890014164741, 5.832890014164741, 5.832890014164741, 5.78135971352466, 6.672425341971495, 7.700439718141092, 6.087462841250339, 6.044394119358453, 4.247927513443585, 4.857980995127572, 4.857980995127572, 8.46352437327118, 0.0, 6.714245517666122, 7.189824558880018, 7.118941072723508, 6.754887502163468, 6.044394119358453, 4.807354922057604, 5.727920454563199, 6.087462841250339, 5.832890014164741, 5.459431618637297, 5.0, 7.562242424221073, 8.129283016944967, 6.845490050944375, 4.906890595608519, 6.129283016944966, 6.727920454563199, 5.977279923499917, 4.584962500721156, 4.754887502163468, 5.426264754702098, 5.426264754702098, 9.177419537989236, 10.091435386323607, 8.400879436282183, 7.409390936137702, 8.129283016944967, 7.714245517666122, 7.366322214245816, 6.523561956057013, 6.523561956057013, 6.523561956057013, 6.459431618637297, 7.442943495848728, 8.531381460516313, 3.0, 6.459431618637297, 10.079484783826816, 5.491853096329675, 5.491853096329675, 8.430452551665532, 7.366322214245816, 7.20945336562895, 7.700439718141092, 7.651051691178929, 6.523561956057013, 5.832890014164741, 4.169925001442312, 5.426264754702098, 5.727920454563199, 6.0, 5.392317422778761, 4.857980995127572, 7.330916878114617, 8.066089190457772, 6.882643049361842, 4.0, 5.807354922057604, 6.339850002884624, 5.554588851677638, 4.584962500721156, 4.459431618637297, 5.392317422778761, 5.392317422778761, 9.002815015607053, 9.69522829149575, 8.219168520462162, 7.366322214245816, 8.092757140919852, 7.409390936137702, 6.94251450533924, 6.20945336562895, 6.20945336562895, 6.20945336562895, 6.189824558880018, 7.0, 8.08214904135387, 4.321928094887363, 6.507794640198696, 9.78953364497036, 5.614709844115208, 5.614709844115208, 8.308339030139408, 6.066089190457772, 6.554588851677638, 7.189824558880018, 7.169925001442312, 6.20945336562895, 5.906890595608519, 3.321928094887362, 4.0, 5.087462841250339, 5.643856189774724, 5.20945336562895, 4.954196310386875, 7.294620748891627, 8.03342300153745, 6.584962500721156, 3.807354922057604, 5.78135971352466, 6.129283016944966, 5.044394119358453, 4.169925001442312, 4.321928094887363, 4.523561956057013, 4.523561956057013, 8.873444112515376, 9.935165049603695, 7.754887502163468, 7.087462841250339, 7.6653359171851765, 7.417852514885898, 6.507794640198696, 5.754887502163468, 5.754887502163468, 5.754887502163468, 5.672425341971495, 6.149747119504682, 7.294620748891627, 3.4594316186372973, 6.247927513443585, 9.499845887083206, 5.169925001442312, 5.169925001442312, 8.643856189774725, 5.643856189774724, 6.882643049361842, 7.05528243550119, 7.022367813028454, 6.768184324776926, 5.643856189774724, 5.247927513443585, 4.857980995127572, 5.807354922057604, 6.339850002884624, 6.20945336562895, 5.78135971352466, 7.774787059601174, 8.611024797307353, 7.515699838284043, 3.700439718141092, 6.442943495848728, 6.768184324776926, 5.807354922057604, 5.554588851677638, 5.20945336562895, 6.087462841250339, 6.087462841250339, 9.722807531169547, 10.536247215688128, 8.686500527183219, 7.851749041416057, 8.515699838284043, 8.049848549450562, 7.044394119358453, 6.149747119504682, 6.149747119504682, 6.149747119504682, 6.087462841250339, 6.965784284662087, 8.092757140919852, 4.459431618637297, 6.491853096329675, 10.122827994807666, 5.392317422778761, 5.392317422778761, 8.499845887083206, 6.339850002884624, 7.1799090900149345, 7.523561956057013, 7.499845887083206, 6.022367813028454, 5.523561956057013, 4.954196310386875, 4.523561956057013, 4.954196310386875, 5.700439718141092, 4.643856189774724, 5.129283016944966, 7.076815597050831, 7.257387842692652, 6.409390936137702, 4.392317422778761, 5.247927513443585, 5.700439718141092, 4.906890595608519, 5.0, 4.523561956057013, 4.754887502163468, 4.754887502163468, 8.703903573444663, 9.479780264029099, 7.577428828035749, 7.098032082960526, 7.672425341971495, 7.149747119504682, 6.6865005271832185, 5.954196310386875, 5.954196310386875, 5.954196310386875, 5.930737337562887, 6.6865005271832185, 7.813781191217037, 3.807354922057604, 6.3750394313469245, 3.321928094887362, 4.754887502163468, 4.754887502163468, 8.266786540694902, null, 6.807354922057604, 6.977279923499917, 6.954196310386875, 6.339850002884624, 5.20945336562895, 4.321928094887363, 5.169925001442312, 6.108524456778169, 5.643856189774724, 4.906890595608519, 5.129283016944966, 7.118941072723508, 7.870364719583405, 6.523561956057013, 4.584962500721156, 5.584962500721156, 5.78135971352466, 5.700439718141092, 5.357552004618084, 4.643856189774724, 4.807354922057604, 4.807354922057604, 8.63662462054365, 9.357552004618084, 7.794415866350106, 7.2384047393250786, 7.794415866350106, 7.599912842187128, 6.247927513443585, 5.554588851677638, 5.554588851677638, 5.554588851677638, 5.554588851677638, 6.870364719583405, 7.948367231584678, null, 6.22881869049588, 9.784634845557521, 4.459431618637297, 4.459431618637297, 7.954196310386875, 7.108524456778169, 6.845490050944375, 7.3750394313469245, 7.348728154231077, 4.906890595608519, 4.0, 1.0, 3.321928094887362, 4.0, 4.247927513443585, 2.807354922057604, 4.321928094887363, 5.614709844115208, 6.442943495848728, 4.584962500721156, 3.807354922057604, 4.392317422778761, 4.321928094887363, 3.807354922057604, 4.807354922057604, 3.807354922057604, 4.392317422778761, 4.392317422778761, 7.60733031374961, 8.768184324776927, 6.539158811108031, 5.882643049361842, 6.741466986401147, 6.044394119358453, 5.0, 4.0, 3.9068905956085187, 3.9068905956085187, 3.807354922057604, 5.169925001442312, 6.426264754702098, 2.584962500721156, 4.321928094887363, 8.523561956057012, 3.0, 3.0, 5.459431618637297, 4.584962500721156, 5.426264754702098, 6.20945336562895, 6.189824558880018, 5.672425341971495, 5.247927513443585, 3.807354922057604, 4.523561956057013, 5.614709844115208, 5.672425341971495, 4.392317422778761, 5.087462841250339, 6.066089190457772, 7.011227255423254, 5.906890595608519, 3.9068905956085187, 4.321928094887363, 5.491853096329675, 4.700439718141092, 4.459431618637297, 3.4594316186372973, 4.523561956057013, 4.523561956057013, 8.204571144249204, 8.861086905995395, 7.451211111832329, 6.614709844115208, 7.357552004618084, 6.882643049361842, 5.754887502163468, 5.0, 5.0, 5.0, 4.954196310386875, 6.539158811108031, 7.636624620543649, 0.0, 5.614709844115208, 9.0, 5.285402218862249, 5.285402218862249, 7.348728154231077, 6.870364719583405, 5.906890595608519, 6.857980995127572, 6.832890014164741, 7.0, 5.584962500721156, 5.523561956057013, 5.700439718141092, 6.700439718141092, 6.554588851677638, 4.459431618637297, 5.554588851677638, 7.577428828035749, 7.918863237274595, 6.700439718141092, 4.643856189774724, 6.672425341971495, 6.807354922057604, 6.066089190457772, 5.0, 5.247927513443585, 5.727920454563199, 5.727920454563199, 8.96289600533726, 10.01262453886506, 8.842350343413807, 7.857980995127572, 8.618385502258606, 8.149747119504681, 7.108524456778169, 6.409390936137702, 6.3750394313469245, 6.3750394313469245, 6.357552004618084, 7.285402218862249, 8.370687406807217, 3.9068905956085187, 6.870364719583405, 10.12670447284319, 6.569855608330948, 6.569855608330948, 8.400879436282183, 7.820178962415188, 7.219168520462161, 7.888743248898259, 7.870364719583405, 1.0, 1.0, null, 1.584962500721156, 1.0, null, 1.584962500721156, null, 2.321928094887362, 4.0, 1.0, null, 2.0, 1.0, 0.0, 1.0, 0.0, null, null, 4.954196310386875, 5.584962500721156, 2.807354922057604, 1.584962500721156, 2.807354922057604, 3.321928094887362, 0.0, null, null, null, null, 0.0, 2.0, null, 2.807354922057604, 4.700439718141092, null, null, 3.584962500721156, 2.0, null, 2.807354922057604, 2.807354922057604, 6.918863237274595, 5.807354922057604, 5.169925001442312, 5.321928094887363, 5.954196310386875, 6.066089190457772, 5.321928094887363, 5.584962500721156, 7.383704292474052, 7.754887502163468, 7.330916878114617, 4.321928094887363, 5.672425341971495, 6.442943495848728, 5.285402218862249, 5.321928094887363, 4.906890595608519, 5.087462841250339, 5.087462841250339, 9.167418145831737, 9.642051692927977, 8.400879436282183, 7.794415866350106, 8.467605550082997, 7.813781191217037, 7.118941072723508, 6.409390936137702, 6.409390936137702, 6.409390936137702, 6.357552004618084, 7.303780748177103, 8.361943773735241, 0.0, 6.584962500721156, 2.0, 5.426264754702098, 5.426264754702098, 7.977279923499917, 0.0, 7.118941072723508, 7.577428828035749, 7.531381460516312, 5.20945336562895, 4.700439718141092, 3.321928094887362, 3.584962500721156, 4.247927513443585, 3.321928094887362, 4.643856189774724, 4.0, 6.303780748177103, 7.159871336778389, 5.247927513443585, 2.584962500721156, 4.321928094887363, 4.954196310386875, 4.321928094887363, 1.0, 3.0, 3.169925001442312, 3.169925001442312, 8.066089190457772, 8.951284714966972, 6.894817763307944, 6.066089190457772, 6.794415866350106, 6.285402218862249, 5.459431618637297, 4.643856189774724, 4.643856189774724, 4.643856189774724, 4.643856189774724, 5.247927513443585, 6.285402218862249, null, 4.321928094887363, 7.2384047393250786, 4.087462841250339, 4.087462841250339, 5.087462841250339, null, 5.614709844115208, 5.700439718141092, 5.672425341971495, 5.78135971352466, 5.285402218862249, 3.321928094887362, 4.321928094887363, 4.700439718141092, 4.700439718141092, 4.247927513443585, 4.754887502163468, 6.20945336562895, 7.658211482751795, 5.882643049361842, 4.087462841250339, 5.426264754702098, 5.285402218862249, 5.0, 4.169925001442312, 4.807354922057604, 4.643856189774724, 4.643856189774724, 8.546894459887637, 9.079484783826816, 7.584962500721156, 6.672425341971495, 7.483815777264256, 6.392317422778761, 6.149747119504682, 5.426264754702098, 5.426264754702098, 5.426264754702098, 5.392317422778761, 6.169925001442312, 7.348728154231077, 1.0, 5.491853096329675, 8.409390936137703, 4.459431618637297, 4.459431618637297, 6.149747119504682, 1.584962500721156, 6.189824558880018, 6.554588851677638, 6.491853096329675, 6.845490050944375, 6.20945336562895, 5.044394119358453, 5.882643049361842, 6.870364719583405, 6.554588851677638, 5.857980995127572, 5.807354922057604, 7.2761244052742375, 7.366322214245816, 6.78135971352466, 5.700439718141092, 6.584962500721156, 6.6865005271832185, 6.044394119358453, 6.247927513443585, 5.392317422778761, 5.930737337562887, 5.930737337562887, 8.379378367071261, 8.90388184573618, 8.710806433699352, 7.6293566200796095, 8.50382573799575, 7.94251450533924, 7.658211482751795, 6.930737337562887, 6.918863237274595, 6.918863237274595, 6.906890595608519, 7.787902559391432, 8.873444112515376, 2.0, 6.954196310386875, 10.084808387804362, 6.129283016944966, 6.129283016944966, 6.965784284662087, 7.22881869049588, 7.467605550082998, 7.7481928495894605, 7.7073591320808825, 6.599912842187128, 6.022367813028454, 5.857980995127572, 6.0, 6.954196310386875, 5.285402218862249, 5.672425341971495, 6.303780748177103, 7.129283016944966, 7.339850002884624, 6.845490050944375, 5.247927513443585, 6.266786540694901, 6.442943495848728, 5.643856189774724, 6.149747119504682, 4.954196310386875, 5.727920454563199, 5.727920454563199, 7.98299357469431, 8.804131021183318, 8.703903573444663, 7.754887502163468, 8.523561956057012, 8.08214904135387, 7.149747119504682, 6.303780748177103, 6.303780748177103, 6.303780748177103, 6.303780748177103, 7.906890595608519, 8.968666793195208, null, 6.794415866350106, 10.099347810403193, 6.087462841250339, 6.087462841250339, 7.118941072723508, 7.960001932068081, 7.451211111832329, 7.577428828035749, 7.577428828035749, 6.303780748177103, 5.20945336562895, 5.930737337562887, 5.78135971352466, 6.442943495848728, 6.108524456778169, 5.044394119358453, 5.832890014164741, 6.741466986401147, 6.918863237274595, 6.965784284662087, 4.247927513443585, 6.321928094887363, 6.569855608330948, 5.459431618637297, 5.807354922057604, 5.169925001442312, 5.906890595608519, 5.906890595608519, 7.734709620225838, 8.475733430966399, 8.276124405274238, 7.577428828035749, 8.169925001442312, 7.864186144654281, 6.870364719583405, 6.0, 5.977279923499917, 5.977279923499917, 5.930737337562887, 7.339850002884624, 8.442943495848729, null, 6.614709844115208, 9.912889336229961, 5.954196310386875, 5.954196310386875, 7.0, 7.442943495848728, 7.451211111832329, 7.426264754702098, 7.409390936137702, 5.459431618637297, 4.643856189774724, 5.087462841250339, 5.882643049361842, 6.599912842187128, 5.087462841250339, 3.9068905956085187, 5.285402218862249, 5.807354922057604, 6.044394119358453, 6.0, 4.321928094887363, 4.392317422778761, 5.0, 5.169925001442312, 5.977279923499917, 3.4594316186372973, 4.321928094887363, 4.321928094887363, 6.741466986401147, 7.679480099505446, 7.098032082960526, 6.554588851677638, 7.247927513443585, 7.20945336562895, 6.189824558880018, 5.392317422778761, 5.392317422778761, 5.392317422778761, 5.392317422778761, 7.266786540694901, 8.31741261376487, null, 5.807354922057604, 7.857980995127572, 4.643856189774724, 4.643856189774724, 5.954196310386875, 6.554588851677638, 5.857980995127572, 6.599912842187128, 6.584962500721156, 7.108524456778169, 6.409390936137702, 5.459431618637297, 6.108524456778169, 6.832890014164741, 6.459431618637297, 4.906890595608519, 6.149747119504682, 7.400879436282184, 7.098032082960526, 7.022367813028454, 4.807354922057604, 6.870364719583405, 6.6293566200796095, 5.554588851677638, 5.727920454563199, 5.584962500721156, 5.700439718141092, 5.700439718141092, 8.271463027904375, 8.915879378835774, 8.741466986401146, 7.774787059601174, 8.668884984266247, 7.936637939002571, 7.266786540694901, 6.475733430966398, 6.475733430966398, 6.475733430966398, 6.475733430966398, 7.800899899920305, 8.90388184573618, 4.584962500721156, 6.882643049361842, 9.06339508128851, 6.554588851677638, 6.554588851677638, 6.475733430966398, 7.149747119504682, 7.348728154231077, 7.734709620225838, 7.727920454563199, 6.3750394313469245, 6.149747119504682, 5.285402218862249, 5.491853096329675, 6.169925001442312, 5.857980995127572, 5.491853096329675, 5.357552004618084, 6.741466986401147, 6.6865005271832185, 5.906890595608519, 4.906890595608519, 5.459431618637297, 6.129283016944966, 5.643856189774724, 6.20945336562895, 4.643856189774724, 5.491853096329675, 5.491853096329675, 7.7481928495894605, 7.971543553950772, 8.087462841250339, 7.2384047393250786, 7.98299357469431, 7.491853096329675, 6.977279923499917, 6.339850002884624, 6.339850002884624, 6.339850002884624, 6.339850002884624, 7.357552004618084, 8.39231742277876, 1.584962500721156, 6.614709844115208, 8.933690654952233, 5.882643049361842, 5.882643049361842, 7.076815597050831, 6.569855608330948, 6.930737337562887, 7.294620748891627, 7.1799090900149345, 6.491853096329675, 5.392317422778761, 4.584962500721156, 4.754887502163468, 5.643856189774724, 5.584962500721156, 5.321928094887363, 5.087462841250339, 6.523561956057013, 6.700439718141092, 5.954196310386875, 4.0, 5.044394119358453, 5.832890014164741, 5.285402218862249, 6.0, 4.584962500721156, 4.954196310386875, 4.954196310386875, 7.22881869049588, 8.375039431346925, 7.754887502163468, 7.189824558880018, 7.672425341971495, 7.348728154231077, 6.599912842187128, 5.754887502163468, 5.754887502163468, 5.754887502163468, 5.727920454563199, 7.247927513443585, 8.308339030139408, 0.0, 6.3750394313469245, 8.519636252843213, 5.554588851677638, 5.554588851677638, 7.066089190457772, 5.832890014164741, 6.658211482751795, 6.954196310386875, 6.906890595608519, 4.754887502163468, 4.857980995127572, 3.321928094887362, 4.643856189774724, 5.285402218862249, 4.754887502163468, 4.247927513443585, 3.9068905956085187, 5.700439718141092, 5.614709844115208, 5.727920454563199, 3.169925001442312, 4.459431618637297, 4.392317422778761, 4.392317422778761, 3.584962500721156, 3.321928094887362, 4.584962500721156, 4.584962500721156, 6.426264754702098, 7.383704292474052, 6.965784284662087, 6.169925001442312, 7.0, 6.066089190457772, 5.643856189774724, 4.700439718141092, 4.700439718141092, 4.700439718141092, 4.700439718141092, 6.129283016944966, 7.247927513443585, null, 4.584962500721156, 7.467605550082998, 4.392317422778761, 4.459431618637297, 5.321928094887363, 5.321928094887363, 6.266786540694901, 6.022367813028454, 6.022367813028454, 5.614709844115208, 5.584962500721156, 4.0, 4.584962500721156, 5.523561956057013, 4.754887502163468, 5.0, 4.700439718141092, 5.672425341971495, 6.321928094887363, 6.475733430966398, 4.169925001442312, 5.247927513443585, 5.129283016944966, 4.643856189774724, 5.321928094887363, 4.523561956057013, 4.643856189774724, 4.643856189774724, 7.139551352398794, 7.523561956057013, 7.357552004618084, 6.643856189774724, 7.303780748177103, 6.906890595608519, 6.507794640198696, 5.700439718141092, 5.700439718141092, 5.700439718141092, 5.672425341971495, 6.539158811108031, 7.599912842187128, null, 5.392317422778761, 9.330916878114618, 4.807354922057604, 4.807354922057604, 6.442943495848728, 6.820178962415188, 6.247927513443585, 6.845490050944375, 6.794415866350106, 5.643856189774724, 4.807354922057604, 4.321928094887363, 5.0, 5.426264754702098, 5.584962500721156, 4.906890595608519, 5.285402218862249, 6.266786540694901, 6.599912842187128, 6.129283016944966, 4.643856189774724, 4.459431618637297, 5.78135971352466, 5.169925001442312, 5.930737337562887, 4.700439718141092, 4.087462841250339, 4.087462841250339, 7.312882955284356, 8.134426320220927, 7.845490050944375, 6.857980995127572, 7.714245517666122, 7.159871336778389, 6.507794640198696, 5.930737337562887, 5.930737337562887, 5.930737337562887, 5.882643049361842, 6.894817763307944, 7.930737337562887, 1.0, 6.149747119504682, 8.588714635582264, 5.247927513443585, 5.247927513443585, 6.672425341971495, 5.807354922057604, 6.539158811108031, 6.658211482751795, 6.614709844115208, 5.807354922057604, 5.426264754702098, 4.0, 4.459431618637297, 5.459431618637297, 4.169925001442312, 4.954196310386875, 5.044394119358453, 5.584962500721156, 5.857980995127572, 6.0, 3.584962500721156, 4.584962500721156, 5.392317422778761, 4.807354922057604, 4.459431618637297, 3.807354922057604, 4.247927513443585, 4.247927513443585, 6.930737337562887, 7.499845887083206, 7.491853096329675, 6.491853096329675, 7.266786540694901, 6.741466986401147, 5.977279923499917, 5.129283016944966, 5.129283016944966, 5.129283016944966, 5.129283016944966, 6.643856189774724, 7.7481928495894605, null, 5.247927513443585, 8.092757140919852, 4.700439718141092, 4.700439718141092, 5.700439718141092, 5.523561956057013, 5.754887502163468, 6.658211482751795, 6.643856189774724, 6.768184324776926, 6.169925001442312, 5.459431618637297, 6.108524456778169, 7.108524456778169, 5.930737337562887, 4.523561956057013, 5.754887502163468, 6.6865005271832185, 6.78135971352466, 7.1799090900149345, 4.169925001442312, 6.20945336562895, 6.658211482751795, 5.727920454563199, 4.584962500721156, 5.247927513443585, 5.832890014164741, 5.832890014164741, 7.839203788096944, 8.665335917185176, 8.535275376620802, 7.994353436858858, 8.479780264029099, 8.149747119504681, 7.383704292474052, 6.614709844115208, 6.614709844115208, 6.614709844115208, 6.599912842187128, 7.807354922057604, 8.894817763307943, 0.0, 7.022367813028454, 9.240791332161956, 6.169925001442312, 6.169925001442312, 7.383704292474052, 7.066089190457772, 7.442943495848728, 7.592457037268081, 7.562242424221073, 5.832890014164741, 4.523561956057013, 3.807354922057604, 4.807354922057604, 5.129283016944966, 4.523561956057013, 5.087462841250339, 4.857980995127572, 6.357552004618084, 6.357552004618084, 6.409390936137702, 3.169925001442312, 5.321928094887363, 4.392317422778761, 4.643856189774724, 5.392317422778761, 4.247927513443585, 4.807354922057604, 4.807354922057604, 7.321928094887363, 8.011227255423254, 7.442943495848728, 6.643856189774724, 7.285402218862249, 7.044394119358453, 6.247927513443585, 5.491853096329675, 5.491853096329675, 5.491853096329675, 5.491853096329675, 6.409390936137702, 7.592457037268081, null, 6.247927513443585, 9.019590728357882, 4.807354922057604, 4.857980995127572, 5.807354922057604, 6.894817763307944, 6.409390936137702, 6.584962500721156, 6.539158811108031, 5.882643049361842, 5.321928094887363, 4.700439718141092, 5.285402218862249, 6.022367813028454, 4.857980995127572, 4.700439718141092, 4.857980995127572, 6.087462841250339, 6.539158811108031, 6.0, 4.459431618637297, 4.906890595608519, 5.044394119358453, 4.523561956057013, 5.754887502163468, 3.700439718141092, 4.754887502163468, 4.754887502163468, 7.022367813028454, 7.400879436282184, 7.499845887083206, 6.807354922057604, 7.400879436282184, 7.139551352398794, 6.022367813028454, 5.087462841250339, 5.087462841250339, 5.087462841250339, 5.0, 7.22881869049588, 8.228818690495881, 2.807354922057604, 6.022367813028454, 9.366322214245816, 4.954196310386875, 4.954196310386875, 6.392317422778761, 7.294620748891627, 6.149747119504682, 7.022367813028454, 6.977279923499917, 6.409390936137702, 6.643856189774724, 4.643856189774724, 5.832890014164741, 6.303780748177103, 6.0, 5.700439718141092, 5.727920454563199, 6.954196310386875, 7.118941072723508, 6.882643049361842, 4.643856189774724, 5.20945336562895, 6.599912842187128, 6.0, 5.954196310386875, 5.169925001442312, 5.614709844115208, 5.614709844115208, 8.016808287686555, 8.696967526234287, 8.400879436282183, 7.475733430966398, 8.29920801838728, 7.882643049361842, 7.219168520462161, 6.3750394313469245, 6.3750394313469245, 6.3750394313469245, 6.357552004618084, 7.531381460516312, 8.682994583681683, 3.584962500721156, 7.108524456778169, 9.932214751968385, 6.087462841250339, 6.087462841250339, 6.845490050944375, 7.787902559391432, 7.2761244052742375, 7.60733031374961, 7.554588851677638, 2.584962500721156, 2.0, null, 1.584962500721156, 2.0, null, 2.321928094887362, 2.0, 1.0, 0.0, 3.0, null, null, 0.0, 0.0, 0.0, 1.0, null, null, 3.169925001442312, 2.584962500721156, 4.0, 2.321928094887362, 3.584962500721156, 3.584962500721156, 2.0, 1.584962500721156, 1.584962500721156, 1.584962500721156, 1.584962500721156, 3.321928094887362, 4.169925001442312, null, 2.584962500721156, 5.285402218862249, 2.0, 2.0, 1.584962500721156, 2.0, 2.807354922057604, 3.0, 2.584962500721156, 5.727920454563199, 5.554588851677638, 5.614709844115208, 4.807354922057604, 5.930737337562887, 4.321928094887363, 4.459431618637297, 4.906890595608519, 6.129283016944966, 6.0, 5.930737337562887, 3.9068905956085187, 4.906890595608519, 5.832890014164741, 4.584962500721156, 4.0, 4.392317422778761, 4.392317422778761, 4.392317422778761, 7.159871336778389, 7.643856189774724, 7.442943495848728, 6.658211482751795, 7.409390936137702, 6.845490050944375, 6.066089190457772, 5.169925001442312, 5.169925001442312, 5.169925001442312, 5.169925001442312, 6.754887502163468, 7.888743248898259, 1.0, 6.022367813028454, 9.12670447284319, 5.357552004618084, 5.357552004618084, 6.247927513443585, 7.022367813028454, 6.6293566200796095, 6.392317422778761, 6.357552004618084, 6.3750394313469245, 6.087462841250339, 4.584962500721156, 5.129283016944966, 6.108524456778169, 5.357552004618084, 4.906890595608519, 5.169925001442312, 6.584962500721156, 6.539158811108031, 6.0, 4.0, 6.0, 6.0, 5.614709844115208, 5.321928094887363, 4.523561956057013, 4.700439718141092, 4.700439718141092, 7.693486957499325, 8.108524456778168, 7.900866807980749, 7.159871336778389, 7.832890014164741, 7.451211111832329, 7.05528243550119, 6.22881869049588, 6.22881869049588, 6.22881869049588, 6.20945336562895, 7.257387842692652, 8.361943773735241, null, 6.643856189774724, 8.43879185257826, 5.392317422778761, 5.392317422778761, 6.022367813028454, 0.0, 7.022367813028454, 7.189824558880018, 7.098032082960526, 5.392317422778761, 5.044394119358453, 4.459431618637297, 4.754887502163468, 5.426264754702098, 4.459431618637297, 4.643856189774724, 4.247927513443585, 5.78135971352466, 5.857980995127572, 5.78135971352466, 3.169925001442312, 4.523561956057013, 5.044394119358453, 4.459431618637297, 4.392317422778761, 3.321928094887362, 3.700439718141092, 3.700439718141092, 6.643856189774724, 7.294620748891627, 7.321928094887363, 6.303780748177103, 7.066089190457772, 6.409390936137702, 5.700439718141092, 5.044394119358453, 5.044394119358453, 5.044394119358453, 5.0, 6.129283016944966, 7.257387842692652, 1.584962500721156, 5.954196310386875, 8.787902559391432, 5.044394119358453, 5.044394119358453, 5.20945336562895, 5.392317422778761, 6.087462841250339, 6.189824558880018, 6.108524456778169], "y0": " ", "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"], ["3L", "AIM12"], ["3L", "AIM13"], ["3L", "AIM14"], ["3L", "AIM15"], ["3L", "AIM16"], ["3L", "AIM17"], ["3L", "Tep1A"], ["3L", "Tep1B"]], "hovertemplate": "contig=%{customdata[0]}<br>amplicon=%{x}<br>log_depth=%{y}<br>mutation=%{customdata[1]}<extra></extra>", "legendgroup": "3L", "marker": {"color": "#D62728"}, "name": "3L", "notched": false, "offsetgroup": "3L", "orientation": "v", "showlegend": true, "type": "box", "x": ["Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52"], "x0": " ", "xaxis": "x", "y": [null, 6.321928094887363, 3.700439718141092, 8.717676423066395, 5.643856189774724, 7.721099188707185, 6.906890595608519, 6.087462841250339, null, 3.584962500721156, 3.0, 4.247927513443585, 1.584962500721156, 1.0, 3.584962500721156, 2.0, null, null, null, 1.584962500721156, null, null, null, 1.584962500721156, null, 1.0, null, 1.0, 1.0, 2.0, 2.321928094887362, 2.321928094887362, null, 3.4594316186372973, 1.0, 5.285402218862249, null, 1.0, 5.459431618637297, 2.584962500721156, null, 5.285402218862249, 3.807354922057604, 4.857980995127572, 4.0, 4.807354922057604, 3.807354922057604, 4.169925001442312, null, 1.584962500721156, null, null, 3.700439718141092, null, null, 1.0, null, null, null, 0.0, null, 2.0, null, 1.0, null, null, null, 0.0, null, 1.0, null, 1.0, null, 3.4594316186372973, 1.0, 2.584962500721156, 2.0, 4.643856189774724, 3.169925001442312, 3.321928094887362, null, 2.584962500721156, 1.0, 2.321928094887362, 3.0, 3.0, 1.584962500721156, 2.0, null, 1.584962500721156, null, 3.0, 1.0, 0.0, null, 2.0, null, 4.459431618637297, 3.584962500721156, 5.087462841250339, 4.321928094887363, 3.807354922057604, 4.584962500721156, 4.087462841250339, null, 4.169925001442312, 4.0, 5.491853096329675, 3.700439718141092, 4.954196310386875, 4.584962500721156, 3.584962500721156, 0.0, 3.169925001442312, null, 1.584962500721156, 0.0, 1.584962500721156, 3.584962500721156, 3.0, null, 3.321928094887362, 2.321928094887362, 4.906890595608519, 1.584962500721156, 4.0, 4.754887502163468, 3.584962500721156, null, 4.0, 1.584962500721156, 4.392317422778761, 2.584962500721156, 3.9068905956085187, 4.807354922057604, 3.584962500721156, null, 4.169925001442312, 2.0, 4.321928094887363, 2.0, 3.584962500721156, 2.0, 2.321928094887362, null, 6.044394119358453, 3.169925001442312, 6.442943495848728, 4.392317422778761, 5.857980995127572, 4.857980995127572, 5.584962500721156, null, 3.0, 0.0, null, 0.0, 1.584962500721156, 1.584962500721156, 2.321928094887362, null, 6.20945336562895, 3.9068905956085187, 5.044394119358453, 4.169925001442312, 5.78135971352466, 3.169925001442312, 3.584962500721156, null, 3.807354922057604, 1.584962500721156, 4.392317422778761, 3.700439718141092, 3.321928094887362, 4.169925001442312, 2.584962500721156, null, 0.0, null, 1.0, 0.0, 2.807354922057604, 2.0, 0.0, null, 0.0, null, 0.0, null, null, null, 1.0, null, 7.515699838284043, 2.0, 3.0, 2.807354922057604, 6.266786540694901, 2.0, 6.845490050944375, null, 6.491853096329675, 4.392317422778761, 6.321928094887363, 4.584962500721156, 5.523561956057013, 6.6865005271832185, 6.087462841250339, null, 4.700439718141092, 2.807354922057604, 5.044394119358453, 4.0, 4.754887502163468, 4.247927513443585, 3.807354922057604, null, 2.807354922057604, 1.0, null, 1.584962500721156, 0.0, 2.584962500721156, 2.0, null, 4.857980995127572, 3.4594316186372973, 4.321928094887363, 3.584962500721156, 4.754887502163468, 5.0, 4.700439718141092, null, 7.03342300153745, 4.247927513443585, 7.2761244052742375, 5.882643049361842, 6.930737337562887, 5.459431618637297, 5.727920454563199, null, 0.0, 2.0, null, null, 1.584962500721156, null, 1.0, null, 4.321928094887363, 3.4594316186372973, 2.807354922057604, 3.169925001442312, 3.9068905956085187, 3.321928094887362, 3.169925001442312, null, 6.22881869049588, 4.459431618637297, 6.442943495848728, 4.392317422778761, 5.129283016944966, 5.129283016944966, 5.169925001442312, null, 5.523561956057013, 3.700439718141092, 4.954196310386875, 5.169925001442312, 6.658211482751795, 4.0, 5.977279923499917, null, 4.807354922057604, 2.0, 5.727920454563199, 2.584962500721156, 4.807354922057604, 4.700439718141092, 4.169925001442312, null, null, 1.0, 0.0, null, 0.0, null, null, null, 7.266786540694901, 5.321928094887363, 7.189824558880018, 5.78135971352466, 5.807354922057604, 7.60733031374961, 7.05528243550119, null, 4.169925001442312, 3.584962500721156, 4.523561956057013, 3.700439718141092, 5.044394119358453, 5.321928094887363, 4.169925001442312, null, 4.523561956057013, 2.584962500721156, 4.954196310386875, 3.321928094887362, 5.459431618637297, 5.700439718141092, 4.321928094887363, null, 6.022367813028454, 3.584962500721156, 4.584962500721156, 5.044394119358453, 5.087462841250339, 4.523561956057013, 5.807354922057604, null, 4.754887502163468, 1.584962500721156, 4.523561956057013, 4.169925001442312, 4.321928094887363, 3.9068905956085187, 3.321928094887362, null, 4.700439718141092, 3.0, 3.4594316186372973, 2.807354922057604, 3.700439718141092, 4.321928094887363, 3.584962500721156, null, 5.459431618637297, 3.9068905956085187, 6.3750394313469245, 5.426264754702098, 6.108524456778169, null, 3.169925001442312, null, 5.129283016944966, 1.0, 4.0, 3.9068905956085187, 5.0, 1.0, null, null, 5.087462841250339, 3.584962500721156, 4.247927513443585, 3.169925001442312, 2.321928094887362, 4.807354922057604, 4.906890595608519, null, 3.0, 1.584962500721156, 3.807354922057604, 3.0, 3.9068905956085187, 4.169925001442312, 2.584962500721156, null, 4.321928094887363, 1.584962500721156, 4.459431618637297, 3.4594316186372973, 4.700439718141092, 4.523561956057013, 3.807354922057604, null, null, null, 0.0, null, 2.0, null, null, null, 7.554588851677638, 4.906890595608519, 7.6653359171851765, 5.807354922057604, 7.7073591320808825, 7.651051691178929, 7.066089190457772, null, 7.507794640198696, 5.169925001442312, 6.977279923499917, 6.285402218862249, 7.392317422778761, 6.614709844115208, 6.78135971352466, 7.6865005271832185, 8.422064766172813, 7.0, 8.703903573444663, 6.714245517666122, 7.409390936137702, 7.129283016944966, 7.599912842187128, null, 5.20945336562895, 2.321928094887362, 6.741466986401147, 4.087462841250339, 5.614709844115208, 3.0, 3.584962500721156, null, 6.0, 3.584962500721156, 5.857980995127572, 4.954196310386875, 5.357552004618084, 3.807354922057604, 4.523561956057013, null, 4.857980995127572, 3.169925001442312, 3.807354922057604, 3.4594316186372973, 4.0, 4.0, 3.807354922057604, null, 6.409390936137702, 4.0, 7.321928094887363, 5.169925001442312, 6.6865005271832185, 5.727920454563199, 5.832890014164741, null, 5.614709844115208, 2.0, 6.714245517666122, 2.807354922057604, 5.459431618637297, 5.954196310386875, 4.807354922057604, null, 5.044394119358453, 0.0, 4.754887502163468, 2.0, 4.584962500721156, 4.321928094887363, 4.584962500721156, null, 3.169925001442312, 2.584962500721156, 2.807354922057604, 2.0, 2.584962500721156, 4.169925001442312, 3.700439718141092, null, 3.9068905956085187, 2.321928094887362, 5.523561956057013, 2.807354922057604, 4.954196310386875, 5.169925001442312, 3.700439718141092, null, null, null, 0.0, null, null, 1.0, 0.0, 1.0, 8.707359132080883, 7.312882955284356, 8.491853096329674, 7.832890014164741, 8.243173983472952, 8.214319120800766, 8.558420713268664, null, 7.20945336562895, 5.044394119358453, 7.839203788096944, 5.882643049361842, 6.845490050944375, 6.409390936137702, 6.754887502163468, null, 4.954196310386875, 2.584962500721156, 5.554588851677638, 3.4594316186372973, 5.0, 4.321928094887363, 4.169925001442312, null, 6.599912842187128, 3.4594316186372973, 7.066089190457772, 6.022367813028454, 7.066089190457772, 6.087462841250339, 5.754887502163468, null, 1.0, null, null, 0.0, null, 2.0, null, null, 4.321928094887363, 1.0, 3.169925001442312, 3.169925001442312, 2.807354922057604, null, 1.584962500721156, null, 5.247927513443585, 2.807354922057604, 5.754887502163468, 3.321928094887362, 5.0, 5.357552004618084, 4.906890595608519, null, 4.247927513443585, 1.0, 5.129283016944966, 2.0, 4.321928094887363, 3.584962500721156, 3.9068905956085187, null, 4.087462841250339, 0.0, 3.321928094887362, 1.584962500721156, 3.584962500721156, 1.584962500721156, 3.0, null, 3.700439718141092, 2.321928094887362, 3.700439718141092, 3.4594316186372973, 4.247927513443585, 3.0, 3.807354922057604, null, 2.0, 0.0, 2.321928094887362, null, 2.0, 0.0, 1.0, null, null, null, 0.0, null, 1.0, 0.0, null, null, 5.672425341971495, 4.584962500721156, 5.554588851677638, 5.169925001442312, 5.832890014164741, 5.044394119358453, 5.882643049361842, null, 5.906890595608519, 3.0, 5.614709844115208, 5.357552004618084, 5.523561956057013, 5.459431618637297, 5.754887502163468, null, 5.857980995127572, 2.321928094887362, 3.807354922057604, 5.0, 5.584962500721156, 3.9068905956085187, 4.807354922057604, null, 6.442943495848728, 4.700439718141092, 5.554588851677638, 5.700439718141092, 5.554588851677638, 4.459431618637297, 5.357552004618084, null, 3.584962500721156, 2.321928094887362, 3.4594316186372973, 2.584962500721156, 4.169925001442312, 2.0, 3.321928094887362, null, 4.584962500721156, 1.584962500721156, 4.906890595608519, 4.754887502163468, 4.584962500721156, 3.700439718141092, 3.9068905956085187, null, 8.194756854422248, 6.768184324776926, 7.330916878114617, 7.20945336562895, 6.539158811108031, 7.679480099505446, 7.734709620225838, null, 2.0, 1.584962500721156, 3.169925001442312, 2.321928094887362, 3.4594316186372973, 2.584962500721156, 3.9068905956085187, 0.0, 6.285402218862249, 5.0, 5.169925001442312, 5.906890595608519, 4.459431618637297, 4.459431618637297, 5.614709844115208, null, 3.9068905956085187, 2.807354922057604, 2.584962500721156, 3.700439718141092, 3.0, 1.0, null, null, 4.087462841250339, 1.0, 4.0, 4.087462841250339, 4.169925001442312, 3.4594316186372973, 4.321928094887363, null, null, null, 0.0, null, 2.0, 0.0, 0.0, null, 7.434628227636725, 6.129283016944966, 6.78135971352466, 6.918863237274595, 6.94251450533924, 6.78135971352466, 7.366322214245816, 2.0, 9.211888294546004, 8.169925001442312, 8.845490050944376, 8.370687406807217, 8.94251450533924, 8.848622940429339, 9.467605550082997, null, 3.700439718141092, 3.807354922057604, 3.700439718141092, 3.0, 4.0, 0.0, 3.0, null, 5.807354922057604, 2.321928094887362, 5.954196310386875, 5.459431618637297, 5.357552004618084, 4.906890595608519, 5.321928094887363, null, null, null, 1.584962500721156, null, 1.0, 0.0, 1.0, null, 0.0, null, null, 0.0, 3.169925001442312, 1.0, 2.0, null, 6.066089190457772, 2.584962500721156, 5.129283016944966, 5.700439718141092, 5.459431618637297, 4.954196310386875, 5.459431618637297, null, null, null, 0.0, null, null, null, null, null, 5.285402218862249, 3.321928094887362, 4.0, 3.4594316186372973, 4.087462841250339, 5.044394119358453, 5.357552004618084, 0.0, null, null, 1.584962500721156, null, 1.0, null, 0.0, null, 5.977279923499917, 3.169925001442312, 4.392317422778761, 4.392317422778761, 5.321928094887363, 5.087462841250339, 5.392317422778761, null, null, null, 1.0, null, 0.0, 0.0, 1.0, 0.0, 2.807354922057604, 0.0, 5.247927513443585, null, 3.0, 5.044394119358453, 3.0, null, 0.0, 1.0, null, 0.0, null, 0.0, 1.0, 6.820178962415188, 6.189824558880018, 5.169925001442312, 7.098032082960526, 4.807354922057604, 6.599912842187128, 6.569855608330948, 5.954196310386875, null, 4.0, 5.087462841250339, 4.169925001442312, 6.339850002884624, 2.0, 6.741466986401147, 5.882643049361842, null, 2.0, 3.321928094887362, 4.0, 4.087462841250339, 1.0, 6.6865005271832185, 4.954196310386875, 1.584962500721156, 3.0, 0.0, null, 1.0, 2.584962500721156, null, null, null, 0.0, null, null, 2.321928094887362, 2.584962500721156, null, 1.0, null, null, null, 2.584962500721156, null, null, 1.0, null, 3.700439718141092, 2.321928094887362, 2.321928094887362, 2.807354922057604, 2.584962500721156, 3.0, 2.807354922057604, 1.0, 2.0, 1.584962500721156, 1.0, 3.169925001442312, 1.0, 2.584962500721156, 2.0, 2.0, 0.0, null, 1.584962500721156, 0.0, 3.169925001442312, null, 2.807354922057604, null, null, 0.0, null, 1.584962500721156, 0.0, null, 2.0, 2.584962500721156, 0.0, 1.584962500721156, 2.807354922057604, 2.584962500721156, 3.700439718141092, 0.0, 5.087462841250339, 1.0, 6.727920454563199, 6.507794640198696, 5.321928094887363, 6.894817763307944, 5.584962500721156, 7.294620748891627, 6.357552004618084, 6.247927513443585, null, null, null, 0.0, null, 0.0, null, null, 0.0, 0.0, 4.087462841250339, null, 2.0, 0.0, 4.459431618637297, 3.807354922057604, null, 2.321928094887362, null, 3.4594316186372973, null, 2.584962500721156, 2.0, 0.0, null, 0.0, null, 3.584962500721156, null, 2.321928094887362, 2.807354922057604, 1.0, null, 0.0, 1.584962500721156, 2.321928094887362, 3.0, 0.0, 4.584962500721156, 3.0, null, null, null, 0.0, 0.0, 0.0, 3.0, 3.0, 3.169925001442312, 2.584962500721156, 1.0, 4.392317422778761, null, 4.087462841250339, 2.0, 2.0, null, 1.0, 1.0, null, 1.0, 1.0, 5.169925001442312, null, 2.321928094887362, 2.807354922057604, 0.0, 3.0, 2.0, 4.247927513443585, 3.9068905956085187, 2.584962500721156, null, null, 0.0, 1.0, null, 1.584962500721156, 1.584962500721156, 1.584962500721156, 5.169925001442312, 5.882643049361842, 2.0, 3.321928094887362, 1.584962500721156, 4.700439718141092, 2.0, 4.584962500721156, null, 1.0, 4.247927513443585, 1.0, 5.426264754702098, 2.584962500721156, 6.087462841250339, 5.491853096329675, 2.807354922057604, 0.0, null, 2.584962500721156, 2.0, 0.0, 3.700439718141092, null, null, null, null, 3.0, null, null, null, 0.0, null, null, 3.0, null, 1.0, 0.0, 5.459431618637297, 3.807354922057604, null, 1.0, 2.321928094887362, 0.0, 3.0, null, 4.754887502163468, 2.0, 0.0, 1.584962500721156, 0.0, 5.882643049361842, 1.584962500721156, 0.0, 5.643856189774724, 3.0, null, null, 1.584962500721156, 1.584962500721156, 1.584962500721156, 0.0, 4.169925001442312, 2.321928094887362, null, 3.584962500721156, 0.0, 3.807354922057604, 0.0, 2.584962500721156, 2.584962500721156, 1.0, null, 1.0, 1.584962500721156, 1.0, 1.0, 1.0, 1.0, 1.584962500721156, 0.0, null, 0.0, null, null, 1.0, 3.169925001442312, 1.0, null, null, 0.0, 0.0, 1.0, 0.0, 2.0, null, 0.0, 2.0, 4.906890595608519, 3.4594316186372973, 5.491853096329675, 1.0, 6.9886846867721655, 5.584962500721156, null, 1.0, 3.700439718141092, 1.0, 4.643856189774724, 1.584962500721156, 6.727920454563199, 3.9068905956085187, 3.4594316186372973, 5.0, 1.584962500721156, 4.523561956057013, 3.321928094887362, 5.584962500721156, 4.392317422778761, 5.20945336562895, 1.0, null, 3.4594316186372973, 2.0, 5.247927513443585, 1.584962500721156, 3.321928094887362, 4.523561956057013, null, null, null, null, 1.0, 0.0, 0.0, 1.0, null, null, null, 2.807354922057604, 2.807354922057604, 0.0, 2.584962500721156, 3.0, 2.321928094887362, 1.584962500721156, 0.0, 3.321928094887362, null, 3.0, 2.0, 2.584962500721156, null, 0.0, 0.0, 2.0, 1.0, null, 1.584962500721156, 1.0, null, null, 1.584962500721156, null, 3.321928094887362, null, 4.169925001442312, 3.584962500721156, null, null, null, null, null, 0.0, 2.0, 2.0, 0.0, null, 0.0, null, null, null, 2.0, null, 0.0, null, null, null, 0.0, 0.0, 3.0, null, null, 1.584962500721156, 0.0, 3.4594316186372973, null, 1.0, 4.0, 1.0, 1.584962500721156, 3.0, 4.584962500721156, 4.906890595608519, 5.727920454563199, 0.0, 5.977279923499917, 6.409390936137702, null, 1.0, 4.906890595608519, 1.584962500721156, 5.392317422778761, 0.0, 6.169925001442312, 5.20945336562895, 3.584962500721156, 2.584962500721156, 1.584962500721156, 6.066089190457772, 1.0, 4.0, 4.392317422778761, 3.321928094887362, null, null, 1.584962500721156, 5.0, 2.0, null, 1.0, 2.321928094887362, null, 3.700439718141092, 1.584962500721156, 3.4594316186372973, 1.0, 2.584962500721156, 4.392317422778761, 3.321928094887362, null, 1.0, 1.0, 3.321928094887362, 2.584962500721156, 0.0, 4.584962500721156, 1.0, null, 0.0, 1.584962500721156, 2.321928094887362, 1.584962500721156, 2.584962500721156, 3.584962500721156, null, 3.4594316186372973, 3.700439718141092, 3.700439718141092, 6.614709844115208, 3.9068905956085187, 3.4594316186372973, 6.6865005271832185, 4.807354922057604, null, 0.0, 1.584962500721156, 3.169925001442312, 2.0, 0.0, 4.754887502163468, 2.584962500721156, null, null, null, 2.321928094887362, 2.584962500721156, null, 2.0, 2.321928094887362, 0.0, null, null, 1.584962500721156, 1.0, 0.0, 4.643856189774724, 3.0, null, null, null, 3.4594316186372973, null, 2.0, 3.584962500721156, null, 4.584962500721156, 4.523561956057013, 3.321928094887362, 4.754887502163468, 2.584962500721156, 3.9068905956085187, 5.087462841250339, 4.087462841250339, 0.0, 1.584962500721156, null, 4.754887502163468, 3.321928094887362, 0.0, 6.022367813028454, 1.0, 2.0, 3.584962500721156, 5.129283016944966, 5.129283016944966, 5.906890595608519, 0.0, 6.614709844115208, 5.285402218862249, null, null, null, 1.0, null, null, 2.0, null, null, 1.584962500721156, 1.584962500721156, 4.523561956057013, 2.321928094887362, null, 2.584962500721156, 1.0, null, null, 0.0, null, 0.0, null, 1.0, 1.0, null, null, 0.0, 4.169925001442312, 1.0, 0.0, 3.321928094887362, null, null, 0.0, 1.584962500721156, null, 2.0, 0.0, 3.4594316186372973, 2.0, 2.584962500721156, 3.584962500721156, 3.0, 2.807354922057604, 2.0, 3.169925001442312, 2.0, 1.0, null, 2.807354922057604, 0.0, 3.584962500721156, 2.321928094887362, null, 2.0, 1.0, null, null, null, null, 0.0, null, 1.0, null, 6.426264754702098, 5.247927513443585, 5.247927513443585, 5.169925001442312, 5.087462841250339, 4.087462841250339, 5.672425341971495, 5.426264754702098, null, null, 0.0, 1.584962500721156, 1.584962500721156, 1.584962500721156, null, 1.0, 1.0, null, 2.0, 1.0, 5.169925001442312, 1.584962500721156, 4.169925001442312, 5.129283016944966, 5.20945336562895, 6.087462841250339, 4.700439718141092, 6.189824558880018, 4.392317422778761, 5.954196310386875, 4.0, 5.129283016944966, 0.0, 5.426264754702098, 3.0, 4.392317422778761, 5.169925001442312, 4.584962500721156, 3.169925001442312, 4.392317422778761, null, null, 2.0, null, 3.0, null, null, 1.0, null, 4.169925001442312, 2.584962500721156, 2.584962500721156, 3.321928094887362, 4.169925001442312, 1.0, 3.584962500721156, 2.321928094887362, 3.4594316186372973, 0.0, 3.0, 2.321928094887362, 2.0, 1.584962500721156, 3.321928094887362, null, null, 1.584962500721156, 1.584962500721156, 3.9068905956085187, 1.0, 2.0, 1.584962500721156, null, null, 0.0, null, 1.0, null, 2.0, 1.0, null, 1.0, 0.0, 1.0, 0.0, null, 2.584962500721156, null, null, null, null, null, null, null, null, 1.584962500721156, null, null, 1.584962500721156, 2.0, 3.584962500721156, 1.0, 4.643856189774724, 3.169925001442312, 10.026523442519766, 9.509775004326936, 8.693486957499326, 8.614709844115207, 8.658211482751796, 9.357552004618084, 8.194756854422248, 9.461479447286155, 0.0, 1.0, null, 2.321928094887362, 3.0, 1.0, 2.0, 2.0, null, null, 3.807354922057604, 1.0, 5.977279923499917, 1.584962500721156, 5.169925001442312, 2.321928094887362, null, 1.0, 4.392317422778761, null, 5.357552004618084, 1.0, 5.700439718141092, 4.392317422778761, null, null, null, null, 1.584962500721156, null, null, 1.0, null, null, 2.0, null, 2.807354922057604, 0.0, 2.584962500721156, 2.584962500721156, null, 0.0, 1.0, 1.584962500721156, 3.321928094887362, null, 3.169925001442312, 2.0, null, null, null, null, null, null, null, null, 0.0, null, 1.0, 1.584962500721156, 1.584962500721156, 1.0, 0.0, null, null, null, 1.0, null, 2.807354922057604, null, 2.584962500721156, 3.584962500721156, null, null, null, 1.0, null, null, null, null, 6.285402218862249, 5.459431618637297, 4.523561956057013, 6.94251450533924, 4.906890595608519, 5.392317422778761, 5.832890014164741, 5.285402218862249, 6.426264754702098, 5.882643049361842, 5.491853096329675, 6.6865005271832185, 4.459431618637297, 5.321928094887363, 5.285402218862249, 5.459431618637297, 7.845490050944375, 7.3750394313469245, 6.20945336562895, 7.918863237274595, 6.303780748177103, 7.426264754702098, 7.357552004618084, 7.303780748177103, 6.357552004618084, 5.754887502163468, 5.247927513443585, 6.523561956057013, 4.954196310386875, 5.882643049361842, 6.0, 5.727920454563199, 8.312882955284355, 7.864186144654281, 6.906890595608519, 9.047123912114026, 6.820178962415188, 7.569855608330948, 8.076815597050832, 7.960001932068081, 9.027905996569885, 8.413627929024173, 7.888743248898259, 9.025139562278508, 7.857980995127572, 7.906890595608519, 7.78135971352466, 8.668884984266247, 0.0, 2.807354922057604, 0.0, 1.0, 5.554588851677638, 1.584962500721156, 1.0, 1.0, null, 0.0, null, null, null, null, null, null, null, 0.0, null, 1.0, null, null, 0.0, null, 6.768184324776926, 5.491853096329675, 5.247927513443585, 7.087462841250339, 5.754887502163468, 4.906890595608519, 5.357552004618084, 6.087462841250339, null, null, null, null, null, null, null, null, 7.507794640198696, 6.768184324776926, 5.954196310386875, 7.971543553950772, 6.0, 6.700439718141092, 7.321928094887363, 7.2384047393250786, 7.7073591320808825, 6.794415866350106, 6.392317422778761, 7.599912842187128, 6.22881869049588, 6.741466986401147, 6.906890595608519, 7.022367813028454, 8.03342300153745, 7.1799090900149345, 6.442943495848728, 7.467605550082998, 6.672425341971495, 7.1799090900149345, 7.118941072723508, 7.599912842187128, 5.857980995127572, 4.954196310386875, 3.9068905956085187, 5.857980995127572, 4.954196310386875, 5.614709844115208, 5.285402218862249, 5.087462841250339, 6.857980995127572, 6.426264754702098, 6.523561956057013, 7.169925001442312, 5.129283016944966, 6.741466986401147, 6.475733430966398, 6.22881869049588, 7.592457037268081, 6.569855608330948, 6.22881869049588, 7.199672344836364, 5.78135971352466, 6.78135971352466, 7.066089190457772, 6.672425341971495, 7.044394119358453, 6.857980995127572, 5.832890014164741, 7.6653359171851765, 5.491853096329675, 6.894817763307944, 6.554588851677638, 6.700439718141092, 5.044394119358453, 4.906890595608519, 4.321928094887363, 6.285402218862249, 2.807354922057604, 4.857980995127572, 5.392317422778761, 4.247927513443585, 6.584962500721156, 6.321928094887363, 5.169925001442312, 7.965784284662087, 5.285402218862249, 5.643856189774724, 7.03342300153745, 6.857980995127572, null, null, null, null, null, null, null, null, 7.366322214245816, 6.303780748177103, 5.754887502163468, 7.467605550082998, 5.614709844115208, 6.339850002884624, 6.3750394313469245, 6.392317422778761, null, null, null, 1.0, 0.0, null, null, null, 6.475733430966398, 5.044394119358453, 4.906890595608519, 7.409390936137702, 4.643856189774724, 5.78135971352466, 6.149747119504682, 5.614709844115208, 6.066089190457772, 5.78135971352466, 2.807354922057604, 3.321928094887362, 3.0, 5.643856189774724, 2.0, 5.20945336562895, 6.169925001442312, 5.523561956057013, 3.807354922057604, 6.672425341971495, 4.807354922057604, 6.044394119358453, 5.807354922057604, 5.700439718141092, 5.129283016944966, 4.643856189774724, 4.087462841250339, 5.523561956057013, 4.321928094887363, 5.643856189774724, 5.754887502163468, 4.906890595608519, 7.0, 6.475733430966398, 5.523561956057013, 7.467605550082998, 5.426264754702098, 6.066089190457772, 6.643856189774724, 6.857980995127572, 6.700439718141092, 6.044394119358453, 4.954196310386875, 7.149747119504682, 5.357552004618084, 5.930737337562887, 5.78135971352466, 6.3750394313469245, 1.0, 0.0, null, 1.0, 0.0, null, null, null, null, null, null, null, null, 1.0, null, 1.0, 6.108524456778169, 4.906890595608519, 4.459431618637297, 6.754887502163468, 4.584962500721156, 4.523561956057013, 5.392317422778761, 5.087462841250339, 7.400879436282184, 6.965784284662087, 6.339850002884624, 7.794415866350106, 6.20945336562895, 6.426264754702098, 6.94251450533924, 6.658211482751795, 6.3750394313469245, 5.643856189774724, 5.357552004618084, 5.807354922057604, 5.044394119358453, 5.584962500721156, 6.108524456778169, 5.459431618637297, null, null, null, 1.0, null, null, null, 1.0, 6.442943495848728, 5.930737337562887, 5.584962500721156, 7.303780748177103, 4.954196310386875, 6.0, 5.977279923499917, 6.20945336562895, 5.977279923499917, 5.491853096329675, 5.0, 6.129283016944966, 4.754887502163468, 4.247927513443585, 5.285402218862249, 5.523561956057013, 6.392317422778761, 5.977279923499917, 5.087462841250339, 7.076815597050831, 5.321928094887363, 5.20945336562895, 6.22881869049588, 5.882643049361842, 6.442943495848728, 5.700439718141092, 4.459431618637297, 6.94251450533924, 4.906890595608519, 6.459431618637297, 5.977279923499917, 6.169925001442312, 6.459431618637297, 6.22881869049588, 5.20945336562895, 6.714245517666122, 5.129283016944966, 5.754887502163468, 5.807354922057604, 6.426264754702098, 6.6293566200796095, 6.523561956057013, 5.357552004618084, 6.768184324776926, 5.285402218862249, 6.169925001442312, 5.727920454563199, 5.700439718141092, 2.321928094887362, 0.0, null, null, null, null, 1.0, null, 7.977279923499917, 7.294620748891627, 6.643856189774724, 7.417852514885898, 6.392317422778761, 6.442943495848728, 6.727920454563199, 7.721099188707185, 7.285402218862249, 6.507794640198696, 6.0, 7.076815597050831, 5.882643049361842, 6.044394119358453, 6.442943495848728, 6.20945336562895, null, null, null, null, null, null, null, null, 6.584962500721156, 5.954196310386875, 4.459431618637297, 6.303780748177103, 5.247927513443585, 4.906890595608519, 5.807354922057604, 5.807354922057604, null, null, 0.0, null, 0.0, null, 1.0, null, 7.6865005271832185, 7.312882955284356, 6.357552004618084, 8.361943773735241, 6.169925001442312, 6.870364719583405, 7.515699838284043, 7.700439718141092, 6.285402218862249, 6.087462841250339, 5.459431618637297, 6.321928094887363, 4.584962500721156, 5.700439718141092, 5.285402218862249, 6.0, 6.906890595608519, 6.614709844115208, 5.523561956057013, 7.22881869049588, 5.554588851677638, 6.189824558880018, 6.087462841250339, 6.523561956057013, 0.0, 0.0, 1.584962500721156, 3.0, 1.0, 2.321928094887362, 2.321928094887362, 2.584962500721156, 5.882643049361842, 5.044394119358453, 4.643856189774724, 6.672425341971495, 4.169925001442312, 5.285402218862249, 5.882643049361842, 5.643856189774724, 6.700439718141092, 5.882643049361842, 5.044394119358453, 7.257387842692652, 4.954196310386875, 5.247927513443585, 5.930737337562887, 6.108524456778169, 1.584962500721156, 3.321928094887362, null, 4.169925001442312, null, 1.0, null, null, 4.807354922057604, 4.700439718141092, 3.584962500721156, 5.584962500721156, 3.0, 5.247927513443585, 5.584962500721156, 4.087462841250339, 7.098032082960526, 6.614709844115208, 5.672425341971495, 7.247927513443585, 5.882643049361842, 6.6293566200796095, 6.643856189774724, 6.741466986401147, null, 0.0, null, null, null, null, null, null, 7.417852514885898, 6.820178962415188, 6.0, 7.483815777264256, 6.169925001442312, 6.357552004618084, 6.754887502163468, 6.857980995127572, null, null, null, null, null, null, null, null, 8.113742166049189, 7.442943495848728, 6.6865005271832185, 8.247927513443585, 6.599912842187128, 6.768184324776926, 7.357552004618084, 7.459431618637297, 8.055282435501189, 7.434628227636725, 6.303780748177103, 7.794415866350106, 6.870364719583405, 7.139551352398794, 6.832890014164741, 7.658211482751795, 7.108524456778169, 6.357552004618084, 5.832890014164741, 7.577428828035749, 5.807354922057604, 6.247927513443585, 6.523561956057013, 6.392317422778761, 6.700439718141092, 5.906890595608519, 4.954196310386875, 6.658211482751795, 4.169925001442312, 6.20945336562895, 6.189824558880018, 6.189824558880018, 8.276124405274238, 8.005624549193879, 7.1799090900149345, 8.573647187493322, 7.3750394313469245, 7.357552004618084, 7.636624620543649, 8.243173983472952, 2.807354922057604, 3.0, 1.0, 5.087462841250339, 0.0, 1.0, 4.392317422778761, 2.584962500721156, 2.0, 2.321928094887362, 2.584962500721156, 2.584962500721156, 0.0, 2.0, 1.0, 3.0, null, null, null, null, null, null, null, null, 6.523561956057013, 5.754887502163468, 5.672425341971495, 6.882643049361842, 4.954196310386875, 5.807354922057604, 5.491853096329675, 6.022367813028454, null, null, null, null, null, null, null, null, 6.845490050944375, 5.78135971352466, 5.357552004618084, 6.6293566200796095, 5.20945336562895, 5.044394119358453, 5.523561956057013, 6.169925001442312, 6.918863237274595, 6.0, 5.285402218862249, 6.303780748177103, 5.78135971352466, 6.507794640198696, 5.426264754702098, 6.459431618637297, 7.832890014164741, 6.94251450533924, 6.426264754702098, 6.599912842187128, 6.409390936137702, 6.672425341971495, 6.285402218862249, 6.523561956057013, 6.9886846867721655, 6.523561956057013, 5.754887502163468, 6.087462841250339, 5.392317422778761, 5.906890595608519, 5.459431618637297, 6.491853096329675, 6.727920454563199, 6.129283016944966, 5.727920454563199, 6.149747119504682, 5.672425341971495, 5.357552004618084, 5.584962500721156, 6.20945336562895, 7.0, 5.754887502163468, 4.700439718141092, 5.044394119358453, 5.614709844115208, 5.584962500721156, 4.459431618637297, 6.22881869049588, 6.754887502163468, 5.727920454563199, 5.321928094887363, 6.491853096329675, 5.832890014164741, 5.754887502163468, 5.129283016944966, 6.044394119358453, 7.554588851677638, 6.9886846867721655, 6.266786540694901, 6.845490050944375, 6.539158811108031, 6.475733430966398, 5.643856189774724, 6.906890595608519, null, 0.0, null, 1.0, null, 1.0, null, null, 7.03342300153745, 6.087462841250339, 5.321928094887363, 6.044394119358453, 5.643856189774724, 5.857980995127572, 5.523561956057013, 6.426264754702098, 6.554588851677638, 5.491853096329675, 5.285402218862249, 4.459431618637297, 5.20945336562895, 5.129283016944966, 5.321928094887363, 5.672425341971495, null, null, null, null, null, null, null, null, 6.3750394313469245, 5.392317422778761, 5.285402218862249, 4.906890595608519, 5.392317422778761, 5.672425341971495, 4.392317422778761, 5.930737337562887, 7.199672344836364, 6.857980995127572, 6.022367813028454, 6.22881869049588, 6.169925001442312, 6.0, 6.022367813028454, 6.426264754702098, 7.451211111832329, 6.870364719583405, 5.930737337562887, 6.807354922057604, 6.169925001442312, 6.554588851677638, 5.906890595608519, 6.832890014164741, 8.060695931687555, 7.6293566200796095, 6.894817763307944, 6.906890595608519, 6.9886846867721655, 7.199672344836364, 6.459431618637297, 7.330916878114617, 6.78135971352466, 6.303780748177103, 5.523561956057013, 5.727920454563199, 5.954196310386875, 6.066089190457772, 5.169925001442312, 6.554588851677638, 3.807354922057604, 3.584962500721156, 3.169925001442312, 2.584962500721156, 3.321928094887362, 4.459431618637297, 2.584962500721156, 3.584962500721156, 7.546894459887636, 7.483815777264256, 6.554588851677638, 7.066089190457772, 6.965784284662087, 6.794415866350106, 5.882643049361842, 7.426264754702098, 5.906890595608519, 5.321928094887363, 4.0, 5.392317422778761, 4.807354922057604, 4.906890595608519, 4.857980995127572, 4.807354922057604, null, 0.0, null, null, null, null, null, null, 6.409390936137702, 5.426264754702098, 4.857980995127572, 5.832890014164741, 4.857980995127572, 5.523561956057013, 5.247927513443585, 5.700439718141092, 6.977279923499917, 6.78135971352466, 6.20945336562895, 6.475733430966398, 6.266786540694901, 5.614709844115208, 5.700439718141092, 6.339850002884624, 5.954196310386875, 4.906890595608519, 3.584962500721156, 5.426264754702098, 4.523561956057013, 4.643856189774724, 5.20945336562895, 4.584962500721156, 6.599912842187128, 5.700439718141092, 5.882643049361842, 6.044394119358453, 5.357552004618084, 5.523561956057013, 5.321928094887363, 6.357552004618084, 7.515699838284043, 6.894817763307944, 6.285402218862249, 6.507794640198696, 6.149747119504682, 6.285402218862249, 5.672425341971495, 7.159871336778389, null, null, null, null, null, null, null, null, 8.820178962415188, 8.897845456005511, 7.294620748891627, 9.324180546618742, 7.139551352398794, 8.569855608330949, 8.558420713268664, 6.894817763307944, 6.9886846867721655, 7.011227255423254, 6.459431618637297, 6.672425341971495, 5.0, 7.05528243550119, 6.22881869049588, 4.700439718141092, 7.2384047393250786, 8.422064766172813, 5.727920454563199, 8.134426320220927, 6.409390936137702, 7.754887502163468, 6.672425341971495, 6.189824558880018, 6.820178962415188, 6.894817763307944, 5.20945336562895, 7.400879436282184, 4.857980995127572, 6.794415866350106, 5.169925001442312, 4.392317422778761, 6.507794640198696, 7.851749041416057, 5.169925001442312, 8.876516946565, 5.954196310386875, 7.845490050944375, 8.108524456778168, 6.20945336562895, 7.870364719583405, 7.434628227636725, 6.0, 7.044394119358453, 6.285402218862249, 6.94251450533924, null, 5.044394119358453, 3.9068905956085187, 4.523561956057013, null, null, 6.266786540694901, 4.954196310386875, null, 2.584962500721156, 6.727920454563199, 6.754887502163468, 5.129283016944966, 7.826548487290915, 4.247927513443585, 6.977279923499917, 6.149747119504682, 5.0, null, null, null, 1.584962500721156, null, 0.0, 0.0, 1.0, 5.672425341971495, 6.768184324776926, 2.807354922057604, 6.491853096329675, 4.523561956057013, 6.426264754702098, 6.303780748177103, 4.700439718141092, 6.066089190457772, 7.451211111832329, 4.906890595608519, 6.087462841250339, 6.022367813028454, 7.022367813028454, 6.584962500721156, 5.78135971352466, 7.754887502163468, 7.554588851677638, 6.392317422778761, 8.426264754702098, 5.491853096329675, 7.442943495848728, 0.0, 5.426264754702098, 7.584962500721156, 8.370687406807217, 5.807354922057604, 7.994353436858858, 6.741466986401147, 8.224001674198105, 7.807354922057604, 6.022367813028454, 8.285402218862249, 9.129283016944967, 7.066089190457772, 8.778077129535358, 7.6293566200796095, 8.584962500721156, 7.839203788096944, 7.20945336562895, 7.971543553950772, 8.098032082960527, 6.672425341971495, 8.366322214245816, 6.491853096329675, 7.870364719583405, 7.60733031374961, 6.20945336562895, 6.357552004618084, 6.714245517666122, 5.954196310386875, 6.6865005271832185, 4.906890595608519, 5.754887502163468, 5.754887502163468, 4.857980995127572, 6.392317422778761, 7.1799090900149345, 4.459431618637297, 8.022367813028454, 5.285402218862249, 6.894817763307944, 5.643856189774724, 5.0, 9.18239435340453, 9.038918989292302, 7.60733031374961, 9.696967526234287, 7.622051819456376, 9.100662339005199, 8.011227255423254, 7.129283016944966, 7.483815777264256, 8.442943495848729, 6.129283016944966, 8.129283016944967, 6.906890595608519, 8.011227255423254, 7.539158811108031, 6.6293566200796095, 5.643856189774724, 6.794415866350106, 3.700439718141092, 6.6865005271832185, 3.584962500721156, 6.321928094887363, 7.066089190457772, 4.321928094887363, 0.0, null, null, 0.0, 0.0, null, null, null, 7.108524456778169, 7.994353436858858, 5.954196310386875, 7.727920454563199, 6.108524456778169, 7.285402218862249, 6.247927513443585, 6.044394119358453, 8.113742166049189, 8.204571144249204, 6.22881869049588, 8.584962500721156, 6.426264754702098, 8.129283016944967, 7.577428828035749, 5.614709844115208, 7.044394119358453, 7.266786540694901, 5.584962500721156, 7.936637939002571, 5.0, 7.03342300153745, 7.539158811108031, 5.523561956057013, 8.507794640198696, 8.50382573799575, 3.4594316186372973, 5.523561956057013, 3.9068905956085187, 7.864186144654281, 2.0, 6.6293566200796095, 7.044394119358453, 7.400879436282184, 5.129283016944966, 7.7615512324444795, 4.523561956057013, 7.768184324776926, 6.714245517666122, 5.087462841250339, 6.857980995127572, 6.930737337562887, 5.247927513443585, 7.467605550082998, 5.247927513443585, 7.044394119358453, 7.076815597050831, 5.954196310386875, 8.266786540694902, 9.4655664048094, 7.199672344836364, 9.019590728357882, 7.924812503605781, 8.81698362325538, 8.854868383260236, 7.6293566200796095, 7.285402218862249, 8.066089190457772, 5.491853096329675, 8.312882955284355, 6.285402218862249, 8.022367813028454, 8.45532722030456, 5.954196310386875, 7.622051819456376, 7.475733430966398, 5.977279923499917, 8.539158811108031, 5.832890014164741, 7.507794640198696, 6.6293566200796095, 5.426264754702098, 7.807354922057604, 7.876516946564999, 6.658211482751795, 7.876516946564999, 6.266786540694901, 7.876516946564999, 7.894817763307944, 6.303780748177103, 7.0, 6.870364719583405, 5.930737337562887, 7.787902559391432, 4.906890595608519, 7.199672344836364, 6.614709844115208, 4.906890595608519, 0.0, 0.0, null, 1.584962500721156, null, 2.0, null, 1.0, 7.2384047393250786, 7.247927513443585, 5.672425341971495, 7.459431618637297, 5.247927513443585, 7.0, 0.0, 4.169925001442312, 6.339850002884624, 7.658211482751795, 4.700439718141092, 8.154818109052105, 4.954196310386875, 7.658211482751795, 6.906890595608519, 5.584962500721156, 6.820178962415188, 6.523561956057013, 5.523561956057013, 7.483815777264256, 4.523561956057013, 6.882643049361842, 6.6293566200796095, 5.129283016944966, 9.432541900388259, 9.550746785383243, 8.388017285345136, 8.826548487290914, 8.285402218862249, 8.945443836377912, 8.044394119358454, 8.290018846932618, 7.330916878114617, 7.400879436282184, 4.754887502163468, 7.03342300153745, 5.832890014164741, 7.392317422778761, 5.459431618637297, 5.977279923499917, 7.442943495848728, 8.405141463136344, 5.20945336562895, 8.554588851677638, 6.569855608330948, 7.7073591320808825, 7.451211111832329, 6.599912842187128, 8.888743248898258, 8.527477006060396, 7.2384047393250786, 7.721099188707185, 7.219168520462161, 8.280770770130603, 7.459431618637297, 7.044394119358453, 8.558420713268664, 8.50382573799575, 7.189824558880018, 8.124121311829187, 7.044394119358453, 8.43879185257826, 7.491853096329675, 7.129283016944966, 7.977279923499917, 7.7073591320808825, 6.169925001442312, 8.044394119358454, 6.129283016944966, 7.807354922057604, 6.491853096329675, 5.754887502163468, 2.0, 8.67595703294175, 1.584962500721156, 7.614709844115208, 7.285402218862249, 8.108524456778168, 7.312882955284356, 6.930737337562887, 6.491853096329675, 6.807354922057604, 5.087462841250339, 7.247927513443585, 4.459431618637297, 6.768184324776926, 1.584962500721156, 4.321928094887363, null, null, 0.0, 0.0, null, null, 0.0, 2.0, 7.118941072723508, 8.252665432450248, 5.807354922057604, 8.149747119504681, 6.3750394313469245, 7.794415866350106, 7.467605550082998, 5.727920454563199, 7.247927513443585, 7.569855608330948, 6.066089190457772, 7.894817763307944, 5.754887502163468, 7.266786540694901, 7.577428828035749, 5.426264754702098, 7.400879436282184, 8.257387842692651, 5.882643049361842, 8.554588851677638, 6.066089190457772, 8.154818109052105, 0.0, 4.857980995127572, 7.94251450533924, 7.727920454563199, 6.714245517666122, 8.233619676759702, 5.727920454563199, 8.098032082960527, 3.169925001442312, 5.0, 4.584962500721156, 5.584962500721156, 3.169925001442312, 6.129283016944966, 3.584962500721156, 6.044394119358453, 5.459431618637297, 4.0, 8.851749041416058, 8.63662462054365, 7.417852514885898, 8.29920801838728, 7.219168520462161, 8.344295907915816, 6.266786540694901, 7.348728154231077, 7.546894459887636, 8.08214904135387, 6.247927513443585, 8.451211111832329, 6.169925001442312, 7.768184324776926, 6.357552004618084, 5.614709844115208, 6.741466986401147, 6.727920454563199, 5.087462841250339, 7.651051691178929, 4.906890595608519, 7.098032082960526, 6.22881869049588, 5.247927513443585, 8.219168520462162, 8.071462362556623, 6.6293566200796095, 8.339850002884624, 6.599912842187128, 8.139551352398794, null, 5.392317422778761, 6.643856189774724, 8.022367813028454, 4.906890595608519, 8.81698362325538, 6.087462841250339, 7.523561956057013, 8.0, 6.22881869049588, 6.523561956057013, 6.599912842187128, 5.20945336562895, 7.383704292474052, 3.321928094887362, 7.129283016944966, 4.169925001442312, 4.0, 0.0, null, null, null, null, 1.0, 1.584962500721156, null, 8.335390354693924, 8.430452551665532, 6.807354922057604, 8.839203788096944, 6.409390936137702, 8.527477006060396, 3.0, 5.754887502163468, 6.189824558880018, 7.3750394313469245, 4.754887502163468, 7.965784284662087, 5.754887502163468, 7.507794640198696, 7.7615512324444795, 4.954196310386875, 6.491853096329675, 7.768184324776926, 4.857980995127572, 7.948367231584678, 5.807354922057604, 7.584962500721156, 7.936637939002571, 5.169925001442312, 8.0, 8.915879378835774, 6.714245517666122, 8.930737337562887, 7.339850002884624, 8.67595703294175, 8.144658242831882, 6.614709844115208, 8.442943495848729, 8.308339030139408, 6.6293566200796095, 8.519636252843213, 6.569855608330948, 7.7073591320808825, 7.417852514885898, 6.22881869049588, 9.850186837645774, 9.479780264029099, 8.108524456778168, 8.933690654952233, 8.144658242831882, 8.813781191217037, 7.876516946564999, 7.6653359171851765, 7.700439718141092, 7.491853096329675, 5.643856189774724, 7.599912842187128, 5.129283016944966, 7.169925001442312, 6.169925001442312, 5.087462841250339, 1.584962500721156, 2.321928094887362, 0.0, 4.0, 0.0, 1.0, 2.0, 2.0, 9.228818690495881, 9.057991722759176, 7.592457037268081, 8.507794640198696, 7.679480099505446, 8.651051691178928, 2.0, 6.20945336562895, 6.643856189774724, 6.754887502163468, 5.087462841250339, 7.409390936137702, 4.523561956057013, 6.857980995127572, 6.507794640198696, 4.459431618637297, 7.700439718141092, 7.6293566200796095, 6.3750394313469245, 8.247927513443585, 5.700439718141092, 6.768184324776926, 8.044394119358454, 5.672425341971495, null, 0.0, null, 0.0, 0.0, 1.0, 0.0, null, 6.189824558880018, 6.266786540694901, 4.807354922057604, 6.584962500721156, 4.754887502163468, 6.129283016944966, 3.700439718141092, 3.807354922057604, 8.113742166049189, 7.977279923499917, 6.066089190457772, 7.129283016944966, 6.266786540694901, 7.562242424221073, 6.066089190457772, 5.857980995127572, 7.523561956057013, 7.467605550082998, 6.022367813028454, 6.845490050944375, 6.247927513443585, 6.820178962415188, 6.266786540694901, 5.857980995127572, 9.832890014164741, 9.571752643503546, 8.546894459887637, 8.430452551665532, 8.405141463136344, 8.912889336229961, 7.022367813028454, 7.2761244052742375, 9.285402218862249, 9.12670447284319, 8.005624549193879, 8.50382573799575, 7.882643049361842, 8.562242424221072, 7.851749041416057, 7.129283016944966, 9.810571634741146, 9.459431618637296, 8.049848549450562, 8.149747119504681, 8.467605550082997, 9.098032082960527, 7.6653359171851765, 7.451211111832329, 8.672425341971495, 8.507794640198696, 7.199672344836364, 7.924812503605781, 6.965784284662087, 8.049848549450562, 7.400879436282184, 6.491853096329675, 7.9886846867721655, 8.651051691178928, 5.857980995127572, 8.060695931687555, 7.426264754702098, 8.199672344836364, 7.219168520462161, 7.087462841250339, 7.614709844115208, 8.049848549450562, 6.108524456778169, 8.08214904135387, 7.05528243550119, 7.562242424221073, 6.918863237274595, 5.426264754702098, 8.257387842692651, 8.087462841250339, 6.9886846867721655, 7.754887502163468, 6.882643049361842, 7.577428828035749, 6.523561956057013, 5.906890595608519, 7.426264754702098, 7.383704292474052, 6.0, 6.6865005271832185, 5.727920454563199, 6.584962500721156, 6.768184324776926, 4.954196310386875, null, null, null, null, null, 1.0, null, null, 6.523561956057013, 7.400879436282184, 4.906890595608519, 5.930737337562887, 6.108524456778169, 7.417852514885898, 1.0, 4.523561956057013, 8.066089190457772, 8.087462841250339, 6.894817763307944, 7.679480099505446, 6.20945336562895, 7.7615512324444795, 6.9886846867721655, 5.727920454563199, 6.930737337562887, 6.741466986401147, 5.700439718141092, 5.247927513443585, 4.857980995127572, 6.247927513443585, 5.20945336562895, 4.523561956057013, 10.049848549450562, 9.792790294301064, 8.640244936222345, 8.957102041562287, 8.731319031025064, 9.50382573799575, 7.219168520462161, 7.954196310386875, 7.754887502163468, 7.330916878114617, 5.882643049361842, 6.539158811108031, 5.78135971352466, 6.94251450533924, 5.584962500721156, 4.643856189774724, 9.079484783826816, 8.991521846075695, 7.820178962415188, 8.73809225962049, 7.392317422778761, 8.703903573444663, 6.9886846867721655, 6.930737337562887, 8.820178962415188, 8.447083226209653, 7.098032082960526, 7.434628227636725, 7.189824558880018, 8.108524456778168, 1.584962500721156, 5.392317422778761, 7.577428828035749, 8.539158811108031, 6.108524456778169, 7.768184324776926, 7.3750394313469245, 8.129283016944967, 7.118941072723508, 6.807354922057604, 2.807354922057604, 1.584962500721156, 0.0, 1.584962500721156, 0.0, null, 1.0, 2.584962500721156, 8.308339030139408, 7.807354922057604, 6.491853096329675, 7.011227255423254, 6.266786540694901, 7.257387842692652, 7.139551352398794, 5.807354922057604, 5.832890014164741, 6.832890014164741, 4.954196310386875, 6.087462841250339, 5.584962500721156, 5.906890595608519, 5.247927513443585, 5.426264754702098, null, 1.0, null, null, null, null, null, 0.0, 6.643856189774724, 7.348728154231077, 5.20945336562895, 7.022367813028454, 6.022367813028454, 7.383704292474052, 5.554588851677638, 4.321928094887363, 6.857980995127572, 8.124121311829187, 5.882643049361842, 7.6653359171851765, 6.6865005271832185, 7.6653359171851765, null, 4.700439718141092, 5.247927513443585, 5.857980995127572, 4.247927513443585, 4.584962500721156, 4.321928094887363, 4.906890595608519, null, 3.807354922057604, 0.0, 8.108524456778168, 0.0, 8.422064766172813, 6.22881869049588, 8.271463027904375, 6.714245517666122, 6.285402218862249, 8.312882955284355, 7.930737337562887, 7.03342300153745, 7.94251450533924, 6.149747119504682, 7.794415866350106, 6.044394119358453, 5.672425341971495, 7.700439718141092, 7.467605550082998, 6.044394119358453, 7.285402218862249, 5.614709844115208, 7.6653359171851765, 6.820178962415188, 5.426264754702098, 7.149747119504682, 7.011227255423254, 5.643856189774724, 7.159871336778389, 5.426264754702098, 6.882643049361842, 7.22881869049588, 4.700439718141092, 8.344295907915816, 7.7481928495894605, 6.459431618637297, 8.60733031374961, 5.614709844115208, 8.027905996569885, 7.098032082960526, 6.087462841250339, 7.118941072723508, 8.0, 5.614709844115208, 7.303780748177103, 7.149747119504682, 7.417852514885898, 6.965784284662087, 6.022367813028454, 6.108524456778169, 6.894817763307944, 0.0, 1.584962500721156, 8.011227255423254, 6.658211482751795, 2.321928094887362, 5.754887502163468, 8.873444112515376, 8.535275376620802, 7.098032082960526, 8.92481250360578, 6.845490050944375, 8.271463027904375, 8.751544059089099, 6.392317422778761, 8.933690654952233, 8.784634845557521, 7.832890014164741, 8.0, 7.912889336229962, 8.219168520462162, 7.7615512324444795, 6.672425341971495, 6.870364719583405, 7.7481928495894605, 5.321928094887363, 8.08214904135387, 5.584962500721156, 7.499845887083206, 7.451211111832329, 5.554588851677638, 9.259743263690781, 8.968666793195208, 7.954196310386875, 7.820178962415188, 7.851749041416057, 8.507794640198696, 6.409390936137702, 6.584962500721156, 8.665335917185176, 8.124121311829187, 6.894817763307944, 8.611024797307353, 6.643856189774724, 7.9886846867721655, 0.0, 5.832890014164741, 6.9886846867721655, 7.807354922057604, 5.459431618637297, 8.189824558880018, 5.882643049361842, 7.584962500721156, 7.924812503605781, 6.339850002884624, 7.658211482751795, 8.50382573799575, 5.882643049361842, 8.124121311829187, 6.954196310386875, 7.857980995127572, 6.845490050944375, 6.491853096329675, 6.3750394313469245, 7.294620748891627, 4.954196310386875, 7.294620748891627, 5.672425341971495, 7.266786540694901, 6.087462841250339, 4.906890595608519, 7.614709844115208, 8.417852514885897, 6.672425341971495, 7.936637939002571, 6.523561956057013, 8.204571144249204, 7.599912842187128, 5.906890595608519, 8.906890595608518, 8.471675214392045, 7.303780748177103, 8.88264304936184, 7.022367813028454, 8.539158811108031, 6.409390936137702, 6.930737337562887, 9.162391328756906, 8.539158811108031, 7.366322214245816, 8.758223214726724, 7.199672344836364, 8.113742166049189, 6.727920454563199, 6.321928094887363, 7.515699838284043, 8.475733430966399, 6.22881869049588, 7.592457037268081, 7.05528243550119, 7.888743248898259, 6.22881869049588, 6.442943495848728, 7.392317422778761, 8.092757140919852, 5.554588851677638, 7.643856189774724, 6.658211482751795, 8.03342300153745, null, 6.149747119504682, 9.276124405274238, 9.057991722759176, 7.6293566200796095, 9.011227255423254, 7.658211482751795, 8.257387842692651, 7.257387842692652, 7.098032082960526, 9.014020470314934, 8.682994583681683, 7.2761244052742375, 8.562242424221072, 6.832890014164741, 8.409390936137703, 8.076815597050832, 6.794415866350106, 8.7714894695006, 8.071462362556623, 6.9886846867721655, 8.022367813028454, 6.584962500721156, 8.060695931687555, 6.321928094887363, 6.266786540694901, 9.164906926675688, 8.851749041416058, 7.2384047393250786, 9.285402218862249, 7.0, 9.022367813028454, 8.357552004618084, 7.189824558880018, 6.426264754702098, 7.768184324776926, 3.0, 2.0, 2.584962500721156, 7.2384047393250786, null, 4.906890595608519, 8.51175265376738, 8.098032082960527, 6.977279923499917, 8.79766152585376, 5.930737337562887, 8.447083226209653, 2.807354922057604, 5.807354922057604, 7.491853096329675, 7.312882955284356, 5.78135971352466, 7.714245517666122, 5.392317422778761, 7.20945336562895, 6.087462841250339, 4.807354922057604, 6.727920454563199, 7.577428828035749, 4.754887502163468, 8.134426320220927, 6.22881869049588, 7.554588851677638, 6.599912842187128, 6.044394119358453, 9.111135670234708, 8.707359132080883, 7.7073591320808825, 8.96289600533726, 7.2384047393250786, 8.50382573799575, 7.507794640198696, 6.754887502163468, 9.632995197142957, 9.022367813028454, 8.262094845370179, 9.187352073200497, 7.94251450533924, 9.068778277985412, 7.330916878114617, 7.339850002884624, 7.714245517666122, 8.276124405274238, 5.754887502163468, 8.379378367071261, 7.189824558880018, 7.954196310386875, 7.475733430966398, 6.882643049361842, 8.326429487122303, 8.654636028527968, 6.3750394313469245, 9.044394119358454, 7.3750394313469245, 8.535275376620802, 7.451211111832329, 6.754887502163468, 8.344295907915816, 8.918863237274595, 6.3750394313469245, 9.321928094887362, 6.965784284662087, 8.531381460516313, 4.247927513443585, 6.129283016944966, 8.826548487290914, 9.3151495622563, 7.285402218862249, 8.721099188707186, 8.290018846932618, 8.936637939002571, 8.507794640198696, 7.768184324776926, 7.864186144654281, 8.679480099505446, 6.491853096329675, 8.49585502688717, 6.918863237274595, 8.204571144249204, 7.169925001442312, 6.807354922057604, 7.139551352398794, 8.005624549193879, 5.614709844115208, 8.294620748891626, 6.78135971352466, 8.29920801838728, 7.78135971352466, 6.321928094887363, 6.794415866350106, 6.727920454563199, 4.954196310386875, 7.219168520462161, 4.392317422778761, 6.965784284662087, 5.906890595608519, 4.087462841250339, 7.159871336778389, 6.3750394313469245, 5.169925001442312, 7.087462841250339, 4.857980995127572, 7.098032082960526, 5.857980995127572, 4.392317422778761, 6.857980995127572, 6.672425341971495, 5.491853096329675, 7.459431618637297, 4.906890595608519, 7.2761244052742375, 6.339850002884624, 4.247927513443585, 7.357552004618084, 7.2761244052742375, 5.906890595608519, 6.643856189774724, 5.584962500721156, 6.523561956057013, 6.507794640198696, 4.807354922057604, 8.139551352398794, 8.290018846932618, 6.965784284662087, 8.491853096329674, 6.870364719583405, 7.78135971352466, 7.426264754702098, 6.584962500721156, 8.422064766172813, 8.214319120800766, 6.599912842187128, 8.303780748177102, 6.882643049361842, 8.308339030139408, 7.044394119358453, 5.523561956057013, 8.665335917185176, 8.51175265376738, 7.087462841250339, 8.912889336229961, 6.700439718141092, 8.049848549450562, 7.539158811108031, 6.554588851677638, 8.219168520462162, 8.885696373339394, 6.6293566200796095, 8.672425341971495, 7.434628227636725, 8.479780264029099, 4.584962500721156, 6.965784284662087, 6.714245517666122, 7.658211482751795, 4.700439718141092, 7.6293566200796095, 6.066089190457772, 7.6865005271832185, 6.392317422778761, 5.087462841250339, 7.936637939002571, 7.577428828035749, 6.022367813028454, 8.169925001442312, 5.882643049361842, 7.507794640198696, 6.0, 5.426264754702098, 8.214319120800766, 8.055282435501189, 6.794415866350106, 8.479780264029099, 6.6293566200796095, 7.870364719583405, 6.303780748177103, 6.044394119358453, 7.475733430966398, 8.562242424221072, 6.189824558880018, 8.857980995127573, 6.22881869049588, 8.848622940429339, 7.294620748891627, 7.499845887083206, 6.491853096329675, 7.636624620543649, 4.954196310386875, 7.459431618637297, 5.247927513443585, 7.794415866350106, 1.0, 4.807354922057604, 7.189824558880018, 6.977279923499917, 5.523561956057013, 7.78135971352466, 5.614709844115208, 7.312882955284356, 5.459431618637297, 5.20945336562895, 8.144658242831882, 8.087462841250339, 6.599912842187128, 8.632995197142957, 5.977279923499917, 8.366322214245816, null, 6.087462841250339, 5.882643049361842, 7.139551352398794, 5.0, 7.714245517666122, 5.523561956057013, 7.539158811108031, 6.087462841250339, 4.906890595608519, 7.562242424221073, 7.149747119504682, 6.3750394313469245, 8.139551352398794, 5.459431618637297, 7.339850002884624, 7.491853096329675, 5.523561956057013, 7.011227255423254, 7.918863237274595, 5.643856189774724, 7.857980995127572, 5.977279923499917, 7.741466986401147, 7.330916878114617, 5.554588851677638, 8.813781191217037, 8.714245517666123, 7.118941072723508, 9.294620748891626, 6.599912842187128, 9.011227255423254, 7.918863237274595, 6.554588851677638, 7.400879436282184, 8.554588851677638, 6.321928094887363, 8.83605035505807, 6.022367813028454, 8.434628227636725, 7.169925001442312, 6.247927513443585, 8.49585502688717, 9.194756854422248, 6.614709844115208, 8.900866807980748, 7.546894459887636, 8.89178370321831, 8.906890595608518, 7.330916878114617, 7.60733031374961, 8.353146825498083, 5.78135971352466, 8.238404739325079, 6.700439718141092, 8.049848549450562, 6.845490050944375, 6.426264754702098, 8.294620748891626, 8.199672344836364, 6.977279923499917, 8.939579214314692, 6.491853096329675, 8.422064766172813, 7.339850002884624, 6.599912842187128, 7.442943495848728, 8.103287808412022, 5.614709844115208, 8.422064766172813, 6.108524456778169, 8.118941072723507, 8.46352437327118, 6.266786540694901, 7.813781191217037, 8.20945336562895, 6.930737337562887, 8.413627929024173, 6.149747119504682, 7.491853096329675, 7.78135971352466, 6.426264754702098, 6.442943495848728, 6.20945336562895, 4.643856189774724, 6.22881869049588, 4.169925001442312, 6.357552004618084, 5.807354922057604, 3.584962500721156, 7.357552004618084, 7.05528243550119, 5.643856189774724, 7.714245517666122, 4.584962500721156, 7.312882955284356, 6.303780748177103, 3.0, 7.459431618637297, 8.312882955284355, 6.066089190457772, 7.507794640198696, 6.977279923499917, 8.262094845370179, 7.936637939002571, 6.954196310386875, 4.807354922057604, 4.857980995127572, 2.807354922057604, 5.614709844115208, 1.0, 4.954196310386875, 3.0, 2.584962500721156, 8.754887502163468, 8.326429487122303, 6.794415866350106, 8.927777962082342, 6.303780748177103, 8.459431618637296, 7.266786540694901, 6.087462841250339, 7.066089190457772, 6.882643049361842, 5.169925001442312, 7.768184324776926, 4.643856189774724, 7.475733430966398, 4.584962500721156, 5.285402218862249, 8.055282435501189, 7.832890014164741, 6.426264754702098, 8.118941072723507, 6.149747119504682, 7.614709844115208, 6.339850002884624, 6.087462841250339, 7.20945336562895, 7.864186144654281, 5.584962500721156, 7.0, 7.108524456778169, 7.417852514885898, 4.906890595608519, 6.129283016944966, 6.78135971352466, 7.7073591320808825, 5.459431618637297, 6.768184324776926, 6.266786540694901, 7.383704292474052, 6.584962500721156, 5.643856189774724, 7.400879436282184, 8.134426320220927, 6.066089190457772, 7.451211111832329, 6.614709844115208, 7.9886846867721655, 1.584962500721156, 5.459431618637297, 7.285402218862249, 8.266786540694902, 6.022367813028454, 7.475733430966398, 7.098032082960526, 7.754887502163468, 6.906890595608519, 5.906890595608519, 7.108524456778169, 7.900866807980749, 5.977279923499917, 6.768184324776926, 6.569855608330948, 7.247927513443585, 6.3750394313469245, 6.129283016944966, 6.832890014164741, 7.894817763307944, 5.169925001442312, 6.820178962415188, 6.189824558880018, 7.199672344836364, 6.727920454563199, 5.554588851677638, 5.20945336562895, 5.882643049361842, 2.807354922057604, 3.584962500721156, 5.523561956057013, 5.285402218862249, 3.807354922057604, 3.584962500721156, 6.554588851677638, 7.330916878114617, 4.321928094887363, 6.247927513443585, 5.727920454563199, 7.022367813028454, 6.392317422778761, 5.882643049361842, 7.948367231584678, 7.539158811108031, 6.129283016944966, 6.614709844115208, 6.6865005271832185, 7.03342300153745, 5.554588851677638, 5.954196310386875, 8.022367813028454, 7.787902559391432, 6.727920454563199, 6.614709844115208, 6.507794640198696, 7.348728154231077, 5.491853096329675, 6.129283016944966, 9.189824558880018, 8.800899899920305, 7.599912842187128, 8.027905996569885, 7.672425341971495, 8.625708843064466, 6.442943495848728, 6.754887502163468, 7.727920454563199, 7.599912842187128, 6.149747119504682, 6.965784284662087, 6.392317422778761, 7.2761244052742375, 4.321928094887363, 5.169925001442312, 8.129283016944967, 7.257387842692652, 6.189824558880018, 7.129283016944966, 6.409390936137702, 7.584962500721156, 7.199672344836364, 5.321928094887363, 8.804131021183318, 8.562242424221072, 7.066089190457772, 8.08214904135387, 7.285402218862249, 8.276124405274238, 6.285402218862249, 6.0, 7.339850002884624, 8.154818109052105, 5.584962500721156, 7.159871336778389, 7.044394119358453, 7.948367231584678, 7.392317422778761, 6.539158811108031, 7.912889336229962, 8.434628227636725, 6.339850002884624, 7.622051819456376, 7.098032082960526, 7.813781191217037, null, 5.977279923499917, 7.149747119504682, 7.651051691178929, 5.20945336562895, 6.714245517666122, 6.754887502163468, 7.219168520462161, 2.321928094887362, 5.491853096329675, 7.948367231584678, 7.189824558880018, 5.523561956057013, 6.94251450533924, 5.882643049361842, 6.906890595608519, 0.0, 4.807354922057604, 7.6293566200796095, 7.22881869049588, 5.857980995127572, 6.475733430966398, 6.285402218862249, 6.700439718141092, 5.930737337562887, 5.285402218862249, 7.366322214245816, 6.584962500721156, 5.727920454563199, 6.169925001442312, 5.523561956057013, 6.426264754702098, 4.392317422778761, 4.700439718141092, 6.727920454563199, 7.409390936137702, 5.491853096329675, 6.189824558880018, 5.977279923499917, 7.392317422778761, 5.087462841250339, 4.807354922057604, 3.807354922057604, 3.584962500721156, null, 2.584962500721156, 1.584962500721156, 3.4594316186372973, 3.0, null, 8.204571144249204, 8.011227255423254, 6.442943495848728, 6.768184324776926, 6.894817763307944, 7.754887502163468, 6.820178962415188, 6.303780748177103, 5.906890595608519, 6.614709844115208, 3.321928094887362, 5.700439718141092, 5.459431618637297, 6.339850002884624, 5.857980995127572, 4.169925001442312, 8.467605550082997, 7.918863237274595, 6.507794640198696, 8.118941072723507, 7.0, 7.60733031374961, 6.491853096329675, 6.149747119504682, 8.055282435501189, 7.794415866350106, 6.303780748177103, 6.977279923499917, 6.754887502163468, 7.499845887083206, 6.658211482751795, 5.977279923499917, 8.055282435501189, 8.011227255423254, 6.044394119358453, 7.734709620225838, 7.392317422778761, 8.076815597050832, 1.0, 5.906890595608519, 0.0, null, null, null, null, null, null, null, 6.442943495848728, 7.149747119504682, 4.247927513443585, 8.076815597050832, 5.20945336562895, 7.546894459887636, 1.0, 4.700439718141092, 6.189824558880018, 7.0, 4.857980995127572, 6.870364719583405, 4.643856189774724, 6.754887502163468, 5.087462841250339, 4.523561956057013, 6.066089190457772, 6.727920454563199, 4.392317422778761, 7.392317422778761, 5.169925001442312, 7.392317422778761, 6.22881869049588, 4.584962500721156, 8.098032082960527, 7.807354922057604, 6.459431618637297, 8.199672344836364, 6.22881869049588, 7.930737337562887, 6.894817763307944, 5.321928094887363, 6.584962500721156, 6.339850002884624, 4.754887502163468, 7.554588851677638, 4.087462841250339, 6.977279923499917, 7.285402218862249, 3.584962500721156, 8.219168520462162, 7.7481928495894605, 6.3750394313469245, 6.94251450533924, 6.584962500721156, 7.2761244052742375, 5.700439718141092, 5.906890595608519, 4.954196310386875, 4.459431618637297, null, 0.0, 5.700439718141092, 5.247927513443585, null, 2.584962500721156, 6.727920454563199, 7.60733031374961, 4.700439718141092, 8.169925001442312, 5.044394119358453, 8.118941072723507, 7.960001932068081, 5.321928094887363, 7.491853096329675, 8.184875342908283, 6.266786540694901, 7.734709620225838, 7.499845887083206, 7.888743248898259, 7.011227255423254, 6.321928094887363, 8.005624549193879, 7.614709844115208, 6.3750394313469245, 8.189824558880018, 5.700439718141092, 7.754887502163468, 5.954196310386875, 5.857980995127572, 7.569855608330948, 7.515699838284043, 6.285402218862249, 6.870364719583405, 6.169925001442312, 7.321928094887363, 6.614709844115208, 5.643856189774724, 7.918863237274595, 7.285402218862249, 6.0, 7.554588851677638, 6.0, 7.348728154231077, 7.357552004618084, 6.044394119358453, 6.754887502163468, 7.2761244052742375, 6.044394119358453, 7.546894459887636, 5.554588851677638, 7.321928094887363, 6.169925001442312, 5.087462841250339, 7.569855608330948, 7.199672344836364, 5.491853096329675, 7.599912842187128, 6.044394119358453, 7.409390936137702, 7.599912842187128, 6.169925001442312, 7.839203788096944, 7.714245517666122, 6.409390936137702, 8.321928094887362, 5.584962500721156, 7.954196310386875, 7.294620748891627, 4.857980995127572, 6.894817763307944, 7.383704292474052, 5.0, 8.060695931687555, 5.954196310386875, 7.6293566200796095, 6.0, 5.78135971352466, 5.754887502163468, 6.754887502163468, 4.0, 6.78135971352466, 4.523561956057013, 7.03342300153745, 6.857980995127572, 4.247927513443585, 8.179909090014934, 7.787902559391432, 6.459431618637297, 8.727920454563199, 5.930737337562887, 7.888743248898259, 6.930737337562887, 6.129283016944966, 7.483815777264256, 8.016808287686555, 3.169925001442312, 5.087462841250339, 3.584962500721156, 7.592457037268081, null, 6.066089190457772, 9.243173983472952, 8.88264304936184, 7.523561956057013, 8.430452551665532, 7.1799090900149345, 8.90388184573618, 7.366322214245816, 7.098032082960526, 7.971543553950772, 7.515699838284043, 6.507794640198696, 8.0, 6.129283016944966, 7.539158811108031, 5.672425341971495, 5.754887502163468, 6.870364719583405, 7.539158811108031, 5.129283016944966, 7.584962500721156, 6.392317422778761, 7.294620748891627, 5.754887502163468, 5.700439718141092, 7.0, 6.965784284662087, 4.906890595608519, 7.876516946564999, 5.0, 7.159871336778389, 6.9886846867721655, 5.392317422778761, 7.562242424221073, 7.266786540694901, 6.149747119504682, 7.870364719583405, 5.523561956057013, 7.3750394313469245, 6.965784284662087, 5.857980995127572, 7.266786540694901, 7.807354922057604, 5.554588851677638, 8.124121311829187, 6.339850002884624, 7.820178962415188, 4.584962500721156, 4.857980995127572, 6.108524456778169, 6.714245517666122, 4.0, 6.754887502163468, 4.807354922057604, 7.087462841250339, 5.614709844115208, 5.169925001442312, 7.129283016944966, 6.9886846867721655, 5.0, 7.622051819456376, 4.807354922057604, 7.03342300153745, 5.554588851677638, 4.459431618637297, 8.076815597050832, 7.734709620225838, 6.475733430966398, 7.451211111832329, 5.930737337562887, 7.787902559391432, 7.03342300153745, 5.954196310386875, 7.584962500721156, 7.312882955284356, 6.149747119504682, 7.467605550082998, 5.672425341971495, 7.584962500721156, 6.78135971352466, 5.426264754702098, 7.499845887083206, 7.129283016944966, 5.700439718141092, 8.044394119358454, 5.285402218862249, 7.392317422778761, 6.285402218862249, 5.247927513443585, 8.330916878114618, 7.832890014164741, 6.807354922057604, 7.515699838284043, 6.643856189774724, 7.832890014164741, null, 5.672425341971495, 6.930737337562887, 6.6865005271832185, 5.169925001442312, 6.870364719583405, 4.954196310386875, 6.491853096329675, 5.491853096329675, 4.584962500721156, 7.912889336229962, 7.409390936137702, 6.409390936137702, 7.383704292474052, 6.20945336562895, 6.807354922057604, 6.977279923499917, 6.022367813028454, 7.303780748177103, 8.266786540694902, 5.554588851677638, 8.370687406807217, 6.768184324776926, 8.022367813028454, 7.303780748177103, 6.426264754702098, 7.965784284662087, 7.721099188707185, 5.977279923499917, 8.483815777264256, 5.672425341971495, 7.894817763307944, 6.700439718141092, 4.954196310386875, 5.882643049361842, 6.6865005271832185, 4.459431618637297, 7.129283016944966, 5.523561956057013, 7.383704292474052, 5.754887502163468, 4.906890595608519, 6.954196310386875, 7.6293566200796095, 5.129283016944966, 8.144658242831882, 5.643856189774724, 7.426264754702098, 6.321928094887363, 5.20945336562895, 7.442943495848728, 7.139551352398794, 5.807354922057604, 6.894817763307944, 5.584962500721156, 6.894817763307944, 7.257387842692652, 5.321928094887363, 6.108524456778169, 6.870364719583405, 4.523561956057013, 7.658211482751795, 4.584962500721156, 6.9886846867721655, 7.330916878114617, 4.807354922057604, 7.693486957499325, 7.294620748891627, 5.700439718141092, 8.228818690495881, 5.523561956057013, 7.954196310386875, 6.426264754702098, 5.321928094887363, 7.820178962415188, 7.523561956057013, 6.303780748177103, 8.276124405274238, 5.807354922057604, 7.417852514885898, 6.857980995127572, 5.672425341971495, 7.622051819456376, 7.366322214245816, 6.0, 7.894817763307944, 5.491853096329675, 7.3750394313469245, 7.044394119358453, 5.129283016944966, 7.523561956057013, 7.459431618637297, 5.614709844115208, 8.044394119358454, 5.357552004618084, 7.741466986401147, 0.0, 4.906890595608519, 7.348728154231077, 8.134426320220927, 5.459431618637297, 8.113742166049189, 5.930737337562887, 8.118941072723507, 6.266786540694901, 5.754887502163468, 6.491853096329675, 7.098032082960526, 4.643856189774724, 7.294620748891627, 5.087462841250339, 7.011227255423254, 6.6293566200796095, 4.857980995127572, 7.622051819456376, 7.285402218862249, 6.339850002884624, 7.768184324776926, 5.554588851677638, 7.442943495848728, 6.9886846867721655, 5.882643049361842, null, 6.303780748177103, null, 6.554588851677638, 5.169925001442312, 6.266786540694901, 5.129283016944966, 4.584962500721156, 7.499845887083206, 6.569855608330948, 5.700439718141092, 7.434628227636725, 5.129283016944966, 6.741466986401147, 4.169925001442312, 4.392317422778761, null, 7.894817763307944, null, 7.577428828035749, 6.20945336562895, 7.870364719583405, 6.599912842187128, 5.906890595608519, 2.584962500721156, 3.169925001442312, 1.584962500721156, 2.0, 0.0, 1.584962500721156, 2.0, 1.0, 6.832890014164741, 7.7481928495894605, 5.491853096329675, 8.076815597050832, 6.108524456778169, 7.294620748891627, 7.044394119358453, 5.672425341971495, 6.108524456778169, 6.303780748177103, 4.584962500721156, 6.977279923499917, 3.700439718141092, 5.727920454563199, 5.459431618637297, 4.0, 6.768184324776926, 6.672425341971495, 5.523561956057013, 7.3750394313469245, 5.321928094887363, 6.832890014164741, 5.584962500721156, 4.321928094887363, 7.426264754702098, 7.741466986401147, 5.357552004618084, 6.870364719583405, 6.554588851677638, 7.149747119504682, 5.930737337562887, 5.882643049361842, 7.417852514885898, 7.78135971352466, 5.459431618637297, 7.303780748177103, 6.894817763307944, 7.20945336562895, 5.129283016944966, 6.066089190457772, 7.845490050944375, 7.339850002884624, 6.285402218862249, 7.285402218862249, 6.339850002884624, 7.05528243550119, 5.392317422778761, 5.459431618637297, 7.434628227636725, 7.076815597050831, 5.169925001442312, 5.247927513443585, 6.22881869049588, 6.491853096329675, 4.169925001442312, 4.584962500721156, 6.977279923499917, 7.693486957499325, 5.20945336562895, 7.011227255423254, 6.714245517666122, 7.451211111832329, 2.0, 5.672425341971495, 6.614709844115208, 7.108524456778169, 4.700439718141092, 6.392317422778761, 6.149747119504682, 6.714245517666122, 6.0, 5.906890595608519, 7.303780748177103, 6.857980995127572, 6.087462841250339, 6.357552004618084, 5.857980995127572, 6.794415866350106, 4.584962500721156, 4.807354922057604, 5.129283016944966, 6.22881869049588, 3.584962500721156, 5.614709844115208, 5.087462841250339, 6.066089190457772, 4.523561956057013, 3.700439718141092, 5.78135971352466, 6.658211482751795, 4.321928094887363, 5.727920454563199, 5.643856189774724, 6.339850002884624, 4.169925001442312, 4.392317422778761, 7.483815777264256, 6.599912842187128, 5.523561956057013, 6.807354922057604, 5.700439718141092, 6.6865005271832185, 4.906890595608519, 4.954196310386875, 6.599912842187128, 6.523561956057013, 5.169925001442312, 5.906890595608519, 5.491853096329675, 5.754887502163468, 5.523561956057013, 5.129283016944966, 6.94251450533924, 7.539158811108031, 5.392317422778761, 6.584962500721156, 6.6865005271832185, 7.330916878114617, 6.0, 6.658211482751795, 6.977279923499917, 6.303780748177103, 5.247927513443585, 6.507794640198696, 5.584962500721156, 6.554588851677638, 4.459431618637297, 4.954196310386875, 7.800899899920305, 6.845490050944375, 5.754887502163468, 6.794415866350106, 5.357552004618084, 6.658211482751795, 4.247927513443585, 4.954196310386875, 6.882643049361842, 7.523561956057013, 5.20945336562895, 6.339850002884624, 6.491853096329675, 7.475733430966398, 4.906890595608519, 5.392317422778761, 2.584962500721156, 2.584962500721156, 2.321928094887362, 1.584962500721156, 1.0, 1.584962500721156, null, 2.0, 5.954196310386875, 6.832890014164741, 4.857980995127572, 6.066089190457772, 5.832890014164741, 6.727920454563199, 4.643856189774724, 5.0, 6.599912842187128, 7.076815597050831, 4.643856189774724, 6.169925001442312, 5.906890595608519, 7.139551352398794, 4.954196310386875, 4.906890595608519, 5.614709844115208, 6.6293566200796095, 3.9068905956085187, 5.0, 5.129283016944966, 5.754887502163468, 5.754887502163468, 4.700439718141092], "y0": " ", "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"], ["X", "Cyp9k1_tag1"], ["X", "Cyp9k1_tag2"], ["X", "Cyp9k1_tag3"], ["X", "AIM25"], ["X", "AIM26"], ["X", "AIM27"], ["X", "AIM28"], ["X", "AIM29"], ["X", "AIM30"], ["X", "AIM31"], ["X", "AIM32"], ["X", "AIM33"], ["X", "AIM34"], ["X", "AIM35"]], "hovertemplate": "contig=%{customdata[0]}<br>amplicon=%{x}<br>log_depth=%{y}<br>mutation=%{customdata[1]}<extra></extra>", "legendgroup": "X", "marker": {"color": "#9467BD"}, "name": "X", "notched": false, "offsetgroup": "X", "orientation": "v", "showlegend": true, "type": "box", "x": ["Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78"], "x0": " ", "xaxis": "x", "y": [null, 7.894817763307944, 2.584962500721156, 6.22881869049588, 5.700439718141092, 3.584962500721156, 5.169925001442312, 4.954196310386875, 6.965784284662087, 3.0, 7.108524456778169, 4.321928094887363, 4.459431618637297, 5.78135971352466, null, 4.700439718141092, 1.584962500721156, 2.0, 2.321928094887362, 1.0, 1.0, 2.807354922057604, 3.4594316186372973, 0.0, 3.321928094887362, 3.0, 0.0, 4.0, null, null, null, 0.0, null, null, null, null, null, null, 0.0, null, 1.0, null, null, 2.807354922057604, 0.0, 1.0, null, 1.0, 0.0, 1.0, 3.169925001442312, 1.0, 3.0, null, 2.321928094887362, null, null, 4.584962500721156, null, 2.321928094887362, 1.584962500721156, 2.0, 1.0, 1.584962500721156, 3.321928094887362, 0.0, 3.807354922057604, 1.0, 1.584962500721156, 0.0, null, 6.189824558880018, 3.321928094887362, 5.044394119358453, 3.169925001442312, 3.0, 3.584962500721156, 4.643856189774724, 4.321928094887363, 3.584962500721156, 1.584962500721156, 3.0, 1.584962500721156, 4.906890595608519, null, 4.321928094887363, null, 1.0, null, 3.0, null, 3.807354922057604, null, 1.0, null, null, 1.0, null, null, null, null, 1.0, null, null, null, null, null, null, 0.0, 0.0, 1.584962500721156, 0.0, null, null, null, null, 0.0, null, null, null, null, null, 0.0, null, 1.0, null, null, 5.0, 2.0, 3.0, 2.321928094887362, null, 1.584962500721156, 1.584962500721156, 4.321928094887363, 2.0, 2.584962500721156, 1.0, 1.0, 1.0, null, 2.807354922057604, 1.0, 1.584962500721156, 1.0, 2.0, 2.807354922057604, 1.0, null, 2.0, 2.0, 2.584962500721156, 2.807354922057604, 2.584962500721156, null, 0.0, null, 1.0, 0.0, 0.0, 1.0, 0.0, null, null, null, 1.0, 2.321928094887362, null, null, 5.882643049361842, 4.392317422778761, 3.584962500721156, 3.807354922057604, 3.169925001442312, 3.9068905956085187, 3.4594316186372973, 4.807354922057604, 1.584962500721156, 4.754887502163468, 3.584962500721156, 3.4594316186372973, 4.087462841250339, null, 5.954196310386875, 2.807354922057604, 4.807354922057604, 3.4594316186372973, 3.0, 3.584962500721156, 4.169925001442312, 4.700439718141092, 2.584962500721156, 4.700439718141092, 3.0, 2.0, 4.087462841250339, null, 3.321928094887362, null, 2.0, 2.321928094887362, 0.0, 2.0, 2.584962500721156, 2.321928094887362, 0.0, 3.169925001442312, 1.584962500721156, 2.807354922057604, 2.321928094887362, null, 4.0, 2.321928094887362, 3.0, 2.584962500721156, 0.0, 2.0, 2.807354922057604, 4.459431618637297, 2.321928094887362, 3.807354922057604, 1.0, 2.0, 3.4594316186372973, 0.0, 5.129283016944966, 1.584962500721156, 1.584962500721156, 2.0, 2.807354922057604, 1.0, 2.0, 3.0, 0.0, 3.584962500721156, 2.0, 2.584962500721156, 3.0, null, 3.169925001442312, 0.0, 3.321928094887362, 1.584962500721156, 2.321928094887362, 0.0, 2.584962500721156, 1.584962500721156, 1.0, 1.0, 2.584962500721156, 2.0, 1.584962500721156, null, 6.954196310386875, 3.807354922057604, 5.044394119358453, 4.247927513443585, 3.169925001442312, 4.0, 4.087462841250339, 5.321928094887363, 4.392317422778761, 5.321928094887363, 4.169925001442312, 2.321928094887362, 5.0, null, 2.321928094887362, null, 2.807354922057604, 1.584962500721156, null, 1.0, 1.584962500721156, 0.0, 1.0, 2.584962500721156, 1.0, 1.0, 0.0, null, 6.554588851677638, 3.9068905956085187, 5.20945336562895, 3.9068905956085187, 3.4594316186372973, 3.584962500721156, 4.247927513443585, 5.426264754702098, 2.0, 5.523561956057013, 3.807354922057604, 1.0, 5.0, null, 5.087462841250339, 1.0, 1.0, 1.0, 1.584962500721156, 2.0, 2.321928094887362, 2.584962500721156, 1.584962500721156, 2.0, null, 0.0, 1.0, null, 1.0, 1.0, null, null, null, 1.0, 0.0, 1.584962500721156, 1.0, null, null, 0.0, 2.321928094887362, null, 0.0, null, null, null, null, null, null, null, null, null, null, 1.584962500721156, null, 0.0, 7.693486957499325, 2.584962500721156, 6.339850002884624, 2.321928094887362, 2.584962500721156, 5.857980995127572, 3.169925001442312, 3.0, 2.0, 3.0, 5.754887502163468, null, 2.0, null, 7.129283016944966, 4.247927513443585, 4.087462841250339, 4.807354922057604, 3.700439718141092, 4.754887502163468, 4.754887502163468, 5.754887502163468, 4.643856189774724, 5.643856189774724, 4.169925001442312, 2.807354922057604, 5.906890595608519, null, 5.247927513443585, 1.584962500721156, 3.9068905956085187, 3.584962500721156, 3.0, 3.169925001442312, 3.321928094887362, 3.0, 4.087462841250339, 3.700439718141092, 2.0, 1.584962500721156, 4.0, null, 3.807354922057604, 1.584962500721156, 1.0, 1.0, 0.0, null, 0.0, 1.584962500721156, 1.584962500721156, 4.087462841250339, 2.0, 0.0, 1.0, null, 5.754887502163468, 3.584962500721156, 4.087462841250339, 3.169925001442312, 3.169925001442312, 3.169925001442312, 3.0, 4.754887502163468, 1.584962500721156, 4.247927513443585, 4.0, 4.087462841250339, 3.700439718141092, null, 8.005624549193879, 5.554588851677638, 5.20945336562895, 5.392317422778761, 5.523561956057013, 5.426264754702098, 5.930737337562887, 6.539158811108031, 4.169925001442312, 6.554588851677638, 5.584962500721156, 2.321928094887362, 5.614709844115208, null, 2.807354922057604, 1.0, 1.0, 1.0, 0.0, null, 0.0, 1.0, null, 0.0, null, 2.321928094887362, 0.0, null, 4.169925001442312, 2.321928094887362, 2.584962500721156, 2.321928094887362, 2.0, 2.807354922057604, 2.0, 4.321928094887363, 1.584962500721156, 4.087462841250339, null, null, 2.0, null, 6.129283016944966, 3.4594316186372973, 4.754887502163468, 3.700439718141092, 3.807354922057604, 4.087462841250339, 4.523561956057013, 5.0, 1.584962500721156, 6.108524456778169, 3.584962500721156, 1.0, 4.807354922057604, null, 6.6293566200796095, 3.321928094887362, 4.584962500721156, 4.321928094887363, 3.700439718141092, 3.584962500721156, 5.0, 4.0, 3.584962500721156, 4.087462841250339, 4.321928094887363, 2.0, 5.129283016944966, null, 6.409390936137702, 3.807354922057604, 4.321928094887363, 3.321928094887362, 2.0, 1.0, 2.0, 3.0, 2.0, 5.392317422778761, 2.0, 2.0, 2.584962500721156, null, null, null, 1.0, null, null, null, null, null, null, null, null, 2.321928094887362, null, null, 8.31741261376487, null, 6.066089190457772, 4.954196310386875, 4.700439718141092, 5.754887502163468, 5.954196310386875, 6.918863237274595, 4.321928094887363, 6.954196310386875, 5.700439718141092, 4.0, 6.087462841250339, 0.0, 5.129283016944966, 1.0, 4.857980995127572, 3.321928094887362, 3.9068905956085187, 3.169925001442312, 3.584962500721156, 4.0, 4.0, 2.807354922057604, 3.807354922057604, 2.321928094887362, 3.584962500721156, null, 5.491853096329675, 3.169925001442312, 3.807354922057604, 2.584962500721156, 2.0, 2.0, 2.807354922057604, 4.169925001442312, 1.0, 5.044394119358453, 3.0, 2.321928094887362, 3.169925001442312, null, 6.832890014164741, 4.700439718141092, 5.169925001442312, 4.0, 4.087462841250339, 2.584962500721156, 4.906890595608519, 5.129283016944966, 4.169925001442312, 5.78135971352466, 3.700439718141092, 1.0, 4.700439718141092, null, 5.357552004618084, 2.584962500721156, 3.321928094887362, 3.321928094887362, 0.0, 3.4594316186372973, 2.584962500721156, 2.807354922057604, 2.584962500721156, 4.584962500721156, 3.0, 1.584962500721156, 3.4594316186372973, null, 4.954196310386875, 2.321928094887362, 2.0, 1.0, 0.0, 2.584962500721156, 3.169925001442312, 3.4594316186372973, 2.584962500721156, 3.584962500721156, 1.0, 0.0, 2.807354922057604, null, 6.285402218862249, 4.087462841250339, 4.392317422778761, 4.087462841250339, 3.807354922057604, 3.584962500721156, 4.0, 5.169925001442312, 3.584962500721156, 5.129283016944966, 4.321928094887363, 1.584962500721156, 5.554588851677638, 0.0, 6.0, 2.807354922057604, 3.584962500721156, 4.169925001442312, 2.0, 3.169925001442312, 2.321928094887362, 3.700439718141092, 2.321928094887362, 4.169925001442312, 2.0, 2.321928094887362, 3.321928094887362, 0.0, 5.906890595608519, 3.321928094887362, 4.169925001442312, 2.807354922057604, 1.584962500721156, 3.700439718141092, 3.169925001442312, 4.392317422778761, 2.584962500721156, 5.169925001442312, 1.0, null, 4.087462841250339, null, 4.392317422778761, 0.0, 1.0, 1.0, 1.584962500721156, 2.321928094887362, 0.0, 2.321928094887362, null, 1.0, 2.0, 1.584962500721156, 2.584962500721156, null, 5.523561956057013, 3.0, 3.169925001442312, 4.0, 3.169925001442312, 3.321928094887362, 1.584962500721156, 4.087462841250339, 0.0, 4.087462841250339, 2.0, 2.584962500721156, 3.4594316186372973, null, 0.0, null, 1.0, null, 0.0, null, null, null, 0.0, null, null, 0.0, null, null, 8.531381460516313, null, 5.930737337562887, 6.108524456778169, 5.247927513443585, 5.807354922057604, 5.584962500721156, 7.321928094887363, 5.285402218862249, 7.3750394313469245, 5.129283016944966, 3.321928094887362, 6.491853096329675, 0.0, 8.022367813028454, 5.523561956057013, 6.794415866350106, 5.044394119358453, 5.087462841250339, 6.066089190457772, 6.189824558880018, 6.523561956057013, 5.321928094887363, 6.614709844115208, 5.491853096329675, 1.0, 5.754887502163468, 0.0, 9.398743691938193, 6.78135971352466, 7.531381460516312, 6.6865005271832185, 6.392317422778761, 7.05528243550119, 6.845490050944375, 8.103287808412022, 6.129283016944966, 8.154818109052105, 6.491853096329675, 1.584962500721156, 7.507794640198696, null, 6.700439718141092, 3.4594316186372973, 4.169925001442312, 4.247927513443585, 4.169925001442312, 3.4594316186372973, 4.0, 4.954196310386875, 3.700439718141092, 4.857980995127572, 2.584962500721156, 2.0, 4.321928094887363, null, 6.965784284662087, 4.392317422778761, 4.643856189774724, 4.0, 4.0, 4.754887502163468, 5.044394119358453, 6.20945336562895, 4.0, 4.523561956057013, 3.9068905956085187, 2.321928094887362, 5.087462841250339, null, 5.087462841250339, 3.700439718141092, 2.584962500721156, 2.0, 1.584962500721156, 3.700439718141092, 2.807354922057604, 4.321928094887363, 1.0, 3.584962500721156, 3.169925001442312, 1.0, 3.807354922057604, null, 7.294620748891627, 4.584962500721156, 6.409390936137702, 4.392317422778761, 3.807354922057604, 4.321928094887363, 4.954196310386875, 7.0, 4.700439718141092, 6.3750394313469245, 5.087462841250339, 1.584962500721156, 5.906890595608519, null, 6.930737337562887, 3.807354922057604, 3.321928094887362, 4.169925001442312, 2.321928094887362, 3.807354922057604, 3.0, 5.906890595608519, 3.700439718141092, 6.321928094887363, 4.169925001442312, 2.0, 4.643856189774724, null, 5.087462841250339, 1.584962500721156, 4.0, 1.584962500721156, 0.0, 1.584962500721156, 2.584962500721156, 4.247927513443585, 2.0, 5.087462841250339, 2.321928094887362, 1.584962500721156, 4.459431618637297, null, 5.169925001442312, 0.0, 1.584962500721156, 1.0, null, 1.584962500721156, 1.0, 1.584962500721156, null, 3.584962500721156, 1.0, 1.584962500721156, 2.0, 1.0, 5.727920454563199, 2.321928094887362, 3.584962500721156, 3.4594316186372973, 1.0, 0.0, 3.0, 3.169925001442312, 2.0, 4.0, 2.584962500721156, 3.169925001442312, 0.0, null, null, null, null, null, null, null, null, null, null, null, null, 2.0, null, 1.584962500721156, 9.5980525001616, 6.044394119358453, 8.016808287686555, 7.076815597050831, 7.592457037268081, 7.672425341971495, 8.066089190457772, 7.918863237274595, 6.94251450533924, 7.303780748177103, 6.807354922057604, 3.9068905956085187, 8.447083226209653, 1.0, 8.011227255423254, 5.491853096329675, 5.954196310386875, 5.321928094887363, 4.0, 5.087462841250339, 5.426264754702098, 7.044394119358453, 4.584962500721156, 6.044394119358453, 5.285402218862249, 3.0, 5.906890595608519, null, 6.0, 3.4594316186372973, 3.807354922057604, 3.4594316186372973, 3.584962500721156, 3.321928094887362, 3.584962500721156, 4.247927513443585, 1.0, 2.584962500721156, 2.584962500721156, 3.0, 3.584962500721156, 1.584962500721156, 7.257387842692652, 4.807354922057604, 5.754887502163468, 5.087462841250339, 4.087462841250339, 5.129283016944966, 5.584962500721156, 5.426264754702098, 5.584962500721156, 6.614709844115208, 4.584962500721156, 2.807354922057604, 6.066089190457772, null, 2.0, null, 1.0, 0.0, null, null, null, 2.0, null, null, null, null, 0.0, 2.321928094887362, 4.087462841250339, 1.584962500721156, 3.321928094887362, 1.584962500721156, 3.321928094887362, 1.0, 3.584962500721156, 3.700439718141092, 2.0, null, 2.0, 1.584962500721156, 4.0, 1.0, 5.614709844115208, 2.321928094887362, 4.459431618637297, 3.807354922057604, 2.807354922057604, 2.584962500721156, 3.169925001442312, 5.129283016944966, 2.0, 4.584962500721156, 3.9068905956085187, 2.584962500721156, 3.4594316186372973, null, 5.20945336562895, 0.0, 3.4594316186372973, 2.807354922057604, 0.0, 3.169925001442312, 2.807354922057604, 4.169925001442312, null, 4.857980995127572, 3.0, 0.0, 2.321928094887362, null, 3.700439718141092, null, 2.0, 1.584962500721156, 1.584962500721156, null, 2.807354922057604, 1.584962500721156, 3.169925001442312, 2.584962500721156, 1.0, 2.0, 2.584962500721156, null, 4.459431618637297, 3.0, 3.0, 2.0, 2.584962500721156, 3.169925001442312, 2.321928094887362, 3.0, 3.321928094887362, 3.321928094887362, 1.0, 0.0, 4.087462841250339, null, 2.321928094887362, 0.0, 1.0, null, null, null, null, 0.0, 0.0, null, 1.0, 2.321928094887362, 3.321928094887362, null, null, null, null, null, null, null, 0.0, null, null, 0.0, null, 0.0, null, null, 6.977279923499917, 3.807354922057604, 5.087462841250339, 4.0, 4.643856189774724, 5.357552004618084, 5.459431618637297, 3.9068905956085187, 4.857980995127572, 4.247927513443585, 4.459431618637297, 3.0, 5.832890014164741, 1.0, 6.741466986401147, 4.321928094887363, 5.247927513443585, 4.169925001442312, 4.584962500721156, 4.169925001442312, 5.044394119358453, 3.807354922057604, 4.0, 4.0, 4.321928094887363, 1.0, 5.357552004618084, null, 6.475733430966398, 3.0, 4.584962500721156, 3.0, 4.247927513443585, 3.321928094887362, 4.857980995127572, 3.321928094887362, 1.0, 0.0, 2.584962500721156, 1.0, 5.087462841250339, 0.0, 6.954196310386875, 4.584962500721156, 6.266786540694901, 4.584962500721156, 5.0, 5.169925001442312, 5.857980995127572, 4.857980995127572, 4.169925001442312, 4.0, 4.459431618637297, 2.807354922057604, 5.832890014164741, null, 4.857980995127572, null, 3.0, 1.584962500721156, 1.0, 3.0, 3.0, 2.0, 2.584962500721156, null, 3.807354922057604, 0.0, 3.169925001442312, 0.0, 5.906890595608519, 3.0, 2.0, 2.321928094887362, 3.584962500721156, 3.0, 3.584962500721156, 3.4594316186372973, 3.584962500721156, 3.4594316186372973, 1.0, 1.0, 4.247927513443585, 0.0, 8.64745842645492, 6.339850002884624, 6.94251450533924, 6.189824558880018, 5.727920454563199, 7.098032082960526, 6.918863237274595, 5.906890595608519, 5.977279923499917, 6.714245517666122, 5.906890595608519, 2.584962500721156, 7.643856189774724, null, 4.321928094887363, 1.0, 2.807354922057604, 1.0, 1.584962500721156, 2.0, 2.321928094887362, 1.0, 1.0, 3.0, 1.0, 2.0, 3.584962500721156, 1.584962500721156, 7.066089190457772, 4.584962500721156, 5.584962500721156, 4.807354922057604, 4.700439718141092, 5.523561956057013, 5.643856189774724, 4.700439718141092, 4.523561956057013, 5.491853096329675, 5.357552004618084, 2.584962500721156, 5.930737337562887, null, 5.0, 1.0, 3.321928094887362, 2.807354922057604, 2.321928094887362, 2.321928094887362, 3.321928094887362, 2.0, 3.584962500721156, 1.584962500721156, 3.700439718141092, 2.584962500721156, 3.584962500721156, null, 4.954196310386875, 2.0, 2.584962500721156, 2.807354922057604, 2.807354922057604, 3.169925001442312, 3.4594316186372973, 1.584962500721156, 3.169925001442312, 3.169925001442312, 2.0, 2.584962500721156, 3.584962500721156, null, null, null, 1.0, null, null, null, null, null, null, 1.0, null, 2.0, null, null, 8.366322214245816, 6.087462841250339, 7.022367813028454, 5.807354922057604, 6.044394119358453, 6.599912842187128, 6.94251450533924, 5.857980995127572, 5.857980995127572, 5.807354922057604, 6.321928094887363, 3.0, 7.330916878114617, 2.321928094887362, 9.94251450533924, 7.658211482751795, 9.055282435501189, 7.475733430966398, 7.768184324776926, 8.370687406807217, 8.396604781181859, 7.839203788096944, 7.599912842187128, 8.204571144249204, 7.247927513443585, 3.700439718141092, 9.328674927327947, 0.0, 4.392317422778761, 3.700439718141092, 3.0, 2.0, 3.321928094887362, 3.169925001442312, 3.584962500721156, 1.584962500721156, 1.584962500721156, 3.169925001442312, 1.0, 2.0, 3.9068905956085187, 1.0, 6.392317422778761, 4.321928094887363, 5.169925001442312, 4.700439718141092, 4.584962500721156, 4.169925001442312, 5.169925001442312, 4.643856189774724, 4.087462841250339, 4.087462841250339, 4.247927513443585, 2.0, 5.426264754702098, null, null, null, 1.584962500721156, null, null, null, 0.0, 0.0, null, 1.0, 1.0, 3.169925001442312, null, null, 3.0, null, 1.0, 0.0, null, 0.0, 1.584962500721156, null, null, null, null, null, 2.584962500721156, 0.0, 6.672425341971495, 4.523561956057013, 3.807354922057604, 4.0, 4.321928094887363, 5.129283016944966, 5.20945336562895, 4.247927513443585, 4.523561956057013, 2.807354922057604, 4.087462841250339, 0.0, 5.614709844115208, null, null, null, 0.0, null, null, null, null, null, null, null, null, 0.0, null, null, 5.78135971352466, 4.392317422778761, 4.459431618637297, 3.0, 3.321928094887362, 3.4594316186372973, 4.0, 2.321928094887362, 3.321928094887362, 4.754887502163468, 3.584962500721156, 2.584962500721156, 4.523561956057013, null, null, null, 0.0, null, null, null, null, null, null, 0.0, null, 2.321928094887362, null, null, 6.727920454563199, 5.523561956057013, 5.321928094887363, 3.700439718141092, 3.807354922057604, 2.584962500721156, 4.584962500721156, 3.4594316186372973, 2.0, 4.523561956057013, 4.321928094887363, 2.321928094887362, 4.857980995127572, null, null, null, 0.0, null, null, null, null, null, 1.0, 1.584962500721156, null, 2.321928094887362, null, 1.0, 0.0, 1.0, 0.0, 0.0, 0.0, null, 0.0, 2.584962500721156, 0.0, 5.321928094887363, 1.0, 5.554588851677638, 1.584962500721156, null, 0.0, null, 0.0, 0.0, 0.0, null, null, null, 0.0, null, 1.0, 3.584962500721156, null, 6.832890014164741, 7.499845887083206, 6.266786540694901, 6.044394119358453, 6.0, 3.169925001442312, 4.700439718141092, 5.129283016944966, 6.066089190457772, 3.584962500721156, 6.321928094887363, 5.169925001442312, 11.877284133523196, 5.087462841250339, 1.584962500721156, 7.366322214245816, null, null, 6.108524456778169, 5.129283016944966, 6.044394119358453, 4.459431618637297, null, 5.459431618637297, 7.930737337562887, 4.087462841250339, 6.768184324776926, 6.6865005271832185, 0.0, 8.005624549193879, null, 1.0, 4.954196310386875, 3.321928094887362, 4.906890595608519, 2.0, null, 4.700439718141092, 7.129283016944966, 4.321928094887363, 7.965784284662087, 5.672425341971495, null, 2.0, null, 2.584962500721156, 0.0, null, 0.0, 2.0, 0.0, null, null, null, 6.266786540694901, 1.584962500721156, null, 3.169925001442312, null, null, null, 1.584962500721156, null, 2.807354922057604, null, 1.0, null, null, null, null, null, 0.0, null, null, null, null, null, null, 0.0, null, null, null, 2.0, null, 3.584962500721156, 3.807354922057604, 3.700439718141092, 3.169925001442312, 2.584962500721156, 2.584962500721156, 2.0, 2.321928094887362, 1.584962500721156, 2.0, 2.0, null, 7.189824558880018, 3.169925001442312, 3.169925001442312, 4.459431618637297, 0.0, 3.0, 2.321928094887362, 0.0, 1.584962500721156, 2.0, 0.0, null, 2.0, 1.0, 7.0, 2.321928094887362, 0.0, 3.9068905956085187, null, null, 1.0, 1.584962500721156, 2.0, 1.0, null, 0.0, 1.0, 1.0, 2.321928094887362, 3.321928094887362, null, 0.0, null, 1.0, 0.0, null, 0.0, 0.0, null, null, 1.0, null, 3.4594316186372973, 1.0, 0.0, 6.539158811108031, 0.0, null, 3.807354922057604, 3.0, 3.321928094887362, 2.584962500721156, null, 3.321928094887362, 5.044394119358453, 1.0, 5.426264754702098, 4.247927513443585, 6.857980995127572, 7.857980995127572, 6.442943495848728, 6.285402218862249, 5.285402218862249, 4.807354922057604, 5.129283016944966, 4.087462841250339, 5.584962500721156, 4.321928094887363, 6.247927513443585, 5.20945336562895, 11.580729651598958, 6.0, null, 0.0, null, 0.0, null, null, null, null, null, null, 2.584962500721156, null, 0.0, 0.0, null, 5.882643049361842, null, 1.0, 3.807354922057604, 2.0, 1.0, 2.0, 2.321928094887362, 2.0, 4.584962500721156, null, 6.22881869049588, 4.0, null, 2.321928094887362, 1.584962500721156, 3.321928094887362, null, null, 0.0, null, 2.807354922057604, 0.0, 3.0, 2.0, 1.0, 1.584962500721156, 2.321928094887362, 1.584962500721156, null, 1.584962500721156, 0.0, null, null, null, null, 0.0, 3.321928094887362, null, 2.807354922057604, 1.0, null, 5.044394119358453, null, 0.0, 3.4594316186372973, 1.584962500721156, 3.4594316186372973, 1.0, null, 2.321928094887362, 5.129283016944966, 1.0, 5.459431618637297, 4.087462841250339, null, 5.087462841250339, null, null, 3.0, null, 0.0, 0.0, null, null, 4.0, null, 2.0, 2.584962500721156, 1.0, 3.584962500721156, null, 2.807354922057604, 1.584962500721156, null, 1.0, 1.584962500721156, 2.584962500721156, 2.0, 2.584962500721156, null, 7.924812503605781, null, null, 5.321928094887363, null, 0.0, 2.584962500721156, 1.584962500721156, 1.584962500721156, 2.321928094887362, null, null, 4.906890595608519, null, 4.0, 3.169925001442312, 0.0, 4.584962500721156, 0.0, 3.321928094887362, 1.584962500721156, 1.0, 2.0, null, 2.0, null, 2.0, 2.584962500721156, 8.044394119358454, 1.584962500721156, null, 3.321928094887362, null, 1.0, 1.0, 0.0, 0.0, null, null, 1.584962500721156, 2.321928094887362, null, 3.4594316186372973, 0.0, 1.0, 5.672425341971495, 1.0, 5.584962500721156, 1.0, 2.321928094887362, 4.247927513443585, 1.584962500721156, 1.584962500721156, 1.0, 2.0, 4.459431618637297, 7.417852514885898, 2.0, 1.0, 8.027905996569885, null, 0.0, 5.930737337562887, 3.321928094887362, 5.357552004618084, 3.169925001442312, 1.0, 3.807354922057604, 7.0, 4.392317422778761, 6.357552004618084, 5.523561956057013, 3.321928094887362, 3.169925001442312, 2.321928094887362, null, 1.0, 0.0, 1.0, 0.0, 3.4594316186372973, 2.0, 3.807354922057604, 1.0, 7.820178962415188, null, null, 1.0, null, null, 1.584962500721156, null, null, null, 1.0, null, 2.0, null, 5.247927513443585, 0.0, null, 5.78135971352466, 0.0, 1.0, 3.584962500721156, 3.0, 2.584962500721156, 3.321928094887362, 2.321928094887362, 2.321928094887362, 5.247927513443585, 3.0, 5.392317422778761, 4.087462841250339, null, 5.426264754702098, null, null, 3.584962500721156, 0.0, 2.321928094887362, 2.0, null, 0.0, 5.129283016944966, null, 4.807354922057604, 3.321928094887362, null, 2.0, null, 2.0, 2.584962500721156, 0.0, 1.0, null, 3.9068905956085187, 2.0, 5.0, 3.0, 4.643856189774724, 0.0, null, 3.700439718141092, null, null, 2.0, 1.584962500721156, 2.0, 1.0, null, 1.0, 3.807354922057604, 1.0, 4.169925001442312, 1.0, null, 4.807354922057604, 2.321928094887362, 2.0, 2.0, null, 2.0, 0.0, 3.169925001442312, null, 3.584962500721156, null, 0.0, 1.584962500721156, null, 2.0, 1.0, 2.584962500721156, 1.584962500721156, 0.0, 1.584962500721156, 2.0, 2.0, null, null, null, null, 2.0, 0.0, 3.700439718141092, null, 1.0, 2.0, 0.0, 2.321928094887362, null, null, 1.0, 3.700439718141092, null, 2.584962500721156, 0.0, null, 3.321928094887362, null, null, null, null, 0.0, null, null, null, 2.0, null, 2.584962500721156, 0.0, null, 7.569855608330948, null, 1.584962500721156, 5.285402218862249, 4.087462841250339, 5.087462841250339, 3.4594316186372973, 1.0, 5.129283016944966, 6.357552004618084, 3.9068905956085187, 6.357552004618084, 6.022367813028454, 1.0, 6.882643049361842, 0.0, 1.584962500721156, 4.321928094887363, 2.807354922057604, 3.9068905956085187, 3.321928094887362, 1.584962500721156, 3.584962500721156, 5.78135971352466, 2.0, 6.539158811108031, 4.954196310386875, null, 5.906890595608519, 3.0, 4.459431618637297, 4.087462841250339, 1.584962500721156, 3.700439718141092, 3.169925001442312, 4.459431618637297, 3.0, 5.459431618637297, 3.169925001442312, 2.0, 3.807354922057604, 2.0, 5.044394119358453, null, 0.0, 3.321928094887362, 4.0, 4.321928094887363, 2.0, null, 3.584962500721156, 5.044394119358453, 2.0, 4.459431618637297, 5.20945336562895, null, 2.321928094887362, null, null, 1.0, null, 0.0, 0.0, null, null, 0.0, null, 2.807354922057604, 0.0, 1.584962500721156, 2.807354922057604, null, 0.0, 0.0, 1.0, 1.0, null, null, 1.584962500721156, 5.459431618637297, null, 5.491853096329675, 1.584962500721156, null, 3.0, 0.0, null, 3.169925001442312, null, 0.0, 0.0, 3.4594316186372973, null, null, null, 6.78135971352466, 1.584962500721156, null, 3.0, null, 0.0, 3.321928094887362, null, null, 0.0, null, 2.0, 4.459431618637297, null, 3.584962500721156, 1.584962500721156, null, 4.754887502163468, null, null, 3.0, 2.807354922057604, 3.0, 2.0, null, 3.584962500721156, 4.700439718141092, 1.0, 3.4594316186372973, 2.807354922057604, 0.0, 1.584962500721156, null, 0.0, 1.0, 0.0, 0.0, 0.0, null, null, 1.584962500721156, 0.0, 0.0, null, null, 3.321928094887362, null, null, null, 0.0, 1.0, null, null, null, 3.700439718141092, null, 2.584962500721156, 1.0, null, 0.0, null, null, 1.0, null, 0.0, null, 1.0, null, 3.9068905956085187, null, 2.0, 0.0, 1.584962500721156, 2.321928094887362, null, 0.0, null, null, 0.0, null, 2.321928094887362, null, 4.247927513443585, null, 0.0, null, 2.0, 8.038918989292302, null, 1.0, 4.906890595608519, 5.20945336562895, 5.523561956057013, 4.523561956057013, null, 4.954196310386875, 7.357552004618084, 3.807354922057604, 6.22881869049588, 6.3750394313469245, null, 7.894817763307944, 0.0, 2.807354922057604, 4.459431618637297, 4.169925001442312, 4.700439718141092, 3.321928094887362, 2.807354922057604, 4.700439718141092, 6.321928094887363, 3.0, 6.741466986401147, 5.857980995127572, null, 4.807354922057604, 1.584962500721156, 2.807354922057604, 2.321928094887362, 0.0, 2.321928094887362, 2.807354922057604, 3.169925001442312, null, 5.0, 1.0, 8.900866807980748, 1.0, null, 4.0, null, null, 2.0, 0.0, 2.321928094887362, 1.584962500721156, null, 0.0, 3.321928094887362, 1.0, 5.129283016944966, 3.169925001442312, 1.584962500721156, 3.700439718141092, null, 3.584962500721156, 0.0, null, 2.321928094887362, 1.584962500721156, 1.584962500721156, null, 4.700439718141092, 0.0, 5.285402218862249, 2.321928094887362, null, 3.9068905956085187, null, 0.0, 2.321928094887362, 1.584962500721156, 1.584962500721156, null, 2.807354922057604, 1.0, 4.643856189774724, null, 5.044394119358453, 2.584962500721156, null, 4.807354922057604, null, null, 2.584962500721156, null, 2.584962500721156, null, 2.584962500721156, null, 1.584962500721156, 2.584962500721156, 4.169925001442312, 1.0, 2.807354922057604, 5.087462841250339, null, 1.0, 4.087462841250339, 1.0, 2.807354922057604, 3.321928094887362, 5.285402218862249, 3.807354922057604, 7.851749041416057, 4.584962500721156, 7.1799090900149345, 4.087462841250339, null, 4.857980995127572, null, 0.0, 2.584962500721156, 2.321928094887362, 2.584962500721156, 0.0, 1.0, 2.584962500721156, 4.087462841250339, 2.0, 4.087462841250339, 3.4594316186372973, 0.0, 4.523561956057013, null, null, 2.584962500721156, 1.0, 0.0, 1.0, null, 2.0, 3.169925001442312, null, 3.0, 2.0, null, 4.700439718141092, null, null, 0.0, null, 1.584962500721156, null, 0.0, null, 3.169925001442312, 1.0, 3.169925001442312, 1.584962500721156, null, null, null, 1.0, null, null, null, null, null, null, 0.0, null, 3.0, null, 0.0, 4.954196310386875, 0.0, 2.584962500721156, 3.584962500721156, 2.0, 2.584962500721156, 0.0, 4.247927513443585, 1.0, 3.700439718141092, 3.0, 9.348728154231077, 2.807354922057604, null, 5.044394119358453, null, null, 2.0, 1.584962500721156, 2.321928094887362, 2.321928094887362, 2.321928094887362, 2.0, 4.523561956057013, null, 4.523561956057013, 3.9068905956085187, null, 6.20945336562895, 0.0, 1.0, 5.169925001442312, 4.906890595608519, 5.754887502163468, 3.700439718141092, 3.0, 5.087462841250339, 6.392317422778761, 2.0, 6.584962500721156, 5.906890595608519, null, 1.0, null, null, null, 0.0, null, null, null, null, 0.0, null, 0.0, null, 1.0, 3.0, null, null, 2.807354922057604, 2.0, 3.0, 2.321928094887362, 2.321928094887362, 1.0, 3.9068905956085187, 1.0, 4.643856189774724, 2.584962500721156, null, 1.584962500721156, null, null, null, 1.0, 1.0, 1.0, null, 1.0, 2.807354922057604, null, 3.584962500721156, 1.0, 0.0, 3.584962500721156, null, null, 2.321928094887362, 2.0, 0.0, null, null, null, 3.584962500721156, 1.0, 4.0, 2.0, null, 2.584962500721156, null, null, 0.0, 2.321928094887362, 2.584962500721156, 2.321928094887362, null, 2.584962500721156, 1.584962500721156, null, 2.584962500721156, 3.0, 4.392317422778761, 3.0, 2.807354922057604, 2.584962500721156, 2.321928094887362, 1.0, 2.321928094887362, 2.584962500721156, 2.584962500721156, 2.807354922057604, 1.0, 1.0, 6.321928094887363, 2.584962500721156, null, 3.4594316186372973, 2.807354922057604, 3.0, 1.0, 1.0, 1.0, 1.0, 1.0, null, null, 1.0, null, 1.584962500721156, null, null, null, null, 0.0, 0.0, null, null, null, null, 0.0, 0.0, null, null, 5.930737337562887, 6.266786540694901, 4.954196310386875, 5.321928094887363, 4.459431618637297, 4.169925001442312, 4.807354922057604, 5.584962500721156, 3.584962500721156, 3.9068905956085187, 5.0, 3.584962500721156, 9.850186837645774, 4.954196310386875, null, 1.584962500721156, null, 1.584962500721156, 1.584962500721156, null, 1.584962500721156, 1.584962500721156, null, 1.0, 2.584962500721156, 3.0, 4.169925001442312, 0.0, null, 5.20945336562895, 1.0, null, 3.321928094887362, 4.954196310386875, 3.807354922057604, 4.584962500721156, 0.0, 5.614709844115208, 3.321928094887362, 2.0, 4.0, 4.169925001442312, 6.189824558880018, 6.247927513443585, 5.491853096329675, 6.247927513443585, 4.700439718141092, 3.169925001442312, 4.643856189774724, 4.392317422778761, 4.0, 3.584962500721156, 3.807354922057604, 4.857980995127572, 9.18239435340453, 5.129283016944966, 1.584962500721156, 5.954196310386875, 3.321928094887362, 4.392317422778761, 3.807354922057604, 3.169925001442312, 4.643856189774724, 4.321928094887363, 2.584962500721156, 3.321928094887362, 4.0, 4.321928094887363, 1.0, 5.0, null, 3.321928094887362, 0.0, null, 1.0, 1.584962500721156, 2.0, 1.0, null, 1.0, 1.0, 2.0, 2.0, 1.584962500721156, null, 3.807354922057604, 3.0, 3.169925001442312, 2.0, 2.321928094887362, 2.584962500721156, 3.0, 1.0, 1.0, null, 1.0, null, 2.807354922057604, 0.0, 3.700439718141092, 3.4594316186372973, 3.321928094887362, 2.0, 1.584962500721156, 2.0, 3.169925001442312, 0.0, null, 1.0, 2.584962500721156, null, 2.0, null, 4.700439718141092, null, null, 1.584962500721156, 3.584962500721156, 3.321928094887362, 2.584962500721156, null, 1.0, null, 1.584962500721156, 4.169925001442312, 2.807354922057604, null, 1.0, null, 0.0, null, 0.0, 1.0, 1.0, null, 1.0, 2.0, null, 1.0, 1.584962500721156, 1.584962500721156, 0.0, null, null, null, 0.0, 1.584962500721156, 0.0, null, null, 2.321928094887362, 2.0, 0.0, 1.0, 0.0, null, null, null, 0.0, null, null, null, null, null, null, null, null, null, null, 5.392317422778761, null, 0.0, 1.0, 3.169925001442312, 2.321928094887362, 2.0, null, 2.584962500721156, 2.584962500721156, 2.0, 3.4594316186372973, 3.584962500721156, 9.79766152585376, 10.080817527608327, 9.319672120946995, 9.566054038171092, 8.179909090014934, 8.139551352398794, 8.20945336562895, 8.897845456005511, 7.906890595608519, 7.864186144654281, 8.164906926675688, 8.339850002884624, 13.12395971059229, 9.487840033823051, null, 3.584962500721156, null, 1.0, 1.584962500721156, null, 0.0, 2.807354922057604, null, 1.0, 2.807354922057604, 0.0, 3.700439718141092, 2.807354922057604, 0.0, 6.754887502163468, null, 0.0, 3.807354922057604, 5.044394119358453, 4.392317422778761, 4.321928094887363, 1.0, 4.700439718141092, 4.459431618637297, 4.087462841250339, 4.700439718141092, 6.0, 0.0, 6.539158811108031, null, 1.0, 4.321928094887363, 4.087462841250339, 5.357552004618084, 4.247927513443585, null, 5.491853096329675, 5.459431618637297, 3.0, 5.357552004618084, 6.0, null, null, null, null, null, null, 0.0, 0.0, null, null, 1.0, null, 1.0, 0.0, 0.0, 3.700439718141092, null, null, 1.584962500721156, 2.0, 2.584962500721156, 2.584962500721156, 0.0, 2.584962500721156, 3.169925001442312, 1.0, 2.584962500721156, 3.4594316186372973, null, 0.0, null, null, null, 2.584962500721156, 2.321928094887362, 1.0, 0.0, 1.0, 3.169925001442312, 1.0, 3.321928094887362, 2.0, null, null, null, null, 0.0, null, null, null, null, null, 1.0, null, null, null, null, 1.0, null, 1.0, 1.0, null, 0.0, null, 0.0, 2.0, null, null, 3.169925001442312, 0.0, null, 0.0, null, null, 1.584962500721156, 1.584962500721156, 0.0, 2.0, null, 1.0, 2.0, null, 3.169925001442312, 1.584962500721156, null, null, null, null, 0.0, null, null, null, null, null, 0.0, null, null, null, 0.0, 6.754887502163468, 4.321928094887363, 5.0, 3.321928094887362, 3.321928094887362, 2.584962500721156, 4.807354922057604, 3.807354922057604, 3.321928094887362, 4.459431618637297, 4.954196310386875, 10.46352437327118, 5.247927513443585, 1.0, 7.149747119504682, 4.643856189774724, 5.426264754702098, 4.700439718141092, 3.700439718141092, 4.087462841250339, 4.0, 4.392317422778761, 2.584962500721156, 4.321928094887363, 4.392317422778761, 10.246740598493144, 6.672425341971495, 1.584962500721156, 8.535275376620802, 6.22881869049588, 7.2384047393250786, 6.266786540694901, 5.977279923499917, 5.882643049361842, 6.3750394313469245, 6.539158811108031, 5.129283016944966, 7.199672344836364, 6.066089190457772, 12.099676554859643, 7.491853096329675, 0.0, 6.930737337562887, 5.169925001442312, 5.129283016944966, 4.643856189774724, 4.0, 4.0, 4.807354922057604, 5.129283016944966, 3.321928094887362, 5.584962500721156, 5.169925001442312, 10.86573327085176, 5.727920454563199, 3.0, 8.665335917185176, 6.321928094887363, 7.294620748891627, 6.20945336562895, 5.857980995127572, 6.149747119504682, 6.78135971352466, 6.9886846867721655, 5.882643049361842, 7.826548487290915, 6.426264754702098, 12.480032814583948, 7.794415866350106, 3.584962500721156, 9.30149619498255, 6.918863237274595, 8.74819284958946, 7.066089190457772, 7.098032082960526, 7.2384047393250786, 7.948367231584678, 6.714245517666122, 6.754887502163468, 8.159871336778389, 7.285402218862249, 11.913637428049103, 8.870364719583405, null, 3.584962500721156, null, 4.0, null, 5.285402218862249, 1.0, 7.491853096329675, null, 5.169925001442312, null, 1.0, 4.459431618637297, 1.584962500721156, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.584962500721156, null, 0.0, 7.2761244052742375, 4.523561956057013, 5.700439718141092, 5.044394119358453, 4.523561956057013, 4.321928094887363, 5.491853096329675, 4.321928094887363, 5.426264754702098, 5.700439718141092, 4.906890595608519, 10.140829770773001, 6.266786540694901, null, null, null, null, null, null, null, null, null, null, null, null, 1.0, null, 1.584962500721156, 7.954196310386875, 6.149747119504682, 6.820178962415188, 6.129283016944966, 5.357552004618084, 5.857980995127572, 6.3750394313469245, 6.845490050944375, 5.523561956057013, 7.03342300153745, 5.832890014164741, 11.884170519108435, 7.366322214245816, null, 8.03342300153745, 5.392317422778761, 6.426264754702098, 5.78135971352466, 5.169925001442312, 5.044394119358453, 6.022367813028454, 3.700439718141092, 5.459431618637297, 6.266786540694901, 6.247927513443585, 11.252074042796185, 6.794415866350106, 1.584962500721156, 8.569855608330949, 5.491853096329675, 8.049848549450562, 6.339850002884624, 6.022367813028454, 6.149747119504682, 6.266786540694901, 6.491853096329675, 4.643856189774724, 6.741466986401147, 6.129283016944966, 11.10459875356437, 7.693486957499325, null, 6.643856189774724, 3.700439718141092, 4.459431618637297, 4.087462841250339, 3.169925001442312, 3.321928094887362, 4.643856189774724, 3.9068905956085187, 2.0, 3.9068905956085187, 2.0, 10.029287226968245, 5.247927513443585, 1.0, 7.546894459887636, 5.727920454563199, 5.700439718141092, 5.857980995127572, 4.247927513443585, 4.584962500721156, 5.491853096329675, 5.392317422778761, 3.0, 6.022367813028454, 4.807354922057604, 11.454813348512525, 6.768184324776926, 1.584962500721156, 7.857980995127572, 5.857980995127572, 6.392317422778761, 5.643856189774724, 5.392317422778761, 5.392317422778761, 5.357552004618084, 4.906890595608519, 3.584962500721156, 5.754887502163468, 5.169925001442312, 11.711666973564347, 6.714245517666122, null, 7.977279923499917, 5.392317422778761, 6.78135971352466, 5.426264754702098, 4.700439718141092, 5.285402218862249, 5.392317422778761, 5.807354922057604, 4.0, 6.491853096329675, 5.044394119358453, 11.287135186086704, 6.584962500721156, 1.584962500721156, 6.20945336562895, 3.700439718141092, 4.247927513443585, 4.807354922057604, 3.0, 2.584962500721156, 3.4594316186372973, 3.169925001442312, 1.584962500721156, 3.4594316186372973, 3.807354922057604, 10.122827994807666, 4.392317422778761, 1.0, 7.05528243550119, 5.357552004618084, 6.20945336562895, 5.169925001442312, 4.459431618637297, 4.523561956057013, 5.807354922057604, 3.584962500721156, 3.584962500721156, 6.339850002884624, 5.672425341971495, 11.378294855911891, 6.266786540694901, null, 0.0, null, null, null, null, null, null, null, null, null, null, 1.0, null, 0.0, 7.643856189774724, 4.643856189774724, 6.189824558880018, 5.20945336562895, 4.807354922057604, 5.321928094887363, 5.285402218862249, 5.426264754702098, 4.0, 5.882643049361842, 5.0, 10.98299357469431, 6.321928094887363, null, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, 1.584962500721156, 6.78135971352466, 4.857980995127572, 5.832890014164741, 4.169925001442312, 2.807354922057604, 3.807354922057604, 5.0, 5.0, 3.321928094887362, 5.807354922057604, 4.906890595608519, 10.868050853745158, 6.066089190457772, null, 6.129283016944966, 2.0, 4.523561956057013, 1.584962500721156, 1.0, 3.807354922057604, 2.321928094887362, 2.0, null, 2.0, 4.906890595608519, 7.7073591320808825, 3.0, 0.0, 7.108524456778169, 4.584962500721156, 5.321928094887363, 4.857980995127572, 3.321928094887362, 4.0, 3.9068905956085187, 3.807354922057604, 0.0, 5.672425341971495, 4.0, 10.644757592516257, 5.832890014164741, null, 6.658211482751795, 4.169925001442312, 5.357552004618084, 4.087462841250339, 4.0, 3.584962500721156, 3.9068905956085187, 4.584962500721156, 1.0, 4.954196310386875, 4.0, 9.851749041416058, 4.954196310386875, 1.584962500721156, 7.303780748177103, 4.857980995127572, 5.906890595608519, 4.857980995127572, 5.129283016944966, 5.044394119358453, 5.882643049361842, 4.459431618637297, 4.459431618637297, 5.882643049361842, 5.459431618637297, 11.101975670949232, 6.303780748177103, 1.0, 7.366322214245816, 4.459431618637297, 5.906890595608519, 5.087462841250339, 4.247927513443585, 5.0, 4.459431618637297, 5.954196310386875, 4.0, 5.523561956057013, 3.4594316186372973, 11.050528905530555, 5.906890595608519, null, 1.584962500721156, null, 1.584962500721156, null, null, null, 0.0, 1.584962500721156, null, 2.0, 0.0, 4.523561956057013, 0.0, null, null, null, null, 0.0, null, null, null, null, null, null, null, 2.321928094887362, null, 0.0, 6.044394119358453, 4.321928094887363, 5.643856189774724, 4.0, 3.807354922057604, 4.087462841250339, 4.643856189774724, 5.0, 2.584962500721156, 4.087462841250339, 3.584962500721156, 10.079484783826816, 5.459431618637297, 1.0, 7.971543553950772, 5.754887502163468, 6.475733430966398, 5.643856189774724, 5.285402218862249, 5.584962500721156, 5.523561956057013, 3.9068905956085187, 4.169925001442312, 5.754887502163468, 5.954196310386875, 11.316847183602473, 7.2761244052742375, 0.0, 6.930737337562887, 4.169925001442312, 5.882643049361842, 5.129283016944966, 4.584962500721156, 4.247927513443585, 4.523561956057013, 5.285402218862249, 4.392317422778761, 5.882643049361842, 4.807354922057604, 10.075479149488016, 6.20945336562895, null, 0.0, null, null, null, null, null, null, null, null, null, null, 4.169925001442312, 0.0, 0.0, 7.451211111832329, 5.0, 6.442943495848728, 4.643856189774724, 4.169925001442312, 4.087462841250339, 5.169925001442312, 5.523561956057013, 3.700439718141092, 6.108524456778169, 4.584962500721156, 10.754052367528924, 6.426264754702098, 0.0, 6.247927513443585, 4.584962500721156, 4.584962500721156, 4.584962500721156, 3.169925001442312, 4.0, 4.392317422778761, 4.754887502163468, 3.0, 3.700439718141092, 4.700439718141092, 10.12670447284319, 4.807354922057604, null, 6.9886846867721655, 4.392317422778761, 5.906890595608519, 4.169925001442312, 3.700439718141092, 4.087462841250339, 4.584962500721156, 5.491853096329675, 3.0, 5.807354922057604, 5.169925001442312, 10.960725994839057, 6.087462841250339, 0.0, 7.2384047393250786, 4.700439718141092, 5.584962500721156, 4.459431618637297, 4.392317422778761, 4.754887502163468, 4.807354922057604, 2.321928094887362, 2.0, 5.426264754702098, 4.523561956057013, 10.448116305409464, 6.149747119504682, 0.0, 7.022367813028454, 4.954196310386875, 5.832890014164741, 4.906890595608519, 4.700439718141092, 4.321928094887363, 5.426264754702098, 4.169925001442312, 4.584962500721156, 4.857980995127572, 5.392317422778761, 10.043027283594547, 6.321928094887363, null, 6.78135971352466, 4.459431618637297, 5.906890595608519, 4.700439718141092, 3.321928094887362, 4.584962500721156, 5.087462841250339, 4.169925001442312, 3.0, 4.321928094887363, 4.459431618637297, 10.757390009366638, 6.0, null, 2.0, 1.0, 2.584962500721156, 1.0, null, null, null, 1.584962500721156, null, 1.0, null, 6.658211482751795, 0.0, 0.0, 8.308339030139408, 5.392317422778761, 7.1799090900149345, 6.22881869049588, 5.857980995127572, 6.149747119504682, 6.426264754702098, 3.169925001442312, 5.20945336562895, 6.066089190457772, 6.285402218862249, 10.62844554013718, 7.768184324776926, 1.584962500721156, 7.658211482751795, 5.0, 7.098032082960526, 5.357552004618084, 4.754887502163468, 4.906890595608519, 5.700439718141092, 5.169925001442312, 5.129283016944966, 5.906890595608519, 5.459431618637297, 10.604553229079038, 6.554588851677638, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.584962500721156, 7.531381460516312, 4.906890595608519, 5.754887502163468, 5.087462841250339, 4.392317422778761, 4.459431618637297, 4.754887502163468, 2.0, 3.807354922057604, 5.807354922057604, 4.754887502163468, 10.7714894695006, 5.584962500721156, null, 0.0, null, null, null, null, 1.584962500721156, null, null, null, null, null, 2.584962500721156, 0.0, null, 8.413627929024173, 5.700439718141092, 7.011227255423254, 6.108524456778169, 5.554588851677638, 5.392317422778761, 6.129283016944966, 6.0, 5.357552004618084, 6.918863237274595, 5.930737337562887, 11.336506559810255, 7.247927513443585, null, 7.05528243550119, 4.392317422778761, 5.754887502163468, 4.459431618637297, 4.247927513443585, 4.392317422778761, 5.285402218862249, 4.321928094887363, 3.0, 5.584962500721156, 4.459431618637297, 10.129283016944967, 6.321928094887363, 2.0, 7.483815777264256, 5.169925001442312, 6.442943495848728, 5.247927513443585, 4.643856189774724, 5.044394119358453, 5.643856189774724, 6.022367813028454, 4.247927513443585, 5.426264754702098, 4.857980995127572, 10.837627933171404, 6.459431618637297, null, 3.321928094887362, 0.0, 2.0, null, null, 0.0, 0.0, 1.0, 0.0, null, 1.0, 6.169925001442312, null, 0.0, 6.794415866350106, 3.807354922057604, 5.459431618637297, 4.169925001442312, 3.169925001442312, 4.0, 4.247927513443585, 4.459431618637297, 3.321928094887362, 5.554588851677638, 4.584962500721156, 10.03342300153745, 4.954196310386875, null, 7.266786540694901, 4.087462841250339, 5.727920454563199, 5.0, 4.700439718141092, 4.169925001442312, 4.807354922057604, 4.906890595608519, 3.584962500721156, 4.459431618637297, 4.247927513443585, 10.037546953962178, 6.169925001442312, null, 3.321928094887362, 1.584962500721156, 0.0, 2.0, null, null, null, 0.0, null, 1.0, null, 7.721099188707185, 0.0, null, 6.409390936137702, 3.700439718141092, 4.906890595608519, 3.0, 3.0, 2.0, 2.321928094887362, 4.169925001442312, 2.807354922057604, 4.584962500721156, 3.807354922057604, 9.957102041562287, 4.643856189774724, null, 7.459431618637297, 5.0, 6.6293566200796095, 5.247927513443585, 5.247927513443585, 5.20945336562895, 5.672425341971495, 5.247927513443585, 5.044394119358453, 6.169925001442312, 5.459431618637297, 10.949097155729207, 6.491853096329675, null, 0.0, null, null, null, null, null, null, null, null, null, null, 1.584962500721156, null, 2.0, 8.005624549193879, 5.426264754702098, 6.78135971352466, 5.491853096329675, 4.954196310386875, 4.857980995127572, 5.78135971352466, 5.169925001442312, 5.321928094887363, 5.426264754702098, 5.0, 10.98299357469431, 6.906890595608519, null, null, null, null, null, null, null, 0.0, null, null, null, null, 3.0, null, 2.0, 8.59618975614441, 6.066089190457772, 7.794415866350106, 6.149747119504682, 5.930737337562887, 5.906890595608519, 6.672425341971495, 6.303780748177103, 5.906890595608519, 6.918863237274595, 5.977279923499917, 11.77313920671969, 7.584962500721156, 2.584962500721156, 8.531381460516313, 6.022367813028454, 7.076815597050831, 5.882643049361842, 5.906890595608519, 5.882643049361842, 6.409390936137702, 6.022367813028454, 4.459431618637297, 6.266786540694901, 6.247927513443585, 11.766528908598865, 7.247927513443585, 1.0, 7.562242424221073, 4.584962500721156, 6.392317422778761, 5.285402218862249, 4.643856189774724, 5.169925001442312, 5.321928094887363, 5.357552004618084, 4.392317422778761, 5.643856189774724, 5.247927513443585, 10.767356854125685, 6.754887502163468, null, 6.918863237274595, 4.321928094887363, 5.044394119358453, 4.584962500721156, 4.0, 4.584962500721156, 4.754887502163468, 4.169925001442312, 3.321928094887362, 5.584962500721156, 4.807354922057604, 10.641148597411233, 6.022367813028454, 2.321928094887362, 8.515699838284043, 5.857980995127572, 7.787902559391432, 7.2384047393250786, 6.108524456778169, 7.219168520462161, 7.60733031374961, 6.357552004618084, 6.507794640198696, 8.29920801838728, 7.285402218862249, 10.97513145692134, 8.144658242831882, 0.0, 4.0, 1.584962500721156, 2.584962500721156, 2.321928094887362, 1.0, 1.0, 0.0, 4.169925001442312, null, 4.392317422778761, 2.0, 8.717676423066395, 1.0, null, 4.321928094887363, 2.0, 2.807354922057604, 3.0, 0.0, 0.0, 1.584962500721156, 2.807354922057604, 1.0, null, null, 8.59245703726808, 2.584962500721156, null, 0.0, null, null, null, null, null, null, null, null, null, null, null, 0.0, 2.321928094887362, 6.930737337562887, 4.523561956057013, 5.906890595608519, 4.523561956057013, 4.643856189774724, 4.392317422778761, 5.169925001442312, 5.392317422778761, 3.0, 5.169925001442312, 4.087462841250339, 10.542064542283443, 6.022367813028454, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 1.0, 6.977279923499917, 4.807354922057604, 5.554588851677638, 5.321928094887363, 4.857980995127572, 4.754887502163468, 6.022367813028454, 3.0, 4.169925001442312, 4.321928094887363, 4.700439718141092, 9.79603960882977, 5.930737337562887, 1.0, 7.3750394313469245, 4.906890595608519, 5.857980995127572, 4.954196310386875, 5.044394119358453, 5.044394119358453, 5.491853096329675, 3.807354922057604, 4.700439718141092, 4.807354922057604, 5.584962500721156, 9.854868383260236, 6.584962500721156, null, 7.820178962415188, 5.807354922057604, 6.894817763307944, 5.554588851677638, 5.584962500721156, 5.78135971352466, 6.6293566200796095, 4.169925001442312, 5.247927513443585, 5.392317422778761, 5.392317422778761, 10.591522346570734, 7.199672344836364, 0.0, 7.507794640198696, 5.087462841250339, 6.3750394313469245, 5.554588851677638, 5.129283016944966, 5.285402218862249, 5.614709844115208, 2.807354922057604, 4.523561956057013, 4.857980995127572, 5.584962500721156, 9.981567281903015, 6.584962500721156, 1.584962500721156, 6.539158811108031, 4.906890595608519, 6.6865005271832185, 5.285402218862249, 5.129283016944966, 4.643856189774724, 5.954196310386875, 4.584962500721156, 4.321928094887363, 4.523561956057013, 4.321928094887363, 9.943979914343739, 6.392317422778761, 0.0, 7.366322214245816, 4.459431618637297, 6.459431618637297, 3.9068905956085187, 5.20945336562895, 4.523561956057013, 5.584962500721156, 3.169925001442312, 4.247927513443585, 3.169925001442312, 3.807354922057604, 8.88264304936184, 5.832890014164741, null, 7.139551352398794, 4.523561956057013, 6.108524456778169, 5.087462841250339, 4.700439718141092, 4.906890595608519, 5.78135971352466, 3.169925001442312, 3.584962500721156, 5.044394119358453, 5.129283016944966, 9.967226258835993, 6.426264754702098, 1.0, 7.554588851677638, 5.832890014164741, 6.727920454563199, 5.523561956057013, 5.426264754702098, 5.700439718141092, 6.169925001442312, 4.0, 5.0, 4.392317422778761, 5.700439718141092, 10.493855449240822, 6.965784284662087, null, null, null, null, 0.0, 0.0, null, null, null, 0.0, 0.0, null, 3.584962500721156, null, 0.0, 7.434628227636725, 5.044394119358453, 5.700439718141092, 5.357552004618084, 4.643856189774724, 5.0, 5.044394119358453, 1.584962500721156, 5.169925001442312, 4.321928094887363, 5.700439718141092, 10.071462362556623, 6.614709844115208, 1.584962500721156, 6.475733430966398, 4.523561956057013, 5.459431618637297, 4.392317422778761, 4.321928094887363, 4.169925001442312, 5.426264754702098, 0.0, 2.321928094887362, 3.9068905956085187, 4.0, 9.469641817239516, 6.129283016944966, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, 6.918863237274595, 3.584962500721156, 6.321928094887363, 4.700439718141092, 4.0, 4.906890595608519, 5.169925001442312, 3.700439718141092, 3.0, 4.169925001442312, 4.700439718141092, 9.152284842306582, 6.0, null, 7.734709620225838, 5.285402218862249, 6.339850002884624, 4.906890595608519, 5.459431618637297, 5.20945336562895, 5.954196310386875, 4.459431618637297, 4.906890595608519, 4.906890595608519, 5.087462841250339, 10.158609688214478, 6.954196310386875, 2.321928094887362, 7.924812503605781, 5.169925001442312, 6.741466986401147, 5.285402218862249, 5.523561956057013, 5.700439718141092, 6.108524456778169, 4.169925001442312, 4.321928094887363, 5.0, 5.0, 10.231221180711186, 7.044394119358453, 1.0, 8.071462362556623, 6.569855608330948, 7.139551352398794, 5.832890014164741, 5.807354922057604, 6.108524456778169, 6.6865005271832185, 5.491853096329675, 5.087462841250339, 6.189824558880018, 6.189824558880018, 11.162391328756906, 7.507794640198696, 1.584962500721156, 7.087462841250339, 5.087462841250339, 6.189824558880018, 4.523561956057013, 4.643856189774724, 4.754887502163468, 5.727920454563199, 4.169925001442312, 4.169925001442312, 4.857980995127572, 5.0, 9.968666793195208, 6.539158811108031, null, 4.523561956057013, 3.0, 3.807354922057604, 2.807354922057604, 1.0, 2.0, 2.321928094887362, 1.584962500721156, 2.0, 3.0, 3.807354922057604, 8.129283016944967, 4.087462841250339, 0.0, 8.049848549450562, 5.584962500721156, 6.857980995127572, 5.857980995127572, 5.727920454563199, 5.727920454563199, 6.044394119358453, 4.169925001442312, 5.392317422778761, 5.129283016944966, 6.22881869049588, 10.306061689428342, 7.60733031374961, 1.0, 6.599912842187128, 4.247927513443585, 4.169925001442312, 3.584962500721156, 3.4594316186372973, 3.9068905956085187, 4.906890595608519, 2.584962500721156, 3.807354922057604, 2.321928094887362, 3.9068905956085187, 9.319672120946995, 5.523561956057013, null, null, null, 1.0, null, null, null, null, null, null, null, null, 2.584962500721156, null, 2.0, 6.918863237274595, 4.321928094887363, 5.554588851677638, 4.807354922057604, 4.857980995127572, 4.0, 5.129283016944966, 3.807354922057604, 4.169925001442312, 4.0, 4.754887502163468, 9.426264754702098, 6.459431618637297, 1.584962500721156, 7.6653359171851765, 5.727920454563199, 5.977279923499917, 4.954196310386875, 4.392317422778761, 5.321928094887363, 5.832890014164741, 2.807354922057604, 4.584962500721156, 4.906890595608519, 5.321928094887363, 10.157346935362844, 7.066089190457772, 0.0, 6.285402218862249, 3.4594316186372973, 5.807354922057604, 3.584962500721156, 2.584962500721156, 3.700439718141092, 4.247927513443585, 4.087462841250339, 3.807354922057604, 3.584962500721156, 2.321928094887362, 8.79766152585376, 5.285402218862249, null, 6.965784284662087, 4.906890595608519, 6.149747119504682, 4.700439718141092, 4.584962500721156, 4.247927513443585, 5.554588851677638, 1.0, 4.584962500721156, 5.044394119358453, 4.807354922057604, 10.00982861736811, 6.303780748177103, 2.584962500721156, 7.977279923499917, 5.169925001442312, 7.0, 5.523561956057013, 5.491853096329675, 5.523561956057013, 6.409390936137702, 4.459431618637297, 5.169925001442312, 4.523561956057013, 5.700439718141092, 10.11504365016171, 7.539158811108031, null, null, null, null, null, null, 0.0, null, null, null, null, null, 1.584962500721156, null, 8.562242424221072, 8.768184324776927, 7.539158811108031, 7.569855608330948, 6.426264754702098, 6.149747119504682, 7.129283016944966, 7.774787059601174, 8.475733430966399, 6.475733430966398, 8.625708843064466, 6.94251450533924, 5.0, 7.826548487290915, 8.89178370321831, 7.149747119504682, 7.257387842692652, 5.426264754702098, 4.807354922057604, 4.392317422778761, 5.977279923499917, 5.523561956057013, 6.285402218862249, 4.584962500721156, 7.22881869049588, 4.857980995127572, 4.584962500721156, 7.0, 9.139551352398794, 8.344295907915816, 7.247927513443585, 7.118941072723508, 5.78135971352466, 5.930737337562887, 6.539158811108031, 6.918863237274595, 7.857980995127572, 5.754887502163468, 7.700439718141092, 6.78135971352466, 1.584962500721156, 7.219168520462161, 7.118941072723508, 6.392317422778761, 4.954196310386875, 4.584962500721156, 4.087462841250339, 3.169925001442312, 3.700439718141092, 4.459431618637297, 5.954196310386875, 4.169925001442312, 5.491853096329675, 4.392317422778761, 2.807354922057604, 5.044394119358453, 8.651051691178928, 8.50382573799575, 6.754887502163468, 6.78135971352466, 5.857980995127572, 5.700439718141092, 6.321928094887363, 6.303780748177103, 7.7615512324444795, 5.321928094887363, 8.087462841250339, 6.339850002884624, 4.321928094887363, 6.906890595608519, 8.46352437327118, 7.727920454563199, 6.882643049361842, 6.906890595608519, 4.857980995127572, 5.285402218862249, 5.554588851677638, 6.820178962415188, 5.392317422778761, 5.643856189774724, 6.459431618637297, 5.700439718141092, 4.643856189774724, 7.087462841250339, null, 5.857980995127572, 0.0, 3.169925001442312, null, 5.857980995127572, 3.321928094887362, 6.266786540694901, null, 4.906890595608519, null, 2.0, null, 0.0, 7.357552004618084, 7.845490050944375, 5.78135971352466, 5.643856189774724, 4.459431618637297, 4.087462841250339, 5.554588851677638, 4.643856189774724, 6.569855608330948, 3.700439718141092, 7.03342300153745, 5.044394119358453, 2.584962500721156, 5.906890595608519, 1.0, null, null, 1.0, 0.0, null, null, null, null, 0.0, 1.584962500721156, null, 2.0, null, 6.569855608330948, 7.169925001442312, 5.285402218862249, 5.754887502163468, 5.129283016944966, 4.459431618637297, 5.129283016944966, 5.700439718141092, 6.672425341971495, 4.459431618637297, 6.108524456778169, 4.584962500721156, 2.321928094887362, 5.954196310386875, 7.3750394313469245, 6.507794640198696, 5.672425341971495, 5.044394119358453, 3.807354922057604, 4.807354922057604, 5.584962500721156, 5.643856189774724, 4.754887502163468, 4.087462841250339, 4.906890595608519, 5.285402218862249, 3.700439718141092, 6.087462841250339, 8.39231742277876, 8.430452551665532, 6.475733430966398, 6.321928094887363, 5.554588851677638, 5.426264754702098, 6.321928094887363, 6.442943495848728, 7.011227255423254, 5.584962500721156, 7.044394119358453, 6.20945336562895, 1.584962500721156, 6.894817763307944, 1.0, 8.479780264029099, 6.539158811108031, 7.348728154231077, 6.108524456778169, 6.426264754702098, 6.94251450533924, 7.442943495848728, 7.442943495848728, 6.643856189774724, 7.475733430966398, 6.392317422778761, 3.169925001442312, 7.679480099505446, 10.116343961237469, 9.29920801838728, 8.422064766172813, 8.087462841250339, 6.569855608330948, 6.965784284662087, 7.679480099505446, 8.400879436282183, 7.94251450533924, 7.523561956057013, 8.451211111832329, 7.189824558880018, 4.807354922057604, 8.417852514885897, 9.0, 8.118941072723507, 7.22881869049588, 6.894817763307944, 5.954196310386875, 5.857980995127572, 6.845490050944375, 7.266786540694901, 7.392317422778761, 6.339850002884624, 7.321928094887363, 6.247927513443585, 2.584962500721156, 7.366322214245816, 8.405141463136344, 7.149747119504682, 7.129283016944966, 5.754887502163468, 4.584962500721156, 4.169925001442312, 3.807354922057604, 5.554588851677638, 6.087462841250339, 3.807354922057604, 6.491853096329675, 3.4594316186372973, 2.584962500721156, 6.539158811108031, 8.479780264029099, 7.954196310386875, 6.022367813028454, 6.426264754702098, 5.523561956057013, 4.754887502163468, 5.807354922057604, 5.426264754702098, 6.845490050944375, 4.0, 6.700439718141092, 5.954196310386875, 3.321928094887362, 6.189824558880018, 10.151016538892248, 9.634811050171718, 8.62935662007961, 8.46352437327118, 6.714245517666122, 6.658211482751795, 7.918863237274595, 7.721099188707185, 8.622051819456376, 7.219168520462161, 8.640244936222345, 7.6293566200796095, 2.807354922057604, 8.434628227636725, 8.618385502258606, 9.022367813028454, 7.330916878114617, 7.857980995127572, 6.584962500721156, 6.169925001442312, 7.118941072723508, 7.442943495848728, 7.451211111832329, 6.321928094887363, 8.060695931687555, 6.20945336562895, 3.169925001442312, 7.7481928495894605, 5.857980995127572, 7.400879436282184, 5.285402218862249, 5.643856189774724, 4.700439718141092, 2.584962500721156, 4.700439718141092, 4.321928094887363, 6.169925001442312, 2.321928094887362, 6.820178962415188, 4.857980995127572, 3.0, 5.285402218862249, null, null, null, 1.584962500721156, null, null, null, null, null, 1.0, null, 0.0, 0.0, null, 7.936637939002571, 8.199672344836364, 6.321928094887363, 6.754887502163468, 5.643856189774724, 5.392317422778761, 6.149747119504682, 6.459431618637297, 7.294620748891627, 5.807354922057604, 7.247927513443585, 5.614709844115208, 1.584962500721156, 6.882643049361842, 8.974414589805527, 8.618385502258606, 7.3750394313469245, 7.531381460516312, 6.189824558880018, 5.614709844115208, 6.599912842187128, 7.05528243550119, 7.882643049361842, 5.700439718141092, 8.005624549193879, 6.087462841250339, 2.0, 7.219168520462161, 8.179909090014934, 8.174925682500678, 6.392317422778761, 6.22881869049588, 5.727920454563199, 3.321928094887362, 5.727920454563199, 5.129283016944966, 6.954196310386875, 4.0, 7.129283016944966, 5.247927513443585, 4.584962500721156, 5.954196310386875, 5.857980995127572, 8.011227255423254, 4.459431618637297, 7.531381460516312, 3.700439718141092, 4.0, 6.741466986401147, 5.0, 3.0, 4.0, 4.459431618637297, 6.6865005271832185, null, 4.643856189774724, 7.900866807980749, 8.071462362556623, 6.108524456778169, 5.954196310386875, 6.022367813028454, 4.954196310386875, 5.727920454563199, 5.459431618637297, 7.044394119358453, 4.321928094887363, 7.011227255423254, 6.087462841250339, 3.9068905956085187, 6.087462841250339, 6.94251450533924, 7.721099188707185, 5.087462841250339, 5.857980995127572, 5.087462841250339, 4.459431618637297, 5.169925001442312, 5.832890014164741, 7.076815597050831, 5.044394119358453, 6.108524456778169, 4.392317422778761, 1.584962500721156, 5.882643049361842, 10.320800548881637, 9.41574176829009, 8.79766152585376, 8.103287808412022, 7.149747119504682, 7.392317422778761, 7.6293566200796095, 8.271463027904375, 8.507794640198696, 7.539158811108031, 8.312882955284355, 7.348728154231077, 5.087462841250339, 8.413627929024173, 8.087462841250339, 8.467605550082997, 6.266786540694901, 7.05528243550119, 6.087462841250339, 6.108524456778169, 6.599912842187128, 6.94251450533924, 7.693486957499325, 6.066089190457772, 7.3750394313469245, 6.569855608330948, 4.523561956057013, 7.266786540694901, 7.577428828035749, 8.103287808412022, 6.247927513443585, 6.539158811108031, 5.672425341971495, 5.169925001442312, 6.357552004618084, 6.285402218862249, 6.954196310386875, 5.357552004618084, 7.321928094887363, 5.357552004618084, 3.584962500721156, 6.754887502163468, 7.820178962415188, 8.379378367071261, 6.807354922057604, 6.6293566200796095, 5.700439718141092, 5.20945336562895, 6.475733430966398, 6.78135971352466, 7.312882955284356, 4.807354922057604, 7.339850002884624, 6.339850002884624, 3.169925001442312, 6.714245517666122, 6.882643049361842, 7.6293566200796095, 5.554588851677638, 5.832890014164741, 4.857980995127572, 4.087462841250339, 6.022367813028454, 5.584962500721156, 6.820178962415188, 4.0, 6.894817763307944, 5.169925001442312, 3.9068905956085187, 5.906890595608519, null, null, 0.0, 0.0, null, null, null, 0.0, null, null, 0.0, 1.0, 2.584962500721156, null, 8.280770770130603, 7.78135971352466, 6.599912842187128, 6.044394119358453, 4.754887502163468, 4.321928094887363, 5.614709844115208, 6.066089190457772, 6.672425341971495, 5.044394119358453, 6.741466986401147, 5.20945336562895, null, 6.554588851677638, 7.434628227636725, 8.632995197142957, 6.3750394313469245, 6.614709844115208, 5.954196310386875, 4.0, 5.906890595608519, 5.614709844115208, 7.569855608330948, 4.392317422778761, 7.636624620543649, 5.584962500721156, 2.321928094887362, 6.392317422778761, 7.2761244052742375, 7.794415866350106, 5.807354922057604, 6.266786540694901, 3.321928094887362, 4.857980995127572, 5.321928094887363, 5.426264754702098, 6.6293566200796095, 4.459431618637297, 6.459431618637297, 4.169925001442312, 2.0, 5.672425341971495, 9.519636252843213, 9.537218400538595, 8.614709844115207, 8.857980995127573, 7.417852514885898, 7.727920454563199, 7.960001932068081, 8.679480099505446, 7.857980995127572, 7.936637939002571, 8.271463027904375, 7.330916878114617, 3.4594316186372973, 9.025139562278508, 7.9886846867721655, 7.562242424221073, 6.78135971352466, 6.22881869049588, 5.169925001442312, 4.954196310386875, 6.169925001442312, 5.643856189774724, 6.303780748177103, 5.0, 6.845490050944375, 5.247927513443585, 3.321928094887362, 6.108524456778169, 9.224001674198105, 8.870364719583405, 7.78135971352466, 7.693486957499325, 5.857980995127572, 6.108524456778169, 6.918863237274595, 7.0, 7.78135971352466, 6.129283016944966, 7.459431618637297, 6.20945336562895, 3.4594316186372973, 7.569855608330948, 9.887220615468385, 8.854868383260236, 8.124121311829187, 7.189824558880018, 6.6865005271832185, 6.672425341971495, 7.189824558880018, 7.584962500721156, 7.392317422778761, 6.599912842187128, 8.124121311829187, 6.643856189774724, 3.0, 7.78135971352466, 8.459431618637296, 8.573647187493322, 7.20945336562895, 7.247927513443585, 5.882643049361842, 6.20945336562895, 7.285402218862249, 7.622051819456376, 7.442943495848728, 6.392317422778761, 7.531381460516312, 6.906890595608519, 4.0, 7.679480099505446, 8.948367231584678, 8.271463027904375, 6.9886846867721655, 7.0, 5.672425341971495, 5.285402218862249, 6.614709844115208, 6.409390936137702, 7.3750394313469245, 4.954196310386875, 7.098032082960526, 6.129283016944966, 2.584962500721156, 7.011227255423254, 8.550746785383243, 9.03342300153745, 7.2384047393250786, 7.266786540694901, 6.357552004618084, 6.491853096329675, 7.366322214245816, 7.7615512324444795, 7.924812503605781, 6.266786540694901, 8.108524456778168, 7.285402218862249, 3.321928094887362, 8.049848549450562, 6.3750394313469245, 7.584962500721156, 5.491853096329675, 6.247927513443585, 4.584962500721156, 4.0, 4.754887502163468, 5.087462841250339, 6.459431618637297, 3.169925001442312, 6.266786540694901, 3.4594316186372973, 5.357552004618084, 5.321928094887363, null, null, null, null, null, null, null, null, null, 1.0, 2.0, null, 0.0, null, 9.324180546618742, 8.78135971352466, 7.794415866350106, 7.149747119504682, 6.303780748177103, 5.584962500721156, 7.076815597050831, 7.149747119504682, 8.124121311829187, 5.643856189774724, 8.154818109052105, 7.022367813028454, 2.584962500721156, 7.459431618637297, 8.588714635582264, 8.139551352398794, 6.78135971352466, 6.442943495848728, 5.392317422778761, 5.321928094887363, 6.0, 6.22881869049588, 7.011227255423254, 5.285402218862249, 7.05528243550119, 5.727920454563199, 3.169925001442312, 6.714245517666122, 8.144658242831882, 8.74819284958946, 6.906890595608519, 6.700439718141092, 6.22881869049588, 5.754887502163468, 6.507794640198696, 6.392317422778761, 7.6293566200796095, 5.977279923499917, 8.285402218862249, 6.087462841250339, 3.0, 7.044394119358453, 5.20945336562895, 7.700439718141092, 4.523561956057013, 5.954196310386875, 5.392317422778761, 4.523561956057013, 5.491853096329675, 5.78135971352466, 5.78135971352466, 3.584962500721156, 6.392317422778761, 4.906890595608519, 2.0, 6.149747119504682, 5.882643049361842, 6.6293566200796095, 4.906890595608519, 4.523561956057013, 4.523561956057013, 3.321928094887362, 4.169925001442312, 5.044394119358453, 5.614709844115208, 3.321928094887362, 4.459431618637297, 3.584962500721156, 4.169925001442312, 4.523561956057013, 9.912889336229961, 8.912889336229961, 8.388017285345136, 7.475733430966398, 6.3750394313469245, 6.149747119504682, 7.383704292474052, 7.700439718141092, 7.845490050944375, 6.78135971352466, 8.060695931687555, 6.78135971352466, 4.700439718141092, 8.066089190457772, 8.276124405274238, 8.707359132080883, 7.098032082960526, 6.584962500721156, 5.807354922057604, 5.832890014164741, 6.94251450533924, 7.044394119358453, 7.257387842692652, 5.285402218862249, 7.787902559391432, 5.832890014164741, 2.584962500721156, 7.199672344836364, 6.6293566200796095, 7.515699838284043, 5.554588851677638, 5.392317422778761, 5.426264754702098, 4.247927513443585, 5.129283016944966, 5.169925001442312, 6.108524456778169, 4.584962500721156, 6.426264754702098, 5.554588851677638, 3.0, 6.066089190457772, 8.98299357469431, 8.49585502688717, 7.285402218862249, 6.569855608330948, 5.954196310386875, 5.392317422778761, 6.6865005271832185, 6.491853096329675, 7.118941072723508, 5.459431618637297, 6.857980995127572, 6.459431618637297, 5.129283016944966, 7.087462841250339, 8.851749041416058, 8.778077129535358, 7.118941072723508, 6.672425341971495, 5.727920454563199, 4.584962500721156, 5.857980995127572, 6.044394119358453, 8.044394119358454, 5.554588851677638, 7.357552004618084, 5.727920454563199, 2.0, 6.714245517666122, 7.294620748891627, 7.499845887083206, 5.554588851677638, 5.357552004618084, 4.643856189774724, 2.0, 4.807354922057604, 5.0, 6.820178962415188, 3.807354922057604, 6.108524456778169, 4.169925001442312, 2.0, 5.0, 0.0, null, 0.0, 0.0, 0.0, 0.0, null, null, null, 0.0, 0.0, 0.0, 2.0, null, 9.44086916761087, 8.945443836377912, 7.7073591320808825, 7.044394119358453, 6.285402218862249, 6.285402218862249, 6.754887502163468, 7.087462841250339, 8.098032082960527, 6.066089190457772, 8.228818690495881, 6.108524456778169, 3.0, 7.562242424221073, 7.994353436858858, 8.108524456778168, 6.357552004618084, 6.491853096329675, 5.20945336562895, 4.754887502163468, 6.022367813028454, 6.087462841250339, 7.129283016944966, 5.321928094887363, 7.257387842692652, 4.807354922057604, 3.0, 6.459431618637297, 8.467605550082997, 8.204571144249204, 6.741466986401147, 6.189824558880018, 5.584962500721156, 5.247927513443585, 6.0, 5.727920454563199, 7.189824558880018, 4.857980995127572, 7.139551352398794, 5.392317422778761, 3.0, 6.584962500721156, 3.4594316186372973, 9.276124405274238, 7.159871336778389, 8.087462841250339, 6.807354922057604, 6.714245517666122, 7.622051819456376, 7.900866807980749, 7.845490050944375, 7.257387842692652, 8.20945336562895, 7.03342300153745, 3.700439718141092, 8.199672344836364, 9.505811553919594, 8.906890595608518, 7.807354922057604, 7.03342300153745, 6.044394119358453, 6.357552004618084, 6.266786540694901, 7.266786540694901, 7.839203788096944, 6.807354922057604, 7.467605550082998, 6.189824558880018, 4.523561956057013, 7.05528243550119, 10.857203471508166, 9.698704666770345, 9.556506054671928, 8.357552004618084, 6.930737337562887, 7.826548487290915, 8.247927513443585, 9.219168520462162, 8.03342300153745, 7.60733031374961, 7.7481928495894605, 7.118941072723508, 3.9068905956085187, 8.86418614465428, 8.550746785383243, 8.308339030139408, 7.199672344836364, 6.3750394313469245, 4.700439718141092, 4.392317422778761, 5.426264754702098, 6.554588851677638, 6.189824558880018, 5.727920454563199, 6.066089190457772, 5.321928094887363, 3.4594316186372973, 6.741466986401147, 4.247927513443585, 3.4594316186372973, 3.321928094887362, 1.0, 2.0, 0.0, null, null, 3.321928094887362, null, 3.807354922057604, null, null, null, 10.303780748177102, 9.417852514885897, 8.936637939002571, 7.820178962415188, 6.768184324776926, 7.066089190457772, 7.592457037268081, 8.011227255423254, 8.087462841250339, 7.247927513443585, 8.682994583681683, 7.321928094887363, 2.0, 8.224001674198105, 6.727920454563199, 7.348728154231077, 5.129283016944966, 5.554588851677638, 4.857980995127572, 4.087462841250339, 4.392317422778761, 4.523561956057013, 6.303780748177103, 4.643856189774724, 6.857980995127572, 4.459431618637297, 1.584962500721156, 5.491853096329675, 8.876516946565, 8.31741261376487, 7.20945336562895, 6.22881869049588, 5.977279923499917, 5.285402218862249, 6.20945336562895, 6.569855608330948, 6.977279923499917, 5.129283016944966, 6.906890595608519, 6.044394119358453, 2.0, 6.741466986401147, null, null, null, 0.0, null, 0.0, null, null, 0.0, null, null, null, 2.321928094887362, null, 7.3750394313469245, 6.523561956057013, 5.614709844115208, 5.247927513443585, 4.459431618637297, 4.392317422778761, 4.807354922057604, 5.643856189774724, 5.169925001442312, 4.169925001442312, 5.321928094887363, 4.857980995127572, 2.321928094887362, 5.426264754702098, 8.965784284662087, 8.199672344836364, 7.1799090900149345, 7.451211111832329, 5.857980995127572, 5.672425341971495, 6.459431618637297, 7.199672344836364, 6.906890595608519, 6.247927513443585, 6.459431618637297, 6.672425341971495, 2.584962500721156, 7.159871336778389, 8.562242424221072, 7.714245517666122, 6.700439718141092, 6.6293566200796095, 5.044394119358453, 5.700439718141092, 5.672425341971495, 6.857980995127572, 5.321928094887363, 4.754887502163468, 5.643856189774724, 5.78135971352466, 2.0, 6.6293566200796095, 3.807354922057604, 9.49585502688717, 8.03342300153745, 8.703903573444663, 7.257387842692652, 7.592457037268081, 8.483815777264256, 9.025139562278508, 8.164906926675688, 8.224001674198105, 7.906890595608519, 7.562242424221073, 4.523561956057013, 9.100662339005199, 9.394462694610317, 9.64565843240871, 8.366322214245816, 7.768184324776926, 6.569855608330948, 7.118941072723508, 7.794415866350106, 8.447083226209653, 7.554588851677638, 7.734709620225838, 7.366322214245816, 7.409390936137702, 3.584962500721156, 8.546894459887637, 10.61194694181998, 9.786269627648466, 9.250298417906333, 8.285402218862249, 6.882643049361842, 8.43879185257826, 8.164906926675688, 9.233619676759702, 7.882643049361842, 7.7615512324444795, 7.022367813028454, 7.888743248898259, 4.087462841250339, 8.727920454563199, 9.605479518061669, 9.079484783826816, 8.366322214245816, 7.507794640198696, 6.20945336562895, 6.6865005271832185, 7.149747119504682, 7.592457037268081, 6.727920454563199, 6.794415866350106, 6.507794640198696, 6.768184324776926, 3.169925001442312, 7.882643049361842, 8.778077129535358, 9.20212382383046, 7.918863237274595, 7.643856189774724, 6.6293566200796095, 6.78135971352466, 7.409390936137702, 7.864186144654281, 6.894817763307944, 6.475733430966398, 7.098032082960526, 6.954196310386875, 1.584962500721156, 8.20945336562895, 9.319672120946995, 8.800899899920305, 8.169925001442312, 7.366322214245816, 6.247927513443585, 6.507794640198696, 7.087462841250339, 7.592457037268081, 6.507794640198696, 6.599912842187128, 6.523561956057013, 6.894817763307944, 3.584962500721156, 7.864186144654281, 9.51175265376738, 8.721099188707186, 8.108524456778168, 7.219168520462161, 5.78135971352466, 6.129283016944966, 6.741466986401147, 7.348728154231077, 6.475733430966398, 6.321928094887363, 6.409390936137702, 6.820178962415188, 2.584962500721156, 7.7481928495894605, 7.562242424221073, 7.845490050944375, 6.475733430966398, 6.507794640198696, 5.285402218862249, 5.0, 5.954196310386875, 6.303780748177103, 5.807354922057604, 5.357552004618084, 5.0, 5.672425341971495, 3.169925001442312, 6.3750394313469245, null, null, null, 0.0, null, null, null, 0.0, null, 0.0, null, null, 1.0, null, 8.271463027904375, 7.700439718141092, 6.754887502163468, 6.357552004618084, 4.459431618637297, 5.700439718141092, 6.303780748177103, 6.357552004618084, 5.754887502163468, 5.392317422778761, 5.459431618637297, 5.614709844115208, 2.0, 6.918863237274595, 8.228818690495881, 8.475733430966399, 7.066089190457772, 7.434628227636725, 6.044394119358453, 5.426264754702098, 6.658211482751795, 7.303780748177103, 6.169925001442312, 6.189824558880018, 6.426264754702098, 5.700439718141092, 4.247927513443585, 7.383704292474052, 7.622051819456376, 7.03342300153745, 6.149747119504682, 5.906890595608519, 4.523561956057013, 4.643856189774724, 5.523561956057013, 5.672425341971495, 5.20945336562895, 3.9068905956085187, 4.754887502163468, 5.044394119358453, 2.0, 5.954196310386875, 10.79603960882977, 9.7714894695006, 9.523561956057012, 8.997179480937621, 7.864186144654281, 8.169925001442312, 8.710806433699352, 9.326429487122303, 8.599912842187127, 8.467605550082997, 7.888743248898259, 8.344295907915816, 4.459431618637297, 9.449148645375436, 8.39231742277876, 7.882643049361842, 7.2384047393250786, 6.459431618637297, 4.523561956057013, 5.426264754702098, 6.22881869049588, 6.523561956057013, 5.857980995127572, 5.807354922057604, 6.0, 5.643856189774724, 3.807354922057604, 7.0, 9.377210530388552, 9.20945336562895, 7.876516946564999, 7.954196310386875, 6.845490050944375, 6.906890595608519, 7.754887502163468, 8.219168520462162, 6.9886846867721655, 7.219168520462161, 7.832890014164741, 7.339850002884624, 3.9068905956085187, 8.523561956057012, 9.709083812550343, 8.700439718141093, 8.238404739325079, 7.118941072723508, 5.906890595608519, 6.94251450533924, 7.199672344836364, 7.807354922057604, 6.977279923499917, 6.392317422778761, 6.357552004618084, 6.906890595608519, 3.321928094887362, 7.562242424221073, 9.682994583681683, 8.909893083770042, 8.092757140919852, 7.05528243550119, 5.832890014164741, 6.6865005271832185, 7.366322214245816, 7.700439718141092, 6.727920454563199, 6.087462841250339, 7.05528243550119, 6.906890595608519, 3.584962500721156, 8.108524456778168, null, 1.584962500721156, null, 1.0, null, null, 1.0, 1.0, 0.0, null, null, null, null, 1.0, 7.832890014164741, 8.233619676759702, 6.882643049361842, 6.741466986401147, 5.459431618637297, 5.930737337562887, 6.0, 7.312882955284356, 6.392317422778761, 6.303780748177103, 6.459431618637297, 6.442943495848728, 3.321928094887362, 7.266786540694901, 6.918863237274595, 5.672425341971495, 5.169925001442312, 4.954196310386875, 2.807354922057604, 3.321928094887362, 4.700439718141092, 5.129283016944966, 5.129283016944966, 4.584962500721156, 4.906890595608519, 3.9068905956085187, 2.807354922057604, 5.584962500721156, null, null, null, null, null, null, null, null, null, null, null, null, 0.0, null, 7.467605550082998, 7.807354922057604, 6.321928094887363, 6.507794640198696, 5.087462841250339, 5.643856189774724, 6.3750394313469245, 6.882643049361842, 6.0, 5.426264754702098, 6.0, 5.906890595608519, 3.807354922057604, 7.0, 9.041659151637214, 7.800899899920305, 7.0, 6.768184324776926, 5.491853096329675, 5.882643049361842, 6.523561956057013, 7.189824558880018, 6.285402218862249, 5.882643049361842, 6.507794640198696, 6.20945336562895, 2.321928094887362, 7.339850002884624, 5.584962500721156, 5.0, 4.247927513443585, 3.4594316186372973, 1.0, 3.0, 3.169925001442312, 2.584962500721156, 3.0, 2.584962500721156, 3.4594316186372973, 2.321928094887362, 2.0, 3.321928094887362, 8.965784284662087, 8.483815777264256, 7.219168520462161, 7.491853096329675, 6.3750394313469245, 5.954196310386875, 6.584962500721156, 6.392317422778761, 7.845490050944375, 5.087462841250339, 8.375039431346925, 6.247927513443585, 2.807354922057604, 7.348728154231077, 8.353146825498083, 8.224001674198105, 7.357552004618084, 6.614709844115208, 6.066089190457772, 5.882643049361842, 6.022367813028454, 6.78135971352466, 7.03342300153745, 4.857980995127572, 7.693486957499325, 5.727920454563199, 1.584962500721156, 7.257387842692652, 8.558420713268664, 8.144658242831882, 7.169925001442312, 6.614709844115208, 5.672425341971495, 4.643856189774724, 5.614709844115208, 6.044394119358453, 6.727920454563199, 4.906890595608519, 6.807354922057604, 6.066089190457772, 3.584962500721156, 6.442943495848728, 6.918863237274595, 7.60733031374961, 6.022367813028454, 6.339850002884624, 5.426264754702098, 4.807354922057604, 5.523561956057013, 5.584962500721156, 6.303780748177103, 4.700439718141092, 6.714245517666122, 4.523561956057013, 3.169925001442312, 6.20945336562895, 8.64745842645492, 8.588714635582264, 7.05528243550119, 6.20945336562895, 5.754887502163468, 5.727920454563199, 6.303780748177103, 6.392317422778761, 7.523561956057013, 5.584962500721156, 7.98299357469431, 6.247927513443585, 1.584962500721156, 6.845490050944375, 8.960001932068081, 7.948367231584678, 7.426264754702098, 6.870364719583405, 6.066089190457772, 5.882643049361842, 6.303780748177103, 6.870364719583405, 6.491853096329675, 5.930737337562887, 6.189824558880018, 5.614709844115208, 3.807354922057604, 7.266786540694901, null, 7.820178962415188, null, 5.727920454563199, 2.321928094887362, 7.129283016944966, 5.857980995127572, 8.098032082960527, 0.0, 7.20945336562895, null, 5.392317422778761, null, 2.0, 8.243173983472952, 9.095397022792557, 7.294620748891627, 7.515699838284043, 6.339850002884624, 6.087462841250339, 7.087462841250339, 7.339850002884624, 8.169925001442312, 5.754887502163468, 8.118941072723507, 7.0, 1.584962500721156, 7.636624620543649, 9.832890014164741, 8.906890595608518, 8.741466986401146, 7.531381460516312, 6.807354922057604, 7.03342300153745, 7.400879436282184, 7.864186144654281, 6.870364719583405, 6.475733430966398, 6.965784284662087, 7.066089190457772, 3.4594316186372973, 7.857980995127572, 7.6865005271832185, 8.383704292474052, 6.794415866350106, 6.658211482751795, 5.882643049361842, 5.087462841250339, 6.392317422778761, 6.321928094887363, 6.882643049361842, 6.066089190457772, 7.098032082960526, 6.491853096329675, 4.247927513443585, 6.584962500721156, 9.988684686772165, 9.005624549193879, 8.721099188707186, 7.257387842692652, 6.741466986401147, 7.247927513443585, 7.636624620543649, 7.912889336229962, 6.426264754702098, 6.845490050944375, 7.022367813028454, 7.6293566200796095, 3.700439718141092, 8.357552004618084, 9.162391328756906, 8.787902559391432, 7.491853096329675, 7.022367813028454, 6.754887502163468, 6.149747119504682, 6.754887502163468, 7.169925001442312, 7.721099188707185, 6.0, 8.092757140919852, 6.882643049361842, 5.0, 7.515699838284043, 8.661778097771988, 8.266786540694902, 7.159871336778389, 6.741466986401147, 5.882643049361842, 5.044394119358453, 5.727920454563199, 6.266786540694901, 7.3750394313469245, 4.392317422778761, 7.011227255423254, 6.523561956057013, 1.584962500721156, 7.076815597050831, 9.370687406807217, 8.900866807980748, 8.055282435501189, 7.2384047393250786, 5.954196310386875, 6.066089190457772, 6.857980995127572, 7.139551352398794, 7.78135971352466, 6.022367813028454, 8.375039431346925, 6.554588851677638, 4.169925001442312, 7.6293566200796095, 7.409390936137702, 8.055282435501189, 6.169925001442312, 6.108524456778169, 5.491853096329675, 5.20945336562895, 5.584962500721156, 5.930737337562887, 6.672425341971495, 4.700439718141092, 6.539158811108031, 5.584962500721156, 2.807354922057604, 6.022367813028454, 8.73809225962049, 8.661778097771988, 7.918863237274595, 6.714245517666122, 6.807354922057604, 5.954196310386875, 6.392317422778761, 6.832890014164741, 7.426264754702098, 5.857980995127572, 7.813781191217037, 6.20945336562895, 2.0, 8.184875342908283, 8.96289600533726, 9.08214904135387, 7.539158811108031, 7.60733031374961, 6.584962500721156, 6.554588851677638, 7.044394119358453, 7.285402218862249, 7.794415866350106, 5.954196310386875, 8.321928094887362, 6.3750394313469245, 3.321928094887362, 7.894817763307944, 8.948367231584678, 9.199672344836364, 7.845490050944375, 7.614709844115208, 6.643856189774724, 6.22881869049588, 7.044394119358453, 7.169925001442312, 7.839203788096944, 6.672425341971495, 7.794415866350106, 6.9886846867721655, 2.807354922057604, 7.651051691178929, 8.744833837499545, 8.813781191217037, 7.636624620543649, 7.491853096329675, 6.169925001442312, 6.129283016944966, 6.794415866350106, 6.845490050944375, 7.169925001442312, 6.303780748177103, 6.882643049361842, 6.475733430966398, 2.807354922057604, 7.672425341971495, 9.13699111208023, 8.658211482751796, 7.948367231584678, 6.965784284662087, 6.3750394313469245, 5.643856189774724, 6.523561956057013, 6.475733430966398, 7.562242424221073, 5.832890014164741, 7.6653359171851765, 6.426264754702098, 2.0, 7.312882955284356, 9.967226258835993, 9.46352437327118, 8.977279923499916, 7.679480099505446, 7.03342300153745, 7.022367813028454, 7.05528243550119, 7.554588851677638, 8.134426320220927, 7.076815597050831, 8.409390936137703, 7.303780748177103, 2.584962500721156, 7.845490050944375, 9.868822554774999, 9.129283016944967, 8.611024797307353, 7.584962500721156, 6.894817763307944, 6.741466986401147, 6.930737337562887, 7.219168520462161, 8.049848549450562, 6.339850002884624, 8.154818109052105, 6.954196310386875, 3.169925001442312, 8.076815597050832, 9.442943495848729, 8.774787059601174, 8.049848549450562, 7.149747119504682, 6.149747119504682, 6.426264754702098, 6.442943495848728, 7.257387842692652, 7.199672344836364, 6.3750394313469245, 7.592457037268081, 6.754887502163468, 2.584962500721156, 7.199672344836364, 8.550746785383243, 9.047123912114026, 7.569855608330948, 7.312882955284356, 7.108524456778169, 6.108524456778169, 7.05528243550119, 7.426264754702098, 8.751544059089099, 5.643856189774724, 8.550746785383243, 7.2761244052742375, 4.392317422778761, 7.643856189774724, 5.426264754702098, 7.546894459887636, 3.700439718141092, 6.459431618637297, 2.321928094887362, 2.321928094887362, 6.20945336562895, 3.807354922057604, 3.807354922057604, 2.584962500721156, 4.459431618637297, 5.78135971352466, null, 2.321928094887362, 8.092757140919852, 8.67595703294175, 6.94251450533924, 6.727920454563199, 6.189824558880018, 5.357552004618084, 6.700439718141092, 6.149747119504682, 7.857980995127572, 6.066089190457772, 7.936637939002571, 6.584962500721156, 1.0, 7.199672344836364, 8.475733430966399, 7.977279923499917, 7.0, 6.285402218862249, 5.614709844115208, 5.20945336562895, 5.614709844115208, 6.129283016944966, 6.94251450533924, 5.491853096329675, 6.539158811108031, 5.392317422778761, 3.9068905956085187, 6.20945336562895, 8.654636028527968, 8.129283016944967, 6.845490050944375, 6.303780748177103, 5.584962500721156, 5.426264754702098, 6.066089190457772, 6.554588851677638, 7.129283016944966, 5.044394119358453, 8.022367813028454, 5.977279923499917, 3.9068905956085187, 6.754887502163468, 8.784634845557521, 9.273795599214264, 7.592457037268081, 7.78135971352466, 6.554588851677638, 5.954196310386875, 7.129283016944966, 7.451211111832329, 8.03342300153745, 6.409390936137702, 8.154818109052105, 7.22881869049588, 2.321928094887362, 7.569855608330948, 10.462502272597265, 9.52943055414615, 9.111135670234708, 8.62935662007961, 7.247927513443585, 7.22881869049588, 7.924812503605781, 8.169925001442312, 8.303780748177102, 7.076815597050831, 8.507794640198696, 7.658211482751795, 4.087462841250339, 8.584962500721156, 8.426264754702098, 8.845490050944376, 7.658211482751795, 7.442943495848728, 6.426264754702098, 6.22881869049588, 6.714245517666122, 7.266786540694901, 7.426264754702098, 6.820178962415188, 7.467605550082998, 6.491853096329675, 2.321928094887362, 7.577428828035749, 10.071462362556623, 9.361943773735241, 8.791162888555018, 8.071462362556623, 7.05528243550119, 6.285402218862249, 7.011227255423254, 7.531381460516312, 8.344295907915816, 6.658211482751795, 8.179909090014934, 7.189824558880018, 5.954196310386875, 8.016808287686555, 10.019590728357882, 9.407267764244732, 8.791162888555018, 7.599912842187128, 7.066089190457772, 6.599912842187128, 7.348728154231077, 7.426264754702098, 8.087462841250339, 6.442943495848728, 8.625708843064466, 7.330916878114617, 3.0, 7.924812503605781, 9.717676423066395, 9.923327485419192, 8.744833837499545, 8.214319120800766, 7.426264754702098, 7.714245517666122, 7.977279923499917, 8.262094845370179, 8.276124405274238, 7.483815777264256, 8.76487159073609, 7.658211482751795, 1.584962500721156, 8.62935662007961, 9.842350343413807, 9.266786540694902, 8.467605550082997, 7.531381460516312, 6.754887502163468, 6.442943495848728, 7.118941072723508, 7.139551352398794, 7.930737337562887, 6.169925001442312, 7.912889336229962, 7.0, 2.321928094887362, 7.426264754702098, 8.531381460516313, 8.751544059089099, 7.159871336778389, 7.129283016944966, 6.442943495848728, 6.442943495848728, 6.672425341971495, 6.491853096329675, 7.794415866350106, 5.754887502163468, 8.149747119504681, 6.658211482751795, 1.584962500721156, 7.434628227636725, 7.807354922057604, 7.459431618637297, 6.22881869049588, 5.930737337562887, 5.285402218862249, 4.523561956057013, 4.807354922057604, 5.169925001442312, 5.700439718141092, 4.169925001442312, 6.741466986401147, 5.044394119358453, null, 5.643856189774724, 7.832890014164741, 7.599912842187128, 6.303780748177103, 5.906890595608519, 5.247927513443585, 4.169925001442312, 4.392317422778761, 4.906890595608519, 6.22881869049588, 3.321928094887362, 7.2384047393250786, 4.169925001442312, 1.584962500721156, 5.977279923499917, 6.870364719583405, 7.531381460516312, 5.554588851677638, 4.954196310386875, 4.700439718141092, 3.584962500721156, 5.169925001442312, 5.247927513443585, 6.475733430966398, 4.643856189774724, 6.321928094887363, 5.357552004618084, 3.9068905956085187, 5.087462841250339, 8.379378367071261, 7.219168520462161, 6.794415866350106, 6.189824558880018, 4.807354922057604, 5.0, 5.392317422778761, 6.20945336562895, 5.906890595608519, 4.700439718141092, 5.954196310386875, 5.247927513443585, 2.807354922057604, 6.20945336562895, 8.321928094887362, 8.483815777264256, 6.930737337562887, 7.0, 6.189824558880018, 6.149747119504682, 6.807354922057604, 6.930737337562887, 7.700439718141092, 6.169925001442312, 8.071462362556623, 6.569855608330948, 4.247927513443585, 6.94251450533924, 9.379378367071261, 8.499845887083206, 7.577428828035749, 6.714245517666122, 5.832890014164741, 6.266786540694901, 6.754887502163468, 6.965784284662087, 7.714245517666122, 6.0, 7.20945336562895, 6.357552004618084, 2.0, 7.451211111832329, 8.076815597050832, 8.76487159073609, 7.22881869049588, 7.539158811108031, 6.189824558880018, 6.189824558880018, 6.820178962415188, 6.870364719583405, 7.643856189774724, 6.044394119358453, 8.257387842692651, 6.409390936137702, 3.807354922057604, 7.6653359171851765, 9.060695931687555, 9.245552706255681, 7.912889336229962, 7.60733031374961, 7.011227255423254, 6.459431618637297, 7.20945336562895, 7.592457037268081, 8.413627929024173, 6.614709844115208, 8.409390936137703, 7.523561956057013, 3.169925001442312, 7.888743248898259, 8.839203788096944, 8.098032082960527, 6.9886846867721655, 6.614709844115208, 5.754887502163468, 5.20945336562895, 6.0, 6.459431618637297, 6.906890595608519, 5.491853096329675, 7.614709844115208, 6.169925001442312, 4.169925001442312, 6.672425341971495, 7.851749041416057, 8.129283016944967, 6.6293566200796095, 6.022367813028454, 5.832890014164741, 4.906890595608519, 5.954196310386875, 6.20945336562895, 6.584962500721156, 5.20945336562895, 7.066089190457772, 5.523561956057013, 2.321928094887362, 6.768184324776926, 9.216745858195306, 8.717676423066395, 7.700439718141092, 6.768184324776926, 5.977279923499917, 5.930737337562887, 6.569855608330948, 6.882643049361842, 7.3750394313469245, 5.087462841250339, 7.614709844115208, 6.189824558880018, 2.584962500721156, 7.149747119504682, 9.335390354693924, 9.00842862207058, 7.6653359171851765, 7.366322214245816, 6.882643049361842, 5.584962500721156, 6.94251450533924, 6.857980995127572, 8.214319120800766, 6.20945336562895, 8.569855608330949, 6.614709844115208, 4.321928094887363, 7.139551352398794, 8.507794640198696, 8.03342300153745, 6.266786540694901, 6.3750394313469245, 6.169925001442312, 5.0, 5.954196310386875, 6.149747119504682, 7.05528243550119, 4.392317422778761, 6.442943495848728, 5.643856189774724, 2.321928094887362, 6.0, 7.0, 7.714245517666122, 6.022367813028454, 5.78135971352466, 5.169925001442312, 5.129283016944966, 5.700439718141092, 5.0, 6.247927513443585, 3.700439718141092, 6.357552004618084, 5.807354922057604, 3.0, 6.169925001442312, 9.090112419664289, 8.939579214314692, 7.6293566200796095, 7.044394119358453, 6.285402218862249, 5.321928094887363, 6.321928094887363, 6.409390936137702, 8.087462841250339, 5.643856189774724, 8.224001674198105, 6.357552004618084, 3.584962500721156, 7.098032082960526, 7.169925001442312, 7.977279923499917, 6.066089190457772, 6.539158811108031, 5.977279923499917, 4.643856189774724, 5.0, 5.169925001442312, 6.584962500721156, 4.0, 6.78135971352466, 5.491853096329675, 3.169925001442312, 6.247927513443585, 6.954196310386875, 8.03342300153745, 6.266786540694901, 6.569855608330948, 6.266786540694901, 4.857980995127572, 5.954196310386875, 6.0, 7.149747119504682, 5.0, 7.400879436282184, 6.409390936137702, 3.807354922057604, 6.409390936137702, 8.727920454563199, 8.108524456778168, 7.339850002884624, 7.2384047393250786, 6.247927513443585, 5.584962500721156, 5.906890595608519, 6.285402218862249, 7.108524456778169, 4.906890595608519, 7.426264754702098, 6.339850002884624, 4.392317422778761, 6.768184324776926, 8.50382573799575, 9.20212382383046, 7.339850002884624, 7.672425341971495, 7.149747119504682, 5.977279923499917, 6.807354922057604, 6.672425341971495, 8.169925001442312, 6.22881869049588, 8.842350343413807, 6.523561956057013, 4.087462841250339, 7.531381460516312, 8.174925682500678, 8.980139577639157, 7.348728154231077, 7.2761244052742375, 6.754887502163468, 5.554588851677638, 6.409390936137702, 6.266786540694901, 8.103287808412022, 5.247927513443585, 8.370687406807217, 6.954196310386875, 4.807354922057604, 7.022367813028454, 9.894817763307943, 9.436711542137214, 8.400879436282183, 8.257387842692651, 7.475733430966398, 6.807354922057604, 7.257387842692652, 7.906890595608519, 8.527477006060396, 6.672425341971495, 9.162391328756906, 7.189824558880018, 4.087462841250339, 8.139551352398794, 8.149747119504681, 8.661778097771988, 7.515699838284043, 6.977279923499917, 6.357552004618084, 5.882643049361842, 6.6293566200796095, 6.714245517666122, 7.434628227636725, 5.247927513443585, 7.523561956057013, 6.507794640198696, 2.584962500721156, 7.467605550082998, 8.044394119358454, 8.758223214726724, 6.977279923499917, 7.285402218862249, 6.20945336562895, 6.189824558880018, 6.614709844115208, 6.94251450533924, 7.977279923499917, 6.459431618637297, 8.118941072723507, 6.768184324776926, 0.0, 7.303780748177103, 9.044394119358454, 8.778077129535358, 7.330916878114617, 6.832890014164741, 6.475733430966398, 5.491853096329675, 6.303780748177103, 6.3750394313469245, 7.754887502163468, 5.754887502163468, 8.204571144249204, 6.357552004618084, 4.700439718141092, 7.1799090900149345, 8.071462362556623, 8.257387842692651, 6.672425341971495, 6.554588851677638, 5.491853096329675, 5.857980995127572, 6.523561956057013, 6.700439718141092, 7.20945336562895, 5.044394119358453, 7.546894459887636, 6.321928094887363, 3.4594316186372973, 6.539158811108031, 7.3750394313469245, 7.442943495848728, 5.807354922057604, 5.614709844115208, 5.129283016944966, 4.459431618637297, 4.169925001442312, 4.321928094887363, 6.339850002884624, 4.754887502163468, 5.977279923499917, 4.584962500721156, 1.584962500721156, 5.247927513443585, 6.965784284662087, 7.912889336229962, 5.977279923499917, 6.044394119358453, 5.129283016944966, 4.392317422778761, 5.285402218862249, 5.087462841250339, 6.426264754702098, 3.9068905956085187, 6.584962500721156, 5.700439718141092, 2.321928094887362, 5.672425341971495, 9.219168520462162, 8.784634845557521, 7.592457037268081, 7.087462841250339, 6.569855608330948, 5.882643049361842, 6.442943495848728, 7.118941072723508, 6.643856189774724, 5.754887502163468, 7.321928094887363, 6.022367813028454, 2.807354922057604, 7.022367813028454, 4.700439718141092, 5.285402218862249, 3.584962500721156, 4.584962500721156, 2.584962500721156, null, 1.584962500721156, 1.584962500721156, 4.857980995127572, 1.0, 4.954196310386875, 3.0, null, 2.0, 8.353146825498083, 8.800899899920305, 7.339850002884624, 7.467605550082998, 6.584962500721156, 5.857980995127572, 6.820178962415188, 7.098032082960526, 7.499845887083206, 5.700439718141092, 7.894817763307944, 6.857980995127572, 2.0, 7.129283016944966, 8.0, 7.787902559391432, 6.066089190457772, 5.754887502163468, 5.247927513443585, 4.459431618637297, 4.857980995127572, 4.754887502163468, 6.672425341971495, 4.087462841250339, 7.011227255423254, 5.087462841250339, null, 5.807354922057604, 8.810571634741146, 8.326429487122303, 7.539158811108031, 6.392317422778761, 5.78135971352466, 5.392317422778761, 6.392317422778761, 6.741466986401147, 6.754887502163468, 4.906890595608519, 6.754887502163468, 6.108524456778169, 1.584962500721156, 6.6293566200796095, 8.98299357469431, 8.005624549193879, 7.531381460516312, 7.03342300153745, 5.672425341971495, 5.930737337562887, 6.22881869049588, 7.05528243550119, 6.189824558880018, 5.523561956057013, 6.426264754702098, 6.303780748177103, 1.584962500721156, 7.312882955284356, 7.599912842187128, 8.016808287686555, 6.768184324776926, 6.614709844115208, 5.78135971352466, 6.087462841250339, 6.409390936137702, 6.832890014164741, 6.768184324776926, 5.491853096329675, 7.03342300153745, 6.321928094887363, 4.247927513443585, 7.05528243550119, 8.204571144249204, 8.31741261376487, 7.2761244052742375, 7.199672344836364, 5.882643049361842, 6.247927513443585, 6.357552004618084, 7.0, 6.672425341971495, 5.614709844115208, 7.159871336778389, 6.247927513443585, 3.9068905956085187, 7.330916878114617, 9.149747119504681, 8.290018846932618, 7.658211482751795, 7.2384047393250786, 6.169925001442312, 6.569855608330948, 6.584962500721156, 7.409390936137702, 6.6293566200796095, 6.149747119504682, 6.954196310386875, 6.044394119358453, 2.584962500721156, 7.800899899920305, 8.784634845557521, 7.7073591320808825, 7.303780748177103, 6.930737337562887, 5.491853096329675, 5.832890014164741, 6.820178962415188, 7.330916878114617, 6.129283016944966, 5.459431618637297, 5.584962500721156, 5.906890595608519, 2.321928094887362, 7.357552004618084, 7.912889336229962, 7.7481928495894605, 6.768184324776926, 6.918863237274595, 5.930737337562887, 5.169925001442312, 6.741466986401147, 6.700439718141092, 6.022367813028454, 4.954196310386875, 6.189824558880018, 6.0, 2.584962500721156, 7.199672344836364, 6.442943495848728, 6.303780748177103, 4.584962500721156, 5.614709844115208, 3.0, 4.906890595608519, 4.807354922057604, 5.459431618637297, 4.087462841250339, 4.169925001442312, 3.9068905956085187, 4.169925001442312, 1.584962500721156, 4.807354922057604, 7.531381460516312, 7.499845887083206, 6.475733430966398, 6.357552004618084, 4.321928094887363, 5.285402218862249, 5.643856189774724, 6.247927513443585, 5.977279923499917, 4.754887502163468, 6.247927513443585, 5.614709844115208, 3.169925001442312, 6.523561956057013, 8.554588851677638, 7.845490050944375, 7.199672344836364, 6.3750394313469245, 5.426264754702098, 5.754887502163468, 6.066089190457772, 6.321928094887363, 5.672425341971495, 4.954196310386875, 6.459431618637297, 6.357552004618084, 3.321928094887362, 6.6293566200796095, 7.6865005271832185, 8.092757140919852, 7.118941072723508, 6.807354922057604, 5.832890014164741, 5.954196310386875, 6.189824558880018, 6.714245517666122, 6.442943495848728, 5.754887502163468, 6.442943495848728, 5.584962500721156, 3.584962500721156, 7.189824558880018, 9.802516365121223, 8.88264304936184, 8.353146825498083, 8.022367813028454, 6.20945336562895, 6.832890014164741, 7.2761244052742375, 7.882643049361842, 7.357552004618084, 6.643856189774724, 7.219168520462161, 7.247927513443585, 2.321928094887362, 8.144658242831882, 8.625708843064466, 7.832890014164741, 7.1799090900149345, 6.491853096329675, 5.459431618637297, 5.643856189774724, 6.044394119358453, 6.247927513443585, 6.044394119358453, 5.954196310386875, 6.022367813028454, 5.392317422778761, 2.584962500721156, 7.139551352398794, 8.73809225962049, 7.936637939002571, 7.108524456778169, 6.78135971352466, 5.584962500721156, 5.832890014164741, 6.20945336562895, 6.569855608330948, 6.339850002884624, 5.643856189774724, 6.149747119504682, 6.0, 3.321928094887362, 7.348728154231077, 8.651051691178928, 8.710806433699352, 7.787902559391432, 7.339850002884624, 6.321928094887363, 6.832890014164741, 7.139551352398794, 7.693486957499325, 6.700439718141092, 6.459431618637297, 6.409390936137702, 6.475733430966398, 2.321928094887362, 7.700439718141092, 9.294620748891626, 8.43879185257826, 7.960001932068081, 7.467605550082998, 5.727920454563199, 6.20945336562895, 6.507794640198696, 7.098032082960526, 6.392317422778761, 6.266786540694901, 6.044394119358453, 6.554588851677638, 3.169925001442312, 7.383704292474052, 9.4655664048094, 8.573647187493322, 8.20945336562895, 7.022367813028454, 6.339850002884624, 6.475733430966398, 6.977279923499917, 7.383704292474052, 6.392317422778761, 6.6293566200796095, 6.614709844115208, 7.118941072723508, 2.0, 7.592457037268081, 7.7615512324444795, 7.924812503605781, 6.954196310386875, 6.426264754702098, 5.882643049361842, 5.426264754702098, 6.442943495848728, 7.087462841250339, 5.906890595608519, 5.977279923499917, 5.459431618637297, 6.22881869049588, 2.0, 7.2384047393250786, 8.447083226209653, 7.434628227636725, 6.672425341971495, 6.523561956057013, 5.584962500721156, 5.392317422778761, 5.643856189774724, 6.303780748177103, 5.321928094887363, 5.357552004618084, 6.0, 6.20945336562895, 1.584962500721156, 6.894817763307944, 8.118941072723507, 7.643856189774724, 6.832890014164741, 6.044394119358453, 4.700439718141092, 5.285402218862249, 5.554588851677638, 6.129283016944966, 6.022367813028454, 5.672425341971495, 6.0, 4.906890595608519, 2.584962500721156, 6.554588851677638, 6.794415866350106, 6.906890595608519, 5.954196310386875, 6.087462841250339, 4.247927513443585, 4.857980995127572, 5.087462841250339, 6.087462841250339, 5.129283016944966, 5.78135971352466, 5.247927513443585, 4.584962500721156, 3.9068905956085187, 6.303780748177103, 8.383704292474052, 7.491853096329675, 6.700439718141092, 5.754887502163468, 5.129283016944966, 5.426264754702098, 6.169925001442312, 6.523561956057013, 5.491853096329675, 5.459431618637297, 6.554588851677638, 6.247927513443585, 3.169925001442312, 7.066089190457772, 5.643856189774724, 4.0, 3.321928094887362, 2.0, 1.584962500721156, 2.807354922057604, 2.584962500721156, 3.0, 0.0, 1.0, 1.584962500721156, 2.584962500721156, 0.0, 3.4594316186372973, 7.672425341971495, 8.055282435501189, 6.965784284662087, 6.894817763307944, 5.930737337562887, 5.727920454563199, 6.266786540694901, 6.832890014164741, 6.285402218862249, 6.022367813028454, 6.643856189774724, 6.339850002884624, 3.4594316186372973, 7.409390936137702, 7.94251450533924, 6.741466986401147, 6.539158811108031, 5.807354922057604, 4.459431618637297, 4.954196310386875, 5.247927513443585, 5.977279923499917, 5.0, 4.906890595608519, 5.0, 4.754887502163468, 0.0, 5.977279923499917, 8.348728154231077, 8.321928094887362, 7.442943495848728, 7.330916878114617, 5.700439718141092, 6.339850002884624, 6.794415866350106, 7.20945336562895, 6.426264754702098, 5.614709844115208, 6.285402218862249, 6.189824558880018, 2.0, 7.507794640198696, 7.971543553950772, 8.108524456778168, 7.159871336778389, 6.977279923499917, 6.129283016944966, 5.754887502163468, 6.20945336562895, 6.6865005271832185, 6.321928094887363, 5.554588851677638, 6.554588851677638, 5.523561956057013, 2.807354922057604, 6.930737337562887, 9.405141463136344, 8.62935662007961, 7.918863237274595, 7.60733031374961, 6.658211482751795, 6.475733430966398, 7.05528243550119, 7.303780748177103, 6.523561956057013, 6.392317422778761, 6.584962500721156, 6.643856189774724, 2.807354922057604, 7.820178962415188, 1.0, 1.0, 0.0, null, null, null, null, null, null, 0.0, 2.584962500721156, null, 0.0, 0.0, 1.584962500721156, 8.357552004618084, 4.584962500721156, 5.614709844115208, 5.614709844115208, 4.321928094887363, 5.78135971352466, 5.129283016944966, 7.257387842692652, 3.0, 7.794415866350106, 5.357552004618084, 4.584962500721156, 6.189824558880018, 8.951284714966972, 7.658211482751795, 7.592457037268081, 5.584962500721156, 5.554588851677638, 4.700439718141092, 5.459431618637297, 5.614709844115208, 6.189824558880018, 4.0, 6.129283016944966, 4.459431618637297, 3.321928094887362, 6.539158811108031, 6.882643049361842, 6.857980995127572, 5.523561956057013, 5.169925001442312, 4.169925001442312, 3.0, 4.247927513443585, 4.807354922057604, 6.189824558880018, 2.0, 5.78135971352466, 3.700439718141092, 3.321928094887362, 4.523561956057013, 8.832890014164741, 8.459431618637296, 7.348728154231077, 6.807354922057604, 5.832890014164741, 5.459431618637297, 6.22881869049588, 6.554588851677638, 7.330916878114617, 5.20945336562895, 7.651051691178929, 5.491853096329675, 3.321928094887362, 6.727920454563199, 7.0, 7.076815597050831, 5.044394119358453, 5.20945336562895, 4.523561956057013, 4.087462841250339, 4.087462841250339, 5.169925001442312, 6.741466986401147, 1.0, 6.930737337562887, 4.807354922057604, 1.584962500721156, 4.807354922057604, 9.0, 7.906890595608519, 7.592457037268081, 6.965784284662087, 5.700439718141092, 5.78135971352466, 6.087462841250339, 7.011227255423254, 6.266786540694901, 5.930737337562887, 5.754887502163468, 6.22881869049588, 4.0, 7.118941072723508, null, 6.20945336562895, null, 3.4594316186372973, null, 6.129283016944966, 3.169925001442312, 6.700439718141092, null, 5.857980995127572, 1.0, 2.584962500721156, 1.0, null, 8.303780748177102, 8.523561956057012, 6.643856189774724, 6.727920454563199, 6.149747119504682, 4.584962500721156, 6.22881869049588, 5.930737337562887, 7.768184324776926, 4.700439718141092, 8.219168520462162, 6.0, 4.523561956057013, 6.066089190457772, 8.339850002884624, 8.59618975614441, 7.475733430966398, 7.189824558880018, 5.977279923499917, 6.6865005271832185, 7.285402218862249, 7.149747119504682, 6.129283016944966, 6.906890595608519, 6.569855608330948, 6.523561956057013, 3.9068905956085187, 7.851749041416057, 8.72451385311995, 8.257387842692651, 7.20945336562895, 6.3750394313469245, 5.807354922057604, 5.357552004618084, 6.149747119504682, 6.066089190457772, 7.05528243550119, 5.247927513443585, 7.864186144654281, 5.727920454563199, 4.392317422778761, 6.539158811108031, 7.832890014164741, 8.049848549450562, 6.754887502163468, 6.569855608330948, 4.906890595608519, 5.491853096329675, 6.0, 6.285402218862249, 6.584962500721156, 5.321928094887363, 6.820178962415188, 5.392317422778761, 4.392317422778761, 6.3750394313469245, 7.303780748177103, 8.262094845370179, 6.741466986401147, 5.672425341971495, 5.643856189774724, 5.20945336562895, 5.906890595608519, 6.339850002884624, 6.965784284662087, 5.169925001442312, 6.894817763307944, 6.169925001442312, 2.0, 6.554588851677638, 9.417852514885897, 8.189824558880018, 7.693486957499325, 6.303780748177103, 6.20945336562895, 4.0, 5.832890014164741, 5.491853096329675, 6.9886846867721655, 5.20945336562895, 7.554588851677638, 5.700439718141092, 3.9068905956085187, 7.2384047393250786, 7.851749041416057, 8.266786540694902, 6.507794640198696, 6.3750394313469245, 5.0, 5.169925001442312, 5.906890595608519, 6.169925001442312, 7.312882955284356, 5.285402218862249, 7.22881869049588, 5.807354922057604, 3.321928094887362, 6.475733430966398, 8.566054038171092, 8.682994583681683, 6.977279923499917, 6.658211482751795, 6.22881869049588, 5.0, 5.807354922057604, 5.459431618637297, 7.044394119358453, 4.754887502163468, 7.569855608330948, 6.6865005271832185, 4.643856189774724, 6.392317422778761, 8.957102041562287, 8.353146825498083, 7.266786540694901, 6.285402218862249, 5.930737337562887, 5.169925001442312, 6.087462841250339, 6.108524456778169, 7.149747119504682, 4.857980995127572, 7.499845887083206, 5.954196310386875, 2.0, 6.523561956057013, 1.0, 7.6865005271832185, 5.129283016944966, 5.20945336562895, 5.392317422778761, 3.321928094887362, 5.426264754702098, 4.857980995127572, 6.832890014164741, 3.321928094887362, 7.087462841250339, 5.087462841250339, 4.169925001442312, 5.832890014164741, 7.800899899920305, 8.873444112515376, 7.066089190457772, 6.714245517666122, 6.285402218862249, 5.459431618637297, 6.78135971352466, 6.539158811108031, 7.622051819456376, 5.554588851677638, 8.149747119504681, 6.266786540694901, 4.807354922057604, 6.700439718141092, 4.807354922057604, 8.243173983472952, 4.321928094887363, 7.044394119358453, 2.321928094887362, 2.0, 6.614709844115208, 4.0, 4.169925001442312, 2.584962500721156, 4.459431618637297, 6.087462841250339, null, 3.169925001442312, 9.994353436858859, 9.303780748177102, 8.774787059601174, 7.562242424221073, 6.954196310386875, 6.459431618637297, 7.169925001442312, 7.076815597050831, 8.357552004618084, 6.129283016944966, 8.348728154231077, 6.832890014164741, 3.9068905956085187, 7.851749041416057, 8.86418614465428, 8.558420713268664, 7.592457037268081, 6.285402218862249, 5.954196310386875, 5.357552004618084, 6.108524456778169, 6.285402218862249, 7.05528243550119, 5.491853096329675, 7.614709844115208, 6.066089190457772, 4.584962500721156, 6.820178962415188, 8.81698362325538, 8.294620748891626, 7.303780748177103, 6.918863237274595, 5.285402218862249, 5.285402218862249, 6.22881869049588, 6.459431618637297, 7.577428828035749, 5.392317422778761, 7.807354922057604, 5.78135971352466, 3.807354922057604, 6.832890014164741, 7.918863237274595, 7.94251450533924, 6.584962500721156, 5.672425341971495, 5.321928094887363, 4.807354922057604, 5.807354922057604, 5.285402218862249, 6.727920454563199, 3.321928094887362, 6.845490050944375, 4.857980995127572, 3.169925001442312, 5.392317422778761, 8.558420713268664, 8.405141463136344, 7.294620748891627, 5.807354922057604, 6.0, 4.392317422778761, 5.426264754702098, 5.754887502163468, 6.714245517666122, 4.807354922057604, 7.303780748177103, 5.321928094887363, 3.0, 6.491853096329675, 9.036173612553485, 8.64745842645492, 7.523561956057013, 7.20945336562895, 6.022367813028454, 5.807354922057604, 6.0, 6.78135971352466, 6.78135971352466, 5.285402218862249, 7.6293566200796095, 6.169925001442312, 4.754887502163468, 6.658211482751795, 6.906890595608519, 7.734709620225838, 6.169925001442312, 5.906890595608519, 5.426264754702098, 4.459431618637297, 4.754887502163468, 5.044394119358453, 6.614709844115208, 3.584962500721156, 6.189824558880018, 4.857980995127572, 1.584962500721156, 6.0, 7.546894459887636, 8.321928094887362, 6.569855608330948, 6.087462841250339, 5.614709844115208, 4.321928094887363, 4.754887502163468, 5.357552004618084, 6.409390936137702, 3.169925001442312, 6.918863237274595, 5.169925001442312, 4.954196310386875, 5.584962500721156, 7.515699838284043, 8.361943773735241, 6.845490050944375, 6.22881869049588, 5.614709844115208, 5.614709844115208, 6.066089190457772, 6.357552004618084, 6.321928094887363, 4.754887502163468, 7.554588851677638, 6.044394119358453, 3.584962500721156, 6.643856189774724, 8.467605550082997, 8.535275376620802, 7.321928094887363, 6.392317422778761, 5.882643049361842, 5.044394119358453, 5.459431618637297, 5.882643049361842, 6.599912842187128, 5.614709844115208, 7.05528243550119, 5.523561956057013, 3.700439718141092, 6.459431618637297, 8.154818109052105, 8.370687406807217, 6.954196310386875, 5.672425341971495, 5.426264754702098, 4.807354922057604, 5.906890595608519, 5.426264754702098, 6.700439718141092, 3.4594316186372973, 7.108524456778169, 4.700439718141092, 4.247927513443585, 6.066089190457772, 9.164906926675688, 8.50382573799575, 7.936637939002571, 7.554588851677638, 6.129283016944966, 6.247927513443585, 5.977279923499917, 7.022367813028454, 7.044394119358453, 5.954196310386875, 6.78135971352466, 6.321928094887363, 3.4594316186372973, 7.22881869049588, 7.794415866350106, 7.499845887083206, 6.523561956057013, 5.491853096329675, 5.20945336562895, 4.169925001442312, 5.247927513443585, 5.129283016944966, 6.442943495848728, 4.584962500721156, 5.614709844115208, 4.643856189774724, 2.321928094887362, 5.459431618637297, 7.864186144654281, 8.066089190457772, 6.965784284662087, 6.78135971352466, 5.459431618637297, 5.584962500721156, 5.930737337562887, 6.569855608330948, 6.569855608330948, 4.754887502163468, 7.159871336778389, 5.754887502163468, 1.0, 6.491853096329675, 8.022367813028454, 8.968666793195208, 7.531381460516312, 7.285402218862249, 6.247927513443585, 5.727920454563199, 6.700439718141092, 6.845490050944375, 7.129283016944966, 6.303780748177103, 7.022367813028454, 6.22881869049588, 2.321928094887362, 7.118941072723508, 9.131856960608793, 8.81698362325538, 7.459431618637297, 6.339850002884624, 6.108524456778169, 5.129283016944966, 6.392317422778761, 6.022367813028454, 7.2761244052742375, 5.285402218862249, 7.499845887083206, 6.392317422778761, 3.0, 6.882643049361842, 8.076815597050832, 7.643856189774724, 6.554588851677638, 5.584962500721156, 4.700439718141092, 4.169925001442312, 5.357552004618084, 5.930737337562887, 6.044394119358453, 4.169925001442312, 6.569855608330948, 5.0, 2.584962500721156, 5.906890595608519, 8.965784284662087, 8.45532722030456, 7.467605550082998, 6.539158811108031, 5.807354922057604, 4.643856189774724, 6.0, 6.087462841250339, 6.569855608330948, 4.321928094887363, 7.266786540694901, 5.700439718141092, 3.700439718141092, 6.491853096329675, 7.348728154231077, 8.238404739325079, 6.539158811108031, 6.044394119358453, 5.392317422778761, 5.044394119358453, 5.523561956057013, 5.930737337562887, 6.357552004618084, 4.392317422778761, 6.741466986401147, 5.954196310386875, 3.584962500721156, 6.044394119358453, 7.199672344836364, 8.335390354693924, 6.149747119504682, 5.614709844115208, 5.321928094887363, 4.459431618637297, 5.882643049361842, 5.247927513443585, 6.599912842187128, 4.087462841250339, 6.6293566200796095, 4.807354922057604, 3.9068905956085187, 5.491853096329675, 8.357552004618084, 8.366322214245816, 6.9886846867721655, 6.22881869049588, 5.807354922057604, 5.0, 5.78135971352466, 5.523561956057013, 7.247927513443585, 5.169925001442312, 7.409390936137702, 5.700439718141092, 3.321928094887362, 6.3750394313469245, 8.857980995127573, 8.668884984266247, 7.499845887083206, 6.599912842187128, 5.857980995127572, 5.392317422778761, 6.523561956057013, 6.339850002884624, 7.584962500721156, 5.0, 7.22881869049588, 6.189824558880018, 5.129283016944966, 6.820178962415188, 8.707359132080883, 8.546894459887637, 6.820178962415188, 6.491853096329675, 6.066089190457772, 4.523561956057013, 5.954196310386875, 6.0, 6.977279923499917, 4.807354922057604, 7.169925001442312, 6.22881869049588, 4.643856189774724, 6.129283016944966, 7.303780748177103, 8.62935662007961, 6.426264754702098, 6.266786540694901, 5.832890014164741, 4.459431618637297, 5.78135971352466, 5.285402218862249, 7.247927513443585, 4.247927513443585, 7.562242424221073, 5.523561956057013, 1.584962500721156, 5.807354922057604, 9.087462841250339, 9.036173612553485, 7.6865005271832185, 6.78135971352466, 6.727920454563199, 5.087462841250339, 6.569855608330948, 5.727920454563199, 8.08214904135387, 4.857980995127572, 8.370687406807217, 6.614709844115208, 4.700439718141092, 6.599912842187128, 7.03342300153745, 8.344295907915816, 6.357552004618084, 6.475733430966398, 5.459431618637297, 4.392317422778761, 5.857980995127572, 5.491853096329675, 7.20945336562895, 4.247927513443585, 7.076815597050831, 5.169925001442312, 4.321928094887363, 6.189824558880018, 7.400879436282184, 8.154818109052105, 6.584962500721156, 6.3750394313469245, 5.321928094887363, 4.857980995127572, 5.906890595608519, 6.129283016944966, 6.78135971352466, 4.321928094887363, 7.312882955284356, 5.044394119358453, 3.584962500721156, 6.554588851677638, 6.442943495848728, 7.20945336562895, 4.954196310386875, 5.0, 4.754887502163468, 3.0, 4.906890595608519, 4.392317422778761, 5.857980995127572, 4.087462841250339, 5.643856189774724, 4.321928094887363, 2.321928094887362, 4.754887502163468, 8.238404739325079, 7.507794640198696, 6.845490050944375, 5.614709844115208, 4.392317422778761, 4.523561956057013, 5.0, 5.392317422778761, 6.149747119504682, 3.0, 6.459431618637297, 4.807354922057604, 4.700439718141092, 5.954196310386875, 9.381542951184585, 8.810571634741146, 7.94251450533924, 6.459431618637297, 6.0, 5.807354922057604, 6.189824558880018, 6.426264754702098, 7.076815597050831, 5.754887502163468, 7.734709620225838, 6.584962500721156, 3.4594316186372973, 6.857980995127572, 4.087462841250339, 3.0, 0.0, 1.0, 1.0, 0.0, 0.0, 1.0, 3.169925001442312, null, 2.584962500721156, 1.0, 0.0, 2.0, 9.060695931687555, 8.566054038171092, 7.562242424221073, 6.3750394313469245, 6.285402218862249, 4.954196310386875, 6.321928094887363, 6.066089190457772, 7.087462841250339, 5.087462841250339, 7.499845887083206, 5.857980995127572, 2.321928094887362, 6.507794640198696, 7.592457037268081, 7.087462841250339, 5.584962500721156, 5.0, 4.700439718141092, 3.169925001442312, 4.754887502163468, 3.584962500721156, 6.459431618637297, 3.0, 6.870364719583405, 4.807354922057604, 2.0, 4.754887502163468, 8.087462841250339, 7.599912842187128, 6.169925001442312, 5.672425341971495, 5.392317422778761, 4.523561956057013, 5.392317422778761, 5.584962500721156, 6.339850002884624, 4.906890595608519, 6.392317422778761, 4.700439718141092, 1.584962500721156, 5.727920454563199, 9.204571144249204, 8.252665432450248, 7.679480099505446, 6.820178962415188, 5.357552004618084, 5.247927513443585, 6.554588851677638, 6.882643049361842, 6.066089190457772, 5.584962500721156, 6.247927513443585, 6.20945336562895, 2.321928094887362, 7.257387842692652, 8.092757140919852, 8.103287808412022, 7.044394119358453, 7.1799090900149345, 5.426264754702098, 6.507794640198696, 6.426264754702098, 6.94251450533924, 5.426264754702098, 6.129283016944966, 6.285402218862249, 6.0, 2.807354922057604, 6.930737337562887, 8.754887502163468, 8.276124405274238, 7.7615512324444795, 6.491853096329675, 5.321928094887363, 5.857980995127572, 6.303780748177103, 6.700439718141092, 5.754887502163468, 6.303780748177103, 6.22881869049588, 5.857980995127572, 3.321928094887362, 6.599912842187128, 7.826548487290915, 7.6865005271832185, 6.714245517666122, 5.614709844115208, 4.807354922057604, 5.954196310386875, 6.108524456778169, 6.321928094887363, 4.857980995127572, 6.129283016944966, 5.087462841250339, 4.459431618637297, 2.584962500721156, 5.807354922057604, 8.262094845370179, 8.179909090014934, 7.22881869049588, 6.94251450533924, 5.643856189774724, 6.409390936137702, 6.108524456778169, 6.906890595608519, 5.882643049361842, 5.247927513443585, 6.303780748177103, 5.832890014164741, 5.169925001442312, 6.870364719583405, 7.400879436282184, 7.60733031374961, 6.569855608330948, 5.78135971352466, 5.169925001442312, 5.169925001442312, 5.672425341971495, 6.303780748177103, 5.554588851677638, 5.459431618637297, 5.954196310386875, 5.754887502163468, 3.807354922057604, 6.857980995127572, 6.882643049361842, 7.930737337562887, 6.614709844115208, 6.459431618637297, 4.584962500721156, 5.285402218862249, 5.727920454563199, 6.0, 5.459431618637297, 4.0, 4.643856189774724, 5.643856189774724, 3.0, 6.714245517666122, 7.247927513443585, 6.554588851677638, 6.129283016944966, 5.727920454563199, 4.584962500721156, 4.584962500721156, 4.857980995127572, 5.491853096329675, 4.906890595608519, 3.807354922057604, 5.285402218862249, 3.169925001442312, 2.321928094887362, 5.426264754702098, 7.894817763307944, 7.2761244052742375, 6.965784284662087, 5.727920454563199, 5.169925001442312, 4.906890595608519, 5.321928094887363, 5.491853096329675, 4.643856189774724, 4.321928094887363, 4.392317422778761, 5.285402218862249, 1.0, 6.044394119358453, 8.08214904135387, 7.6293566200796095, 6.930737337562887, 5.906890595608519, 5.169925001442312, 5.247927513443585, 5.459431618637297, 5.882643049361842, 5.392317422778761, 4.700439718141092, 5.554588851677638, 5.584962500721156, 1.0, 6.044394119358453, 6.426264754702098, 6.727920454563199, 5.700439718141092, 5.754887502163468, 4.754887502163468, 4.523561956057013, 5.0, 5.584962500721156, 4.459431618637297, 4.754887502163468, 5.672425341971495, 4.169925001442312, 3.0, 5.523561956057013, 2.0, 8.326429487122303, 6.169925001442312, 6.845490050944375, 5.247927513443585, 6.087462841250339, 6.22881869049588, 6.930737337562887, 5.807354922057604, 5.727920454563199, 5.906890595608519, 5.727920454563199, 3.584962500721156, 7.321928094887363, 8.038918989292302, 7.3750394313469245, 6.94251450533924, 5.523561956057013, 4.247927513443585, 5.169925001442312, 5.78135971352466, 5.954196310386875, 4.754887502163468, 5.044394119358453, 4.906890595608519, 5.044394119358453, 3.4594316186372973, 5.930737337562887, 8.149747119504681, 7.499845887083206, 7.2384047393250786, 6.0, 4.700439718141092, 5.044394119358453, 5.754887502163468, 5.643856189774724, 5.672425341971495, 5.247927513443585, 5.357552004618084, 5.169925001442312, 2.0, 6.614709844115208, 8.78135971352466, 7.807354922057604, 7.357552004618084, 6.108524456778169, 5.426264754702098, 5.700439718141092, 6.614709844115208, 6.539158811108031, 5.906890595608519, 5.643856189774724, 5.857980995127572, 6.266786540694901, 4.523561956057013, 6.539158811108031, 4.700439718141092, 3.0, 2.321928094887362, null, 1.0, 0.0, 1.584962500721156, 2.807354922057604, 0.0, 1.0, 1.0, 2.0, 1.0, 2.0, 6.906890595608519, 6.930737337562887, 6.022367813028454, 5.754887502163468, 4.954196310386875, 5.169925001442312, 5.554588851677638, 5.807354922057604, 5.129283016944966, 5.169925001442312, 4.643856189774724, 5.0, 2.807354922057604, 6.247927513443585, 8.194756854422248, 7.491853096329675, 7.044394119358453, 6.087462841250339, 5.247927513443585, 5.672425341971495, 6.108524456778169, 6.392317422778761, 5.247927513443585, 5.044394119358453, 5.285402218862249, 5.643856189774724, 3.169925001442312, 6.321928094887363, 7.636624620543649, 6.523561956057013, 6.339850002884624, 5.523561956057013, 4.523561956057013, 4.584962500721156, 5.20945336562895, 5.727920454563199, 5.20945336562895, 4.459431618637297, 5.0, 5.044394119358453, 2.321928094887362, 5.882643049361842], "y0": " ", "yaxis": "y"}], "layout": {"boxmode": "group", "legend": {"title": {"text": "contig"}, "tracegroupgap": 0}, "margin": {"t": 60}, "template": {"data": {"bar": [{"error_x": {"color": "rgb(36,36,36)"}, "error_y": {"color": "rgb(36,36,36)"}, "marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "baxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmapgl"}], "histogram": [{"marker": {"line": {"color": "white", "width": 0.6}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "rgb(237,237,237)"}, "line": {"color": "white"}}, "header": {"fill": {"color": "rgb(217,217,217)"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "colorscale": {"diverging": [[0.0, "rgb(103,0,31)"], [0.1, "rgb(178,24,43)"], [0.2, "rgb(214,96,77)"], [0.3, "rgb(244,165,130)"], [0.4, "rgb(253,219,199)"], [0.5, "rgb(247,247,247)"], [0.6, "rgb(209,229,240)"], [0.7, "rgb(146,197,222)"], [0.8, "rgb(67,147,195)"], [0.9, "rgb(33,102,172)"], [1.0, "rgb(5,48,97)"]], "sequential": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "sequentialminus": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]]}, "colorway": ["#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF"], "font": {"color": "rgb(36,36,36)"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "white", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "white", "polar": {"angularaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "radialaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "scene": {"xaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "zaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}, "shapedefaults": {"fillcolor": "black", "line": {"width": 0}, "opacity": 0.3}, "ternary": {"aaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "baxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "caxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}}, "width": 1000, "xaxis": {"anchor": "y", "categoryarray": ["Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_18", "Agam_19", "Agam_20", "Agam_21", "Agam_22", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_44", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_64", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_79", "Agam_80", "Agam_81", "Agam_82"], "categoryorder": "array", "domain": [0.0, 1.0], "title": {"text": "amplicon"}}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0], "title": {"text": "log_depth"}}}}, "text/html": ["<div>                            <div id=\"e8b04d23-9640-4c24-9fcf-3e775b11b2e8\" class=\"plotly-graph-div\" style=\"height:525px; width:1000px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"e8b04d23-9640-4c24-9fcf-3e775b11b2e8\")) {                    Plotly.newPlot(                        \"e8b04d23-9640-4c24-9fcf-3e775b11b2e8\",                        [{\"alignmentgroup\":\"True\",\"customdata\":[[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"],[\"2R\",\"Ace1_G280S\"],[\"2R\",\"AIM9\"],[\"2R\",\"AIM10\"],[\"2R\",\"Cyp6p3_I88T\"],[\"2R\",\"Cyp6_tag1\"],[\"2R\",\"Cyp6_tag2\"],[\"2R\",\"Cyp6p4_I236M\"],[\"2R\",\"Cyp6_tag3\"],[\"2R\",\"Cyp6_tag4\"],[\"2R\",\"Cyp6_tag5\"],[\"2R\",\"Cyp6_tag6\"],[\"2R\",\"Cyp6_tag7\"],[\"2R\",\"Cyp6_tag8\"],[\"2R\",\"DSX2\"],[\"2R\",\"DSX1\"],[\"2R\",\"AIM11\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003eamplicon=%{x}\\u003cbr\\u003elog_depth=%{y}\\u003cbr\\u003emutation=%{customdata[1]}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"2R\",\"marker\":{\"color\":\"#1F77B4\"},\"name\":\"2R\",\"notched\":false,\"offsetgroup\":\"2R\",\"orientation\":\"v\",\"showlegend\":true,\"x\":[\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_43\",\"Agam_82\",\"Agam_81\",\"Agam_44\"],\"x0\":\" \",\"xaxis\":\"x\",\"y\":[7.169925001442312,4.0,5.285402218862249,8.31741261376487,4.169925001442312,8.071462362556623,7.417852514885898,null,4.857980995127572,4.700439718141092,2.584962500721156,8.092757140919852,7.087462841250339,null,null,10.199672344836364,5.087462841250339,1.0,2.321928094887362,4.392317422778761,1.584962500721156,4.169925001442312,3.700439718141092,null,3.0,1.0,1.0,2.321928094887362,1.0,null,null,5.727920454563199,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,2.584962500721156,0.0,1.0,3.0,null,3.169925001442312,1.0,null,0.0,0.0,0.0,null,null,1.0,1.0,2.321928094887362,3.700439718141092,1.0,1.584962500721156,4.906890595608519,null,4.754887502163468,4.247927513443585,null,3.0,1.0,0.0,4.169925001442312,3.169925001442312,null,null,6.3750394313469245,5.807354922057604,3.0,3.700439718141092,4.754887502163468,2.584962500721156,3.807354922057604,5.0,null,3.807354922057604,2.807354922057604,1.584962500721156,3.4594316186372973,2.321928094887362,null,null,6.087462841250339,5.491853096329675,3.169925001442312,null,1.584962500721156,null,null,2.321928094887362,null,4.906890595608519,null,null,null,null,null,null,0.0,null,null,null,null,null,null,0.0,null,0.0,null,null,0.0,null,null,null,null,null,0.0,null,null,null,null,0.0,null,0.0,null,null,0.0,null,null,null,null,3.321928094887362,1.0,2.321928094887362,4.247927513443585,2.321928094887362,4.459431618637297,5.459431618637297,null,2.321928094887362,2.321928094887362,1.0,3.584962500721156,2.584962500721156,null,null,5.285402218862249,2.584962500721156,1.0,0.0,2.584962500721156,0.0,3.321928094887362,1.0,null,2.807354922057604,1.0,null,null,null,null,null,4.0,2.584962500721156,0.0,1.584962500721156,1.584962500721156,null,1.0,null,null,1.584962500721156,null,null,1.584962500721156,0.0,null,null,2.584962500721156,6.339850002884624,3.321928094887362,3.0,5.930737337562887,3.169925001442312,3.4594316186372973,5.954196310386875,2.0,2.807354922057604,3.807354922057604,3.0,5.426264754702098,4.392317422778761,null,null,5.491853096329675,6.044394119358453,3.584962500721156,4.0,6.321928094887363,2.807354922057604,5.584962500721156,5.321928094887363,null,3.0,4.392317422778761,2.584962500721156,5.672425341971495,4.700439718141092,null,null,5.584962500721156,4.169925001442312,0.0,1.0,5.0,null,2.584962500721156,2.321928094887362,null,1.584962500721156,0.0,1.0,2.0,1.0,null,null,3.9068905956085187,3.321928094887362,null,2.0,4.392317422778761,1.0,4.523561956057013,0.0,null,3.700439718141092,2.807354922057604,null,1.0,0.0,null,null,5.643856189774724,4.0,2.321928094887362,0.0,5.584962500721156,1.584962500721156,4.459431618637297,3.584962500721156,null,2.807354922057604,1.584962500721156,null,3.584962500721156,2.584962500721156,null,null,4.584962500721156,4.0,2.321928094887362,null,4.0,1.584962500721156,2.807354922057604,3.0,null,2.0,1.0,1.0,2.321928094887362,1.0,null,null,5.857980995127572,6.643856189774724,3.321928094887362,3.584962500721156,6.820178962415188,2.807354922057604,5.954196310386875,6.022367813028454,null,5.169925001442312,4.169925001442312,2.0,6.044394119358453,5.044394119358453,null,null,8.060695931687555,null,null,1.584962500721156,2.321928094887362,null,0.0,4.087462841250339,null,0.0,null,null,2.0,1.0,null,null,4.392317422778761,6.426264754702098,3.169925001442312,3.700439718141092,7.169925001442312,3.700439718141092,6.741466986401147,5.491853096329675,null,5.169925001442312,5.20945336562895,3.807354922057604,3.807354922057604,2.807354922057604,null,null,6.066089190457772,4.584962500721156,2.321928094887362,0.0,3.0,1.0,1.584962500721156,3.700439718141092,null,1.0,2.0,1.0,4.321928094887363,3.321928094887362,null,null,5.977279923499917,2.0,null,null,null,null,2.0,1.0,null,null,null,null,1.0,0.0,null,null,2.584962500721156,null,null,null,null,null,null,1.584962500721156,null,null,null,null,1.0,0.0,null,null,null,4.906890595608519,2.0,3.0,3.169925001442312,2.0,3.807354922057604,5.129283016944966,null,2.584962500721156,2.321928094887362,2.584962500721156,3.0,2.0,null,null,6.303780748177103,7.417852514885898,4.087462841250339,5.584962500721156,7.330916878114617,3.321928094887362,6.066089190457772,6.845490050944375,null,4.754887502163468,5.129283016944966,3.0,6.392317422778761,5.392317422778761,null,null,8.968666793195208,5.20945336562895,2.321928094887362,2.0,5.321928094887363,0.0,4.169925001442312,4.807354922057604,null,4.807354922057604,3.0,null,4.0,3.0,null,null,6.022367813028454,4.169925001442312,0.0,2.0,3.169925001442312,2.584962500721156,3.321928094887362,3.807354922057604,null,null,2.0,null,3.321928094887362,2.321928094887362,null,null,2.0,5.247927513443585,2.321928094887362,3.700439718141092,6.491853096329675,1.0,4.954196310386875,6.129283016944966,null,3.807354922057604,3.4594316186372973,null,5.459431618637297,4.459431618637297,null,null,5.129283016944966,7.189824558880018,3.9068905956085187,5.20945336562895,7.971543553950772,3.700439718141092,6.129283016944966,7.312882955284356,null,4.584962500721156,6.022367813028454,3.0,6.643856189774724,5.643856189774724,null,null,7.3750394313469245,2.0,null,null,2.584962500721156,null,null,1.0,null,3.169925001442312,null,null,null,null,null,null,2.807354922057604,3.584962500721156,null,null,4.700439718141092,1.0,2.0,3.4594316186372973,null,2.0,3.0,0.0,4.169925001442312,3.169925001442312,null,null,6.169925001442312,5.523561956057013,3.584962500721156,3.4594316186372973,6.845490050944375,2.584962500721156,6.321928094887363,5.954196310386875,null,4.584962500721156,4.584962500721156,2.584962500721156,5.169925001442312,4.169925001442312,null,null,7.672425341971495,7.011227255423254,4.247927513443585,4.321928094887363,4.954196310386875,3.4594316186372973,5.285402218862249,6.459431618637297,null,4.643856189774724,5.044394119358453,2.321928094887362,4.321928094887363,3.321928094887362,null,null,8.228818690495881,4.459431618637297,2.321928094887362,4.392317422778761,6.22881869049588,2.0,5.357552004618084,5.0,null,3.9068905956085187,2.321928094887362,1.584962500721156,5.700439718141092,4.700439718141092,null,null,8.103287808412022,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,8.03342300153745,4.906890595608519,5.78135971352466,8.113742166049189,4.700439718141092,1.0,6.845490050944375,null,1.0,5.930737337562887,5.614709844115208,6.672425341971495,5.672425341971495,null,null,7.044394119358453,7.159871336778389,3.321928094887362,3.4594316186372973,6.066089190457772,null,3.4594316186372973,5.169925001442312,null,4.392317422778761,3.4594316186372973,2.584962500721156,4.459431618637297,3.4594316186372973,null,null,4.523561956057013,5.0,2.807354922057604,3.169925001442312,5.584962500721156,1.0,4.807354922057604,5.459431618637297,null,4.0,3.321928094887362,1.584962500721156,3.321928094887362,2.321928094887362,null,null,5.554588851677638,6.643856189774724,3.9068905956085187,4.247927513443585,6.539158811108031,2.807354922057604,5.554588851677638,6.475733430966398,null,5.321928094887363,4.321928094887363,1.0,6.0,5.0,null,null,5.906890595608519,4.0,null,2.321928094887362,4.954196310386875,1.584962500721156,4.700439718141092,4.754887502163468,null,3.0,2.0,1.0,3.584962500721156,2.584962500721156,null,null,5.0,5.087462841250339,2.321928094887362,2.321928094887362,4.754887502163468,1.584962500721156,2.584962500721156,5.087462841250339,1.584962500721156,1.584962500721156,2.0,1.0,4.321928094887363,3.321928094887362,null,null,4.169925001442312,6.475733430966398,4.247927513443585,4.523561956057013,6.569855608330948,2.584962500721156,6.022367813028454,5.554588851677638,null,5.392317422778761,3.584962500721156,3.0,5.954196310386875,5.0,null,null,5.285402218862249,5.643856189774724,3.169925001442312,3.169925001442312,5.807354922057604,1.584962500721156,5.321928094887363,4.584962500721156,null,3.807354922057604,3.584962500721156,null,5.906890595608519,4.906890595608519,null,null,5.807354922057604,5.643856189774724,3.0,3.0,5.459431618637297,0.0,4.584962500721156,5.285402218862249,0.0,4.169925001442312,3.0,2.0,3.584962500721156,2.584962500721156,null,null,4.392317422778761,3.584962500721156,0.0,null,4.459431618637297,null,2.0,3.700439718141092,null,3.700439718141092,3.321928094887362,null,4.169925001442312,3.169925001442312,null,null,2.321928094887362,5.584962500721156,3.321928094887362,2.0,5.285402218862249,2.807354922057604,4.459431618637297,5.643856189774724,null,2.584962500721156,3.169925001442312,null,4.584962500721156,3.584962500721156,null,null,6.741466986401147,null,null,null,null,null,null,0.0,null,null,null,null,1.584962500721156,0.0,null,null,null,8.154818109052105,5.169925001442312,6.475733430966398,8.991521846075695,5.426264754702098,7.303780748177103,8.0,null,5.700439718141092,6.392317422778761,5.285402218862249,8.011227255423254,7.011227255423254,null,null,7.826548487290915,8.611024797307353,5.129283016944966,5.554588851677638,8.022367813028454,4.906890595608519,6.614709844115208,7.219168520462161,0.0,6.459431618637297,6.539158811108031,5.0,7.569855608330948,6.584962500721156,null,null,6.857980995127572,8.813781191217037,6.066089190457772,7.400879436282184,9.862637357558794,6.087462841250339,8.741466986401146,9.076815597050832,null,6.643856189774724,7.366322214245816,0.0,8.804131021183318,7.800899899920305,null,null,7.614709844115208,5.459431618637297,3.4594316186372973,3.807354922057604,6.266786540694901,2.807354922057604,6.0,6.285402218862249,null,5.321928094887363,3.321928094887362,3.584962500721156,5.754887502163468,4.754887502163468,null,null,6.475733430966398,7.409390936137702,3.584962500721156,3.807354922057604,7.087462841250339,4.0,5.930737337562887,5.930737337562887,0.0,5.523561956057013,4.700439718141092,3.9068905956085187,6.022367813028454,5.0,null,null,6.303780748177103,5.906890595608519,2.807354922057604,3.4594316186372973,5.459431618637297,1.0,5.169925001442312,4.700439718141092,null,2.0,4.321928094887363,2.584962500721156,4.392317422778761,3.321928094887362,null,null,3.9068905956085187,7.546894459887636,3.9068905956085187,5.882643049361842,8.005624549193879,3.169925001442312,6.807354922057604,6.459431618637297,null,5.169925001442312,5.491853096329675,null,7.05528243550119,6.066089190457772,null,null,7.022367813028454,4.169925001442312,2.584962500721156,3.584962500721156,5.977279923499917,2.807354922057604,5.807354922057604,6.266786540694901,null,2.584962500721156,3.321928094887362,2.0,6.700439718141092,5.727920454563199,null,null,8.087462841250339,5.0,2.584962500721156,3.4594316186372973,5.554588851677638,1.0,4.087462841250339,3.584962500721156,null,3.584962500721156,3.321928094887362,1.0,4.459431618637297,3.4594316186372973,null,null,5.321928094887363,4.0,null,1.584962500721156,5.523561956057013,0.0,2.321928094887362,3.4594316186372973,null,3.321928094887362,0.0,null,4.754887502163468,3.700439718141092,null,null,4.906890595608519,4.247927513443585,1.584962500721156,2.807354922057604,5.906890595608519,null,2.584962500721156,5.672425341971495,null,1.584962500721156,2.0,1.0,3.700439718141092,2.807354922057604,null,null,5.129283016944966,null,null,null,null,null,null,0.0,null,1.584962500721156,null,0.0,null,null,null,null,null,9.952741247186488,7.643856189774724,8.179909090014934,9.199672344836364,7.6865005271832185,8.900866807980748,8.703903573444663,1.0,7.845490050944375,8.696967526234287,6.459431618637297,8.703903573444663,7.714245517666122,null,null,7.658211482751795,8.366322214245816,5.357552004618084,5.672425341971495,8.447083226209653,4.643856189774724,3.169925001442312,6.20945336562895,1.584962500721156,5.523561956057013,6.189824558880018,4.523561956057013,6.754887502163468,5.754887502163468,null,null,7.400879436282184,5.857980995127572,2.321928094887362,2.321928094887362,6.066089190457772,2.807354922057604,5.285402218862249,6.714245517666122,null,4.700439718141092,3.4594316186372973,null,5.807354922057604,4.807354922057604,null,null,5.285402218862249,7.366322214245816,4.700439718141092,5.459431618637297,7.22881869049588,3.321928094887362,6.554588851677638,6.475733430966398,null,5.247927513443585,5.129283016944966,3.807354922057604,6.658211482751795,5.672425341971495,null,null,6.845490050944375,null,null,null,3.4594316186372973,1.0,1.584962500721156,2.584962500721156,null,0.0,null,null,null,null,null,null,2.321928094887362,5.491853096329675,1.0,3.4594316186372973,6.0,1.0,2.584962500721156,3.584962500721156,null,2.807354922057604,3.4594316186372973,2.0,4.0,3.0,null,null,3.584962500721156,4.523561956057013,2.321928094887362,3.4594316186372973,6.658211482751795,2.0,5.584962500721156,5.930737337562887,null,2.0,3.0,1.0,5.392317422778761,4.392317422778761,null,null,7.523561956057013,4.169925001442312,2.584962500721156,1.0,5.20945336562895,1.584962500721156,4.584962500721156,3.169925001442312,null,3.321928094887362,1.0,null,4.700439718141092,3.700439718141092,null,null,4.087462841250339,4.169925001442312,2.321928094887362,1.0,3.0,null,2.584962500721156,3.584962500721156,0.0,2.321928094887362,2.0,1.0,3.4594316186372973,2.321928094887362,null,null,4.087462841250339,5.523561956057013,3.169925001442312,2.584962500721156,5.169925001442312,1.584962500721156,2.584962500721156,1.584962500721156,null,3.807354922057604,2.584962500721156,3.0,3.0,2.0,null,null,3.807354922057604,null,null,0.0,2.0,0.0,0.0,1.584962500721156,null,1.0,0.0,0.0,null,null,null,null,1.0,null,null,null,null,null,null,null,null,0.0,null,0.0,0.0,null,null,null,null,8.842350343413807,4.906890595608519,3.584962500721156,4.954196310386875,4.857980995127572,5.129283016944966,5.426264754702098,null,5.285402218862249,5.321928094887363,4.906890595608519,4.392317422778761,3.321928094887362,null,null,6.285402218862249,7.820178962415188,3.4594316186372973,4.321928094887363,6.189824558880018,3.4594316186372973,4.459431618637297,5.754887502163468,null,3.9068905956085187,5.0,1.0,6.247927513443585,5.247927513443585,null,null,6.768184324776926,7.870364719583405,4.087462841250339,3.807354922057604,4.857980995127572,1.0,3.9068905956085187,4.169925001442312,null,6.523561956057013,3.169925001442312,2.807354922057604,3.584962500721156,2.584962500721156,null,null,4.643856189774724,6.930737337562887,4.754887502163468,5.087462841250339,6.714245517666122,3.700439718141092,5.882643049361842,5.78135971352466,0.0,6.339850002884624,5.247927513443585,1.0,5.523561956057013,4.523561956057013,null,null,5.857980995127572,5.0,1.584962500721156,1.584962500721156,4.523561956057013,2.0,3.321928094887362,4.169925001442312,null,5.20945336562895,2.807354922057604,2.584962500721156,3.321928094887362,2.321928094887362,null,null,2.807354922057604,5.321928094887363,2.584962500721156,1.584962500721156,4.954196310386875,2.321928094887362,3.169925001442312,3.700439718141092,null,2.807354922057604,2.0,null,4.247927513443585,3.169925001442312,null,null,6.022367813028454,9.832890014164741,6.584962500721156,6.807354922057604,8.379378367071261,5.169925001442312,6.554588851677638,7.417852514885898,0.0,8.076815597050832,7.03342300153745,6.066089190457772,7.169925001442312,6.189824558880018,null,null,9.098032082960527,4.807354922057604,0.0,0.0,2.807354922057604,null,0.0,3.0,null,1.584962500721156,1.584962500721156,1.0,1.584962500721156,0.0,null,null,1.0,7.294620748891627,5.882643049361842,3.9068905956085187,7.693486957499325,4.700439718141092,5.584962500721156,6.0,null,4.954196310386875,5.169925001442312,0.0,6.20945336562895,5.20945336562895,null,null,7.562242424221073,5.087462841250339,2.0,2.0,4.321928094887363,2.0,2.584962500721156,3.0,null,4.643856189774724,2.0,1.0,2.584962500721156,1.584962500721156,null,null,5.78135971352466,6.044394119358453,2.584962500721156,2.807354922057604,4.459431618637297,0.0,2.584962500721156,4.321928094887363,null,3.807354922057604,2.0,null,2.0,1.0,null,null,3.807354922057604,null,null,null,null,null,null,1.0,null,0.0,null,null,null,null,null,null,null,9.283088353024002,5.832890014164741,7.294620748891627,7.451211111832329,5.643856189774724,7.149747119504682,5.247927513443585,0.0,8.219168520462162,7.417852514885898,5.672425341971495,6.658211482751795,5.672425341971495,null,null,7.076815597050831,11.406205005418855,8.049848549450562,8.113742166049189,9.611024797307353,7.3750394313469245,9.071462362556623,8.774787059601174,2.0,8.189824558880018,9.224001674198105,6.523561956057013,8.169925001442312,7.169925001442312,2.584962500721156,2.584962500721156,8.228818690495881,5.700439718141092,2.807354922057604,3.169925001442312,3.700439718141092,null,3.700439718141092,3.700439718141092,null,4.087462841250339,2.0,null,2.584962500721156,1.584962500721156,null,null,4.321928094887363,6.672425341971495,2.584962500721156,2.807354922057604,6.22881869049588,4.169925001442312,5.832890014164741,4.643856189774724,0.0,4.700439718141092,4.807354922057604,null,4.0,3.0,null,null,6.672425341971495,1.0,0.0,null,null,0.0,null,null,null,0.0,null,null,null,null,null,null,null,4.169925001442312,null,null,1.0,null,null,null,null,2.0,null,1.0,1.0,0.0,null,null,1.584962500721156,8.066089190457772,4.906890595608519,4.0,5.807354922057604,2.584962500721156,3.321928094887362,3.4594316186372973,null,6.129283016944966,4.700439718141092,3.807354922057604,5.614709844115208,4.700439718141092,null,null,6.78135971352466,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.672425341971495,3.807354922057604,2.584962500721156,5.321928094887363,2.584962500721156,4.584962500721156,4.754887502163468,null,5.727920454563199,4.643856189774724,3.700439718141092,4.247927513443585,3.321928094887362,null,null,5.807354922057604,null,0.0,null,null,null,null,null,null,1.0,null,null,1.0,null,null,null,null,6.741466986401147,4.247927513443585,4.087462841250339,5.614709844115208,2.321928094887362,4.321928094887363,4.087462841250339,null,5.906890595608519,4.087462841250339,3.0,3.169925001442312,2.0,null,null,6.569855608330948,1.0,null,null,null,null,null,0.0,null,1.0,null,null,1.0,null,null,null,0.0,null,0.0,0.0,3.321928094887362,1.584962500721156,3.169925001442312,2.807354922057604,null,null,null,1.584962500721156,3.584962500721156,2.584962500721156,null,null,5.459431618637297,null,null,null,0.0,0.0,0.0,null,null,null,0.0,null,1.584962500721156,0.0,null,null,null,4.459431618637297,4.169925001442312,4.700439718141092,6.965784284662087,3.584962500721156,7.22881869049588,5.977279923499917,0.0,4.807354922057604,4.247927513443585,4.523561956057013,6.129283016944966,5.20945336562895,null,null,8.839203788096944,5.321928094887363,3.9068905956085187,6.741466986401147,8.0,4.906890595608519,7.451211111832329,7.330916878114617,2.0,3.0,6.0,5.087462841250339,6.189824558880018,5.247927513443585,null,null,9.233619676759702,3.321928094887362,3.0,5.20945336562895,7.577428828035749,2.321928094887362,7.118941072723508,7.076815597050831,null,4.857980995127572,3.807354922057604,4.459431618637297,3.9068905956085187,2.807354922057604,null,null,8.820178962415188,null,2.0,1.584962500721156,0.0,null,2.807354922057604,2.0,null,0.0,1.0,null,2.0,1.0,null,null,2.0,1.0,1.584962500721156,null,null,null,null,1.0,null,2.584962500721156,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.0,null,2.584962500721156,2.0,2.807354922057604,null,1.0,1.584962500721156,null,null,null,2.0,2.0,1.0,null,null,4.0,null,2.0,1.584962500721156,3.169925001442312,0.0,1.0,3.9068905956085187,null,2.0,1.584962500721156,null,1.0,0.0,null,null,5.044394119358453,1.0,1.0,2.0,2.0,null,0.0,1.584962500721156,null,2.0,1.584962500721156,null,2.0,1.0,null,null,4.700439718141092,null,null,null,2.0,null,2.321928094887362,1.0,null,2.0,null,null,2.584962500721156,1.584962500721156,null,null,5.129283016944966,3.0,1.0,3.584962500721156,6.066089190457772,2.0,5.247927513443585,4.906890595608519,null,3.700439718141092,3.321928094887362,2.0,3.0,2.0,null,null,8.098032082960527,4.247927513443585,4.954196310386875,5.357552004618084,7.044394119358453,3.584962500721156,6.066089190457772,5.906890595608519,null,5.727920454563199,5.357552004618084,3.584962500721156,6.491853096329675,5.491853096329675,null,null,8.184875342908283,null,null,null,0.0,null,null,0.0,null,null,null,null,null,null,null,null,1.584962500721156,1.0,1.0,3.700439718141092,4.700439718141092,2.321928094887362,2.584962500721156,3.584962500721156,null,2.0,3.321928094887362,3.0,3.807354922057604,2.807354922057604,null,null,6.569855608330948,null,null,1.0,1.0,null,2.0,1.584962500721156,null,2.0,null,null,3.0,2.0,null,null,3.584962500721156,null,null,null,1.584962500721156,null,0.0,0.0,null,null,0.0,null,1.0,0.0,null,null,4.459431618637297,2.584962500721156,3.169925001442312,1.584962500721156,4.523561956057013,null,4.700439718141092,4.247927513443585,null,null,3.0,2.0,4.643856189774724,3.584962500721156,null,null,6.794415866350106,null,null,2.584962500721156,5.169925001442312,null,4.087462841250339,1.584962500721156,null,0.0,1.584962500721156,null,null,null,null,null,5.727920454563199,null,null,1.0,1.0,0.0,3.321928094887362,1.584962500721156,null,2.321928094887362,null,1.0,0.0,null,null,null,4.169925001442312,null,0.0,2.321928094887362,4.459431618637297,2.321928094887362,3.807354922057604,4.906890595608519,null,1.0,1.0,2.584962500721156,null,null,null,null,5.247927513443585,1.0,0.0,2.0,2.584962500721156,0.0,3.4594316186372973,3.0,null,0.0,1.584962500721156,1.0,2.584962500721156,1.584962500721156,null,null,5.672425341971495,null,0.0,0.0,null,0.0,1.0,1.584962500721156,null,null,null,null,1.0,0.0,null,null,0.0,1.0,2.0,0.0,3.169925001442312,null,3.321928094887362,3.169925001442312,null,2.584962500721156,null,null,null,null,null,null,4.643856189774724,3.584962500721156,3.584962500721156,5.392317422778761,7.285402218862249,5.0,6.768184324776926,7.108524456778169,1.0,1.584962500721156,4.700439718141092,3.321928094887362,5.087462841250339,4.087462841250339,null,null,8.861086905995395,1.0,1.584962500721156,null,4.0,null,3.0,4.643856189774724,null,2.584962500721156,0.0,0.0,4.087462841250339,3.0,null,null,4.807354922057604,0.0,1.0,null,1.0,null,2.0,0.0,null,1.0,null,null,null,null,null,null,2.807354922057604,3.807354922057604,2.807354922057604,3.0,4.247927513443585,1.0,4.906890595608519,3.169925001442312,null,2.0,2.321928094887362,null,2.584962500721156,1.584962500721156,null,null,7.870364719583405,2.0,1.0,2.0,4.392317422778761,1.0,4.459431618637297,4.459431618637297,null,1.0,3.4594316186372973,3.0,2.807354922057604,2.0,null,null,2.807354922057604,2.584962500721156,0.0,1.584962500721156,4.643856189774724,1.0,2.807354922057604,2.0,null,2.0,0.0,2.0,4.700439718141092,3.700439718141092,null,null,5.672425341971495,1.0,null,0.0,3.0,1.584962500721156,3.700439718141092,1.0,null,1.0,0.0,null,3.0,2.0,null,null,5.906890595608519,null,0.0,0.0,1.584962500721156,1.0,2.0,0.0,null,null,1.0,null,1.584962500721156,0.0,null,null,5.169925001442312,null,null,null,1.0,null,0.0,2.584962500721156,0.0,1.0,0.0,null,2.321928094887362,1.0,null,null,3.4594316186372973,1.584962500721156,null,2.321928094887362,3.4594316186372973,1.0,3.700439718141092,1.0,null,2.0,2.0,2.0,null,null,null,null,6.409390936137702,null,null,null,0.0,null,1.0,2.584962500721156,null,null,0.0,null,0.0,0.0,null,null,4.247927513443585,4.459431618637297,4.247927513443585,5.20945336562895,6.741466986401147,2.584962500721156,6.087462841250339,6.357552004618084,null,3.169925001442312,4.906890595608519,4.247927513443585,4.392317422778761,3.584962500721156,null,null,7.839203788096944,4.584962500721156,3.4594316186372973,4.643856189774724,5.426264754702098,2.807354922057604,5.523561956057013,5.129283016944966,1.0,2.0,3.807354922057604,3.321928094887362,null,null,null,null,7.98299357469431,1.0,2.584962500721156,2.807354922057604,5.700439718141092,2.584962500721156,4.321928094887363,4.754887502163468,null,1.0,2.807354922057604,null,5.087462841250339,4.087462841250339,null,null,6.820178962415188,4.321928094887363,2.807354922057604,3.321928094887362,5.247927513443585,3.0,5.426264754702098,4.906890595608519,null,1.0,3.169925001442312,3.584962500721156,null,null,null,null,7.523561956057013,null,null,null,null,null,2.0,null,null,1.584962500721156,1.584962500721156,null,1.0,0.0,null,null,0.0,null,null,1.0,2.584962500721156,null,null,2.0,null,2.584962500721156,0.0,null,0.0,null,null,null,4.857980995127572,2.0,0.0,0.0,null,1.0,1.584962500721156,2.584962500721156,null,2.0,null,null,null,null,null,null,2.321928094887362,1.0,0.0,1.0,0.0,0.0,3.0,1.0,null,1.0,1.584962500721156,null,1.0,0.0,null,null,1.0,2.584962500721156,1.584962500721156,2.584962500721156,3.700439718141092,0.0,3.700439718141092,3.4594316186372973,null,null,2.807354922057604,2.0,null,null,null,null,6.392317422778761,null,null,null,2.0,null,3.169925001442312,null,null,1.0,1.0,null,null,null,null,null,2.321928094887362,null,null,1.0,2.807354922057604,0.0,2.807354922057604,2.807354922057604,null,1.0,1.0,1.0,null,null,null,null,4.754887502163468,null,null,null,null,null,0.0,1.0,null,0.0,null,null,null,null,null,null,2.0,null,null,0.0,2.807354922057604,0.0,null,1.0,null,1.0,null,1.0,null,null,null,null,4.643856189774724,5.247927513443585,4.523561956057013,4.954196310386875,6.643856189774724,4.247927513443585,6.794415866350106,6.266786540694901,1.584962500721156,6.409390936137702,5.285402218862249,4.169925001442312,6.475733430966398,5.491853096329675,null,null,8.829722735086058,4.700439718141092,3.700439718141092,5.321928094887363,7.266786540694901,3.584962500721156,5.584962500721156,6.303780748177103,0.0,4.807354922057604,4.087462841250339,4.087462841250339,5.392317422778761,4.392317422778761,null,null,9.566054038171092,null,1.0,2.0,3.584962500721156,null,4.247927513443585,3.321928094887362,null,3.0,0.0,null,4.0,3.0,null,null,5.672425341971495,null,1.584962500721156,1.584962500721156,2.321928094887362,0.0,2.0,0.0,null,null,0.0,1.584962500721156,null,null,null,null,2.584962500721156,1.0,0.0,0.0,4.700439718141092,2.584962500721156,3.321928094887362,2.321928094887362,null,2.584962500721156,0.0,2.0,4.954196310386875,3.9068905956085187,null,null,4.584962500721156,1.0,0.0,1.0,4.392317422778761,null,3.169925001442312,2.0,null,null,0.0,null,2.321928094887362,1.584962500721156,null,null,6.303780748177103,2.0,null,2.321928094887362,3.4594316186372973,null,0.0,4.169925001442312,null,null,0.0,null,null,null,null,null,5.087462841250339,3.9068905956085187,2.584962500721156,4.584962500721156,6.599912842187128,3.169925001442312,5.426264754702098,4.459431618637297,null,2.584962500721156,2.807354922057604,1.0,6.044394119358453,5.044394119358453,null,null,8.144658242831882,null,0.0,1.584962500721156,2.584962500721156,2.321928094887362,4.643856189774724,4.247927513443585,null,null,2.0,null,null,null,null,null,5.977279923499917,null,1.584962500721156,1.0,3.700439718141092,1.0,2.807354922057604,3.0,null,0.0,2.0,1.0,3.0,2.0,null,null,5.129283016944966,null,null,1.0,4.0,1.584962500721156,1.584962500721156,3.321928094887362,0.0,2.0,1.584962500721156,1.0,2.584962500721156,1.584962500721156,null,null,5.807354922057604,null,null,null,1.0,null,null,2.0,null,1.0,null,1.584962500721156,null,null,null,null,2.0,2.584962500721156,3.169925001442312,1.584962500721156,3.584962500721156,1.584962500721156,4.459431618637297,4.247927513443585,null,2.321928094887362,0.0,2.0,4.584962500721156,3.584962500721156,null,null,5.523561956057013,null,1.584962500721156,4.392317422778761,5.0,2.0,5.247927513443585,5.285402218862249,0.0,1.0,2.584962500721156,2.584962500721156,4.906890595608519,3.9068905956085187,null,null,7.199672344836364,4.584962500721156,4.247927513443585,6.0,6.266786540694901,4.459431618637297,6.087462841250339,6.108524456778169,0.0,0.0,4.754887502163468,4.584962500721156,5.643856189774724,4.700439718141092,null,null,8.787902559391432,null,null,null,null,0.0,null,null,null,1.0,null,null,null,null,null,null,2.321928094887362,null,0.0,2.584962500721156,3.700439718141092,0.0,3.700439718141092,4.754887502163468,null,null,2.321928094887362,null,1.584962500721156,1.0,null,null,5.857980995127572,null,1.0,null,2.321928094887362,null,1.584962500721156,null,null,null,0.0,1.0,2.0,1.0,null,null,3.584962500721156,2.584962500721156,null,2.321928094887362,2.321928094887362,null,2.0,3.321928094887362,null,1.0,0.0,1.0,2.0,1.0,null,null,5.392317422778761,2.0,2.0,1.0,3.169925001442312,1.0,3.169925001442312,3.807354922057604,null,null,1.0,null,null,null,null,null,4.754887502163468,2.0,1.0,null,1.584962500721156,null,0.0,0.0,null,3.321928094887362,0.0,null,2.0,1.0,null,null,4.392317422778761,null,null,1.0,1.584962500721156,1.584962500721156,0.0,null,null,1.0,null,null,null,null,null,null,3.0,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,null,2.0,2.807354922057604,4.754887502163468,4.523561956057013,4.954196310386875,3.321928094887362,3.4594316186372973,3.4594316186372973,1.0,5.426264754702098,2.807354922057604,4.321928094887363,3.807354922057604,2.807354922057604,null,null,6.169925001442312,1.0,1.584962500721156,null,null,null,2.0,1.584962500721156,null,0.0,null,null,1.0,0.0,null,null,1.584962500721156,5.0,4.0,0.0,3.584962500721156,3.169925001442312,4.0,4.169925001442312,0.0,3.584962500721156,4.0,2.584962500721156,null,null,null,null,1.0,3.584962500721156,5.0,3.700439718141092,5.459431618637297,3.0,5.392317422778761,5.554588851677638,null,4.906890595608519,4.392317422778761,4.584962500721156,3.9068905956085187,2.807354922057604,null,null,6.108524456778169,2.584962500721156,3.700439718141092,3.700439718141092,3.169925001442312,1.0,null,3.321928094887362,null,4.807354922057604,3.321928094887362,2.807354922057604,3.807354922057604,2.807354922057604,null,null,4.643856189774724,2.0,null,null,1.0,1.584962500721156,1.584962500721156,null,null,0.0,1.584962500721156,null,0.0,null,null,null,0.0,null,1.584962500721156,1.0,1.584962500721156,1.0,0.0,1.0,null,4.087462841250339,1.584962500721156,2.0,1.0,0.0,null,null,3.700439718141092,2.0,2.0,1.584962500721156,2.0,1.0,1.0,null,null,1.584962500721156,1.584962500721156,null,2.321928094887362,1.0,null,null,2.584962500721156,1.0,null,0.0,2.807354922057604,0.0,3.169925001442312,1.0,null,0.0,3.169925001442312,2.0,null,null,null,null,5.459431618637297,null,1.0,1.584962500721156,0.0,1.0,0.0,0.0,null,null,1.0,0.0,null,null,null,null,2.584962500721156,null,null,null,1.0,0.0,null,null,null,null,1.584962500721156,null,null,null,null,null,3.321928094887362,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.0,2.0,3.169925001442312,1.0,1.0,2.807354922057604,2.321928094887362,null,4.700439718141092,2.807354922057604,1.0,2.807354922057604,2.0,null,null,1.584962500721156,8.098032082960527,8.539158811108031,8.933690654952233,9.228818690495881,7.622051819456376,9.08214904135387,8.826548487290914,4.087462841250339,9.776433032444734,8.566054038171092,8.535275376620802,7.787902559391432,6.768184324776926,null,null,10.467605550082997,2.0,1.0,0.0,2.0,2.321928094887362,null,2.321928094887362,null,2.584962500721156,0.0,4.169925001442312,2.0,1.0,null,null,4.169925001442312,3.0,3.807354922057604,4.906890595608519,5.78135971352466,4.392317422778761,4.807354922057604,4.954196310386875,0.0,5.169925001442312,4.906890595608519,3.584962500721156,0.0,null,null,null,6.569855608330948,5.169925001442312,4.087462841250339,3.169925001442312,5.672425341971495,2.321928094887362,4.857980995127572,5.614709844115208,0.0,3.0,4.643856189774724,3.807354922057604,1.584962500721156,1.0,null,null,8.139551352398794,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.584962500721156,2.0,2.0,2.584962500721156,0.0,0.0,2.0,3.169925001442312,0.0,1.0,2.807354922057604,2.0,1.0,0.0,null,null,4.321928094887363,null,null,2.0,2.584962500721156,0.0,1.0,3.0,null,null,1.0,1.0,1.0,0.0,null,null,5.357552004618084,null,null,null,null,null,0.0,null,null,null,null,0.0,null,null,null,null,null,1.0,null,1.0,null,null,0.0,null,null,1.0,null,null,1.584962500721156,0.0,null,null,1.0,2.0,1.0,2.0,2.807354922057604,1.0,1.0,3.169925001442312,null,3.321928094887362,2.584962500721156,1.584962500721156,1.0,0.0,null,null,4.169925001442312,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,5.129283016944966,3.807354922057604,4.0,6.906890595608519,4.321928094887363,6.930737337562887,6.569855608330948,null,3.4594316186372973,5.247927513443585,5.20945336562895,5.459431618637297,4.459431618637297,null,null,6.554588851677638,5.614709844115208,4.523561956057013,6.832890014164741,6.066089190457772,4.584962500721156,6.658211482751795,6.672425341971495,null,5.044394119358453,6.339850002884624,6.357552004618084,5.129283016944966,4.087462841250339,null,null,6.475733430966398,5.754887502163468,5.491853096329675,7.924812503605781,8.027905996569885,6.321928094887363,8.63662462054365,8.46352437327118,1.0,6.768184324776926,7.539158811108031,7.303780748177103,7.1799090900149345,6.169925001442312,null,null,1.0,4.169925001442312,4.321928094887363,6.169925001442312,5.700439718141092,3.169925001442312,5.807354922057604,5.614709844115208,0.0,4.459431618637297,4.754887502163468,4.584962500721156,5.643856189774724,4.643856189774724,null,null,null,8.475733430966399,6.044394119358453,null,8.257387842692651,5.977279923499917,8.539158811108031,8.531381460516313,1.0,6.78135971352466,7.330916878114617,7.409390936137702,7.20945336562895,6.20945336562895,null,null,4.700439718141092,8.169925001442312,7.651051691178929,5.906890595608519,7.672425341971495,6.727920454563199,8.487840033823051,8.159871336778389,3.4594316186372973,7.523561956057013,8.339850002884624,8.308339030139408,6.894817763307944,5.882643049361842,null,null,9.640244936222345,null,5.491853096329675,null,1.584962500721156,null,null,null,null,5.643856189774724,null,1.0,1.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,0.0,6.129283016944966,5.247927513443585,4.169925001442312,5.832890014164741,4.643856189774724,6.285402218862249,6.108524456778169,0.0,5.857980995127572,5.954196310386875,4.584962500721156,5.0,4.0,null,null,6.3750394313469245,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.285402218862249,5.357552004618084,6.392317422778761,7.22881869049588,4.523561956057013,7.60733031374961,7.247927513443585,0.0,6.539158811108031,6.189824558880018,6.022367813028454,6.169925001442312,5.169925001442312,null,null,1.584962500721156,5.954196310386875,5.554588851677638,7.700439718141092,7.159871336778389,5.727920454563199,7.98299357469431,7.169925001442312,0.0,7.022367813028454,6.754887502163468,6.523561956057013,6.266786540694901,5.247927513443585,null,null,7.700439718141092,6.584962500721156,6.554588851677638,8.219168520462162,7.768184324776926,6.044394119358453,7.813781191217037,6.714245517666122,2.0,5.78135971352466,7.467605550082998,7.285402218862249,6.918863237274595,5.930737337562887,null,null,8.954196310386875,4.459431618637297,4.0,5.554588851677638,5.321928094887363,3.321928094887362,5.459431618637297,5.554588851677638,null,4.643856189774724,4.321928094887363,4.700439718141092,4.523561956057013,3.4594316186372973,null,null,6.339850002884624,4.807354922057604,4.523561956057013,7.734709620225838,6.247927513443585,5.285402218862249,7.483815777264256,7.159871336778389,1.584962500721156,5.321928094887363,6.523561956057013,6.339850002884624,5.977279923499917,4.954196310386875,null,null,8.654636028527968,6.0,5.930737337562887,7.679480099505446,7.451211111832329,5.044394119358453,7.491853096329675,7.507794640198696,0.0,6.303780748177103,6.584962500721156,6.087462841250339,5.906890595608519,4.906890595608519,null,null,8.129283016944967,5.584962500721156,5.392317422778761,1.0,8.308339030139408,6.149747119504682,8.459431618637296,8.271463027904375,1.0,6.3750394313469245,7.400879436282184,7.076815597050831,7.011227255423254,6.0,null,null,8.734709620225837,3.807354922057604,3.0,null,4.584962500721156,2.807354922057604,4.523561956057013,4.087462841250339,null,2.0,3.4594316186372973,3.584962500721156,4.807354922057604,3.807354922057604,null,null,6.266786540694901,null,4.523561956057013,null,6.3750394313469245,4.169925001442312,7.257387842692652,7.076815597050831,1.0,3.700439718141092,3.321928094887362,5.643856189774724,4.584962500721156,3.584962500721156,null,null,8.826548487290914,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.0,5.807354922057604,4.954196310386875,3.321928094887362,6.894817763307944,5.523561956057013,7.577428828035749,7.672425341971495,2.321928094887362,5.700439718141092,6.832890014164741,6.714245517666122,6.20945336562895,5.20945336562895,null,null,7.426264754702098,2.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.459431618637297,2.584962500721156,4.169925001442312,6.189824558880018,4.169925001442312,6.285402218862249,6.409390936137702,0.0,3.807354922057604,5.087462841250339,4.321928094887363,4.857980995127572,3.9068905956085187,null,null,7.087462841250339,2.0,2.0,3.169925001442312,1.584962500721156,null,3.4594316186372973,3.169925001442312,0.0,2.0,2.0,2.0,null,null,null,null,4.643856189774724,5.247927513443585,3.700439718141092,6.0,6.087462841250339,4.169925001442312,6.954196310386875,6.614709844115208,1.0,4.0,5.523561956057013,6.0,6.247927513443585,5.247927513443585,null,null,7.7481928495894605,5.643856189774724,4.459431618637297,6.087462841250339,5.426264754702098,4.321928094887363,6.409390936137702,6.266786540694901,0.0,3.584962500721156,4.954196310386875,4.700439718141092,5.0,4.0,null,null,7.2761244052742375,5.285402218862249,4.321928094887363,6.930737337562887,6.78135971352466,3.9068905956085187,6.78135971352466,6.857980995127572,1.0,5.977279923499917,5.930737337562887,5.247927513443585,5.977279923499917,5.0,null,null,7.651051691178929,4.643856189774724,4.584962500721156,6.169925001442312,6.700439718141092,4.700439718141092,6.741466986401147,6.169925001442312,null,3.807354922057604,5.832890014164741,5.643856189774724,5.044394119358453,4.087462841250339,null,null,7.499845887083206,null,0.0,null,1.0,null,2.0,1.584962500721156,null,0.0,null,null,0.0,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.0,3.584962500721156,null,5.954196310386875,3.9068905956085187,6.523561956057013,6.22881869049588,1.584962500721156,5.392317422778761,4.807354922057604,4.700439718141092,4.584962500721156,3.584962500721156,null,null,6.20945336562895,5.857980995127572,5.321928094887363,null,7.189824558880018,5.044394119358453,7.592457037268081,7.400879436282184,1.0,6.303780748177103,6.6293566200796095,6.169925001442312,5.807354922057604,4.807354922057604,null,null,8.022367813028454,4.807354922057604,4.169925001442312,4.906890595608519,6.321928094887363,4.459431618637297,6.965784284662087,6.426264754702098,null,4.643856189774724,6.321928094887363,5.554588851677638,5.700439718141092,4.700439718141092,null,null,7.651051691178929,null,null,null,null,null,1.0,2.0,null,1.0,1.0,null,null,null,null,null,1.584962500721156,5.754887502163468,4.700439718141092,4.807354922057604,6.022367813028454,4.169925001442312,6.807354922057604,6.569855608330948,1.0,4.321928094887363,5.491853096329675,5.754887502163468,5.285402218862249,4.247927513443585,null,null,7.022367813028454,5.954196310386875,3.9068905956085187,5.700439718141092,5.247927513443585,2.584962500721156,6.129283016944966,5.20945336562895,0.0,2.584962500721156,4.643856189774724,4.807354922057604,3.807354922057604,2.807354922057604,null,null,6.539158811108031,5.087462841250339,4.0,6.475733430966398,6.845490050944375,4.247927513443585,7.159871336778389,6.741466986401147,0.0,5.906890595608519,6.066089190457772,5.523561956057013,5.954196310386875,4.954196310386875,null,null,1.584962500721156,5.285402218862249,5.0,7.366322214245816,6.108524456778169,4.459431618637297,7.303780748177103,6.954196310386875,0.0,3.807354922057604,6.247927513443585,5.523561956057013,5.584962500721156,4.584962500721156,null,null,7.936637939002571,5.643856189774724,4.906890595608519,6.426264754702098,5.78135971352466,3.807354922057604,6.491853096329675,6.149747119504682,null,5.584962500721156,5.727920454563199,5.247927513443585,4.321928094887363,3.321928094887362,null,null,null,4.584962500721156,4.700439718141092,5.643856189774724,5.20945336562895,3.700439718141092,6.087462841250339,5.169925001442312,null,3.9068905956085187,5.0,4.321928094887363,4.087462841250339,3.0,null,null,8.038918989292302,null,null,null,null,null,null,1.0,null,null,null,null,1.0,0.0,null,null,4.954196310386875,6.554588851677638,6.087462841250339,2.0,7.044394119358453,5.614709844115208,6.658211482751795,6.442943495848728,2.321928094887362,5.807354922057604,7.285402218862249,7.409390936137702,5.247927513443585,4.247927513443585,null,null,7.693486957499325,6.459431618637297,5.044394119358453,null,7.266786540694901,4.857980995127572,7.584962500721156,7.643856189774724,1.584962500721156,6.066089190457772,7.129283016944966,6.977279923499917,6.426264754702098,5.426264754702098,null,null,8.294620748891626,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,1.584962500721156,7.409390936137702,5.0,3.9068905956085187,6.459431618637297,3.0,6.584962500721156,6.78135971352466,0.0,6.539158811108031,5.857980995127572,5.857980995127572,5.584962500721156,4.584962500721156,null,null,7.149747119504682,1.0,null,null,null,null,0.0,null,null,1.0,0.0,null,null,null,null,null,0.0,8.247927513443585,5.672425341971495,6.442943495848728,7.876516946564999,5.285402218862249,8.011227255423254,8.129283016944967,1.584962500721156,6.0,7.1799090900149345,6.6865005271832185,6.768184324776926,5.78135971352466,null,null,3.0,4.906890595608519,4.954196310386875,6.247927513443585,5.807354922057604,4.169925001442312,5.78135971352466,5.832890014164741,null,4.523561956057013,5.426264754702098,5.357552004618084,4.584962500721156,3.584962500721156,null,null,6.807354922057604,5.700439718141092,5.169925001442312,7.129283016944966,6.700439718141092,4.857980995127572,7.076815597050831,7.05528243550119,0.0,4.857980995127572,6.303780748177103,5.954196310386875,5.857980995127572,4.857980995127572,null,null,8.471675214392045,0.0,null,1.584962500721156,1.584962500721156,0.0,1.0,1.0,null,1.0,0.0,null,null,null,null,null,2.321928094887362,4.247927513443585,3.321928094887362,6.0,6.189824558880018,4.169925001442312,6.066089190457772,6.426264754702098,null,4.954196310386875,5.523561956057013,4.643856189774724,4.857980995127572,3.807354922057604,null,null,7.2384047393250786,6.0,4.643856189774724,5.857980995127572,5.977279923499917,4.392317422778761,6.857980995127572,6.554588851677638,null,5.129283016944966,5.882643049361842,6.044394119358453,5.754887502163468,4.754887502163468,null,null,null,null,1.0,0.0,3.0,null,2.807354922057604,1.584962500721156,null,null,1.0,1.0,0.0,null,null,null,4.087462841250339,4.0,2.321928094887362,0.0,5.169925001442312,2.321928094887362,5.169925001442312,5.727920454563199,null,4.087462841250339,3.584962500721156,3.321928094887362,4.523561956057013,3.4594316186372973,null,null,6.189824558880018,5.807354922057604,4.700439718141092,5.426264754702098,7.076815597050831,4.906890595608519,7.930737337562887,7.727920454563199,1.0,6.339850002884624,6.794415866350106,6.266786540694901,5.643856189774724,4.643856189774724,null,null,8.550746785383243,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.169925001442312,5.643856189774724,6.599912842187128,6.930737337562887,3.807354922057604,6.3750394313469245,7.108524456778169,1.584962500721156,7.219168520462161,6.149747119504682,4.584962500721156,6.022367813028454,5.0,null,null,7.417852514885898,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,6.906890595608519,5.882643049361842,3.321928094887362,8.144658242831882,6.022367813028454,8.686500527183219,8.447083226209653,2.807354922057604,6.491853096329675,7.918863237274595,7.636624620543649,6.78135971352466,5.78135971352466,null,null,9.262094845370179,6.426264754702098,6.20945336562895,8.366322214245816,7.894817763307944,4.954196310386875,7.882643049361842,7.523561956057013,1.0,7.199672344836364,7.2761244052742375,6.426264754702098,6.189824558880018,5.169925001442312,null,null,8.238404739325079,5.584962500721156,5.426264754702098,7.348728154231077,6.599912842187128,4.700439718141092,6.94251450533924,6.741466986401147,1.584962500721156,4.584962500721156,6.321928094887363,6.247927513443585,6.475733430966398,5.491853096329675,null,null,7.383704292474052,4.807354922057604,4.459431618637297,6.554588851677638,6.108524456778169,3.0,6.285402218862249,6.303780748177103,null,3.169925001442312,5.392317422778761,4.321928094887363,5.882643049361842,4.906890595608519,null,null,7.20945336562895,7.294620748891627,6.845490050944375,8.603626344986193,8.266786540694902,5.882643049361842,7.339850002884624,8.554588851677638,2.0,7.442943495848728,7.918863237274595,6.554588851677638,7.9886846867721655,7.0,null,null,9.273795599214264,null,2.0,2.0,5.357552004618084,null,5.554588851677638,5.357552004618084,null,2.584962500721156,1.584962500721156,1.0,4.169925001442312,3.169925001442312,null,null,7.03342300153745,2.0,2.584962500721156,2.0,1.584962500721156,null,2.321928094887362,0.0,null,1.0,0.0,1.0,1.0,0.0,null,null,0.0,null,0.0,0.0,0.0,null,0.0,null,null,null,null,1.0,null,null,null,null,0.0,5.643856189774724,4.584962500721156,0.0,5.169925001442312,4.169925001442312,6.0,6.066089190457772,null,3.0,5.643856189774724,5.643856189774724,5.044394119358453,4.087462841250339,null,null,7.643856189774724,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.523561956057013,4.523561956057013,4.584962500721156,5.643856189774724,4.643856189774724,6.3750394313469245,6.554588851677638,2.0,5.044394119358453,6.554588851677638,6.807354922057604,4.321928094887363,3.321928094887362,null,null,7.459431618637297,6.700439718141092,5.357552004618084,2.0,6.475733430966398,4.754887502163468,7.098032082960526,6.857980995127572,2.321928094887362,6.129283016944966,6.882643049361842,6.882643049361842,5.523561956057013,4.523561956057013,null,null,0.0,8.049848549450562,5.247927513443585,4.459431618637297,5.857980995127572,5.247927513443585,6.523561956057013,5.78135971352466,2.584962500721156,5.554588851677638,6.6865005271832185,6.918863237274595,4.807354922057604,3.700439718141092,null,null,6.845490050944375,5.78135971352466,5.426264754702098,6.285402218862249,6.044394119358453,4.700439718141092,5.977279923499917,6.0,null,5.700439718141092,6.3750394313469245,6.491853096329675,5.321928094887363,4.321928094887363,null,null,6.569855608330948,6.108524456778169,4.857980995127572,4.459431618637297,6.066089190457772,4.906890595608519,6.426264754702098,6.339850002884624,1.0,5.459431618637297,6.807354922057604,6.584962500721156,5.392317422778761,4.321928094887363,null,null,6.700439718141092,5.78135971352466,5.643856189774724,5.832890014164741,4.169925001442312,3.0,4.392317422778761,5.584962500721156,null,5.0,5.169925001442312,4.700439718141092,3.700439718141092,2.584962500721156,null,null,5.285402218862249,5.584962500721156,4.584962500721156,7.011227255423254,5.247927513443585,4.321928094887363,5.832890014164741,6.507794640198696,2.321928094887362,5.0,5.754887502163468,6.129283016944966,4.584962500721156,3.584962500721156,null,null,7.118941072723508,6.0,5.700439718141092,4.700439718141092,5.78135971352466,4.643856189774724,6.392317422778761,6.108524456778169,null,5.906890595608519,6.6293566200796095,6.0,4.169925001442312,3.169925001442312,null,null,0.0,null,null,null,0.0,null,null,null,null,0.0,null,null,null,null,null,null,0.0,8.379378367071261,5.0,3.9068905956085187,5.584962500721156,4.392317422778761,5.727920454563199,5.426264754702098,null,6.20945336562895,6.022367813028454,5.129283016944966,4.807354922057604,3.807354922057604,null,null,2.807354922057604,5.700439718141092,4.0,null,5.0,4.0,5.700439718141092,5.247927513443585,0.0,4.459431618637297,5.614709844115208,5.247927513443585,2.584962500721156,1.584962500721156,null,null,6.303780748177103,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.754887502163468,5.357552004618084,5.643856189774724,3.9068905956085187,3.9068905956085187,5.392317422778761,5.321928094887363,null,5.643856189774724,5.392317422778761,5.247927513443585,2.0,1.0,null,null,6.700439718141092,6.754887502163468,5.321928094887363,0.0,6.507794640198696,5.459431618637297,6.599912842187128,6.870364719583405,null,5.832890014164741,7.159871336778389,6.882643049361842,5.523561956057013,4.523561956057013,null,null,1.0,5.857980995127572,5.857980995127572,1.0,5.523561956057013,5.0,5.614709844115208,6.066089190457772,1.584962500721156,4.807354922057604,6.149747119504682,6.022367813028454,4.0,3.0,null,null,7.584962500721156,6.643856189774724,5.977279923499917,7.622051819456376,5.954196310386875,5.129283016944966,6.94251450533924,6.066089190457772,1.0,6.321928094887363,6.845490050944375,6.741466986401147,5.169925001442312,4.169925001442312,null,null,7.257387842692652,5.0,4.906890595608519,6.569855608330948,5.491853096329675,4.459431618637297,5.754887502163468,5.554588851677638,0.0,4.523561956057013,6.0,5.321928094887363,5.129283016944966,4.087462841250339,null,null,7.339850002884624,3.0,2.0,3.4594316186372973,3.584962500721156,1.0,2.0,3.169925001442312,null,3.0,3.584962500721156,1.0,2.0,1.0,null,null,3.807354922057604,5.906890595608519,6.108524456778169,6.741466986401147,6.6865005271832185,6.169925001442312,7.442943495848728,6.845490050944375,2.321928094887362,6.20945336562895,7.727920454563199,7.539158811108031,5.977279923499917,4.954196310386875,null,null,0.0,5.357552004618084,4.584962500721156,null,5.357552004618084,4.321928094887363,5.643856189774724,5.491853096329675,null,4.700439718141092,6.066089190457772,5.727920454563199,4.584962500721156,3.584962500721156,null,null,5.614709844115208,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.523561956057013,3.9068905956085187,null,5.643856189774724,4.0,5.20945336562895,5.523561956057013,null,4.906890595608519,6.321928094887363,6.321928094887363,3.321928094887362,2.321928094887362,null,null,6.672425341971495,5.930737337562887,5.614709844115208,null,6.066089190457772,4.523561956057013,6.442943495848728,6.539158811108031,2.0,5.357552004618084,6.768184324776926,6.409390936137702,4.087462841250339,3.0,null,null,6.78135971352466,6.754887502163468,4.169925001442312,0.0,3.807354922057604,2.584962500721156,4.754887502163468,4.392317422778761,1.0,4.392317422778761,5.285402218862249,4.906890595608519,2.584962500721156,1.584962500721156,null,null,5.044394119358453,4.906890595608519,4.807354922057604,4.169925001442312,5.491853096329675,3.584962500721156,4.459431618637297,5.727920454563199,null,6.189824558880018,5.426264754702098,4.906890595608519,4.523561956057013,3.584962500721156,null,null,1.0,6.882643049361842,5.672425341971495,2.321928094887362,6.247927513443585,5.523561956057013,6.727920454563199,6.266786540694901,1.584962500721156,6.0,7.022367813028454,6.930737337562887,5.523561956057013,4.523561956057013,null,null,6.894817763307944,null,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,5.672425341971495,7.321928094887363,4.643856189774724,9.287712379549449,5.247927513443585,8.734709620225837,8.005624549193879,1.0,8.335390354693924,7.2761244052742375,7.7073591320808825,8.124121311829187,7.129283016944966,null,null,11.34318571544788,4.169925001442312,5.285402218862249,2.807354922057604,6.727920454563199,4.754887502163468,6.741466986401147,6.247927513443585,null,6.044394119358453,6.149747119504682,5.426264754702098,6.459431618637297,5.459431618637297,null,null,9.147204924942228,5.169925001442312,6.794415866350106,3.321928094887362,8.67595703294175,5.832890014164741,8.076815597050832,7.539158811108031,null,7.700439718141092,6.658211482751795,6.022367813028454,7.442943495848728,6.459431618637297,null,null,10.842350343413807,3.169925001442312,5.727920454563199,5.285402218862249,6.918863237274595,3.700439718141092,6.78135971352466,6.714245517666122,null,5.459431618637297,5.906890595608519,5.20945336562895,6.700439718141092,5.727920454563199,null,null,9.707359132080883,4.321928094887363,5.554588851677638,3.807354922057604,8.939579214314692,5.247927513443585,8.654636028527968,7.727920454563199,null,7.357552004618084,6.087462841250339,6.965784284662087,7.813781191217037,6.845490050944375,null,null,11.257387842692651,4.954196310386875,6.169925001442312,2.807354922057604,6.78135971352466,4.459431618637297,6.409390936137702,5.554588851677638,null,7.011227255423254,5.930737337562887,6.820178962415188,6.303780748177103,5.285402218862249,null,null,9.184875342908283,4.459431618637297,6.321928094887363,null,2.321928094887362,null,2.0,4.754887502163468,null,8.022367813028454,0.0,1.0,null,null,null,null,4.321928094887363,3.700439718141092,4.643856189774724,2.584962500721156,7.6293566200796095,4.954196310386875,7.813781191217037,6.087462841250339,null,5.426264754702098,4.247927513443585,5.554588851677638,6.3750394313469245,5.392317422778761,null,null,10.216745858195306,null,0.0,null,null,null,null,1.0,null,0.0,null,null,null,null,null,null,1.0,null,4.906890595608519,1.0,6.78135971352466,4.247927513443585,6.658211482751795,6.357552004618084,null,5.523561956057013,4.700439718141092,4.906890595608519,5.554588851677638,4.523561956057013,null,null,9.579315937580015,4.754887502163468,6.189824558880018,1.584962500721156,6.491853096329675,4.459431618637297,6.022367813028454,5.523561956057013,0.0,6.700439718141092,6.087462841250339,6.108524456778169,5.523561956057013,4.523561956057013,null,null,9.057991722759176,4.321928094887363,6.108524456778169,6.727920454563199,7.832890014164741,4.0,8.118941072723507,7.303780748177103,null,7.022367813028454,5.807354922057604,6.321928094887363,7.78135971352466,6.794415866350106,null,null,10.522581531254831,4.857980995127572,7.357552004618084,5.426264754702098,8.03342300153745,5.672425341971495,7.857980995127572,7.94251450533924,null,8.224001674198105,7.199672344836364,7.066089190457772,7.3750394313469245,6.3750394313469245,null,null,11.00982861736811,6.129283016944966,7.930737337562887,3.321928094887362,8.49585502688717,6.149747119504682,8.426264754702098,7.658211482751795,null,8.744833837499545,7.754887502163468,7.2384047393250786,7.651051691178929,6.658211482751795,null,null,11.186114239541643,4.321928094887363,7.066089190457772,3.700439718141092,7.7615512324444795,5.554588851677638,8.252665432450248,7.0,null,7.807354922057604,6.977279923499917,6.491853096329675,7.266786540694901,6.285402218862249,null,null,10.52061868055628,3.0,4.906890595608519,2.584962500721156,5.78135971352466,4.0,6.918863237274595,5.727920454563199,0.0,6.087462841250339,5.977279923499917,6.321928094887363,6.426264754702098,5.491853096329675,null,null,9.189824558880018,3.0,5.727920454563199,1.0,7.851749041416057,4.754887502163468,7.459431618637297,7.475733430966398,null,6.930737337562887,5.807354922057604,5.426264754702098,6.658211482751795,5.672425341971495,null,null,10.222794902868111,6.321928094887363,7.734709620225838,2.321928094887362,9.714245517666123,6.442943495848728,9.20212382383046,8.618385502258606,null,8.686500527183219,7.864186144654281,8.326429487122303,8.968666793195208,7.98299357469431,null,null,11.635264656539514,5.426264754702098,6.954196310386875,3.584962500721156,9.016808287686555,4.954196310386875,8.491853096329674,7.888743248898259,0.0,8.335390354693924,7.247927513443585,7.714245517666122,8.280770770130603,7.2761244052742375,null,null,11.007728114632254,2.321928094887362,4.087462841250339,0.0,7.366322214245816,3.4594316186372973,6.794415866350106,5.857980995127572,null,5.357552004618084,4.523561956057013,5.857980995127572,5.882643049361842,4.906890595608519,null,null,9.649256177517314,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,1.0,4.459431618637297,6.22881869049588,2.807354922057604,7.339850002884624,5.491853096329675,7.977279923499917,7.118941072723508,null,6.882643049361842,5.954196310386875,5.0,7.108524456778169,6.108524456778169,null,null,10.573647187493322,4.169925001442312,6.3750394313469245,1.584962500721156,7.651051691178929,5.357552004618084,8.413627929024173,7.960001932068081,null,7.475733430966398,6.459431618637297,5.523561956057013,7.219168520462161,6.22881869049588,null,null,10.67595703294175,3.4594316186372973,4.392317422778761,1.0,7.219168520462161,4.392317422778761,7.515699838284043,7.1799090900149345,null,6.266786540694901,5.044394119358453,5.169925001442312,7.011227255423254,6.108524456778169,null,null,10.376125389276174,3.807354922057604,4.807354922057604,2.0,5.285402218862249,2.321928094887362,4.754887502163468,5.392317422778761,0.0,5.523561956057013,4.321928094887363,4.459431618637297,4.807354922057604,3.807354922057604,null,null,7.60733031374961,3.0,4.906890595608519,5.321928094887363,7.78135971352466,3.9068905956085187,7.599912842187128,6.820178962415188,null,5.129283016944966,5.129283016944966,5.357552004618084,7.918863237274595,6.918863237274595,null,null,10.554588851677638,3.169925001442312,5.459431618637297,2.321928094887362,7.417852514885898,3.700439718141092,7.417852514885898,6.554588851677638,0.0,6.189824558880018,5.491853096329675,5.285402218862249,7.022367813028454,6.022367813028454,null,null,9.868822554774999,6.727920454563199,7.643856189774724,6.22881869049588,9.266786540694902,5.857980995127572,8.915879378835774,8.409390936137703,0.0,9.071462362556623,7.882643049361842,8.57742882803575,8.348728154231077,7.392317422778761,null,null,11.64880694972577,3.807354922057604,6.392317422778761,4.087462841250339,8.900866807980748,5.285402218862249,8.303780748177102,7.577428828035749,null,7.451211111832329,6.475733430966398,7.499845887083206,8.071462362556623,7.098032082960526,null,null,10.933690654952233,4.459431618637297,6.247927513443585,2.584962500721156,7.434628227636725,5.321928094887363,7.994353436858858,7.312882955284356,null,6.832890014164741,6.108524456778169,6.044394119358453,7.044394119358453,6.044394119358453,null,null,10.1357092861044,4.169925001442312,6.321928094887363,2.321928094887362,7.734709620225838,5.426264754702098,7.870364719583405,8.038918989292302,null,7.483815777264256,6.3750394313469245,6.022367813028454,6.643856189774724,5.672425341971495,null,null,10.543998450134541,2.584962500721156,5.700439718141092,0.0,6.6865005271832185,4.087462841250339,7.066089190457772,6.599912842187128,null,6.247927513443585,5.614709844115208,5.247927513443585,6.149747119504682,5.169925001442312,null,null,9.850186837645774,1.0,null,null,null,null,null,1.584962500721156,null,1.0,null,0.0,null,null,null,null,0.0,3.584962500721156,5.672425341971495,2.807354922057604,6.882643049361842,4.700439718141092,7.022367813028454,7.05528243550119,null,6.339850002884624,4.906890595608519,5.392317422778761,5.643856189774724,4.643856189774724,null,null,9.800899899920305,3.0,5.0,2.321928094887362,7.839203788096944,4.584962500721156,7.918863237274595,7.159871336778389,null,6.044394119358453,5.584962500721156,3.584962500721156,7.459431618637297,6.442943495848728,null,null,10.679480099505446,2.584962500721156,4.754887502163468,1.584962500721156,6.539158811108031,3.807354922057604,6.820178962415188,6.700439718141092,null,6.189824558880018,4.523561956057013,5.247927513443585,6.129283016944966,5.129283016944966,null,null,9.620219825507487,6.700439718141092,8.308339030139408,5.0,9.030667136246942,6.339850002884624,8.848622940429339,8.262094845370179,1.584962500721156,9.419960177847889,8.487840033823051,8.055282435501189,8.285402218862249,7.285402218862249,null,null,11.421012855779226,3.700439718141092,6.087462841250339,1.584962500721156,6.918863237274595,4.392317422778761,7.417852514885898,6.507794640198696,null,6.491853096329675,5.882643049361842,4.0,5.459431618637297,4.584962500721156,null,null,9.684748620421626,5.087462841250339,6.700439718141092,4.754887502163468,8.7714894695006,5.392317422778761,8.118941072723507,6.954196310386875,null,7.794415866350106,6.794415866350106,6.741466986401147,7.658211482751795,6.658211482751795,null,null,10.9901039638575,5.807354922057604,7.515699838284043,3.169925001442312,7.924812503605781,6.357552004618084,7.965784284662087,7.159871336778389,null,8.199672344836364,7.442943495848728,7.066089190457772,7.741466986401147,6.741466986401147,null,null,10.505811553919594,5.754887502163468,7.303780748177103,3.584962500721156,7.894817763307944,6.247927513443585,8.303780748177102,8.164906926675688,null,7.800899899920305,7.05528243550119,6.189824558880018,7.539158811108031,6.539158811108031,null,null,10.794415866350105,4.169925001442312,6.266786540694901,4.087462841250339,7.768184324776926,4.807354922057604,8.179909090014934,7.679480099505446,null,7.169925001442312,6.584962500721156,6.339850002884624,6.672425341971495,5.700439718141092,null,null,10.44086916761087,5.614709844115208,7.409390936137702,3.807354922057604,7.977279923499917,5.807354922057604,8.139551352398794,7.857980995127572,null,7.6865005271832185,7.636624620543649,6.169925001442312,7.774787059601174,6.768184324776926,null,null,11.080817527608327,3.0,4.754887502163468,2.0,6.741466986401147,4.169925001442312,6.266786540694901,6.108524456778169,null,5.247927513443585,5.169925001442312,5.0,5.459431618637297,4.392317422778761,null,null,9.684748620421626,null,null,null,null,null,null,1.0,null,2.0,null,1.0,null,null,null,null,null,4.906890595608519,6.845490050944375,6.459431618637297,8.800899899920305,5.129283016944966,8.396604781181859,7.882643049361842,0.0,7.599912842187128,7.189824558880018,6.672425341971495,8.651051691178928,7.658211482751795,null,null,11.099347810403193,3.0,6.044394119358453,2.807354922057604,7.189824558880018,4.459431618637297,7.839203788096944,6.807354922057604,null,6.6293566200796095,6.22881869049588,5.426264754702098,6.94251450533924,5.954196310386875,null,null,10.184875342908283,4.643856189774724,6.285402218862249,2.321928094887362,8.507794640198696,5.169925001442312,8.43879185257826,7.539158811108031,null,7.20945336562895,6.569855608330948,6.523561956057013,7.965784284662087,6.977279923499917,null,null,11.157346935362844,5.0,6.6293566200796095,2.0,8.139551352398794,4.906890595608519,8.238404739325079,7.734709620225838,0.0,7.400879436282184,6.569855608330948,6.247927513443585,7.118941072723508,6.129283016944966,null,null,10.73809225962049,1.0,4.643856189774724,2.0,5.672425341971495,3.321928094887362,6.169925001442312,5.459431618637297,null,5.0,4.392317422778761,4.321928094887363,5.044394119358453,4.0,null,null,8.707359132080883,6.554588851677638,7.219168520462161,3.0,8.335390354693924,5.832890014164741,7.924812503605781,7.651051691178929,1.0,8.184875342908283,7.417852514885898,7.330916878114617,7.700439718141092,6.700439718141092,null,null,10.83605035505807,5.807354922057604,6.491853096329675,2.321928094887362,7.9886846867721655,5.643856189774724,7.7073591320808825,7.285402218862249,null,7.584962500721156,7.011227255423254,7.011227255423254,8.149747119504681,7.149747119504682,null,null,10.667111542075027,3.0,5.614709844115208,0.0,6.442943495848728,3.169925001442312,6.643856189774724,6.658211482751795,null,6.409390936137702,5.459431618637297,5.169925001442312,6.426264754702098,5.426264754702098,null,null,9.677719641641009,5.832890014164741,6.6293566200796095,4.954196310386875,7.6293566200796095,4.700439718141092,7.924812503605781,7.577428828035749,1.0,7.426264754702098,6.507794640198696,6.303780748177103,7.0,6.022367813028454,null,null,10.27262978497637,4.459431618637297,5.906890595608519,0.0,8.405141463136344,5.0,8.741466986401146,7.906890595608519,null,6.643856189774724,6.321928094887363,5.321928094887363,8.0,7.022367813028454,null,null,10.897845456005511,3.0,3.584962500721156,2.321928094887362,6.426264754702098,3.321928094887362,7.312882955284356,6.794415866350106,null,4.754887502163468,4.643856189774724,4.0,6.321928094887363,5.357552004618084,null,null,9.73640193131829,null,null,null,null,null,null,null,null,1.0,null,null,null,null,null,null,0.0,4.523561956057013,6.599912842187128,2.321928094887362,8.308339030139408,5.523561956057013,8.189824558880018,8.011227255423254,null,7.636624620543649,6.954196310386875,6.108524456778169,7.636624620543649,6.643856189774724,null,null,11.04916787237217,2.0,5.700439718141092,2.584962500721156,7.800899899920305,4.321928094887363,7.614709844115208,7.22881869049588,null,6.507794640198696,6.066089190457772,5.426264754702098,7.409390936137702,6.426264754702098,null,null,10.442943495848729,5.0,5.78135971352466,2.807354922057604,8.308339030139408,4.700439718141092,7.700439718141092,7.076815597050831,null,6.754887502163468,5.523561956057013,6.672425341971495,7.392317422778761,6.409390936137702,null,null,10.395534135462302,6.0,7.546894459887636,5.977279923499917,8.686500527183219,6.044394119358453,8.741466986401146,8.243173983472952,null,8.507794640198696,7.189824558880018,7.507794640198696,7.651051691178929,6.643856189774724,null,null,11.257387842692651,4.523561956057013,7.066089190457772,2.807354922057604,8.276124405274238,5.584962500721156,8.280770770130603,7.6293566200796095,1.584962500721156,7.936637939002571,6.768184324776926,7.321928094887363,7.857980995127572,6.870364719583405,null,null,10.82097669262124,7.546894459887636,8.483815777264256,3.700439718141092,9.071462362556623,6.954196310386875,8.794415866350105,8.103287808412022,2.584962500721156,9.521600439723727,8.611024797307353,9.243173983472952,8.257387842692651,7.294620748891627,null,null,11.029977346589579,4.807354922057604,5.672425341971495,1.584962500721156,6.977279923499917,5.044394119358453,7.087462841250339,6.857980995127572,null,7.159871336778389,5.392317422778761,5.392317422778761,6.0,5.0,null,null,9.733015321685963,1.0,null,null,4.584962500721156,null,4.392317422778761,3.807354922057604,null,null,1.0,1.0,3.807354922057604,2.807354922057604,null,null,7.294620748891627,6.820178962415188,7.7615512324444795,7.651051691178929,9.364134655008051,6.108524456778169,9.011227255423254,8.348728154231077,1.0,8.807354922057604,8.189824558880018,8.413627929024173,8.614709844115207,7.622051819456376,null,null,11.394462694610317,3.584962500721156,4.523561956057013,2.0,7.383704292474052,4.700439718141092,7.169925001442312,6.94251450533924,null,6.247927513443585,5.044394119358453,4.754887502163468,6.94251450533924,5.954196310386875,null,null,10.032045726930809,4.584962500721156,6.491853096329675,1.0,7.569855608330948,4.954196310386875,7.507794640198696,7.539158811108031,0.0,7.348728154231077,6.539158811108031,4.857980995127572,7.076815597050831,6.087462841250339,null,null,10.5980525001616,null,null,null,0.0,null,null,null,null,null,null,null,0.0,null,null,null,null,4.321928094887363,4.954196310386875,2.0,6.129283016944966,3.807354922057604,5.930737337562887,5.554588851677638,null,6.22881869049588,4.754887502163468,5.0,5.0,4.0,null,null,8.63662462054365,5.321928094887363,6.741466986401147,3.0,7.108524456778169,4.700439718141092,7.20945336562895,6.475733430966398,1.0,7.851749041416057,6.442943495848728,6.857980995127572,6.459431618637297,5.459431618637297,null,null,9.857980995127573,4.0,6.523561956057013,3.321928094887362,6.700439718141092,3.807354922057604,6.357552004618084,5.554588851677638,1.0,7.0,5.459431618637297,6.507794640198696,5.700439718141092,4.700439718141092,null,null,9.027905996569885,7.562242424221073,8.661778097771988,4.754887502163468,8.997179480937621,6.285402218862249,8.573647187493322,8.379378367071261,null,9.459431618637296,8.348728154231077,9.337621901992508,8.066089190457772,7.076815597050831,null,null,11.07347215397646,6.894817763307944,8.134426320220927,4.169925001442312,8.129283016944967,6.321928094887363,8.149747119504681,7.434628227636725,null,9.095397022792557,8.038918989292302,8.092757140919852,7.584962500721156,6.584962500721156,null,null,10.499845887083206,7.507794640198696,9.049848549450562,3.321928094887362,8.139551352398794,6.554588851677638,8.257387842692651,8.339850002884624,null,10.002815015607053,8.426264754702098,7.592457037268081,7.467605550082998,6.459431618637297,null,null,10.750706986224948,5.754887502163468,7.442943495848728,2.0,7.6865005271832185,5.727920454563199,7.6653359171851765,7.159871336778389,null,8.169925001442312,7.366322214245816,7.483815777264256,7.087462841250339,6.108524456778169,0.0,0.0,10.105908508571158,6.169925001442312,7.954196310386875,3.169925001442312,7.6865005271832185,5.754887502163468,8.011227255423254,7.870364719583405,null,8.78135971352466,7.562242424221073,7.643856189774724,7.467605550082998,6.475733430966398,null,null,10.399811959325685,6.3750394313469245,7.426264754702098,2.584962500721156,7.651051691178929,5.523561956057013,7.546894459887636,7.108524456778169,null,8.224001674198105,7.05528243550119,7.22881869049588,7.066089190457772,6.066089190457772,null,null,9.915879378835774,5.977279923499917,7.087462841250339,1.0,7.357552004618084,5.906890595608519,7.643856189774724,7.507794640198696,null,8.228818690495881,6.882643049361842,7.108524456778169,6.794415866350106,5.807354922057604,null,null,10.019590728357882,4.700439718141092,5.832890014164741,2.584962500721156,6.584962500721156,4.0,6.303780748177103,5.554588851677638,0.0,7.076815597050831,5.977279923499917,5.882643049361842,4.906890595608519,3.9068905956085187,null,null,9.041659151637214,null,null,null,0.0,null,1.0,null,null,null,null,null,null,null,null,null,0.0,4.906890595608519,5.700439718141092,1.0,6.189824558880018,4.643856189774724,6.569855608330948,5.672425341971495,null,6.820178962415188,5.357552004618084,7.05528243550119,5.754887502163468,4.807354922057604,null,null,9.116343961237469,5.129283016944966,6.807354922057604,3.4594316186372973,7.129283016944966,4.584962500721156,6.965784284662087,6.459431618637297,null,7.754887502163468,6.6865005271832185,6.614709844115208,6.285402218862249,5.285402218862249,null,null,9.663558104217273,3.584962500721156,5.807354922057604,1.0,4.523561956057013,2.584962500721156,5.977279923499917,4.700439718141092,null,5.700439718141092,4.459431618637297,4.0,4.321928094887363,3.321928094887362,null,null,8.344295907915816,7.78135971352466,8.894817763307943,6.78135971352466,8.643856189774725,7.129283016944966,8.960001932068081,8.199672344836364,1.584962500721156,9.954196310386875,8.974414589805527,8.73809225962049,7.876516946564999,6.906890595608519,null,null,11.449148645375436,4.906890595608519,6.599912842187128,2.584962500721156,6.727920454563199,4.247927513443585,6.507794640198696,6.0,null,7.139551352398794,6.247927513443585,6.303780748177103,5.491853096329675,4.459431618637297,null,null,9.118941072723507,6.794415866350106,7.965784284662087,4.643856189774724,8.219168520462162,6.6865005271832185,8.076815597050832,8.164906926675688,null,8.900866807980748,7.392317422778761,7.679480099505446,7.721099188707185,6.741466986401147,null,null,10.62662165235837,5.906890595608519,7.442943495848728,3.169925001442312,7.714245517666122,5.614709844115208,7.434628227636725,6.6293566200796095,null,8.189824558880018,6.954196310386875,7.800899899920305,6.965784284662087,5.954196310386875,null,null,10.154818109052105,5.554588851677638,7.303780748177103,3.4594316186372973,7.7481928495894605,5.357552004618084,7.499845887083206,7.721099188707185,0.0,8.103287808412022,7.129283016944966,6.78135971352466,6.700439718141092,5.672425341971495,null,null,10.361943773735241,null,2.0,null,0.0,1.584962500721156,1.0,0.0,null,2.584962500721156,2.584962500721156,2.0,2.0,1.0,null,null,3.700439718141092,5.357552004618084,7.0,2.321928094887362,6.807354922057604,5.0,7.169925001442312,7.011227255423254,null,7.7073591320808825,6.426264754702098,5.643856189774724,5.321928094887363,4.321928094887363,null,null,9.469641817239516,4.0,5.643856189774724,1.584962500721156,6.303780748177103,4.0,6.321928094887363,5.392317422778761,null,6.321928094887363,5.672425341971495,6.614709844115208,4.700439718141092,3.700439718141092,null,null,8.611024797307353,null,null,null,null,null,null,1.0,null,0.0,null,0.0,null,null,null,null,0.0,5.285402218862249,6.507794640198696,2.321928094887362,7.03342300153745,5.044394119358453,6.894817763307944,6.523561956057013,null,7.303780748177103,5.930737337562887,6.442943495848728,6.614709844115208,5.614709844115208,null,null,9.296916206879288,4.247927513443585,6.832890014164741,3.4594316186372973,6.614709844115208,4.954196310386875,6.94251450533924,6.584962500721156,null,7.787902559391432,6.507794640198696,5.554588851677638,6.426264754702098,5.426264754702098,null,null,9.842350343413807,2.584962500721156,4.754887502163468,1.0,4.321928094887363,2.321928094887362,5.357552004618084,3.0,null,4.754887502163468,4.0,4.247927513443585,3.584962500721156,2.584962500721156,null,null,7.679480099505446,5.459431618637297,6.321928094887363,6.700439718141092,8.930737337562887,4.754887502163468,9.038918989292302,8.487840033823051,null,7.087462841250339,6.906890595608519,7.066089190457772,8.832890014164741,7.845490050944375,null,null,11.439830883981392,4.584962500721156,6.599912842187128,3.169925001442312,8.08214904135387,4.954196310386875,7.918863237274595,7.426264754702098,null,7.467605550082998,7.312882955284356,6.754887502163468,7.483815777264256,6.491853096329675,null,null,10.580258567499788,4.459431618637297,5.357552004618084,2.807354922057604,8.08214904135387,4.643856189774724,8.219168520462162,6.491853096329675,null,7.03342300153745,5.882643049361842,6.022367813028454,7.451211111832329,6.459431618637297,null,null,10.234817431117325,4.584962500721156,5.700439718141092,1.584962500721156,6.672425341971495,3.700439718141092,7.294620748891627,6.189824558880018,0.0,6.700439718141092,5.044394119358453,5.20945336562895,5.954196310386875,5.0,null,null,9.83605035505807,4.459431618637297,6.022367813028454,2.584962500721156,9.121533517340032,5.392317422778761,7.906890595608519,7.643856189774724,null,7.285402218862249,6.321928094887363,7.169925001442312,8.271463027904375,7.285402218862249,null,null,11.124767535822473,5.700439718141092,6.741466986401147,3.321928094887362,7.366322214245816,4.857980995127572,7.189824558880018,6.6293566200796095,null,7.900866807980749,6.475733430966398,7.451211111832329,6.507794640198696,5.523561956057013,null,null,9.661778097771988,6.584962500721156,7.820178962415188,null,3.807354922057604,1.0,3.169925001442312,6.0,0.0,9.364134655008051,2.0,0.0,1.0,0.0,null,null,6.321928094887363,5.392317422778761,6.882643049361842,2.321928094887362,9.071462362556623,5.129283016944966,8.848622940429339,8.39231742277876,null,8.066089190457772,6.954196310386875,7.219168520462161,8.45532722030456,7.451211111832329,null,null,11.602234901341063,5.906890595608519,7.383704292474052,3.0,7.554588851677638,5.672425341971495,7.700439718141092,7.507794640198696,null,8.851749041416058,7.467605550082998,7.383704292474052,7.366322214245816,6.3750394313469245,null,null,10.462502272597265,4.459431618637297,6.321928094887363,1.584962500721156,7.882643049361842,5.169925001442312,7.330916878114617,7.087462841250339,0.0,7.3750394313469245,6.339850002884624,6.0,6.6293566200796095,5.643856189774724,null,null,10.28886607416582,6.475733430966398,7.994353436858858,3.807354922057604,7.94251450533924,6.321928094887363,7.643856189774724,7.693486957499325,0.0,9.221587121264806,7.787902559391432,8.247927513443585,7.392317422778761,6.392317422778761,null,null,10.310612781659529,5.0,6.768184324776926,5.285402218862249,8.665335917185176,5.754887502163468,8.507794640198696,8.08214904135387,null,7.9886846867721655,7.294620748891627,6.303780748177103,8.066089190457772,7.118941072723508,null,null,11.197830998012197,4.0,6.044394119358453,3.4594316186372973,8.228818690495881,5.491853096329675,7.820178962415188,8.066089190457772,null,7.129283016944966,6.523561956057013,6.066089190457772,7.994353436858858,7.0,null,null,10.469641817239516,4.459431618637297,6.918863237274595,7.0,8.055282435501189,4.954196310386875,8.194756854422248,7.924812503605781,null,7.700439718141092,6.977279923499917,6.658211482751795,8.383704292474052,7.383704292474052,null,null,10.84313591111135,4.584962500721156,6.087462841250339,1.0,7.577428828035749,3.9068905956085187,7.400879436282184,6.392317422778761,null,7.066089190457772,5.643856189774724,6.392317422778761,6.918863237274595,5.930737337562887,null,null,9.881113960675096,4.906890595608519,6.129283016944966,3.4594316186372973,8.459431618637296,6.149747119504682,7.857980995127572,7.727920454563199,null,8.038918989292302,7.475733430966398,7.483815777264256,7.894817763307944,6.906890595608519,null,null,10.909893083770042,5.643856189774724,7.312882955284356,3.0,8.842350343413807,5.832890014164741,8.64745842645492,8.055282435501189,null,8.519636252843213,7.6865005271832185,7.2384047393250786,8.233619676759702,7.2384047393250786,null,null,11.130570562805426,5.977279923499917,6.882643049361842,2.321928094887362,8.867278739709661,6.247927513443585,8.434628227636725,8.144658242831882,null,8.312882955284355,7.451211111832329,7.954196310386875,8.252665432450248,7.247927513443585,null,null,10.877284133523196,5.247927513443585,7.139551352398794,2.807354922057604,8.038918989292302,5.20945336562895,7.930737337562887,7.826548487290915,null,7.507794640198696,6.714245517666122,6.94251450533924,6.820178962415188,5.832890014164741,null,null,10.450180247164754,4.906890595608519,6.741466986401147,4.643856189774724,8.523561956057012,5.491853096329675,7.971543553950772,7.577428828035749,null,7.845490050944375,6.930737337562887,6.954196310386875,8.087462841250339,7.108524456778169,null,null,10.830515206976838,6.044394119358453,7.787902559391432,2.0,8.741466986401146,5.78135971352466,8.700439718141093,8.247927513443585,null,8.78135971352466,7.546894459887636,7.247927513443585,8.768184324776927,7.774787059601174,null,null,11.36468185586456,6.285402218862249,7.426264754702098,2.0,8.507794640198696,5.459431618637297,8.45532722030456,8.276124405274238,0.0,8.654636028527968,7.409390936137702,7.087462841250339,8.0,7.011227255423254,null,null,10.902375114486025,5.044394119358453,7.022367813028454,1.0,7.960001932068081,4.857980995127572,7.826548487290915,7.622051819456376,null,8.027905996569885,6.832890014164741,6.554588851677638,7.076815597050831,6.087462841250339,null,null,10.687375683437468,5.169925001442312,6.954196310386875,4.459431618637297,9.124121311829187,5.954196310386875,9.038918989292302,8.804131021183318,null,8.124121311829187,7.400879436282184,7.321928094887363,8.405141463136344,7.434628227636725,null,null,11.776844232402167,1.0,3.9068905956085187,0.0,4.584962500721156,null,3.0,4.169925001442312,null,4.643856189774724,3.169925001442312,3.584962500721156,4.0,3.0,null,null,6.794415866350106,4.321928094887363,6.523561956057013,4.0,8.539158811108031,4.954196310386875,8.43879185257826,7.9886846867721655,null,7.330916878114617,6.820178962415188,5.882643049361842,7.900866807980749,6.906890595608519,null,null,11.151016538892248,4.643856189774724,5.554588851677638,null,7.800899899920305,4.584962500721156,7.366322214245816,7.22881869049588,null,6.727920454563199,5.906890595608519,5.700439718141092,6.977279923499917,5.977279923499917,null,null,10.030667136246942,5.0,6.247927513443585,2.807354922057604,7.888743248898259,5.321928094887363,7.960001932068081,7.3750394313469245,null,7.451211111832329,6.20945336562895,6.442943495848728,7.6293566200796095,6.643856189774724,null,null,10.445014845868423,5.584962500721156,7.108524456778169,4.321928094887363,8.980139577639157,6.149747119504682,8.965784284662087,8.566054038171092,0.0,8.339850002884624,7.2384047393250786,7.339850002884624,8.271463027904375,7.294620748891627,null,null,11.47826403158172,6.832890014164741,7.930737337562887,3.9068905956085187,9.154818109052105,6.357552004618084,8.915879378835774,8.873444112515376,1.0,8.668884984266247,8.214319120800766,8.312882955284355,8.39231742277876,7.383704292474052,null,null,11.590119174107175,5.321928094887363,7.149747119504682,2.321928094887362,8.651051691178928,5.643856189774724,7.851749041416057,7.636624620543649,null,8.118941072723507,7.499845887083206,7.434628227636725,7.813781191217037,6.845490050944375,null,null,10.703038388986418,6.247927513443585,7.285402218862249,5.459431618637297,9.20212382383046,6.321928094887363,8.700439718141093,8.294620748891626,null,8.741466986401146,7.577428828035749,8.098032082960527,8.169925001442312,7.20945336562895,null,null,11.2940463132715,5.882643049361842,7.3750394313469245,3.807354922057604,9.184875342908283,6.459431618637297,8.693486957499326,8.672425341971495,0.0,8.430452551665532,7.6865005271832185,7.569855608330948,8.717676423066395,7.727920454563199,null,null,11.596655667674662,6.845490050944375,8.20945336562895,3.169925001442312,9.403012023574997,6.409390936137702,9.038918989292302,8.727920454563199,0.0,9.147204924942228,8.344295907915816,8.409390936137703,8.405141463136344,7.409390936137702,null,null,11.642954223480332,5.857980995127572,7.087462841250339,2.0,8.734709620225837,5.857980995127572,8.74819284958946,8.159871336778389,null,7.714245517666122,7.2761244052742375,6.930737337562887,7.924812503605781,6.965784284662087,null,null,11.254438148267257,4.321928094887363,6.658211482751795,3.9068905956085187,8.768184324776927,6.066089190457772,8.303780748177102,8.124121311829187,1.584962500721156,8.344295907915816,7.22881869049588,6.906890595608519,7.794415866350106,6.857980995127572,null,null,11.025831668332026,2.584962500721156,5.087462841250339,1.0,7.339850002884624,3.700439718141092,6.614709844115208,5.977279923499917,1.0,5.807354922057604,5.554588851677638,5.459431618637297,5.285402218862249,4.321928094887363,null,null,9.405141463136344,3.0,4.247927513443585,3.584962500721156,6.9886846867721655,3.807354922057604,6.94251450533924,6.0,0.0,5.285402218862249,5.20945336562895,4.523561956057013,7.303780748177103,6.321928094887363,null,null,9.831307243802051,3.584962500721156,4.906890595608519,null,7.076815597050831,3.321928094887362,7.20945336562895,6.491853096329675,null,5.78135971352466,5.321928094887363,4.754887502163468,6.832890014164741,5.832890014164741,null,null,9.888743248898258,3.0,5.584962500721156,1.0,6.643856189774724,3.0,6.357552004618084,6.22881869049588,null,6.768184324776926,5.426264754702098,5.727920454563199,6.247927513443585,5.285402218862249,null,null,9.207014320177532,5.169925001442312,6.807354922057604,3.4594316186372973,8.442943495848729,6.0,7.721099188707185,7.894817763307944,null,7.727920454563199,6.9886846867721655,6.599912842187128,7.813781191217037,6.832890014164741,null,null,10.618385502258606,5.0,6.339850002884624,2.807354922057604,8.087462841250339,5.357552004618084,7.714245517666122,7.651051691178929,1.0,7.721099188707185,6.832890014164741,6.700439718141092,7.499845887083206,6.523561956057013,null,null,10.788718332690458,5.247927513443585,7.20945336562895,3.0,8.507794640198696,5.977279923499917,8.169925001442312,7.577428828035749,null,7.9886846867721655,7.339850002884624,7.94251450533924,7.714245517666122,6.727920454563199,null,null,10.884933647949762,5.169925001442312,7.330916878114617,4.169925001442312,9.177419537989236,6.087462841250339,8.539158811108031,8.290018846932618,null,8.285402218862249,7.658211482751795,7.965784284662087,8.668884984266247,7.6653359171851765,null,null,11.409390936137703,5.523561956057013,6.044394119358453,3.321928094887362,7.20945336562895,5.20945336562895,7.285402218862249,7.03342300153745,null,7.383704292474052,6.475733430966398,6.129283016944966,6.930737337562887,5.930737337562887,null,null,10.271463027904375,5.0,6.022367813028454,2.321928094887362,7.6653359171851765,4.584962500721156,7.149747119504682,7.011227255423254,null,7.442943495848728,5.977279923499917,6.129283016944966,6.491853096329675,5.523561956057013,null,null,10.083479327331842,5.20945336562895,6.554588851677638,6.285402218862249,8.044394119358454,4.643856189774724,7.882643049361842,7.820178962415188,null,7.22881869049588,7.022367813028454,6.442943495848728,7.768184324776926,6.768184324776926,null,null,10.726218159332198,4.459431618637297,6.339850002884624,3.807354922057604,9.238404739325079,6.129283016944966,8.413627929024173,8.471675214392045,null,7.6865005271832185,6.906890595608519,7.169925001442312,8.422064766172813,7.442943495848728,null,null,11.651051691178928,3.584962500721156,5.392317422778761,2.807354922057604,7.348728154231077,4.754887502163468,7.622051819456376,6.870364719583405,null,5.930737337562887,5.807354922057604,5.285402218862249,7.129283016944966,6.129283016944966,null,null,10.51175265376738,3.584962500721156,5.754887502163468,3.0,7.6865005271832185,3.321928094887362,6.918863237274595,6.507794640198696,null,6.321928094887363,5.807354922057604,5.754887502163468,6.754887502163468,5.78135971352466,null,null,9.90388184573618,4.459431618637297,6.247927513443585,4.321928094887363,8.632995197142957,5.0,8.535275376620802,7.924812503605781,null,7.2761244052742375,6.794415866350106,6.754887502163468,7.7615512324444795,6.820178962415188,null,null,11.156083076288681,3.584962500721156,5.087462841250339,5.614709844115208,7.658211482751795,3.807354922057604,7.199672344836364,7.20945336562895,null,6.0,5.832890014164741,5.0,7.05528243550119,6.066089190457772,null,null,9.909893083770042,4.392317422778761,5.78135971352466,2.321928094887362,7.562242424221073,4.643856189774724,7.693486957499325,6.930737337562887,0.0,6.930737337562887,5.930737337562887,5.554588851677638,6.954196310386875,5.977279923499917,null,null,10.422064766172813,4.584962500721156,5.832890014164741,2.0,8.044394119358454,4.584962500721156,7.643856189774724,7.189824558880018,null,7.366322214245816,6.442943495848728,6.700439718141092,7.392317422778761,6.409390936137702,null,null,10.311748315004959,4.584962500721156,6.491853096329675,2.321928094887362,9.339850002884624,6.149747119504682,8.980139577639157,8.459431618637296,null,7.658211482751795,7.087462841250339,7.523561956057013,8.682994583681683,7.7073591320808825,null,null,11.67595703294175,4.700439718141092,6.247927513443585,2.0,8.467605550082997,5.169925001442312,8.643856189774725,8.46352437327118,null,7.247927513443585,6.539158811108031,6.882643049361842,8.379378367071261,7.392317422778761,null,null,11.519636252843213,6.321928094887363,7.807354922057604,6.977279923499917,9.603626344986193,5.906890595608519,9.144658242831882,8.807354922057604,0.0,8.20945336562895,7.912889336229962,7.60733031374961,9.211888294546004,8.224001674198105,null,null,11.912515144802397,4.754887502163468,6.820178962415188,4.0,8.632995197142957,5.672425341971495,8.312882955284355,7.087462841250339,null,7.7615512324444795,6.614709844115208,6.794415866350106,8.276124405274238,7.321928094887363,null,null,11.005624549193879,4.754887502163468,6.906890595608519,3.807354922057604,8.768184324776927,5.321928094887363,8.326429487122303,8.189824558880018,null,7.622051819456376,7.409390936137702,7.499845887083206,8.442943495848729,7.459431618637297,null,null,11.244958393151133,4.247927513443585,6.22881869049588,4.321928094887363,8.46352437327118,5.491853096329675,8.308339030139408,7.768184324776926,null,7.515699838284043,6.247927513443585,5.459431618637297,7.845490050944375,6.857980995127572,null,null,11.078817949961978,4.459431618637297,6.754887502163468,3.0,8.098032082960527,5.700439718141092,7.636624620543649,6.870364719583405,null,7.451211111832329,6.807354922057604,6.321928094887363,7.066089190457772,6.066089190457772,null,null,10.539158811108031,3.0,4.584962500721156,null,6.954196310386875,3.584962500721156,6.643856189774724,5.491853096329675,null,5.727920454563199,4.807354922057604,4.584962500721156,6.044394119358453,5.044394119358453,null,null,9.303780748177102,1.0,4.087462841250339,2.321928094887362,7.294620748891627,3.807354922057604,7.011227255423254,6.918863237274595,null,5.930737337562887,5.643856189774724,5.930737337562887,7.189824558880018,6.20945336562895,null,null,10.100662339005199,4.807354922057604,6.727920454563199,4.857980995127572,8.531381460516313,5.285402218862249,8.087462841250339,7.693486957499325,0.0,7.312882955284356,7.05528243550119,6.569855608330948,7.864186144654281,6.870364719583405,null,null,10.98655314975666,null,2.584962500721156,0.0,6.129283016944966,2.584962500721156,4.857980995127572,5.491853096329675,null,3.4594316186372973,2.584962500721156,1.0,3.807354922057604,2.807354922057604,null,null,8.400879436282183,4.906890595608519,6.614709844115208,3.584962500721156,8.734709620225837,5.426264754702098,8.515699838284043,7.1799090900149345,null,7.754887502163468,7.129283016944966,7.044394119358453,8.159871336778389,7.199672344836364,null,null,11.039604517953759,3.807354922057604,5.392317422778761,2.321928094887362,7.614709844115208,5.129283016944966,7.294620748891627,6.491853096329675,null,5.584962500721156,5.614709844115208,4.247927513443585,6.794415866350106,5.807354922057604,null,null,10.233619676759702,4.584962500721156,6.266786540694901,6.727920454563199,8.159871336778389,4.700439718141092,7.693486957499325,7.515699838284043,null,7.159871336778389,6.714245517666122,5.930737337562887,7.977279923499917,7.0,null,null,10.428360172704291,5.321928094887363,6.918863237274595,0.0,7.129283016944966,4.584962500721156,6.918863237274595,6.845490050944375,null,8.098032082960527,6.569855608330948,7.011227255423254,6.507794640198696,5.554588851677638,null,null,9.939579214314692,4.700439718141092,6.539158811108031,2.807354922057604,7.592457037268081,5.087462841250339,7.7073591320808825,7.066089190457772,0.0,7.7481928495894605,6.672425341971495,6.169925001442312,7.03342300153745,6.044394119358453,null,null,10.052568050804153,5.426264754702098,6.794415866350106,3.169925001442312,7.774787059601174,4.754887502163468,7.599912842187128,7.05528243550119,null,8.098032082960527,6.754887502163468,7.139551352398794,7.149747119504682,6.189824558880018,null,null,10.250298417906333,5.857980995127572,6.426264754702098,3.0,7.129283016944966,5.392317422778761,7.159871336778389,6.754887502163468,0.0,8.214319120800766,6.807354922057604,7.491853096329675,6.6865005271832185,5.672425341971495,null,null,9.935165049603695,5.0,6.965784284662087,3.321928094887362,7.321928094887363,4.523561956057013,6.714245517666122,6.426264754702098,null,7.679480099505446,6.507794640198696,7.219168520462161,6.700439718141092,5.700439718141092,null,null,9.426264754702098,5.392317422778761,6.584962500721156,3.584962500721156,7.0,3.807354922057604,6.714245517666122,6.266786540694901,0.0,7.584962500721156,6.357552004618084,6.906890595608519,6.409390936137702,5.426264754702098,null,null,9.499845887083206,3.807354922057604,5.321928094887363,0.0,4.459431618637297,2.0,4.0,4.0,null,6.129283016944966,4.169925001442312,4.459431618637297,3.321928094887362,2.321928094887362,null,null,7.139551352398794,3.9068905956085187,5.906890595608519,2.0,6.189824558880018,3.9068905956085187,6.247927513443585,5.78135971352466,0.0,7.076815597050831,6.0,5.672425341971495,5.882643049361842,4.906890595608519,null,null,9.12670447284319,4.459431618637297,6.658211482751795,3.321928094887362,6.3750394313469245,4.906890595608519,7.044394119358453,6.523561956057013,0.0,7.894817763307944,6.285402218862249,5.807354922057604,6.672425341971495,5.672425341971495,null,null,9.51175265376738,5.285402218862249,6.409390936137702,2.584962500721156,7.149747119504682,4.643856189774724,6.6865005271832185,5.754887502163468,null,7.515699838284043,6.022367813028454,6.768184324776926,6.741466986401147,5.754887502163468,null,null,9.564149489985732,5.0,7.592457037268081,3.169925001442312,8.022367813028454,5.882643049361842,8.124121311829187,7.6653359171851765,null,8.997179480937621,7.768184324776926,7.366322214245816,7.546894459887636,6.569855608330948,null,null,10.643856189774725,4.459431618637297,6.339850002884624,2.584962500721156,6.523561956057013,4.392317422778761,6.539158811108031,5.882643049361842,0.0,7.7481928495894605,6.189824558880018,5.977279923499917,6.108524456778169,5.129283016944966,null,null,9.116343961237469,4.700439718141092,6.321928094887363,1.584962500721156,6.794415866350106,4.459431618637297,6.700439718141092,6.882643049361842,null,7.768184324776926,6.20945336562895,6.409390936137702,6.491853096329675,5.523561956057013,null,null,9.475733430966399,5.930737337562887,7.569855608330948,3.169925001442312,7.857980995127572,5.129283016944966,7.741466986401147,7.0,1.0,8.73809225962049,7.357552004618084,7.03342300153745,6.754887502163468,5.754887502163468,null,null,10.121533517340032,6.247927513443585,7.1799090900149345,1.0,7.303780748177103,4.857980995127572,6.94251450533924,6.78135971352466,1.0,8.08214904135387,6.6865005271832185,6.584962500721156,6.303780748177103,5.285402218862249,null,null,9.848622940429339,6.0,7.22881869049588,2.807354922057604,7.876516946564999,5.169925001442312,7.442943495848728,7.22881869049588,0.0,8.247927513443585,6.930737337562887,7.800899899920305,6.491853096329675,5.554588851677638,null,null,9.94104760634058,5.044394119358453,6.658211482751795,2.807354922057604,6.409390936137702,4.807354922057604,6.392317422778761,6.614709844115208,0.0,7.826548487290915,6.392317422778761,6.475733430966398,6.321928094887363,5.321928094887363,null,null,9.194756854422248,3.807354922057604,6.108524456778169,1.0,5.523561956057013,4.584962500721156,6.539158811108031,5.523561956057013,null,7.087462841250339,5.857980995127572,5.832890014164741,5.584962500721156,4.584962500721156,null,null,9.129283016944967,5.169925001442312,6.22881869049588,1.584962500721156,6.044394119358453,3.9068905956085187,6.392317422778761,5.672425341971495,0.0,7.149747119504682,5.554588851677638,6.149747119504682,5.584962500721156,4.643856189774724,null,null,8.83605035505807,4.169925001442312,6.0,1.584962500721156,6.169925001442312,4.459431618637297,5.357552004618084,5.643856189774724,0.0,7.149747119504682,5.523561956057013,5.954196310386875,5.0,4.087462841250339,null,null,8.599912842187127,3.584962500721156,6.247927513443585,1.584962500721156,6.754887502163468,3.700439718141092,6.426264754702098,5.832890014164741,0.0,7.531381460516312,6.066089190457772,6.599912842187128,5.977279923499917,5.0,null,null,9.339850002884624,2.0,2.0,1.0,2.0,0.0,2.0,3.169925001442312,null,2.584962500721156,2.807354922057604,2.584962500721156,null,null,null,null,4.807354922057604,5.087462841250339,6.965784284662087,1.0,7.189824558880018,5.087462841250339,7.189824558880018,5.954196310386875,null,8.233619676759702,6.523561956057013,6.584962500721156,5.954196310386875,5.044394119358453,null,null,9.60177078840771,null,5.614709844115208,null,6.20945336562895,3.321928094887362,5.247927513443585,3.9068905956085187,null,6.658211482751795,0.0,6.149747119504682,5.554588851677638,4.523561956057013,null,null,8.515699838284043,5.247927513443585,6.768184324776926,2.321928094887362,7.257387842692652,5.044394119358453,7.321928094887363,6.845490050944375,null,8.243173983472952,6.857980995127572,6.672425341971495,6.599912842187128,5.614709844115208,null,null,9.929258408636972,4.906890595608519,6.6865005271832185,3.169925001442312,6.954196310386875,4.700439718141092,7.011227255423254,6.672425341971495,null,8.038918989292302,6.523561956057013,6.392317422778761,6.954196310386875,5.930737337562887,null,null,9.481799431665753,5.807354922057604,7.523561956057013,2.807354922057604,7.592457037268081,5.78135971352466,7.1799090900149345,6.870364719583405,0.0,8.330916878114618,7.257387842692652,7.577428828035749,6.754887502163468,5.754887502163468,null,null,10.037546953962178,null,0.0,null,0.0,null,null,null,null,3.0,null,null,null,null,null,null,1.0,3.321928094887362,4.807354922057604,1.0,8.487840033823051,4.857980995127572,8.0,6.599912842187128,null,5.857980995127572,5.169925001442312,6.022367813028454,7.658211482751795,6.658211482751795,2.0,2.0,10.63662462054365,2.0,5.247927513443585,2.584962500721156,7.357552004618084,4.321928094887363,6.977279923499917,6.78135971352466,null,6.285402218862249,6.189824558880018,6.3750394313469245,6.9886846867721655,5.977279923499917,null,null,9.567956075415466,3.0,5.247927513443585,2.807354922057604,7.266786540694901,4.321928094887363,7.219168520462161,6.584962500721156,null,6.087462841250339,5.357552004618084,5.807354922057604,7.426264754702098,6.459431618637297,null,null,9.967226258835993,5.169925001442312,6.247927513443585,2.584962500721156,8.599912842187127,4.459431618637297,8.011227255423254,7.734709620225838,null,7.366322214245816,6.459431618637297,7.022367813028454,7.768184324776926,6.768184324776926,null,null,10.527477006060396,2.0,4.0,2.0,6.906890595608519,4.087462841250339,7.108524456778169,6.9886846867721655,null,5.954196310386875,4.700439718141092,3.4594316186372973,6.658211482751795,5.672425341971495,null,null,9.99859042974533,4.906890595608519,6.20945336562895,6.339850002884624,6.870364719583405,3.0,6.409390936137702,6.599912842187128,2.321928094887362,7.651051691178929,6.930737337562887,6.022367813028454,6.700439718141092,5.700439718141092,null,null,9.52943055414615,4.169925001442312,5.954196310386875,null,2.0,0.0,1.584962500721156,4.169925001442312,null,7.876516946564999,0.0,null,1.0,0.0,null,null,4.0,4.0,5.614709844115208,3.169925001442312,8.78135971352466,5.129283016944966,8.357552004618084,7.434628227636725,null,6.6293566200796095,5.727920454563199,6.6865005271832185,7.78135971352466,6.78135971352466,null,null,11.080151309614088,6.285402218862249,7.442943495848728,6.247927513443585,7.257387842692652,5.357552004618084,7.499845887083206,7.1799090900149345,null,8.72451385311995,7.169925001442312,7.011227255423254,7.087462841250339,6.108524456778169,null,null,9.977279923499916,4.584962500721156,5.954196310386875,2.807354922057604,7.6865005271832185,4.754887502163468,7.894817763307944,7.546894459887636,null,7.05528243550119,6.442943495848728,5.321928094887363,7.339850002884624,6.339850002884624,null,null,10.353146825498083,4.459431618637297,6.357552004618084,3.0,7.294620748891627,4.321928094887363,7.434628227636725,6.569855608330948,0.0,6.857980995127572,6.129283016944966,5.882643049361842,7.129283016944966,6.129283016944966,null,null,9.896332403909941,5.321928094887363,6.247927513443585,4.0,7.592457037268081,4.459431618637297,7.3750394313469245,6.894817763307944,null,7.087462841250339,6.357552004618084,5.672425341971495,7.118941072723508,6.129283016944966,null,null,10.12670447284319,3.807354922057604,5.643856189774724,3.4594316186372973,7.924812503605781,5.129283016944966,7.820178962415188,7.499845887083206,null,7.076815597050831,6.930737337562887,7.03342300153745,7.03342300153745,6.044394119358453,null,null,10.332036548361652,4.169925001442312,6.044394119358453,2.584962500721156,7.60733031374961,4.169925001442312,7.6865005271832185,7.169925001442312,0.0,7.159871336778389,6.044394119358453,5.523561956057013,7.087462841250339,6.087462841250339,null,null,10.381542951184585,5.044394119358453,5.754887502163468,4.584962500721156,8.640244936222345,4.700439718141092,8.179909090014934,7.247927513443585,null,7.087462841250339,6.022367813028454,6.169925001442312,7.807354922057604,6.820178962415188,null,null,10.667998535672528,5.044394119358453,5.930737337562887,4.0,7.894817763307944,4.247927513443585,7.714245517666122,6.807354922057604,0.0,7.266786540694901,5.906890595608519,6.491853096329675,7.266786540694901,6.266786540694901,null,null,10.333155350310616,2.584962500721156,4.247927513443585,1.0,7.303780748177103,3.4594316186372973,7.774787059601174,6.475733430966398,null,4.754887502163468,4.754887502163468,4.584962500721156,7.149747119504682,6.20945336562895,null,null,10.205793249397157,4.321928094887363,5.285402218862249,3.584962500721156,8.554588851677638,5.321928094887363,8.294620748891626,7.584962500721156,null,7.409390936137702,6.507794640198696,6.882643049361842,7.787902559391432,6.845490050944375,null,null,11.079484783826816,3.321928094887362,4.459431618637297,0.0,4.954196310386875,2.0,4.523561956057013,4.754887502163468,null,5.700439718141092,3.4594316186372973,3.9068905956085187,3.807354922057604,2.807354922057604,2.0,2.0,7.491853096329675,6.247927513443585,7.022367813028454,4.247927513443585,8.945443836377912,5.459431618637297,8.531381460516313,8.603626344986193,1.0,8.499845887083206,7.813781191217037,7.149747119504682,8.238404739325079,7.257387842692652,null,null,11.500343969270403,5.087462841250339,6.3750394313469245,1.0,7.219168520462161,4.700439718141092,7.734709620225838,7.247927513443585,null,7.467605550082998,6.266786540694901,5.087462841250339,7.339850002884624,6.339850002884624,null,null,10.293471648838134,5.857980995127572,6.459431618637297,4.0,8.087462841250339,4.807354922057604,7.774787059601174,7.451211111832329,null,7.734709620225838,6.247927513443585,7.0,7.936637939002571,6.965784284662087,null,null,10.443979542601253,3.4594316186372973,5.044394119358453,2.321928094887362,7.199672344836364,4.392317422778761,7.483815777264256,7.03342300153745,null,6.339850002884624,5.044394119358453,5.247927513443585,7.076815597050831,6.087462841250339,null,null,9.954196310386875,3.807354922057604,5.700439718141092,3.4594316186372973,7.906890595608519,4.392317422778761,7.531381460516312,6.882643049361842,0.0,6.700439718141092,6.149747119504682,5.78135971352466,7.2761244052742375,6.285402218862249,null,null,10.377210530388552,4.321928094887363,6.754887502163468,2.0,8.335390354693924,4.643856189774724,7.864186144654281,7.330916878114617,1.0,7.6865005271832185,6.906890595608519,6.857980995127572,7.614709844115208,6.6293566200796095,null,null,10.452241240430817,3.584962500721156,5.930737337562887,1.0,7.0,4.247927513443585,6.714245517666122,6.584962500721156,null,6.845490050944375,5.523561956057013,6.22881869049588,6.965784284662087,6.022367813028454,2.0,2.0,9.731319031025064,4.321928094887363,4.906890595608519,2.321928094887362,7.475733430966398,4.247927513443585,7.366322214245816,7.0,null,5.523561956057013,5.321928094887363,5.727920454563199,7.294620748891627,6.303780748177103,null,null,10.088788238716907,4.169925001442312,6.584962500721156,0.0,7.794415866350106,4.459431618637297,7.599912842187128,7.507794640198696,null,7.20945336562895,6.247927513443585,5.977279923499917,7.383704292474052,6.3750394313469245,null,null,10.380461065088973,4.321928094887363,5.614709844115208,5.832890014164741,7.930737337562887,4.523561956057013,7.159871336778389,7.139551352398794,null,6.768184324776926,6.303780748177103,5.78135971352466,7.451211111832329,6.459431618637297,null,null,10.280770770130603,3.0,5.321928094887363,1.584962500721156,7.721099188707185,4.0,7.531381460516312,6.643856189774724,null,6.409390936137702,5.584962500721156,5.614709844115208,7.05528243550119,6.066089190457772,null,null,10.18239435340453,5.700439718141092,6.807354922057604,0.0,7.383704292474052,5.20945336562895,7.658211482751795,7.247927513443585,null,8.03342300153745,6.768184324776926,6.409390936137702,7.087462841250339,6.087462841250339,null,null,10.023754353299417,3.169925001442312,5.584962500721156,2.0,6.426264754702098,2.584962500721156,6.569855608330948,6.442943495848728,null,6.523561956057013,5.321928094887363,5.321928094887363,5.807354922057604,4.807354922057604,null,null,9.515699838284043,5.321928094887363,6.599912842187128,2.584962500721156,7.321928094887363,4.523561956057013,7.257387842692652,6.658211482751795,1.584962500721156,7.459431618637297,6.491853096329675,6.303780748177103,7.022367813028454,6.044394119358453,null,null,9.843921051289035,5.554588851677638,6.554588851677638,2.321928094887362,8.569855608330949,5.321928094887363,7.900866807980749,7.087462841250339,null,8.098032082960527,6.672425341971495,6.965784284662087,7.679480099505446,6.6865005271832185,null,null,10.523561956057012,4.392317422778761,5.954196310386875,3.584962500721156,8.154818109052105,4.643856189774724,8.08214904135387,7.562242424221073,null,7.22881869049588,6.189824558880018,6.539158811108031,7.467605550082998,6.507794640198696,null,null,10.711666973564347,4.169925001442312,5.614709844115208,2.584962500721156,7.169925001442312,3.700439718141092,6.442943495848728,6.442943495848728,null,6.409390936137702,5.882643049361842,5.643856189774724,6.918863237274595,5.930737337562887,null,null,9.353146825498083,4.807354922057604,6.022367813028454,3.700439718141092,7.727920454563199,4.754887502163468,7.727920454563199,7.076815597050831,null,6.599912842187128,6.303780748177103,5.643856189774724,7.554588851677638,6.569855608330948,null,null,10.46454575033394,4.584962500721156,5.930737337562887,1.584962500721156,7.199672344836364,3.700439718141092,7.7073591320808825,7.076815597050831,null,6.285402218862249,6.129283016944966,4.0,6.768184324776926,5.754887502163468,null,null,9.614709844115207,3.807354922057604,5.044394119358453,2.807354922057604,7.400879436282184,4.087462841250339,7.108524456778169,6.643856189774724,null,6.022367813028454,5.044394119358453,5.129283016944966,6.954196310386875,6.0,null,null,10.164906926675688,4.0,5.247927513443585,1.0,7.562242424221073,4.392317422778761,7.539158811108031,7.870364719583405,null,6.339850002884624,5.672425341971495,3.700439718141092,6.820178962415188,5.832890014164741,null,null,10.339850002884624,4.392317422778761,6.108524456778169,3.169925001442312,8.184875342908283,4.754887502163468,7.774787059601174,7.076815597050831,null,7.22881869049588,6.491853096329675,6.6865005271832185,7.475733430966398,6.491853096329675,null,null,10.62296694479051,4.807354922057604,5.727920454563199,2.807354922057604,7.636624620543649,4.584962500721156,7.78135971352466,6.507794640198696,null,7.129283016944966,6.149747119504682,6.321928094887363,7.087462841250339,6.087462841250339,null,null,10.345405246717796,4.0,4.392317422778761,2.321928094887362,8.361943773735241,4.754887502163468,7.78135971352466,7.0,null,5.954196310386875,6.044394119358453,6.247927513443585,8.03342300153745,7.05528243550119,null,null,10.750706986224948,4.584962500721156,6.066089190457772,3.584962500721156,8.826548487290914,5.392317422778761,8.426264754702098,8.060695931687555,0.0,6.6865005271832185,6.20945336562895,6.882643049361842,8.011227255423254,7.03342300153745,null,null,11.082814337672273,3.321928094887362,5.554588851677638,5.20945336562895,7.409390936137702,4.523561956057013,7.523561956057013,6.820178962415188,null,6.339850002884624,5.426264754702098,5.247927513443585,7.285402218862249,6.321928094887363,null,null,10.326429487122303,4.459431618637297,5.807354922057604,2.0,7.562242424221073,4.643856189774724,7.257387842692652,6.6865005271832185,0.0,7.0,6.285402218862249,5.392317422778761,7.426264754702098,6.442943495848728,null,null,9.994353436858859,3.584962500721156,4.321928094887363,1.0,6.409390936137702,2.807354922057604,6.022367813028454,6.339850002884624,null,5.78135971352466,4.247927513443585,4.643856189774724,5.727920454563199,4.754887502163468,null,null,9.152284842306582,4.700439718141092,5.129283016944966,1.0,6.78135971352466,3.4594316186372973,6.741466986401147,6.189824558880018,null,6.714245517666122,5.459431618637297,5.044394119358453,6.189824558880018,5.169925001442312,null,null,9.590587049915035,5.392317422778761,6.539158811108031,3.0,8.108524456778168,5.0,7.554588851677638,7.247927513443585,0.0,7.339850002884624,6.658211482751795,6.672425341971495,7.467605550082998,6.475733430966398,null,null,10.429406741513981,null,2.0,null,3.321928094887362,0.0,3.700439718141092,1.584962500721156,null,1.584962500721156,1.0,null,3.169925001442312,2.321928094887362,null,null,6.523561956057013,4.0,6.087462841250339,1.0,8.134426320220927,4.906890595608519,7.900866807980749,7.60733031374961,null,7.330916878114617,6.554588851677638,6.409390936137702,7.523561956057013,6.539158811108031,null,null,10.60177078840771,2.584962500721156,4.906890595608519,1.0,7.03342300153745,3.321928094887362,6.339850002884624,6.584962500721156,null,5.247927513443585,4.247927513443585,4.247927513443585,6.129283016944966,5.129283016944966,null,null,9.533329732305834,3.584962500721156,4.857980995127572,1.584962500721156,7.366322214245816,4.0,6.820178962415188,6.491853096329675,null,6.554588851677638,5.044394119358453,5.882643049361842,6.754887502163468,5.78135971352466,null,null,9.79603960882977,5.321928094887363,6.727920454563199,3.169925001442312,7.467605550082998,4.247927513443585,6.78135971352466,6.569855608330948,null,8.159871336778389,6.882643049361842,6.965784284662087,6.20945336562895,5.169925001442312,null,null,9.54882190845875,5.832890014164741,6.714245517666122,2.807354922057604,7.139551352398794,4.523561956057013,6.78135971352466,6.700439718141092,1.0,7.515699838284043,6.22881869049588,7.442943495848728,6.169925001442312,5.169925001442312,null,null,9.546894459887637,5.392317422778761,6.491853096329675,2.321928094887362,6.149747119504682,4.857980995127572,6.442943495848728,6.523561956057013,0.0,7.754887502163468,6.285402218862249,5.169925001442312,6.321928094887363,5.285402218862249,null,null,9.149747119504681,5.321928094887363,6.339850002884624,1.584962500721156,5.169925001442312,2.807354922057604,5.044394119358453,5.044394119358453,null,7.2761244052742375,5.426264754702098,4.906890595608519,5.169925001442312,4.169925001442312,1.0,1.0,8.03342300153745,6.044394119358453,6.9886846867721655,1.584962500721156,6.727920454563199,4.643856189774724,7.507794640198696,7.189824558880018,null,8.066089190457772,6.845490050944375,7.022367813028454,6.643856189774724,5.643856189774724,null,null,9.407267764244732,4.807354922057604,6.129283016944966,2.0,6.321928094887363,4.247927513443585,6.459431618637297,5.78135971352466,null,7.434628227636725,6.044394119358453,6.0,6.044394119358453,5.044394119358453,null,null,9.014020470314934,5.087462841250339,6.339850002884624,0.0,6.339850002884624,4.321928094887363,6.321928094887363,5.882643049361842,0.0,7.1799090900149345,5.906890595608519,6.658211482751795,6.0,5.0,null,null,8.997179480937621,4.321928094887363,4.906890595608519,1.584962500721156,5.20945336562895,2.321928094887362,4.906890595608519,5.169925001442312,null,6.129283016944966,4.754887502163468,5.426264754702098,4.321928094887363,3.321928094887362,1.0,1.0,8.016808287686555,4.0,5.247927513443585,1.584962500721156,6.087462841250339,4.087462841250339,5.700439718141092,5.78135971352466,null,6.9886846867721655,5.700439718141092,5.672425341971495,5.459431618637297,4.459431618637297,null,null,8.566054038171092,4.857980995127572,5.614709844115208,null,6.149747119504682,2.0,6.285402218862249,5.906890595608519,0.0,6.614709844115208,5.459431618637297,5.129283016944966,6.129283016944966,5.129283016944966,null,null,8.74819284958946,3.807354922057604,6.20945336562895,1.584962500721156,5.044394119358453,2.807354922057604,5.357552004618084,5.357552004618084,null,6.78135971352466,5.0,4.459431618637297,5.044394119358453,4.0,null,null,7.977279923499917,5.20945336562895,6.918863237274595,4.392317422778761,7.20945336562895,4.321928094887363,6.459431618637297,6.044394119358453,null,7.60733031374961,6.882643049361842,6.459431618637297,5.977279923499917,5.0,null,null,9.394462694610317,4.700439718141092,6.0,1.584962500721156,6.459431618637297,4.087462841250339,5.392317422778761,5.523561956057013,null,6.768184324776926,5.672425341971495,5.426264754702098,5.247927513443585,4.321928094887363,null,null,8.744833837499545,4.906890595608519,5.807354922057604,4.700439718141092,5.672425341971495,3.700439718141092,5.614709844115208,4.643856189774724,null,6.658211482751795,5.491853096329675,5.459431618637297,6.149747119504682,5.169925001442312,null,null,8.31741261376487,5.285402218862249,6.584962500721156,3.4594316186372973,6.918863237274595,4.857980995127572,7.159871336778389,6.0,null,7.417852514885898,6.507794640198696,6.672425341971495,6.169925001442312,5.20945336562895,null,null,9.54882190845875,null,1.0,null,1.0,0.0,null,null,null,2.321928094887362,2.0,1.0,null,null,null,null,4.087462841250339,4.459431618637297,5.78135971352466,3.0,5.247927513443585,3.9068905956085187,5.459431618637297,4.906890595608519,null,6.870364719583405,5.392317422778761,5.78135971352466,5.247927513443585,4.247927513443585,null,null,8.546894459887637,4.700439718141092,6.066089190457772,3.321928094887362,6.554588851677638,4.584962500721156,6.727920454563199,6.129283016944966,null,6.906890595608519,5.930737337562887,6.584962500721156,5.584962500721156,4.584962500721156,null,null,8.885696373339394,4.0,4.857980995127572,2.321928094887362,5.426264754702098,2.584962500721156,5.672425341971495,5.357552004618084,null,6.303780748177103,4.643856189774724,5.392317422778761,5.700439718141092,4.700439718141092,null,null,8.20945336562895],\"y0\":\" \",\"yaxis\":\"y\",\"type\":\"box\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"],[\"3R\",\"AIM18\"],[\"3R\",\"AIM19\"],[\"3R\",\"AIM20\"],[\"3R\",\"AIM21\"],[\"3R\",\"AIM22\"],[\"3R\",\"AIM23\"],[\"3R\",\"AIM24\"],[\"3R\",\"D7R2\"],[\"3R\",\"Gste_tag1\"],[\"3R\",\"Gste_tag2\"],[\"3R\",\"Gste_F120L\"],[\"3R\",\"Gste_L119V\"],[\"3R\",\"Gste_I114T\"],[\"3R\",\"Gste_tag3\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003eamplicon=%{x}\\u003cbr\\u003elog_depth=%{y}\\u003cbr\\u003emutation=%{customdata[1]}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"3R\",\"marker\":{\"color\":\"#FF7F0E\"},\"name\":\"3R\",\"notched\":false,\"offsetgroup\":\"3R\",\"orientation\":\"v\",\"showlegend\":true,\"x\":[\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_63\",\"Agam_63\",\"Agam_64\"],\"x0\":\" \",\"xaxis\":\"x\",\"y\":[9.44086916761087,5.285402218862249,5.087462841250339,3.807354922057604,5.321928094887363,5.357552004618084,5.169925001442312,4.643856189774724,null,4.906890595608519,3.4594316186372973,3.4594316186372973,4.584962500721156,6.066089190457772,5.247927513443585,3.321928094887362,2.807354922057604,1.0,2.584962500721156,2.0,3.321928094887362,3.9068905956085187,null,2.0,0.0,0.0,1.0,2.0,2.0,0.0,0.0,2.0,null,1.0,null,null,null,1.0,null,null,1.584962500721156,1.0,4.247927513443585,1.0,1.0,2.321928094887362,1.0,0.0,1.0,2.0,null,2.0,null,null,0.0,null,5.807354922057604,2.0,1.0,1.584962500721156,1.584962500721156,1.0,1.0,2.0,null,null,null,null,null,null,5.906890595608519,5.285402218862249,4.523561956057013,2.584962500721156,3.700439718141092,4.247927513443585,4.459431618637297,4.700439718141092,null,null,2.807354922057604,2.807354922057604,3.807354922057604,1.0,0.0,4.459431618637297,null,null,null,3.169925001442312,1.0,4.087462841250339,null,null,0.0,0.0,1.0,1.0,2.0,0.0,0.0,1.0,null,null,null,null,null,null,null,null,1.0,1.0,null,0.0,0.0,0.0,null,0.0,null,null,null,1.0,null,null,1.0,1.0,5.78135971352466,3.0,3.0,2.321928094887362,2.807354922057604,2.584962500721156,2.0,2.0,null,2.0,0.0,0.0,1.584962500721156,1.0,1.0,2.321928094887362,0.0,3.0,3.0,1.584962500721156,2.321928094887362,1.584962500721156,null,null,0.0,0.0,1.584962500721156,1.584962500721156,2.584962500721156,1.584962500721156,2.0,0.0,null,null,2.321928094887362,null,null,1.0,null,null,null,1.584962500721156,6.22881869049588,4.807354922057604,2.807354922057604,3.4594316186372973,3.321928094887362,4.523561956057013,2.807354922057604,3.807354922057604,null,4.169925001442312,null,null,null,0.0,7.2384047393250786,5.20945336562895,4.584962500721156,4.0,4.087462841250339,5.044394119358453,3.9068905956085187,3.700439718141092,null,1.0,2.0,2.0,3.4594316186372973,4.0,5.554588851677638,2.584962500721156,null,2.321928094887362,1.0,2.321928094887362,2.584962500721156,3.321928094887362,null,null,0.0,0.0,1.584962500721156,null,5.754887502163468,2.321928094887362,1.0,2.807354922057604,2.807354922057604,1.0,3.4594316186372973,2.584962500721156,null,null,0.0,0.0,2.321928094887362,1.0,5.426264754702098,1.584962500721156,0.0,1.584962500721156,3.0,2.584962500721156,1.0,2.0,null,2.321928094887362,1.0,1.0,2.321928094887362,3.321928094887362,4.459431618637297,3.321928094887362,2.321928094887362,0.0,1.584962500721156,2.0,1.584962500721156,1.584962500721156,3.169925001442312,null,0.0,0.0,1.0,1.0,6.882643049361842,5.491853096329675,4.523561956057013,3.4594316186372973,4.459431618637297,3.321928094887362,4.392317422778761,4.0,5.832890014164741,4.0,2.584962500721156,2.584962500721156,3.584962500721156,5.727920454563199,4.523561956057013,1.0,1.0,2.584962500721156,null,null,0.0,0.0,null,null,null,null,null,0.0,7.6653359171851765,3.807354922057604,4.459431618637297,3.4594316186372973,3.584962500721156,4.807354922057604,3.321928094887362,5.392317422778761,null,4.0,2.584962500721156,2.584962500721156,3.321928094887362,3.700439718141092,5.643856189774724,2.0,null,1.0,3.0,2.807354922057604,2.0,2.807354922057604,null,2.584962500721156,null,null,0.0,null,3.321928094887362,0.0,null,2.0,null,null,1.584962500721156,null,null,null,null,null,0.0,2.584962500721156,null,null,null,1.584962500721156,null,0.0,1.584962500721156,null,null,null,0.0,0.0,1.0,1.0,5.459431618637297,3.0,2.584962500721156,5.20945336562895,6.303780748177103,2.0,1.0,4.0,null,4.0,2.0,2.0,3.0,null,7.851749041416057,6.247927513443585,5.906890595608519,3.0,6.044394119358453,5.321928094887363,3.321928094887362,5.426264754702098,null,4.584962500721156,2.0,2.0,3.321928094887362,4.0,6.285402218862249,4.906890595608519,3.0,3.584962500721156,4.169925001442312,4.523561956057013,1.0,3.0,null,null,2.321928094887362,2.321928094887362,3.321928094887362,3.321928094887362,4.807354922057604,2.0,3.584962500721156,1.584962500721156,2.807354922057604,1.0,1.0,2.321928094887362,null,null,null,null,0.0,2.584962500721156,7.011227255423254,3.321928094887362,3.169925001442312,3.584962500721156,4.459431618637297,null,2.584962500721156,3.700439718141092,null,1.584962500721156,null,null,1.0,null,8.543031820255237,6.882643049361842,5.321928094887363,4.584962500721156,6.087462841250339,5.906890595608519,5.285402218862249,5.357552004618084,null,4.807354922057604,3.584962500721156,3.584962500721156,4.584962500721156,0.0,2.807354922057604,0.0,null,1.584962500721156,null,null,null,0.0,0.0,null,2.0,2.0,3.169925001442312,null,5.584962500721156,2.807354922057604,3.584962500721156,0.0,0.0,2.584962500721156,2.0,3.584962500721156,null,3.0,null,null,null,2.0,7.6293566200796095,5.285402218862249,3.584962500721156,3.321928094887362,3.0,5.087462841250339,2.0,4.459431618637297,null,4.584962500721156,null,null,1.0,0.0,7.149747119504682,6.044394119358453,4.906890595608519,3.0,4.392317422778761,2.807354922057604,4.0,4.700439718141092,0.0,2.0,3.169925001442312,3.169925001442312,4.247927513443585,2.584962500721156,7.159871336778389,4.459431618637297,3.321928094887362,2.0,3.584962500721156,2.0,null,2.0,null,3.700439718141092,null,null,0.0,null,1.584962500721156,null,null,1.0,null,null,null,null,null,null,null,null,0.0,null,8.930737337562887,6.22881869049588,5.906890595608519,4.906890595608519,6.303780748177103,5.882643049361842,4.857980995127572,6.129283016944966,null,4.906890595608519,3.9068905956085187,3.9068905956085187,4.906890595608519,5.0,5.392317422778761,4.807354922057604,2.321928094887362,3.700439718141092,5.087462841250339,4.643856189774724,3.807354922057604,4.0,2.807354922057604,4.0,3.4594316186372973,3.4594316186372973,4.700439718141092,3.169925001442312,6.857980995127572,1.584962500721156,3.700439718141092,2.807354922057604,3.169925001442312,3.9068905956085187,2.0,3.584962500721156,null,1.0,2.0,2.0,3.0,2.321928094887362,6.794415866350106,5.906890595608519,4.906890595608519,3.9068905956085187,5.247927513443585,3.4594316186372973,4.584962500721156,4.459431618637297,null,null,3.321928094887362,3.321928094887362,4.392317422778761,4.459431618637297,5.930737337562887,3.0,3.0,2.321928094887362,3.0,3.584962500721156,2.321928094887362,2.584962500721156,null,3.0,1.0,1.0,2.0,null,5.643856189774724,2.584962500721156,1.584962500721156,2.0,3.169925001442312,null,2.584962500721156,3.584962500721156,null,1.584962500721156,0.0,0.0,1.0,3.321928094887362,7.577428828035749,4.857980995127572,4.169925001442312,4.169925001442312,4.523561956057013,4.754887502163468,4.0,1.584962500721156,null,4.0,3.0,3.0,4.087462841250339,2.321928094887362,5.700439718141092,4.321928094887363,3.4594316186372973,3.0,4.169925001442312,3.9068905956085187,3.807354922057604,4.247927513443585,null,2.584962500721156,null,null,null,null,6.569855608330948,4.169925001442312,3.4594316186372973,2.584962500721156,3.700439718141092,3.0,2.584962500721156,3.321928094887362,null,0.0,3.0,3.0,4.0,2.0,4.857980995127572,2.584962500721156,null,1.0,null,2.0,1.0,1.584962500721156,null,1.0,null,null,null,null,6.285402218862249,4.169925001442312,3.169925001442312,3.169925001442312,3.9068905956085187,3.4594316186372973,3.700439718141092,3.321928094887362,null,2.321928094887362,null,null,0.0,0.0,null,null,1.584962500721156,1.584962500721156,null,0.0,null,null,null,null,null,null,1.0,1.0,9.614709844115207,6.507794640198696,5.906890595608519,4.700439718141092,6.727920454563199,5.906890595608519,5.954196310386875,6.129283016944966,null,5.247927513443585,4.247927513443585,4.247927513443585,5.285402218862249,6.044394119358453,8.92481250360578,7.108524456778169,6.357552004618084,5.584962500721156,6.303780748177103,6.321928094887363,5.857980995127572,6.3750394313469245,null,4.459431618637297,4.087462841250339,4.087462841250339,5.087462841250339,null,10.083479327331842,7.7481928495894605,7.515699838284043,8.169925001442312,7.348728154231077,7.066089190457772,7.523561956057013,7.3750394313469245,null,6.0,5.169925001442312,5.169925001442312,6.189824558880018,5.700439718141092,7.554588851677638,4.700439718141092,3.584962500721156,3.584962500721156,4.459431618637297,4.459431618637297,3.321928094887362,4.807354922057604,null,3.321928094887362,2.321928094887362,2.321928094887362,3.584962500721156,3.321928094887362,8.066089190457772,5.459431618637297,4.459431618637297,3.0,5.0,3.807354922057604,5.129283016944966,5.523561956057013,null,4.584962500721156,2.0,2.0,3.0,0.0,6.392317422778761,4.459431618637297,2.584962500721156,2.807354922057604,3.321928094887362,2.584962500721156,4.321928094887363,4.0,null,null,2.321928094887362,2.321928094887362,3.584962500721156,3.0,8.344295907915816,6.129283016944966,4.700439718141092,4.584962500721156,5.285402218862249,5.129283016944966,4.321928094887363,6.0,null,2.584962500721156,2.0,2.0,3.4594316186372973,3.169925001442312,8.098032082960527,3.0,4.807354922057604,3.584962500721156,4.523561956057013,3.584962500721156,2.0,3.807354922057604,null,3.807354922057604,0.0,0.0,1.0,1.584962500721156,7.011227255423254,3.9068905956085187,2.584962500721156,2.321928094887362,3.169925001442312,2.0,3.321928094887362,3.9068905956085187,null,2.0,1.0,1.0,2.321928094887362,0.0,6.392317422778761,3.321928094887362,2.321928094887362,1.584962500721156,2.321928094887362,3.0,2.0,3.4594316186372973,null,1.584962500721156,null,null,null,3.584962500721156,6.285402218862249,3.169925001442312,null,2.584962500721156,1.584962500721156,3.169925001442312,2.321928094887362,1.584962500721156,null,1.0,1.0,1.0,2.0,1.0,null,1.0,1.0,1.584962500721156,null,null,0.0,null,null,null,null,null,1.0,2.584962500721156,9.92035285541508,8.761551232444479,8.618385502258606,7.022367813028454,8.731319031025064,8.471675214392045,8.383704292474052,8.405141463136344,null,5.357552004618084,5.954196310386875,5.954196310386875,6.965784284662087,4.954196310386875,8.954196310386875,6.584962500721156,6.087462841250339,4.523561956057013,5.754887502163468,6.247927513443585,4.906890595608519,6.189824558880018,null,2.0,4.906890595608519,4.906890595608519,5.906890595608519,null,6.149747119504682,3.807354922057604,3.0,2.807354922057604,4.0,3.0,3.584962500721156,3.807354922057604,null,2.584962500721156,2.321928094887362,2.321928094887362,3.321928094887362,2.0,8.243173983472952,5.727920454563199,5.643856189774724,4.584962500721156,5.700439718141092,5.459431618637297,5.20945336562895,6.066089190457772,null,4.087462841250339,2.0,2.0,3.169925001442312,4.0,3.584962500721156,2.0,1.0,null,1.0,null,2.0,1.584962500721156,null,null,null,null,null,null,5.087462841250339,2.584962500721156,1.584962500721156,2.321928094887362,3.0,3.9068905956085187,1.584962500721156,3.584962500721156,null,null,1.0,1.0,2.0,null,7.1799090900149345,3.321928094887362,3.0,2.584962500721156,3.700439718141092,3.321928094887362,1.0,3.700439718141092,3.0,2.0,1.584962500721156,1.584962500721156,2.584962500721156,3.321928094887362,6.426264754702098,3.807354922057604,2.584962500721156,2.321928094887362,2.584962500721156,2.584962500721156,3.0,4.0,null,null,1.0,1.0,2.0,1.584962500721156,3.9068905956085187,3.584962500721156,4.087462841250339,2.584962500721156,2.807354922057604,3.321928094887362,null,1.0,null,2.0,1.0,1.0,2.0,null,4.906890595608519,4.321928094887363,3.584962500721156,2.321928094887362,3.4594316186372973,3.0,3.700439718141092,2.0,null,null,1.0,1.0,2.321928094887362,null,0.0,2.321928094887362,1.0,1.584962500721156,0.0,null,2.584962500721156,1.584962500721156,null,null,null,null,1.584962500721156,null,null,null,0.0,null,null,null,null,null,null,null,null,null,1.0,null,6.409390936137702,5.857980995127572,5.807354922057604,5.169925001442312,6.22881869049588,6.507794640198696,6.20945336562895,6.129283016944966,null,3.0,2.807354922057604,2.807354922057604,3.9068905956085187,4.169925001442312,6.523561956057013,6.303780748177103,3.4594316186372973,4.321928094887363,5.20945336562895,5.882643049361842,5.459431618637297,5.426264754702098,5.247927513443585,1.0,4.392317422778761,4.392317422778761,5.357552004618084,3.584962500721156,5.523561956057013,6.339850002884624,3.807354922057604,3.321928094887362,5.087462841250339,5.459431618637297,4.169925001442312,4.0,null,2.0,2.321928094887362,2.321928094887362,3.584962500721156,1.0,7.321928094887363,6.169925001442312,6.0,4.247927513443585,5.954196310386875,5.754887502163468,5.672425341971495,5.954196310386875,null,3.584962500721156,null,null,null,3.584962500721156,4.807354922057604,4.459431618637297,3.0,2.584962500721156,3.321928094887362,3.321928094887362,3.321928094887362,3.9068905956085187,null,1.0,null,null,null,1.584962500721156,5.754887502163468,4.392317422778761,3.0,3.0,3.9068905956085187,3.807354922057604,3.584962500721156,4.807354922057604,null,null,2.807354922057604,2.807354922057604,3.9068905956085187,3.584962500721156,9.047123912114026,8.076815597050832,7.348728154231077,5.643856189774724,7.1799090900149345,7.577428828035749,6.6293566200796095,7.357552004618084,null,4.807354922057604,4.700439718141092,4.700439718141092,5.700439718141092,3.807354922057604,3.9068905956085187,3.169925001442312,1.584962500721156,2.0,1.0,2.0,1.0,2.0,null,null,1.584962500721156,1.584962500721156,3.169925001442312,1.0,7.199672344836364,6.672425341971495,5.807354922057604,4.807354922057604,5.614709844115208,6.22881869049588,5.700439718141092,5.78135971352466,null,4.087462841250339,3.4594316186372973,3.4594316186372973,4.523561956057013,2.0,4.857980995127572,4.700439718141092,3.0,1.584962500721156,3.321928094887362,4.247927513443585,null,2.584962500721156,null,1.0,1.0,1.0,2.321928094887362,2.584962500721156,5.169925001442312,4.459431618637297,1.584962500721156,2.584962500721156,3.169925001442312,4.169925001442312,3.321928094887362,3.807354922057604,null,2.584962500721156,1.584962500721156,1.584962500721156,3.0,3.4594316186372973,null,0.0,1.584962500721156,1.0,null,null,0.0,null,null,null,null,null,1.0,1.0,8.417852514885897,7.924812503605781,7.348728154231077,5.832890014164741,7.475733430966398,7.417852514885898,7.2384047393250786,7.321928094887363,null,4.700439718141092,null,null,null,5.169925001442312,9.832890014164741,9.409390936137703,9.152284842306582,7.6293566200796095,9.169925001442312,8.64745842645492,9.152284842306582,8.72451385311995,null,6.20945336562895,7.149747119504682,7.149747119504682,8.164906926675688,6.189824558880018,5.20945336562895,4.807354922057604,2.807354922057604,2.0,3.0,1.0,0.0,3.700439718141092,null,1.0,2.807354922057604,2.807354922057604,4.0,1.584962500721156,6.022367813028454,5.832890014164741,6.0,4.700439718141092,5.357552004618084,5.357552004618084,5.087462841250339,4.954196310386875,null,3.0,2.0,2.0,3.4594316186372973,null,null,0.0,null,2.0,null,null,null,null,null,null,null,null,0.0,null,1.584962500721156,1.0,null,0.0,1.584962500721156,1.0,null,1.0,null,null,1.0,1.0,2.0,null,6.285402218862249,6.149747119504682,5.614709844115208,3.807354922057604,5.882643049361842,5.20945336562895,5.491853096329675,5.857980995127572,5.392317422778761,3.807354922057604,4.169925001442312,4.169925001442312,5.20945336562895,3.169925001442312,null,1.0,0.0,0.0,null,null,null,1.584962500721156,null,null,null,null,0.0,0.0,5.78135971352466,4.906890595608519,4.906890595608519,4.087462841250339,3.9068905956085187,4.459431618637297,4.0,4.321928094887363,null,2.0,3.700439718141092,3.700439718141092,4.754887502163468,2.584962500721156,null,0.0,1.584962500721156,2.321928094887362,null,0.0,null,null,null,null,null,null,1.0,1.584962500721156,6.321928094887363,5.129283016944966,4.247927513443585,3.807354922057604,4.807354922057604,5.491853096329675,4.906890595608519,5.247927513443585,null,3.4594316186372973,3.169925001442312,3.169925001442312,4.169925001442312,null,null,0.0,1.0,1.584962500721156,null,null,1.584962500721156,null,null,null,null,null,0.0,1.584962500721156,4.954196310386875,1.584962500721156,1.584962500721156,2.807354922057604,null,null,1.0,0.0,0.0,null,null,null,1.584962500721156,3.700439718141092,1.584962500721156,null,0.0,null,null,null,1.0,null,null,null,null,null,null,2.0,8.471675214392045,5.643856189774724,4.700439718141092,7.0,4.857980995127572,5.321928094887363,5.426264754702098,5.247927513443585,1.584962500721156,5.129283016944966,3.584962500721156,3.584962500721156,4.754887502163468,4.643856189774724,9.259743263690781,6.672425341971495,6.78135971352466,4.643856189774724,6.247927513443585,2.0,6.523561956057013,6.539158811108031,null,5.426264754702098,6.599912842187128,6.599912842187128,7.622051819456376,5.0,9.098032082960527,5.0,5.285402218862249,1.0,5.087462841250339,null,4.247927513443585,3.321928094887362,4.459431618637297,5.0,0.0,0.0,1.584962500721156,4.459431618637297,3.584962500721156,2.584962500721156,null,2.0,2.0,null,null,1.584962500721156,null,1.0,0.0,0.0,1.0,0.0,0.0,4.247927513443585,null,1.584962500721156,0.0,3.0,null,1.584962500721156,null,null,null,null,null,null,3.0,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,3.169925001442312,2.321928094887362,3.807354922057604,3.4594316186372973,1.0,3.321928094887362,1.0,2.807354922057604,null,2.584962500721156,1.584962500721156,1.584962500721156,2.584962500721156,0.0,3.584962500721156,3.169925001442312,1.0,4.321928094887363,2.0,1.0,null,1.584962500721156,0.0,0.0,null,null,null,null,4.0,3.584962500721156,1.584962500721156,0.0,3.169925001442312,null,2.807354922057604,2.807354922057604,null,2.0,null,null,null,null,5.044394119358453,2.0,null,2.0,2.321928094887362,1.0,1.0,2.0,null,null,null,null,null,1.0,7.459431618637297,4.392317422778761,4.0,3.169925001442312,3.807354922057604,null,4.169925001442312,3.700439718141092,null,4.087462841250339,3.4594316186372973,3.4594316186372973,4.459431618637297,2.0,8.134426320220927,6.599912842187128,5.044394119358453,6.658211482751795,6.169925001442312,5.087462841250339,5.392317422778761,6.247927513443585,0.0,4.392317422778761,3.169925001442312,3.169925001442312,4.321928094887363,null,2.584962500721156,1.0,0.0,null,0.0,null,1.0,null,null,null,null,null,null,null,6.087462841250339,2.0,3.807354922057604,2.321928094887362,0.0,0.0,3.700439718141092,2.0,4.087462841250339,3.0,null,null,null,3.169925001442312,3.584962500721156,null,1.0,0.0,0.0,2.584962500721156,null,1.0,null,1.0,null,null,null,null,3.4594316186372973,null,null,3.0,null,0.0,null,null,null,1.0,null,null,null,null,7.066089190457772,3.169925001442312,3.0,null,3.4594316186372973,null,3.321928094887362,2.807354922057604,null,2.584962500721156,null,null,null,3.0,5.882643049361842,2.584962500721156,1.0,2.0,2.0,null,1.0,2.584962500721156,null,3.0,1.0,1.0,2.321928094887362,3.169925001442312,4.169925001442312,null,1.584962500721156,1.0,0.0,null,2.584962500721156,2.0,1.0,1.0,null,null,null,0.0,5.044394119358453,2.0,2.0,1.0,2.0,null,null,2.0,null,2.584962500721156,null,null,null,3.0,5.087462841250339,3.169925001442312,1.0,3.169925001442312,1.584962500721156,null,null,2.0,2.321928094887362,1.0,null,null,0.0,1.0,4.0,1.584962500721156,1.0,2.0,null,0.0,null,null,null,null,null,null,1.584962500721156,null,4.807354922057604,2.0,1.0,5.857980995127572,4.643856189774724,null,null,3.4594316186372973,0.0,3.321928094887362,0.0,0.0,1.0,null,9.14210705730255,5.832890014164741,6.321928094887363,3.807354922057604,5.426264754702098,2.0,5.954196310386875,5.285402218862249,null,5.754887502163468,4.321928094887363,4.321928094887363,5.321928094887363,4.459431618637297,3.584962500721156,1.0,null,3.0,2.0,3.0,1.0,0.0,null,1.0,0.0,0.0,1.584962500721156,null,3.700439718141092,2.321928094887362,null,1.584962500721156,null,1.0,1.0,0.0,0.0,null,null,null,null,1.0,7.129283016944966,4.169925001442312,4.643856189774724,3.321928094887362,3.169925001442312,1.0,2.807354922057604,3.807354922057604,0.0,3.584962500721156,3.169925001442312,3.169925001442312,4.321928094887363,5.247927513443585,6.9886846867721655,3.0,2.321928094887362,3.169925001442312,3.807354922057604,2.0,3.321928094887362,2.807354922057604,null,4.906890595608519,1.0,1.0,2.321928094887362,0.0,5.754887502163468,null,null,4.087462841250339,1.584962500721156,1.0,2.0,1.0,1.0,1.584962500721156,1.584962500721156,1.584962500721156,2.584962500721156,null,5.459431618637297,1.584962500721156,1.0,2.0,2.0,null,3.4594316186372973,2.584962500721156,null,1.0,2.807354922057604,2.807354922057604,3.807354922057604,null,5.169925001442312,null,null,2.0,1.0,1.0,1.0,1.0,null,3.321928094887362,null,null,null,null,3.9068905956085187,null,2.0,null,null,null,1.0,1.584962500721156,0.0,2.0,0.0,0.0,1.0,1.0,5.169925001442312,2.321928094887362,2.807354922057604,null,2.0,null,2.0,0.0,2.321928094887362,null,null,null,2.0,1.584962500721156,3.321928094887362,2.0,2.584962500721156,null,null,null,1.0,null,null,null,null,null,0.0,1.0,8.08214904135387,6.189824558880018,5.20945336562895,2.584962500721156,5.672425341971495,null,2.584962500721156,5.392317422778761,5.087462841250339,3.9068905956085187,3.321928094887362,3.321928094887362,4.321928094887363,3.807354922057604,7.247927513443585,4.857980995127572,4.906890595608519,2.584962500721156,5.285402218862249,0.0,4.643856189774724,4.954196310386875,4.169925001442312,3.0,4.0,4.0,5.044394119358453,3.169925001442312,6.794415866350106,3.169925001442312,3.4594316186372973,2.807354922057604,4.169925001442312,3.321928094887362,3.0,2.584962500721156,null,4.321928094887363,0.0,0.0,1.0,null,6.569855608330948,4.584962500721156,4.754887502163468,2.0,4.523561956057013,null,3.321928094887362,5.20945336562895,4.0,4.0,3.9068905956085187,3.9068905956085187,4.906890595608519,3.9068905956085187,2.0,0.0,0.0,null,null,null,1.0,1.0,null,null,0.0,0.0,1.584962500721156,null,5.459431618637297,2.0,null,1.0,2.0,null,1.0,1.0,1.584962500721156,null,null,null,1.0,null,4.584962500721156,null,0.0,null,1.0,1.0,null,1.0,null,1.0,null,null,null,1.0,4.247927513443585,1.0,1.0,1.0,3.169925001442312,0.0,1.0,0.0,0.0,2.0,null,null,null,null,6.321928094887363,2.584962500721156,3.9068905956085187,2.0,2.807354922057604,1.0,1.0,3.169925001442312,2.807354922057604,2.321928094887362,1.0,1.0,2.0,null,3.584962500721156,null,1.0,0.0,0.0,null,0.0,0.0,null,1.584962500721156,0.0,0.0,2.0,null,3.0,2.807354922057604,1.0,0.0,1.584962500721156,null,null,2.321928094887362,null,null,null,null,null,null,2.321928094887362,null,0.0,0.0,null,null,1.0,null,null,1.0,null,null,0.0,null,3.9068905956085187,0.0,null,2.321928094887362,0.0,null,null,0.0,1.584962500721156,0.0,null,null,null,null,8.49585502688717,6.426264754702098,6.266786540694901,4.087462841250339,5.584962500721156,null,5.614709844115208,6.475733430966398,6.714245517666122,5.285402218862249,1.0,1.0,2.0,4.700439718141092,8.611024797307353,6.108524456778169,5.426264754702098,3.4594316186372973,4.700439718141092,0.0,4.0,5.321928094887363,4.584962500721156,4.392317422778761,1.584962500721156,1.584962500721156,2.584962500721156,4.700439718141092,6.022367813028454,3.807354922057604,2.0,4.584962500721156,null,null,0.0,null,null,1.0,null,null,null,2.0,5.554588851677638,2.0,1.0,2.321928094887362,2.321928094887362,null,1.0,2.0,1.0,2.584962500721156,null,null,null,null,5.044394119358453,1.0,3.0,2.0,1.0,null,2.0,2.321928094887362,2.0,3.0,null,null,0.0,3.0,5.930737337562887,2.0,0.0,2.0,2.0,null,0.0,0.0,0.0,2.0,null,null,null,2.584962500721156,6.087462841250339,null,2.321928094887362,null,0.0,null,null,1.0,null,4.169925001442312,null,null,null,null,7.577428828035749,4.459431618637297,5.285402218862249,3.4594316186372973,4.392317422778761,2.0,2.584962500721156,3.4594316186372973,null,3.169925001442312,3.169925001442312,3.169925001442312,4.169925001442312,5.321928094887363,6.022367813028454,3.321928094887362,2.584962500721156,null,1.584962500721156,0.0,2.584962500721156,2.321928094887362,null,1.0,null,null,null,null,5.247927513443585,2.321928094887362,2.0,3.0,2.321928094887362,null,null,1.584962500721156,1.0,2.0,2.321928094887362,2.321928094887362,3.4594316186372973,null,4.954196310386875,1.0,2.584962500721156,3.169925001442312,1.584962500721156,null,null,1.0,2.0,null,0.0,0.0,1.584962500721156,null,2.321928094887362,1.0,null,1.0,null,null,0.0,0.0,null,0.0,null,null,0.0,null,5.523561956057013,3.321928094887362,0.0,4.643856189774724,3.584962500721156,1.0,2.807354922057604,2.321928094887362,null,3.584962500721156,0.0,0.0,1.0,1.0,6.507794640198696,3.807354922057604,3.584962500721156,3.0,3.700439718141092,null,1.0,3.0,null,3.807354922057604,3.700439718141092,3.700439718141092,4.754887502163468,3.4594316186372973,8.366322214245816,6.426264754702098,5.857980995127572,0.0,5.169925001442312,2.0,5.523561956057013,5.78135971352466,5.357552004618084,5.0,null,null,1.0,3.807354922057604,2.807354922057604,null,null,0.0,null,null,null,null,null,null,null,null,null,1.0,5.727920454563199,3.0,2.321928094887362,2.321928094887362,0.0,0.0,1.0,2.321928094887362,null,3.807354922057604,1.584962500721156,1.584962500721156,2.321928094887362,null,3.9068905956085187,2.0,null,null,0.0,null,null,0.0,0.0,null,null,null,null,null,5.807354922057604,2.807354922057604,0.0,0.0,3.169925001442312,null,3.321928094887362,2.321928094887362,1.0,1.0,1.0,1.0,2.321928094887362,3.584962500721156,4.459431618637297,3.9068905956085187,null,0.0,4.0,null,2.584962500721156,3.700439718141092,1.0,null,1.0,1.0,2.321928094887362,null,4.247927513443585,2.584962500721156,2.321928094887362,4.321928094887363,1.584962500721156,2.584962500721156,null,2.321928094887362,2.584962500721156,3.321928094887362,null,null,null,null,2.0,2.0,2.0,1.584962500721156,0.0,1.0,2.0,1.0,null,1.0,0.0,0.0,1.0,null,null,null,1.0,null,null,null,null,0.0,0.0,null,null,null,null,null,6.20945336562895,5.459431618637297,4.857980995127572,5.882643049361842,4.643856189774724,4.0,5.357552004618084,4.906890595608519,1.0,1.584962500721156,3.169925001442312,3.169925001442312,4.392317422778761,3.700439718141092,3.4594316186372973,3.584962500721156,3.321928094887362,1.0,null,2.0,1.584962500721156,0.0,null,1.584962500721156,null,null,null,null,5.169925001442312,6.3750394313469245,4.169925001442312,null,5.169925001442312,null,2.321928094887362,5.857980995127572,0.0,null,null,null,null,3.0,6.894817763307944,6.0,5.247927513443585,6.357552004618084,4.954196310386875,5.321928094887363,4.169925001442312,4.807354922057604,3.807354922057604,2.0,3.807354922057604,3.807354922057604,4.807354922057604,2.0,5.857980995127572,5.392317422778761,3.9068905956085187,3.9068905956085187,5.169925001442312,4.700439718141092,3.700439718141092,5.044394119358453,1.0,2.584962500721156,3.321928094887362,3.321928094887362,4.321928094887363,3.169925001442312,3.321928094887362,2.321928094887362,null,0.0,2.584962500721156,null,1.0,1.0,1.584962500721156,null,null,null,0.0,null,4.700439718141092,4.0,3.9068905956085187,2.321928094887362,1.584962500721156,2.584962500721156,2.0,3.584962500721156,null,2.584962500721156,0.0,0.0,1.0,null,3.321928094887362,4.247927513443585,2.321928094887362,2.807354922057604,3.700439718141092,2.0,1.0,2.807354922057604,null,1.0,0.0,0.0,1.0,1.0,4.459431618637297,4.643856189774724,null,null,2.321928094887362,2.0,2.0,3.807354922057604,2.584962500721156,2.0,null,null,0.0,null,3.0,3.4594316186372973,1.0,1.0,1.0,null,3.0,2.0,null,null,1.0,1.0,2.0,1.0,3.4594316186372973,2.0,3.0,null,0.0,null,2.584962500721156,null,0.0,1.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.4594316186372973,4.643856189774724,3.807354922057604,3.0,3.584962500721156,2.321928094887362,2.0,3.321928094887362,null,4.169925001442312,2.584962500721156,2.584962500721156,3.700439718141092,null,10.016808287686555,9.071462362556623,9.18239435340453,10.314016703901357,8.965784284662087,7.888743248898259,8.731319031025064,9.052568050804153,4.754887502163468,7.219168520462161,7.845490050944375,7.845490050944375,8.861086905995395,2.0,4.247927513443585,2.321928094887362,3.321928094887362,1.584962500721156,2.0,0.0,3.4594316186372973,2.321928094887362,1.584962500721156,1.0,null,null,null,1.584962500721156,6.882643049361842,6.426264754702098,5.977279923499917,0.0,5.727920454563199,2.584962500721156,4.0,5.754887502163468,0.0,5.321928094887363,5.857980995127572,5.857980995127572,6.894817763307944,2.321928094887362,7.294620748891627,5.285402218862249,5.523561956057013,4.087462841250339,5.554588851677638,2.807354922057604,5.357552004618084,5.954196310386875,null,5.643856189774724,4.643856189774724,4.643856189774724,5.700439718141092,3.321928094887362,2.321928094887362,null,null,0.0,0.0,null,null,0.0,null,null,null,null,null,null,3.9068905956085187,3.807354922057604,3.0,0.0,3.4594316186372973,null,null,2.584962500721156,2.321928094887362,null,2.807354922057604,2.807354922057604,3.807354922057604,1.0,4.0,3.321928094887362,2.0,0.0,1.584962500721156,null,2.584962500721156,2.321928094887362,null,2.584962500721156,null,null,null,2.0,0.0,null,null,1.584962500721156,null,0.0,null,0.0,null,null,null,null,null,null,1.0,null,null,1.0,1.0,null,null,null,null,null,null,null,null,null,3.9068905956085187,3.321928094887362,3.4594316186372973,3.584962500721156,1.584962500721156,1.0,1.0,2.321928094887362,null,0.0,3.700439718141092,3.700439718141092,4.700439718141092,2.584962500721156,0.0,0.0,1.0,0.0,null,null,null,null,null,null,0.0,0.0,1.0,1.0,7.348728154231077,4.754887502163468,5.044394119358453,5.700439718141092,3.807354922057604,3.321928094887362,5.459431618637297,4.247927513443585,null,4.169925001442312,5.129283016944966,5.129283016944966,6.149747119504682,6.087462841250339,7.339850002884624,4.459431618637297,6.129283016944966,6.442943495848728,5.285402218862249,2.584962500721156,6.247927513443585,4.169925001442312,null,3.0,5.321928094887363,5.321928094887363,6.321928094887363,4.807354922057604,9.071462362556623,6.266786540694901,7.0,7.870364719583405,2.584962500721156,6.794415866350106,7.159871336778389,6.820178962415188,null,4.906890595608519,6.643856189774724,6.643856189774724,7.636624620543649,6.78135971352466,7.6865005271832185,5.285402218862249,4.906890595608519,6.741466986401147,4.169925001442312,5.169925001442312,5.357552004618084,5.0,null,3.4594316186372973,5.044394119358453,5.044394119358453,6.044394119358453,4.523561956057013,9.854868383260236,7.0,7.169925001442312,8.546894459887637,6.022367813028454,6.321928094887363,7.483815777264256,6.94251450533924,null,5.807354922057604,6.569855608330948,6.584962500721156,7.577428828035749,5.169925001442312,9.375039431346925,8.344295907915816,8.523561956057012,9.177419537989236,7.076815597050831,7.820178962415188,8.654636028527968,7.592457037268081,null,6.658211482751795,7.2384047393250786,7.257387842692652,8.257387842692651,5.614709844115208,1.584962500721156,6.977279923499917,1.0,1.0,0.0,5.882643049361842,1.0,5.087462841250339,null,null,5.614709844115208,5.614709844115208,6.614709844115208,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,1.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.734709620225838,5.0,5.906890595608519,7.169925001442312,2.807354922057604,5.169925001442312,6.0,4.584962500721156,null,3.807354922057604,5.129283016944966,5.129283016944966,6.149747119504682,3.9068905956085187,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,8.832890014164741,6.807354922057604,6.569855608330948,7.515699838284043,1.0,6.357552004618084,7.189824558880018,6.392317422778761,5.672425341971495,4.954196310386875,6.442943495848728,6.442943495848728,7.451211111832329,5.087462841250339,8.312882955284355,6.409390936137702,6.599912842187128,7.515699838284043,null,5.727920454563199,6.491853096329675,4.906890595608519,null,4.754887502163468,5.78135971352466,5.807354922057604,6.807354922057604,4.906890595608519,8.885696373339394,7.417852514885898,7.636624620543649,8.499845887083206,6.044394119358453,6.9886846867721655,7.409390936137702,6.285402218862249,null,5.087462841250339,7.22881869049588,7.22881869049588,8.228818690495881,5.727920454563199,6.614709844115208,4.906890595608519,4.321928094887363,5.954196310386875,3.807354922057604,4.954196310386875,4.392317422778761,3.321928094887362,null,2.0,2.584962500721156,2.584962500721156,3.584962500721156,3.584962500721156,8.379378367071261,5.78135971352466,6.321928094887363,6.672425341971495,1.0,4.807354922057604,6.491853096329675,5.285402218862249,null,3.584962500721156,3.0,3.0,4.0,3.807354922057604,8.64745842645492,6.022367813028454,6.20945336562895,7.409390936137702,0.0,5.584962500721156,6.285402218862249,4.643856189774724,null,4.700439718141092,6.339850002884624,6.339850002884624,7.348728154231077,6.285402218862249,8.257387842692651,6.129283016944966,5.882643049361842,7.491853096329675,0.0,5.754887502163468,6.475733430966398,5.882643049361842,null,5.247927513443585,5.523561956057013,5.523561956057013,6.507794640198696,5.20945336562895,6.930737337562887,5.044394119358453,4.0,5.426264754702098,0.0,2.584962500721156,3.9068905956085187,3.169925001442312,null,4.0,3.9068905956085187,3.9068905956085187,4.906890595608519,3.584962500721156,8.39231742277876,6.266786540694901,6.066089190457772,7.741466986401147,5.357552004618084,5.247927513443585,7.266786540694901,4.0,4.459431618637297,4.169925001442312,4.459431618637297,4.459431618637297,5.459431618637297,4.857980995127572,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,8.066089190457772,6.044394119358453,6.022367813028454,7.491853096329675,5.554588851677638,6.087462841250339,6.442943495848728,4.857980995127572,null,4.700439718141092,6.189824558880018,6.189824558880018,7.1799090900149345,5.882643049361842,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,7.562242424221073,5.169925001442312,5.584962500721156,6.794415866350106,4.247927513443585,4.857980995127572,5.906890595608519,4.247927513443585,1.584962500721156,4.459431618637297,5.554588851677638,5.554588851677638,6.584962500721156,5.285402218862249,4.392317422778761,3.807354922057604,2.0,6.700439718141092,4.857980995127572,3.0,3.0,2.321928094887362,1.584962500721156,2.807354922057604,1.584962500721156,1.584962500721156,2.584962500721156,1.0,7.693486957499325,4.906890595608519,4.954196310386875,6.658211482751795,3.584962500721156,4.459431618637297,3.584962500721156,4.0,null,4.321928094887363,4.807354922057604,4.807354922057604,5.807354922057604,4.523561956057013,7.118941072723508,4.754887502163468,4.857980995127572,5.700439718141092,4.459431618637297,2.584962500721156,4.087462841250339,3.4594316186372973,null,3.584962500721156,4.247927513443585,4.247927513443585,5.321928094887363,4.584962500721156,8.016808287686555,6.169925001442312,6.22881869049588,7.139551352398794,6.0,4.954196310386875,6.672425341971495,5.392317422778761,null,4.169925001442312,5.392317422778761,5.392317422778761,6.392317422778761,4.392317422778761,7.787902559391432,5.977279923499917,6.022367813028454,6.22881869049588,4.643856189774724,5.321928094887363,5.285402218862249,4.0,null,4.0,4.523561956057013,4.523561956057013,5.614709844115208,4.584962500721156,1.584962500721156,1.584962500721156,0.0,2.0,null,null,null,null,null,null,null,null,null,2.584962500721156,null,1.0,null,null,null,null,null,null,0.0,1.0,null,null,null,1.0,7.087462841250339,4.857980995127572,5.20945336562895,6.857980995127572,0.0,3.807354922057604,5.807354922057604,3.321928094887362,null,3.9068905956085187,3.169925001442312,3.169925001442312,4.392317422778761,3.0,8.400879436282183,6.672425341971495,6.727920454563199,7.754887502163468,2.321928094887362,6.169925001442312,7.022367813028454,6.044394119358453,1.0,4.700439718141092,6.700439718141092,6.700439718141092,7.700439718141092,6.22881869049588,7.467605550082998,5.882643049361842,5.643856189774724,7.011227255423254,5.78135971352466,4.321928094887363,6.149747119504682,3.807354922057604,null,4.0,5.832890014164741,5.832890014164741,6.820178962415188,3.584962500721156,0.0,null,1.0,3.0,null,null,null,0.0,null,null,null,null,null,null,7.870364719583405,6.0,4.700439718141092,7.149747119504682,4.857980995127572,5.754887502163468,6.714245517666122,4.954196310386875,null,4.584962500721156,5.459431618637297,5.459431618637297,6.442943495848728,5.700439718141092,7.219168520462161,4.0,4.700439718141092,6.169925001442312,0.0,4.169925001442312,6.0,4.643856189774724,null,3.807354922057604,5.0,5.0,6.022367813028454,3.807354922057604,7.531381460516312,5.285402218862249,5.554588851677638,6.6293566200796095,4.321928094887363,5.0,5.700439718141092,4.523561956057013,null,4.459431618637297,5.392317422778761,5.392317422778761,6.392317422778761,5.169925001442312,7.734709620225838,5.672425341971495,5.285402218862249,6.6293566200796095,null,4.807354922057604,5.247927513443585,5.169925001442312,5.0,3.807354922057604,5.169925001442312,5.169925001442312,6.20945336562895,5.882643049361842,7.409390936137702,5.20945336562895,4.700439718141092,6.954196310386875,null,5.169925001442312,6.129283016944966,4.459431618637297,null,2.584962500721156,4.321928094887363,4.321928094887363,5.357552004618084,1.0,7.507794640198696,5.169925001442312,5.643856189774724,6.584962500721156,4.807354922057604,4.906890595608519,5.0,5.554588851677638,null,3.0,4.392317422778761,4.392317422778761,5.426264754702098,4.584962500721156,4.169925001442312,null,1.0,1.0,null,1.0,null,0.0,null,2.0,1.0,1.0,2.584962500721156,null,8.339850002884624,7.076815597050831,7.643856189774724,8.550746785383243,2.584962500721156,6.169925001442312,7.754887502163468,7.108524456778169,null,5.169925001442312,7.2384047393250786,7.2384047393250786,8.238404739325079,5.614709844115208,8.194756854422248,6.285402218862249,6.392317422778761,7.727920454563199,2.0,5.857980995127572,6.507794640198696,5.491853096329675,null,4.321928094887363,6.459431618637297,6.459431618637297,7.475733430966398,4.754887502163468,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.714245517666122,5.392317422778761,5.285402218862249,7.330916878114617,4.754887502163468,5.20945336562895,6.491853096329675,5.882643049361842,null,4.584962500721156,4.523561956057013,4.523561956057013,5.554588851677638,4.0,0.0,null,null,null,null,null,1.0,null,null,null,null,null,null,null,8.810571634741146,6.906890595608519,6.94251450533924,7.994353436858858,6.845490050944375,6.491853096329675,7.554588851677638,5.491853096329675,5.614709844115208,4.321928094887363,6.832890014164741,6.832890014164741,7.832890014164741,5.954196310386875,7.451211111832329,4.906890595608519,5.129283016944966,6.554588851677638,4.247927513443585,4.643856189774724,6.0,3.0,null,3.4594316186372973,4.807354922057604,4.807354922057604,5.807354922057604,2.0,7.906890595608519,6.066089190457772,6.303780748177103,7.383704292474052,0.0,6.459431618637297,6.247927513443585,4.523561956057013,null,4.700439718141092,6.20945336562895,6.20945336562895,7.199672344836364,5.247927513443585,3.4594316186372973,2.584962500721156,2.321928094887362,2.584962500721156,null,1.584962500721156,0.0,1.0,null,2.0,2.0,2.0,3.169925001442312,2.584962500721156,7.05528243550119,4.169925001442312,5.285402218862249,6.491853096329675,0.0,4.169925001442312,6.087462841250339,3.169925001442312,null,3.169925001442312,5.247927513443585,5.247927513443585,6.247927513443585,4.754887502163468,7.636624620543649,5.727920454563199,5.392317422778761,7.159871336778389,4.643856189774724,5.169925001442312,5.977279923499917,4.523561956057013,null,2.807354922057604,4.584962500721156,4.584962500721156,5.584962500721156,5.087462841250339,3.9068905956085187,1.0,0.0,1.0,0.0,2.0,1.0,1.0,null,null,null,null,null,null,6.954196310386875,4.0,2.584962500721156,5.044394119358453,null,1.0,3.700439718141092,2.584962500721156,null,3.321928094887362,3.321928094887362,3.321928094887362,4.459431618637297,1.584962500721156,8.243173983472952,6.149747119504682,6.357552004618084,7.546894459887636,4.954196310386875,5.906890595608519,6.3750394313469245,5.700439718141092,5.357552004618084,5.044394119358453,5.882643049361842,5.882643049361842,6.894817763307944,5.754887502163468,0.0,null,null,2.0,null,null,null,null,null,null,null,null,null,null,8.219168520462162,6.475733430966398,6.918863237274595,7.693486957499325,5.754887502163468,4.906890595608519,7.266786540694901,4.087462841250339,5.285402218862249,4.321928094887363,6.357552004618084,6.357552004618084,7.357552004618084,5.0,null,null,null,1.0,null,1.0,null,null,null,null,null,null,null,null,8.948367231584678,7.515699838284043,7.066089190457772,8.257387842692651,3.321928094887362,6.643856189774724,7.60733031374961,5.977279923499917,2.807354922057604,5.584962500721156,5.0,5.0,5.977279923499917,4.857980995127572,8.936637939002571,6.820178962415188,7.044394119358453,8.164906926675688,6.189824558880018,5.977279923499917,7.247927513443585,6.714245517666122,null,5.087462841250339,6.954196310386875,6.954196310386875,7.960001932068081,6.357552004618084,8.442943495848729,6.129283016944966,6.321928094887363,7.257387842692652,5.247927513443585,5.754887502163468,6.6865005271832185,5.20945336562895,null,4.169925001442312,6.20945336562895,6.20945336562895,7.189824558880018,5.700439718141092,7.569855608330948,4.857980995127572,5.0,6.569855608330948,1.0,4.954196310386875,5.426264754702098,5.169925001442312,null,4.247927513443585,5.392317422778761,5.392317422778761,6.409390936137702,5.247927513443585,8.98299357469431,8.31741261376487,8.224001674198105,8.326429487122303,6.6293566200796095,6.714245517666122,8.370687406807217,6.459431618637297,6.507794640198696,4.700439718141092,7.383704292474052,7.383704292474052,8.383704292474052,6.459431618637297,6.6293566200796095,1.0,2.0,1.0,0.0,1.0,1.0,1.0,null,null,0.0,0.0,1.0,3.807354922057604,5.087462841250339,1.0,1.0,3.700439718141092,null,3.0,null,null,null,2.0,null,null,null,2.584962500721156,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,7.426264754702098,4.700439718141092,6.022367813028454,7.011227255423254,4.643856189774724,4.392317422778761,5.977279923499917,3.321928094887362,null,3.321928094887362,5.087462841250339,5.087462841250339,6.087462841250339,5.087462841250339,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,7.169925001442312,5.882643049361842,5.643856189774724,6.507794640198696,0.0,5.614709844115208,6.392317422778761,4.754887502163468,null,4.584962500721156,5.523561956057013,5.523561956057013,6.523561956057013,3.9068905956085187,7.442943495848728,6.149747119504682,5.882643049361842,7.622051819456376,0.0,5.906890595608519,6.6293566200796095,4.584962500721156,null,4.169925001442312,6.0,6.0,7.0,4.906890595608519,7.6293566200796095,6.392317422778761,6.794415866350106,7.734709620225838,6.066089190457772,5.523561956057013,7.2761244052742375,6.169925001442312,null,4.584962500721156,5.832890014164741,5.832890014164741,6.845490050944375,3.4594316186372973,7.219168520462161,6.266786540694901,6.569855608330948,7.7481928495894605,1.0,5.700439718141092,6.523561956057013,5.807354922057604,null,5.0,6.409390936137702,6.409390936137702,7.400879436282184,5.0,6.906890595608519,5.247927513443585,6.266786540694901,7.159871336778389,4.523561956057013,5.0,6.714245517666122,4.0,null,4.087462841250339,5.857980995127572,5.857980995127572,6.857980995127572,4.169925001442312,6.266786540694901,5.832890014164741,5.087462841250339,7.05528243550119,4.643856189774724,5.321928094887363,4.087462841250339,5.554588851677638,null,4.0,6.044394119358453,6.044394119358453,7.011227255423254,3.321928094887362,7.066089190457772,5.554588851677638,5.584962500721156,6.794415866350106,4.087462841250339,6.087462841250339,6.149747119504682,4.643856189774724,0.0,2.0,5.523561956057013,5.523561956057013,6.523561956057013,4.754887502163468,7.554588851677638,6.087462841250339,6.584962500721156,7.741466986401147,5.882643049361842,6.20945336562895,6.832890014164741,6.169925001442312,null,4.392317422778761,6.78135971352466,6.78135971352466,7.787902559391432,5.584962500721156,0.0,null,null,0.0,null,1.0,null,null,null,null,null,null,null,null,7.169925001442312,6.247927513443585,6.087462841250339,7.159871336778389,5.285402218862249,5.954196310386875,6.977279923499917,5.044394119358453,null,5.0,5.954196310386875,5.954196310386875,6.954196310386875,3.9068905956085187,6.409390936137702,5.357552004618084,5.285402218862249,6.882643049361842,2.321928094887362,4.392317422778761,6.087462841250339,5.20945336562895,4.906890595608519,4.0,5.554588851677638,5.554588851677638,6.614709844115208,3.0,null,1.0,null,null,null,null,null,null,null,null,null,null,null,null,6.569855608330948,5.554588851677638,5.087462841250339,6.78135971352466,0.0,5.491853096329675,5.584962500721156,3.807354922057604,null,4.0,5.672425341971495,5.672425341971495,6.714245517666122,3.807354922057604,7.434628227636725,6.78135971352466,6.569855608330948,7.912889336229962,5.584962500721156,5.584962500721156,7.05528243550119,5.672425341971495,null,4.392317422778761,6.523561956057013,6.523561956057013,7.523561956057013,5.169925001442312,7.417852514885898,6.357552004618084,7.22881869049588,7.98299357469431,1.0,6.129283016944966,7.108524456778169,6.507794640198696,null,4.169925001442312,6.845490050944375,6.845490050944375,7.839203788096944,4.807354922057604,7.832890014164741,6.894817763307944,7.05528243550119,8.43879185257826,2.0,6.94251450533924,7.247927513443585,6.768184324776926,0.0,4.857980995127572,3.169925001442312,3.169925001442312,4.321928094887363,2.0,6.94251450533924,5.459431618637297,5.857980995127572,7.076815597050831,5.169925001442312,6.044394119358453,6.189824558880018,5.20945336562895,null,3.0,5.857980995127572,5.857980995127572,6.882643049361842,4.247927513443585,5.0,3.321928094887362,4.0,4.643856189774724,2.584962500721156,2.0,4.0,3.700439718141092,null,2.0,3.0,3.0,4.087462841250339,2.321928094887362,7.721099188707185,6.672425341971495,6.977279923499917,8.113742166049189,5.906890595608519,5.554588851677638,7.357552004618084,6.820178962415188,null,4.584962500721156,6.965784284662087,6.965784284662087,7.960001932068081,5.0,6.247927513443585,4.643856189774724,5.247927513443585,6.6865005271832185,5.169925001442312,4.0,5.807354922057604,3.9068905956085187,null,4.392317422778761,5.044394119358453,5.044394119358453,6.022367813028454,3.0,0.0,null,1.0,null,null,null,null,null,null,1.0,null,null,null,null,6.672425341971495,5.491853096329675,5.426264754702098,7.076815597050831,0.0,4.754887502163468,6.643856189774724,5.392317422778761,null,4.321928094887363,3.807354922057604,3.807354922057604,4.906890595608519,2.321928094887362,6.794415866350106,6.321928094887363,6.266786540694901,7.592457037268081,0.0,5.727920454563199,7.066089190457772,5.857980995127572,null,3.0,4.700439718141092,4.807354922057604,5.832890014164741,2.807354922057604,5.727920454563199,4.954196310386875,5.044394119358453,6.129283016944966,4.392317422778761,3.807354922057604,4.906890595608519,3.9068905956085187,null,3.321928094887362,5.087462841250339,5.087462841250339,6.087462841250339,2.584962500721156,6.965784284662087,5.584962500721156,5.807354922057604,7.426264754702098,4.321928094887363,5.807354922057604,6.357552004618084,5.044394119358453,null,4.247927513443585,6.20945336562895,6.22881869049588,7.247927513443585,4.169925001442312,7.577428828035749,6.714245517666122,7.044394119358453,8.022367813028454,7.0,6.491853096329675,7.539158811108031,6.754887502163468,null,4.0,7.189824558880018,7.189824558880018,8.189824558880018,4.584962500721156,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,10.687375683437468,8.308339030139408,7.483815777264256,9.131856960608793,7.139551352398794,7.562242424221073,7.643856189774724,7.507794640198696,8.383704292474052,6.426264754702098,6.087462841250339,6.087462841250339,7.118941072723508,7.321928094887363,8.79766152585376,6.977279923499917,6.3750394313469245,6.794415866350106,5.614709844115208,5.78135971352466,6.22881869049588,6.169925001442312,7.800899899920305,5.321928094887363,4.087462841250339,4.087462841250339,5.20945336562895,4.643856189774724,10.029287226968245,8.087462841250339,7.199672344836364,7.906890595608519,6.554588851677638,6.554588851677638,6.845490050944375,6.714245517666122,8.370687406807217,6.357552004618084,5.954196310386875,5.954196310386875,6.954196310386875,5.954196310386875,8.693486957499326,6.672425341971495,5.882643049361842,7.562242424221073,5.459431618637297,5.78135971352466,5.357552004618084,5.285402218862249,7.022367813028454,3.321928094887362,4.857980995127572,4.857980995127572,5.882643049361842,4.643856189774724,10.277287400130357,6.977279923499917,6.754887502163468,7.022367813028454,6.129283016944966,5.906890595608519,6.087462841250339,6.6865005271832185,7.577428828035749,6.285402218862249,5.20945336562895,5.20945336562895,6.285402218862249,7.554588851677638,8.447083226209653,7.599912842187128,6.9886846867721655,8.290018846932618,6.491853096329675,6.491853096329675,6.807354922057604,6.714245517666122,7.2761244052742375,4.700439718141092,5.491853096329675,5.491853096329675,6.539158811108031,4.169925001442312,null,7.400879436282184,null,4.392317422778761,2.584962500721156,6.857980995127572,null,6.930737337562887,0.0,3.584962500721156,5.584962500721156,5.584962500721156,6.584962500721156,null,9.280770770130603,5.857980995127572,5.129283016944966,6.426264754702098,5.321928094887363,5.426264754702098,5.087462841250339,4.857980995127572,6.321928094887363,4.643856189774724,3.321928094887362,3.321928094887362,4.321928094887363,5.129283016944966,0.0,0.0,0.0,0.0,0.0,1.0,1.0,null,null,null,null,null,null,1.0,8.59618975614441,6.266786540694901,5.584962500721156,7.483815777264256,5.20945336562895,5.357552004618084,5.0,4.807354922057604,6.6293566200796095,4.906890595608519,4.0,4.0,5.044394119358453,4.906890595608519,8.108524456778168,7.459431618637297,6.820178962415188,7.400879436282184,6.643856189774724,6.727920454563199,6.189824558880018,6.820178962415188,7.383704292474052,5.044394119358453,5.20945336562895,5.20945336562895,6.266786540694901,4.523561956057013,9.517669388133811,7.159871336778389,6.614709844115208,7.467605550082998,6.169925001442312,6.087462841250339,5.78135971352466,6.169925001442312,7.459431618637297,6.087462841250339,4.906890595608519,4.906890595608519,5.906890595608519,6.882643049361842,9.977279923499916,8.588714635582264,7.539158811108031,9.131856960608793,7.159871336778389,7.383704292474052,7.2761244052742375,7.219168520462161,8.417852514885897,6.3750394313469245,5.832890014164741,5.832890014164741,6.845490050944375,6.614709844115208,10.224001674198105,9.044394119358454,8.103287808412022,8.842350343413807,8.022367813028454,7.864186144654281,8.055282435501189,8.20945336562895,9.207014320177532,7.199672344836364,6.977279923499917,6.977279923499917,8.0,7.60733031374961,9.812177305514448,8.20945336562895,7.392317422778761,8.519636252843213,6.78135971352466,7.451211111832329,6.700439718141092,7.098032082960526,8.703903573444663,5.700439718141092,6.149747119504682,6.149747119504682,7.169925001442312,6.392317422778761,8.252665432450248,5.882643049361842,6.022367813028454,5.523561956057013,5.044394119358453,4.754887502163468,6.22881869049588,5.129283016944966,7.417852514885898,5.321928094887363,3.4594316186372973,3.4594316186372973,4.754887502163468,3.9068905956085187,9.273795599214264,6.584962500721156,6.357552004618084,7.734709620225838,5.727920454563199,6.392317422778761,6.066089190457772,5.614709844115208,7.1799090900149345,5.882643049361842,4.321928094887363,4.321928094887363,5.392317422778761,6.0,10.808159772868375,8.721099188707186,8.238404739325079,9.661778097771988,7.870364719583405,7.857980995127572,7.954196310386875,8.134426320220927,9.219168520462162,6.614709844115208,7.118941072723508,7.118941072723508,8.139551352398794,7.076815597050831,10.253847484987404,8.335390354693924,7.531381460516312,8.344295907915816,7.584962500721156,7.20945336562895,7.426264754702098,7.672425341971495,8.519636252843213,6.108524456778169,6.108524456778169,6.108524456778169,7.149747119504682,6.894817763307944,8.523561956057012,5.882643049361842,4.857980995127572,6.700439718141092,5.459431618637297,4.321928094887363,5.0,4.700439718141092,6.392317422778761,5.247927513443585,3.169925001442312,3.169925001442312,4.321928094887363,3.807354922057604,null,null,null,1.584962500721156,null,null,null,null,null,null,null,null,null,null,9.426264754702098,7.321928094887363,6.658211482751795,8.066089190457772,6.303780748177103,6.554588851677638,6.459431618637297,5.977279923499917,7.774787059601174,6.599912842187128,5.357552004618084,5.357552004618084,6.392317422778761,5.459431618637297,9.842350343413807,7.651051691178929,7.199672344836364,8.519636252843213,7.044394119358453,6.754887502163468,7.149747119504682,6.129283016944966,8.060695931687555,5.523561956057013,5.321928094887363,5.321928094887363,6.357552004618084,7.076815597050831,9.46352437327118,6.189824558880018,6.022367813028454,6.129283016944966,5.554588851677638,4.643856189774724,5.044394119358453,5.392317422778761,7.05528243550119,6.442943495848728,4.087462841250339,4.087462841250339,5.129283016944966,7.011227255423254,6.672425341971495,4.954196310386875,3.584962500721156,8.038918989292302,7.118941072723508,5.0,3.0,5.807354922057604,5.832890014164741,6.700439718141092,2.807354922057604,2.807354922057604,3.9068905956085187,4.392317422778761,9.290018846932618,6.285402218862249,5.78135971352466,7.622051819456376,6.0,5.0,5.20945336562895,5.129283016944966,7.149747119504682,5.977279923499917,3.4594316186372973,3.4594316186372973,4.459431618637297,5.754887502163468,9.092757140919852,6.658211482751795,6.066089190457772,7.499845887083206,5.727920454563199,5.754887502163468,5.807354922057604,5.584962500721156,7.108524456778169,5.0,4.523561956057013,4.523561956057013,5.523561956057013,5.554588851677638,10.62844554013718,9.312882955284355,8.224001674198105,8.79766152585376,7.965784284662087,8.169925001442312,7.636624620543649,8.430452551665532,9.398743691938193,7.303780748177103,7.294620748891627,7.294620748891627,8.312882955284355,7.2384047393250786,9.987264012072538,7.965784284662087,7.03342300153745,7.912889336229962,6.820178962415188,6.169925001442312,6.491853096329675,6.845490050944375,8.294620748891626,6.6865005271832185,5.392317422778761,5.392317422778761,6.426264754702098,6.339850002884624,9.290018846932618,7.451211111832329,6.569855608330948,7.554588851677638,6.614709844115208,6.247927513443585,6.392317422778761,6.491853096329675,7.426264754702098,4.954196310386875,5.087462841250339,5.087462841250339,6.169925001442312,6.22881869049588,9.588714635582264,7.366322214245816,7.022367813028454,8.016808287686555,6.475733430966398,6.523561956057013,6.339850002884624,6.523561956057013,7.894817763307944,6.066089190457772,5.459431618637297,5.459431618637297,6.523561956057013,6.321928094887363,8.829722735086058,6.539158811108031,5.426264754702098,7.577428828035749,5.357552004618084,5.392317422778761,5.20945336562895,5.930737337562887,6.882643049361842,5.321928094887363,4.807354922057604,4.807354922057604,5.906890595608519,4.321928094887363,0.0,null,1.0,2.0,null,0.0,null,null,null,1.0,null,null,0.0,null,9.019590728357882,6.954196310386875,5.882643049361842,4.954196310386875,6.169925001442312,5.977279923499917,5.977279923499917,6.22881869049588,7.426264754702098,5.523561956057013,4.643856189774724,4.643856189774724,5.672425341971495,5.882643049361842,9.689997971419446,6.599912842187128,6.247927513443585,7.467605550082998,6.189824558880018,5.426264754702098,5.857980995127572,5.700439718141092,7.434628227636725,6.129283016944966,3.807354922057604,3.807354922057604,4.857980995127572,5.169925001442312,8.791162888555018,6.727920454563199,5.491853096329675,6.9886846867721655,5.357552004618084,4.523561956057013,5.672425341971495,5.78135971352466,6.6293566200796095,3.4594316186372973,3.584962500721156,3.584962500721156,4.643856189774724,4.459431618637297,10.46352437327118,9.326429487122303,8.566054038171092,9.216745858195306,8.39231742277876,8.271463027904375,7.906890595608519,8.727920454563199,9.62935662007961,7.285402218862249,7.321928094887363,7.321928094887363,8.31741261376487,6.906890595608519,8.813781191217037,7.199672344836364,6.22881869049588,5.977279923499917,6.087462841250339,6.247927513443585,5.643856189774724,5.754887502163468,7.392317422778761,6.20945336562895,5.523561956057013,5.523561956057013,6.599912842187128,6.303780748177103,10.030667136246942,8.144658242831882,7.108524456778169,8.016808287686555,7.129283016944966,7.199672344836364,6.6865005271832185,7.129283016944966,8.348728154231077,6.285402218862249,5.727920454563199,5.727920454563199,6.741466986401147,6.845490050944375,9.759888183221834,8.51175265376738,7.515699838284043,8.262094845370179,7.330916878114617,7.266786540694901,6.741466986401147,7.6293566200796095,9.098032082960527,6.658211482751795,6.426264754702098,6.426264754702098,7.442943495848728,6.954196310386875,9.799281621521923,8.326429487122303,7.3750394313469245,9.095397022792557,7.321928094887363,7.22881869049588,6.794415866350106,7.076815597050831,8.603626344986193,6.044394119358453,6.0,6.0,7.0,7.247927513443585,9.403012023574997,7.434628227636725,6.741466986401147,7.2761244052742375,6.794415866350106,6.569855608330948,6.426264754702098,6.954196310386875,7.7073591320808825,5.459431618637297,5.247927513443585,5.247927513443585,6.357552004618084,5.954196310386875,10.019590728357882,8.353146825498083,7.94251450533924,9.154818109052105,7.592457037268081,7.169925001442312,7.727920454563199,7.658211482751795,8.599912842187127,6.247927513443585,6.266786540694901,6.266786540694901,7.266786540694901,6.906890595608519,8.451211111832329,6.658211482751795,3.700439718141092,6.3750394313469245,5.672425341971495,5.044394119358453,4.906890595608519,5.20945336562895,6.475733430966398,5.285402218862249,4.0,4.0,5.129283016944966,5.426264754702098,1.0,null,1.0,1.0,null,1.0,null,null,null,null,null,null,0.0,null,10.220378327695228,7.971543553950772,7.266786540694901,7.94251450533924,7.098032082960526,6.9886846867721655,6.714245517666122,7.011227255423254,8.479780264029099,6.169925001442312,5.643856189774724,5.643856189774724,6.672425341971495,5.906890595608519,9.483815777264256,7.05528243550119,6.247927513443585,7.727920454563199,6.285402218862249,5.392317422778761,6.22881869049588,6.022367813028454,7.741466986401147,5.459431618637297,5.129283016944966,5.129283016944966,6.129283016944966,4.954196310386875,10.265615046484458,7.658211482751795,6.3750394313469245,7.523561956057013,6.643856189774724,6.266786540694901,6.794415866350106,6.857980995127572,7.936637939002571,5.247927513443585,5.0,5.0,6.0,7.0,9.746514321138463,7.894817763307944,6.643856189774724,8.379378367071261,6.6293566200796095,6.741466986401147,6.614709844115208,6.539158811108031,8.169925001442312,6.044394119358453,5.20945336562895,5.20945336562895,6.247927513443585,6.285402218862249,7.721099188707185,5.643856189774724,5.523561956057013,6.108524456778169,4.523561956057013,4.584962500721156,4.584962500721156,4.459431618637297,6.321928094887363,4.906890595608519,3.9068905956085187,3.9068905956085187,4.906890595608519,5.044394119358453,9.76983784362944,8.581200581924957,7.409390936137702,8.546894459887637,7.348728154231077,7.700439718141092,7.483815777264256,7.531381460516312,8.909893083770042,6.845490050944375,6.087462841250339,6.087462841250339,7.087462841250339,7.22881869049588,9.873444112515376,7.727920454563199,6.918863237274595,8.59245703726808,6.857980995127572,6.459431618637297,5.554588851677638,7.022367813028454,8.290018846932618,5.954196310386875,5.614709844115208,5.614709844115208,6.643856189774724,5.247927513443585,8.693486957499326,6.303780748177103,5.523561956057013,7.285402218862249,5.285402218862249,5.169925001442312,5.491853096329675,5.392317422778761,6.442943495848728,5.459431618637297,3.9068905956085187,3.9068905956085187,4.954196310386875,5.169925001442312,9.400879436282183,7.2384047393250786,7.22881869049588,7.672425341971495,6.6865005271832185,6.643856189774724,6.599912842187128,6.870364719583405,7.882643049361842,5.491853096329675,5.285402218862249,5.285402218862249,6.321928094887363,7.247927513443585,10.043027283594547,7.159871336778389,6.700439718141092,8.149747119504681,6.643856189774724,6.247927513443585,6.584962500721156,6.189824558880018,7.820178962415188,5.930737337562887,5.357552004618084,5.357552004618084,6.392317422778761,6.820178962415188,8.7714894695006,5.727920454563199,3.807354922057604,6.266786540694901,4.321928094887363,4.523561956057013,4.700439718141092,4.754887502163468,6.066089190457772,5.523561956057013,3.169925001442312,3.169925001442312,4.169925001442312,3.0,null,1.0,1.0,1.584962500721156,null,null,null,0.0,null,null,null,null,null,0.0,10.34318571544788,7.700439718141092,7.266786540694901,7.857980995127572,6.832890014164741,7.066089190457772,6.442943495848728,7.383704292474052,8.294620748891626,6.442943495848728,5.357552004618084,5.357552004618084,6.392317422778761,6.643856189774724,9.656424863277781,7.044394119358453,6.409390936137702,7.832890014164741,5.930737337562887,5.491853096329675,6.303780748177103,5.906890595608519,7.087462841250339,6.0,4.754887502163468,4.754887502163468,5.754887502163468,5.554588851677638,9.505811553919594,7.022367813028454,6.491853096329675,7.044394119358453,6.129283016944966,5.700439718141092,6.247927513443585,6.169925001442312,7.417852514885898,5.906890595608519,4.857980995127572,4.857980995127572,5.857980995127572,6.569855608330948,10.443979542601253,8.744833837499545,7.499845887083206,9.303780748177102,7.636624620543649,7.906890595608519,7.651051691178929,7.599912842187128,8.86418614465428,6.491853096329675,6.78135971352466,6.78135971352466,7.851749041416057,6.894817763307944,9.86418614465428,7.954196310386875,6.906890595608519,7.882643049361842,7.022367813028454,7.189824558880018,7.219168520462161,6.9886846867721655,8.51175265376738,5.643856189774724,6.0,6.0,7.05528243550119,5.954196310386875,10.213104219641906,9.257387842692651,8.842350343413807,10.001408194392809,8.668884984266247,8.581200581924957,8.447083226209653,8.353146825498083,9.5980525001616,7.2384047393250786,7.417852514885898,7.417852514885898,8.430452551665532,7.285402218862249,8.851749041416058,7.357552004618084,6.643856189774724,7.78135971352466,5.643856189774724,6.022367813028454,6.022367813028454,6.392317422778761,7.312882955284356,4.807354922057604,4.643856189774724,4.643856189774724,5.700439718141092,5.977279923499917,5.954196310386875,null,null,null,null,null,1.0,1.0,2.321928094887362,null,0.0,0.0,1.0,3.0,10.63117705570398,8.778077129535358,7.826548487290915,8.73809225962049,7.954196310386875,8.285402218862249,7.199672344836364,8.262094845370179,9.03342300153745,6.554588851677638,6.672425341971495,6.672425341971495,7.6865005271832185,7.108524456778169,9.03342300153745,5.754887502163468,5.247927513443585,5.554588851677638,4.754887502163468,4.754887502163468,4.700439718141092,5.614709844115208,6.523561956057013,4.321928094887363,4.321928094887363,4.321928094887363,5.357552004618084,5.584962500721156,9.625708843064466,7.348728154231077,6.954196310386875,6.906890595608519,6.643856189774724,6.523561956057013,6.087462841250339,6.459431618637297,7.569855608330948,4.954196310386875,4.584962500721156,4.584962500721156,5.614709844115208,5.857980995127572,null,1.0,null,1.584962500721156,null,0.0,null,null,null,1.0,0.0,0.0,1.0,null,7.851749041416057,6.523561956057013,5.129283016944966,6.247927513443585,5.321928094887363,5.614709844115208,5.554588851677638,5.392317422778761,6.303780748177103,4.459431618637297,4.0,4.0,5.0,5.20945336562895,8.879583249612784,8.016808287686555,7.108524456778169,8.614709844115207,7.03342300153745,6.409390936137702,6.807354922057604,6.965784284662087,7.78135971352466,5.087462841250339,5.754887502163468,5.754887502163468,6.794415866350106,5.523561956057013,8.39231742277876,7.507794640198696,6.303780748177103,7.888743248898259,6.475733430966398,6.0,6.426264754702098,6.475733430966398,7.321928094887363,5.426264754702098,5.044394119358453,5.087462841250339,6.129283016944966,4.584962500721156,10.395534135462302,9.537218400538595,9.027905996569885,10.246740598493144,8.43879185257826,8.62935662007961,8.81698362325538,8.845490050944376,9.779719355143405,7.129283016944966,7.546894459887636,7.562242424221073,8.569855608330949,7.523561956057013,9.698704666770345,9.118941072723507,8.654636028527968,9.839203788096944,8.08214904135387,8.515699838284043,8.523561956057012,8.29920801838728,9.139551352398794,6.491853096329675,7.491853096329675,7.491853096329675,8.499845887083206,5.954196310386875,9.640244936222345,9.870364719583405,8.734709620225837,10.200898605038445,8.569855608330949,9.00842862207058,8.144658242831882,9.517669388133811,9.622051819456376,6.965784284662087,8.027905996569885,8.027905996569885,9.036173612553485,7.03342300153745,9.44086916761087,8.467605550082997,7.266786540694901,8.842350343413807,7.066089190457772,7.434628227636725,7.169925001442312,8.055282435501189,8.554588851677638,5.357552004618084,6.569855608330948,6.584962500721156,7.614709844115208,5.0,9.579315937580015,8.654636028527968,7.787902559391432,9.149747119504681,7.426264754702098,7.98299357469431,7.6653359171851765,7.700439718141092,8.76487159073609,6.22881869049588,6.741466986401147,6.741466986401147,7.7481928495894605,6.0,8.994353436858859,8.247927513443585,7.924812503605781,8.011227255423254,7.159871336778389,7.05528243550119,7.2384047393250786,7.400879436282184,8.326429487122303,5.247927513443585,6.459431618637297,6.459431618637297,7.467605550082998,6.20945336562895,9.285402218862249,8.134426320220927,7.22881869049588,8.974414589805527,7.266786540694901,7.6293566200796095,6.714245517666122,7.491853096329675,8.396604781181859,4.523561956057013,5.930737337562887,5.930737337562887,6.965784284662087,5.554588851677638,7.918863237274595,7.339850002884624,6.108524456778169,7.247927513443585,6.357552004618084,6.459431618637297,6.129283016944966,6.087462841250339,7.022367813028454,5.169925001442312,5.321928094887363,5.321928094887363,6.3750394313469245,5.044394119358453,1.0,1.0,null,0.0,0.0,0.0,0.0,null,null,null,null,null,null,null,8.038918989292302,7.199672344836364,6.20945336562895,7.700439718141092,6.266786540694901,6.584962500721156,6.044394119358453,6.392317422778761,7.2761244052742375,5.285402218862249,4.459431618637297,4.459431618637297,5.459431618637297,4.321928094887363,8.686500527183219,7.936637939002571,7.622051819456376,8.845490050944376,7.149747119504682,6.9886846867721655,7.434628227636725,6.954196310386875,8.005624549193879,5.977279923499917,5.977279923499917,5.977279923499917,6.9886846867721655,5.129283016944966,7.118941072723508,6.906890595608519,5.584962500721156,7.2761244052742375,4.807354922057604,5.700439718141092,5.882643049361842,5.754887502163468,6.22881869049588,4.584962500721156,5.0,5.0,6.022367813028454,3.584962500721156,10.458406613236532,10.00842862207058,9.216745858195306,10.591522346570734,8.845490050944376,9.294620748891626,9.219168520462162,9.221587121264806,9.939579214314692,7.9886846867721655,8.03342300153745,8.03342300153745,9.038918989292302,7.6865005271832185,8.049848549450562,7.6653359171851765,6.459431618637297,7.562242424221073,6.459431618637297,6.845490050944375,6.906890595608519,6.459431618637297,7.539158811108031,4.247927513443585,5.247927513443585,5.247927513443585,6.266786540694901,4.857980995127572,9.729620743553038,8.997179480937621,7.9886846867721655,9.179909090014934,8.049848549450562,8.243173983472952,7.734709620225838,8.118941072723507,8.939579214314692,6.266786540694901,7.1799090900149345,7.1799090900149345,8.184875342908283,6.714245517666122,9.074141462752506,8.280770770130603,7.491853096329675,9.074141462752506,7.467605550082998,7.400879436282184,7.330916878114617,7.7073591320808825,8.614709844115207,5.614709844115208,6.584962500721156,6.584962500721156,7.60733031374961,5.882643049361842,9.259743263690781,8.603626344986193,7.539158811108031,9.231221180711186,7.2384047393250786,7.554588851677638,7.149747119504682,7.60733031374961,8.413627929024173,5.321928094887363,5.977279923499917,5.977279923499917,6.9886846867721655,6.022367813028454,2.584962500721156,3.0,2.0,1.0,2.584962500721156,2.584962500721156,2.0,2.807354922057604,2.807354922057604,null,1.0,1.0,1.584962500721156,null,8.682994583681683,8.03342300153745,6.94251450533924,8.654636028527968,7.011227255423254,6.807354922057604,7.05528243550119,7.199672344836364,7.882643049361842,5.523561956057013,6.044394119358453,6.044394119358453,7.066089190457772,5.672425341971495,7.6865005271832185,6.658211482751795,6.087462841250339,6.882643049361842,5.700439718141092,6.022367813028454,5.807354922057604,5.954196310386875,7.022367813028454,3.4594316186372973,4.906890595608519,4.906890595608519,5.954196310386875,4.700439718141092,null,1.584962500721156,0.0,0.0,null,1.0,null,null,0.0,null,null,null,null,null,8.330916878114618,7.813781191217037,6.569855608330948,6.426264754702098,6.507794640198696,6.6293566200796095,6.78135971352466,7.139551352398794,7.554588851677638,4.754887502163468,5.672425341971495,5.672425341971495,6.6865005271832185,4.857980995127572,8.562242424221072,8.194756854422248,7.219168520462161,8.614709844115207,6.965784284662087,7.189824558880018,7.257387842692652,7.693486957499325,8.134426320220927,6.459431618637297,6.108524456778169,6.108524456778169,7.139551352398794,5.20945336562895,6.22881869049588,5.523561956057013,4.0,5.977279923499917,4.0,4.807354922057604,4.954196310386875,4.643856189774724,5.754887502163468,3.807354922057604,3.9068905956085187,3.9068905956085187,5.0,null,10.499845887083206,7.491853096329675,6.523561956057013,8.744833837499545,6.820178962415188,6.870364719583405,6.357552004618084,6.94251450533924,8.169925001442312,6.303780748177103,5.807354922057604,5.807354922057604,6.807354922057604,7.475733430966398,9.566054038171092,7.303780748177103,7.1799090900149345,8.214319120800766,6.491853096329675,6.459431618637297,7.076815597050831,6.569855608330948,8.370687406807217,6.357552004618084,5.807354922057604,5.807354922057604,6.820178962415188,6.507794640198696,9.306061689428342,6.614709844115208,6.108524456778169,7.754887502163468,6.22881869049588,6.169925001442312,6.044394119358453,6.442943495848728,7.434628227636725,6.066089190457772,4.807354922057604,4.807354922057604,5.882643049361842,6.643856189774724,8.682994583681683,6.247927513443585,5.807354922057604,6.3750394313469245,5.930737337562887,5.357552004618084,5.882643049361842,5.554588851677638,6.727920454563199,5.426264754702098,4.584962500721156,4.584962500721156,5.584962500721156,6.129283016944966,10.151016538892248,7.467605550082998,6.754887502163468,7.303780748177103,6.149747119504682,5.906890595608519,6.247927513443585,6.523561956057013,7.6865005271832185,6.599912842187128,5.321928094887363,5.321928094887363,6.339850002884624,7.531381460516312,8.703903573444663,7.330916878114617,7.118941072723508,8.581200581924957,7.0,7.044394119358453,7.434628227636725,6.754887502163468,7.832890014164741,5.321928094887363,6.0,6.0,6.977279923499917,4.906890595608519,3.4594316186372973,9.116343961237469,null,7.03342300153745,4.392317422778761,7.94251450533924,null,7.906890595608519,1.584962500721156,5.584962500721156,7.20945336562895,7.20945336562895,8.204571144249204,2.0,10.53818893205242,7.960001932068081,7.266786540694901,9.005624549193879,7.409390936137702,7.312882955284356,7.087462841250339,7.531381460516312,8.430452551665532,6.78135971352466,5.672425341971495,5.672425341971495,6.714245517666122,7.930737337562887,9.335390354693924,8.88264304936184,7.800899899920305,8.64745842645492,7.954196310386875,7.965784284662087,7.539158811108031,8.108524456778168,8.78135971352466,6.149747119504682,6.906890595608519,6.906890595608519,7.924812503605781,6.266786540694901,9.35974956032233,6.918863237274595,6.0,8.134426320220927,6.523561956057013,6.247927513443585,6.643856189774724,6.768184324776926,7.60733031374961,6.022367813028454,4.954196310386875,4.954196310386875,5.930737337562887,6.149747119504682,9.131856960608793,8.906890595608518,8.108524456778168,8.727920454563199,8.233619676759702,8.174925682500678,7.721099188707185,8.426264754702098,8.888743248898258,6.569855608330948,7.011227255423254,7.044394119358453,8.071462362556623,5.832890014164741,10.037546953962178,7.539158811108031,7.366322214245816,6.087462841250339,7.076815597050831,7.159871336778389,6.9886846867721655,7.3750394313469245,8.134426320220927,6.3750394313469245,5.857980995127572,5.857980995127572,6.857980995127572,7.247927513443585,9.79603960882977,7.546894459887636,6.339850002884624,7.3750394313469245,6.475733430966398,6.022367813028454,6.247927513443585,6.584962500721156,7.906890595608519,6.569855608330948,5.129283016944966,5.129283016944966,6.129283016944966,6.643856189774724,9.870364719583405,8.092757140919852,7.266786540694901,8.867278739709661,7.348728154231077,7.636624620543649,7.05528243550119,7.2384047393250786,8.59618975614441,6.832890014164741,6.285402218862249,6.285402218862249,7.285402218862249,6.6865005271832185,8.930737337562887,7.05528243550119,5.491853096329675,7.562242424221073,6.149747119504682,6.22881869049588,5.807354922057604,6.108524456778169,7.832890014164741,6.169925001442312,4.087462841250339,4.087462841250339,5.087462841250339,4.857980995127572,9.914385132155443,7.569855608330948,7.189824558880018,8.228818690495881,6.584962500721156,7.400879436282184,6.820178962415188,7.266786540694901,8.968666793195208,6.409390936137702,5.087462841250339,5.087462841250339,6.169925001442312,7.303780748177103,10.147204924942228,8.375039431346925,7.392317422778761,8.997179480937621,7.442943495848728,7.6865005271832185,7.312882955284356,7.6293566200796095,8.651051691178928,6.599912842187128,5.672425341971495,5.672425341971495,6.700439718141092,5.614709844115208,10.057991722759176,8.546894459887637,7.199672344836364,9.189824558880018,7.303780748177103,7.2761244052742375,7.339850002884624,7.562242424221073,8.535275376620802,6.672425341971495,6.599912842187128,6.599912842187128,7.6653359171851765,7.20945336562895,9.60917873814198,8.0,7.562242424221073,8.731319031025064,7.066089190457772,7.098032082960526,6.9886846867721655,7.523561956057013,8.204571144249204,6.108524456778169,5.857980995127572,5.857980995127572,6.857980995127572,6.0,9.746514321138463,7.417852514885898,6.442943495848728,7.800899899920305,7.05528243550119,6.658211482751795,6.584962500721156,7.475733430966398,8.252665432450248,6.20945336562895,5.321928094887363,5.321928094887363,6.321928094887363,5.523561956057013,10.246740598493144,8.303780748177102,7.577428828035749,8.326429487122303,7.700439718141092,7.800899899920305,7.451211111832329,8.087462841250339,8.845490050944376,6.906890595608519,6.539158811108031,6.539158811108031,7.546894459887636,6.9886846867721655,10.129283016944967,8.08214904135387,7.592457037268081,8.668884984266247,7.392317422778761,7.636624620543649,7.169925001442312,7.614709844115208,8.658211482751796,6.149747119504682,6.820178962415188,6.820178962415188,7.807354922057604,6.906890595608519,9.64745842645492,7.60733031374961,7.357552004618084,8.83605035505807,6.832890014164741,7.515699838284043,7.149747119504682,7.149747119504682,8.266786540694902,6.475733430966398,5.906890595608519,5.906890595608519,6.918863237274595,6.6865005271832185,10.77066389291676,8.027905996569885,7.614709844115208,8.906890595608518,7.400879436282184,7.294620748891627,6.977279923499917,6.954196310386875,8.854868383260236,7.562242424221073,6.044394119358453,6.044394119358453,7.022367813028454,8.016808287686555,5.554588851677638,3.807354922057604,2.0,8.303780748177102,6.426264754702098,3.321928094887362,3.0,4.954196310386875,4.169925001442312,6.129283016944966,1.584962500721156,1.584962500721156,2.584962500721156,3.807354922057604,9.88264304936184,7.434628227636725,6.614709844115208,5.832890014164741,7.044394119358453,6.066089190457772,6.965784284662087,6.507794640198696,8.257387842692651,6.426264754702098,4.584962500721156,4.584962500721156,5.700439718141092,7.1799090900149345,9.03342300153745,6.754887502163468,5.882643049361842,5.614709844115208,6.22881869049588,5.930737337562887,5.247927513443585,6.392317422778761,7.139551352398794,5.977279923499917,4.807354922057604,4.807354922057604,5.832890014164741,6.022367813028454,9.493855449240822,7.149747119504682,5.857980995127572,8.280770770130603,6.3750394313469245,6.285402218862249,6.741466986401147,6.672425341971495,7.499845887083206,6.507794640198696,5.044394119358453,5.044394119358453,6.087462841250339,6.754887502163468,10.296916206879288,8.108524456778168,7.392317422778761,6.569855608330948,7.882643049361842,7.383704292474052,7.257387842692652,7.888743248898259,8.92184093707449,7.531381460516312,6.044394119358453,6.044394119358453,7.066089190457772,7.22881869049588,10.61654884377899,8.994353436858859,8.422064766172813,9.749869427396844,8.357552004618084,8.184875342908283,7.94251450533924,8.257387842692651,9.405141463136344,7.507794640198696,6.507794640198696,6.507794640198696,7.531381460516312,7.78135971352466,9.768184324776927,8.087462841250339,7.199672344836364,8.703903573444663,7.189824558880018,7.339850002884624,7.409390936137702,7.554588851677638,8.535275376620802,6.459431618637297,6.321928094887363,6.321928094887363,7.339850002884624,6.94251450533924,10.428360172704291,8.266786540694902,7.592457037268081,9.262094845370179,7.539158811108031,7.531381460516312,7.451211111832329,7.977279923499917,8.977279923499916,6.820178962415188,6.357552004618084,6.357552004618084,7.409390936137702,7.483815777264256,10.57742882803575,8.174925682500678,7.693486957499325,9.194756854422248,7.900866807980749,7.584962500721156,7.539158811108031,8.03342300153745,8.832890014164741,6.643856189774724,6.442943495848728,6.442943495848728,7.491853096329675,7.321928094887363,10.531381460516313,9.283088353024002,8.330916878114618,9.92184093707449,8.353146825498083,8.31741261376487,8.016808287686555,8.632995197142957,9.62935662007961,7.366322214245816,7.044394119358453,7.044394119358453,8.044394119358454,7.7073591320808825,10.221587121264806,7.845490050944375,7.219168520462161,6.129283016944966,7.357552004618084,6.918863237274595,6.714245517666122,7.1799090900149345,8.573647187493322,6.857980995127572,6.247927513443585,6.247927513443585,7.285402218862249,7.491853096329675,10.059344460824425,7.994353436858858,6.794415866350106,8.588714635582264,7.257387842692652,7.3750394313469245,7.066089190457772,6.965784284662087,8.39231742277876,7.05528243550119,5.614709844115208,5.614709844115208,6.614709844115208,7.266786540694901,8.515699838284043,6.491853096329675,5.247927513443585,6.78135971352466,5.754887502163468,4.584962500721156,6.0,5.169925001442312,6.614709844115208,5.727920454563199,4.643856189774724,4.643856189774724,5.672425341971495,6.491853096329675,8.810571634741146,6.303780748177103,5.700439718141092,6.357552004618084,5.584962500721156,4.954196310386875,5.044394119358453,5.0,6.321928094887363,5.643856189774724,3.700439718141092,3.700439718141092,4.754887502163468,5.247927513443585,8.885696373339394,6.108524456778169,4.700439718141092,5.491853096329675,5.727920454563199,5.0,5.247927513443585,6.20945336562895,6.6865005271832185,5.285402218862249,4.087462841250339,4.169925001442312,5.129283016944966,5.20945336562895,8.330916878114618,7.022367813028454,5.392317422778761,6.930737337562887,5.754887502163468,5.78135971352466,4.857980995127572,6.169925001442312,7.483815777264256,5.20945336562895,4.169925001442312,4.169925001442312,5.20945336562895,5.554588851677638,9.703903573444663,7.832890014164741,7.22881869049588,8.562242424221072,7.108524456778169,7.3750394313469245,6.392317422778761,7.303780748177103,8.361943773735241,6.491853096329675,5.584962500721156,5.584962500721156,6.599912842187128,5.954196310386875,9.661778097771988,7.658211482751795,7.087462841250339,6.409390936137702,7.312882955284356,6.965784284662087,6.672425341971495,7.459431618637297,8.03342300153745,6.459431618637297,5.700439718141092,5.700439718141092,6.714245517666122,6.870364719583405,9.712527000439824,7.768184324776926,7.285402218862249,6.539158811108031,7.643856189774724,6.94251450533924,6.94251450533924,7.400879436282184,8.357552004618084,6.108524456778169,6.0,6.0,7.011227255423254,6.832890014164741,10.24436383512051,8.467605550082997,8.011227255423254,8.326429487122303,8.055282435501189,7.734709620225838,7.442943495848728,7.851749041416057,9.030667136246942,6.882643049361842,6.357552004618084,6.357552004618084,7.357552004618084,6.965784284662087,9.027905996569885,7.467605550082998,6.339850002884624,7.727920454563199,6.768184324776926,6.247927513443585,6.189824558880018,6.475733430966398,7.857980995127572,5.906890595608519,5.321928094887363,5.321928094887363,6.339850002884624,5.882643049361842,9.250298417906333,6.9886846867721655,6.357552004618084,7.087462841250339,6.507794640198696,6.554588851677638,6.321928094887363,6.339850002884624,7.475733430966398,5.247927513443585,5.087462841250339,5.087462841250339,6.087462841250339,5.857980995127572,9.96289600533726,7.768184324776926,6.569855608330948,8.39231742277876,7.321928094887363,6.807354922057604,6.965784284662087,7.05528243550119,8.303780748177102,6.321928094887363,5.285402218862249,5.285402218862249,6.303780748177103,6.714245517666122,10.207014320177532,7.483815777264256,6.6293566200796095,8.59245703726808,7.2761244052742375,6.768184324776926,6.857980995127572,6.857980995127572,8.400879436282183,6.643856189774724,6.0,6.0,7.022367813028454,6.965784284662087,9.29920801838728,6.820178962415188,6.321928094887363,7.78135971352466,6.409390936137702,6.149747119504682,6.426264754702098,5.930737337562887,7.294620748891627,6.066089190457772,4.584962500721156,4.584962500721156,5.643856189774724,5.643856189774724,8.804131021183318,6.169925001442312,5.832890014164741,6.9886846867721655,6.20945336562895,5.643856189774724,5.78135971352466,5.954196310386875,7.2761244052742375,4.954196310386875,4.392317422778761,4.392317422778761,5.459431618637297,5.247927513443585,10.098032082960527,7.159871336778389,6.768184324776926,8.807354922057604,7.05528243550119,6.614709844115208,6.965784284662087,6.584962500721156,7.857980995127572,6.523561956057013,5.169925001442312,5.169925001442312,6.169925001442312,6.857980995127572,9.111135670234708,5.584962500721156,5.357552004618084,6.643856189774724,6.285402218862249,5.491853096329675,5.700439718141092,5.807354922057604,6.768184324776926,6.339850002884624,4.643856189774724,4.643856189774724,5.727920454563199,6.022367813028454,9.276124405274238,7.066089190457772,6.087462841250339,7.03342300153745,6.507794640198696,6.044394119358453,6.491853096329675,6.022367813028454,7.491853096329675,5.807354922057604,4.321928094887363,4.321928094887363,5.321928094887363,5.857980995127572,9.39231742277876,7.285402218862249,6.321928094887363,7.918863237274595,6.658211482751795,6.321928094887363,6.832890014164741,6.022367813028454,7.643856189774724,5.523561956057013,4.906890595608519,4.906890595608519,5.954196310386875,6.906890595608519,10.582141981658777,7.7073591320808825,7.118941072723508,8.800899899920305,7.400879436282184,7.169925001442312,7.303780748177103,7.139551352398794,8.689997971419446,6.9886846867721655,5.491853096329675,5.491853096329675,6.539158811108031,7.417852514885898,10.35974956032233,7.562242424221073,6.906890595608519,7.839203788096944,7.330916878114617,6.6865005271832185,6.9886846867721655,6.741466986401147,8.219168520462162,6.794415866350106,5.392317422778761,5.392317422778761,6.409390936137702,7.523561956057013,10.688250309133178,8.672425341971495,7.78135971352466,8.761551232444479,8.224001674198105,7.820178962415188,7.515699838284043,7.813781191217037,9.074141462752506,7.285402218862249,6.523561956057013,6.523561956057013,7.569855608330948,7.614709844115208,9.977279923499916,7.741466986401147,6.930737337562887,8.312882955284355,7.169925001442312,7.022367813028454,6.977279923499917,7.098032082960526,8.353146825498083,6.392317422778761,5.930737337562887,5.954196310386875,7.011227255423254,6.727920454563199,10.20945336562895,7.672425341971495,6.894817763307944,7.483815777264256,7.451211111832329,7.366322214245816,6.845490050944375,7.2384047393250786,8.584962500721156,6.754887502163468,5.930737337562887,5.930737337562887,6.94251450533924,7.066089190457772,9.915879378835774,7.483815777264256,6.794415866350106,8.59245703726808,6.894817763307944,6.906890595608519,6.475733430966398,6.658211482751795,7.888743248898259,6.918863237274595,5.614709844115208,5.643856189774724,6.643856189774724,6.845490050944375,9.515699838284043,7.3750394313469245,6.392317422778761,8.312882955284355,6.94251450533924,6.149747119504682,6.643856189774724,6.727920454563199,8.016808287686555,6.554588851677638,5.523561956057013,5.523561956057013,6.569855608330948,6.599912842187128,8.266786540694902,5.523561956057013,5.169925001442312,6.741466986401147,4.754887502163468,5.087462841250339,5.0,5.129283016944966,6.357552004618084,5.169925001442312,3.807354922057604,3.807354922057604,4.807354922057604,5.044394119358453,9.100662339005199,5.807354922057604,5.087462841250339,7.0,5.78135971352466,5.643856189774724,5.643856189774724,5.643856189774724,6.614709844115208,6.0,4.247927513443585,4.247927513443585,5.247927513443585,5.930737337562887,9.556506054671928,7.7073591320808825,6.768184324776926,7.6293566200796095,7.1799090900149345,7.2384047393250786,6.954196310386875,7.2384047393250786,8.467605550082997,6.918863237274595,6.189824558880018,6.189824558880018,7.219168520462161,6.426264754702098,7.149747119504682,null,2.0,2.584962500721156,3.0,1.0,null,null,4.321928094887363,4.0,0.0,0.0,1.0,4.169925001442312,10.193525360501216,7.475733430966398,6.894817763307944,8.523561956057012,7.129283016944966,6.643856189774724,6.569855608330948,7.044394119358453,8.451211111832329,6.614709844115208,5.857980995127572,5.857980995127572,6.870364719583405,6.129283016944966,9.308339030139408,6.108524456778169,5.321928094887363,6.930737337562887,5.357552004618084,4.807354922057604,5.169925001442312,4.754887502163468,6.78135971352466,5.857980995127572,4.247927513443585,4.247927513443585,5.321928094887363,5.523561956057013,9.63662462054365,7.20945336562895,6.741466986401147,6.22881869049588,6.6293566200796095,6.266786540694901,6.108524456778169,7.257387842692652,7.845490050944375,6.339850002884624,5.426264754702098,5.426264754702098,6.426264754702098,5.392317422778761,9.002815015607053,7.546894459887636,6.794415866350106,8.696967526234287,6.820178962415188,7.011227255423254,6.857980995127572,7.294620748891627,7.960001932068081,6.339850002884624,6.129283016944966,6.129283016944966,7.139551352398794,5.523561956057013,9.049848549450562,7.727920454563199,6.459431618637297,7.864186144654281,6.930737337562887,6.794415866350106,6.78135971352466,6.820178962415188,8.124121311829187,6.044394119358453,5.78135971352466,5.78135971352466,6.794415866350106,5.857980995127572,8.988684686772165,7.888743248898259,7.011227255423254,7.820178962415188,7.129283016944966,7.569855608330948,6.700439718141092,7.912889336229962,8.113742166049189,6.584962500721156,6.20945336562895,6.20945336562895,7.22881869049588,5.954196310386875,8.829722735086058,7.6865005271832185,7.139551352398794,9.0,7.426264754702098,7.693486957499325,7.357552004618084,7.515699838284043,8.379378367071261,6.20945336562895,6.303780748177103,6.303780748177103,7.294620748891627,6.066089190457772,8.479780264029099,7.693486957499325,6.9886846867721655,7.584962500721156,7.05528243550119,7.467605550082998,6.409390936137702,7.60733031374961,8.144658242831882,6.303780748177103,5.727920454563199,5.727920454563199,6.727920454563199,5.247927513443585,8.487840033823051,7.562242424221073,6.882643049361842,8.335390354693924,7.044394119358453,6.918863237274595,6.894817763307944,7.011227255423254,7.6865005271832185,5.930737337562887,6.108524456778169,6.108524456778169,7.118941072723508,4.392317422778761,6.247927513443585,6.149747119504682,4.321928094887363,6.285402218862249,5.523561956057013,5.700439718141092,4.247927513443585,5.832890014164741,5.78135971352466,4.169925001442312,4.321928094887363,4.321928094887363,5.357552004618084,2.584962500721156,8.066089190457772,6.930737337562887,6.357552004618084,6.918863237274595,6.392317422778761,5.754887502163468,6.149747119504682,6.554588851677638,7.312882955284356,5.20945336562895,5.087462841250339,5.087462841250339,6.108524456778169,5.20945336562895,8.379378367071261,7.577428828035749,6.6865005271832185,8.20945336562895,6.807354922057604,6.977279923499917,6.845490050944375,6.954196310386875,7.807354922057604,6.129283016944966,5.727920454563199,5.78135971352466,6.794415866350106,5.321928094887363,8.330916878114618,7.087462841250339,7.139551352398794,8.668884984266247,7.129283016944966,7.03342300153745,6.832890014164741,7.169925001442312,7.679480099505446,5.643856189774724,5.643856189774724,5.643856189774724,6.643856189774724,5.459431618637297,9.57742882803575,8.479780264029099,8.0,9.375039431346925,8.027905996569885,7.622051819456376,7.483815777264256,8.0,8.89178370321831,6.6865005271832185,6.794415866350106,6.794415866350106,7.787902559391432,6.643856189774724,8.149747119504681,7.483815777264256,6.321928094887363,8.233619676759702,6.569855608330948,5.977279923499917,6.614709844115208,6.672425341971495,7.6293566200796095,5.392317422778761,6.022367813028454,6.022367813028454,7.066089190457772,5.169925001442312,8.826548487290914,7.426264754702098,6.658211482751795,8.0,6.727920454563199,7.076815597050831,7.098032082960526,7.357552004618084,7.768184324776926,5.727920454563199,4.857980995127572,4.857980995127572,5.882643049361842,6.266786540694901,9.108524456778168,8.49585502688717,7.774787059601174,8.375039431346925,7.592457037268081,7.622051819456376,7.011227255423254,7.754887502163468,8.566054038171092,6.727920454563199,6.539158811108031,6.539158811108031,7.569855608330948,5.426264754702098,8.72451385311995,8.08214904135387,6.894817763307944,8.703903573444663,7.531381460516312,7.531381460516312,7.199672344836364,7.285402218862249,7.882643049361842,6.894817763307944,5.807354922057604,5.807354922057604,6.832890014164741,6.189824558880018,9.12670447284319,8.266786540694902,7.2761244052742375,8.98299357469431,7.294620748891627,7.599912842187128,6.539158811108031,7.60733031374961,8.266786540694902,6.6293566200796095,6.20945336562895,6.20945336562895,7.2384047393250786,6.044394119358453,8.118941072723507,7.400879436282184,6.672425341971495,8.848622940429339,7.139551352398794,7.087462841250339,6.906890595608519,7.199672344836364,7.6293566200796095,6.087462841250339,5.78135971352466,5.78135971352466,6.794415866350106,5.78135971352466,7.768184324776926,7.294620748891627,6.247927513443585,7.20945336562895,6.554588851677638,6.507794640198696,6.189824558880018,6.6865005271832185,7.159871336778389,5.754887502163468,5.554588851677638,5.554588851677638,6.584962500721156,4.0,8.199672344836364,6.672425341971495,5.882643049361842,7.366322214245816,6.149747119504682,6.768184324776926,5.807354922057604,6.539158811108031,6.714245517666122,5.643856189774724,4.954196310386875,4.954196310386875,5.977279923499917,4.807354922057604,7.507794640198696,6.523561956057013,5.614709844115208,7.219168520462161,6.392317422778761,6.392317422778761,6.339850002884624,6.066089190457772,6.794415866350106,5.321928094887363,4.643856189774724,4.643856189774724,5.700439718141092,4.584962500721156,8.459431618637296,7.108524456778169,6.266786540694901,7.820178962415188,7.022367813028454,6.022367813028454,6.539158811108031,6.339850002884624,7.442943495848728,5.357552004618084,5.169925001442312,5.169925001442312,6.22881869049588,4.321928094887363,3.807354922057604,4.0,2.0,4.247927513443585,2.0,2.584962500721156,3.321928094887362,3.0,4.321928094887363,null,1.584962500721156,1.584962500721156,2.584962500721156,1.0,8.686500527183219,7.614709844115208,6.554588851677638,8.588714635582264,7.22881869049588,7.303780748177103,7.357552004618084,7.149747119504682,8.113742166049189,5.247927513443585,5.906890595608519,5.930737337562887,6.94251450533924,4.459431618637297,7.459431618637297,6.78135971352466,6.303780748177103,7.285402218862249,6.108524456778169,6.129283016944966,5.523561956057013,5.78135971352466,7.022367813028454,5.491853096329675,4.700439718141092,4.700439718141092,5.727920454563199,4.807354922057604,8.861086905995395,7.693486957499325,7.515699838284043,8.312882955284355,7.434628227636725,7.312882955284356,6.977279923499917,7.539158811108031,8.108524456778168,6.066089190457772,6.285402218862249,6.285402218862249,7.285402218862249,5.169925001442312,8.550746785383243,7.643856189774724,7.0,8.632995197142957,7.129283016944966,7.011227255423254,7.044394119358453,6.954196310386875,7.845490050944375,5.906890595608519,5.78135971352466,5.78135971352466,6.820178962415188,4.459431618637297,8.81698362325538,8.46352437327118,7.417852514885898,7.894817763307944,7.569855608330948,7.577428828035749,7.339850002884624,7.577428828035749,8.285402218862249,6.700439718141092,6.599912842187128,6.599912842187128,7.599912842187128,5.727920454563199,0.0,0.0,2.0,1.0,null,null,null,0.0,null,null,null,null,null,null,9.733015321685963,5.20945336562895,5.491853096329675,6.022367813028454,5.169925001442312,5.584962500721156,5.584962500721156,5.285402218862249,6.845490050944375,5.754887502163468,4.584962500721156,4.584962500721156,5.643856189774724,5.614709844115208,8.562242424221072,6.321928094887363,5.807354922057604,7.076815597050831,5.700439718141092,5.459431618637297,6.247927513443585,5.754887502163468,7.658211482751795,5.0,4.584962500721156,4.584962500721156,5.584962500721156,5.169925001442312,8.977279923499916,5.930737337562887,5.247927513443585,6.965784284662087,5.754887502163468,5.727920454563199,5.087462841250339,5.700439718141092,6.965784284662087,5.491853096329675,4.0,4.0,5.044394119358453,6.0,9.505811553919594,7.169925001442312,6.357552004618084,8.016808287686555,6.94251450533924,6.392317422778761,6.303780748177103,6.599912842187128,7.78135971352466,5.643856189774724,4.754887502163468,4.754887502163468,5.832890014164741,6.426264754702098,8.951284714966972,5.727920454563199,4.392317422778761,6.727920454563199,5.247927513443585,4.906890595608519,5.523561956057013,4.754887502163468,6.189824558880018,6.087462841250339,3.321928094887362,3.321928094887362,4.392317422778761,4.857980995127572,8.622051819456376,7.554588851677638,6.714245517666122,8.20945336562895,6.672425341971495,7.20945336562895,6.507794640198696,7.1799090900149345,7.721099188707185,6.392317422778761,6.087462841250339,6.087462841250339,7.076815597050831,4.247927513443585,1.584962500721156,6.491853096329675,null,null,2.0,6.459431618637297,null,6.820178962415188,1.0,4.0,5.426264754702098,5.426264754702098,6.426264754702098,null,10.00982861736811,6.523561956057013,5.727920454563199,7.087462841250339,6.108524456778169,5.672425341971495,4.523561956057013,5.882643049361842,7.076815597050831,6.339850002884624,5.0,5.0,6.044394119358453,7.066089190457772,9.041659151637214,7.9886846867721655,7.569855608330948,8.954196310386875,7.584962500721156,7.774787059601174,7.392317422778761,7.366322214245816,8.388017285345136,6.714245517666122,6.539158811108031,6.539158811108031,7.569855608330948,5.087462841250339,9.419960177847889,7.483815777264256,6.475733430966398,7.965784284662087,6.459431618637297,6.087462841250339,6.339850002884624,6.554588851677638,7.417852514885898,5.754887502163468,5.129283016944966,5.169925001442312,6.169925001442312,6.044394119358453,9.134426320220927,6.820178962415188,5.807354922057604,7.6865005271832185,6.672425341971495,6.794415866350106,6.3750394313469245,6.584962500721156,7.383704292474052,5.754887502163468,5.044394119358453,5.044394119358453,6.129283016944966,5.954196310386875,8.826548487290914,6.918863237274595,5.857980995127572,7.515699838284043,6.614709844115208,6.6293566200796095,6.303780748177103,6.169925001442312,7.754887502163468,6.22881869049588,4.584962500721156,4.584962500721156,5.700439718141092,5.700439718141092,9.411510988012072,6.569855608330948,6.965784284662087,7.330916878114617,6.247927513443585,6.044394119358453,6.882643049361842,6.569855608330948,8.308339030139408,5.882643049361842,4.700439718141092,4.700439718141092,5.754887502163468,5.78135971352466,9.113742166049189,6.857980995127572,6.285402218862249,7.011227255423254,6.539158811108031,6.491853096329675,6.108524456778169,6.6293566200796095,7.392317422778761,5.882643049361842,5.044394119358453,5.044394119358453,6.066089190457772,6.169925001442312,9.79766152585376,6.569855608330948,5.930737337562887,7.94251450533924,6.3750394313469245,5.643856189774724,6.266786540694901,6.266786540694901,7.693486957499325,5.832890014164741,5.0,5.0,6.044394119358453,6.870364719583405,9.271463027904375,7.076815597050831,6.22881869049588,7.098032082960526,6.614709844115208,6.044394119358453,6.20945336562895,6.3750394313469245,7.499845887083206,5.727920454563199,4.754887502163468,4.754887502163468,5.78135971352466,6.189824558880018,9.283088353024002,4.857980995127572,3.584962500721156,6.894817763307944,5.044394119358453,5.247927513443585,4.906890595608519,5.0,6.78135971352466,5.523561956057013,3.0,3.0,4.169925001442312,5.832890014164741,9.948367231584678,6.94251450533924,5.754887502163468,8.159871336778389,7.139551352398794,6.700439718141092,6.044394119358453,6.087462841250339,7.727920454563199,6.643856189774724,5.0,5.0,6.0,6.807354922057604,6.426264754702098,3.9068905956085187,4.169925001442312,7.721099188707185,6.954196310386875,4.169925001442312,2.0,4.906890595608519,4.954196310386875,6.475733430966398,2.0,2.0,3.0,3.584962500721156,10.355351096424812,8.43879185257826,7.499845887083206,8.326429487122303,7.539158811108031,7.584962500721156,7.554588851677638,7.7615512324444795,8.985841937003341,7.303780748177103,5.977279923499917,5.977279923499917,6.965784284662087,7.383704292474052,9.507794640198696,6.807354922057604,6.247927513443585,7.948367231584678,6.409390936137702,6.599912842187128,6.357552004618084,6.820178962415188,7.826548487290915,6.491853096329675,5.584962500721156,5.584962500721156,6.569855608330948,6.820178962415188,9.428360172704291,7.442943495848728,6.409390936137702,8.312882955284355,6.475733430966398,6.977279923499917,5.832890014164741,6.965784284662087,8.076815597050832,6.303780748177103,5.584962500721156,5.584962500721156,6.584962500721156,6.599912842187128,9.055282435501189,5.832890014164741,5.357552004618084,6.392317422778761,5.882643049361842,5.426264754702098,5.321928094887363,5.247927513443585,6.894817763307944,6.0,4.087462841250339,4.087462841250339,5.20945336562895,5.700439718141092,9.271463027904375,6.918863237274595,6.189824558880018,6.820178962415188,6.247927513443585,6.129283016944966,5.807354922057604,6.321928094887363,7.044394119358453,5.672425341971495,4.321928094887363,4.392317422778761,5.426264754702098,5.672425341971495,9.428360172704291,7.7073591320808825,6.409390936137702,7.330916878114617,6.741466986401147,6.768184324776926,6.169925001442312,7.149747119504682,8.038918989292302,6.189824558880018,5.426264754702098,5.426264754702098,6.491853096329675,6.539158811108031,8.751544059089099,5.727920454563199,5.20945336562895,6.845490050944375,5.727920454563199,5.882643049361842,5.523561956057013,5.754887502163468,6.643856189774724,5.247927513443585,4.247927513443585,4.247927513443585,5.247927513443585,5.392317422778761,9.087462841250339,5.554588851677638,4.700439718141092,6.643856189774724,6.066089190457772,5.459431618637297,5.321928094887363,5.0,6.870364719583405,6.022367813028454,3.9068905956085187,3.9068905956085187,4.954196310386875,6.539158811108031,9.368506461507693,6.954196310386875,5.977279923499917,8.164906926675688,6.807354922057604,6.882643049361842,6.108524456778169,6.894817763307944,7.727920454563199,5.832890014164741,5.392317422778761,5.392317422778761,6.426264754702098,6.087462841250339,9.204571144249204,6.727920454563199,5.672425341971495,7.076815597050831,6.807354922057604,6.22881869049588,5.459431618637297,6.22881869049588,7.129283016944966,5.672425341971495,4.459431618637297,4.459431618637297,5.459431618637297,6.108524456778169,9.20945336562895,6.339850002884624,5.321928094887363,7.2384047393250786,6.321928094887363,5.0,5.392317422778761,5.169925001442312,6.94251450533924,5.954196310386875,4.169925001442312,4.169925001442312,5.20945336562895,5.643856189774724,9.422064766172813,7.357552004618084,7.0,7.900866807980749,7.247927513443585,6.754887502163468,6.584962500721156,7.392317422778761,8.487840033823051,6.321928094887363,5.832890014164741,5.832890014164741,6.832890014164741,5.727920454563199,8.442943495848729,5.832890014164741,4.954196310386875,7.076815597050831,5.906890595608519,5.700439718141092,4.700439718141092,5.247927513443585,6.569855608330948,4.906890595608519,3.9068905956085187,3.9068905956085187,4.857980995127572,4.807354922057604,9.030667136246942,7.2384047393250786,6.022367813028454,7.294620748891627,6.599912842187128,6.108524456778169,5.727920454563199,6.741466986401147,7.774787059601174,6.459431618637297,5.584962500721156,5.584962500721156,6.584962500721156,5.285402218862249,9.4241662888181,7.584962500721156,6.977279923499917,8.573647187493322,7.2761244052742375,7.087462841250339,6.820178962415188,7.108524456778169,7.924812503605781,5.614709844115208,5.672425341971495,5.672425341971495,6.672425341971495,5.754887502163468,9.663558104217273,6.906890595608519,6.22881869049588,5.129283016944966,7.108524456778169,6.339850002884624,6.426264754702098,6.392317422778761,7.754887502163468,6.357552004618084,5.0,5.0,6.0,6.954196310386875,8.388017285345136,5.930737337562887,5.857980995127572,7.0,5.977279923499917,5.523561956057013,5.954196310386875,5.643856189774724,6.94251450533924,5.0,4.321928094887363,4.321928094887363,5.357552004618084,4.906890595608519,9.513727595952437,6.768184324776926,6.459431618637297,7.870364719583405,6.700439718141092,6.569855608330948,6.22881869049588,6.442943495848728,7.523561956057013,5.672425341971495,4.321928094887363,4.321928094887363,5.392317422778761,6.475733430966398,8.731319031025064,6.930737337562887,5.700439718141092,6.882643049361842,6.339850002884624,6.426264754702098,5.357552004618084,6.3750394313469245,7.643856189774724,5.321928094887363,4.523561956057013,4.523561956057013,5.584962500721156,6.321928094887363,8.86418614465428,6.266786540694901,5.643856189774724,7.22881869049588,6.3750394313469245,5.129283016944966,5.977279923499917,5.285402218862249,6.894817763307944,5.426264754702098,4.321928094887363,4.321928094887363,5.392317422778761,5.78135971352466,9.430452551665532,6.129283016944966,5.832890014164741,6.754887502163468,6.357552004618084,6.149747119504682,5.614709844115208,5.832890014164741,7.339850002884624,5.807354922057604,4.247927513443585,4.247927513443585,5.321928094887363,5.882643049361842,9.64745842645492,7.366322214245816,6.066089190457772,7.392317422778761,6.794415866350106,6.044394119358453,5.614709844115208,6.954196310386875,7.539158811108031,5.643856189774724,5.357552004618084,5.357552004618084,6.3750394313469245,6.714245517666122,9.353146825498083,6.6865005271832185,5.700439718141092,7.721099188707185,6.6293566200796095,6.303780748177103,5.754887502163468,5.78135971352466,7.266786540694901,5.584962500721156,4.807354922057604,4.807354922057604,5.882643049361842,5.754887502163468,9.643856189774725,5.700439718141092,5.392317422778761,7.426264754702098,6.169925001442312,5.754887502163468,6.149747119504682,5.554588851677638,7.169925001442312,5.807354922057604,3.807354922057604,3.807354922057604,4.807354922057604,6.247927513443585,10.131856960608793,7.022367813028454,6.6293566200796095,7.339850002884624,6.672425341971495,6.285402218862249,6.672425341971495,6.672425341971495,7.965784284662087,6.426264754702098,4.523561956057013,4.523561956057013,5.554588851677638,7.044394119358453,9.199672344836364,6.303780748177103,5.554588851677638,7.294620748891627,6.108524456778169,5.672425341971495,5.832890014164741,5.321928094887363,6.832890014164741,5.930737337562887,4.643856189774724,4.643856189774724,5.672425341971495,6.20945336562895,9.154818109052105,7.339850002884624,5.643856189774724,7.357552004618084,6.0,6.0,5.357552004618084,5.882643049361842,7.409390936137702,5.247927513443585,4.906890595608519,4.906890595608519,5.954196310386875,6.189824558880018,8.247927513443585,5.930737337562887,4.700439718141092,6.475733430966398,5.087462841250339,5.357552004618084,4.643856189774724,3.807354922057604,5.754887502163468,4.0,3.169925001442312,3.169925001442312,4.169925001442312,5.392317422778761,8.447083226209653,6.108524456778169,5.491853096329675,6.977279923499917,5.954196310386875,6.339850002884624,5.754887502163468,6.22881869049588,6.965784284662087,5.087462841250339,4.754887502163468,4.754887502163468,5.754887502163468,5.357552004618084,9.564149489985732,7.459431618637297,6.78135971352466,8.262094845370179,6.954196310386875,6.794415866350106,6.569855608330948,6.768184324776926,7.98299357469431,5.129283016944966,5.857980995127572,5.857980995127572,6.870364719583405,7.0,5.584962500721156,1.0,null,2.584962500721156,0.0,null,1.0,2.0,3.169925001442312,1.0,null,null,null,2.0,9.569855608330949,6.754887502163468,6.247927513443585,7.459431618637297,6.965784284662087,6.614709844115208,5.882643049361842,6.754887502163468,7.584962500721156,6.303780748177103,5.321928094887363,5.321928094887363,6.321928094887363,6.442943495848728,8.566054038171092,5.044394119358453,3.807354922057604,6.3750394313469245,4.807354922057604,4.807354922057604,4.169925001442312,5.321928094887363,5.807354922057604,3.807354922057604,3.0,3.0,4.0,5.523561956057013,8.73809225962049,5.882643049361842,4.857980995127572,6.554588851677638,6.066089190457772,6.339850002884624,5.129283016944966,5.643856189774724,6.539158811108031,5.954196310386875,4.0,4.0,5.0,5.614709844115208,8.430452551665532,7.6865005271832185,6.599912842187128,7.554588851677638,6.918863237274595,6.870364719583405,6.714245517666122,7.475733430966398,8.066089190457772,5.392317422778761,5.930737337562887,5.930737337562887,6.94251450533924,5.643856189774724,8.39231742277876,7.714245517666122,6.22881869049588,8.49585502688717,6.6293566200796095,7.2761244052742375,7.044394119358453,7.357552004618084,7.794415866350106,6.087462841250339,5.523561956057013,5.523561956057013,6.569855608330948,6.20945336562895,8.066089190457772,7.531381460516312,7.339850002884624,8.321928094887362,6.539158811108031,7.303780748177103,6.523561956057013,7.022367813028454,7.507794640198696,4.584962500721156,5.643856189774724,5.643856189774724,6.672425341971495,5.491853096329675,7.523561956057013,7.483815777264256,5.247927513443585,7.383704292474052,6.189824558880018,6.741466986401147,5.672425341971495,7.05528243550119,6.491853096329675,5.087462841250339,5.614709844115208,5.614709844115208,6.614709844115208,5.321928094887363,8.625708843064466,7.864186144654281,6.339850002884624,7.294620748891627,7.1799090900149345,7.417852514885898,6.189824558880018,7.129283016944966,7.78135971352466,5.247927513443585,5.643856189774724,5.643856189774724,6.714245517666122,4.584962500721156,8.219168520462162,7.05528243550119,6.392317422778761,8.011227255423254,6.539158811108031,6.754887502163468,6.044394119358453,7.169925001442312,7.2761244052742375,4.954196310386875,4.954196310386875,4.954196310386875,5.954196310386875,4.459431618637297,7.857980995127572,6.392317422778761,6.149747119504682,7.6293566200796095,6.108524456778169,6.459431618637297,5.832890014164741,6.539158811108031,7.129283016944966,4.643856189774724,5.087462841250339,5.087462841250339,6.108524456778169,4.459431618637297,6.507794640198696,5.78135971352466,4.459431618637297,6.491853096329675,4.807354922057604,5.491853096329675,5.20945336562895,5.321928094887363,6.087462841250339,4.700439718141092,3.4594316186372973,3.4594316186372973,4.523561956057013,3.321928094887362,7.459431618637297,6.954196310386875,5.554588851677638,7.266786540694901,5.954196310386875,6.20945336562895,5.285402218862249,6.392317422778761,6.554588851677638,4.857980995127572,4.754887502163468,4.754887502163468,5.857980995127572,3.807354922057604,7.539158811108031,6.977279923499917,5.727920454563199,6.6293566200796095,6.321928094887363,6.087462841250339,5.78135971352466,6.569855608330948,7.022367813028454,4.169925001442312,4.906890595608519,4.906890595608519,5.977279923499917,4.392317422778761,7.285402218862249,6.426264754702098,5.614709844115208,7.475733430966398,6.087462841250339,6.285402218862249,5.882643049361842,5.882643049361842,6.6293566200796095,4.169925001442312,4.523561956057013,4.523561956057013,5.491853096329675,2.0,8.243173983472952,7.2384047393250786,6.965784284662087,8.535275376620802,6.894817763307944,6.658211482751795,6.845490050944375,6.741466986401147,7.700439718141092,5.247927513443585,6.0,6.0,7.044394119358453,4.392317422778761,7.721099188707185,6.78135971352466,6.189824558880018,6.658211482751795,5.930737337562887,6.087462841250339,5.906890595608519,6.129283016944966,6.965784284662087,3.584962500721156,5.392317422778761,5.392317422778761,6.409390936137702,4.321928094887363,7.658211482751795,6.247927513443585,5.906890595608519,7.3750394313469245,6.044394119358453,5.857980995127572,6.149747119504682,6.357552004618084,6.3750394313469245,4.169925001442312,4.954196310386875,4.954196310386875,5.977279923499917,4.392317422778761,8.535275376620802,7.7615512324444795,5.584962500721156,8.696967526234287,6.882643049361842,6.930737337562887,6.523561956057013,6.882643049361842,7.851749041416057,5.20945336562895,5.357552004618084,5.357552004618084,6.392317422778761,4.321928094887363,3.0,2.584962500721156,1.0,4.0,2.0,null,1.0,1.584962500721156,2.321928094887362,1.0,1.0,1.0,1.584962500721156,null,7.303780748177103,6.507794640198696,6.087462841250339,7.577428828035749,5.977279923499917,5.700439718141092,5.727920454563199,6.022367813028454,6.870364719583405,3.807354922057604,4.857980995127572,4.857980995127572,5.882643049361842,3.0,7.820178962415188,6.857980995127572,6.108524456778169,7.22881869049588,6.539158811108031,6.392317422778761,6.087462841250339,6.442943495848728,7.098032082960526,5.857980995127572,4.700439718141092,4.700439718141092,5.727920454563199,5.459431618637297,7.076815597050831,6.475733430966398,5.906890595608519,6.672425341971495,5.807354922057604,5.954196310386875,5.459431618637297,5.459431618637297,6.523561956057013,4.584962500721156,4.584962500721156,4.584962500721156,5.584962500721156,3.807354922057604],\"y0\":\" \",\"yaxis\":\"y\",\"type\":\"box\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"],[\"2L\",null],[\"2L\",\"AIM2\"],[\"2L\",\"AIM3\"],[\"2L\",\"AIM4\"],[\"2L\",\"AIM5\"],[\"2L\",\"AIM6\"],[\"2L\",\"AIM7\"],[\"2L\",\"Vgsc_tag1\"],[\"2L\",\"Vgsc_tag2\"],[\"2L\",\"Vgsc_tag3\"],[\"2L\",\"Vgsc_V402L\"],[\"2L\",\"Vgsc_D466H\"],[\"2L\",\"Vgsc_tag4\"],[\"2L\",\"Vgsc_tag5\"],[\"2L\",\"Vgsc_tag6\"],[\"2L\",\"Vgsc_tag7\"],[\"2L\",\"Vgsc_T791M\"],[\"2L\",\"Vgsc_L995S\"],[\"2L\",\"Vgsc_L995F\"],[\"2L\",\"Vgsc_tag8\"],[\"2L\",\"Vgsc_tag9\"],[\"2L\",\"Vgsc_I1527T\"],[\"2L\",\"Vgsc_N1570Y\"],[\"2L\",\"Vgsc_E1597G\"],[\"2L\",\"Vgsc_A1746S\"],[\"2L\",\"Vgsc_V1853I\"],[\"2L\",\"Vgsc_I1868T\"],[\"2L\",\"Vgsc_P1874S\"],[\"2L\",\"Vgsc_P1874L\"],[\"2L\",\"Vgsc_Y1882C\"],[\"2L\",\"AIM8\"],[\"2L\",\"Vgsc_A1934V\"],[\"2L\",\"Vgsc_tag10\"],[\"2L\",\"Vgsc_tag11\"],[\"2L\",\"Coeae1d_tag\"],[\"2L\",\"Rdl_A296S\"],[\"2L\",\"Rdl_A296G\"],[\"2L\",\"Cyp4j5_L43F\"],[\"2L\",\"34mb_tag1\"],[\"2L\",\"34mb_tag2\"],[\"2L\",\"34mb_tag3\"],[\"2L\",\"34mb_tag4\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003eamplicon=%{x}\\u003cbr\\u003elog_depth=%{y}\\u003cbr\\u003emutation=%{customdata[1]}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"2L\",\"marker\":{\"color\":\"#2CA02C\"},\"name\":\"2L\",\"notched\":false,\"offsetgroup\":\"2L\",\"orientation\":\"v\",\"showlegend\":true,\"x\":[\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\",\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_79\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_80\",\"Agam_20\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_22\",\"Agam_23\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_31\"],\"x0\":\" \",\"xaxis\":\"x\",\"y\":[5.0,4.857980995127572,2.0,3.700439718141092,4.392317422778761,4.906890595608519,4.392317422778761,3.807354922057604,6.357552004618084,7.787902559391432,5.727920454563199,1.0,5.285402218862249,5.459431618637297,4.643856189774724,4.247927513443585,3.9068905956085187,3.9068905956085187,3.9068905956085187,9.066089190457772,9.682994583681683,6.954196310386875,5.392317422778761,6.266786540694901,5.754887502163468,5.672425341971495,4.700439718141092,4.700439718141092,4.700439718141092,4.643856189774724,5.459431618637297,6.584962500721156,6.321928094887363,5.169925001442312,0.0,4.584962500721156,4.584962500721156,8.603626344986193,6.22881869049588,6.392317422778761,6.507794640198696,6.459431618637297,4.087462841250339,2.0,2.0,2.321928094887362,2.584962500721156,2.321928094887362,2.584962500721156,1.584962500721156,2.584962500721156,3.321928094887362,2.584962500721156,null,2.584962500721156,3.0,2.807354922057604,0.0,1.0,0.0,0.0,5.554588851677638,5.643856189774724,4.807354922057604,4.169925001442312,5.169925001442312,4.247927513443585,3.4594316186372973,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,3.700439718141092,4.807354922057604,2.584962500721156,3.321928094887362,null,2.584962500721156,2.584962500721156,5.0,3.169925001442312,4.0,3.4594316186372973,3.4594316186372973,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.169925001442312,1.0,null,null,null,1.584962500721156,null,null,null,null,null,2.321928094887362,null,2.0,1.584962500721156,null,null,1.0,null,null,null,null,1.0,1.0,null,null,null,null,null,null,0.0,3.9068905956085187,null,1.584962500721156,null,null,null,0.0,null,0.0,0.0,3.169925001442312,4.584962500721156,2.584962500721156,1.584962500721156,2.0,2.321928094887362,2.0,1.0,1.0,1.0,1.0,1.0,3.169925001442312,2.0,2.321928094887362,0.0,null,null,4.247927513443585,1.0,1.0,1.0,1.584962500721156,2.807354922057604,1.0,1.0,0.0,1.0,null,1.0,2.0,2.0,4.584962500721156,3.584962500721156,1.0,1.584962500721156,1.0,2.321928094887362,2.584962500721156,null,0.0,0.0,5.044394119358453,6.285402218862249,2.807354922057604,0.0,1.584962500721156,2.321928094887362,3.700439718141092,2.584962500721156,2.584962500721156,2.584962500721156,2.321928094887362,1.584962500721156,3.169925001442312,3.0,1.0,1.584962500721156,2.0,2.0,5.832890014164741,3.169925001442312,2.0,3.4594316186372973,3.4594316186372973,4.321928094887363,4.643856189774724,4.087462841250339,3.4594316186372973,3.584962500721156,3.807354922057604,3.584962500721156,3.0,3.321928094887362,4.807354922057604,4.321928094887363,2.584962500721156,3.9068905956085187,1.584962500721156,3.0,3.700439718141092,1.0,3.4594316186372973,3.4594316186372973,6.0,6.741466986401147,5.906890595608519,4.857980995127572,5.754887502163468,5.357552004618084,5.0,3.807354922057604,3.700439718141092,3.700439718141092,3.700439718141092,5.491853096329675,6.584962500721156,3.321928094887362,5.0,2.0,3.0,3.0,5.247927513443585,4.247927513443585,3.807354922057604,4.807354922057604,4.807354922057604,null,1.0,2.0,1.0,3.584962500721156,null,0.0,null,null,null,null,null,null,null,0.0,2.584962500721156,null,0.0,0.0,null,0.0,null,0.0,0.0,1.0,2.0,null,null,null,null,4.459431618637297,5.584962500721156,null,null,null,null,null,null,2.0,null,1.0,1.584962500721156,null,null,null,null,null,1.0,null,null,null,null,null,null,2.0,null,null,null,null,null,null,0.0,3.700439718141092,0.0,null,null,null,null,null,null,null,null,null,3.169925001442312,null,null,2.321928094887362,2.0,2.0,1.584962500721156,null,0.0,null,null,null,null,null,null,null,0.0,null,null,null,null,1.0,null,1.584962500721156,null,null,0.0,null,null,null,null,3.9068905956085187,null,null,null,null,1.0,null,null,null,null,null,3.0,null,2.321928094887362,2.321928094887362,2.807354922057604,2.807354922057604,1.0,0.0,0.0,null,null,2.0,1.0,1.0,2.321928094887362,null,null,1.584962500721156,1.584962500721156,3.0,4.584962500721156,1.0,null,2.807354922057604,2.321928094887362,0.0,1.0,1.584962500721156,null,null,5.523561956057013,6.247927513443585,3.700439718141092,3.321928094887362,4.087462841250339,3.700439718141092,3.0,2.0,2.0,2.0,2.0,2.0,3.4594316186372973,5.0,2.0,1.584962500721156,2.0,2.0,5.857980995127572,2.807354922057604,3.0,2.807354922057604,2.807354922057604,2.321928094887362,1.0,1.0,1.0,1.584962500721156,null,1.584962500721156,1.0,1.584962500721156,3.321928094887362,2.584962500721156,null,2.321928094887362,null,1.584962500721156,1.0,0.0,1.584962500721156,1.584962500721156,2.321928094887362,4.754887502163468,3.169925001442312,2.807354922057604,3.4594316186372973,1.584962500721156,1.584962500721156,null,null,null,null,3.0,4.906890595608519,null,null,2.584962500721156,1.584962500721156,2.0,2.0,3.321928094887362,2.0,2.807354922057604,2.807354922057604,null,null,null,null,null,null,null,0.0,1.0,1.584962500721156,2.584962500721156,null,1.0,1.584962500721156,null,null,null,null,null,0.0,4.584962500721156,1.584962500721156,null,null,0.0,2.584962500721156,1.0,1.0,1.0,1.0,1.584962500721156,3.700439718141092,0.0,1.0,0.0,null,null,2.0,1.0,2.807354922057604,0.0,0.0,3.700439718141092,3.700439718141092,2.0,2.584962500721156,4.247927513443585,3.807354922057604,2.321928094887362,2.321928094887362,4.906890595608519,5.426264754702098,4.0,1.584962500721156,2.807354922057604,4.087462841250339,3.4594316186372973,2.584962500721156,1.584962500721156,2.321928094887362,2.321928094887362,6.672425341971495,6.977279923499917,4.754887502163468,3.807354922057604,4.754887502163468,4.247927513443585,3.807354922057604,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,4.643856189774724,5.78135971352466,4.169925001442312,4.169925001442312,2.584962500721156,3.321928094887362,3.321928094887362,4.700439718141092,3.584962500721156,4.700439718141092,4.584962500721156,4.584962500721156,4.321928094887363,3.700439718141092,2.584962500721156,2.0,2.807354922057604,2.807354922057604,3.0,3.4594316186372973,4.247927513443585,5.672425341971495,3.584962500721156,3.0,4.459431618637297,5.0,2.584962500721156,2.584962500721156,3.0,3.169925001442312,3.169925001442312,6.754887502163468,7.118941072723508,6.303780748177103,5.491853096329675,6.247927513443585,5.554588851677638,4.247927513443585,3.0,3.0,3.0,3.0,4.700439718141092,5.882643049361842,4.247927513443585,5.357552004618084,0.0,3.700439718141092,3.700439718141092,5.954196310386875,4.754887502163468,3.807354922057604,5.754887502163468,5.754887502163468,null,1.584962500721156,2.0,1.584962500721156,1.584962500721156,null,0.0,1.0,1.584962500721156,4.643856189774724,2.0,null,2.0,1.584962500721156,1.584962500721156,1.0,2.0,0.0,0.0,5.20945336562895,5.491853096329675,3.807354922057604,3.169925001442312,4.169925001442312,3.0,1.0,null,null,null,null,3.169925001442312,4.321928094887363,null,4.247927513443585,2.321928094887362,2.0,2.0,4.584962500721156,4.087462841250339,2.0,4.0,3.9068905956085187,3.0,1.0,null,1.0,0.0,2.0,1.584962500721156,2.807354922057604,4.857980995127572,4.754887502163468,3.0,null,1.0,3.807354922057604,0.0,1.0,2.321928094887362,null,null,5.321928094887363,5.392317422778761,4.754887502163468,3.169925001442312,4.247927513443585,3.4594316186372973,3.700439718141092,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,2.0,3.0,1.0,3.0,1.0,1.0,1.0,1.0,1.584962500721156,4.0,3.321928094887362,3.321928094887362,1.0,2.0,null,0.0,1.584962500721156,2.0,null,2.0,3.169925001442312,5.0,2.584962500721156,null,2.807354922057604,2.321928094887362,2.0,3.9068905956085187,1.584962500721156,null,null,4.857980995127572,6.022367813028454,4.0,4.523561956057013,4.754887502163468,4.392317422778761,3.807354922057604,2.807354922057604,2.807354922057604,2.807354922057604,2.584962500721156,3.584962500721156,4.857980995127572,3.0,3.0,1.0,1.0,1.0,5.087462841250339,null,3.584962500721156,4.0,4.0,0.0,0.0,2.0,null,1.0,null,1.584962500721156,0.0,1.0,3.0,2.584962500721156,null,null,1.584962500721156,null,1.0,2.0,null,null,3.584962500721156,5.807354922057604,4.906890595608519,3.4594316186372973,4.169925001442312,2.584962500721156,3.4594316186372973,2.0,1.584962500721156,1.584962500721156,1.584962500721156,3.169925001442312,4.807354922057604,null,2.321928094887362,0.0,null,null,2.0,3.169925001442312,4.247927513443585,2.807354922057604,2.584962500721156,4.392317422778761,4.584962500721156,2.584962500721156,3.0,4.700439718141092,4.0,2.584962500721156,3.700439718141092,5.554588851677638,6.768184324776926,5.0,2.807354922057604,3.807354922057604,3.807354922057604,3.169925001442312,4.0,3.321928094887362,4.459431618637297,4.459431618637297,7.219168520462161,8.204571144249204,6.523561956057013,5.614709844115208,6.3750394313469245,5.882643049361842,4.392317422778761,3.169925001442312,3.169925001442312,3.169925001442312,3.169925001442312,5.129283016944966,6.266786540694901,4.906890595608519,3.700439718141092,1.0,4.0,4.0,6.807354922057604,5.426264754702098,5.169925001442312,5.954196310386875,5.954196310386875,2.0,0.0,1.0,null,0.0,null,null,null,0.0,2.321928094887362,null,0.0,null,2.584962500721156,null,null,1.584962500721156,null,null,3.169925001442312,4.169925001442312,1.0,1.0,1.0,2.0,2.0,0.0,0.0,0.0,null,null,2.584962500721156,null,2.321928094887362,0.0,2.584962500721156,2.584962500721156,1.0,null,3.0,2.0,2.0,4.169925001442312,4.523561956057013,2.584962500721156,2.321928094887362,4.584962500721156,4.0,4.087462841250339,3.700439718141092,5.832890014164741,6.22881869049588,4.584962500721156,1.0,3.0,4.906890595608519,3.807354922057604,3.321928094887362,2.0,2.807354922057604,2.807354922057604,7.2761244052742375,8.139551352398794,6.321928094887363,5.614709844115208,6.339850002884624,5.906890595608519,4.321928094887363,3.4594316186372973,3.4594316186372973,3.4594316186372973,3.169925001442312,5.087462841250339,6.189824558880018,5.044394119358453,5.321928094887363,0.0,4.321928094887363,4.321928094887363,6.523561956057013,2.807354922057604,4.321928094887363,5.754887502163468,5.700439718141092,2.584962500721156,null,1.0,1.584962500721156,2.0,3.0,1.584962500721156,0.0,0.0,4.0,3.0,1.0,2.0,1.584962500721156,2.0,null,1.584962500721156,null,null,5.700439718141092,5.700439718141092,4.087462841250339,3.169925001442312,4.087462841250339,3.807354922057604,1.584962500721156,1.0,1.0,1.0,1.0,3.321928094887362,4.523561956057013,4.643856189774724,3.0,2.321928094887362,1.0,1.0,5.643856189774724,0.0,3.9068905956085187,3.584962500721156,3.584962500721156,null,null,null,0.0,0.0,null,null,null,1.584962500721156,2.0,null,null,1.584962500721156,0.0,null,null,null,null,null,1.0,3.9068905956085187,null,1.584962500721156,1.584962500721156,1.0,null,null,null,null,null,0.0,3.0,null,3.584962500721156,1.584962500721156,null,null,1.0,0.0,0.0,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,3.169925001442312,0.0,null,0.0,null,2.0,null,null,null,null,null,3.9068905956085187,0.0,2.0,1.0,null,null,1.0,null,null,null,0.0,2.807354922057604,6.285402218862249,2.0,3.169925001442312,3.321928094887362,2.584962500721156,1.0,2.0,3.169925001442312,4.754887502163468,1.0,4.321928094887363,2.0,3.0,5.700439718141092,1.0,0.0,4.954196310386875,4.954196310386875,4.700439718141092,6.087462841250339,4.954196310386875,5.459431618637297,4.700439718141092,7.826548487290915,3.4594316186372973,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,4.0,5.129283016944966,3.0,3.0,0.0,6.20945336562895,6.20945336562895,4.321928094887363,null,3.321928094887362,7.768184324776926,7.727920454563199,5.78135971352466,5.247927513443585,4.321928094887363,4.392317422778761,4.954196310386875,4.169925001442312,4.459431618637297,3.9068905956085187,5.426264754702098,6.6293566200796095,5.832890014164741,2.321928094887362,4.459431618637297,5.392317422778761,4.169925001442312,4.700439718141092,3.169925001442312,3.169925001442312,3.169925001442312,7.851749041416057,8.108524456778168,6.247927513443585,5.614709844115208,6.247927513443585,6.129283016944966,4.754887502163468,3.700439718141092,3.700439718141092,3.700439718141092,3.700439718141092,5.700439718141092,6.768184324776926,6.087462841250339,5.643856189774724,1.0,5.169925001442312,5.169925001442312,6.845490050944375,5.459431618637297,6.044394119358453,6.392317422778761,6.392317422778761,2.807354922057604,2.321928094887362,2.0,3.0,3.700439718141092,2.321928094887362,1.584962500721156,2.584962500721156,4.321928094887363,4.807354922057604,3.807354922057604,1.584962500721156,2.321928094887362,3.321928094887362,2.321928094887362,1.584962500721156,1.0,2.584962500721156,2.584962500721156,5.459431618637297,6.539158811108031,4.954196310386875,4.523561956057013,4.906890595608519,4.754887502163468,3.4594316186372973,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,3.700439718141092,5.044394119358453,3.321928094887362,2.0,2.584962500721156,2.0,2.0,6.108524456778169,4.392317422778761,4.169925001442312,4.754887502163468,4.754887502163468,1.584962500721156,2.321928094887362,2.0,0.0,1.0,0.0,1.0,null,1.0,3.4594316186372973,2.0,null,null,1.584962500721156,null,1.0,null,0.0,0.0,4.087462841250339,4.754887502163468,3.700439718141092,2.0,3.0,2.584962500721156,2.321928094887362,0.0,0.0,0.0,0.0,2.321928094887362,3.9068905956085187,0.0,2.0,1.0,1.0,1.0,3.321928094887362,2.807354922057604,2.584962500721156,3.321928094887362,3.321928094887362,4.392317422778761,3.700439718141092,2.0,2.584962500721156,3.321928094887362,3.321928094887362,2.0,1.584962500721156,3.700439718141092,5.614709844115208,4.459431618637297,2.584962500721156,3.169925001442312,3.4594316186372973,1.0,1.584962500721156,2.584962500721156,2.0,2.0,4.954196310386875,6.820178962415188,5.491853096329675,4.087462841250339,5.0,4.321928094887363,4.0,3.321928094887362,3.169925001442312,3.169925001442312,3.169925001442312,4.0,5.087462841250339,3.584962500721156,4.0,2.0,3.4594316186372973,3.4594316186372973,6.22881869049588,2.321928094887362,3.4594316186372973,5.0,5.0,5.754887502163468,5.285402218862249,5.20945336562895,4.807354922057604,5.392317422778761,5.523561956057013,5.321928094887363,4.643856189774724,6.129283016944966,7.936637939002571,6.129283016944966,3.4594316186372973,5.754887502163468,5.754887502163468,4.392317422778761,5.392317422778761,3.700439718141092,4.321928094887363,4.321928094887363,8.581200581924957,9.019590728357882,7.426264754702098,6.6293566200796095,7.442943495848728,7.05528243550119,5.78135971352466,5.0,5.0,5.0,5.0,6.768184324776926,7.845490050944375,5.584962500721156,6.066089190457772,2.0,5.321928094887363,5.321928094887363,7.651051691178929,6.189824558880018,6.507794640198696,6.882643049361842,6.857980995127572,null,null,null,0.0,1.0,0.0,0.0,null,1.0,0.0,null,null,1.584962500721156,null,null,0.0,null,0.0,0.0,3.4594316186372973,3.700439718141092,0.0,0.0,0.0,2.0,1.584962500721156,0.0,0.0,0.0,0.0,1.0,2.321928094887362,null,1.0,1.0,1.0,1.0,3.321928094887362,0.0,2.0,1.584962500721156,1.584962500721156,3.0,2.0,null,1.0,2.321928094887362,1.0,2.584962500721156,2.584962500721156,2.807354922057604,4.643856189774724,2.0,null,3.169925001442312,0.0,1.0,1.0,null,1.584962500721156,1.584962500721156,5.0,6.022367813028454,4.857980995127572,3.584962500721156,4.392317422778761,3.9068905956085187,2.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,3.700439718141092,4.857980995127572,4.459431618637297,4.169925001442312,2.0,2.0,2.0,3.807354922057604,1.0,3.584962500721156,4.169925001442312,4.169925001442312,4.643856189774724,4.087462841250339,3.0,3.807354922057604,4.584962500721156,3.0,2.807354922057604,3.807354922057604,4.754887502163468,6.392317422778761,4.459431618637297,2.0,3.584962500721156,4.643856189774724,3.584962500721156,4.247927513443585,3.321928094887362,3.4594316186372973,3.4594316186372973,7.22881869049588,7.459431618637297,6.614709844115208,5.20945336562895,6.285402218862249,5.523561956057013,4.857980995127572,4.0,4.0,4.0,4.0,5.700439718141092,6.754887502163468,5.584962500721156,4.906890595608519,1.584962500721156,3.9068905956085187,3.9068905956085187,6.392317422778761,3.321928094887362,6.087462841250339,5.977279923499917,5.977279923499917,5.044394119358453,3.807354922057604,3.807354922057604,3.807354922057604,4.087462841250339,3.584962500721156,3.4594316186372973,3.700439718141092,5.357552004618084,6.442943495848728,4.321928094887363,2.584962500721156,4.169925001442312,3.807354922057604,3.4594316186372973,3.0,3.700439718141092,4.0,4.0,7.247927513443585,7.741466986401147,6.672425341971495,5.426264754702098,6.539158811108031,5.977279923499917,5.584962500721156,4.857980995127572,4.807354922057604,4.807354922057604,4.807354922057604,5.247927513443585,6.3750394313469245,4.700439718141092,4.169925001442312,0.0,3.700439718141092,3.700439718141092,6.6865005271832185,4.523561956057013,3.584962500721156,5.285402218862249,5.285402218862249,3.0,1.584962500721156,null,3.0,3.4594316186372973,3.169925001442312,3.321928094887362,2.321928094887362,4.643856189774724,6.321928094887363,4.523561956057013,2.0,4.169925001442312,3.584962500721156,2.0,1.0,1.0,1.584962500721156,1.584962500721156,7.266786540694901,7.294620748891627,5.554588851677638,4.700439718141092,5.700439718141092,4.807354922057604,3.169925001442312,2.0,2.0,2.0,2.0,4.392317422778761,5.554588851677638,3.584962500721156,4.321928094887363,null,2.584962500721156,2.584962500721156,4.584962500721156,3.4594316186372973,3.807354922057604,4.857980995127572,4.807354922057604,null,null,null,null,null,null,null,null,null,null,2.0,null,1.0,null,null,1.0,null,null,null,null,2.321928094887362,2.0,null,null,null,2.0,null,null,null,null,null,2.0,null,null,1.584962500721156,2.0,2.0,0.0,0.0,0.0,0.0,0.0,5.78135971352466,5.523561956057013,4.857980995127572,4.807354922057604,4.906890595608519,5.700439718141092,5.0,4.321928094887363,6.977279923499917,7.888743248898259,6.3750394313469245,4.169925001442312,5.727920454563199,6.022367813028454,5.357552004618084,5.321928094887363,4.087462841250339,5.087462841250339,5.087462841250339,8.89178370321831,9.144658242831882,7.554588851677638,6.584962500721156,7.434628227636725,7.159871336778389,6.459431618637297,5.700439718141092,5.700439718141092,5.700439718141092,5.614709844115208,6.491853096329675,7.546894459887636,5.392317422778761,6.022367813028454,2.0,5.285402218862249,5.285402218862249,6.754887502163468,4.169925001442312,6.554588851677638,7.129283016944966,7.098032082960526,4.0,2.584962500721156,1.0,2.807354922057604,3.4594316186372973,2.584962500721156,3.807354922057604,0.0,2.584962500721156,5.459431618637297,4.643856189774724,2.0,1.0,3.169925001442312,2.0,2.321928094887362,2.0,1.0,1.0,5.426264754702098,5.554588851677638,4.807354922057604,4.523561956057013,4.754887502163468,4.392317422778761,4.321928094887363,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,4.0,5.247927513443585,3.700439718141092,4.0,1.584962500721156,3.700439718141092,3.700439718141092,5.392317422778761,3.700439718141092,5.20945336562895,3.321928094887362,3.321928094887362,3.169925001442312,0.0,2.0,1.584962500721156,3.0,1.0,1.584962500721156,2.321928094887362,4.459431618637297,5.0,3.0,null,3.0,3.321928094887362,1.584962500721156,0.0,2.321928094887362,1.584962500721156,1.584962500721156,6.569855608330948,6.754887502163468,5.426264754702098,4.169925001442312,4.954196310386875,4.169925001442312,3.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,4.169925001442312,5.169925001442312,3.0,3.584962500721156,0.0,3.0,3.0,5.807354922057604,2.807354922057604,3.4594316186372973,5.0,5.0,4.584962500721156,4.321928094887363,3.807354922057604,3.9068905956085187,4.807354922057604,3.321928094887362,3.9068905956085187,3.169925001442312,5.169925001442312,6.459431618637297,4.321928094887363,2.321928094887362,3.807354922057604,4.906890595608519,3.0,3.169925001442312,3.9068905956085187,4.247927513443585,4.247927513443585,6.614709844115208,7.392317422778761,6.22881869049588,5.426264754702098,6.189824558880018,6.087462841250339,5.129283016944966,4.247927513443585,4.247927513443585,4.247927513443585,4.247927513443585,5.0,6.22881869049588,4.0,4.906890595608519,null,4.169925001442312,4.169925001442312,6.066089190457772,6.339850002884624,4.169925001442312,6.066089190457772,6.066089190457772,3.584962500721156,3.321928094887362,null,2.321928094887362,3.584962500721156,null,1.0,2.584962500721156,3.700439718141092,4.0,3.584962500721156,null,2.584962500721156,3.0,2.584962500721156,1.0,1.584962500721156,2.321928094887362,2.321928094887362,5.614709844115208,6.78135971352466,4.807354922057604,4.087462841250339,4.857980995127572,3.584962500721156,3.169925001442312,2.0,2.0,2.0,2.0,3.807354922057604,4.857980995127572,2.321928094887362,3.584962500721156,2.0,2.0,2.0,4.321928094887363,4.0,4.169925001442312,4.392317422778761,4.247927513443585,3.0,3.0,null,2.584962500721156,3.169925001442312,2.807354922057604,1.0,2.584962500721156,3.807354922057604,3.4594316186372973,2.584962500721156,2.584962500721156,3.0,3.321928094887362,3.0,1.584962500721156,2.807354922057604,2.0,2.0,4.857980995127572,5.906890595608519,4.321928094887363,3.584962500721156,4.459431618637297,4.807354922057604,3.807354922057604,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,4.523561956057013,5.754887502163468,2.0,3.4594316186372973,0.0,null,null,5.285402218862249,4.392317422778761,5.169925001442312,4.392317422778761,4.321928094887363,4.954196310386875,3.584962500721156,3.321928094887362,2.0,4.459431618637297,3.169925001442312,3.807354922057604,4.169925001442312,5.392317422778761,6.066089190457772,5.0,2.584962500721156,4.906890595608519,4.700439718141092,3.700439718141092,4.0,2.584962500721156,4.087462841250339,4.087462841250339,7.2761244052742375,7.266786540694901,6.507794640198696,5.169925001442312,6.108524456778169,5.882643049361842,4.807354922057604,4.087462841250339,4.087462841250339,4.0,4.0,5.523561956057013,6.554588851677638,4.523561956057013,4.700439718141092,2.0,3.807354922057604,3.807354922057604,6.977279923499917,4.459431618637297,4.857980995127572,5.0,5.0,3.807354922057604,3.321928094887362,2.807354922057604,2.807354922057604,3.169925001442312,3.169925001442312,2.584962500721156,3.0,4.459431618637297,5.169925001442312,3.4594316186372973,2.0,3.584962500721156,3.9068905956085187,2.584962500721156,1.0,2.321928094887362,2.321928094887362,2.321928094887362,6.321928094887363,7.554588851677638,5.672425341971495,4.392317422778761,5.523561956057013,5.169925001442312,3.169925001442312,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,4.087462841250339,5.129283016944966,2.321928094887362,4.459431618637297,1.584962500721156,2.584962500721156,2.584962500721156,6.108524456778169,3.9068905956085187,2.807354922057604,5.357552004618084,5.285402218862249,4.247927513443585,3.584962500721156,2.0,2.0,3.0,2.584962500721156,2.807354922057604,2.807354922057604,4.169925001442312,6.044394119358453,4.0,1.0,3.584962500721156,4.0,2.584962500721156,3.807354922057604,2.807354922057604,2.321928094887362,2.321928094887362,6.285402218862249,6.554588851677638,5.584962500721156,4.754887502163468,5.247927513443585,4.321928094887363,3.9068905956085187,3.169925001442312,3.169925001442312,3.169925001442312,3.169925001442312,4.247927513443585,5.247927513443585,4.0,3.584962500721156,0.0,2.584962500721156,2.584962500721156,5.906890595608519,4.169925001442312,2.584962500721156,4.643856189774724,4.523561956057013,1.584962500721156,null,1.0,1.584962500721156,2.321928094887362,1.0,null,0.0,2.584962500721156,4.087462841250339,null,0.0,3.169925001442312,1.0,1.0,2.584962500721156,2.0,1.584962500721156,1.584962500721156,4.906890595608519,5.357552004618084,3.807354922057604,2.584962500721156,3.169925001442312,3.321928094887362,2.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,3.584962500721156,3.584962500721156,2.0,1.0,1.0,1.0,2.584962500721156,2.0,4.169925001442312,2.807354922057604,2.807354922057604,3.700439718141092,3.0,0.0,2.584962500721156,3.321928094887362,3.0,2.584962500721156,3.169925001442312,4.087462841250339,5.285402218862249,3.807354922057604,1.0,2.321928094887362,3.807354922057604,2.321928094887362,2.584962500721156,0.0,2.321928094887362,2.321928094887362,6.108524456778169,7.2384047393250786,5.044394119358453,4.807354922057604,5.247927513443585,4.906890595608519,2.584962500721156,2.0,2.0,2.0,2.0,4.643856189774724,5.807354922057604,1.0,3.807354922057604,2.321928094887362,null,null,6.189824558880018,2.807354922057604,4.169925001442312,4.807354922057604,4.807354922057604,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,null,null,0.0,null,null,null,null,2.321928094887362,1.584962500721156,null,null,null,null,null,null,null,null,null,1.0,null,null,0.0,1.0,1.0,0.0,null,0.0,null,null,6.321928094887363,5.882643049361842,5.285402218862249,5.0,5.523561956057013,5.832890014164741,5.643856189774724,5.20945336562895,7.2384047393250786,8.426264754702098,7.118941072723508,3.0,5.672425341971495,6.426264754702098,5.491853096329675,4.700439718141092,4.906890595608519,4.906890595608519,4.906890595608519,9.20945336562895,9.957102041562287,8.071462362556623,7.098032082960526,8.011227255423254,7.348728154231077,6.754887502163468,5.906890595608519,5.906890595608519,5.906890595608519,5.882643049361842,6.584962500721156,7.727920454563199,6.614709844115208,6.149747119504682,1.584962500721156,5.459431618637297,5.459431618637297,8.459431618637296,6.672425341971495,6.599912842187128,7.965784284662087,7.948367231584678,6.129283016944966,6.129283016944966,5.700439718141092,5.20945336562895,6.303780748177103,5.392317422778761,4.643856189774724,5.247927513443585,6.475733430966398,7.592457037268081,6.129283016944966,4.643856189774724,5.426264754702098,6.741466986401147,4.459431618637297,4.906890595608519,4.954196310386875,5.087462841250339,5.087462841250339,8.219168520462162,9.019590728357882,7.851749041416057,6.965784284662087,8.060695931687555,7.118941072723508,6.523561956057013,5.672425341971495,5.643856189774724,5.643856189774724,5.614709844115208,7.149747119504682,8.214319120800766,6.087462841250339,6.392317422778761,1.0,5.643856189774724,5.643856189774724,7.930737337562887,6.475733430966398,6.0,7.451211111832329,7.434628227636725,7.149747119504682,6.700439718141092,5.700439718141092,6.087462841250339,7.400879436282184,6.247927513443585,6.539158811108031,6.22881869049588,7.857980995127572,9.177419537989236,7.906890595608519,4.906890595608519,6.475733430966398,7.515699838284043,6.727920454563199,6.357552004618084,6.20945336562895,6.20945336562895,6.20945336562895,9.667111542075027,10.651051691178928,8.945443836377912,8.326429487122303,9.095397022792557,8.430452551665532,7.721099188707185,6.930737337562887,6.918863237274595,6.918863237274595,6.918863237274595,7.894817763307944,8.965784284662087,7.312882955284356,6.918863237274595,3.169925001442312,6.599912842187128,6.599912842187128,9.319672120946995,null,7.918863237274595,8.51175265376738,8.49585502688717,4.0,4.169925001442312,1.0,3.169925001442312,4.392317422778761,2.584962500721156,2.584962500721156,3.584962500721156,5.554588851677638,6.507794640198696,4.459431618637297,2.321928094887362,4.807354922057604,3.4594316186372973,3.0,3.807354922057604,2.584962500721156,4.087462841250339,4.087462841250339,6.857980995127572,7.774787059601174,6.357552004618084,4.906890595608519,6.0,4.807354922057604,3.700439718141092,2.807354922057604,2.807354922057604,2.807354922057604,2.807354922057604,4.857980995127572,6.022367813028454,5.523561956057013,4.087462841250339,0.0,3.4594316186372973,3.4594316186372973,7.066089190457772,5.754887502163468,5.169925001442312,5.087462841250339,5.044394119358453,4.523561956057013,4.807354922057604,5.0,3.0,4.247927513443585,4.169925001442312,4.247927513443585,4.0,5.672425341971495,6.392317422778761,4.700439718141092,1.584962500721156,4.392317422778761,5.247927513443585,4.087462841250339,4.523561956057013,4.247927513443585,3.321928094887362,3.321928094887362,7.434628227636725,8.071462362556623,6.584962500721156,5.807354922057604,6.672425341971495,6.169925001442312,5.614709844115208,4.643856189774724,4.584962500721156,4.584962500721156,4.523561956057013,5.523561956057013,6.614709844115208,4.906890595608519,4.392317422778761,3.169925001442312,5.0,5.0,5.807354922057604,3.807354922057604,5.906890595608519,6.044394119358453,6.022367813028454,3.584962500721156,4.754887502163468,3.584962500721156,2.807354922057604,3.169925001442312,3.807354922057604,2.584962500721156,3.321928094887362,4.807354922057604,4.857980995127572,4.584962500721156,1.0,1.584962500721156,3.4594316186372973,2.807354922057604,3.169925001442312,1.0,1.0,1.0,5.78135971352466,6.523561956057013,4.321928094887363,3.169925001442312,3.700439718141092,3.9068905956085187,4.0,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,4.459431618637297,5.523561956057013,3.0,2.584962500721156,1.0,3.584962500721156,3.584962500721156,5.392317422778761,2.584962500721156,5.087462841250339,5.392317422778761,5.357552004618084,5.247927513443585,4.906890595608519,3.584962500721156,3.700439718141092,5.129283016944966,4.169925001442312,4.392317422778761,4.169925001442312,6.339850002884624,6.6865005271832185,6.247927513443585,3.584962500721156,4.584962500721156,6.022367813028454,5.169925001442312,5.0,3.700439718141092,3.807354922057604,3.807354922057604,8.184875342908283,8.686500527183219,7.219168520462161,6.643856189774724,7.2384047393250786,6.357552004618084,5.882643049361842,5.0,4.954196310386875,4.954196310386875,4.954196310386875,5.930737337562887,7.03342300153745,5.357552004618084,6.0,2.0,5.491853096329675,5.491853096329675,6.584962500721156,5.727920454563199,6.554588851677638,6.357552004618084,6.339850002884624,3.584962500721156,3.169925001442312,null,1.0,2.0,4.459431618637297,4.169925001442312,3.169925001442312,5.727920454563199,6.569855608330948,3.321928094887362,1.0,4.087462841250339,4.087462841250339,3.584962500721156,2.807354922057604,2.584962500721156,2.584962500721156,2.584962500721156,7.383704292474052,8.632995197142957,5.78135971352466,4.754887502163468,5.643856189774724,5.491853096329675,4.700439718141092,4.0,3.9068905956085187,3.9068905956085187,3.807354922057604,2.807354922057604,4.584962500721156,6.129283016944966,3.700439718141092,1.0,2.584962500721156,2.584962500721156,7.614709844115208,1.584962500721156,4.857980995127572,5.392317422778761,5.357552004618084,3.700439718141092,3.169925001442312,2.584962500721156,1.0,1.584962500721156,2.807354922057604,1.584962500721156,1.584962500721156,3.321928094887362,4.857980995127572,4.459431618637297,1.0,null,3.584962500721156,2.584962500721156,2.0,2.321928094887362,1.584962500721156,1.584962500721156,6.066089190457772,6.882643049361842,5.044394119358453,3.584962500721156,4.523561956057013,3.169925001442312,3.4594316186372973,2.0,2.0,2.0,2.0,3.584962500721156,4.857980995127572,4.321928094887363,3.0,1.0,3.9068905956085187,3.9068905956085187,4.754887502163468,1.584962500721156,3.584962500721156,4.523561956057013,4.459431618637297,3.0,1.0,2.0,0.0,1.584962500721156,2.0,1.0,1.0,3.9068905956085187,4.857980995127572,4.584962500721156,null,2.584962500721156,3.169925001442312,2.0,1.0,null,null,null,5.392317422778761,6.426264754702098,4.700439718141092,4.0,4.643856189774724,4.087462841250339,2.321928094887362,1.0,1.0,1.0,1.0,2.321928094887362,3.9068905956085187,2.807354922057604,2.321928094887362,2.584962500721156,1.0,1.0,4.169925001442312,2.584962500721156,3.584962500721156,4.0,4.0,3.0,2.584962500721156,1.0,1.0,2.0,2.584962500721156,0.0,2.0,3.4594316186372973,3.807354922057604,3.321928094887362,null,2.584962500721156,2.807354922057604,2.321928094887362,3.0,1.0,1.0,1.0,5.584962500721156,6.658211482751795,4.754887502163468,4.087462841250339,4.906890595608519,3.700439718141092,2.807354922057604,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,3.169925001442312,4.643856189774724,3.4594316186372973,1.0,1.0,3.4594316186372973,3.4594316186372973,5.357552004618084,2.321928094887362,3.807354922057604,4.247927513443585,4.247927513443585,0.0,null,null,null,null,0.0,null,null,null,null,null,0.0,1.584962500721156,null,null,null,null,null,null,null,3.4594316186372973,0.0,null,null,null,1.584962500721156,null,null,null,null,null,2.807354922057604,null,null,2.584962500721156,null,null,1.0,null,null,null,null,7.948367231584678,7.679480099505446,7.076815597050831,7.467605550082998,8.164906926675688,7.339850002884624,7.189824558880018,6.754887502163468,8.134426320220927,8.948367231584678,9.238404739325079,6.930737337562887,6.906890595608519,7.6865005271832185,7.199672344836364,7.417852514885898,6.754887502163468,6.672425341971495,6.672425341971495,9.837627933171404,9.850186837645774,9.388017285345136,8.72451385311995,9.199672344836364,9.172427508645482,8.804131021183318,7.807354922057604,7.794415866350106,7.794415866350106,7.794415866350106,9.038918989292302,10.08214904135387,6.658211482751795,7.948367231584678,3.807354922057604,7.820178962415188,7.820178962415188,8.62935662007961,8.366322214245816,8.149747119504681,9.027905996569885,9.027905996569885,6.087462841250339,5.807354922057604,4.700439718141092,5.129283016944966,5.78135971352466,5.0,5.0,4.857980995127572,6.614709844115208,7.78135971352466,6.20945336562895,3.584962500721156,5.672425341971495,5.727920454563199,4.954196310386875,5.20945336562895,4.906890595608519,4.857980995127572,4.857980995127572,8.658211482751796,9.30149619498255,7.714245517666122,6.539158811108031,7.577428828035749,7.219168520462161,6.475733430966398,5.554588851677638,5.554588851677638,5.554588851677638,5.491853096329675,6.523561956057013,7.679480099505446,6.044394119358453,6.169925001442312,null,5.584962500721156,5.584962500721156,8.43879185257826,6.357552004618084,5.906890595608519,7.294620748891627,7.294620748891627,2.584962500721156,3.321928094887362,2.0,1.0,3.584962500721156,null,1.584962500721156,2.321928094887362,4.0,5.554588851677638,3.807354922057604,null,3.321928094887362,2.321928094887362,2.584962500721156,2.0,3.169925001442312,3.321928094887362,3.321928094887362,6.3750394313469245,7.159871336778389,5.954196310386875,4.247927513443585,5.491853096329675,4.700439718141092,3.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.0,4.584962500721156,5.754887502163468,3.169925001442312,2.584962500721156,1.0,2.0,2.0,5.977279923499917,1.584962500721156,4.584962500721156,5.169925001442312,5.129283016944966,5.554588851677638,5.700439718141092,4.321928094887363,4.523561956057013,5.321928094887363,3.9068905956085187,4.523561956057013,5.044394119358453,5.285402218862249,7.011227255423254,6.0,2.0,5.426264754702098,5.584962500721156,4.0,5.247927513443585,3.4594316186372973,5.129283016944966,5.129283016944966,7.339850002884624,8.257387842692651,6.965784284662087,6.539158811108031,7.303780748177103,6.569855608330948,5.727920454563199,4.857980995127572,4.857980995127572,4.857980995127572,4.857980995127572,6.108524456778169,7.219168520462161,5.169925001442312,5.044394119358453,2.321928094887362,5.129283016944966,5.129283016944966,5.614709844115208,5.523561956057013,5.954196310386875,7.011227255423254,6.9886846867721655,1.0,null,null,null,null,null,1.584962500721156,null,1.0,2.584962500721156,1.0,null,null,null,null,null,null,0.0,0.0,0.0,3.700439718141092,2.0,null,0.0,null,null,null,null,null,null,0.0,1.0,1.0,null,null,null,null,3.0,null,1.0,0.0,0.0,2.584962500721156,2.0,1.0,2.321928094887362,2.807354922057604,3.321928094887362,2.807354922057604,2.807354922057604,3.700439718141092,3.807354922057604,2.584962500721156,1.0,2.584962500721156,2.0,1.0,2.321928094887362,null,1.0,1.0,4.643856189774724,5.554588851677638,2.321928094887362,4.0,4.392317422778761,4.087462841250339,4.0,3.0,3.0,3.0,3.0,3.700439718141092,4.857980995127572,2.584962500721156,4.087462841250339,1.584962500721156,3.0,3.0,4.700439718141092,3.700439718141092,3.0,4.321928094887363,4.321928094887363,3.321928094887362,3.0,2.584962500721156,1.0,1.584962500721156,3.584962500721156,2.807354922057604,1.584962500721156,4.584962500721156,5.807354922057604,3.700439718141092,2.584962500721156,2.321928094887362,3.584962500721156,2.807354922057604,3.0,2.321928094887362,1.0,1.0,6.169925001442312,7.417852514885898,5.044394119358453,4.807354922057604,5.459431618637297,4.247927513443585,3.9068905956085187,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,3.9068905956085187,4.906890595608519,4.321928094887363,3.0,0.0,2.0,2.0,6.426264754702098,1.0,4.169925001442312,4.700439718141092,4.643856189774724,3.169925001442312,2.584962500721156,1.0,0.0,2.807354922057604,3.0,3.0,1.0,3.4594316186372973,5.087462841250339,3.0,null,1.0,1.584962500721156,1.584962500721156,3.321928094887362,2.0,0.0,0.0,5.700439718141092,6.741466986401147,4.523561956057013,3.584962500721156,4.700439718141092,2.807354922057604,3.4594316186372973,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,2.807354922057604,4.584962500721156,null,2.584962500721156,null,1.584962500721156,1.584962500721156,6.285402218862249,1.0,1.0,3.321928094887362,3.169925001442312,2.321928094887362,3.0,null,null,2.321928094887362,1.0,2.321928094887362,1.0,1.584962500721156,3.4594316186372973,2.807354922057604,1.0,2.807354922057604,3.0,0.0,null,0.0,1.0,1.0,2.807354922057604,4.247927513443585,5.247927513443585,3.321928094887362,4.169925001442312,3.321928094887362,1.0,0.0,0.0,0.0,0.0,3.321928094887362,4.700439718141092,null,2.584962500721156,2.807354922057604,1.584962500721156,1.584962500721156,4.0,2.0,2.0,3.169925001442312,3.169925001442312,3.321928094887362,2.321928094887362,null,1.0,4.247927513443585,2.0,2.0,2.321928094887362,3.584962500721156,4.392317422778761,3.0,null,2.584962500721156,2.321928094887362,1.584962500721156,4.247927513443585,2.807354922057604,2.321928094887362,2.321928094887362,5.285402218862249,6.044394119358453,5.426264754702098,4.754887502163468,5.614709844115208,4.247927513443585,4.321928094887363,3.321928094887362,3.321928094887362,3.321928094887362,3.321928094887362,4.954196310386875,6.022367813028454,2.584962500721156,2.584962500721156,2.0,1.0,1.0,5.321928094887363,4.087462841250339,3.700439718141092,4.857980995127572,4.857980995127572,1.584962500721156,0.0,1.0,0.0,0.0,0.0,null,null,null,0.0,1.0,null,null,null,1.584962500721156,null,0.0,null,null,2.584962500721156,3.700439718141092,null,null,null,1.0,2.321928094887362,0.0,0.0,0.0,0.0,1.0,2.807354922057604,0.0,2.584962500721156,0.0,3.0,3.0,2.0,null,null,1.0,1.0,null,null,null,null,null,1.0,null,null,null,null,null,null,null,0.0,null,0.0,null,null,null,null,3.700439718141092,1.584962500721156,null,null,null,1.0,null,null,null,null,null,2.321928094887362,null,null,2.0,1.0,1.0,1.0,null,0.0,null,null,5.321928094887363,5.357552004618084,4.0,5.044394119358453,5.357552004618084,4.247927513443585,4.523561956057013,4.247927513443585,4.906890595608519,5.807354922057604,6.507794640198696,4.584962500721156,3.807354922057604,4.392317422778761,4.584962500721156,4.906890595608519,4.392317422778761,4.0,4.0,5.906890595608519,6.894817763307944,6.894817763307944,5.930737337562887,6.247927513443585,6.044394119358453,5.584962500721156,4.459431618637297,4.459431618637297,4.459431618637297,4.459431618637297,6.599912842187128,7.651051691178929,3.807354922057604,5.727920454563199,3.700439718141092,4.584962500721156,4.584962500721156,6.523561956057013,3.0,5.832890014164741,6.643856189774724,6.643856189774724,4.643856189774724,4.807354922057604,3.321928094887362,4.321928094887363,5.087462841250339,3.4594316186372973,3.321928094887362,3.321928094887362,5.0,4.954196310386875,5.087462841250339,4.0,4.459431618637297,4.700439718141092,4.0,4.321928094887363,3.700439718141092,3.807354922057604,3.807354922057604,6.459431618637297,7.159871336778389,6.523561956057013,5.614709844115208,6.149747119504682,5.977279923499917,5.357552004618084,4.247927513443585,4.247927513443585,4.247927513443585,4.247927513443585,6.442943495848728,7.507794640198696,2.0,5.357552004618084,1.0,5.087462841250339,5.087462841250339,5.930737337562887,5.807354922057604,6.266786540694901,6.247927513443585,6.266786540694901,4.459431618637297,4.0,3.807354922057604,4.0,5.247927513443585,4.459431618637297,2.584962500721156,3.0,4.247927513443585,4.954196310386875,4.0,2.584962500721156,3.321928094887362,3.9068905956085187,3.0,4.0,1.584962500721156,2.584962500721156,2.584962500721156,5.247927513443585,5.357552004618084,5.247927513443585,4.643856189774724,5.044394119358453,5.584962500721156,3.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,6.129283016944966,7.129283016944966,1.0,4.523561956057013,null,4.584962500721156,4.584962500721156,4.0,5.426264754702098,5.0,5.491853096329675,5.491853096329675,5.672425341971495,4.807354922057604,5.0,4.906890595608519,5.087462841250339,4.754887502163468,4.584962500721156,4.247927513443585,5.285402218862249,5.906890595608519,5.906890595608519,3.807354922057604,5.129283016944966,5.554588851677638,4.754887502163468,5.0,4.169925001442312,3.807354922057604,3.807354922057604,6.658211482751795,7.721099188707185,6.94251450533924,6.129283016944966,6.845490050944375,6.3750394313469245,5.754887502163468,4.906890595608519,4.906890595608519,4.906890595608519,4.906890595608519,6.20945336562895,7.2384047393250786,3.584962500721156,4.643856189774724,1.584962500721156,5.20945336562895,5.20945336562895,6.768184324776926,5.857980995127572,6.303780748177103,5.754887502163468,5.700439718141092,4.0,2.321928094887362,1.584962500721156,1.0,3.169925001442312,3.169925001442312,1.584962500721156,2.807354922057604,4.169925001442312,4.523561956057013,3.700439718141092,2.0,2.584962500721156,2.807354922057604,0.0,2.321928094887362,1.0,null,null,4.169925001442312,4.807354922057604,4.643856189774724,3.807354922057604,4.584962500721156,4.459431618637297,4.392317422778761,3.169925001442312,3.0,3.0,3.0,4.523561956057013,5.78135971352466,3.0,3.321928094887362,0.0,3.807354922057604,3.807354922057604,3.700439718141092,null,3.700439718141092,4.584962500721156,4.523561956057013,3.321928094887362,3.0,3.4594316186372973,3.0,3.584962500721156,3.700439718141092,3.0,3.4594316186372973,4.321928094887363,5.285402218862249,2.584962500721156,1.0,3.0,3.807354922057604,1.584962500721156,3.0,3.0,2.584962500721156,2.584962500721156,4.954196310386875,5.882643049361842,5.247927513443585,4.459431618637297,5.554588851677638,5.044394119358453,4.392317422778761,3.321928094887362,3.321928094887362,3.321928094887362,3.321928094887362,4.169925001442312,5.491853096329675,3.584962500721156,3.0,1.584962500721156,4.584962500721156,4.584962500721156,3.807354922057604,4.247927513443585,1.0,5.426264754702098,5.357552004618084,6.794415866350106,6.857980995127572,5.426264754702098,6.247927513443585,7.434628227636725,6.727920454563199,5.491853096329675,5.78135971352466,7.6653359171851765,7.459431618637297,7.622051819456376,5.321928094887363,6.614709844115208,7.257387842692652,6.491853096329675,6.700439718141092,5.754887502163468,6.442943495848728,6.442943495848728,8.734709620225837,9.174925682500678,8.679480099505446,7.774787059601174,8.515699838284043,8.308339030139408,7.876516946564999,7.044394119358453,7.03342300153745,7.03342300153745,7.03342300153745,8.005624549193879,9.08214904135387,6.3750394313469245,7.794415866350106,1.0,7.129283016944966,7.129283016944966,7.05528243550119,7.257387842692652,7.60733031374961,8.184875342908283,8.164906926675688,1.0,2.584962500721156,1.0,null,2.321928094887362,2.0,1.584962500721156,2.0,2.321928094887362,2.584962500721156,null,1.0,1.0,0.0,1.584962500721156,1.0,null,null,null,2.807354922057604,3.584962500721156,3.807354922057604,null,2.584962500721156,3.4594316186372973,1.0,null,null,null,null,3.169925001442312,4.523561956057013,2.321928094887362,3.4594316186372973,0.0,1.0,1.0,2.0,1.0,4.247927513443585,2.0,2.0,5.285402218862249,5.044394119358453,3.4594316186372973,4.392317422778761,5.807354922057604,4.247927513443585,4.0,4.754887502163468,5.78135971352466,6.129283016944966,5.906890595608519,3.584962500721156,5.857980995127572,5.129283016944966,4.807354922057604,5.977279923499917,3.807354922057604,4.643856189774724,4.643856189774724,6.794415866350106,7.285402218862249,7.076815597050831,5.754887502163468,6.820178962415188,6.285402218862249,6.409390936137702,5.523561956057013,5.523561956057013,5.523561956057013,5.491853096329675,6.426264754702098,7.491853096329675,3.584962500721156,5.614709844115208,0.0,5.087462841250339,5.087462841250339,5.643856189774724,6.78135971352466,5.977279923499917,6.614709844115208,6.614709844115208,3.321928094887362,2.584962500721156,3.321928094887362,1.0,3.4594316186372973,1.584962500721156,2.0,2.321928094887362,3.584962500721156,2.807354922057604,2.0,2.584962500721156,3.0,2.807354922057604,null,3.0,2.0,1.0,1.0,4.857980995127572,5.169925001442312,4.321928094887363,3.4594316186372973,4.392317422778761,3.321928094887362,2.807354922057604,2.0,2.0,2.0,2.0,3.700439718141092,4.857980995127572,3.321928094887362,3.169925001442312,2.584962500721156,2.584962500721156,2.584962500721156,4.247927513443585,4.807354922057604,4.0,4.169925001442312,4.169925001442312,3.4594316186372973,2.321928094887362,3.0,2.0,3.321928094887362,3.321928094887362,1.584962500721156,2.321928094887362,4.169925001442312,4.169925001442312,4.169925001442312,3.807354922057604,3.584962500721156,3.584962500721156,3.321928094887362,4.0,2.321928094887362,2.0,2.0,4.584962500721156,5.643856189774724,5.044394119358453,4.247927513443585,4.807354922057604,4.700439718141092,4.584962500721156,3.4594316186372973,3.4594316186372973,3.4594316186372973,3.4594316186372973,4.643856189774724,5.727920454563199,3.807354922057604,4.459431618637297,0.0,3.321928094887362,3.321928094887362,4.169925001442312,4.584962500721156,3.9068905956085187,5.044394119358453,5.044394119358453,0.0,null,null,null,null,0.0,null,null,null,null,null,0.0,1.584962500721156,null,null,2.0,null,null,null,null,3.9068905956085187,2.321928094887362,null,null,null,0.0,null,null,null,null,null,1.584962500721156,null,2.321928094887362,2.584962500721156,0.0,0.0,1.0,null,1.0,null,null,6.94251450533924,6.409390936137702,6.044394119358453,6.285402218862249,6.870364719583405,6.459431618637297,6.357552004618084,5.672425341971495,6.807354922057604,7.199672344836364,8.071462362556623,5.977279923499917,6.768184324776926,6.6865005271832185,5.977279923499917,6.20945336562895,5.727920454563199,5.857980995127572,5.857980995127572,8.179909090014934,8.335390354693924,8.164906926675688,7.426264754702098,7.954196310386875,7.614709844115208,7.434628227636725,6.409390936137702,6.392317422778761,6.392317422778761,6.357552004618084,8.011227255423254,9.044394119358454,6.044394119358453,7.159871336778389,2.584962500721156,6.857980995127572,6.857980995127572,7.426264754702098,6.741466986401147,7.614709844115208,7.948367231584678,7.948367231584678,8.487840033823051,7.876516946564999,7.400879436282184,7.912889336229962,8.618385502258606,7.900866807980749,7.523561956057013,7.6293566200796095,8.774787059601174,9.084808387804362,9.840777923595054,7.6293566200796095,8.257387842692651,8.491853096329674,7.960001932068081,8.103287808412022,7.409390936137702,7.577428828035749,7.577428828035749,9.693486957499326,10.29117069932186,9.917372079476841,9.139551352398794,9.702172685365548,9.623881490013458,9.335390354693924,8.294620748891626,8.285402218862249,8.280770770130603,8.280770770130603,9.594324603924848,10.654636028527968,7.614709844115208,9.068778277985412,3.321928094887362,8.50382573799575,8.50382573799575,9.513727595952437,8.487840033823051,9.247927513443585,9.791162888555018,9.787902559391432,2.321928094887362,0.0,2.0,1.0,3.0,2.807354922057604,2.0,2.807354922057604,2.584962500721156,2.584962500721156,3.0,null,2.807354922057604,3.321928094887362,2.0,2.0,2.0,1.0,1.0,4.169925001442312,5.754887502163468,4.459431618637297,3.4594316186372973,4.169925001442312,3.584962500721156,3.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,4.321928094887363,5.523561956057013,1.0,2.584962500721156,1.584962500721156,3.169925001442312,3.169925001442312,4.392317422778761,3.584962500721156,4.0,4.754887502163468,4.754887502163468,5.169925001442312,4.700439718141092,4.459431618637297,4.700439718141092,5.321928094887363,3.0,3.169925001442312,4.459431618637297,5.392317422778761,5.78135971352466,5.857980995127572,3.169925001442312,5.321928094887363,4.906890595608519,3.700439718141092,5.087462841250339,3.0,4.169925001442312,4.169925001442312,6.0,7.022367813028454,6.459431618637297,5.78135971352466,6.169925001442312,5.643856189774724,4.392317422778761,3.321928094887362,3.321928094887362,3.321928094887362,3.321928094887362,6.066089190457772,7.118941072723508,4.169925001442312,5.087462841250339,2.0,4.807354922057604,4.807354922057604,5.357552004618084,3.807354922057604,5.087462841250339,6.22881869049588,6.22881869049588,0.0,null,null,null,null,1.0,null,null,null,null,null,0.0,0.0,null,null,null,null,null,null,0.0,4.700439718141092,1.0,null,null,null,1.584962500721156,null,null,null,null,null,2.321928094887362,null,2.0,2.0,1.0,1.0,0.0,null,null,0.0,1.0,1.0,null,null,0.0,null,null,0.0,0.0,0.0,1.0,1.0,1.0,1.0,1.0,null,1.584962500721156,0.0,null,null,0.0,2.0,3.169925001442312,null,0.0,1.584962500721156,2.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,2.321928094887362,3.169925001442312,null,1.0,null,null,null,2.0,1.0,null,2.0,2.0,4.807354922057604,4.754887502163468,4.459431618637297,4.584962500721156,5.247927513443585,4.169925001442312,4.247927513443585,4.392317422778761,5.129283016944966,5.754887502163468,4.906890595608519,3.321928094887362,4.584962500721156,4.954196310386875,4.523561956057013,4.459431618637297,4.247927513443585,4.0,4.0,6.321928094887363,7.2761244052742375,6.554588851677638,5.700439718141092,6.409390936137702,6.303780748177103,5.614709844115208,4.700439718141092,4.700439718141092,4.700439718141092,4.700439718141092,6.3750394313469245,7.426264754702098,4.169925001442312,5.554588851677638,1.584962500721156,4.807354922057604,4.807354922057604,6.714245517666122,3.169925001442312,6.0,6.339850002884624,6.339850002884624,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,4.459431618637297,1.0,null,null,null,0.0,null,null,null,null,0.0,3.0,null,null,1.584962500721156,2.321928094887362,2.584962500721156,0.0,null,null,null,null,4.392317422778761,3.321928094887362,4.0,3.4594316186372973,4.321928094887363,2.321928094887362,3.0,3.0,4.0,4.087462841250339,4.954196310386875,2.0,3.0,3.9068905956085187,2.807354922057604,3.4594316186372973,2.321928094887362,3.321928094887362,3.321928094887362,5.672425341971495,5.906890595608519,5.392317422778761,4.807354922057604,5.554588851677638,5.285402218862249,4.247927513443585,3.700439718141092,3.584962500721156,3.584962500721156,3.584962500721156,4.754887502163468,5.906890595608519,null,4.807354922057604,2.807354922057604,3.584962500721156,3.700439718141092,5.169925001442312,4.392317422778761,4.523561956057013,5.044394119358453,5.044394119358453,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,4.087462841250339,2.321928094887362,null,null,null,2.807354922057604,null,null,null,null,null,3.9068905956085187,null,2.584962500721156,1.0,1.0,1.0,null,null,null,null,null,4.169925001442312,4.754887502163468,3.0,3.584962500721156,4.857980995127572,4.954196310386875,2.807354922057604,3.4594316186372973,4.247927513443585,4.954196310386875,4.700439718141092,3.0,1.584962500721156,4.392317422778761,4.392317422778761,4.321928094887363,3.169925001442312,3.0,3.0,5.882643049361842,6.189824558880018,6.20945336562895,5.169925001442312,6.149747119504682,5.247927513443585,5.700439718141092,4.643856189774724,4.584962500721156,4.584962500721156,4.584962500721156,5.832890014164741,6.94251450533924,3.807354922057604,5.20945336562895,2.807354922057604,4.643856189774724,4.643856189774724,5.357552004618084,5.807354922057604,5.700439718141092,5.459431618637297,5.459431618637297,null,null,null,null,null,0.0,null,null,null,null,null,null,0.0,null,null,1.0,null,null,null,null,4.523561956057013,1.0,null,null,null,1.584962500721156,null,null,null,null,null,2.321928094887362,0.0,1.0,2.0,1.0,1.0,1.0,null,null,null,null,0.0,1.0,null,null,null,1.0,0.0,0.0,null,4.459431618637297,null,null,2.0,null,2.0,2.0,1.584962500721156,null,null,4.0,5.357552004618084,0.0,0.0,0.0,null,1.0,null,null,null,null,null,1.0,5.857980995127572,2.584962500721156,1.0,null,null,6.409390936137702,2.321928094887362,0.0,1.584962500721156,2.0,null,null,null,0.0,null,0.0,null,null,null,0.0,0.0,null,0.0,null,null,0.0,null,null,null,2.0,3.4594316186372973,1.0,null,null,null,3.169925001442312,0.0,0.0,0.0,0.0,null,1.584962500721156,2.807354922057604,null,1.584962500721156,1.0,1.0,2.0,null,null,null,0.0,4.700439718141092,6.78135971352466,4.807354922057604,3.584962500721156,4.087462841250339,5.044394119358453,2.807354922057604,2.0,5.977279923499917,6.285402218862249,6.129283016944966,4.169925001442312,5.044394119358453,1.584962500721156,4.906890595608519,3.807354922057604,3.4594316186372973,3.0,3.0,8.294620748891626,8.807354922057604,6.832890014164741,5.977279923499917,6.614709844115208,5.523561956057013,4.906890595608519,3.807354922057604,3.807354922057604,3.807354922057604,3.584962500721156,5.78135971352466,6.820178962415188,8.124121311829187,5.614709844115208,1.0,4.523561956057013,4.523561956057013,7.247927513443585,5.169925001442312,5.584962500721156,5.20945336562895,5.321928094887363,6.247927513443585,8.487840033823051,5.554588851677638,5.523561956057013,6.189824558880018,5.523561956057013,4.643856189774724,null,7.2761244052742375,5.807354922057604,7.727920454563199,1.0,3.700439718141092,6.087462841250339,3.4594316186372973,4.754887502163468,null,5.20945336562895,5.20945336562895,9.252665432450248,9.554588851677638,8.447083226209653,7.20945336562895,8.022367813028454,7.159871336778389,6.832890014164741,5.754887502163468,5.754887502163468,5.754887502163468,5.727920454563199,7.108524456778169,8.092757140919852,9.820178962415188,6.857980995127572,3.0,6.0,6.0,8.876516946565,null,5.78135971352466,8.087462841250339,8.049848549450562,6.189824558880018,7.1799090900149345,3.807354922057604,4.247927513443585,5.087462841250339,5.285402218862249,3.807354922057604,null,6.584962500721156,6.0,6.954196310386875,1.0,2.807354922057604,4.807354922057604,4.247927513443585,4.169925001442312,0.0,3.9068905956085187,3.9068905956085187,9.108524456778168,9.39231742277876,7.339850002884624,5.700439718141092,6.285402218862249,5.754887502163468,5.554588851677638,4.643856189774724,4.643856189774724,4.643856189774724,4.584962500721156,6.087462841250339,7.108524456778169,9.546894459887637,4.523561956057013,1.584962500721156,4.700439718141092,4.700439718141092,8.434628227636725,0.0,5.882643049361842,6.066089190457772,5.954196310386875,1.584962500721156,2.807354922057604,null,null,null,null,0.0,1.584962500721156,2.321928094887362,1.584962500721156,2.0,0.0,null,null,0.0,null,1.584962500721156,null,null,1.584962500721156,3.700439718141092,2.321928094887362,1.584962500721156,2.0,2.321928094887362,2.584962500721156,1.0,1.0,1.0,1.0,2.0,2.807354922057604,4.0,1.0,0.0,null,null,2.584962500721156,null,2.0,1.0,1.584962500721156,0.0,0.0,0.0,1.0,2.807354922057604,null,null,null,null,null,null,null,null,null,1.584962500721156,3.584962500721156,null,0.0,0.0,null,2.0,null,1.0,0.0,0.0,2.321928094887362,0.0,0.0,0.0,0.0,3.807354922057604,4.906890595608519,null,null,null,1.0,1.0,null,1.584962500721156,null,1.0,1.0,null,null,null,null,0.0,null,null,null,null,0.0,2.584962500721156,null,1.0,null,null,null,null,null,null,null,2.807354922057604,1.0,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,2.0,null,null,null,null,3.0,5.0,1.0,1.0,1.0,1.0,1.0,2.807354922057604,3.4594316186372973,2.584962500721156,3.4594316186372973,1.0,2.0,0.0,2.321928094887362,null,1.584962500721156,1.584962500721156,1.584962500721156,3.0,4.321928094887363,3.9068905956085187,3.0,3.807354922057604,3.169925001442312,3.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,3.584962500721156,4.523561956057013,3.0,2.0,4.087462841250339,null,null,2.584962500721156,2.0,2.0,3.700439718141092,3.4594316186372973,0.0,2.584962500721156,1.0,1.0,0.0,3.0,0.0,1.0,2.0,2.584962500721156,1.0,null,1.584962500721156,1.0,0.0,null,null,0.0,0.0,3.4594316186372973,3.807354922057604,0.0,3.169925001442312,3.169925001442312,2.807354922057604,2.0,1.0,1.0,1.0,1.0,2.584962500721156,3.584962500721156,2.0,2.584962500721156,null,null,null,3.169925001442312,1.0,1.0,2.584962500721156,2.584962500721156,1.584962500721156,4.584962500721156,2.807354922057604,3.169925001442312,2.0,3.0,0.0,null,1.584962500721156,2.0,2.321928094887362,null,null,1.584962500721156,null,2.0,null,0.0,0.0,4.169925001442312,4.807354922057604,3.584962500721156,4.247927513443585,4.392317422778761,3.0,2.584962500721156,1.0,1.0,1.0,1.0,4.0,5.129283016944966,4.169925001442312,4.0,1.0,2.0,2.0,2.584962500721156,null,3.0,3.9068905956085187,4.0,2.321928094887362,3.169925001442312,1.0,null,1.0,null,null,null,2.321928094887362,2.807354922057604,null,null,0.0,1.584962500721156,null,1.0,null,0.0,0.0,4.754887502163468,5.169925001442312,2.0,2.321928094887362,2.807354922057604,2.584962500721156,2.321928094887362,1.0,1.0,1.0,1.0,2.321928094887362,4.169925001442312,5.169925001442312,2.584962500721156,null,null,null,5.554588851677638,null,3.0,2.0,2.321928094887362,4.321928094887363,6.507794640198696,2.584962500721156,2.321928094887362,3.0,2.321928094887362,2.807354922057604,null,5.087462841250339,3.700439718141092,4.857980995127572,1.0,2.584962500721156,4.459431618637297,2.321928094887362,1.0,0.0,3.321928094887362,3.321928094887362,7.577428828035749,7.977279923499917,5.727920454563199,4.643856189774724,5.044394119358453,4.807354922057604,4.523561956057013,3.321928094887362,3.321928094887362,3.321928094887362,3.321928094887362,4.754887502163468,5.78135971352466,8.312882955284355,3.0,1.0,4.0,4.0,7.20945336562895,0.0,4.0,5.807354922057604,5.78135971352466,4.459431618637297,7.658211482751795,3.9068905956085187,4.523561956057013,5.129283016944966,5.727920454563199,5.247927513443585,4.459431618637297,6.554588851677638,7.2761244052742375,6.392317422778761,4.169925001442312,5.357552004618084,4.0,4.321928094887363,4.643856189774724,3.700439718141092,4.247927513443585,4.247927513443585,8.326429487122303,8.7714894695006,7.700439718141092,6.658211482751795,7.03342300153745,6.714245517666122,5.882643049361842,4.906890595608519,4.906890595608519,4.906890595608519,4.906890595608519,6.643856189774724,7.679480099505446,9.273795599214264,5.169925001442312,1.0,4.700439718141092,4.700439718141092,6.807354922057604,4.459431618637297,6.3750394313469245,7.087462841250339,7.044394119358453,null,0.0,null,null,null,1.0,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,2.0,2.584962500721156,null,null,1.0,1.584962500721156,null,null,null,null,null,1.0,2.584962500721156,null,1.0,1.0,1.0,3.4594316186372973,null,1.0,null,null,4.700439718141092,4.700439718141092,null,2.0,2.584962500721156,4.754887502163468,2.807354922057604,1.0,4.321928094887363,4.392317422778761,5.169925001442312,0.0,3.169925001442312,3.584962500721156,0.0,2.584962500721156,null,1.584962500721156,1.584962500721156,4.700439718141092,5.906890595608519,5.554588851677638,4.523561956057013,5.169925001442312,3.9068905956085187,4.459431618637297,3.700439718141092,3.700439718141092,3.700439718141092,3.700439718141092,3.321928094887362,4.392317422778761,6.129283016944966,4.321928094887363,2.321928094887362,2.584962500721156,2.584962500721156,4.700439718141092,null,4.643856189774724,3.9068905956085187,3.9068905956085187,0.0,1.584962500721156,null,null,1.584962500721156,1.584962500721156,null,0.0,3.321928094887362,0.0,2.0,1.0,0.0,1.0,2.0,0.0,null,null,null,4.169925001442312,3.807354922057604,3.321928094887362,1.0,1.0,0.0,1.0,0.0,0.0,0.0,0.0,1.0,2.0,3.321928094887362,3.0,0.0,1.584962500721156,1.584962500721156,2.584962500721156,null,0.0,1.0,1.0,1.0,1.0,1.0,0.0,null,null,null,null,0.0,2.321928094887362,1.0,null,2.807354922057604,1.584962500721156,null,null,null,null,null,4.807354922057604,5.044394119358453,2.584962500721156,0.0,1.0,1.0,2.584962500721156,1.0,1.0,1.0,1.0,0.0,2.584962500721156,0.0,1.0,null,2.584962500721156,2.584962500721156,2.584962500721156,null,0.0,null,null,3.584962500721156,5.321928094887363,3.584962500721156,1.0,1.0,2.584962500721156,3.0,null,4.523561956057013,1.0,4.906890595608519,null,0.0,3.0,2.321928094887362,1.0,null,2.0,2.0,6.539158811108031,6.6865005271832185,5.614709844115208,4.392317422778761,5.0,3.321928094887362,2.807354922057604,1.584962500721156,1.584962500721156,1.584962500721156,1.0,3.584962500721156,4.857980995127572,6.918863237274595,3.584962500721156,1.0,2.0,2.0,6.409390936137702,null,4.807354922057604,4.643856189774724,4.584962500721156,3.0,3.321928094887362,null,1.0,null,1.0,null,null,4.321928094887363,3.0,4.087462841250339,null,null,1.0,0.0,null,null,1.584962500721156,1.584962500721156,5.977279923499917,6.754887502163468,3.4594316186372973,2.321928094887362,2.584962500721156,2.584962500721156,2.584962500721156,1.0,1.0,1.0,1.0,2.321928094887362,3.4594316186372973,6.507794640198696,1.0,0.0,1.0,1.0,5.672425341971495,null,1.0,3.169925001442312,3.169925001442312,0.0,2.807354922057604,null,1.0,1.0,null,null,1.0,3.0,3.321928094887362,1.584962500721156,null,null,null,1.584962500721156,2.0,1.0,0.0,0.0,3.700439718141092,4.169925001442312,3.169925001442312,1.0,0.0,2.807354922057604,1.0,0.0,0.0,0.0,0.0,0.0,2.807354922057604,5.523561956057013,1.584962500721156,1.584962500721156,2.0,2.0,3.321928094887362,null,2.321928094887362,2.321928094887362,2.321928094887362,3.0,3.807354922057604,2.584962500721156,null,1.584962500721156,3.321928094887362,2.807354922057604,null,3.700439718141092,4.459431618637297,3.0,null,1.584962500721156,3.169925001442312,2.0,1.0,null,0.0,0.0,5.930737337562887,6.066089190457772,4.643856189774724,3.700439718141092,4.459431618637297,2.584962500721156,3.0,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,3.0,4.0,6.285402218862249,1.0,0.0,3.0,3.0,6.066089190457772,null,4.169925001442312,3.700439718141092,3.584962500721156,2.321928094887362,4.857980995127572,null,1.0,1.0,1.584962500721156,1.0,null,2.584962500721156,2.807354922057604,2.584962500721156,null,null,0.0,1.584962500721156,0.0,1.0,null,null,5.357552004618084,4.392317422778761,3.807354922057604,3.169925001442312,3.321928094887362,3.321928094887362,3.169925001442312,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,3.0,4.0,6.044394119358453,2.0,1.584962500721156,null,null,5.247927513443585,null,3.321928094887362,2.807354922057604,2.807354922057604,null,2.321928094887362,null,0.0,null,1.0,null,null,0.0,null,null,null,null,1.584962500721156,0.0,1.0,null,0.0,0.0,4.169925001442312,4.392317422778761,3.169925001442312,1.0,2.0,0.0,2.0,0.0,0.0,0.0,0.0,1.0,2.321928094887362,2.0,1.0,0.0,1.0,1.0,4.0,null,1.584962500721156,2.321928094887362,2.321928094887362,2.0,6.906890595608519,2.0,2.321928094887362,0.0,1.0,null,null,1.584962500721156,2.584962500721156,2.0,3.9068905956085187,null,2.0,4.459431618637297,null,null,3.700439718141092,3.700439718141092,4.0,3.807354922057604,3.584962500721156,3.700439718141092,3.9068905956085187,5.977279923499917,1.0,0.0,0.0,0.0,0.0,2.584962500721156,3.807354922057604,4.0,2.584962500721156,null,5.247927513443585,5.247927513443585,2.0,null,2.584962500721156,6.266786540694901,6.189824558880018,5.643856189774724,7.741466986401147,4.0,3.807354922057604,4.754887502163468,4.700439718141092,null,null,6.700439718141092,6.0,6.357552004618084,1.0,3.584962500721156,5.426264754702098,4.700439718141092,3.9068905956085187,null,4.584962500721156,4.584962500721156,8.67595703294175,9.019590728357882,7.348728154231077,6.108524456778169,6.832890014164741,6.409390936137702,6.285402218862249,5.426264754702098,5.426264754702098,5.426264754702098,5.285402218862249,5.857980995127572,6.845490050944375,9.396604781181859,5.954196310386875,4.584962500721156,5.643856189774724,5.643856189774724,8.405141463136344,null,5.807354922057604,6.845490050944375,6.78135971352466,2.321928094887362,3.169925001442312,null,0.0,2.321928094887362,3.584962500721156,null,0.0,1.584962500721156,2.584962500721156,2.807354922057604,null,3.0,1.0,1.0,1.0,2.0,0.0,0.0,4.954196310386875,5.491853096329675,3.169925001442312,1.0,2.0,3.169925001442312,3.169925001442312,1.0,1.0,1.0,1.0,2.807354922057604,4.169925001442312,4.754887502163468,2.584962500721156,0.0,2.0,2.0,5.169925001442312,0.0,1.0,2.0,2.321928094887362,null,1.0,null,null,null,null,0.0,null,null,null,null,null,0.0,null,null,null,null,null,null,2.0,2.807354922057604,2.584962500721156,null,null,1.0,1.0,null,null,null,null,null,0.0,3.584962500721156,1.0,null,2.321928094887362,2.321928094887362,2.807354922057604,0.0,0.0,1.0,1.0,4.0,5.0,1.0,2.321928094887362,4.169925001442312,4.700439718141092,3.321928094887362,null,4.954196310386875,4.523561956057013,5.247927513443585,null,0.0,2.584962500721156,1.584962500721156,null,null,2.321928094887362,2.321928094887362,6.022367813028454,7.098032082960526,5.392317422778761,5.129283016944966,5.357552004618084,4.584962500721156,3.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,4.087462841250339,5.321928094887363,7.159871336778389,4.906890595608519,1.584962500721156,2.321928094887362,2.321928094887362,6.658211482751795,0.0,4.906890595608519,5.169925001442312,5.169925001442312,2.321928094887362,5.491853096329675,2.0,3.0,1.0,2.807354922057604,null,null,3.807354922057604,2.807354922057604,4.700439718141092,1.0,1.584962500721156,4.169925001442312,2.0,1.0,null,3.169925001442312,3.169925001442312,6.066089190457772,6.882643049361842,4.321928094887363,4.321928094887363,4.643856189774724,4.906890595608519,3.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,3.700439718141092,4.584962500721156,6.285402218862249,3.0,1.0,3.4594316186372973,3.4594316186372973,5.977279923499917,null,4.700439718141092,4.584962500721156,4.584962500721156,0.0,2.321928094887362,null,null,1.0,null,null,1.0,2.0,3.700439718141092,null,1.0,0.0,1.584962500721156,null,null,0.0,null,null,3.807354922057604,5.857980995127572,1.0,null,null,1.584962500721156,2.321928094887362,1.0,1.0,1.0,1.0,1.0,2.0,5.285402218862249,2.0,1.0,0.0,1.0,6.965784284662087,1.584962500721156,2.807354922057604,3.0,3.0,1.0,4.0,null,2.807354922057604,2.0,2.584962500721156,0.0,null,3.807354922057604,4.321928094887363,3.584962500721156,null,null,3.169925001442312,0.0,null,null,0.0,0.0,3.584962500721156,5.78135971352466,4.247927513443585,2.584962500721156,3.700439718141092,3.169925001442312,3.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,3.169925001442312,4.169925001442312,5.169925001442312,3.0,0.0,1.0,1.0,5.491853096329675,null,4.0,2.584962500721156,2.584962500721156,1.0,0.0,0.0,null,null,0.0,2.321928094887362,null,3.169925001442312,3.321928094887362,null,0.0,null,1.584962500721156,1.584962500721156,0.0,1.584962500721156,0.0,0.0,3.807354922057604,5.491853096329675,2.584962500721156,2.321928094887362,3.0,1.584962500721156,null,null,null,null,null,1.0,2.0,3.321928094887362,1.0,1.0,1.0,1.0,4.169925001442312,null,2.0,3.584962500721156,3.584962500721156,1.584962500721156,1.0,null,0.0,1.0,1.0,1.0,null,1.584962500721156,2.0,2.0,null,1.0,null,1.0,1.0,null,1.0,1.0,3.4594316186372973,1.584962500721156,2.807354922057604,1.0,2.321928094887362,null,2.0,1.0,1.0,1.0,1.0,1.0,2.584962500721156,null,1.0,null,0.0,0.0,3.807354922057604,null,1.0,1.584962500721156,1.0,2.0,2.0,null,null,0.0,1.0,null,null,2.584962500721156,3.584962500721156,2.584962500721156,null,1.0,1.584962500721156,null,1.0,null,1.0,1.0,3.700439718141092,5.614709844115208,3.807354922057604,2.807354922057604,3.584962500721156,2.0,1.584962500721156,0.0,0.0,0.0,0.0,3.169925001442312,4.247927513443585,5.754887502163468,2.0,0.0,1.0,1.0,5.129283016944966,null,3.584962500721156,3.321928094887362,3.321928094887362,1.584962500721156,3.321928094887362,1.0,0.0,null,null,null,0.0,2.321928094887362,1.0,2.584962500721156,null,0.0,0.0,1.0,null,null,null,null,4.523561956057013,2.807354922057604,3.584962500721156,1.584962500721156,1.584962500721156,0.0,2.0,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,null,1.0,4.321928094887363,2.584962500721156,0.0,null,null,1.0,null,null,2.584962500721156,2.584962500721156,5.169925001442312,7.679480099505446,4.0,4.906890595608519,5.087462841250339,4.700439718141092,null,null,6.357552004618084,4.087462841250339,6.672425341971495,2.0,2.584962500721156,5.584962500721156,4.169925001442312,3.169925001442312,null,3.700439718141092,3.700439718141092,8.169925001442312,8.475733430966399,7.285402218862249,6.392317422778761,7.20945336562895,6.409390936137702,6.20945336562895,5.0,5.0,5.0,5.0,6.930737337562887,7.9886846867721655,8.357552004618084,5.426264754702098,null,4.857980995127572,4.857980995127572,7.523561956057013,1.584962500721156,5.459431618637297,6.475733430966398,6.459431618637297,5.129283016944966,6.022367813028454,3.807354922057604,3.169925001442312,3.584962500721156,4.643856189774724,0.0,null,5.357552004618084,3.0,5.930737337562887,2.584962500721156,1.0,4.459431618637297,2.0,3.4594316186372973,null,3.321928094887362,3.321928094887362,7.864186144654281,8.388017285345136,6.832890014164741,5.169925001442312,5.882643049361842,5.954196310386875,5.954196310386875,4.954196310386875,4.954196310386875,4.954196310386875,4.954196310386875,5.727920454563199,6.845490050944375,7.882643049361842,5.491853096329675,3.0,4.321928094887363,4.321928094887363,7.321928094887363,null,1.0,6.285402218862249,6.266786540694901,3.169925001442312,3.321928094887362,2.584962500721156,2.807354922057604,2.807354922057604,4.459431618637297,2.321928094887362,1.584962500721156,4.392317422778761,5.357552004618084,3.807354922057604,1.0,3.584962500721156,4.0,2.0,2.584962500721156,2.0,2.807354922057604,2.807354922057604,6.700439718141092,6.614709844115208,4.584962500721156,4.247927513443585,4.392317422778761,4.087462841250339,2.321928094887362,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,4.247927513443585,5.20945336562895,4.169925001442312,4.0,null,3.321928094887362,3.321928094887362,6.0,null,4.321928094887363,5.129283016944966,5.087462841250339,5.087462841250339,6.554588851677638,3.4594316186372973,3.584962500721156,4.169925001442312,4.0,4.643856189774724,null,5.0,null,4.643856189774724,0.0,1.0,4.321928094887363,2.807354922057604,2.0,null,3.584962500721156,3.584962500721156,6.303780748177103,6.3750394313469245,5.882643049361842,5.129283016944966,5.882643049361842,5.554588851677638,5.614709844115208,4.643856189774724,4.643856189774724,4.643856189774724,4.643856189774724,5.491853096329675,6.569855608330948,7.169925001442312,4.906890595608519,null,2.584962500721156,2.584962500721156,6.0,0.0,5.523561956057013,5.807354922057604,5.78135971352466,0.0,3.0,null,0.0,0.0,null,null,null,2.0,0.0,null,null,null,1.0,1.0,null,null,0.0,0.0,1.0,0.0,3.4594316186372973,1.0,1.0,null,0.0,null,null,null,null,2.0,3.0,3.169925001442312,null,null,1.0,1.0,3.4594316186372973,null,null,0.0,0.0,2.0,2.321928094887362,2.0,0.0,1.0,2.0,0.0,null,2.321928094887362,1.0,2.584962500721156,null,1.0,0.0,null,1.0,1.0,null,null,4.247927513443585,4.459431618637297,3.700439718141092,2.321928094887362,2.807354922057604,3.169925001442312,4.0,2.807354922057604,2.807354922057604,2.807354922057604,2.807354922057604,2.321928094887362,3.321928094887362,4.0,1.0,1.584962500721156,3.169925001442312,3.169925001442312,3.584962500721156,null,1.0,2.0,2.584962500721156,1.584962500721156,1.0,null,0.0,null,null,null,1.0,1.584962500721156,1.584962500721156,1.0,1.0,null,null,0.0,null,null,null,null,3.584962500721156,4.523561956057013,2.321928094887362,1.584962500721156,2.584962500721156,0.0,null,null,null,null,null,1.0,2.0,2.584962500721156,1.0,0.0,null,null,2.584962500721156,null,1.584962500721156,2.807354922057604,2.807354922057604,1.0,3.169925001442312,null,0.0,null,1.0,0.0,null,2.321928094887362,1.584962500721156,null,null,0.0,2.807354922057604,0.0,null,null,1.584962500721156,1.584962500721156,4.584962500721156,4.954196310386875,3.169925001442312,1.584962500721156,2.584962500721156,2.0,2.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.0,null,2.321928094887362,4.584962500721156,2.584962500721156,0.0,0.0,0.0,2.0,null,1.0,2.321928094887362,2.321928094887362,3.0,4.584962500721156,2.0,2.0,3.0,2.584962500721156,null,null,4.392317422778761,3.321928094887362,4.392317422778761,null,0.0,4.247927513443585,1.584962500721156,3.0,null,2.0,2.0,6.066089190457772,6.129283016944966,4.807354922057604,3.807354922057604,4.392317422778761,3.9068905956085187,4.523561956057013,3.169925001442312,3.169925001442312,3.169925001442312,3.169925001442312,4.169925001442312,5.20945336562895,6.727920454563199,3.4594316186372973,1.0,2.321928094887362,2.584962500721156,5.754887502163468,null,3.4594316186372973,5.0,4.857980995127572,0.0,2.0,2.0,0.0,null,null,null,null,null,0.0,1.0,null,0.0,null,0.0,1.0,null,1.0,1.0,2.584962500721156,2.321928094887362,2.807354922057604,1.584962500721156,2.321928094887362,0.0,1.584962500721156,null,null,null,null,1.584962500721156,2.807354922057604,4.0,0.0,0.0,null,null,3.700439718141092,null,null,null,0.0,null,3.0,1.584962500721156,null,null,1.0,null,null,2.0,1.0,1.0,null,0.0,0.0,0.0,null,null,0.0,0.0,3.321928094887362,4.169925001442312,1.0,0.0,1.584962500721156,1.0,1.584962500721156,0.0,0.0,0.0,0.0,2.0,3.169925001442312,3.807354922057604,2.0,null,null,null,3.0,null,1.0,2.321928094887362,2.321928094887362,null,1.0,null,null,null,0.0,null,null,null,0.0,null,null,0.0,1.0,null,null,null,null,null,2.321928094887362,2.584962500721156,null,null,null,2.0,1.0,null,null,null,null,0.0,1.0,2.0,0.0,null,null,null,4.087462841250339,null,null,null,null,null,0.0,1.0,null,null,2.0,null,null,2.0,null,4.643856189774724,null,1.0,null,null,null,null,null,null,0.0,5.357552004618084,null,null,null,0.0,3.169925001442312,2.0,2.0,2.0,2.0,null,2.584962500721156,3.0,1.0,1.0,3.807354922057604,3.807354922057604,5.700439718141092,null,null,0.0,1.0,6.169925001442312,7.965784284662087,5.554588851677638,5.247927513443585,6.20945336562895,5.247927513443585,null,1.584962500721156,6.754887502163468,4.523561956057013,6.523561956057013,4.169925001442312,4.087462841250339,6.22881869049588,3.4594316186372973,3.584962500721156,0.0,5.614709844115208,5.614709844115208,8.405141463136344,9.211888294546004,8.312882955284355,6.599912842187128,7.924812503605781,7.108524456778169,6.727920454563199,6.0,6.0,6.0,5.977279923499917,6.539158811108031,7.584962500721156,8.927777962082342,6.266786540694901,1.0,5.491853096329675,5.491853096329675,7.6653359171851765,null,7.159871336778389,7.577428828035749,7.562242424221073,5.882643049361842,7.247927513443585,3.807354922057604,4.523561956057013,5.20945336562895,5.357552004618084,5.247927513443585,null,6.768184324776926,4.459431618637297,5.643856189774724,null,2.807354922057604,5.321928094887363,4.643856189774724,3.169925001442312,null,3.9068905956085187,3.9068905956085187,8.312882955284355,9.030667136246942,7.459431618637297,6.22881869049588,7.257387842692652,6.672425341971495,5.700439718141092,4.857980995127572,4.807354922057604,4.807354922057604,4.807354922057604,6.087462841250339,7.118941072723508,8.550746785383243,4.954196310386875,0.0,5.392317422778761,5.426264754702098,7.906890595608519,0.0,5.727920454563199,6.768184324776926,6.754887502163468,2.0,4.0,null,1.584962500721156,1.0,1.0,2.321928094887362,1.0,3.9068905956085187,1.0,2.584962500721156,2.807354922057604,2.584962500721156,null,2.321928094887362,3.321928094887362,2.0,1.584962500721156,1.584962500721156,5.882643049361842,6.6293566200796095,3.169925001442312,3.700439718141092,3.9068905956085187,2.584962500721156,2.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,2.321928094887362,3.700439718141092,5.754887502163468,2.0,1.0,2.0,2.0,5.754887502163468,0.0,3.321928094887362,2.807354922057604,3.0,3.4594316186372973,4.700439718141092,1.584962500721156,1.584962500721156,1.0,2.584962500721156,1.0,null,4.0,null,3.807354922057604,null,0.0,2.584962500721156,1.584962500721156,null,null,2.321928094887362,2.321928094887362,5.044394119358453,5.459431618637297,4.906890595608519,2.321928094887362,3.9068905956085187,3.9068905956085187,3.807354922057604,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,3.321928094887362,4.700439718141092,5.247927513443585,2.321928094887362,0.0,1.0,1.0,4.169925001442312,null,3.169925001442312,4.643856189774724,4.643856189774724,3.0,1.0,0.0,1.584962500721156,2.584962500721156,null,0.0,0.0,3.321928094887362,4.247927513443585,2.0,1.0,3.169925001442312,2.321928094887362,2.0,2.807354922057604,1.584962500721156,null,null,4.459431618637297,5.321928094887363,2.807354922057604,2.584962500721156,3.0,3.0,4.169925001442312,3.169925001442312,3.169925001442312,3.169925001442312,3.169925001442312,2.321928094887362,3.4594316186372973,4.700439718141092,2.321928094887362,1.0,3.807354922057604,3.807354922057604,5.754887502163468,2.0,2.807354922057604,2.0,2.0,0.0,4.392317422778761,null,null,0.0,4.169925001442312,null,null,3.700439718141092,2.807354922057604,2.584962500721156,1.0,0.0,null,null,0.0,0.0,2.584962500721156,2.584962500721156,4.807354922057604,6.149747119504682,4.700439718141092,1.584962500721156,2.0,2.584962500721156,2.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,2.807354922057604,7.05528243550119,3.0,0.0,2.584962500721156,2.584962500721156,6.087462841250339,0.0,3.0,2.584962500721156,2.321928094887362,2.584962500721156,2.0,1.0,0.0,null,2.0,2.807354922057604,null,3.321928094887362,2.807354922057604,3.584962500721156,null,null,2.321928094887362,0.0,null,null,null,null,5.491853096329675,5.285402218862249,3.584962500721156,2.321928094887362,3.0,3.0,2.0,1.0,1.0,1.0,1.0,2.0,3.4594316186372973,5.882643049361842,null,0.0,1.0,1.0,5.392317422778761,0.0,2.807354922057604,4.087462841250339,4.087462841250339,4.321928094887363,6.044394119358453,3.0,3.321928094887362,2.321928094887362,4.459431618637297,3.4594316186372973,0.0,4.906890595608519,4.906890595608519,4.700439718141092,null,3.169925001442312,4.169925001442312,0.0,3.807354922057604,1.584962500721156,4.0,4.0,6.807354922057604,7.011227255423254,4.857980995127572,2.584962500721156,3.169925001442312,5.247927513443585,4.459431618637297,3.807354922057604,3.807354922057604,3.807354922057604,3.700439718141092,4.392317422778761,5.491853096329675,8.199672344836364,4.754887502163468,2.807354922057604,4.807354922057604,4.857980995127572,7.199672344836364,2.584962500721156,4.700439718141092,4.643856189774724,4.523561956057013,3.700439718141092,4.169925001442312,1.0,0.0,2.0,1.0,1.0,null,4.247927513443585,2.321928094887362,4.0,null,null,1.584962500721156,null,0.0,null,2.0,2.0,5.614709844115208,6.554588851677638,4.857980995127572,4.087462841250339,4.700439718141092,3.807354922057604,3.4594316186372973,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,3.584962500721156,5.857980995127572,2.584962500721156,null,null,null,5.754887502163468,0.0,3.0,4.523561956057013,4.459431618637297,2.584962500721156,3.4594316186372973,1.0,0.0,1.0,0.0,0.0,null,3.4594316186372973,1.584962500721156,2.0,null,0.0,1.0,null,null,null,null,null,3.9068905956085187,5.247927513443585,4.0,2.321928094887362,3.169925001442312,2.584962500721156,3.0,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,2.321928094887362,3.321928094887362,5.643856189774724,2.0,0.0,null,0.0,4.247927513443585,null,1.0,2.807354922057604,2.807354922057604,1.0,3.700439718141092,null,0.0,0.0,0.0,null,null,2.807354922057604,1.584962500721156,3.321928094887362,1.584962500721156,0.0,2.0,1.0,1.0,null,null,null,3.9068905956085187,6.0,3.4594316186372973,2.584962500721156,3.4594316186372973,3.0,1.0,0.0,0.0,0.0,0.0,2.321928094887362,3.4594316186372973,5.169925001442312,2.0,2.0,null,null,4.321928094887363,0.0,2.584962500721156,3.0,3.0,null,0.0,null,null,null,0.0,null,null,0.0,null,null,1.584962500721156,null,null,null,0.0,null,null,null,0.0,4.087462841250339,1.0,null,0.0,1.0,2.0,null,null,null,null,0.0,2.584962500721156,3.584962500721156,3.169925001442312,1.584962500721156,1.0,1.0,3.9068905956085187,null,2.0,null,null,2.321928094887362,4.906890595608519,2.321928094887362,1.584962500721156,2.321928094887362,4.169925001442312,3.0,1.584962500721156,4.087462841250339,3.321928094887362,3.4594316186372973,2.584962500721156,1.0,0.0,3.4594316186372973,3.4594316186372973,3.0,2.321928094887362,2.321928094887362,6.0,6.475733430966398,4.523561956057013,3.4594316186372973,4.0,3.321928094887362,1.584962500721156,0.0,0.0,0.0,0.0,3.9068905956085187,5.0,6.569855608330948,3.700439718141092,1.0,1.584962500721156,1.584962500721156,4.0,4.523561956057013,2.584962500721156,4.321928094887363,4.392317422778761,3.700439718141092,3.0,2.584962500721156,1.584962500721156,2.807354922057604,2.584962500721156,2.807354922057604,null,5.129283016944966,4.807354922057604,4.321928094887363,null,2.321928094887362,4.584962500721156,2.584962500721156,null,0.0,2.321928094887362,2.321928094887362,6.614709844115208,7.562242424221073,4.523561956057013,3.700439718141092,4.0,4.087462841250339,4.754887502163468,3.807354922057604,3.807354922057604,3.807354922057604,3.700439718141092,3.807354922057604,4.857980995127572,7.774787059601174,3.0,1.584962500721156,1.0,1.0,6.870364719583405,null,4.169925001442312,4.321928094887363,4.169925001442312,6.0,7.03342300153745,4.459431618637297,4.459431618637297,5.044394119358453,4.807354922057604,3.169925001442312,null,6.6293566200796095,5.672425341971495,6.475733430966398,2.0,1.584962500721156,5.584962500721156,4.392317422778761,4.392317422778761,0.0,4.169925001442312,4.169925001442312,8.625708843064466,8.778077129535358,7.599912842187128,6.442943495848728,7.044394119358453,6.129283016944966,6.044394119358453,4.954196310386875,4.954196310386875,4.954196310386875,4.954196310386875,6.189824558880018,7.22881869049588,9.63117705570398,5.882643049361842,0.0,5.357552004618084,5.357552004618084,7.2761244052742375,0.0,4.954196310386875,7.149747119504682,7.108524456778169,0.0,null,1.0,0.0,1.0,null,null,null,1.584962500721156,null,1.0,1.0,null,0.0,null,null,null,null,null,2.321928094887362,3.321928094887362,1.0,1.0,1.0,1.584962500721156,null,null,null,null,null,null,null,3.321928094887362,null,null,null,null,3.0,null,null,null,null,1.584962500721156,4.321928094887363,null,1.584962500721156,2.584962500721156,2.584962500721156,1.0,null,4.247927513443585,3.4594316186372973,null,null,0.0,2.584962500721156,0.0,null,0.0,2.0,2.0,5.78135971352466,5.129283016944966,3.9068905956085187,2.321928094887362,3.584962500721156,3.584962500721156,4.0,2.807354922057604,2.807354922057604,2.807354922057604,2.807354922057604,2.321928094887362,3.700439718141092,5.523561956057013,3.0,null,2.584962500721156,2.584962500721156,4.169925001442312,2.807354922057604,3.807354922057604,3.9068905956085187,3.9068905956085187,null,2.321928094887362,null,0.0,0.0,null,null,null,2.321928094887362,1.584962500721156,2.0,null,null,null,null,null,null,null,null,3.0,4.584962500721156,3.0,1.0,1.0,2.0,1.584962500721156,1.0,1.0,1.0,1.0,2.0,2.807354922057604,4.459431618637297,null,1.584962500721156,null,null,4.523561956057013,null,1.0,2.584962500721156,2.584962500721156,1.584962500721156,4.0,null,0.0,1.0,2.0,null,null,3.4594316186372973,1.0,1.0,null,1.0,1.584962500721156,0.0,null,null,0.0,0.0,3.4594316186372973,5.930737337562887,3.807354922057604,3.4594316186372973,3.9068905956085187,3.4594316186372973,2.0,0.0,0.0,0.0,0.0,1.584962500721156,2.584962500721156,5.584962500721156,2.584962500721156,0.0,2.0,2.0,1.0,null,1.0,2.584962500721156,2.584962500721156,2.584962500721156,4.643856189774724,1.0,0.0,2.0,2.584962500721156,0.0,null,2.807354922057604,null,3.584962500721156,null,null,0.0,1.0,null,null,1.584962500721156,1.584962500721156,4.087462841250339,5.357552004618084,4.459431618637297,3.169925001442312,3.4594316186372973,3.584962500721156,3.169925001442312,2.0,2.0,2.0,2.0,3.807354922057604,4.906890595608519,4.584962500721156,3.169925001442312,null,1.0,1.0,4.807354922057604,0.0,4.0,4.169925001442312,4.087462841250339,1.0,4.169925001442312,1.0,1.0,2.0,1.0,null,0.0,2.321928094887362,0.0,2.584962500721156,null,1.0,0.0,2.807354922057604,2.0,0.0,0.0,0.0,1.584962500721156,3.807354922057604,3.321928094887362,2.584962500721156,3.169925001442312,3.321928094887362,3.169925001442312,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,3.584962500721156,4.754887502163468,2.807354922057604,2.807354922057604,null,3.0,3.0,2.0,2.321928094887362,3.169925001442312,3.169925001442312,2.807354922057604,1.0,1.0,2.584962500721156,0.0,1.0,2.0,null,1.584962500721156,1.584962500721156,1.0,null,null,2.0,null,0.0,2.0,1.0,1.0,1.0,2.321928094887362,3.9068905956085187,2.584962500721156,1.0,2.0,2.321928094887362,2.0,0.0,0.0,0.0,0.0,2.0,3.321928094887362,null,null,null,1.584962500721156,1.584962500721156,3.4594316186372973,null,1.0,2.321928094887362,2.0,null,0.0,null,null,1.0,null,0.0,null,1.0,null,null,null,null,null,null,null,null,null,null,null,2.321928094887362,1.0,null,1.0,1.0,1.584962500721156,1.0,1.0,1.0,1.0,0.0,1.584962500721156,null,null,null,2.0,2.0,2.0,null,null,0.0,0.0,4.459431618637297,5.906890595608519,3.807354922057604,4.523561956057013,4.087462841250339,4.700439718141092,4.087462841250339,3.4594316186372973,4.807354922057604,4.523561956057013,5.554588851677638,3.584962500721156,4.584962500721156,3.584962500721156,3.807354922057604,4.954196310386875,2.584962500721156,3.0,3.0,6.426264754702098,6.6293566200796095,6.672425341971495,5.044394119358453,5.807354922057604,5.392317422778761,5.321928094887363,4.169925001442312,4.169925001442312,4.169925001442312,4.169925001442312,5.754887502163468,6.930737337562887,7.321928094887363,5.357552004618084,1.584962500721156,4.807354922057604,4.807354922057604,4.247927513443585,null,5.247927513443585,5.754887502163468,5.700439718141092,0.0,3.169925001442312,1.0,1.584962500721156,1.584962500721156,2.584962500721156,null,null,3.169925001442312,1.0,1.0,null,null,2.321928094887362,null,2.321928094887362,null,0.0,0.0,2.807354922057604,5.044394119358453,4.754887502163468,1.0,2.0,2.0,3.584962500721156,0.0,0.0,0.0,0.0,2.321928094887362,3.584962500721156,3.9068905956085187,3.584962500721156,2.0,1.0,1.0,3.700439718141092,1.584962500721156,null,2.807354922057604,2.807354922057604,3.584962500721156,6.22881869049588,3.321928094887362,5.0,5.169925001442312,1.0,1.0,null,4.0,0.0,5.321928094887363,1.0,2.0,2.807354922057604,2.0,3.0,0.0,3.321928094887362,3.321928094887362,5.554588851677638,5.357552004618084,5.672425341971495,4.247927513443585,5.044394119358453,5.882643049361842,4.700439718141092,3.584962500721156,3.584962500721156,3.584962500721156,3.584962500721156,6.409390936137702,7.392317422778761,6.169925001442312,4.0,3.169925001442312,4.169925001442312,4.169925001442312,5.20945336562895,0.0,5.169925001442312,6.169925001442312,6.066089190457772,4.643856189774724,6.442943495848728,4.954196310386875,4.087462841250339,4.643856189774724,4.954196310386875,2.321928094887362,3.0,5.247927513443585,3.584962500721156,4.807354922057604,3.321928094887362,4.247927513443585,0.0,5.0,4.392317422778761,3.0,4.247927513443585,4.247927513443585,5.78135971352466,6.845490050944375,6.475733430966398,5.044394119358453,5.882643049361842,5.930737337562887,4.321928094887363,3.169925001442312,3.169925001442312,3.169925001442312,3.169925001442312,5.392317422778761,6.459431618637297,5.523561956057013,4.523561956057013,3.4594316186372973,5.247927513443585,5.247927513443585,6.303780748177103,1.584962500721156,5.392317422778761,6.189824558880018,6.189824558880018,4.584962500721156,4.392317422778761,4.754887502163468,3.700439718141092,4.459431618637297,3.169925001442312,3.807354922057604,3.700439718141092,5.044394119358453,4.392317422778761,4.321928094887363,1.0,4.392317422778761,3.9068905956085187,3.807354922057604,3.9068905956085187,3.584962500721156,2.807354922057604,2.807354922057604,5.285402218862249,5.857980995127572,6.442943495848728,4.954196310386875,5.643856189774724,5.426264754702098,4.857980995127572,3.9068905956085187,3.9068905956085187,3.9068905956085187,3.807354922057604,5.554588851677638,6.569855608330948,5.087462841250339,4.906890595608519,1.584962500721156,4.169925001442312,4.169925001442312,4.392317422778761,null,4.247927513443585,5.754887502163468,5.614709844115208,2.321928094887362,4.087462841250339,1.0,1.584962500721156,0.0,1.0,null,0.0,1.0,2.0,1.0,1.0,null,1.0,null,null,null,0.0,0.0,3.807354922057604,4.169925001442312,3.700439718141092,2.807354922057604,3.0,2.321928094887362,2.0,null,null,null,null,2.807354922057604,4.087462841250339,5.129283016944966,null,null,2.0,2.0,3.169925001442312,0.0,3.0,3.0,3.0,3.321928094887362,3.0,3.0,2.321928094887362,2.584962500721156,1.584962500721156,2.584962500721156,1.0,3.584962500721156,2.807354922057604,3.807354922057604,null,3.807354922057604,0.0,2.807354922057604,3.807354922057604,1.0,1.0,1.0,2.584962500721156,4.643856189774724,3.807354922057604,4.0,4.584962500721156,3.807354922057604,3.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,4.0,4.906890595608519,null,2.0,null,1.584962500721156,1.584962500721156,2.321928094887362,null,3.169925001442312,4.321928094887363,4.169925001442312,2.807354922057604,2.321928094887362,1.0,0.0,1.0,2.321928094887362,1.584962500721156,null,1.584962500721156,2.584962500721156,3.169925001442312,2.0,null,2.584962500721156,1.0,3.0,1.584962500721156,0.0,0.0,3.0,3.321928094887362,4.247927513443585,3.0,3.807354922057604,3.321928094887362,4.0,3.169925001442312,3.169925001442312,3.169925001442312,3.169925001442312,3.700439718141092,4.584962500721156,2.0,2.584962500721156,null,1.0,1.0,4.169925001442312,null,2.584962500721156,3.9068905956085187,4.0,3.0,4.857980995127572,2.584962500721156,2.0,3.0,3.0,null,null,3.4594316186372973,1.0,3.169925001442312,null,1.0,3.584962500721156,2.584962500721156,null,0.0,1.584962500721156,1.584962500721156,4.523561956057013,4.954196310386875,3.807354922057604,3.584962500721156,3.807354922057604,3.4594316186372973,3.4594316186372973,2.584962500721156,2.584962500721156,2.584962500721156,2.321928094887362,4.169925001442312,5.247927513443585,4.700439718141092,3.584962500721156,0.0,2.584962500721156,2.584962500721156,3.9068905956085187,0.0,3.169925001442312,3.169925001442312,3.169925001442312,2.0,3.584962500721156,1.0,0.0,0.0,0.0,0.0,null,2.0,null,3.321928094887362,null,null,null,1.584962500721156,1.0,null,0.0,0.0,2.0,3.169925001442312,2.584962500721156,2.0,2.321928094887362,1.584962500721156,null,null,null,null,null,1.584962500721156,2.584962500721156,3.4594316186372973,2.321928094887362,null,2.0,2.0,3.807354922057604,null,null,2.807354922057604,2.584962500721156,2.807354922057604,1.584962500721156,null,null,1.0,null,null,0.0,2.584962500721156,1.584962500721156,2.584962500721156,null,0.0,0.0,1.0,0.0,null,1.0,1.0,2.584962500721156,3.584962500721156,3.700439718141092,2.321928094887362,3.0,1.584962500721156,1.584962500721156,0.0,0.0,0.0,0.0,2.807354922057604,4.0,2.584962500721156,0.0,0.0,2.0,2.0,3.321928094887362,0.0,1.0,1.0,0.0,null,null,null,null,null,null,null,null,null,0.0,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,0.0,1.584962500721156,null,1.0,0.0,2.0,2.0,1.0,null,null,null,null,3.807354922057604,5.643856189774724,2.0,3.321928094887362,3.700439718141092,3.584962500721156,3.4594316186372973,null,3.9068905956085187,2.0,5.169925001442312,2.0,2.321928094887362,3.807354922057604,2.321928094887362,1.584962500721156,null,2.584962500721156,2.584962500721156,5.426264754702098,6.189824558880018,5.392317422778761,4.0,4.643856189774724,3.9068905956085187,4.459431618637297,3.0,3.0,3.0,2.807354922057604,4.584962500721156,5.832890014164741,5.672425341971495,4.700439718141092,2.584962500721156,2.584962500721156,2.584962500721156,3.0,null,4.906890595608519,4.906890595608519,4.954196310386875,8.758223214726724,10.537218400538595,7.954196310386875,8.348728154231077,8.60733031374961,8.159871336778389,null,7.599912842187128,9.044394119358454,8.62935662007961,9.758223214726724,8.027905996569885,8.08214904135387,8.038918989292302,8.262094845370179,7.787902559391432,7.294620748891627,7.392317422778761,7.392317422778761,10.029287226968245,10.489847960439297,10.28886607416582,9.491853096329674,10.064742764750257,9.62935662007961,9.505811553919594,8.471675214392045,8.471675214392045,8.471675214392045,8.451211111832329,9.768184324776927,10.810571634741146,10.022367813028454,9.139551352398794,4.087462841250339,8.383704292474052,8.383704292474052,8.888743248898258,9.370687406807217,9.588714635582264,9.815383295813538,9.820178962415188,1.584962500721156,3.169925001442312,2.0,2.321928094887362,3.321928094887362,3.0,null,null,3.807354922057604,3.9068905956085187,1.584962500721156,1.0,0.0,2.584962500721156,1.0,3.700439718141092,null,3.0,3.0,4.247927513443585,4.247927513443585,3.4594316186372973,2.321928094887362,3.4594316186372973,3.4594316186372973,3.321928094887362,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,3.807354922057604,5.044394119358453,4.807354922057604,1.584962500721156,3.0,1.584962500721156,1.584962500721156,3.700439718141092,0.0,3.321928094887362,3.169925001442312,3.169925001442312,5.584962500721156,7.417852514885898,5.0,4.700439718141092,5.285402218862249,5.459431618637297,null,0.0,5.700439718141092,3.584962500721156,5.700439718141092,2.0,2.321928094887362,5.044394119358453,4.0,4.459431618637297,null,4.700439718141092,4.700439718141092,6.523561956057013,6.832890014164741,6.9886846867721655,6.22881869049588,6.794415866350106,6.087462841250339,6.303780748177103,5.20945336562895,5.20945336562895,5.20945336562895,5.169925001442312,6.475733430966398,7.434628227636725,7.129283016944966,5.584962500721156,0.0,5.700439718141092,5.700439718141092,6.266786540694901,null,5.882643049361842,5.807354922057604,5.78135971352466,5.906890595608519,7.7481928495894605,5.20945336562895,4.700439718141092,5.857980995127572,5.426264754702098,null,1.0,5.727920454563199,3.700439718141092,5.554588851677638,0.0,2.0,5.357552004618084,5.044394119358453,3.0,1.0,3.9068905956085187,3.9068905956085187,6.3750394313469245,7.507794640198696,7.076815597050831,6.087462841250339,7.022367813028454,6.714245517666122,6.303780748177103,5.357552004618084,5.357552004618084,5.357552004618084,5.357552004618084,6.409390936137702,7.491853096329675,7.491853096329675,4.906890595608519,1.584962500721156,4.584962500721156,4.584962500721156,6.78135971352466,0.0,5.044394119358453,6.087462841250339,6.022367813028454,null,0.0,2.321928094887362,1.0,null,null,null,null,1.584962500721156,null,1.0,null,null,1.584962500721156,0.0,1.0,null,0.0,0.0,null,1.0,3.169925001442312,0.0,0.0,1.584962500721156,0.0,null,null,null,null,0.0,0.0,2.321928094887362,null,0.0,1.0,1.0,2.0,null,null,2.0,1.0,2.807354922057604,5.247927513443585,3.0,2.807354922057604,null,2.0,null,null,3.584962500721156,1.584962500721156,3.9068905956085187,null,null,3.584962500721156,2.807354922057604,2.0,0.0,1.584962500721156,1.584962500721156,3.9068905956085187,4.584962500721156,4.321928094887363,4.087462841250339,4.700439718141092,4.169925001442312,3.4594316186372973,2.0,2.0,2.0,2.0,4.392317422778761,5.357552004618084,4.700439718141092,4.392317422778761,0.0,2.0,2.0,3.584962500721156,null,3.584962500721156,3.700439718141092,3.700439718141092,3.0,4.906890595608519,3.0,null,2.0,null,1.584962500721156,null,2.807354922057604,2.321928094887362,3.321928094887362,1.584962500721156,1.584962500721156,2.321928094887362,1.0,1.584962500721156,null,1.0,1.0,4.087462841250339,5.087462841250339,3.9068905956085187,3.321928094887362,4.0,3.169925001442312,3.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,2.807354922057604,3.807354922057604,4.0,2.584962500721156,null,2.584962500721156,2.584962500721156,4.247927513443585,0.0,3.4594316186372973,2.0,2.0,null,0.0,0.0,null,null,1.0,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,2.584962500721156,null,0.0,0.0,null,null,null,null,null,null,0.0,1.0,null,1.584962500721156,null,null,null,null,null,0.0,null,0.0,1.0,1.584962500721156,1.0,null,null,0.0,null,null,0.0,null,null,null,null,null,0.0,null,null,null,null,null,null,2.807354922057604,1.0,2.584962500721156,null,1.584962500721156,0.0,0.0,0.0,0.0,null,0.0,2.584962500721156,1.0,null,1.0,1.0,1.0,null,null,null,0.0,2.321928094887362,3.9068905956085187,1.0,1.0,0.0,2.584962500721156,null,null,3.4594316186372973,null,1.0,null,0.0,1.0,1.584962500721156,1.0,null,2.0,2.0,3.169925001442312,4.754887502163468,4.087462841250339,3.169925001442312,3.700439718141092,2.321928094887362,3.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,2.584962500721156,3.700439718141092,4.857980995127572,4.169925001442312,3.169925001442312,null,3.0,3.0,4.247927513443585,null,2.0,2.584962500721156,2.321928094887362,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,0.0,null,null,null,null,null,0.0,null,null,null,null,null,1.584962500721156,null,null,null,1.0,1.0,null,null,null,0.0,0.0,4.643856189774724,2.0,2.807354922057604,3.4594316186372973,4.247927513443585,3.9068905956085187,3.4594316186372973,2.584962500721156,5.0,6.409390936137702,6.303780748177103,4.0,4.087462841250339,4.700439718141092,5.247927513443585,3.807354922057604,4.247927513443585,3.4594316186372973,3.4594316186372973,6.906890595608519,7.22881869049588,5.700439718141092,4.584962500721156,4.754887502163468,4.643856189774724,5.523561956057013,4.392317422778761,4.392317422778761,4.392317422778761,4.392317422778761,5.129283016944966,6.20945336562895,4.0,4.643856189774724,2.0,4.321928094887363,4.321928094887363,6.523561956057013,null,3.584962500721156,4.754887502163468,4.700439718141092,5.392317422778761,3.4594316186372973,3.9068905956085187,4.087462841250339,4.523561956057013,4.523561956057013,3.700439718141092,3.9068905956085187,5.491853096329675,6.189824558880018,6.700439718141092,4.584962500721156,4.643856189774724,5.20945336562895,3.9068905956085187,3.321928094887362,4.754887502163468,2.807354922057604,2.807354922057604,6.768184324776926,7.1799090900149345,6.9886846867721655,6.108524456778169,6.392317422778761,4.700439718141092,6.266786540694901,5.20945336562895,5.20945336562895,5.20945336562895,5.20945336562895,5.247927513443585,6.247927513443585,2.0,5.754887502163468,1.584962500721156,3.807354922057604,3.807354922057604,6.20945336562895,null,5.584962500721156,3.700439718141092,3.700439718141092,6.247927513443585,5.321928094887363,5.700439718141092,5.930737337562887,6.20945336562895,6.247927513443585,5.832890014164741,5.426264754702098,6.906890595608519,7.98299357469431,8.383704292474052,6.507794640198696,6.066089190457772,6.554588851677638,6.475733430966398,6.129283016944966,5.321928094887363,5.357552004618084,5.357552004618084,8.632995197142957,9.400879436282183,8.294620748891626,7.491853096329675,8.071462362556623,7.294620748891627,7.515699838284043,6.426264754702098,6.426264754702098,6.392317422778761,6.321928094887363,7.417852514885898,8.467605550082997,6.22881869049588,7.05528243550119,3.0,5.906890595608519,5.906890595608519,7.7073591320808825,4.754887502163468,6.475733430966398,7.491853096329675,7.467605550082998,5.0,4.169925001442312,4.459431618637297,3.4594316186372973,4.700439718141092,4.700439718141092,4.321928094887363,3.169925001442312,5.129283016944966,6.584962500721156,6.303780748177103,4.247927513443585,4.247927513443585,5.459431618637297,5.087462841250339,4.459431618637297,3.700439718141092,3.584962500721156,3.584962500721156,7.417852514885898,7.930737337562887,6.569855608330948,6.247927513443585,6.442943495848728,5.727920454563199,5.882643049361842,4.754887502163468,4.754887502163468,4.754887502163468,4.754887502163468,5.882643049361842,6.906890595608519,5.523561956057013,5.169925001442312,2.0,4.392317422778761,4.392317422778761,5.857980995127572,null,5.087462841250339,4.754887502163468,4.754887502163468,6.6293566200796095,5.426264754702098,6.169925001442312,6.507794640198696,6.918863237274595,6.569855608330948,6.0,5.727920454563199,7.515699838284043,8.447083226209653,8.734709620225837,6.78135971352466,6.339850002884624,7.247927513443585,6.832890014164741,6.614709844115208,6.247927513443585,5.672425341971495,5.672425341971495,9.688250309133178,9.893301530860564,8.252665432450248,7.2384047393250786,7.813781191217037,7.577428828035749,7.924812503605781,6.845490050944375,6.820178962415188,6.820178962415188,6.820178962415188,8.118941072723507,9.162391328756906,6.977279923499917,7.199672344836364,4.087462841250339,6.700439718141092,6.700439718141092,8.005624549193879,null,7.312882955284356,7.507794640198696,7.467605550082998,7.451211111832329,6.3750394313469245,6.9886846867721655,7.569855608330948,7.845490050944375,7.2761244052742375,6.807354922057604,6.392317422778761,7.9886846867721655,8.179909090014934,9.445014845868423,7.483815777264256,7.0,8.027905996569885,7.442943495848728,7.2384047393250786,6.409390936137702,6.672425341971495,6.672425341971495,9.105908508571158,9.308339030139408,9.31741261376487,8.523561956057012,8.945443836377912,8.370687406807217,8.813781191217037,7.7615512324444795,7.754887502163468,7.754887502163468,7.7481928495894605,8.936637939002571,9.970105890612182,5.247927513443585,8.45532722030456,3.321928094887362,7.357552004618084,7.357552004618084,8.179909090014934,2.584962500721156,8.169925001442312,8.654636028527968,8.625708843064466,null,null,6.392317422778761,5.044394119358453,5.426264754702098,null,null,null,1.0,null,3.0,null,null,0.0,2.0,5.906890595608519,null,null,null,2.0,1.0,1.0,null,null,0.0,1.0,0.0,0.0,0.0,0.0,6.491853096329675,7.491853096329675,null,null,null,null,null,1.0,null,0.0,1.584962500721156,1.584962500721156,null,null,null,null,null,null,null,null,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,null,null,1.0,null,null,null,null,null,null,null,1.0,null,null,null,null,null,null,null,null,null,null,1.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.906890595608519,3.4594316186372973,4.169925001442312,4.700439718141092,4.857980995127572,4.857980995127572,4.807354922057604,4.169925001442312,5.554588851677638,6.357552004618084,7.357552004618084,5.087462841250339,4.459431618637297,5.832890014164741,5.392317422778761,5.700439718141092,3.9068905956085187,4.0,4.0,6.906890595608519,7.139551352398794,7.139551352398794,5.554588851677638,5.954196310386875,5.392317422778761,6.539158811108031,5.523561956057013,5.523561956057013,5.523561956057013,5.491853096329675,6.339850002884624,7.348728154231077,4.0,6.129283016944966,2.321928094887362,4.906890595608519,4.906890595608519,6.78135971352466,null,5.392317422778761,2.807354922057604,2.807354922057604,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,null,1.0,0.0,0.0,0.0,0.0,null,null,1.0,null,null,null,null,null,null,null,null,null,5.977279923499917,4.169925001442312,5.643856189774724,6.108524456778169,6.169925001442312,5.700439718141092,5.754887502163468,5.285402218862249,6.409390936137702,7.577428828035749,8.303780748177102,5.882643049361842,6.0,6.643856189774724,6.303780748177103,6.22881869049588,5.357552004618084,5.321928094887363,5.321928094887363,8.622051819456376,8.810571634741146,8.005624549193879,6.700439718141092,7.159871336778389,6.285402218862249,7.483815777264256,6.3750394313469245,6.357552004618084,6.357552004618084,6.357552004618084,7.507794640198696,8.531381460516313,7.20945336562895,6.845490050944375,2.321928094887362,5.554588851677638,5.554588851677638,7.531381460516312,4.087462841250339,6.700439718141092,7.066089190457772,7.0,5.584962500721156,4.906890595608519,4.857980995127572,5.491853096329675,5.882643049361842,4.857980995127572,5.247927513443585,4.754887502163468,6.108524456778169,7.129283016944966,7.813781191217037,5.392317422778761,5.426264754702098,6.22881869049588,5.977279923499917,5.930737337562887,5.169925001442312,4.700439718141092,4.700439718141092,8.199672344836364,8.430452551665532,7.475733430966398,7.108524456778169,7.475733430966398,6.658211482751795,6.857980995127572,5.857980995127572,5.857980995127572,5.857980995127572,5.857980995127572,7.1799090900149345,8.214319120800766,3.807354922057604,6.442943495848728,1.584962500721156,5.643856189774724,5.643856189774724,7.348728154231077,null,6.169925001442312,6.303780748177103,6.266786540694901,6.475733430966398,4.807354922057604,5.906890595608519,5.930737337562887,6.459431618637297,6.507794640198696,5.643856189774724,5.954196310386875,7.149747119504682,7.569855608330948,8.447083226209653,6.321928094887363,6.169925001442312,6.392317422778761,6.700439718141092,5.857980995127572,5.087462841250339,5.523561956057013,5.523561956057013,8.194756854422248,8.997179480937621,8.554588851677638,7.139551352398794,7.651051691178929,7.741466986401147,7.851749041416057,6.820178962415188,6.807354922057604,6.820178962415188,6.820178962415188,7.599912842187128,8.614709844115207,4.321928094887363,7.807354922057604,2.584962500721156,7.189824558880018,7.189824558880018,7.339850002884624,null,6.870364719583405,7.800899899920305,7.7615512324444795,4.321928094887363,3.584962500721156,3.0,4.0,4.0,4.321928094887363,3.700439718141092,3.169925001442312,5.044394119358453,5.857980995127572,5.357552004618084,3.0,3.4594316186372973,4.643856189774724,3.584962500721156,2.807354922057604,2.807354922057604,3.169925001442312,3.169925001442312,6.727920454563199,6.569855608330948,5.906890595608519,5.044394119358453,5.554588851677638,4.857980995127572,4.700439718141092,3.169925001442312,3.0,3.0,3.0,5.247927513443585,6.339850002884624,4.0,4.392317422778761,0.0,4.584962500721156,4.584962500721156,5.357552004618084,null,3.700439718141092,3.4594316186372973,3.321928094887362,5.78135971352466,4.0,3.0,4.643856189774724,4.857980995127572,5.426264754702098,5.392317422778761,4.754887502163468,6.658211482751795,7.108524456778169,7.614709844115208,4.392317422778761,6.20945336562895,6.20945336562895,4.906890595608519,5.169925001442312,5.321928094887363,3.584962500721156,3.584962500721156,8.154818109052105,8.294620748891626,7.643856189774724,6.658211482751795,7.247927513443585,5.643856189774724,6.741466986401147,5.672425341971495,5.672425341971495,5.672425341971495,5.672425341971495,6.409390936137702,7.426264754702098,4.954196310386875,6.442943495848728,3.584962500721156,4.906890595608519,4.906890595608519,6.409390936137702,null,6.22881869049588,4.807354922057604,4.807354922057604,5.754887502163468,5.20945336562895,5.321928094887363,4.807354922057604,5.807354922057604,5.321928094887363,5.754887502163468,4.392317422778761,6.714245517666122,7.20945336562895,7.426264754702098,5.554588851677638,5.044394119358453,6.169925001442312,5.491853096329675,5.672425341971495,4.754887502163468,5.087462841250339,5.087462841250339,8.581200581924957,8.820178962415188,7.857980995127572,7.129283016944966,7.499845887083206,6.584962500721156,6.794415866350106,5.78135971352466,5.754887502163468,5.754887502163468,5.727920454563199,6.6293566200796095,7.672425341971495,5.807354922057604,6.129283016944966,3.321928094887362,4.584962500721156,4.584962500721156,6.930737337562887,null,5.906890595608519,7.312882955284356,7.294620748891627,5.832890014164741,5.285402218862249,3.807354922057604,5.044394119358453,5.727920454563199,5.0,5.285402218862249,4.321928094887363,6.129283016944966,7.219168520462161,7.3750394313469245,4.906890595608519,4.392317422778761,5.643856189774724,5.857980995127572,5.930737337562887,4.584962500721156,4.643856189774724,4.643856189774724,8.169925001442312,8.643856189774725,7.6653359171851765,6.741466986401147,7.149747119504682,6.539158811108031,6.965784284662087,5.857980995127572,5.832890014164741,5.832890014164741,5.832890014164741,6.357552004618084,7.409390936137702,5.321928094887363,6.087462841250339,2.0,5.0,5.0,7.2761244052742375,null,5.614709844115208,6.169925001442312,6.149747119504682,4.459431618637297,3.9068905956085187,3.807354922057604,3.0,4.087462841250339,4.0,3.584962500721156,1.0,4.700439718141092,5.584962500721156,5.523561956057013,1.0,4.321928094887363,4.169925001442312,3.584962500721156,4.321928094887363,2.807354922057604,1.584962500721156,1.584962500721156,6.426264754702098,6.754887502163468,5.087462841250339,4.392317422778761,4.906890595608519,4.392317422778761,4.754887502163468,3.584962500721156,3.584962500721156,3.584962500721156,3.4594316186372973,4.321928094887363,5.491853096329675,4.584962500721156,4.523561956057013,1.0,3.321928094887362,3.321928094887362,5.78135971352466,null,4.0,2.807354922057604,2.807354922057604,4.954196310386875,4.087462841250339,4.807354922057604,5.20945336562895,4.523561956057013,4.584962500721156,5.129283016944966,4.321928094887363,5.78135971352466,7.294620748891627,7.285402218862249,5.523561956057013,4.807354922057604,5.357552004618084,6.0,5.392317422778761,4.459431618637297,4.0,4.0,8.124121311829187,8.467605550082997,7.108524456778169,5.977279923499917,6.339850002884624,5.930737337562887,6.6865005271832185,5.614709844115208,5.584962500721156,5.584962500721156,5.554588851677638,6.6293566200796095,7.643856189774724,7.20945336562895,6.022367813028454,2.0,3.700439718141092,3.700439718141092,7.257387842692652,null,5.954196310386875,6.129283016944966,6.066089190457772,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.491853096329675,4.087462841250339,5.129283016944966,5.087462841250339,5.321928094887363,4.643856189774724,4.754887502163468,4.169925001442312,5.754887502163468,7.118941072723508,7.357552004618084,4.700439718141092,5.0,5.727920454563199,5.614709844115208,4.754887502163468,4.459431618637297,4.584962500721156,4.584962500721156,7.954196310386875,8.113742166049189,7.426264754702098,6.727920454563199,6.965784284662087,6.266786540694901,6.491853096329675,5.357552004618084,5.357552004618084,5.321928094887363,5.285402218862249,6.807354922057604,7.832890014164741,4.700439718141092,6.303780748177103,4.087462841250339,5.392317422778761,5.392317422778761,7.03342300153745,null,6.066089190457772,4.392317422778761,4.392317422778761,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.247927513443585,3.584962500721156,3.584962500721156,4.523561956057013,3.807354922057604,4.643856189774724,4.584962500721156,3.321928094887362,5.643856189774724,6.569855608330948,7.22881869049588,4.584962500721156,5.129283016944966,5.357552004618084,4.807354922057604,4.392317422778761,3.700439718141092,3.9068905956085187,3.9068905956085187,7.0,8.113742166049189,6.643856189774724,5.700439718141092,5.882643049361842,4.857980995127572,5.807354922057604,4.643856189774724,4.584962500721156,4.584962500721156,4.584962500721156,5.523561956057013,6.569855608330948,5.584962500721156,5.523561956057013,2.807354922057604,4.643856189774724,4.643856189774724,5.727920454563199,3.169925001442312,5.285402218862249,5.20945336562895,5.20945336562895,1.0,3.4594316186372973,1.0,2.0,3.321928094887362,2.0,1.584962500721156,1.584962500721156,1.0,3.700439718141092,2.584962500721156,5.0,1.0,3.321928094887362,4.584962500721156,null,null,3.584962500721156,3.584962500721156,4.087462841250339,4.459431618637297,3.169925001442312,4.169925001442312,4.321928094887363,5.357552004618084,3.4594316186372973,2.321928094887362,2.321928094887362,2.321928094887362,2.0,2.584962500721156,3.700439718141092,2.0,2.321928094887362,1.0,4.321928094887363,4.321928094887363,2.0,null,2.807354922057604,6.20945336562895,6.149747119504682,4.807354922057604,3.169925001442312,3.321928094887362,3.4594316186372973,4.169925001442312,4.584962500721156,4.0,2.584962500721156,5.129283016944966,6.339850002884624,5.857980995127572,3.321928094887362,4.643856189774724,4.169925001442312,5.044394119358453,4.392317422778761,0.0,3.584962500721156,3.584962500721156,7.044394119358453,7.643856189774724,6.321928094887363,5.044394119358453,5.554588851677638,5.357552004618084,5.727920454563199,4.643856189774724,4.643856189774724,4.643856189774724,4.643856189774724,5.129283016944966,6.169925001442312,5.247927513443585,5.321928094887363,3.4594316186372973,4.169925001442312,4.169925001442312,6.357552004618084,null,4.857980995127572,5.426264754702098,5.426264754702098,4.0,2.807354922057604,3.0,2.584962500721156,3.4594316186372973,3.807354922057604,3.700439718141092,3.169925001442312,4.392317422778761,5.523561956057013,5.754887502163468,4.169925001442312,3.807354922057604,4.247927513443585,4.087462841250339,3.0,3.700439718141092,2.584962500721156,2.584962500721156,6.78135971352466,7.330916878114617,5.977279923499917,4.087462841250339,5.044394119358453,4.906890595608519,5.20945336562895,4.169925001442312,4.087462841250339,4.087462841250339,4.087462841250339,4.906890595608519,6.0,3.584962500721156,4.643856189774724,3.584962500721156,3.4594316186372973,3.4594316186372973,6.20945336562895,0.0,4.169925001442312,3.700439718141092,3.584962500721156,5.614709844115208,3.700439718141092,5.321928094887363,5.20945336562895,5.321928094887363,5.426264754702098,4.643856189774724,4.523561956057013,6.321928094887363,6.894817763307944,7.467605550082998,5.426264754702098,5.584962500721156,5.392317422778761,5.754887502163468,5.491853096329675,4.392317422778761,4.321928094887363,4.321928094887363,7.888743248898259,8.46352437327118,7.247927513443585,6.459431618637297,6.807354922057604,6.044394119358453,6.672425341971495,5.491853096329675,5.491853096329675,5.491853096329675,5.491853096329675,6.507794640198696,7.592457037268081,4.700439718141092,5.930737337562887,1.0,4.857980995127572,4.857980995127572,6.643856189774724,null,6.087462841250339,6.108524456778169,6.0,4.321928094887363,4.392317422778761,4.392317422778761,4.087462841250339,4.700439718141092,4.321928094887363,4.0,4.0,5.672425341971495,6.714245517666122,7.044394119358453,5.169925001442312,4.169925001442312,4.906890595608519,4.954196310386875,5.0,3.700439718141092,4.392317422778761,4.392317422778761,7.515699838284043,7.994353436858858,6.569855608330948,6.087462841250339,6.392317422778761,5.643856189774724,6.22881869049588,5.20945336562895,5.20945336562895,5.20945336562895,5.20945336562895,6.129283016944966,7.20945336562895,4.584962500721156,5.426264754702098,2.321928094887362,4.857980995127572,4.857980995127572,5.78135971352466,null,4.643856189774724,5.977279923499917,5.954196310386875,0.0,null,null,null,null,null,0.0,0.0,null,null,null,1.0,0.0,null,null,null,null,null,null,1.584962500721156,2.321928094887362,2.0,0.0,0.0,0.0,1.0,0.0,0.0,0.0,0.0,null,0.0,null,0.0,0.0,null,null,null,null,null,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,1.0,null,null,null,null,null,null,null,0.0,2.0,null,null,null,null,1.0,null,null,null,null,null,1.0,null,null,0.0,null,null,0.0,null,null,null,null,4.087462841250339,2.807354922057604,3.584962500721156,4.321928094887363,4.087462841250339,4.392317422778761,3.9068905956085187,2.807354922057604,4.523561956057013,6.108524456778169,6.672425341971495,3.700439718141092,3.584962500721156,4.169925001442312,4.807354922057604,4.169925001442312,2.0,3.321928094887362,3.321928094887362,6.303780748177103,7.118941072723508,6.285402218862249,5.584962500721156,5.584962500721156,5.044394119358453,5.906890595608519,4.807354922057604,4.807354922057604,4.807354922057604,4.807354922057604,5.554588851677638,6.614709844115208,4.906890595608519,5.087462841250339,1.584962500721156,2.584962500721156,2.584962500721156,5.584962500721156,null,5.20945336562895,3.169925001442312,3.169925001442312,5.700439718141092,5.0,5.247927513443585,5.554588851677638,5.727920454563199,5.930737337562887,5.20945336562895,4.459431618637297,6.392317422778761,7.417852514885898,8.066089190457772,5.857980995127572,5.672425341971495,5.954196310386875,6.066089190457772,5.247927513443585,4.700439718141092,4.523561956057013,4.523561956057013,8.179909090014934,8.73809225962049,7.658211482751795,6.491853096329675,6.845490050944375,6.672425341971495,7.0,5.954196310386875,5.954196310386875,5.954196310386875,5.906890595608519,7.189824558880018,8.199672344836364,5.700439718141092,6.857980995127572,3.321928094887362,5.129283016944966,5.129283016944966,7.0,null,6.339850002884624,6.523561956057013,6.491853096329675,4.700439718141092,4.087462841250339,4.459431618637297,4.643856189774724,4.700439718141092,4.523561956057013,3.9068905956085187,4.0,5.357552004618084,6.303780748177103,6.882643049361842,4.954196310386875,4.807354922057604,4.754887502163468,4.754887502163468,5.285402218862249,4.392317422778761,3.4594316186372973,3.4594316186372973,7.139551352398794,7.60733031374961,7.348728154231077,5.700439718141092,6.022367813028454,5.930737337562887,6.20945336562895,5.087462841250339,5.087462841250339,5.087462841250339,5.087462841250339,6.20945336562895,7.257387842692652,4.392317422778761,5.672425341971495,0.0,4.906890595608519,4.906890595608519,5.727920454563199,null,5.285402218862249,3.0,3.0,null,null,null,null,null,null,null,null,null,1.584962500721156,1.0,null,null,null,1.0,null,null,null,null,0.0,null,1.0,0.0,0.0,null,1.0,0.0,0.0,0.0,0.0,null,null,null,null,null,null,null,null,null,null,0.0,0.0,5.584962500721156,4.0,4.700439718141092,4.643856189774724,5.169925001442312,5.044394119358453,4.523561956057013,4.643856189774724,5.700439718141092,6.672425341971495,6.714245517666122,5.20945336562895,5.247927513443585,5.357552004618084,4.459431618637297,5.20945336562895,4.087462841250339,4.169925001442312,4.169925001442312,7.330916878114617,7.672425341971495,6.727920454563199,6.066089190457772,6.409390936137702,6.022367813028454,6.044394119358453,4.857980995127572,4.857980995127572,4.857980995127572,4.857980995127572,6.108524456778169,7.098032082960526,5.392317422778761,5.672425341971495,2.584962500721156,4.169925001442312,4.169925001442312,6.727920454563199,0.0,5.614709844115208,3.9068905956085187,3.700439718141092,4.523561956057013,3.0,4.087462841250339,4.0,3.700439718141092,4.459431618637297,3.700439718141092,3.169925001442312,4.906890595608519,5.727920454563199,6.303780748177103,4.643856189774724,3.584962500721156,4.807354922057604,5.0,4.392317422778761,4.087462841250339,3.700439718141092,3.700439718141092,6.918863237274595,7.199672344836364,6.321928094887363,5.523561956057013,5.807354922057604,5.20945336562895,5.357552004618084,4.321928094887363,4.247927513443585,4.247927513443585,4.169925001442312,5.491853096329675,6.507794640198696,4.087462841250339,5.044394119358453,2.321928094887362,4.807354922057604,4.807354922057604,6.149747119504682,null,5.169925001442312,5.584962500721156,5.459431618637297,5.087462841250339,3.9068905956085187,3.807354922057604,4.321928094887363,4.643856189774724,4.643856189774724,4.700439718141092,4.0,5.459431618637297,6.741466986401147,6.129283016944966,4.584962500721156,3.807354922057604,5.643856189774724,5.523561956057013,4.321928094887363,4.169925001442312,4.247927513443585,4.247927513443585,7.6653359171851765,8.038918989292302,7.129283016944966,5.78135971352466,6.321928094887363,5.906890595608519,6.087462841250339,5.044394119358453,5.044394119358453,5.044394119358453,5.044394119358453,5.930737337562887,6.906890595608519,5.129283016944966,5.754887502163468,0.0,3.807354922057604,3.807354922057604,5.459431618637297,null,5.247927513443585,4.169925001442312,4.087462841250339,4.584962500721156,3.700439718141092,4.321928094887363,4.700439718141092,4.584962500721156,4.169925001442312,4.459431618637297,4.643856189774724,5.727920454563199,6.539158811108031,7.357552004618084,5.0,4.857980995127572,5.129283016944966,5.044394119358453,4.643856189774724,4.321928094887363,4.247927513443585,4.247927513443585,7.592457037268081,7.826548487290915,6.845490050944375,5.882643049361842,6.409390936137702,5.807354922057604,5.614709844115208,4.523561956057013,4.523561956057013,4.459431618637297,4.459431618637297,6.087462841250339,7.098032082960526,3.807354922057604,5.906890595608519,1.584962500721156,4.169925001442312,4.169925001442312,6.794415866350106,null,4.906890595608519,5.426264754702098,5.20945336562895,5.643856189774724,4.169925001442312,4.584962500721156,4.700439718141092,4.807354922057604,4.906890595608519,5.087462841250339,3.321928094887362,5.392317422778761,6.266786540694901,6.700439718141092,4.087462841250339,5.169925001442312,5.584962500721156,5.247927513443585,5.087462841250339,3.321928094887362,4.523561956057013,4.523561956057013,7.076815597050831,7.339850002884624,7.1799090900149345,5.906890595608519,6.339850002884624,5.491853096329675,5.977279923499917,4.754887502163468,4.754887502163468,4.754887502163468,4.754887502163468,6.339850002884624,7.383704292474052,2.584962500721156,5.700439718141092,1.584962500721156,5.247927513443585,5.247927513443585,5.832890014164741,null,6.066089190457772,5.977279923499917,5.930737337562887,4.392317422778761,4.169925001442312,4.321928094887363,4.906890595608519,4.700439718141092,5.0,5.20945336562895,2.807354922057604,5.754887502163468,6.303780748177103,6.442943495848728,5.20945336562895,4.087462841250339,5.584962500721156,5.357552004618084,5.129283016944966,4.321928094887363,4.169925001442312,4.169925001442312,7.400879436282184,7.622051819456376,6.491853096329675,5.807354922057604,6.392317422778761,6.066089190457772,6.20945336562895,4.954196310386875,4.954196310386875,4.954196310386875,4.954196310386875,5.906890595608519,6.977279923499917,5.0,4.954196310386875,0.0,4.169925001442312,4.169925001442312,5.554588851677638,null,5.426264754702098,5.523561956057013,5.426264754702098,2.0,null,null,null,null,null,null,null,1.0,2.584962500721156,0.0,0.0,1.0,null,0.0,null,2.0,0.0,0.0,2.321928094887362,4.392317422778761,0.0,null,0.0,null,0.0,null,null,null,null,1.584962500721156,3.169925001442312,1.0,null,1.0,1.0,1.0,3.321928094887362,null,null,0.0,0.0,6.6293566200796095,4.700439718141092,6.044394119358453,6.129283016944966,6.321928094887363,6.247927513443585,5.285402218862249,5.169925001442312,6.807354922057604,7.108524456778169,8.539158811108031,6.614709844115208,5.491853096329675,6.6293566200796095,6.6293566200796095,6.129283016944966,5.129283016944966,5.614709844115208,5.614709844115208,7.851749041416057,8.189824558880018,8.164906926675688,7.348728154231077,7.592457037268081,7.285402218862249,8.139551352398794,7.05528243550119,7.05528243550119,7.05528243550119,7.044394119358453,7.700439718141092,8.734709620225837,4.523561956057013,7.357552004618084,2.0,6.285402218862249,6.285402218862249,7.312882955284356,null,6.714245517666122,6.870364719583405,6.870364719583405,5.20945336562895,4.700439718141092,4.857980995127572,5.169925001442312,5.285402218862249,4.807354922057604,5.044394119358453,4.643856189774724,5.906890595608519,6.714245517666122,7.60733031374961,5.285402218862249,5.491853096329675,5.857980995127572,5.357552004618084,5.285402218862249,4.0,4.459431618637297,4.459431618637297,7.569855608330948,8.0,7.451211111832329,6.78135971352466,7.0,6.087462841250339,6.78135971352466,5.614709844115208,5.614709844115208,5.614709844115208,5.584962500721156,6.857980995127572,7.924812503605781,4.857980995127572,5.807354922057604,2.807354922057604,6.22881869049588,6.22881869049588,6.672425341971495,null,5.832890014164741,7.011227255423254,7.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.523561956057013,4.754887502163468,3.9068905956085187,4.700439718141092,4.807354922057604,4.857980995127572,4.321928094887363,3.169925001442312,5.426264754702098,6.768184324776926,6.870364719583405,4.807354922057604,5.247927513443585,5.357552004618084,4.807354922057604,4.523561956057013,3.9068905956085187,4.169925001442312,4.169925001442312,7.515699838284043,7.864186144654281,6.977279923499917,5.857980995127572,6.22881869049588,5.754887502163468,6.247927513443585,5.129283016944966,5.087462841250339,5.087462841250339,5.0,6.20945336562895,7.266786540694901,4.392317422778761,5.285402218862249,2.0,4.459431618637297,4.459431618637297,6.700439718141092,null,5.614709844115208,5.727920454563199,5.754887502163468,null,null,null,null,null,null,null,null,1.0,0.0,1.0,null,null,0.0,null,null,null,null,null,0.0,1.0,null,null,null,0.0,1.0,null,null,null,null,null,null,null,null,null,null,null,1.0,null,null,0.0,0.0,5.882643049361842,3.9068905956085187,4.954196310386875,5.727920454563199,5.700439718141092,5.832890014164741,4.700439718141092,4.906890595608519,6.845490050944375,7.569855608330948,8.344295907915816,6.442943495848728,5.857980995127572,6.409390936137702,6.459431618637297,6.044394119358453,5.285402218862249,5.0,5.0,8.005624549193879,8.791162888555018,8.149747119504681,7.219168520462161,7.499845887083206,7.044394119358453,7.546894459887636,6.475733430966398,6.459431618637297,6.459431618637297,6.459431618637297,7.339850002884624,8.370687406807217,5.643856189774724,6.965784284662087,3.321928094887362,5.78135971352466,5.78135971352466,8.238404739325079,null,6.442943495848728,6.392317422778761,6.357552004618084,5.321928094887363,3.700439718141092,5.087462841250339,4.459431618637297,4.459431618637297,3.321928094887362,4.523561956057013,3.321928094887362,5.392317422778761,5.491853096329675,6.357552004618084,5.321928094887363,4.0,5.554588851677638,5.169925001442312,4.700439718141092,4.169925001442312,4.321928094887363,4.321928094887363,6.768184324776926,7.6293566200796095,6.6293566200796095,5.857980995127572,6.247927513443585,5.700439718141092,6.426264754702098,5.392317422778761,5.392317422778761,5.392317422778761,5.392317422778761,6.108524456778169,7.139551352398794,4.169925001442312,5.459431618637297,2.0,3.807354922057604,3.807354922057604,5.857980995127572,null,5.0,5.554588851677638,5.491853096329675,5.832890014164741,4.169925001442312,4.643856189774724,5.129283016944966,5.584962500721156,5.392317422778761,4.0,4.169925001442312,5.857980995127572,6.523561956057013,7.554588851677638,5.727920454563199,5.247927513443585,6.189824558880018,5.584962500721156,5.672425341971495,4.169925001442312,4.807354922057604,4.807354922057604,7.599912842187128,8.113742166049189,7.1799090900149345,6.409390936137702,6.882643049361842,6.22881869049588,6.94251450533924,5.832890014164741,5.832890014164741,5.832890014164741,5.807354922057604,6.554588851677638,7.569855608330948,4.321928094887363,5.906890595608519,2.321928094887362,5.321928094887363,5.321928094887363,6.569855608330948,null,5.832890014164741,5.807354922057604,5.78135971352466,1.0,0.0,null,0.0,1.0,0.0,1.0,0.0,1.584962500721156,2.584962500721156,0.0,null,2.321928094887362,1.584962500721156,0.0,1.0,null,null,null,3.584962500721156,3.700439718141092,2.807354922057604,1.584962500721156,1.584962500721156,1.0,2.807354922057604,1.0,0.0,0.0,1.584962500721156,1.584962500721156,3.4594316186372973,null,3.169925001442312,0.0,null,null,3.321928094887362,null,null,null,null,4.321928094887363,4.0,3.807354922057604,4.087462841250339,4.0,4.643856189774724,3.584962500721156,2.0,4.459431618637297,5.129283016944966,6.321928094887363,4.321928094887363,3.584962500721156,4.906890595608519,4.459431618637297,4.459431618637297,3.584962500721156,4.392317422778761,4.392317422778761,6.599912842187128,7.475733430966398,6.108524456778169,5.129283016944966,5.392317422778761,5.392317422778761,5.459431618637297,4.523561956057013,4.523561956057013,4.523561956057013,4.523561956057013,5.754887502163468,6.794415866350106,4.247927513443585,4.954196310386875,2.321928094887362,4.0,4.0,6.149747119504682,null,4.857980995127572,5.807354922057604,5.807354922057604,4.459431618637297,3.321928094887362,4.906890595608519,4.321928094887363,4.459431618637297,4.857980995127572,3.807354922057604,2.584962500721156,5.20945336562895,5.930737337562887,7.011227255423254,4.700439718141092,4.584962500721156,5.169925001442312,4.643856189774724,4.807354922057604,4.321928094887363,3.9068905956085187,3.9068905956085187,7.0,7.400879436282184,6.599912842187128,5.832890014164741,6.20945336562895,5.491853096329675,5.906890595608519,4.857980995127572,4.857980995127572,4.857980995127572,4.807354922057604,6.0,7.108524456778169,4.700439718141092,5.0,3.169925001442312,4.321928094887363,4.321928094887363,5.930737337562887,null,5.78135971352466,5.523561956057013,5.523561956057013,1.584962500721156,null,null,1.0,0.0,2.0,null,2.0,0.0,3.4594316186372973,2.584962500721156,null,1.584962500721156,1.584962500721156,0.0,2.584962500721156,0.0,null,null,4.0,5.169925001442312,2.0,1.584962500721156,1.584962500721156,2.807354922057604,2.321928094887362,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,2.584962500721156,1.0,1.0,1.584962500721156,1.0,1.0,1.0,null,2.584962500721156,0.0,0.0,3.321928094887362,2.584962500721156,1.0,3.4594316186372973,3.0,3.807354922057604,3.169925001442312,0.0,4.247927513443585,5.357552004618084,5.392317422778761,3.807354922057604,4.087462841250339,4.0,3.700439718141092,3.584962500721156,2.321928094887362,1.584962500721156,1.584962500721156,6.189824558880018,6.700439718141092,5.0,4.0,4.169925001442312,4.459431618637297,4.169925001442312,2.807354922057604,2.807354922057604,2.807354922057604,2.807354922057604,4.087462841250339,5.247927513443585,3.584962500721156,3.4594316186372973,2.807354922057604,2.584962500721156,2.584962500721156,5.321928094887363,null,3.807354922057604,4.0,4.0,5.643856189774724,3.169925001442312,4.0,4.906890595608519,5.754887502163468,5.672425341971495,5.392317422778761,4.392317422778761,6.108524456778169,7.118941072723508,7.876516946564999,5.584962500721156,5.087462841250339,5.727920454563199,5.857980995127572,6.087462841250339,5.044394119358453,5.044394119358453,5.044394119358453,7.754887502163468,8.164906926675688,7.219168520462161,6.539158811108031,6.727920454563199,6.539158811108031,7.118941072723508,6.066089190457772,6.044394119358453,6.044394119358453,6.044394119358453,6.554588851677638,7.60733031374961,5.700439718141092,5.977279923499917,3.169925001442312,5.700439718141092,5.700439718141092,6.700439718141092,null,6.129283016944966,3.4594316186372973,3.321928094887362,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,1.584962500721156,null,0.0,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.266786540694901,4.643856189774724,5.247927513443585,5.78135971352466,5.321928094887363,5.523561956057013,5.129283016944966,4.700439718141092,6.392317422778761,7.139551352398794,7.807354922057604,5.857980995127572,5.857980995127572,6.392317422778761,6.108524456778169,5.977279923499917,5.392317422778761,4.857980995127572,4.857980995127572,7.7481928495894605,8.280770770130603,7.554588851677638,6.906890595608519,7.247927513443585,6.643856189774724,7.348728154231077,6.247927513443585,6.22881869049588,6.22881869049588,6.20945336562895,7.189824558880018,8.194756854422248,4.857980995127572,6.78135971352466,2.807354922057604,5.523561956057013,5.523561956057013,6.882643049361842,3.700439718141092,6.741466986401147,7.3750394313469245,7.357552004618084,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.0,null,null,null,null,null,null,null,null,6.6865005271832185,4.807354922057604,5.906890595608519,6.569855608330948,6.539158811108031,6.108524456778169,6.108524456778169,5.087462841250339,6.918863237274595,7.734709620225838,8.588714635582264,6.754887502163468,5.954196310386875,6.700439718141092,6.820178962415188,6.599912842187128,5.459431618637297,5.554588851677638,5.554588851677638,8.584962500721156,9.005624549193879,8.224001674198105,7.366322214245816,7.636624620543649,6.965784284662087,7.971543553950772,6.918863237274595,6.894817763307944,6.894817763307944,6.882643049361842,7.7481928495894605,8.76487159073609,6.266786540694901,6.94251450533924,3.584962500721156,6.303780748177103,6.321928094887363,7.721099188707185,null,6.3750394313469245,5.392317422778761,5.321928094887363,6.714245517666122,5.285402218862249,5.857980995127572,5.700439718141092,6.491853096329675,6.442943495848728,5.614709844115208,5.491853096329675,6.930737337562887,7.700439718141092,8.285402218862249,5.832890014164741,6.108524456778169,6.820178962415188,6.475733430966398,6.459431618637297,5.459431618637297,5.584962500721156,5.584962500721156,8.78135971352466,8.794415866350105,8.228818690495881,7.499845887083206,8.022367813028454,7.357552004618084,7.6865005271832185,6.727920454563199,6.714245517666122,6.714245517666122,6.700439718141092,7.357552004618084,8.375039431346925,5.392317422778761,6.870364719583405,4.087462841250339,5.977279923499917,5.977279923499917,7.22881869049588,null,6.672425341971495,7.1799090900149345,7.118941072723508,5.554588851677638,4.169925001442312,4.584962500721156,4.584962500721156,5.357552004618084,4.643856189774724,4.392317422778761,4.321928094887363,5.523561956057013,6.539158811108031,7.434628227636725,5.169925001442312,5.044394119358453,5.832890014164741,5.643856189774724,4.584962500721156,4.857980995127572,4.754887502163468,4.754887502163468,7.870364719583405,8.396604781181859,7.219168520462161,6.700439718141092,6.965784284662087,6.339850002884624,6.965784284662087,5.882643049361842,5.832890014164741,5.832890014164741,5.832890014164741,6.569855608330948,7.651051691178929,4.700439718141092,6.0,2.584962500721156,4.807354922057604,4.807354922057604,6.554588851677638,null,5.727920454563199,4.087462841250339,4.087462841250339,4.754887502163468,3.169925001442312,3.321928094887362,3.584962500721156,5.044394119358453,5.0,4.321928094887363,3.700439718141092,5.321928094887363,6.475733430966398,6.426264754702098,5.321928094887363,4.807354922057604,5.247927513443585,5.0,4.807354922057604,4.700439718141092,4.087462841250339,4.087462841250339,7.721099188707185,7.845490050944375,6.906890595608519,5.930737337562887,6.523561956057013,5.672425341971495,5.754887502163468,4.700439718141092,4.700439718141092,4.700439718141092,4.700439718141092,5.129283016944966,6.303780748177103,3.807354922057604,5.247927513443585,2.0,4.392317422778761,4.459431618637297,6.303780748177103,null,5.247927513443585,6.066089190457772,6.022367813028454,7.339850002884624,5.169925001442312,6.700439718141092,6.643856189774724,7.285402218862249,7.2384047393250786,6.569855608330948,6.714245517666122,7.159871336778389,8.321928094887362,8.851749041416058,7.266786540694901,7.894817763307944,7.2384047393250786,7.434628227636725,7.400879436282184,6.392317422778761,6.442943495848728,6.442943495848728,8.038918989292302,8.977279923499916,9.149747119504681,7.426264754702098,7.813781191217037,7.936637939002571,8.348728154231077,7.303780748177103,7.294620748891627,7.294620748891627,7.285402218862249,8.076815597050832,9.079484783826816,6.569855608330948,7.754887502163468,3.0,7.087462841250339,7.087462841250339,8.625708843064466,null,7.022367813028454,7.303780748177103,7.266786540694901,2.584962500721156,null,null,null,1.0,1.0,2.807354922057604,0.0,3.169925001442312,4.459431618637297,2.584962500721156,2.584962500721156,2.807354922057604,2.321928094887362,0.0,2.0,null,null,null,5.930737337562887,6.714245517666122,4.247927513443585,2.807354922057604,3.584962500721156,2.584962500721156,3.4594316186372973,2.321928094887362,2.321928094887362,2.321928094887362,2.321928094887362,1.584962500721156,2.807354922057604,3.0,1.0,null,1.0,1.0,4.459431618637297,null,2.0,1.0,1.0,2.0,1.584962500721156,null,0.0,null,1.584962500721156,1.584962500721156,1.584962500721156,3.807354922057604,4.247927513443585,3.0,null,2.584962500721156,null,1.584962500721156,1.584962500721156,0.0,0.0,0.0,3.169925001442312,5.321928094887363,3.807354922057604,2.807354922057604,3.584962500721156,1.584962500721156,2.0,1.0,1.0,1.0,1.0,2.807354922057604,3.700439718141092,1.0,2.584962500721156,0.0,2.0,2.0,3.0,null,null,3.321928094887362,3.169925001442312,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,0.0,null,null,null,null,0.0,1.0,null,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,0.0,4.700439718141092,4.0,4.169925001442312,4.247927513443585,4.392317422778761,4.321928094887363,4.321928094887363,3.4594316186372973,5.044394119358453,6.459431618637297,6.832890014164741,4.807354922057604,5.087462841250339,5.285402218862249,5.087462841250339,5.247927513443585,3.807354922057604,3.4594316186372973,3.4594316186372973,6.977279923499917,7.6293566200796095,6.894817763307944,5.554588851677638,6.044394119358453,5.426264754702098,6.149747119504682,5.087462841250339,5.044394119358453,5.044394119358453,5.044394119358453,6.108524456778169,7.199672344836364,4.0,5.169925001442312,2.321928094887362,4.0,4.0,6.169925001442312,4.169925001442312,4.523561956057013,5.459431618637297,5.459431618637297,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.0,0.0,0.0,0.0,0.0,0.0,1.0,null,null,null,null,null,null,null,null,null,null,5.169925001442312,3.700439718141092,4.754887502163468,5.087462841250339,4.857980995127572,3.700439718141092,4.0,3.9068905956085187,5.426264754702098,5.832890014164741,6.741466986401147,5.169925001442312,4.857980995127572,5.087462841250339,4.700439718141092,5.491853096329675,4.643856189774724,3.584962500721156,3.584962500721156,6.3750394313469245,6.643856189774724,6.741466986401147,5.882643049361842,6.129283016944966,6.149747119504682,6.426264754702098,5.357552004618084,5.357552004618084,5.357552004618084,5.357552004618084,6.523561956057013,7.531381460516312,3.0,5.727920454563199,2.0,3.807354922057604,3.807354922057604,5.426264754702098,null,4.754887502163468,3.700439718141092,3.700439718141092,5.392317422778761,3.9068905956085187,4.584962500721156,5.392317422778761,5.554588851677638,4.700439718141092,4.087462841250339,3.9068905956085187,6.0,6.321928094887363,7.515699838284043,4.0,5.321928094887363,5.392317422778761,5.321928094887363,5.643856189774724,4.247927513443585,4.247927513443585,4.247927513443585,6.754887502163468,7.199672344836364,7.3750394313469245,6.044394119358453,6.321928094887363,5.700439718141092,6.614709844115208,5.554588851677638,5.491853096329675,5.491853096329675,5.491853096329675,6.768184324776926,7.813781191217037,4.0,5.754887502163468,1.0,5.0,5.0,6.426264754702098,null,6.108524456778169,5.78135971352466,5.78135971352466,6.129283016944966,4.247927513443585,5.672425341971495,5.614709844115208,6.20945336562895,5.614709844115208,5.321928094887363,4.643856189774724,6.22881869049588,6.189824558880018,8.194756854422248,6.321928094887363,5.832890014164741,6.507794640198696,6.303780748177103,6.584962500721156,5.087462841250339,4.906890595608519,4.906890595608519,6.965784284662087,7.6865005271832185,7.787902559391432,6.918863237274595,7.20945336562895,6.539158811108031,7.554588851677638,6.491853096329675,6.491853096329675,6.491853096329675,6.491853096329675,7.467605550082998,8.491853096329674,5.0,6.658211482751795,4.0,5.247927513443585,5.247927513443585,6.044394119358453,null,7.044394119358453,6.820178962415188,6.754887502163468,5.285402218862249,4.392317422778761,4.807354922057604,5.0,5.554588851677638,4.906890595608519,4.584962500721156,4.0,6.022367813028454,4.857980995127572,7.392317422778761,5.459431618637297,4.584962500721156,5.807354922057604,5.357552004618084,5.807354922057604,4.087462841250339,4.321928094887363,4.321928094887363,6.894817763307944,6.894817763307944,7.451211111832329,6.303780748177103,6.768184324776926,6.022367813028454,6.977279923499917,5.832890014164741,5.832890014164741,5.832890014164741,5.832890014164741,6.845490050944375,7.851749041416057,4.321928094887363,6.442943495848728,2.321928094887362,4.906890595608519,4.906890595608519,5.954196310386875,1.0,6.22881869049588,6.169925001442312,6.189824558880018,5.087462841250339,4.321928094887363,4.459431618637297,4.906890595608519,4.906890595608519,5.129283016944966,4.584962500721156,3.584962500721156,5.247927513443585,4.954196310386875,6.870364719583405,5.169925001442312,5.169925001442312,5.727920454563199,5.523561956057013,5.321928094887363,3.9068905956085187,4.523561956057013,4.523561956057013,6.087462841250339,6.857980995127572,6.94251450533924,6.066089190457772,6.321928094887363,6.266786540694901,6.491853096329675,5.357552004618084,5.357552004618084,5.357552004618084,5.357552004618084,6.108524456778169,7.159871336778389,3.584962500721156,6.108524456778169,2.321928094887362,4.321928094887363,4.321928094887363,4.857980995127572,null,6.0,5.491853096329675,5.426264754702098,4.459431618637297,4.087462841250339,5.169925001442312,4.700439718141092,5.285402218862249,4.169925001442312,4.169925001442312,2.584962500721156,4.087462841250339,5.20945336562895,6.285402218862249,4.321928094887363,3.321928094887362,4.169925001442312,4.954196310386875,6.303780748177103,3.584962500721156,3.807354922057604,3.807354922057604,5.584962500721156,6.087462841250339,6.149747119504682,5.044394119358453,5.584962500721156,5.78135971352466,5.491853096329675,4.523561956057013,4.523561956057013,4.523561956057013,4.459431618637297,6.714245517666122,7.700439718141092,2.0,4.700439718141092,2.0,5.0,5.0,4.700439718141092,null,4.321928094887363,5.643856189774724,5.554588851677638,5.78135971352466,4.0,4.321928094887363,4.857980995127572,5.614709844115208,4.321928094887363,4.584962500721156,3.700439718141092,5.584962500721156,5.807354922057604,7.539158811108031,5.357552004618084,5.392317422778761,5.700439718141092,5.20945336562895,5.087462841250339,4.857980995127572,4.459431618637297,4.459431618637297,6.523561956057013,7.149747119504682,6.6865005271832185,6.189824558880018,6.409390936137702,5.832890014164741,6.845490050944375,5.807354922057604,5.78135971352466,5.78135971352466,5.78135971352466,6.523561956057013,7.539158811108031,3.807354922057604,6.285402218862249,2.0,5.20945336562895,5.20945336562895,6.108524456778169,null,6.022367813028454,5.554588851677638,5.523561956057013,6.189824558880018,4.857980995127572,5.491853096329675,5.584962500721156,6.339850002884624,5.857980995127572,5.614709844115208,5.321928094887363,6.108524456778169,6.22881869049588,8.060695931687555,5.321928094887363,6.066089190457772,6.442943495848728,6.507794640198696,6.149747119504682,5.700439718141092,5.357552004618084,5.357552004618084,7.321928094887363,7.491853096329675,7.7481928495894605,7.087462841250339,7.475733430966398,7.05528243550119,7.392317422778761,6.392317422778761,6.3750394313469245,6.3750394313469245,6.3750394313469245,7.409390936137702,8.426264754702098,4.906890595608519,6.918863237274595,2.0,6.0,6.0,5.906890595608519,null,6.584962500721156,7.507794640198696,7.434628227636725,0.0,null,0.0,null,null,null,null,null,null,null,2.0,null,null,0.0,null,null,null,null,null,1.0,2.321928094887362,null,1.0,1.584962500721156,null,0.0,null,null,null,null,null,null,null,2.0,null,null,null,null,null,null,0.0,0.0,5.426264754702098,4.247927513443585,4.807354922057604,5.044394119358453,5.20945336562895,4.807354922057604,4.700439718141092,3.584962500721156,5.584962500721156,5.700439718141092,7.366322214245816,5.392317422778761,5.392317422778761,5.672425341971495,5.357552004618084,6.0,4.906890595608519,4.169925001442312,4.169925001442312,6.727920454563199,7.066089190457772,6.906890595608519,6.189824558880018,6.491853096329675,6.491853096329675,6.6293566200796095,5.523561956057013,5.523561956057013,5.523561956057013,5.523561956057013,6.643856189774724,7.651051691178929,4.807354922057604,5.426264754702098,2.0,5.523561956057013,5.523561956057013,5.977279923499917,null,6.169925001442312,5.977279923499917,5.930737337562887,4.643856189774724,3.9068905956085187,4.0,4.459431618637297,4.321928094887363,3.807354922057604,3.321928094887362,3.807354922057604,4.523561956057013,5.044394119358453,6.539158811108031,4.523561956057013,4.523561956057013,4.643856189774724,5.087462841250339,4.321928094887363,3.584962500721156,4.459431618637297,4.459431618637297,6.189824558880018,6.149747119504682,6.303780748177103,5.523561956057013,5.672425341971495,5.584962500721156,5.78135971352466,4.700439718141092,4.700439718141092,4.700439718141092,4.700439718141092,5.832890014164741,6.857980995127572,4.459431618637297,5.20945336562895,2.0,4.459431618637297,4.459431618637297,4.700439718141092,null,5.554588851677638,6.149747119504682,6.087462841250339,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,1.0,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.523561956057013,3.807354922057604,4.392317422778761,4.0,4.523561956057013,4.392317422778761,3.321928094887362,3.584962500721156,5.584962500721156,5.044394119358453,6.918863237274595,4.700439718141092,4.857980995127572,4.643856189774724,5.0,5.0,4.247927513443585,3.4594316186372973,3.4594316186372973,5.643856189774724,6.554588851677638,6.523561956057013,5.044394119358453,5.357552004618084,5.832890014164741,6.266786540694901,5.20945336562895,5.20945336562895,5.20945336562895,5.20945336562895,6.169925001442312,7.139551352398794,3.0,5.584962500721156,1.0,4.906890595608519,4.906890595608519,5.321928094887363,2.321928094887362,4.807354922057604,5.807354922057604,5.754887502163468,5.977279923499917,4.523561956057013,5.554588851677638,5.087462841250339,5.614709844115208,5.392317422778761,5.321928094887363,4.643856189774724,5.672425341971495,6.169925001442312,7.768184324776926,5.523561956057013,5.169925001442312,5.857980995127572,6.129283016944966,6.339850002884624,5.247927513443585,4.807354922057604,4.807354922057604,7.357552004618084,7.285402218862249,7.643856189774724,6.643856189774724,7.011227255423254,6.754887502163468,7.592457037268081,6.6293566200796095,6.599912842187128,6.599912842187128,6.599912842187128,7.066089190457772,8.087462841250339,4.523561956057013,6.442943495848728,2.584962500721156,6.169925001442312,6.169925001442312,5.954196310386875,null,6.044394119358453,4.643856189774724,4.584962500721156,5.643856189774724,4.247927513443585,4.906890595608519,5.643856189774724,5.78135971352466,5.523561956057013,5.491853096329675,4.169925001442312,6.087462841250339,6.169925001442312,7.948367231584678,5.426264754702098,5.459431618637297,5.78135971352466,6.266786540694901,6.392317422778761,5.087462841250339,4.584962500721156,4.584962500721156,7.022367813028454,7.383704292474052,7.614709844115208,6.672425341971495,6.9886846867721655,6.392317422778761,7.554588851677638,6.491853096329675,6.491853096329675,6.491853096329675,6.491853096329675,7.118941072723508,8.139551352398794,3.584962500721156,6.523561956057013,3.169925001442312,5.643856189774724,5.643856189774724,6.044394119358453,null,6.409390936137702,6.247927513443585,6.22881869049588,6.554588851677638,5.285402218862249,5.807354922057604,6.108524456778169,6.768184324776926,6.149747119504682,5.930737337562887,5.0,7.1799090900149345,6.507794640198696,8.471675214392045,6.303780748177103,6.475733430966398,7.05528243550119,6.507794640198696,6.614709844115208,5.78135971352466,5.882643049361842,5.882643049361842,7.820178962415188,8.118941072723507,8.400879436282183,7.459431618637297,7.924812503605781,7.303780748177103,7.826548487290915,6.832890014164741,6.820178962415188,6.820178962415188,6.807354922057604,7.832890014164741,8.876516946565,4.584962500721156,7.169925001442312,3.4594316186372973,6.321928094887363,6.321928094887363,6.459431618637297,null,6.658211482751795,7.741466986401147,7.6653359171851765,5.672425341971495,4.0,4.857980995127572,5.20945336562895,5.807354922057604,4.754887502163468,5.20945336562895,4.321928094887363,5.727920454563199,6.0,7.312882955284356,5.614709844115208,5.129283016944966,5.426264754702098,5.285402218862249,5.832890014164741,5.129283016944966,5.087462841250339,5.087462841250339,6.9886846867721655,7.011227255423254,7.098032082960526,6.392317422778761,6.78135971352466,6.459431618637297,6.643856189774724,5.584962500721156,5.554588851677638,5.554588851677638,5.554588851677638,6.794415866350106,7.800899899920305,4.0,6.3750394313469245,2.0,5.129283016944966,5.129283016944966,5.554588851677638,null,5.584962500721156,4.700439718141092,4.700439718141092,2.321928094887362,2.0,null,3.169925001442312,2.584962500721156,3.321928094887362,2.321928094887362,1.0,3.169925001442312,3.0,5.129283016944966,3.169925001442312,2.807354922057604,3.321928094887362,3.4594316186372973,3.9068905956085187,1.0,2.321928094887362,2.321928094887362,4.087462841250339,5.491853096329675,4.906890595608519,4.392317422778761,4.754887502163468,3.169925001442312,4.584962500721156,3.4594316186372973,3.4594316186372973,3.4594316186372973,3.4594316186372973,3.321928094887362,4.584962500721156,3.0,2.584962500721156,1.584962500721156,2.584962500721156,2.584962500721156,2.807354922057604,null,3.321928094887362,3.0,3.0,5.930737337562887,4.754887502163468,5.857980995127572,5.906890595608519,6.357552004618084,6.426264754702098,4.906890595608519,5.426264754702098,6.741466986401147,6.426264754702098,8.204571144249204,5.930737337562887,6.149747119504682,6.459431618637297,6.459431618637297,6.266786540694901,6.087462841250339,5.247927513443585,5.247927513443585,7.636624620543649,7.948367231584678,7.851749041416057,7.189824558880018,7.6865005271832185,7.383704292474052,7.894817763307944,6.870364719583405,6.870364719583405,6.870364719583405,6.870364719583405,7.876516946564999,8.909893083770042,4.523561956057013,7.20945336562895,3.0,6.087462841250339,6.108524456778169,5.977279923499917,null,6.523561956057013,6.741466986401147,6.727920454563199,4.700439718141092,3.9068905956085187,3.584962500721156,3.584962500721156,4.0,3.9068905956085187,4.169925001442312,2.807354922057604,4.523561956057013,5.247927513443585,6.6293566200796095,4.392317422778761,4.0,4.523561956057013,4.584962500721156,4.169925001442312,2.807354922057604,3.584962500721156,3.584962500721156,6.087462841250339,5.78135971352466,6.087462841250339,5.321928094887363,5.584962500721156,5.247927513443585,5.882643049361842,4.857980995127572,4.857980995127572,4.857980995127572,4.807354922057604,5.321928094887363,6.3750394313469245,2.584962500721156,5.129283016944966,1.584962500721156,4.321928094887363,4.321928094887363,5.584962500721156,null,5.459431618637297,3.584962500721156,3.4594316186372973,null,null,null,0.0,null,null,null,null,null,null,null,1.0,null,null,null,null,null,0.0,0.0,null,null,1.0,null,null,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.754887502163468,3.700439718141092,4.807354922057604,4.643856189774724,4.906890595608519,4.247927513443585,4.0,3.9068905956085187,5.087462841250339,5.459431618637297,6.918863237274595,4.700439718141092,5.169925001442312,4.954196310386875,4.857980995127572,5.0,3.584962500721156,3.4594316186372973,3.4594316186372973,6.087462841250339,6.339850002884624,6.820178962415188,5.554588851677638,5.807354922057604,5.554588851677638,6.149747119504682,5.044394119358453,5.044394119358453,5.044394119358453,5.044394119358453,6.022367813028454,7.05528243550119,3.584962500721156,5.20945336562895,0.0,4.906890595608519,4.906890595608519,5.672425341971495,null,5.807354922057604,5.643856189774724,5.614709844115208,5.614709844115208,3.584962500721156,5.247927513443585,5.523561956057013,5.523561956057013,5.0,4.700439718141092,4.247927513443585,5.954196310386875,5.930737337562887,7.321928094887363,5.169925001442312,5.672425341971495,5.78135971352466,6.066089190457772,5.700439718141092,5.20945336562895,4.807354922057604,4.807354922057604,7.03342300153745,7.491853096329675,7.491853096329675,6.321928094887363,6.741466986401147,6.285402218862249,7.139551352398794,6.044394119358453,6.044394119358453,6.044394119358453,6.044394119358453,7.076815597050831,8.113742166049189,4.584962500721156,6.149747119504682,3.321928094887362,5.087462841250339,5.087462841250339,5.044394119358453,null,6.339850002884624,6.266786540694901,6.22881869049588,4.643856189774724,2.807354922057604,3.321928094887362,4.0,3.807354922057604,3.321928094887362,2.584962500721156,2.584962500721156,3.700439718141092,4.169925001442312,6.459431618637297,3.807354922057604,4.906890595608519,4.523561956057013,4.459431618637297,4.906890595608519,2.0,3.0,3.0,5.614709844115208,5.672425341971495,6.022367813028454,4.807354922057604,4.906890595608519,4.857980995127572,6.066089190457772,5.0,5.0,5.0,5.0,5.129283016944966,6.20945336562895,3.169925001442312,4.857980995127572,null,3.321928094887362,3.321928094887362,4.247927513443585,0.0,4.807354922057604,5.247927513443585,5.247927513443585,5.426264754702098,4.392317422778761,4.700439718141092,5.285402218862249,4.754887502163468,4.321928094887363,4.087462841250339,3.321928094887362,5.20945336562895,5.491853096329675,7.434628227636725,4.807354922057604,4.247927513443585,5.584962500721156,5.614709844115208,5.614709844115208,4.392317422778761,4.087462841250339,4.087462841250339,6.409390936137702,6.9886846867721655,7.087462841250339,5.807354922057604,5.954196310386875,5.930737337562887,6.523561956057013,5.392317422778761,5.392317422778761,5.392317422778761,5.392317422778761,6.569855608330948,7.577428828035749,3.0,5.459431618637297,2.321928094887362,5.247927513443585,5.247927513443585,4.906890595608519,null,6.189824558880018,5.930737337562887,5.857980995127572,6.0,4.700439718141092,5.700439718141092,5.523561956057013,6.087462841250339,5.906890595608519,5.20945336562895,4.906890595608519,6.614709844115208,6.321928094887363,8.339850002884624,6.266786540694901,5.727920454563199,6.339850002884624,6.584962500721156,6.0,5.584962500721156,4.954196310386875,4.954196310386875,6.820178962415188,7.339850002884624,7.918863237274595,7.199672344836364,7.459431618637297,6.794415866350106,7.6293566200796095,6.569855608330948,6.569855608330948,6.569855608330948,6.569855608330948,7.554588851677638,8.59618975614441,3.807354922057604,6.954196310386875,1.584962500721156,5.906890595608519,5.906890595608519,5.727920454563199,0.0,6.554588851677638,6.459431618637297,6.426264754702098,null,null,null,null,0.0,0.0,null,null,null,null,null,null,null,0.0,null,null,0.0,null,null,null,2.0,1.0,null,1.0,null,1.0,0.0,0.0,0.0,0.0,null,null,null,null,0.0,0.0,0.0,null,null,null,null,null,7.622051819456376,7.491853096329675,6.523561956057013,6.658211482751795,7.2761244052742375,6.832890014164741,6.906890595608519,6.539158811108031,8.228818690495881,9.152284842306582,8.361943773735241,5.857980995127572,6.954196310386875,7.409390936137702,6.918863237274595,7.03342300153745,6.614709844115208,6.658211482751795,6.658211482751795,10.096715154488535,10.800090987624994,9.350939181546432,8.308339030139408,9.174925682500678,8.459431618637296,7.894817763307944,6.954196310386875,6.954196310386875,6.954196310386875,6.94251450533924,8.285402218862249,9.368506461507693,5.20945336562895,7.451211111832329,11.03823313473178,6.539158811108031,6.539158811108031,9.076815597050832,8.285402218862249,8.022367813028454,8.62935662007961,8.622051819456376,6.339850002884624,5.807354922057604,4.700439718141092,4.459431618637297,5.930737337562887,6.189824558880018,5.954196310386875,5.672425341971495,7.20945336562895,7.294620748891627,7.159871336778389,0.0,6.459431618637297,6.108524456778169,4.0,5.584962500721156,5.321928094887363,4.321928094887363,4.321928094887363,8.071462362556623,8.761551232444479,8.179909090014934,7.366322214245816,8.139551352398794,6.6293566200796095,6.614709844115208,5.857980995127572,5.832890014164741,5.832890014164741,5.807354922057604,6.539158811108031,7.658211482751795,6.169925001442312,6.906890595608519,4.087462841250339,4.857980995127572,4.857980995127572,7.592457037268081,0.0,7.417852514885898,6.754887502163468,6.768184324776926,6.768184324776926,6.569855608330948,5.727920454563199,6.169925001442312,6.845490050944375,6.087462841250339,6.044394119358453,5.857980995127572,7.832890014164741,8.262094845370179,7.672425341971495,5.087462841250339,7.044394119358453,7.011227255423254,6.459431618637297,6.22881869049588,5.643856189774724,6.247927513443585,6.247927513443585,8.794415866350105,10.156083076288681,8.693486957499326,7.714245517666122,8.618385502258606,8.326429487122303,7.721099188707185,6.894817763307944,6.882643049361842,6.882643049361842,6.857980995127572,7.636624620543649,8.710806433699352,7.303780748177103,7.483815777264256,10.843921051289035,5.700439718141092,5.727920454563199,8.73809225962049,7.658211482751795,7.044394119358453,8.113742166049189,8.098032082960527,6.087462841250339,5.584962500721156,3.807354922057604,4.523561956057013,5.129283016944966,5.426264754702098,4.087462841250339,4.169925001442312,6.700439718141092,7.247927513443585,5.930737337562887,4.247927513443585,5.832890014164741,5.832890014164741,4.906890595608519,5.643856189774724,5.247927513443585,5.129283016944966,5.129283016944966,8.353146825498083,9.139551352398794,7.754887502163468,6.569855608330948,7.459431618637297,6.807354922057604,6.129283016944966,5.426264754702098,5.426264754702098,5.426264754702098,5.426264754702098,6.247927513443585,7.321928094887363,1.0,6.357552004618084,9.693486957499326,4.906890595608519,4.906890595608519,7.499845887083206,5.426264754702098,6.129283016944966,6.857980995127572,6.794415866350106,6.189824558880018,5.977279923499917,4.700439718141092,5.087462841250339,6.108524456778169,5.857980995127572,5.584962500721156,5.087462841250339,7.569855608330948,8.939579214314692,7.2761244052742375,4.700439718141092,5.832890014164741,6.087462841250339,5.977279923499917,5.392317422778761,5.643856189774724,5.357552004618084,5.357552004618084,9.894817763307943,10.508785162064513,8.179909090014934,7.03342300153745,7.78135971352466,7.507794640198696,6.78135971352466,5.977279923499917,5.977279923499917,5.977279923499917,5.954196310386875,7.011227255423254,8.08214904135387,4.0,6.658211482751795,10.184875342908283,5.426264754702098,5.426264754702098,8.60733031374961,5.857980995127572,6.930737337562887,7.392317422778761,7.357552004618084,6.108524456778169,6.129283016944966,5.930737337562887,5.357552004618084,6.459431618637297,6.266786540694901,4.584962500721156,5.20945336562895,6.614709844115208,6.930737337562887,7.434628227636725,4.087462841250339,6.169925001442312,6.149747119504682,6.189824558880018,6.087462841250339,5.426264754702098,5.554588851677638,5.554588851677638,8.055282435501189,8.344295907915816,8.087462841250339,7.011227255423254,7.658211482751795,7.794415866350106,6.9886846867721655,6.129283016944966,6.108524456778169,6.108524456778169,6.066089190457772,7.05528243550119,8.124121311829187,0.0,6.22881869049588,10.281930026955443,6.285402218862249,6.285402218862249,7.936637939002571,6.539158811108031,7.05528243550119,7.348728154231077,7.321928094887363,0.0,0.0,5.129283016944966,4.700439718141092,5.906890595608519,null,0.0,null,1.584962500721156,null,null,null,null,null,3.0,6.20945336562895,null,2.584962500721156,2.584962500721156,1.0,null,0.0,0.0,null,3.807354922057604,4.0,1.0,1.0,1.0,1.0,7.741466986401147,8.774787059601174,null,null,2.321928094887362,2.0,2.0,null,6.714245517666122,null,3.700439718141092,3.4594316186372973,5.906890595608519,5.614709844115208,4.321928094887363,4.0,4.459431618637297,4.700439718141092,5.087462841250339,4.087462841250339,7.011227255423254,7.734709620225838,6.894817763307944,3.807354922057604,4.954196310386875,4.700439718141092,4.954196310386875,3.0,4.392317422778761,4.392317422778761,4.392317422778761,8.879583249612784,9.283088353024002,6.643856189774724,5.832890014164741,6.409390936137702,6.409390936137702,5.906890595608519,4.954196310386875,4.954196310386875,4.954196310386875,4.906890595608519,5.857980995127572,6.918863237274595,3.4594316186372973,5.754887502163468,9.197216693110052,4.247927513443585,4.247927513443585,7.60733031374961,4.087462841250339,5.857980995127572,6.569855608330948,6.523561956057013,0.0,null,0.0,null,null,0.0,null,null,0.0,null,null,null,1.584962500721156,1.0,null,null,null,null,null,0.0,4.643856189774724,1.0,null,null,null,3.169925001442312,0.0,0.0,0.0,0.0,null,3.169925001442312,null,1.0,1.584962500721156,null,null,1.584962500721156,null,1.0,0.0,0.0,4.754887502163468,4.754887502163468,4.584962500721156,3.9068905956085187,4.523561956057013,4.754887502163468,4.584962500721156,3.9068905956085187,6.189824558880018,7.679480099505446,6.392317422778761,4.0,5.169925001442312,5.523561956057013,4.954196310386875,5.614709844115208,4.169925001442312,4.643856189774724,4.643856189774724,8.169925001442312,8.778077129535358,7.1799090900149345,6.087462841250339,7.022367813028454,6.491853096329675,5.977279923499917,5.044394119358453,5.044394119358453,5.044394119358453,5.044394119358453,5.906890595608519,7.03342300153745,3.321928094887362,5.491853096329675,8.087462841250339,4.643856189774724,4.643856189774724,8.108524456778168,5.321928094887363,5.614709844115208,6.614709844115208,6.539158811108031,6.087462841250339,6.285402218862249,5.614709844115208,5.584962500721156,5.807354922057604,5.700439718141092,5.584962500721156,4.807354922057604,6.845490050944375,6.845490050944375,7.011227255423254,4.700439718141092,5.392317422778761,6.303780748177103,6.0,6.584962500721156,4.523561956057013,5.169925001442312,5.169925001442312,7.60733031374961,7.7615512324444795,8.076815597050832,7.098032082960526,7.584962500721156,7.774787059601174,6.930737337562887,6.129283016944966,6.129283016944966,6.129283016944966,6.129283016944966,6.906890595608519,8.022367813028454,null,7.03342300153745,9.159871336778389,6.149747119504682,6.149747119504682,6.475733430966398,6.087462841250339,7.20945336562895,7.0,7.011227255423254,5.857980995127572,5.807354922057604,4.523561956057013,5.0,6.189824558880018,6.129283016944966,5.247927513443585,5.169925001442312,7.159871336778389,7.864186144654281,7.066089190457772,5.285402218862249,5.930737337562887,6.022367813028454,5.247927513443585,5.129283016944966,4.754887502163468,5.930737337562887,5.930737337562887,9.199672344836364,9.848622940429339,7.864186144654281,6.870364719583405,7.584962500721156,7.2761244052742375,6.442943495848728,5.643856189774724,5.614709844115208,5.614709844115208,5.614709844115208,7.05528243550119,8.144658242831882,2.0,6.339850002884624,9.958552715431011,6.022367813028454,6.022367813028454,8.63662462054365,7.409390936137702,7.366322214245816,6.965784284662087,6.977279923499917,7.108524456778169,7.087462841250339,5.321928094887363,6.044394119358453,7.066089190457772,7.339850002884624,6.169925001442312,6.426264754702098,8.044394119358454,8.707359132080883,7.60733031374961,5.554588851677638,6.727920454563199,7.266786540694901,6.523561956057013,6.539158811108031,6.149747119504682,6.442943495848728,6.442943495848728,9.794415866350105,10.0,8.873444112515376,8.118941072723507,8.717676423066395,8.603626344986193,7.7615512324444795,6.870364719583405,6.870364719583405,6.870364719583405,6.870364719583405,7.851749041416057,8.954196310386875,4.459431618637297,7.643856189774724,10.015415052386688,6.539158811108031,6.539158811108031,8.72451385311995,7.219168520462161,7.467605550082998,8.228818690495881,8.238404739325079,8.027905996569885,7.906890595608519,6.584962500721156,6.882643049361842,8.0,7.2384047393250786,6.303780748177103,6.78135971352466,8.734709620225837,9.08214904135387,8.703903573444663,6.247927513443585,7.7615512324444795,7.714245517666122,7.442943495848728,6.285402218862249,6.894817763307944,7.159871336778389,7.159871336778389,10.10459875356437,10.494855584491198,9.620219825507487,8.83605035505807,9.618385502258606,9.197216693110052,8.321928094887362,7.442943495848728,7.434628227636725,7.434628227636725,7.417852514885898,8.92184093707449,9.975847968006784,0.0,8.550746785383243,11.496853777388042,7.813781191217037,7.813781191217037,9.611024797307353,8.734709620225837,8.543031820255237,9.214319120800766,9.20945336562895,7.169925001442312,6.845490050944375,5.857980995127572,5.977279923499917,6.882643049361842,6.794415866350106,5.554588851677638,5.727920454563199,7.539158811108031,8.124121311829187,7.149747119504682,4.700439718141092,6.285402218862249,7.312882955284356,6.266786540694901,5.614709844115208,6.523561956057013,5.672425341971495,5.672425341971495,9.507794640198696,9.430452551665532,8.668884984266247,7.672425341971495,8.405141463136344,8.103287808412022,7.523561956057013,6.714245517666122,6.714245517666122,6.714245517666122,6.714245517666122,7.6865005271832185,8.751544059089099,2.807354922057604,7.417852514885898,10.754887502163468,6.3750394313469245,6.3750394313469245,8.682994583681683,7.098032082960526,7.409390936137702,7.906890595608519,7.876516946564999,6.022367813028454,4.643856189774724,3.321928094887362,4.321928094887363,4.459431618637297,5.392317422778761,5.392317422778761,5.321928094887363,6.954196310386875,7.159871336778389,7.022367813028454,3.807354922057604,5.977279923499917,6.614709844115208,3.9068905956085187,3.584962500721156,4.643856189774724,3.584962500721156,3.584962500721156,7.599912842187128,8.087462841250339,7.357552004618084,6.94251450533924,7.651051691178929,6.266786540694901,6.894817763307944,6.087462841250339,6.087462841250339,6.087462841250339,6.044394119358453,5.906890595608519,7.0,null,6.339850002884624,9.13699111208023,4.807354922057604,4.807354922057604,6.807354922057604,5.20945336562895,6.807354922057604,6.129283016944966,6.108524456778169,5.584962500721156,5.672425341971495,4.321928094887363,4.754887502163468,4.754887502163468,5.491853096329675,5.554588851677638,5.087462841250339,7.129283016944966,7.714245517666122,6.614709844115208,4.459431618637297,5.727920454563199,5.954196310386875,5.906890595608519,5.807354922057604,4.523561956057013,4.584962500721156,4.584962500721156,8.696967526234287,9.357552004618084,7.7615512324444795,6.794415866350106,7.3750394313469245,7.294620748891627,5.832890014164741,4.954196310386875,4.954196310386875,4.954196310386875,4.906890595608519,6.599912842187128,7.636624620543649,2.321928094887362,6.569855608330948,9.938109326219239,5.672425341971495,5.672425341971495,7.554588851677638,5.044394119358453,6.977279923499917,7.0,6.94251450533924,7.807354922057604,7.475733430966398,6.794415866350106,6.857980995127572,7.6293566200796095,7.523561956057013,7.199672344836364,6.700439718141092,8.960001932068081,9.355351096424812,9.052568050804153,6.20945336562895,7.700439718141092,8.055282435501189,7.357552004618084,6.741466986401147,7.076815597050831,6.714245517666122,6.714245517666122,10.43879185257826,10.968666793195208,9.684748620421626,8.867278739709661,9.62935662007961,9.154818109052105,8.507794640198696,7.6293566200796095,7.6293566200796095,7.6293566200796095,7.584962500721156,8.546894459887637,9.618385502258606,0.0,8.405141463136344,10.78135971352466,7.392317422778761,7.392317422778761,9.605479518061669,7.807354922057604,8.566054038171092,9.044394119358454,9.038918989292302,6.794415866350106,6.977279923499917,5.857980995127572,6.285402218862249,7.1799090900149345,6.727920454563199,6.426264754702098,5.807354922057604,7.98299357469431,8.92184093707449,8.228818690495881,5.78135971352466,6.643856189774724,7.348728154231077,6.658211482751795,6.426264754702098,6.189824558880018,6.266786540694901,6.266786540694901,9.992938336165814,10.396604781181859,9.250298417906333,8.139551352398794,8.839203788096944,8.527477006060396,7.857980995127572,6.977279923499917,6.977279923499917,6.977279923499917,6.965784284662087,8.03342300153745,9.147204924942228,3.4594316186372973,7.977279923499917,11.165535141377925,6.491853096329675,6.491853096329675,9.108524456778168,8.344295907915816,7.599912842187128,8.357552004618084,8.339850002884624,5.20945336562895,4.643856189774724,4.321928094887363,3.584962500721156,3.584962500721156,4.857980995127572,5.247927513443585,3.169925001442312,6.22881869049588,7.400879436282184,5.523561956057013,2.321928094887362,4.857980995127572,4.643856189774724,4.459431618637297,3.807354922057604,3.169925001442312,4.0,4.0,8.228818690495881,8.794415866350105,6.614709844115208,5.807354922057604,6.409390936137702,6.3750394313469245,4.700439718141092,4.0,4.0,4.0,3.9068905956085187,4.954196310386875,6.247927513443585,null,5.392317422778761,8.930737337562887,4.392317422778761,4.392317422778761,7.339850002884624,5.426264754702098,4.523561956057013,6.022367813028454,6.0,null,null,null,null,null,null,null,null,null,0.0,null,null,null,null,null,null,null,null,null,0.0,1.0,null,0.0,0.0,0.0,0.0,null,null,null,null,null,0.0,1.0,0.0,1.584962500721156,null,null,null,null,null,0.0,0.0,6.149747119504682,6.339850002884624,4.906890595608519,5.20945336562895,5.754887502163468,6.066089190457772,6.149747119504682,5.321928094887363,7.442943495848728,7.912889336229962,7.044394119358453,4.643856189774724,6.357552004618084,6.087462841250339,5.643856189774724,6.266786540694901,5.523561956057013,5.643856189774724,5.643856189774724,9.471675214392045,9.688250309133178,8.285402218862249,7.562242424221073,8.103287808412022,7.700439718141092,6.807354922057604,5.930737337562887,5.882643049361842,5.882643049361842,5.857980995127572,7.011227255423254,8.092757140919852,0.0,6.918863237274595,4.954196310386875,6.0,6.0,8.727920454563199,2.807354922057604,6.714245517666122,7.523561956057013,7.515699838284043,6.794415866350106,6.475733430966398,5.426264754702098,5.426264754702098,6.285402218862249,6.584962500721156,5.977279923499917,5.491853096329675,7.6865005271832185,8.76487159073609,7.924812503605781,4.807354922057604,6.727920454563199,6.672425341971495,5.78135971352466,6.266786540694901,5.321928094887363,5.584962500721156,5.584962500721156,9.49585502688717,10.036173612553485,8.703903573444663,7.434628227636725,8.098032082960527,7.924812503605781,7.3750394313469245,6.539158811108031,6.539158811108031,6.539158811108031,6.491853096329675,7.3750394313469245,8.413627929024173,6.523561956057013,7.169925001442312,9.696967526234287,6.129283016944966,6.129283016944966,8.968666793195208,6.3750394313469245,7.189824558880018,7.94251450533924,7.900866807980749,5.954196310386875,5.20945336562895,3.807354922057604,4.247927513443585,5.285402218862249,4.857980995127572,5.357552004618084,3.9068905956085187,6.906890595608519,7.924812503605781,6.129283016944966,4.0,5.857980995127572,5.614709844115208,5.285402218862249,4.169925001442312,5.087462841250339,5.129283016944966,5.129283016944966,8.569855608330949,9.426264754702098,7.442943495848728,6.714245517666122,7.392317422778761,7.22881869049588,6.754887502163468,5.857980995127572,5.857980995127572,5.857980995127572,5.857980995127572,5.727920454563199,6.820178962415188,3.0,5.882643049361842,8.632995197142957,4.954196310386875,4.954196310386875,7.768184324776926,5.357552004618084,6.321928094887363,6.6865005271832185,6.672425341971495,4.087462841250339,7.108524456778169,3.0,3.9068905956085187,5.044394119358453,4.0,3.584962500721156,3.584962500721156,4.523561956057013,5.321928094887363,3.9068905956085187,5.0,4.169925001442312,4.392317422778761,6.741466986401147,4.643856189774724,2.0,6.22881869049588,6.22881869049588,6.409390936137702,6.882643049361842,6.741466986401147,6.754887502163468,6.599912842187128,8.758223214726724,5.491853096329675,4.643856189774724,4.643856189774724,4.643856189774724,4.169925001442312,5.930737337562887,6.9886846867721655,null,4.700439718141092,0.0,6.754887502163468,6.754887502163468,5.129283016944966,0.0,5.0,8.442943495848729,8.417852514885897,5.882643049361842,5.700439718141092,4.0,4.247927513443585,3.9068905956085187,5.672425341971495,4.643856189774724,4.906890595608519,7.05528243550119,8.184875342908283,6.741466986401147,4.321928094887363,6.044394119358453,5.614709844115208,5.247927513443585,4.754887502163468,4.584962500721156,4.643856189774724,4.643856189774724,9.197216693110052,9.513727595952437,7.672425341971495,6.714245517666122,7.129283016944966,7.266786540694901,6.169925001442312,5.044394119358453,5.044394119358453,5.044394119358453,5.044394119358453,6.108524456778169,7.247927513443585,4.087462841250339,6.459431618637297,9.76487159073609,4.700439718141092,4.700439718141092,8.491853096329674,5.930737337562887,6.6865005271832185,6.832890014164741,6.832890014164741,6.022367813028454,4.954196310386875,4.169925001442312,4.169925001442312,4.906890595608519,5.584962500721156,4.906890595608519,4.523561956057013,6.643856189774724,7.459431618637297,6.554588851677638,4.321928094887363,6.129283016944966,5.129283016944966,4.754887502163468,4.584962500721156,4.392317422778761,4.857980995127572,4.857980995127572,8.7714894695006,9.036173612553485,7.531381460516312,6.303780748177103,6.94251450533924,6.965784284662087,6.20945336562895,5.459431618637297,5.459431618637297,5.459431618637297,5.459431618637297,5.906890595608519,6.965784284662087,null,5.129283016944966,9.29920801838728,5.0,5.0,7.409390936137702,4.954196310386875,5.977279923499917,6.807354922057604,6.727920454563199,7.882643049361842,7.930737337562887,7.011227255423254,7.475733430966398,8.124121311829187,7.700439718141092,7.066089190457772,7.189824558880018,8.826548487290914,9.29232163280204,8.717676423066395,5.882643049361842,7.734709620225838,8.08214904135387,7.357552004618084,7.294620748891627,7.294620748891627,7.076815597050831,7.076815597050831,10.361943773735241,10.855647166027266,9.776433032444734,8.971543553950772,9.746514321138463,9.228818690495881,8.64745842645492,7.787902559391432,7.787902559391432,7.787902559391432,7.78135971352466,9.044394119358454,10.11504365016171,5.523561956057013,8.710806433699352,11.741466986401146,7.098032082960526,7.108524456778169,9.632995197142957,8.888743248898258,8.50382573799575,9.177419537989236,9.162391328756906,7.129283016944966,6.475733430966398,5.426264754702098,5.78135971352466,6.247927513443585,6.3750394313469245,6.189824558880018,5.930737337562887,7.965784284662087,8.731319031025064,7.813781191217037,5.392317422778761,6.845490050944375,6.754887502163468,6.022367813028454,5.857980995127572,5.426264754702098,6.189824558880018,6.189824558880018,9.172427508645482,10.213104219641906,8.491853096329674,7.882643049361842,8.396604781181859,8.066089190457772,7.330916878114617,6.491853096329675,6.475733430966398,6.475733430966398,6.475733430966398,7.60733031374961,8.651051691178928,1.584962500721156,7.199672344836364,10.615629636968098,6.149747119504682,6.149747119504682,8.228818690495881,6.6865005271832185,7.108524456778169,7.94251450533924,7.924812503605781,6.189824558880018,5.78135971352466,5.321928094887363,5.584962500721156,5.754887502163468,5.491853096329675,5.491853096329675,4.459431618637297,7.266786540694901,8.038918989292302,7.392317422778761,4.906890595608519,5.169925001442312,6.459431618637297,6.0,5.882643049361842,4.700439718141092,5.523561956057013,5.523561956057013,8.930737337562887,9.721099188707186,8.179909090014934,6.906890595608519,7.6653359171851765,7.554588851677638,7.129283016944966,6.189824558880018,6.169925001442312,6.169925001442312,6.129283016944966,6.832890014164741,7.906890595608519,0.0,6.569855608330948,10.311748315004959,6.129283016944966,6.129283016944966,8.134426320220927,6.965784284662087,6.820178962415188,7.20945336562895,7.159871336778389,6.6293566200796095,6.459431618637297,4.321928094887363,5.584962500721156,6.459431618637297,6.20945336562895,5.614709844115208,6.044394119358453,7.442943495848728,8.027905996569885,7.3750394313469245,4.700439718141092,6.584962500721156,6.554588851677638,5.247927513443585,5.882643049361842,5.832890014164741,5.977279923499917,5.977279923499917,9.375039431346925,9.842350343413807,8.348728154231077,7.546894459887636,8.164906926675688,7.864186144654281,7.312882955284356,6.409390936137702,6.409390936137702,6.409390936137702,6.3750394313469245,7.475733430966398,8.531381460516313,3.4594316186372973,6.832890014164741,10.290018846932618,5.087462841250339,5.087462841250339,7.965784284662087,6.303780748177103,6.857980995127572,7.554588851677638,7.531381460516312,5.832890014164741,5.672425341971495,4.584962500721156,4.0,5.20945336562895,5.906890595608519,3.321928094887362,4.906890595608519,6.820178962415188,7.247927513443585,5.78135971352466,3.9068905956085187,4.754887502163468,5.321928094887363,5.129283016944966,3.0,4.584962500721156,5.169925001442312,5.169925001442312,8.618385502258606,9.211888294546004,7.658211482751795,7.03342300153745,7.651051691178929,6.930737337562887,6.22881869049588,5.285402218862249,5.247927513443585,5.247927513443585,5.20945336562895,6.741466986401147,7.794415866350106,null,6.087462841250339,9.62935662007961,4.857980995127572,4.857980995127572,7.499845887083206,5.700439718141092,5.857980995127572,6.599912842187128,6.554588851677638,null,null,null,null,null,0.0,null,null,null,null,null,0.0,0.0,null,null,null,null,null,null,1.584962500721156,4.169925001442312,0.0,null,1.0,0.0,2.321928094887362,null,null,null,null,null,3.0,null,2.584962500721156,1.0,2.0,2.0,0.0,0.0,2.0,null,null,5.954196310386875,5.832890014164741,4.584962500721156,4.392317422778761,5.491853096329675,5.78135971352466,5.954196310386875,4.954196310386875,6.965784284662087,7.584962500721156,6.700439718141092,4.321928094887363,5.554588851677638,6.022367813028454,5.247927513443585,6.087462841250339,4.247927513443585,4.857980995127572,4.857980995127572,8.348728154231077,9.074141462752506,7.930737337562887,6.727920454563199,7.515699838284043,7.2384047393250786,6.189824558880018,5.20945336562895,5.20945336562895,5.20945336562895,5.20945336562895,6.169925001442312,7.366322214245816,null,6.357552004618084,8.92184093707449,5.247927513443585,5.247927513443585,7.6293566200796095,5.672425341971495,6.321928094887363,7.108524456778169,7.044394119358453,5.857980995127572,6.044394119358453,4.321928094887363,4.459431618637297,5.491853096329675,5.807354922057604,4.392317422778761,4.807354922057604,7.266786540694901,8.303780748177102,7.118941072723508,4.459431618637297,6.409390936137702,5.930737337562887,4.906890595608519,4.807354922057604,4.906890595608519,4.754887502163468,4.754887502163468,9.221587121264806,9.805743872151618,7.98299357469431,6.857980995127572,7.734709620225838,7.483815777264256,6.754887502163468,6.022367813028454,6.0,6.0,5.954196310386875,6.392317422778761,7.434628227636725,3.321928094887362,6.357552004618084,9.847057346091336,5.321928094887363,5.321928094887363,7.94251450533924,5.459431618637297,6.285402218862249,7.044394119358453,7.0,5.700439718141092,5.285402218862249,3.584962500721156,4.169925001442312,4.954196310386875,4.954196310386875,4.0,4.087462841250339,6.392317422778761,7.459431618637297,6.3750394313469245,2.321928094887362,4.392317422778761,5.20945336562895,4.247927513443585,4.392317422778761,4.700439718141092,4.584962500721156,4.584962500721156,8.103287808412022,9.189824558880018,7.139551352398794,6.3750394313469245,7.149747119504682,6.658211482751795,5.700439718141092,4.857980995127572,4.857980995127572,4.857980995127572,4.857980995127572,5.807354922057604,6.918863237274595,2.321928094887362,5.321928094887363,9.451211111832329,4.700439718141092,4.700439718141092,7.129283016944966,6.108524456778169,5.857980995127572,6.459431618637297,6.426264754702098,8.285402218862249,8.39231742277876,7.247927513443585,7.6293566200796095,8.507794640198696,8.124121311829187,7.076815597050831,7.768184324776926,8.930737337562887,9.005624549193879,9.167418145831737,7.266786540694901,8.108524456778168,8.826548487290914,7.539158811108031,7.426264754702098,7.499845887083206,7.554588851677638,7.554588851677638,10.318542809702723,10.749031382040204,10.156083076288681,9.543031820255237,10.274960472140602,9.566054038171092,9.036173612553485,8.103287808412022,8.098032082960527,8.098032082960527,8.087462841250339,9.219168520462162,10.293471648838134,4.0,8.945443836377912,10.949097155729207,7.727920454563199,7.727920454563199,9.400879436282183,8.64745842645492,8.857980995127573,9.403012023574997,9.396604781181859,6.044394119358453,5.523561956057013,4.700439718141092,5.321928094887363,5.700439718141092,4.700439718141092,5.672425341971495,5.0,7.169925001442312,7.483815777264256,6.169925001442312,3.700439718141092,5.643856189774724,5.700439718141092,4.754887502163468,5.857980995127572,4.523561956057013,4.754887502163468,4.754887502163468,8.335390354693924,9.324180546618742,7.826548487290915,6.599912842187128,7.592457037268081,7.383704292474052,6.321928094887363,5.426264754702098,5.426264754702098,5.426264754702098,5.426264754702098,6.6293566200796095,7.7615512324444795,6.491853096329675,6.392317422778761,3.9068905956085187,5.491853096329675,5.491853096329675,7.515699838284043,null,6.6293566200796095,6.554588851677638,6.569855608330948,7.199672344836364,6.741466986401147,5.584962500721156,6.066089190457772,6.599912842187128,6.658211482751795,6.247927513443585,5.807354922057604,8.049848549450562,8.804131021183318,7.977279923499917,5.129283016944966,6.94251450533924,7.066089190457772,6.044394119358453,6.977279923499917,6.108524456778169,6.442943495848728,6.442943495848728,9.79603960882977,10.31741261376487,8.885696373339394,7.826548487290915,8.581200581924957,8.285402218862249,7.60733031374961,6.727920454563199,6.727920454563199,6.727920454563199,6.727920454563199,8.016808287686555,9.108524456778168,7.2761244052742375,7.03342300153745,9.710806433699352,6.189824558880018,6.189824558880018,8.487840033823051,6.857980995127572,7.546894459887636,8.370687406807217,8.348728154231077,7.554588851677638,7.651051691178929,6.614709844115208,6.442943495848728,7.257387842692652,7.098032082960526,7.169925001442312,6.584962500721156,8.098032082960527,8.164906926675688,7.845490050944375,6.247927513443585,7.199672344836364,7.507794640198696,6.491853096329675,7.098032082960526,6.459431618637297,6.807354922057604,6.807354922057604,9.64745842645492,9.945443836377912,9.236014191900084,8.483815777264256,9.31741261376487,9.014020470314934,8.189824558880018,7.366322214245816,7.357552004618084,7.357552004618084,7.348728154231077,8.308339030139408,9.388017285345136,2.584962500721156,8.164906926675688,10.00982861736811,7.169925001442312,7.169925001442312,7.832890014164741,7.434628227636725,7.7481928495894605,8.588714635582264,8.588714635582264,7.499845887083206,7.312882955284356,5.672425341971495,5.977279923499917,7.294620748891627,6.741466986401147,6.285402218862249,6.357552004618084,8.066089190457772,8.679480099505446,7.800899899920305,5.954196310386875,6.475733430966398,7.409390936137702,6.169925001442312,6.108524456778169,6.523561956057013,6.768184324776926,6.768184324776926,9.611024797307353,10.281930026955443,9.179909090014934,8.321928094887362,9.038918989292302,8.92481250360578,8.071462362556623,7.1799090900149345,7.1799090900149345,7.1799090900149345,7.1799090900149345,8.055282435501189,9.157346935362844,null,7.434628227636725,9.90839262077375,6.672425341971495,6.672425341971495,8.321928094887362,7.357552004618084,7.622051819456376,8.417852514885897,8.388017285345136,6.599912842187128,6.3750394313469245,5.554588851677638,4.954196310386875,6.22881869049588,5.754887502163468,5.285402218862249,5.044394119358453,7.149747119504682,7.954196310386875,7.321928094887363,4.954196310386875,5.954196310386875,6.6293566200796095,5.930737337562887,5.247927513443585,5.584962500721156,6.108524456778169,6.108524456778169,9.087462841250339,9.46352437327118,8.467605550082997,7.400879436282184,8.108524456778168,7.954196310386875,7.3750394313469245,6.658211482751795,6.643856189774724,6.643856189774724,6.6293566200796095,7.330916878114617,8.366322214245816,2.584962500721156,6.918863237274595,9.357552004618084,6.169925001442312,6.169925001442312,7.60733031374961,6.149747119504682,7.3750394313469245,7.531381460516312,7.499845887083206,7.159871336778389,7.247927513443585,5.584962500721156,6.20945336562895,7.189824558880018,7.483815777264256,7.219168520462161,6.285402218862249,8.487840033823051,8.562242424221072,8.451211111832329,5.727920454563199,7.011227255423254,7.330916878114617,6.965784284662087,7.011227255423254,6.475733430966398,6.658211482751795,6.658211482751795,9.497851836951117,10.46454575033394,9.326429487122303,8.228818690495881,8.857980995127573,9.041659151637214,8.515699838284043,7.651051691178929,7.651051691178929,7.651051691178929,7.651051691178929,8.247927513443585,9.346513733165635,1.584962500721156,7.813781191217037,10.266786540694902,7.011227255423254,7.011227255423254,9.41574176829009,7.451211111832329,8.011227255423254,8.539158811108031,8.507794640198696,5.20945336562895,5.20945336562895,4.523561956057013,4.169925001442312,4.0,3.807354922057604,4.321928094887363,4.0,6.614709844115208,7.189824558880018,5.459431618637297,4.392317422778761,5.357552004618084,4.857980995127572,4.954196310386875,5.087462841250339,4.643856189774724,3.700439718141092,3.700439718141092,8.228818690495881,9.187352073200497,7.366322214245816,5.954196310386875,6.6293566200796095,6.321928094887363,5.643856189774724,4.807354922057604,4.807354922057604,4.807354922057604,4.754887502163468,5.459431618637297,6.599912842187128,0.0,5.954196310386875,8.108524456778168,5.129283016944966,5.129283016944966,7.467605550082998,4.954196310386875,5.643856189774724,6.392317422778761,6.357552004618084,null,null,null,null,0.0,null,null,null,null,0.0,null,null,1.0,null,null,0.0,null,null,null,null,3.0,null,null,null,null,null,null,null,null,null,null,2.0,null,2.0,2.584962500721156,0.0,0.0,2.321928094887362,null,null,0.0,0.0,7.108524456778169,6.94251450533924,4.807354922057604,5.754887502163468,6.832890014164741,6.845490050944375,5.832890014164741,6.087462841250339,8.243173983472952,8.89178370321831,7.643856189774724,5.357552004618084,6.918863237274595,6.94251450533924,5.930737337562887,5.857980995127572,5.426264754702098,6.475733430966398,6.475733430966398,9.751544059089099,10.508785162064513,8.98299357469431,8.011227255423254,8.86418614465428,8.519636252843213,7.693486957499325,6.820178962415188,6.807354922057604,6.807354922057604,6.78135971352466,7.693486957499325,8.800899899920305,3.700439718141092,7.303780748177103,10.825753832883112,6.392317422778761,6.392317422778761,8.665335917185176,6.930737337562887,7.636624620543649,8.43879185257826,8.430452551665532,6.247927513443585,5.614709844115208,5.554588851677638,4.954196310386875,5.954196310386875,4.807354922057604,5.087462841250339,5.087462841250339,7.189824558880018,7.459431618637297,6.507794640198696,4.321928094887363,5.807354922057604,5.977279923499917,5.584962500721156,5.392317422778761,4.523561956057013,4.954196310386875,4.954196310386875,9.030667136246942,9.449148645375436,7.888743248898259,6.614709844115208,7.531381460516312,7.392317422778761,6.266786540694901,5.321928094887363,5.285402218862249,5.285402218862249,5.285402218862249,7.03342300153745,8.092757140919852,null,6.523561956057013,8.848622940429339,6.022367813028454,6.022367813028454,8.59245703726808,5.832890014164741,6.845490050944375,7.066089190457772,7.044394119358453,7.044394119358453,6.426264754702098,5.169925001442312,5.584962500721156,6.321928094887363,6.409390936137702,6.044394119358453,5.727920454563199,7.6293566200796095,8.622051819456376,7.7073591320808825,5.247927513443585,6.845490050944375,6.3750394313469245,5.857980995127572,5.977279923499917,5.754887502163468,6.22881869049588,6.22881869049588,9.485829308701904,10.358651200892886,8.703903573444663,7.851749041416057,8.527477006060396,8.184875342908283,6.857980995127572,6.169925001442312,6.169925001442312,6.169925001442312,6.149747119504682,7.2384047393250786,8.339850002884624,1.0,7.189824558880018,9.784634845557521,6.169925001442312,6.169925001442312,9.055282435501189,6.643856189774724,7.475733430966398,7.813781191217037,7.800899899920305,6.614709844115208,6.643856189774724,4.643856189774724,5.832890014164741,6.149747119504682,6.507794640198696,6.22881869049588,5.169925001442312,7.7615512324444795,8.219168520462162,7.417852514885898,4.807354922057604,5.78135971352466,6.285402218862249,5.882643049361842,5.807354922057604,5.554588851677638,5.857980995127572,5.857980995127572,8.98299357469431,9.965784284662087,8.651051691178928,7.475733430966398,8.308339030139408,7.888743248898259,7.339850002884624,6.539158811108031,6.539158811108031,6.539158811108031,6.539158811108031,7.330916878114617,8.434628227636725,3.9068905956085187,6.614709844115208,9.556506054671928,6.357552004618084,6.357552004618084,8.933690654952233,6.189824558880018,6.977279923499917,7.794415866350106,7.741466986401147,4.754887502163468,4.321928094887363,4.459431618637297,3.700439718141092,4.169925001442312,3.807354922057604,3.584962500721156,3.700439718141092,5.20945336562895,6.442943495848728,5.357552004618084,3.169925001442312,5.044394119358453,5.087462841250339,3.9068905956085187,5.20945336562895,3.584962500721156,4.169925001442312,4.169925001442312,6.965784284662087,7.651051691178929,6.409390936137702,5.20945336562895,6.0,5.954196310386875,4.954196310386875,3.9068905956085187,3.9068905956085187,3.9068905956085187,3.9068905956085187,5.285402218862249,6.426264754702098,1.0,5.426264754702098,2.807354922057604,3.807354922057604,3.807354922057604,7.294620748891627,null,5.0,5.321928094887363,5.285402218862249,7.6293566200796095,7.22881869049588,5.584962500721156,6.700439718141092,7.636624620543649,7.022367813028454,6.870364719583405,6.894817763307944,8.139551352398794,8.405141463136344,7.794415866350106,4.459431618637297,7.118941072723508,7.774787059601174,7.098032082960526,6.857980995127572,6.426264754702098,6.977279923499917,6.977279923499917,9.348728154231077,10.187352073200497,9.357552004618084,8.348728154231077,9.211888294546004,8.842350343413807,7.700439718141092,6.754887502163468,6.754887502163468,6.754887502163468,6.754887502163468,8.422064766172813,9.475733430966399,4.247927513443585,7.912889336229962,10.17617314910749,6.857980995127572,6.857980995127572,8.957102041562287,7.507794640198696,7.614709844115208,8.643856189774725,8.62935662007961,6.741466986401147,6.108524456778169,5.727920454563199,5.700439718141092,6.832890014164741,6.894817763307944,6.044394119358453,5.672425341971495,7.794415866350106,8.519636252843213,7.467605550082998,5.247927513443585,6.569855608330948,6.727920454563199,6.129283016944966,5.523561956057013,5.882643049361842,5.78135971352466,5.78135971352466,9.428360172704291,10.156083076288681,8.754887502163468,7.813781191217037,8.434628227636725,8.092757140919852,7.087462841250339,6.22881869049588,6.22881869049588,6.22881869049588,6.20945336562895,7.577428828035749,8.62935662007961,0.0,7.169925001442312,10.430452551665532,6.714245517666122,6.727920454563199,9.134426320220927,6.507794640198696,7.129283016944966,8.479780264029099,8.467605550082997,5.954196310386875,4.906890595608519,3.321928094887362,3.807354922057604,4.954196310386875,5.392317422778761,5.426264754702098,4.247927513443585,6.584962500721156,7.303780748177103,6.285402218862249,4.321928094887363,5.554588851677638,5.20945336562895,4.584962500721156,5.523561956057013,4.857980995127572,3.169925001442312,3.169925001442312,7.483815777264256,8.997179480937621,7.651051691178929,6.066089190457772,6.794415866350106,6.820178962415188,6.087462841250339,5.285402218862249,5.285402218862249,5.285402218862249,5.20945336562895,6.22881869049588,7.285402218862249,3.169925001442312,5.614709844115208,7.9886846867721655,5.247927513443585,5.247927513443585,6.930737337562887,5.20945336562895,5.78135971352466,6.614709844115208,6.539158811108031,6.303780748177103,6.392317422778761,6.266786540694901,5.727920454563199,6.554588851677638,6.894817763307944,6.149747119504682,5.700439718141092,7.348728154231077,7.906890595608519,7.475733430966398,5.523561956057013,6.554588851677638,6.357552004618084,6.285402218862249,6.044394119358453,5.754887502163468,5.700439718141092,5.700439718141092,9.154818109052105,9.873444112515376,8.483815777264256,7.584962500721156,8.144658242831882,8.154818109052105,7.219168520462161,6.303780748177103,6.303780748177103,6.303780748177103,6.303780748177103,7.622051819456376,8.661778097771988,null,7.348728154231077,9.513727595952437,6.357552004618084,6.3750394313469245,8.86418614465428,6.930737337562887,7.3750394313469245,7.409390936137702,7.392317422778761,6.700439718141092,5.754887502163468,5.523561956057013,4.807354922057604,6.108524456778169,6.507794640198696,5.977279923499917,5.491853096329675,7.7615512324444795,8.271463027904375,7.219168520462161,4.643856189774724,5.700439718141092,6.768184324776926,5.832890014164741,5.523561956057013,4.754887502163468,5.882643049361842,5.882643049361842,8.96289600533726,10.310612781659529,8.447083226209653,7.515699838284043,8.098032082960527,8.214319120800766,7.022367813028454,6.303780748177103,6.303780748177103,6.303780748177103,6.22881869049588,6.9886846867721655,8.08214904135387,2.321928094887362,6.882643049361842,9.321928094887362,6.108524456778169,6.108524456778169,8.897845456005511,6.285402218862249,6.918863237274595,7.459431618637297,7.459431618637297,4.643856189774724,4.169925001442312,3.807354922057604,2.807354922057604,4.087462841250339,4.392317422778761,4.700439718141092,4.584962500721156,6.523561956057013,6.94251450533924,5.614709844115208,3.807354922057604,4.523561956057013,4.700439718141092,4.643856189774724,4.169925001442312,3.584962500721156,4.321928094887363,4.321928094887363,7.924812503605781,9.149747119504681,7.285402218862249,5.392317422778761,6.392317422778761,6.584962500721156,5.554588851677638,4.584962500721156,4.584962500721156,4.584962500721156,4.584962500721156,5.044394119358453,6.169925001442312,3.169925001442312,4.857980995127572,7.820178962415188,3.9068905956085187,3.9068905956085187,7.98299357469431,4.392317422778761,5.087462841250339,6.285402218862249,6.247927513443585,0.0,null,null,null,0.0,1.0,null,null,null,null,null,null,null,0.0,null,0.0,null,null,null,0.0,2.0,1.0,null,null,0.0,0.0,null,null,null,null,null,3.0,null,null,2.0,null,null,1.584962500721156,null,null,null,null,7.159871336778389,6.870364719583405,6.0,6.087462841250339,6.754887502163468,6.700439718141092,6.303780748177103,5.930737337562887,8.252665432450248,8.379378367071261,7.499845887083206,5.754887502163468,7.20945336562895,6.930737337562887,6.247927513443585,6.727920454563199,5.807354922057604,5.672425341971495,5.672425341971495,9.60733031374961,10.41679752760606,8.954196310386875,7.754887502163468,8.599912842187127,8.467605550082997,7.312882955284356,6.554588851677638,6.554588851677638,6.554588851677638,6.554588851677638,7.651051691178929,8.679480099505446,6.247927513443585,7.554588851677638,10.264442600226602,6.906890595608519,6.918863237274595,8.144658242831882,6.6293566200796095,7.507794640198696,8.139551352398794,8.118941072723507,5.977279923499917,5.459431618637297,4.906890595608519,4.321928094887363,4.857980995127572,5.832890014164741,5.727920454563199,4.857980995127572,6.6865005271832185,7.721099188707185,6.491853096329675,2.321928094887362,5.807354922057604,5.614709844115208,5.247927513443585,5.523561956057013,5.129283016944966,5.087462841250339,5.087462841250339,8.689997971419446,9.649256177517314,7.60733031374961,6.807354922057604,7.483815777264256,7.475733430966398,6.459431618637297,5.584962500721156,5.584962500721156,5.584962500721156,5.554588851677638,6.491853096329675,7.475733430966398,2.0,6.247927513443585,9.7714894695006,5.807354922057604,5.807354922057604,8.290018846932618,6.442943495848728,6.169925001442312,7.20945336562895,7.169925001442312,6.087462841250339,5.78135971352466,5.0,4.392317422778761,5.491853096329675,6.247927513443585,5.0,4.754887502163468,7.294620748891627,8.20945336562895,7.022367813028454,3.807354922057604,6.392317422778761,6.22881869049588,5.672425341971495,5.392317422778761,4.754887502163468,5.044394119358453,5.044394119358453,8.515699838284043,9.85642552862553,7.787902559391432,7.129283016944966,7.693486957499325,7.451211111832329,6.507794640198696,5.700439718141092,5.700439718141092,5.700439718141092,5.672425341971495,6.584962500721156,7.636624620543649,null,6.339850002884624,10.040289721025717,5.807354922057604,5.807354922057604,8.375039431346925,5.832890014164741,6.599912842187128,7.491853096329675,7.467605550082998,7.700439718141092,7.554588851677638,6.357552004618084,6.754887502163468,7.6865005271832185,6.554588851677638,6.714245517666122,6.714245517666122,8.169925001442312,8.974414589805527,8.179909090014934,6.044394119358453,7.531381460516312,7.321928094887363,6.643856189774724,6.78135971352466,6.303780748177103,6.3750394313469245,6.3750394313469245,10.204571144249204,10.829722735086058,9.552669097514272,8.396604781181859,9.269126679149418,8.977279923499916,8.087462841250339,7.1799090900149345,7.1799090900149345,7.1799090900149345,7.1799090900149345,8.643856189774725,9.731319031025064,4.169925001442312,8.129283016944967,10.46352437327118,7.118941072723508,7.118941072723508,9.605479518061669,7.434628227636725,8.189824558880018,8.679480099505446,8.668884984266247,7.199672344836364,6.672425341971495,5.523561956057013,6.0,6.3750394313469245,6.475733430966398,5.426264754702098,5.906890595608519,7.531381460516312,8.39231742277876,7.475733430966398,4.754887502163468,6.392317422778761,6.714245517666122,6.108524456778169,6.539158811108031,5.857980995127572,6.20945336562895,6.20945336562895,9.473705749619416,10.029287226968245,8.686500527183219,7.977279923499917,8.569855608330949,8.618385502258606,7.189824558880018,6.3750394313469245,6.3750394313469245,6.3750394313469245,6.3750394313469245,7.6653359171851765,8.744833837499545,4.459431618637297,7.467605550082998,9.804131021183318,6.3750394313469245,6.3750394313469245,8.46352437327118,7.108524456778169,7.339850002884624,8.124121311829187,8.103287808412022,8.46352437327118,8.044394119358454,7.467605550082998,7.851749041416057,8.804131021183318,7.876516946564999,6.507794640198696,7.339850002884624,8.86418614465428,9.149747119504681,8.888743248898258,7.554588851677638,7.882643049361842,7.954196310386875,7.531381460516312,8.113742166049189,7.118941072723508,7.727920454563199,7.727920454563199,9.952741247186488,10.560332834212442,10.164906926675688,9.344295907915816,9.971543553950772,9.709083812550343,8.879583249612784,7.94251450533924,7.930737337562887,7.930737337562887,7.924812503605781,9.449148645375436,10.482807956726667,4.700439718141092,8.936637939002571,11.806549621985962,7.467605550082998,7.475733430966398,8.980139577639157,8.294620748891626,9.084808387804362,9.509775004326936,9.505811553919594,5.584962500721156,5.357552004618084,5.247927513443585,5.20945336562895,6.087462841250339,5.523561956057013,4.643856189774724,4.584962500721156,6.918863237274595,7.592457037268081,6.832890014164741,4.700439718141092,6.066089190457772,5.882643049361842,5.426264754702098,5.700439718141092,5.169925001442312,5.044394119358453,5.044394119358453,7.845490050944375,9.375039431346925,8.159871336778389,7.066089190457772,7.727920454563199,7.491853096329675,6.459431618637297,5.672425341971495,5.672425341971495,5.672425341971495,5.672425341971495,6.554588851677638,7.679480099505446,0.0,5.906890595608519,8.682994583681683,5.754887502163468,5.754887502163468,7.357552004618084,6.169925001442312,6.357552004618084,7.2761244052742375,7.247927513443585,0.0,null,null,0.0,null,2.0,1.0,0.0,1.584962500721156,4.0,1.0,null,1.0,1.0,0.0,null,null,1.584962500721156,1.584962500721156,5.129283016944966,6.129283016944966,2.321928094887362,2.807354922057604,3.169925001442312,2.807354922057604,1.0,0.0,0.0,0.0,0.0,2.0,3.0,2.0,1.0,3.0,1.0,1.0,5.0,null,2.584962500721156,null,null,8.118941072723507,7.531381460516312,6.507794640198696,6.954196310386875,7.636624620543649,7.577428828035749,6.409390936137702,7.149747119504682,8.447083226209653,8.804131021183318,8.661778097771988,6.22881869049588,7.475733430966398,7.820178962415188,7.294620748891627,6.149747119504682,6.768184324776926,6.930737337562887,6.930737337562887,9.733015321685963,10.885696373339394,10.00842862207058,9.164906926675688,9.994353436858859,9.319672120946995,8.562242424221072,7.906890595608519,7.906890595608519,7.906890595608519,7.894817763307944,8.710806433699352,9.799281621521923,null,8.308339030139408,11.432019846812493,7.118941072723508,7.118941072723508,9.485829308701904,8.867278739709661,8.43879185257826,8.879583249612784,8.851749041416058,5.523561956057013,3.321928094887362,3.321928094887362,3.9068905956085187,4.906890595608519,3.9068905956085187,5.700439718141092,4.087462841250339,6.189824558880018,7.357552004618084,5.857980995127572,2.0,4.459431618637297,5.169925001442312,4.392317422778761,4.459431618637297,3.321928094887362,3.700439718141092,3.700439718141092,8.375039431346925,9.194756854422248,7.266786540694901,6.321928094887363,7.066089190457772,6.523561956057013,5.285402218862249,4.523561956057013,4.523561956057013,4.523561956057013,4.459431618637297,5.832890014164741,6.918863237274595,null,5.807354922057604,8.491853096329674,5.285402218862249,5.285402218862249,7.483815777264256,6.22881869049588,5.0,6.321928094887363,6.247927513443585,6.768184324776926,5.169925001442312,4.906890595608519,5.857980995127572,5.857980995127572,5.882643049361842,5.584962500721156,5.129283016944966,7.312882955284356,8.214319120800766,6.857980995127572,4.906890595608519,6.169925001442312,5.906890595608519,6.044394119358453,5.78135971352466,5.491853096329675,5.906890595608519,5.906890595608519,9.216745858195306,9.86418614465428,8.285402218862249,7.531381460516312,8.224001674198105,7.98299357469431,6.870364719583405,6.087462841250339,6.066089190457772,6.066089190457772,6.044394119358453,6.894817763307944,8.022367813028454,null,6.882643049361842,9.108524456778168,5.906890595608519,5.906890595608519,8.754887502163468,6.108524456778169,7.05528243550119,7.679480099505446,7.658211482751795,0.0,null,null,null,null,null,null,null,0.0,null,null,null,1.0,null,null,0.0,null,null,null,null,3.0,0.0,null,1.0,null,0.0,null,null,null,null,0.0,2.584962500721156,null,1.0,2.0,2.0,2.0,2.321928094887362,null,0.0,0.0,0.0,5.044394119358453,5.247927513443585,4.807354922057604,4.643856189774724,4.807354922057604,5.169925001442312,3.9068905956085187,3.807354922057604,5.754887502163468,6.426264754702098,5.78135971352466,4.321928094887363,4.700439718141092,4.523561956057013,4.247927513443585,4.700439718141092,3.584962500721156,4.392317422778761,4.392317422778761,7.2384047393250786,7.807354922057604,6.930737337562887,6.20945336562895,6.882643049361842,6.569855608330948,6.169925001442312,5.247927513443585,5.247927513443585,5.247927513443585,5.247927513443585,6.266786540694901,7.2761244052742375,null,4.321928094887363,8.829722735086058,4.643856189774724,4.643856189774724,6.569855608330948,6.087462841250339,5.426264754702098,5.882643049361842,5.727920454563199,6.820178962415188,6.554588851677638,5.584962500721156,6.044394119358453,6.727920454563199,5.727920454563199,5.672425341971495,5.169925001442312,7.0,7.247927513443585,7.721099188707185,5.357552004618084,6.599912842187128,6.339850002884624,5.554588851677638,6.491853096329675,5.584962500721156,5.930737337562887,5.930737337562887,8.326429487122303,9.25502856981873,8.479780264029099,7.366322214245816,8.055282435501189,7.930737337562887,7.257387842692652,6.409390936137702,6.409390936137702,6.409390936137702,6.392317422778761,7.392317422778761,8.400879436282183,1.0,7.1799090900149345,3.700439718141092,6.442943495848728,6.442943495848728,7.022367813028454,0.0,7.434628227636725,7.679480099505446,7.643856189774724,6.321928094887363,5.977279923499917,4.584962500721156,5.459431618637297,5.930737337562887,5.807354922057604,4.906890595608519,5.129283016944966,6.491853096329675,6.584962500721156,7.011227255423254,3.9068905956085187,6.149747119504682,5.78135971352466,5.807354922057604,5.672425341971495,5.285402218862249,5.247927513443585,5.247927513443585,7.7073591320808825,8.330916878114618,7.857980995127572,6.906890595608519,7.622051819456376,7.531381460516312,6.672425341971495,5.832890014164741,5.832890014164741,5.832890014164741,5.832890014164741,7.118941072723508,8.179909090014934,null,6.247927513443585,9.005624549193879,4.954196310386875,4.954196310386875,6.965784284662087,6.339850002884624,6.643856189774724,7.20945336562895,7.199672344836364,8.543031820255237,8.262094845370179,7.6293566200796095,7.882643049361842,8.842350343413807,8.060695931687555,7.622051819456376,7.515699838284043,8.774787059601174,9.139551352398794,8.915879378835774,6.870364719583405,8.353146825498083,8.375039431346925,7.727920454563199,8.550746785383243,7.562242424221073,7.539158811108031,7.539158811108031,9.851749041416058,10.480790201095816,10.323054760341646,9.35974956032233,10.192292814470767,9.654636028527968,8.86418614465428,7.918863237274595,7.918863237274595,7.918863237274595,7.918863237274595,9.513727595952437,10.566054038171092,7.108524456778169,8.991521846075695,12.044735626056909,7.643856189774724,7.643856189774724,9.339850002884624,9.59245703726808,9.296916206879288,9.78953364497036,9.787902559391432,8.290018846932618,7.60733031374961,6.643856189774724,7.247927513443585,7.870364719583405,7.820178962415188,6.930737337562887,7.303780748177103,8.654636028527968,8.64745842645492,8.57742882803575,6.754887502163468,7.672425341971495,7.721099188707185,7.459431618637297,7.78135971352466,7.312882955284356,7.442943495848728,7.442943495848728,9.162391328756906,9.896332403909941,9.912889336229961,8.918863237274595,9.583082767502933,9.560332834212442,8.257387842692651,7.330916878114617,7.330916878114617,7.330916878114617,7.330916878114617,9.113742166049189,10.161131882984307,3.584962500721156,8.672425341971495,10.746514321138463,8.184875342908283,8.184875342908283,9.14210705730255,8.103287808412022,8.62935662007961,9.172427508645482,9.144658242831882,7.845490050944375,7.845490050944375,7.734709620225838,8.43879185257826,9.044394119358454,8.199672344836364,6.870364719583405,7.357552004618084,8.668884984266247,8.569855608330949,8.870364719583405,6.614709844115208,7.584962500721156,7.807354922057604,7.459431618637297,8.63662462054365,7.2761244052742375,7.266786540694901,7.266786540694901,9.111135670234708,9.862637357558794,9.754887502163468,9.002815015607053,9.668884984266247,9.876516946565,8.689997971419446,7.679480099505446,7.672425341971495,7.672425341971495,7.672425341971495,9.911391987843459,10.940313597145968,4.169925001442312,8.550746785383243,10.700439718141093,7.78135971352466,7.78135971352466,8.335390354693924,9.076815597050832,8.78135971352466,9.584962500721156,9.586839787961827,6.954196310386875,6.845490050944375,6.129283016944966,6.539158811108031,7.434628227636725,6.599912842187128,4.754887502163468,6.189824558880018,7.948367231584678,7.900866807980749,7.839203788096944,5.247927513443585,7.257387842692652,7.22881869049588,6.870364719583405,5.643856189774724,6.491853096329675,6.643856189774724,6.643856189774724,8.92481250360578,9.590587049915035,9.060695931687555,8.20945336562895,8.870364719583405,8.721099188707186,7.592457037268081,6.714245517666122,6.714245517666122,6.714245517666122,6.700439718141092,8.189824558880018,9.252665432450248,1.584962500721156,7.734709620225838,9.826548487290914,7.022367813028454,7.022367813028454,8.257387842692651,7.149747119504682,7.727920454563199,8.303780748177102,8.280770770130603,7.523561956057013,7.149747119504682,6.459431618637297,6.918863237274595,7.658211482751795,7.257387842692652,5.906890595608519,6.643856189774724,8.179909090014934,8.0,8.139551352398794,5.882643049361842,7.066089190457772,7.149747119504682,6.918863237274595,6.845490050944375,6.539158811108031,6.569855608330948,6.569855608330948,8.951284714966972,9.659995892429977,9.4241662888181,8.603626344986193,9.187352073200497,8.991521846075695,8.049848549450562,7.285402218862249,7.285402218862249,7.285402218862249,7.266786540694901,8.640244936222345,9.702172685365548,3.321928094887362,8.189824558880018,10.30035256032822,6.870364719583405,6.870364719583405,8.459431618637296,7.930737337562887,7.98299357469431,8.59618975614441,8.562242424221072,7.1799090900149345,6.149747119504682,6.523561956057013,6.22881869049588,7.1799090900149345,6.727920454563199,5.459431618637297,5.954196310386875,7.546894459887636,7.658211482751795,7.888743248898259,5.392317422778761,6.491853096329675,6.523561956057013,6.3750394313469245,6.189824558880018,6.0,6.303780748177103,6.303780748177103,8.614709844115207,9.159871336778389,8.894817763307943,8.124121311829187,8.72451385311995,8.751544059089099,7.584962500721156,6.754887502163468,6.754887502163468,6.754887502163468,6.741466986401147,7.930737337562887,9.002815015607053,null,7.721099188707185,9.78953364497036,6.087462841250339,6.087462841250339,8.447083226209653,7.539158811108031,7.693486957499325,8.159871336778389,8.134426320220927,7.05528243550119,6.169925001442312,6.169925001442312,6.714245517666122,7.20945336562895,6.754887502163468,5.727920454563199,5.857980995127572,7.614709844115208,7.636624620543649,7.60733031374961,5.491853096329675,6.857980995127572,6.794415866350106,6.339850002884624,6.409390936137702,5.426264754702098,6.066089190457772,6.066089190457772,8.475733430966399,9.339850002884624,9.057991722759176,7.977279923499917,8.632995197142957,8.64745842645492,7.832890014164741,6.906890595608519,6.906890595608519,6.894817763307944,6.882643049361842,7.977279923499917,9.08214904135387,2.0,7.870364719583405,10.635718120331047,6.303780748177103,6.303780748177103,7.774787059601174,8.169925001442312,7.247927513443585,8.224001674198105,8.204571144249204,6.0,5.700439718141092,5.087462841250339,5.044394119358453,6.0,5.700439718141092,5.169925001442312,5.129283016944966,6.108524456778169,6.392317422778761,7.022367813028454,2.807354922057604,5.832890014164741,5.321928094887363,5.700439718141092,5.954196310386875,4.754887502163468,5.087462841250339,5.087462841250339,7.820178962415188,8.247927513443585,7.679480099505446,6.820178962415188,7.339850002884624,7.693486957499325,6.930737337562887,5.930737337562887,5.930737337562887,5.930737337562887,5.906890595608519,7.139551352398794,8.169925001442312,0.0,6.409390936137702,8.754887502163468,4.954196310386875,4.954196310386875,7.483815777264256,5.523561956057013,6.672425341971495,7.169925001442312,7.139551352398794,null,null,null,null,null,0.0,null,null,null,null,null,null,null,0.0,null,null,null,null,null,0.0,2.0,null,null,0.0,null,1.0,null,null,null,null,null,0.0,null,1.0,null,null,null,0.0,0.0,null,0.0,0.0,6.169925001442312,6.044394119358453,5.087462841250339,5.169925001442312,5.754887502163468,5.129283016944966,5.426264754702098,4.906890595608519,6.700439718141092,6.409390936137702,6.845490050944375,3.584962500721156,5.247927513443585,5.754887502163468,5.357552004618084,6.599912842187128,5.672425341971495,5.727920454563199,5.727920454563199,7.539158811108031,8.224001674198105,7.864186144654281,6.845490050944375,7.562242424221073,7.22881869049588,6.584962500721156,5.643856189774724,5.643856189774724,5.643856189774724,5.643856189774724,6.965784284662087,7.977279923499917,0.0,6.491853096329675,9.804131021183318,5.906890595608519,5.906890595608519,6.569855608330948,7.0,6.977279923499917,7.400879436282184,7.312882955284356,6.94251450533924,6.491853096329675,5.906890595608519,6.247927513443585,6.426264754702098,6.906890595608519,5.614709844115208,5.459431618637297,7.523561956057013,7.266786540694901,7.266786540694901,4.700439718141092,6.392317422778761,6.768184324776926,6.392317422778761,6.0,5.643856189774724,6.149747119504682,6.149747119504682,8.124121311829187,8.96289600533726,8.710806433699352,7.768184324776926,8.303780748177102,8.361943773735241,7.3750394313469245,6.614709844115208,6.614709844115208,6.614709844115208,6.614709844115208,8.016808287686555,9.016808287686555,2.321928094887362,7.321928094887363,10.752380646552893,6.507794640198696,6.507794640198696,7.6653359171851765,7.592457037268081,7.60733031374961,7.6293566200796095,7.562242424221073,5.614709844115208,5.0,4.754887502163468,4.754887502163468,5.426264754702098,4.643856189774724,3.321928094887362,4.247927513443585,5.906890595608519,6.768184324776926,6.022367813028454,2.584962500721156,4.857980995127572,5.247927513443585,4.906890595608519,4.584962500721156,4.523561956057013,4.643856189774724,4.643856189774724,7.022367813028454,7.507794640198696,7.199672344836364,6.169925001442312,6.807354922057604,6.754887502163468,5.954196310386875,5.20945336562895,5.20945336562895,5.20945336562895,5.169925001442312,5.906890595608519,6.954196310386875,null,5.426264754702098,8.405141463136344,5.087462841250339,5.087462841250339,5.954196310386875,5.392317422778761,6.643856189774724,6.129283016944966,6.087462841250339,8.948367231584678,8.768184324776927,7.658211482751795,8.375039431346925,8.861086905995395,8.50382573799575,7.60733031374961,7.507794640198696,9.326429487122303,9.283088353024002,9.622051819456376,7.066089190457772,8.471675214392045,8.791162888555018,8.224001674198105,8.055282435501189,7.679480099505446,7.870364719583405,7.870364719583405,10.233619676759702,10.639340708652231,10.468624042918018,9.674192268145683,10.383704292474052,9.868822554774999,9.400879436282183,8.45532722030456,8.451211111832329,8.451211111832329,8.413627929024173,9.905387005018131,10.95492329203032,4.169925001442312,9.192292814470767,11.597121428789569,8.049848549450562,8.049848549450562,9.859534786382653,1.0,9.703903573444663,9.90388184573618,9.897845456005511,6.189824558880018,5.882643049361842,5.672425341971495,5.426264754702098,6.22881869049588,6.129283016944966,6.022367813028454,5.491853096329675,7.044394119358453,7.189824558880018,7.219168520462161,4.169925001442312,5.857980995127572,5.614709844115208,5.285402218862249,6.643856189774724,5.426264754702098,5.247927513443585,5.247927513443585,7.6865005271832185,8.262094845370179,8.0,7.108524456778169,7.787902559391432,7.507794640198696,6.965784284662087,6.087462841250339,6.087462841250339,6.087462841250339,6.022367813028454,6.807354922057604,7.912889336229962,0.0,6.918863237274595,9.022367813028454,5.857980995127572,5.857980995127572,6.965784284662087,5.906890595608519,6.845490050944375,7.22881869049588,7.22881869049588,7.870364719583405,7.754887502163468,6.727920454563199,7.199672344836364,7.6293566200796095,7.6293566200796095,6.794415866350106,6.906890595608519,8.243173983472952,8.184875342908283,8.285402218862249,5.643856189774724,7.515699838284043,7.658211482751795,6.727920454563199,7.636624620543649,6.672425341971495,7.169925001442312,7.169925001442312,9.422064766172813,9.862637357558794,9.638435913990472,8.682994583681683,9.428360172704291,9.174925682500678,8.43879185257826,7.507794640198696,7.499845887083206,7.499845887083206,7.491853096329675,8.778077129535358,9.86573327085176,0.0,7.741466986401147,10.382624026574916,7.139551352398794,7.139551352398794,9.00842862207058,7.912889336229962,8.08214904135387,8.829722735086058,8.823367240046235,7.330916878114617,7.189824558880018,6.643856189774724,6.741466986401147,7.400879436282184,6.741466986401147,6.741466986401147,6.475733430966398,7.924812503605781,8.092757140919852,8.344295907915816,5.832890014164741,6.894817763307944,6.554588851677638,6.459431618637297,7.20945336562895,6.22881869049588,6.554588851677638,6.554588851677638,8.842350343413807,9.285402218862249,9.31741261376487,7.994353436858858,8.791162888555018,8.554588851677638,7.864186144654281,6.820178962415188,6.807354922057604,6.807354922057604,6.807354922057604,8.257387842692651,9.364134655008051,2.584962500721156,8.092757140919852,11.025139562278508,6.794415866350106,6.794415866350106,8.076815597050832,8.409390936137703,7.643856189774724,8.388017285345136,8.375039431346925,7.2384047393250786,7.066089190457772,6.022367813028454,6.339850002884624,7.339850002884624,6.820178962415188,6.6865005271832185,6.6293566200796095,7.78135971352466,8.252665432450248,8.294620748891626,6.22881869049588,5.930737337562887,7.1799090900149345,6.426264754702098,7.348728154231077,6.303780748177103,6.700439718141092,6.700439718141092,8.727920454563199,9.774787059601174,9.328674927327947,8.184875342908283,8.971543553950772,8.936637939002571,8.044394119358454,7.339850002884624,7.339850002884624,7.339850002884624,7.330916878114617,8.189824558880018,9.273795599214264,1.584962500721156,7.643856189774724,11.054604317960672,7.339850002884624,7.339850002884624,8.344295907915816,8.379378367071261,7.672425341971495,8.339850002884624,8.31741261376487,2.321928094887362,1.0,1.0,0.0,2.321928094887362,1.0,1.584962500721156,0.0,1.584962500721156,1.0,1.0,0.0,null,1.584962500721156,0.0,null,0.0,1.0,1.0,2.321928094887362,2.0,2.584962500721156,2.807354922057604,3.169925001442312,3.4594316186372973,1.584962500721156,1.0,0.0,0.0,0.0,1.0,1.584962500721156,null,null,4.247927513443585,1.0,1.0,2.584962500721156,2.0,2.0,2.584962500721156,2.321928094887362,6.870364719583405,6.339850002884624,5.20945336562895,5.906890595608519,7.066089190457772,6.459431618637297,5.672425341971495,6.022367813028454,7.383704292474052,7.321928094887363,7.6653359171851765,5.584962500721156,6.658211482751795,6.491853096329675,6.357552004618084,5.954196310386875,5.882643049361842,5.727920454563199,5.727920454563199,8.339850002884624,8.848622940429339,8.707359132080883,7.754887502163468,8.467605550082997,8.219168520462162,7.357552004618084,6.599912842187128,6.584962500721156,6.584962500721156,6.584962500721156,7.813781191217037,8.879583249612784,null,7.321928094887363,9.481799431665753,6.459431618637297,6.459431618637297,7.515699838284043,6.475733430966398,7.189824558880018,7.839203788096944,7.820178962415188,5.643856189774724,5.20945336562895,5.285402218862249,5.459431618637297,5.523561956057013,5.321928094887363,4.459431618637297,4.643856189774724,6.459431618637297,6.3750394313469245,6.0,3.169925001442312,5.672425341971495,5.807354922057604,5.247927513443585,5.285402218862249,4.857980995127572,4.584962500721156,4.584962500721156,6.977279923499917,8.016808287686555,7.330916878114617,6.569855608330948,7.159871336778389,7.076815597050831,6.357552004618084,5.459431618637297,5.459431618637297,5.459431618637297,5.426264754702098,6.189824558880018,7.2761244052742375,0.0,6.303780748177103,9.552669097514272,4.459431618637297,4.459431618637297,6.94251450533924,6.807354922057604,6.303780748177103,6.6865005271832185,6.643856189774724,null,null,null,null,null,null,null,null,null,null,null,null,1.0,0.0,null,null,null,0.0,0.0,null,2.321928094887362,0.0,1.0,1.584962500721156,null,null,null,null,null,null,null,2.0,0.0,2.584962500721156,null,null,null,null,null,null,0.0,1.0,6.321928094887363,6.266786540694901,5.129283016944966,5.672425341971495,6.426264754702098,6.129283016944966,5.672425341971495,5.523561956057013,7.011227255423254,7.199672344836364,7.0,5.247927513443585,5.857980995127572,5.672425341971495,5.807354922057604,6.409390936137702,5.523561956057013,5.672425341971495,5.672425341971495,7.515699838284043,8.59245703726808,8.247927513443585,7.1799090900149345,7.78135971352466,7.714245517666122,6.954196310386875,5.954196310386875,5.930737337562887,5.930737337562887,5.906890595608519,7.139551352398794,8.214319120800766,4.392317422778761,7.0,10.171176797651771,6.149747119504682,6.149747119504682,7.900866807980749,7.139551352398794,7.1799090900149345,7.467605550082998,7.426264754702098,7.189824558880018,6.794415866350106,5.129283016944966,6.044394119358453,6.672425341971495,6.768184324776926,5.857980995127572,6.20945336562895,7.679480099505446,7.20945336562895,7.303780748177103,5.044394119358453,7.257387842692652,6.614709844115208,6.339850002884624,6.426264754702098,6.247927513443585,6.044394119358453,6.044394119358453,7.693486957499325,8.734709620225837,8.531381460516313,7.672425341971495,8.285402218862249,8.098032082960527,7.076815597050831,6.285402218862249,6.266786540694901,6.266786540694901,6.266786540694901,7.787902559391432,8.829722735086058,0.0,7.451211111832329,9.63117705570398,6.108524456778169,6.108524456778169,6.741466986401147,6.832890014164741,7.357552004618084,8.076815597050832,8.027905996569885,4.247927513443585,4.392317422778761,4.0,3.807354922057604,4.392317422778761,4.584962500721156,3.321928094887362,3.0,5.247927513443585,5.087462841250339,4.906890595608519,2.584962500721156,3.807354922057604,4.169925001442312,3.169925001442312,2.321928094887362,3.700439718141092,3.0,3.0,5.906890595608519,6.599912842187128,5.426264754702098,5.247927513443585,5.672425341971495,5.977279923499917,5.392317422778761,4.392317422778761,4.392317422778761,4.392317422778761,4.392317422778761,5.087462841250339,6.22881869049588,null,5.20945336562895,6.906890595608519,3.700439718141092,3.700439718141092,5.727920454563199,0.0,5.491853096329675,5.643856189774724,5.672425341971495,6.845490050944375,7.03342300153745,5.700439718141092,5.754887502163468,6.954196310386875,5.977279923499917,6.357552004618084,6.409390936137702,7.851749041416057,8.774787059601174,7.539158811108031,5.0,5.954196310386875,7.159871336778389,6.357552004618084,6.321928094887363,5.807354922057604,5.857980995127572,5.857980995127572,9.9901039638575,10.661778097771988,8.74819284958946,7.787902559391432,8.703903573444663,7.774787059601174,7.651051691178929,6.894817763307944,6.857980995127572,6.857980995127572,6.794415866350106,7.787902559391432,8.876516946565,3.584962500721156,6.614709844115208,10.369597346278677,6.087462841250339,6.087462841250339,8.451211111832329,6.954196310386875,7.257387842692652,7.882643049361842,7.851749041416057,7.219168520462161,6.3750394313469245,5.20945336562895,6.149747119504682,6.303780748177103,6.870364719583405,6.459431618637297,6.768184324776926,7.851749041416057,7.912889336229962,7.900866807980749,4.169925001442312,7.044394119358453,7.339850002884624,5.78135971352466,5.78135971352466,6.22881869049588,5.321928094887363,5.321928094887363,9.342074667999139,9.60733031374961,9.169925001442312,8.339850002884624,9.238404739325079,7.864186144654281,7.523561956057013,6.906890595608519,6.906890595608519,6.906890595608519,6.894817763307944,7.507794640198696,8.588714635582264,1.584962500721156,6.906890595608519,9.88264304936184,5.643856189774724,5.643856189774724,8.665335917185176,6.714245517666122,7.794415866350106,7.768184324776926,7.7481928495894605,6.459431618637297,5.807354922057604,3.4594316186372973,5.087462841250339,5.807354922057604,5.087462841250339,4.954196310386875,5.426264754702098,7.159871336778389,7.562242424221073,6.108524456778169,4.0,5.807354922057604,6.845490050944375,5.700439718141092,5.357552004618084,4.523561956057013,5.392317422778761,5.392317422778761,8.618385502258606,9.67595703294175,8.228818690495881,7.098032082960526,8.022367813028454,7.451211111832329,6.584962500721156,5.807354922057604,5.78135971352466,5.78135971352466,5.78135971352466,6.965784284662087,8.049848549450562,0.0,6.392317422778761,8.94251450533924,5.392317422778761,5.392317422778761,6.845490050944375,6.022367813028454,7.523561956057013,7.118941072723508,7.098032082960526,6.285402218862249,5.643856189774724,5.169925001442312,4.584962500721156,4.754887502163468,5.321928094887363,4.523561956057013,5.247927513443585,6.584962500721156,7.139551352398794,6.22881869049588,4.523561956057013,5.20945336562895,5.930737337562887,4.754887502163468,4.392317422778761,5.247927513443585,4.392317422778761,4.392317422778761,8.276124405274238,8.960001932068081,7.845490050944375,6.870364719583405,7.6865005271832185,6.930737337562887,6.108524456778169,5.20945336562895,5.20945336562895,5.20945336562895,5.20945336562895,6.491853096329675,7.592457037268081,2.0,5.78135971352466,9.489847960439297,5.169925001442312,5.169925001442312,7.339850002884624,5.459431618637297,6.643856189774724,6.6293566200796095,6.599912842187128,6.754887502163468,6.108524456778169,4.584962500721156,5.700439718141092,6.087462841250339,6.247927513443585,6.129283016944966,5.392317422778761,7.658211482751795,8.59245703726808,7.266786540694901,5.044394119358453,6.569855608330948,6.727920454563199,5.857980995127572,5.321928094887363,5.129283016944966,5.459431618637297,5.459431618637297,9.709083812550343,10.388017285345136,8.527477006060396,7.467605550082998,8.531381460516313,7.6293566200796095,7.539158811108031,6.768184324776926,6.768184324776926,6.768184324776926,6.754887502163468,7.442943495848728,8.491853096329674,3.321928094887362,6.768184324776926,9.08214904135387,5.906890595608519,5.906890595608519,8.703903573444663,6.614709844115208,6.930737337562887,7.614709844115208,7.592457037268081,6.714245517666122,6.794415866350106,5.954196310386875,6.189824558880018,6.930737337562887,5.832890014164741,5.129283016944966,5.832890014164741,7.169925001442312,7.400879436282184,7.294620748891627,5.0,6.442943495848728,6.882643049361842,6.066089190457772,6.066089190457772,5.807354922057604,5.523561956057013,5.523561956057013,8.233619676759702,8.640244936222345,8.804131021183318,8.098032082960527,8.67595703294175,8.179909090014934,7.569855608330948,6.727920454563199,6.727920454563199,6.727920454563199,6.727920454563199,7.977279923499917,9.025139562278508,0.0,7.149747119504682,10.35974956032233,6.321928094887363,6.339850002884624,6.599912842187128,7.011227255423254,7.636624620543649,7.839203788096944,7.794415866350106,1.0,4.321928094887363,6.523561956057013,7.392317422778761,8.174925682500678,null,null,2.0,3.807354922057604,1.584962500721156,1.584962500721156,3.807354922057604,1.0,null,5.392317422778761,6.754887502163468,0.0,3.169925001442312,3.169925001442312,1.584962500721156,3.169925001442312,2.584962500721156,3.9068905956085187,2.0,6.22881869049588,6.247927513443585,1.584962500721156,1.584962500721156,1.584962500721156,1.0,9.20945336562895,10.287712379549449,null,1.584962500721156,0.0,4.459431618637297,4.459431618637297,1.0,1.0,1.0,6.321928094887363,6.266786540694901,7.507794640198696,7.044394119358453,5.459431618637297,5.930737337562887,6.768184324776926,6.599912842187128,7.149747119504682,6.357552004618084,8.113742166049189,9.011227255423254,7.94251450533924,5.977279923499917,6.643856189774724,7.303780748177103,6.539158811108031,6.442943495848728,6.044394119358453,5.882643049361842,5.882643049361842,10.211888294546004,10.831307243802051,9.228818690495881,8.335390354693924,9.108524456778168,8.46352437327118,8.134426320220927,7.383704292474052,7.383704292474052,7.383704292474052,7.357552004618084,7.971543553950772,9.079484783826816,2.0,7.383704292474052,9.689997971419446,6.741466986401147,6.741466986401147,9.52552080909507,7.434628227636725,8.087462841250339,8.308339030139408,8.29920801838728,7.839203788096944,7.257387842692652,6.357552004618084,6.94251450533924,7.7073591320808825,6.794415866350106,7.2384047393250786,6.807354922057604,8.016808287686555,8.124121311829187,8.184875342908283,5.882643049361842,6.954196310386875,7.679480099505446,7.076815597050831,7.366322214245816,6.491853096329675,6.569855608330948,6.569855608330948,8.603626344986193,9.461479447286155,9.622051819456376,8.774787059601174,9.432541900388259,9.076815597050832,8.159871336778389,7.417852514885898,7.409390936137702,7.409390936137702,7.400879436282184,8.651051691178928,9.719388820942083,1.584962500721156,7.994353436858858,10.1357092861044,6.894817763307944,6.894817763307944,8.430452551665532,7.794415866350106,8.194756854422248,8.74819284958946,8.721099188707186,6.727920454563199,6.022367813028454,5.285402218862249,5.614709844115208,6.108524456778169,5.584962500721156,5.954196310386875,5.087462841250339,7.442943495848728,8.060695931687555,7.098032082960526,4.169925001442312,6.20945336562895,6.22881869049588,5.906890595608519,5.672425341971495,5.044394119358453,5.491853096329675,5.491853096329675,8.90388184573618,9.620219825507487,8.519636252843213,7.60733031374961,8.285402218862249,7.839203788096944,7.149747119504682,6.285402218862249,6.285402218862249,6.285402218862249,6.266786540694901,6.977279923499917,8.113742166049189,2.321928094887362,6.768184324776926,9.12670447284319,5.754887502163468,5.754887502163468,8.055282435501189,6.149747119504682,7.434628227636725,7.434628227636725,7.451211111832329,7.936637939002571,7.60733031374961,6.643856189774724,7.577428828035749,7.994353436858858,7.20945336562895,6.491853096329675,7.22881869049588,8.271463027904375,8.071462362556623,8.108524456778168,6.727920454563199,7.303780748177103,8.08214904135387,7.169925001442312,7.3750394313469245,6.285402218862249,7.011227255423254,7.011227255423254,9.310612781659529,9.481799431665753,9.813781191217037,8.873444112515376,9.54882190845875,9.002815015607053,8.03342300153745,7.219168520462161,7.219168520462161,7.219168520462161,7.169925001442312,8.857980995127573,9.955649907528374,2.0,8.330916878114618,11.347067657165871,7.442943495848728,7.451211111832329,7.592457037268081,7.7615512324444795,8.731319031025064,8.820178962415188,8.845490050944376,7.409390936137702,6.918863237274595,6.409390936137702,6.022367813028454,6.918863237274595,6.507794640198696,6.539158811108031,6.409390936137702,7.9886846867721655,8.184875342908283,8.022367813028454,5.554588851677638,6.6293566200796095,7.139551352398794,6.392317422778761,6.672425341971495,5.78135971352466,5.930737337562887,5.930737337562887,9.99859042974533,10.486835021563051,9.238404739325079,8.262094845370179,8.94251450533924,8.174925682500678,7.936637939002571,7.098032082960526,7.098032082960526,7.098032082960526,7.098032082960526,8.098032082960527,9.194756854422248,4.169925001442312,7.330916878114617,9.831307243802051,6.189824558880018,6.189824558880018,9.0,7.285402218862249,7.918863237274595,7.894817763307944,7.900866807980749,6.845490050944375,6.845490050944375,5.392317422778761,5.807354922057604,6.409390936137702,5.807354922057604,5.807354922057604,5.523561956057013,7.672425341971495,8.257387842692651,6.906890595608519,4.169925001442312,6.409390936137702,6.507794640198696,5.977279923499917,5.491853096329675,5.491853096329675,5.357552004618084,5.357552004618084,9.44086916761087,9.981567281903015,8.854868383260236,7.727920454563199,8.558420713268664,8.066089190457772,7.022367813028454,6.189824558880018,6.189824558880018,6.189824558880018,6.169925001442312,7.108524456778169,8.228818690495881,6.754887502163468,7.219168520462161,3.169925001442312,5.78135971352466,5.78135971352466,8.027905996569885,1.584962500721156,7.03342300153745,7.741466986401147,7.754887502163468,7.400879436282184,6.954196310386875,6.066089190457772,6.22881869049588,7.199672344836364,6.392317422778761,6.672425341971495,5.906890595608519,7.882643049361842,8.499845887083206,7.499845887083206,5.20945336562895,6.554588851677638,7.219168520462161,6.247927513443585,6.442943495848728,6.066089190457772,6.149747119504682,6.149747119504682,9.57553924683453,9.997179480937621,9.159871336778389,8.405141463136344,9.144658242831882,8.46352437327118,7.6865005271832185,7.011227255423254,7.011227255423254,7.011227255423254,7.011227255423254,8.134426320220927,9.192292814470767,2.584962500721156,7.622051819456376,10.697836357962377,6.9886846867721655,6.9886846867721655,8.661778097771988,8.076815597050832,7.7073591320808825,8.546894459887637,8.50382573799575,6.087462841250339,5.700439718141092,5.357552004618084,5.321928094887363,6.149747119504682,4.906890595608519,4.247927513443585,5.20945336562895,6.714245517666122,7.622051819456376,6.727920454563199,4.392317422778761,5.727920454563199,6.129283016944966,5.426264754702098,4.0,4.523561956057013,5.0,5.0,8.79766152585376,9.057991722759176,8.03342300153745,6.9886846867721655,7.741466986401147,7.294620748891627,6.491853096329675,5.614709844115208,5.584962500721156,5.584962500721156,5.584962500721156,6.643856189774724,7.741466986401147,null,5.857980995127572,9.469641817239516,4.700439718141092,4.700439718141092,7.1799090900149345,5.584962500721156,6.9886846867721655,6.820178962415188,6.727920454563199,7.651051691178929,6.807354922057604,5.247927513443585,5.78135971352466,6.832890014164741,7.011227255423254,6.599912842187128,7.129283016944966,8.451211111832329,8.611024797307353,8.149747119504681,4.807354922057604,7.20945336562895,7.894817763307944,6.022367813028454,5.727920454563199,6.845490050944375,5.285402218862249,5.285402218862249,9.726218159332198,9.946906274456397,9.668884984266247,8.417852514885897,9.605479518061669,8.247927513443585,8.20945336562895,7.569855608330948,7.569855608330948,7.569855608330948,7.562242424221073,7.7615512324444795,8.839203788096944,4.392317422778761,7.7481928495894605,11.015415052386688,5.832890014164741,5.832890014164741,7.918863237274595,6.523561956057013,8.066089190457772,8.339850002884624,8.326429487122303,7.546894459887636,7.139551352398794,6.584962500721156,6.614709844115208,7.392317422778761,6.894817763307944,6.807354922057604,6.672425341971495,8.076815597050832,8.581200581924957,7.888743248898259,4.954196310386875,6.754887502163468,7.392317422778761,6.584962500721156,6.22881869049588,6.554588851677638,5.930737337562887,5.930737337562887,9.717676423066395,10.287712379549449,9.509775004326936,8.700439718141093,9.523561956057012,8.826548487290914,7.851749041416057,7.159871336778389,7.149747119504682,7.149747119504682,7.149747119504682,8.257387842692651,9.364134655008051,null,7.918863237274595,10.134426320220927,6.870364719583405,6.870364719583405,8.703903573444663,7.531381460516312,8.113742166049189,8.50382573799575,8.487840033823051,7.807354922057604,7.0,6.044394119358453,6.539158811108031,7.2384047393250786,6.954196310386875,6.0,6.3750394313469245,8.011227255423254,8.20945336562895,8.113742166049189,5.832890014164741,6.78135971352466,7.820178962415188,6.857980995127572,6.539158811108031,6.523561956057013,6.22881869049588,6.22881869049588,9.567956075415466,10.108524456778168,9.477758266443889,8.717676423066395,9.390168956200183,8.81698362325538,8.280770770130603,7.507794640198696,7.499845887083206,7.499845887083206,7.483815777264256,8.271463027904375,9.372865060112588,null,7.569855608330948,10.92851837525789,7.159871336778389,7.159871336778389,8.614709844115207,8.710806433699352,7.864186144654281,8.558420713268664,8.554588851677638,7.467605550082998,6.475733430966398,6.149747119504682,6.20945336562895,6.965784284662087,6.906890595608519,6.22881869049588,6.20945336562895,7.98299357469431,8.238404739325079,7.900866807980749,5.672425341971495,6.266786540694901,7.199672344836364,6.022367813028454,6.426264754702098,5.247927513443585,6.266786540694901,6.266786540694901,9.3151495622563,9.828136484194108,9.174925682500678,8.426264754702098,9.041659151637214,8.409390936137703,7.734709620225838,7.03342300153745,7.022367813028454,7.022367813028454,7.0,8.108524456778168,9.172427508645482,2.0,7.78135971352466,9.76487159073609,6.087462841250339,6.087462841250339,7.960001932068081,0.0,7.754887502163468,8.257387842692651,8.285402218862249,7.139551352398794,6.087462841250339,5.392317422778761,6.149747119504682,6.20945336562895,6.129283016944966,5.169925001442312,6.266786540694901,7.800899899920305,8.59245703726808,7.459431618637297,4.807354922057604,6.22881869049588,6.832890014164741,6.285402218862249,5.727920454563199,5.672425341971495,5.727920454563199,5.727920454563199,9.459431618637296,10.051208940914766,8.927777962082342,8.016808287686555,8.86418614465428,8.400879436282183,7.727920454563199,7.022367813028454,7.022367813028454,7.011227255423254,6.965784284662087,7.584962500721156,8.668884984266247,0.0,6.977279923499917,9.49585502688717,6.22881869049588,6.22881869049588,7.539158811108031,null,7.392317422778761,7.971543553950772,7.94251450533924,7.832890014164741,7.2384047393250786,5.857980995127572,6.6865005271832185,8.044394119358454,7.199672344836364,6.6293566200796095,7.0,8.459431618637296,8.83605035505807,8.214319120800766,5.78135971352466,7.011227255423254,7.7073591320808825,6.9886846867721655,7.011227255423254,6.392317422778761,7.087462841250339,7.087462841250339,9.906890595608518,10.66622400280318,9.874981347653774,8.948367231584678,9.734709620225837,9.147204924942228,8.357552004618084,7.6293566200796095,7.6293566200796095,7.6293566200796095,7.599912842187128,8.599912842187127,9.698704666770345,0.0,7.651051691178929,10.381542951184585,7.05528243550119,7.05528243550119,8.78135971352466,7.900866807980749,8.087462841250339,8.948367231584678,8.933690654952233,7.539158811108031,6.727920454563199,7.011227255423254,6.554588851677638,7.219168520462161,7.169925001442312,5.832890014164741,6.475733430966398,8.189824558880018,8.861086905995395,8.430452551665532,5.426264754702098,6.523561956057013,7.475733430966398,6.475733430966398,6.754887502163468,6.189824558880018,6.3750394313469245,6.3750394313469245,9.622051819456376,10.134426320220927,9.493855449240822,8.731319031025064,9.39231742277876,8.76487159073609,8.199672344836364,7.330916878114617,7.303780748177103,7.303780748177103,7.294620748891627,8.247927513443585,9.333155350310616,5.459431618637297,7.643856189774724,10.172427508645482,6.820178962415188,6.820178962415188,9.100662339005199,7.554588851677638,8.189824558880018,8.475733430966399,8.442943495848729,7.011227255423254,6.614709844115208,5.357552004618084,6.22881869049588,6.727920454563199,5.906890595608519,6.3750394313469245,6.149747119504682,7.599912842187128,8.531381460516313,7.820178962415188,4.459431618637297,6.044394119358453,7.05528243550119,6.066089190457772,6.303780748177103,6.22881869049588,5.754887502163468,5.754887502163468,9.116343961237469,9.815383295813538,9.111135670234708,8.257387842692651,8.985841937003341,8.388017285345136,7.515699838284043,6.807354922057604,6.807354922057604,6.807354922057604,6.794415866350106,8.005624549193879,9.090112419664289,2.584962500721156,6.9886846867721655,9.682994583681683,5.857980995127572,5.857980995127572,8.643856189774725,7.2761244052742375,7.467605550082998,8.357552004618084,8.339850002884624,7.643856189774724,7.392317422778761,5.700439718141092,6.149747119504682,6.857980995127572,7.357552004618084,7.539158811108031,6.643856189774724,8.57742882803575,9.174925682500678,8.233619676759702,4.321928094887363,7.066089190457772,7.6293566200796095,6.794415866350106,6.870364719583405,6.357552004618084,6.523561956057013,6.523561956057013,10.12023787734196,11.020285500844647,9.59618975614441,8.758223214726724,9.57742882803575,8.930737337562887,8.076815597050832,7.3750394313469245,7.3750394313469245,7.3750394313469245,7.348728154231077,8.076815597050832,9.18239435340453,4.954196310386875,7.7481928495894605,10.186114239541643,6.6293566200796095,6.6293566200796095,8.86418614465428,7.366322214245816,8.413627929024173,8.672425341971495,8.658211482751796,2.584962500721156,6.539158811108031,1.0,2.807354922057604,3.321928094887362,1.0,1.584962500721156,1.0,3.4594316186372973,4.0,2.0,4.584962500721156,2.584962500721156,3.0,6.087462841250339,3.700439718141092,2.321928094887362,5.584962500721156,5.584962500721156,5.523561956057013,6.022367813028454,4.857980995127572,6.0,5.044394119358453,8.290018846932618,4.247927513443585,3.4594316186372973,3.4594316186372973,3.4594316186372973,3.169925001442312,4.857980995127572,5.906890595608519,null,2.584962500721156,1.0,5.643856189774724,5.643856189774724,4.0,null,3.584962500721156,7.60733031374961,7.554588851677638,7.139551352398794,6.614709844115208,5.554588851677638,5.491853096329675,5.930737337562887,6.247927513443585,6.442943495848728,5.491853096329675,7.807354922057604,8.479780264029099,7.149747119504682,5.087462841250339,6.700439718141092,6.475733430966398,5.977279923499917,6.22881869049588,4.954196310386875,6.129283016944966,6.129283016944966,9.417852514885897,10.321928094887362,8.768184324776927,8.103287808412022,8.758223214726724,8.228818690495881,7.022367813028454,6.339850002884624,6.339850002884624,6.339850002884624,6.303780748177103,7.159871336778389,8.271463027904375,5.087462841250339,7.257387842692652,9.233619676759702,6.247927513443585,6.247927513443585,8.957102041562287,6.6865005271832185,7.339850002884624,7.924812503605781,7.900866807980749,5.832890014164741,6.087462841250339,4.584962500721156,5.20945336562895,5.554588851677638,5.832890014164741,5.285402218862249,4.523561956057013,7.159871336778389,7.643856189774724,6.727920454563199,3.584962500721156,6.0,6.108524456778169,5.0,5.321928094887363,4.087462841250339,5.169925001442312,5.169925001442312,8.686500527183219,9.285402218862249,7.882643049361842,7.044394119358453,7.7073591320808825,7.321928094887363,6.584962500721156,5.727920454563199,5.727920454563199,5.727920454563199,5.727920454563199,6.357552004618084,7.491853096329675,3.807354922057604,6.658211482751795,9.638435913990472,5.523561956057013,5.523561956057013,8.124121311829187,6.977279923499917,6.78135971352466,7.129283016944966,7.087462841250339,6.022367813028454,6.087462841250339,5.0,4.807354922057604,6.149747119504682,6.169925001442312,5.523561956057013,4.700439718141092,7.339850002884624,8.276124405274238,7.03342300153745,4.584962500721156,5.832890014164741,6.599912842187128,5.459431618637297,5.247927513443585,5.20945336562895,5.459431618637297,5.459431618637297,9.076815597050832,9.800899899920305,8.238404739325079,7.348728154231077,8.144658242831882,7.434628227636725,7.066089190457772,6.189824558880018,6.189824558880018,6.189824558880018,6.169925001442312,7.219168520462161,8.335390354693924,3.807354922057604,6.700439718141092,9.945443836377912,5.247927513443585,5.247927513443585,7.247927513443585,0.0,6.94251450533924,7.400879436282184,7.3750394313469245,7.554588851677638,7.483815777264256,6.266786540694901,6.409390936137702,7.312882955284356,7.011227255423254,6.741466986401147,6.409390936137702,8.672425341971495,9.044394119358454,7.900866807980749,5.672425341971495,6.700439718141092,7.592457037268081,6.658211482751795,6.357552004618084,6.303780748177103,6.584962500721156,6.584962500721156,9.78135971352466,10.830515206976838,9.791162888555018,8.430452551665532,9.445014845868423,8.60733031374961,7.994353436858858,7.2761244052742375,7.2761244052742375,7.2761244052742375,7.2384047393250786,8.118941072723507,9.236014191900084,5.426264754702098,7.700439718141092,10.07815080773465,6.700439718141092,6.700439718141092,9.513727595952437,7.2761244052742375,7.9886846867721655,8.584962500721156,8.562242424221072,8.290018846932618,7.6653359171851765,6.523561956057013,7.475733430966398,8.071462362556623,7.721099188707185,6.906890595608519,7.348728154231077,8.81698362325538,9.370687406807217,8.951284714966972,7.098032082960526,7.087462841250339,8.487840033823051,7.383704292474052,7.139551352398794,6.9886846867721655,6.9886846867721655,6.9886846867721655,10.544964432789238,10.768184324776927,10.145932145820515,9.361943773735241,10.131856960608793,9.531381460516313,8.873444112515376,8.134426320220927,8.134426320220927,8.134426320220927,8.134426320220927,9.052568050804153,10.161131882984307,3.4594316186372973,8.625708843064466,10.694357887221452,7.383704292474052,7.383704292474052,8.527477006060396,2.0,8.842350343413807,9.240791332161956,9.231221180711186,7.2761244052742375,6.599912842187128,5.857980995127572,6.658211482751795,7.266786540694901,6.149747119504682,5.672425341971495,6.807354922057604,7.971543553950772,8.413627929024173,7.554588851677638,5.906890595608519,6.321928094887363,7.400879436282184,6.523561956057013,6.087462841250339,5.700439718141092,6.022367813028454,6.022367813028454,9.588714635582264,10.211888294546004,9.079484783826816,8.475733430966399,9.129283016944967,8.76487159073609,7.658211482751795,6.832890014164741,6.820178962415188,6.820178962415188,6.794415866350106,8.285402218862249,9.388017285345136,3.4594316186372973,7.554588851677638,10.703038388986418,6.507794640198696,6.507794640198696,7.754887502163468,7.467605550082998,7.800899899920305,8.344295907915816,8.31741261376487,7.918863237274595,7.05528243550119,6.392317422778761,6.741466986401147,7.426264754702098,6.845490050944375,6.523561956057013,6.794415866350106,8.499845887083206,9.087462841250339,8.366322214245816,6.0,6.906890595608519,7.6653359171851765,7.044394119358453,6.569855608330948,6.20945336562895,6.554588851677638,6.554588851677638,10.084808387804362,10.79766152585376,9.554588851677638,8.751544059089099,9.436711542137214,8.83605035505807,8.479780264029099,7.6865005271832185,7.6865005271832185,7.6865005271832185,7.6653359171851765,8.434628227636725,9.517669388133811,4.459431618637297,7.864186144654281,10.060695931687555,7.044394119358453,7.044394119358453,8.199672344836364,2.807354922057604,8.326429487122303,8.51175265376738,8.515699838284043,7.813781191217037,7.159871336778389,6.321928094887363,6.78135971352466,7.434628227636725,7.0,6.357552004618084,6.599912842187128,8.665335917185176,9.231221180711186,8.257387842692651,6.044394119358453,6.727920454563199,7.906890595608519,6.954196310386875,6.303780748177103,6.614709844115208,6.507794640198696,6.507794640198696,10.363039630256514,10.972261848733291,9.77313920671969,8.971543553950772,9.731319031025064,8.974414589805527,8.290018846932618,7.507794640198696,7.507794640198696,7.507794640198696,7.442943495848728,8.523561956057012,9.588714635582264,5.0,7.813781191217037,11.21006248324023,6.882643049361842,6.882643049361842,9.129283016944967,7.562242424221073,8.335390354693924,8.854868383260236,8.832890014164741,8.366322214245816,7.930737337562887,7.247927513443585,7.467605550082998,8.348728154231077,7.9886846867721655,7.285402218862249,7.409390936137702,8.74819284958946,9.124121311829187,8.968666793195208,6.491853096329675,7.614709844115208,8.62935662007961,7.426264754702098,7.011227255423254,7.129283016944966,7.562242424221073,7.562242424221073,10.321928094887362,10.90839262077375,10.296916206879288,9.394462694610317,10.203348002979762,9.569855608330949,9.105908508571158,8.471675214392045,8.467605550082997,8.467605550082997,8.447083226209653,9.273795599214264,10.319672120946995,4.807354922057604,8.535275376620802,11.5980525001616,7.6653359171851765,7.6653359171851765,8.848622940429339,8.434628227636725,8.988684686772165,9.485829308701904,9.473705749619416,7.523561956057013,6.882643049361842,5.754887502163468,6.409390936137702,6.832890014164741,6.714245517666122,6.820178962415188,6.108524456778169,8.257387842692651,8.92184093707449,8.303780748177102,5.78135971352466,6.087462841250339,7.392317422778761,6.3750394313469245,6.714245517666122,5.906890595608519,6.044394119358453,6.044394119358453,9.975847968006784,10.543998450134541,9.375039431346925,8.400879436282183,9.071462362556623,8.707359132080883,7.832890014164741,7.2384047393250786,7.2384047393250786,7.2384047393250786,7.199672344836364,7.918863237274595,8.96289600533726,1.0,7.900866807980749,9.67065624911844,7.189824558880018,7.189824558880018,9.076815597050832,7.392317422778761,8.238404739325079,8.29920801838728,8.262094845370179,7.2761244052742375,6.643856189774724,5.129283016944966,6.129283016944966,6.714245517666122,6.714245517666122,5.727920454563199,6.22881869049588,8.076815597050832,8.668884984266247,7.679480099505446,5.357552004618084,6.569855608330948,7.348728154231077,6.569855608330948,6.22881869049588,5.643856189774724,5.643856189774724,5.643856189774724,9.519636252843213,10.570804437724497,9.095397022792557,8.375039431346925,9.087462841250339,8.471675214392045,7.614709844115208,6.894817763307944,6.894817763307944,6.894817763307944,6.845490050944375,7.7615512324444795,8.832890014164741,0.0,7.3750394313469245,2.584962500721156,6.507794640198696,6.507794640198696,8.558420713268664,0.0,7.714245517666122,8.169925001442312,8.159871336778389,5.357552004618084,4.807354922057604,5.0,4.906890595608519,5.321928094887363,4.754887502163468,5.523561956057013,4.459431618637297,6.442943495848728,7.011227255423254,5.906890595608519,4.321928094887363,5.700439718141092,5.754887502163468,4.643856189774724,4.906890595608519,4.321928094887363,4.523561956057013,4.523561956057013,8.326429487122303,8.794415866350105,7.614709844115208,6.6293566200796095,7.357552004618084,6.6865005271832185,6.507794640198696,5.614709844115208,5.614709844115208,5.614709844115208,5.584962500721156,6.303780748177103,7.321928094887363,4.0,5.459431618637297,9.068778277985412,4.807354922057604,4.807354922057604,7.483815777264256,6.285402218862249,6.044394119358453,6.539158811108031,6.507794640198696,5.643856189774724,4.954196310386875,4.0,4.321928094887363,4.392317422778761,4.392317422778761,4.857980995127572,4.321928094887363,6.357552004618084,7.459431618637297,5.906890595608519,4.0,5.523561956057013,5.357552004618084,4.584962500721156,4.087462841250339,4.321928094887363,4.584962500721156,4.584962500721156,8.348728154231077,8.948367231584678,7.076815597050831,6.6865005271832185,7.159871336778389,6.9886846867721655,6.169925001442312,5.523561956057013,5.523561956057013,5.523561956057013,5.523561956057013,5.882643049361842,6.965784284662087,null,5.954196310386875,8.08214904135387,5.129283016944966,5.129283016944966,7.599912842187128,0.0,6.108524456778169,6.459431618637297,6.426264754702098,5.832890014164741,5.672425341971495,4.700439718141092,4.169925001442312,5.247927513443585,5.321928094887363,4.700439718141092,4.584962500721156,6.569855608330948,7.787902559391432,6.022367813028454,3.700439718141092,5.20945336562895,5.20945336562895,4.321928094887363,5.0,3.4594316186372973,4.392317422778761,4.392317422778761,8.361943773735241,8.957102041562287,7.636624620543649,6.614709844115208,7.330916878114617,6.754887502163468,6.149747119504682,5.247927513443585,5.247927513443585,5.247927513443585,5.247927513443585,5.882643049361842,7.03342300153745,null,5.807354922057604,7.9886846867721655,4.321928094887363,4.321928094887363,8.005624549193879,5.459431618637297,6.599912842187128,6.94251450533924,6.882643049361842,6.189824558880018,6.129283016944966,4.584962500721156,4.584962500721156,5.584962500721156,5.754887502163468,4.321928094887363,5.087462841250339,6.475733430966398,6.658211482751795,6.523561956057013,4.0,5.523561956057013,6.303780748177103,5.426264754702098,5.0,4.247927513443585,4.954196310386875,4.954196310386875,7.721099188707185,8.523561956057012,7.734709620225838,7.219168520462161,7.851749041416057,7.189824558880018,6.965784284662087,6.0,6.0,6.0,5.977279923499917,6.741466986401147,7.820178962415188,1.0,6.22881869049588,8.417852514885897,5.169925001442312,5.169925001442312,6.491853096329675,5.614709844115208,6.569855608330948,6.741466986401147,6.672425341971495,7.129283016944966,6.9886846867721655,5.754887502163468,5.954196310386875,6.965784284662087,6.584962500721156,6.3750394313469245,6.303780748177103,7.741466986401147,8.39231742277876,7.294620748891627,5.169925001442312,6.794415866350106,7.066089190457772,5.832890014164741,6.20945336562895,6.22881869049588,6.426264754702098,6.426264754702098,9.407267764244732,10.032045726930809,9.121533517340032,8.344295907915816,9.152284842306582,8.668884984266247,7.768184324776926,7.118941072723508,7.108524456778169,7.108524456778169,7.108524456778169,7.948367231584678,8.991521846075695,5.584962500721156,7.321928094887363,9.394462694610317,6.475733430966398,6.475733430966398,8.86418614465428,6.6293566200796095,7.693486957499325,8.113742166049189,8.098032082960527,7.303780748177103,6.442943495848728,6.066089190457772,6.3750394313469245,6.832890014164741,6.930737337562887,6.584962500721156,6.108524456778169,7.965784284662087,8.294620748891626,7.366322214245816,5.672425341971495,6.247927513443585,7.05528243550119,6.20945336562895,6.442943495848728,5.807354922057604,5.807354922057604,5.807354922057604,9.285402218862249,9.906890595608518,8.945443836377912,8.294620748891626,8.804131021183318,8.409390936137703,7.483815777264256,6.643856189774724,6.643856189774724,6.643856189774724,6.6293566200796095,7.700439718141092,8.78135971352466,2.584962500721156,7.149747119504682,9.684748620421626,6.554588851677638,6.554588851677638,8.199672344836364,6.930737337562887,7.636624620543649,7.954196310386875,7.948367231584678,6.977279923499917,7.087462841250339,5.554588851677638,6.392317422778761,6.870364719583405,6.539158811108031,6.94251450533924,6.357552004618084,7.977279923499917,8.761551232444479,7.6653359171851765,5.78135971352466,6.870364719583405,7.1799090900149345,6.169925001442312,6.599912842187128,5.930737337562887,6.022367813028454,6.022367813028454,9.668884984266247,9.92035285541508,9.245552706255681,8.321928094887362,9.047123912114026,8.519636252843213,7.912889336229962,7.108524456778169,7.108524456778169,7.108524456778169,7.108524456778169,7.960001932068081,9.011227255423254,5.584962500721156,7.2384047393250786,9.828136484194108,6.6293566200796095,6.6293566200796095,8.909893083770042,7.05528243550119,7.864186144654281,8.573647187493322,8.566054038171092,8.005624549193879,7.426264754702098,6.066089190457772,6.672425341971495,7.2761244052742375,6.832890014164741,7.011227255423254,6.870364719583405,8.543031820255237,9.025139562278508,8.434628227636725,6.426264754702098,6.94251450533924,7.658211482751795,6.741466986401147,7.159871336778389,6.672425341971495,7.022367813028454,7.022367813028454,10.264442600226602,10.812979471251483,9.643856189774725,8.79766152585376,9.564149489985732,9.044394119358454,8.51175265376738,7.721099188707185,7.721099188707185,7.721099188707185,7.714245517666122,8.531381460516313,9.623881490013458,3.807354922057604,7.888743248898259,10.247927513443585,7.1799090900149345,7.1799090900149345,8.308339030139408,7.672425341971495,8.459431618637296,8.845490050944376,8.813781191217037,6.584962500721156,6.149747119504682,5.357552004618084,5.727920454563199,6.044394119358453,5.700439718141092,5.491853096329675,5.614709844115208,7.139551352398794,7.930737337562887,6.741466986401147,4.584962500721156,5.807354922057604,6.832890014164741,5.906890595608519,6.129283016944966,5.0,5.321928094887363,5.321928094887363,8.888743248898258,9.187352073200497,8.276124405274238,7.459431618637297,8.266786540694902,7.569855608330948,6.977279923499917,6.247927513443585,6.247927513443585,6.247927513443585,6.20945336562895,6.965784284662087,8.092757140919852,null,6.870364719583405,9.945443836377912,5.832890014164741,5.832890014164741,7.651051691178929,6.6865005271832185,6.965784284662087,7.569855608330948,7.546894459887636,6.426264754702098,5.643856189774724,4.807354922057604,5.392317422778761,6.247927513443585,5.426264754702098,5.357552004618084,5.392317422778761,7.339850002884624,8.027905996569885,7.05528243550119,5.0,5.247927513443585,6.614709844115208,5.491853096329675,6.044394119358453,5.20945336562895,4.906890595608519,4.906890595608519,8.820178962415188,9.44086916761087,8.194756854422248,7.577428828035749,8.271463027904375,7.651051691178929,7.044394119358453,6.22881869049588,6.22881869049588,6.22881869049588,6.22881869049588,7.087462841250339,8.179909090014934,null,6.247927513443585,8.912889336229961,5.087462841250339,5.087462841250339,7.912889336229962,5.727920454563199,7.189824558880018,7.562242424221073,7.546894459887636,6.845490050944375,6.672425341971495,5.857980995127572,6.409390936137702,6.475733430966398,6.741466986401147,6.266786540694901,5.930737337562887,7.60733031374961,8.266786540694902,7.562242424221073,5.78135971352466,6.321928094887363,6.906890595608519,6.442943495848728,6.584962500721156,5.672425341971495,6.149747119504682,6.149747119504682,9.111135670234708,10.157346935362844,8.754887502163468,8.092757140919852,8.751544059089099,8.108524456778168,7.247927513443585,6.3750394313469245,6.3750394313469245,6.3750394313469245,6.3750394313469245,7.693486957499325,8.731319031025064,3.0,7.159871336778389,10.576484346796851,6.523561956057013,6.523561956057013,8.535275376620802,7.924812503605781,7.599912842187128,7.857980995127572,7.845490050944375,7.523561956057013,7.169925001442312,5.392317422778761,5.727920454563199,6.392317422778761,6.768184324776926,6.044394119358453,6.285402218862249,8.303780748177102,9.152284842306582,7.971543553950772,5.129283016944966,6.78135971352466,7.651051691178929,6.426264754702098,5.906890595608519,5.807354922057604,6.426264754702098,6.426264754702098,9.918863237274595,10.843921051289035,9.098032082960527,8.129283016944967,8.939579214314692,8.562242424221072,7.857980995127572,7.149747119504682,7.149747119504682,7.149747119504682,7.118941072723508,7.693486957499325,8.758223214726724,4.857980995127572,7.285402218862249,10.892542816648552,6.768184324776926,6.768184324776926,9.531381460516313,6.906890595608519,8.092757140919852,8.39231742277876,8.375039431346925,6.643856189774724,6.0,4.643856189774724,5.357552004618084,5.643856189774724,5.392317422778761,6.087462841250339,5.672425341971495,7.139551352398794,7.826548487290915,6.94251450533924,4.459431618637297,5.857980995127572,6.022367813028454,5.584962500721156,5.700439718141092,4.807354922057604,5.491853096329675,5.491853096329675,8.31741261376487,9.566054038171092,7.864186144654281,7.199672344836364,7.794415866350106,7.348728154231077,6.285402218862249,5.523561956057013,5.523561956057013,5.523561956057013,5.491853096329675,6.507794640198696,7.599912842187128,null,6.169925001442312,8.800899899920305,4.643856189774724,4.643856189774724,7.768184324776926,5.614709844115208,6.977279923499917,7.118941072723508,7.108524456778169,6.0,5.169925001442312,4.169925001442312,4.523561956057013,5.087462841250339,5.727920454563199,5.285402218862249,5.0,6.700439718141092,6.965784284662087,6.599912842187128,3.584962500721156,5.044394119358453,6.044394119358453,5.392317422778761,5.807354922057604,4.807354922057604,4.906890595608519,4.906890595608519,7.721099188707185,8.857980995127573,7.754887502163468,7.044394119358453,7.714245517666122,7.169925001442312,6.475733430966398,5.672425341971495,5.643856189774724,5.643856189774724,5.614709844115208,6.643856189774724,7.6653359171851765,null,5.78135971352466,8.51175265376738,4.857980995127572,4.857980995127572,7.149747119504682,5.754887502163468,6.357552004618084,6.930737337562887,6.882643049361842,7.044394119358453,6.768184324776926,4.321928094887363,5.700439718141092,6.108524456778169,6.614709844115208,5.882643049361842,6.066089190457772,8.044394119358454,8.603626344986193,7.515699838284043,5.285402218862249,6.569855608330948,6.870364719583405,6.247927513443585,5.78135971352466,5.977279923499917,5.832890014164741,5.832890014164741,9.449148645375436,10.550746785383243,8.73809225962049,7.7481928495894605,8.426264754702098,8.005624549193879,7.294620748891627,6.599912842187128,6.599912842187128,6.599912842187128,6.569855608330948,7.417852514885898,8.515699838284043,3.584962500721156,7.266786540694901,10.51175265376738,5.285402218862249,5.285402218862249,9.060695931687555,6.700439718141092,7.599912842187128,7.876516946564999,7.851749041416057,6.20945336562895,6.022367813028454,4.0,5.247927513443585,5.554588851677638,5.044394119358453,4.584962500721156,5.554588851677638,7.129283016944966,7.864186144654281,6.459431618637297,4.584962500721156,5.129283016944966,5.930737337562887,5.523561956057013,4.523561956057013,4.584962500721156,4.906890595608519,4.906890595608519,8.67595703294175,9.06339508128851,7.569855608330948,6.845490050944375,7.562242424221073,7.03342300153745,6.491853096329675,5.614709844115208,5.614709844115208,5.614709844115208,5.491853096329675,6.426264754702098,7.562242424221073,null,5.857980995127572,9.353146825498083,5.754887502163468,5.754887502163468,7.7481928495894605,5.954196310386875,6.584962500721156,7.011227255423254,6.94251450533924,6.409390936137702,6.3750394313469245,4.523561956057013,4.584962500721156,5.672425341971495,6.266786540694901,5.392317422778761,5.392317422778761,7.0,7.7481928495894605,6.727920454563199,5.0,5.882643049361842,6.599912842187128,5.882643049361842,5.857980995127572,5.087462841250339,4.321928094887363,4.321928094887363,8.81698362325538,9.67065624911844,8.276124405274238,7.20945336562895,7.965784284662087,7.392317422778761,6.6865005271832185,5.672425341971495,5.672425341971495,5.672425341971495,5.614709844115208,6.820178962415188,7.960001932068081,4.700439718141092,6.426264754702098,9.06339508128851,5.643856189774724,5.643856189774724,8.022367813028454,null,7.139551352398794,7.087462841250339,7.066089190457772,6.832890014164741,6.108524456778169,5.392317422778761,5.584962500721156,6.066089190457772,6.149747119504682,5.247927513443585,5.357552004618084,7.22881869049588,7.888743248898259,7.643856189774724,5.169925001442312,6.357552004618084,6.643856189774724,5.977279923499917,5.643856189774724,5.584962500721156,5.523561956057013,5.523561956057013,8.813781191217037,9.689997971419446,8.50382573799575,7.693486957499325,8.442943495848729,7.734709620225838,6.754887502163468,5.930737337562887,5.930737337562887,5.906890595608519,5.906890595608519,7.257387842692652,8.312882955284355,3.0,6.918863237274595,10.277287400130357,6.044394119358453,6.044394119358453,7.900866807980749,6.22881869049588,7.643856189774724,7.539158811108031,7.491853096329675,7.592457037268081,7.066089190457772,5.832890014164741,6.066089190457772,6.727920454563199,6.614709844115208,6.247927513443585,6.189824558880018,8.499845887083206,9.174925682500678,8.353146825498083,5.930737337562887,7.03342300153745,7.577428828035749,6.658211482751795,6.044394119358453,6.149747119504682,6.539158811108031,6.539158811108031,10.080817527608327,11.067434360756522,9.432541900388259,8.59245703726808,9.189824558880018,8.813781191217037,7.888743248898259,7.076815597050831,7.066089190457772,7.066089190457772,7.03342300153745,7.599912842187128,8.686500527183219,4.584962500721156,7.467605550082998,11.057991722759176,6.894817763307944,6.894817763307944,8.90388184573618,7.108524456778169,7.888743248898259,8.413627929024173,8.405141463136344,7.139551352398794,6.894817763307944,5.459431618637297,5.930737337562887,6.189824558880018,6.169925001442312,6.643856189774724,5.643856189774724,8.321928094887362,8.614709844115207,7.721099188707185,5.247927513443585,6.247927513443585,7.2384047393250786,6.3750394313469245,5.882643049361842,6.189824558880018,6.108524456778169,6.108524456778169,9.485829308701904,10.679480099505446,8.980139577639157,8.247927513443585,8.997179480937621,8.257387842692651,7.507794640198696,6.820178962415188,6.820178962415188,6.820178962415188,6.820178962415188,7.426264754702098,8.515699838284043,3.700439718141092,7.321928094887363,9.63117705570398,6.3750394313469245,6.3750394313469245,9.095397022792557,6.554588851677638,7.787902559391432,8.252665432450248,8.233619676759702,8.330916878114618,7.700439718141092,6.894817763307944,6.930737337562887,7.366322214245816,7.149747119504682,7.546894459887636,7.076815597050831,8.957102041562287,9.144658242831882,8.50382573799575,6.22881869049588,7.357552004618084,7.672425341971495,6.965784284662087,7.348728154231077,6.894817763307944,6.845490050944375,6.845490050944375,10.217957697864113,11.032734528586714,10.011227255423254,9.231221180711186,9.888743248898258,9.179909090014934,8.479780264029099,7.826548487290915,7.826548487290915,7.826548487290915,7.813781191217037,8.57742882803575,9.638435913990472,4.700439718141092,8.087462841250339,11.458406613236532,7.098032082960526,7.108524456778169,9.20212382383046,7.900866807980749,8.731319031025064,9.098032082960527,9.06339508128851,7.05528243550119,6.9886846867721655,5.459431618637297,5.882643049361842,6.392317422778761,5.392317422778761,6.285402218862249,6.0,7.894817763307944,8.219168520462162,7.257387842692652,5.459431618637297,6.539158811108031,7.087462841250339,6.285402218862249,6.087462841250339,5.807354922057604,5.882643049361842,5.882643049361842,9.499845887083206,10.35974956032233,8.784634845557521,8.271463027904375,8.951284714966972,8.417852514885897,7.651051691178929,6.807354922057604,6.794415866350106,6.794415866350106,6.78135971352466,7.6865005271832185,8.807354922057604,4.087462841250339,7.312882955284356,9.668884984266247,6.22881869049588,6.22881869049588,8.011227255423254,7.05528243550119,7.554588851677638,8.005624549193879,8.0,7.22881869049588,6.894817763307944,6.0,6.339850002884624,6.523561956057013,6.741466986401147,6.3750394313469245,6.022367813028454,8.189824558880018,8.603626344986193,7.78135971352466,5.392317422778761,6.507794640198696,7.22881869049588,5.807354922057604,6.285402218862249,5.754887502163468,6.20945336562895,6.20945336562895,9.667111542075027,10.54978466794786,8.980139577639157,8.519636252843213,9.111135670234708,8.499845887083206,7.60733031374961,6.94251450533924,6.94251450533924,6.94251450533924,6.918863237274595,7.768184324776926,8.83605035505807,1.0,6.845490050944375,9.988684686772165,6.475733430966398,6.475733430966398,8.88264304936184,7.169925001442312,7.930737337562887,8.139551352398794,8.124121311829187,6.94251450533924,6.794415866350106,5.459431618637297,5.78135971352466,6.129283016944966,6.459431618637297,6.20945336562895,6.321928094887363,7.721099188707185,8.651051691178928,7.523561956057013,4.459431618637297,6.584962500721156,6.768184324776926,6.129283016944966,6.6865005271832185,5.584962500721156,5.906890595608519,5.906890595608519,9.417852514885897,10.31741261376487,8.829722735086058,7.754887502163468,8.672425341971495,7.971543553950772,7.483815777264256,6.714245517666122,6.714245517666122,6.714245517666122,6.714245517666122,7.643856189774724,8.72451385311995,5.0,7.159871336778389,9.368506461507693,6.321928094887363,6.321928094887363,8.930737337562887,6.507794640198696,7.700439718141092,8.071462362556623,8.076815597050832,6.768184324776926,6.727920454563199,5.357552004618084,5.700439718141092,6.392317422778761,6.6293566200796095,5.930737337562887,5.426264754702098,7.426264754702098,8.366322214245816,7.03342300153745,4.700439718141092,6.247927513443585,7.05528243550119,5.584962500721156,6.149747119504682,5.857980995127572,5.882643049361842,5.882643049361842,9.055282435501189,10.002815015607053,8.800899899920305,7.876516946564999,8.566054038171092,8.098032082960527,7.451211111832329,6.6865005271832185,6.672425341971495,6.672425341971495,6.643856189774724,7.507794640198696,8.566054038171092,5.247927513443585,7.1799090900149345,10.277287400130357,5.554588851677638,5.584962500721156,7.658211482751795,6.857980995127572,7.366322214245816,8.0,7.977279923499917,4.584962500721156,4.906890595608519,4.0,3.169925001442312,4.169925001442312,4.807354922057604,3.9068905956085187,4.247927513443585,6.339850002884624,6.409390936137702,5.087462841250339,4.0,4.169925001442312,5.392317422778761,4.807354922057604,2.807354922057604,3.584962500721156,4.523561956057013,4.523561956057013,7.813781191217037,8.985841937003341,7.2761244052742375,6.20945336562895,6.906890595608519,6.129283016944966,5.754887502163468,4.857980995127572,4.857980995127572,4.857980995127572,4.857980995127572,5.523561956057013,6.599912842187128,null,5.459431618637297,8.588714635582264,3.584962500721156,3.584962500721156,7.199672344836364,4.754887502163468,5.285402218862249,5.727920454563199,5.727920454563199,6.20945336562895,5.754887502163468,4.321928094887363,4.807354922057604,5.0,4.807354922057604,5.20945336562895,4.0,6.6865005271832185,7.794415866350106,6.285402218862249,3.807354922057604,5.247927513443585,5.614709844115208,4.857980995127572,4.754887502163468,4.169925001442312,5.129283016944966,5.129283016944966,8.906890595608518,9.231221180711186,7.6865005271832185,7.098032082960526,7.679480099505446,7.0,5.882643049361842,5.087462841250339,5.087462841250339,5.087462841250339,5.087462841250339,6.321928094887363,7.348728154231077,0.0,6.247927513443585,9.426264754702098,4.906890595608519,4.906890595608519,7.820178962415188,6.108524456778169,6.930737337562887,6.754887502163468,6.6293566200796095,7.066089190457772,6.643856189774724,5.882643049361842,5.554588851677638,6.768184324776926,6.554588851677638,5.857980995127572,5.857980995127572,7.658211482751795,8.45532722030456,7.569855608330948,4.906890595608519,6.266786540694901,7.303780748177103,6.523561956057013,6.087462841250339,6.022367813028454,5.392317422778761,5.392317422778761,9.259743263690781,9.967226258835993,8.94251450533924,8.396604781181859,9.139551352398794,8.357552004618084,7.643856189774724,6.954196310386875,6.954196310386875,6.954196310386875,6.918863237274595,8.159871336778389,9.219168520462162,null,7.05528243550119,9.567956075415466,6.129283016944966,6.129283016944966,8.422064766172813,6.930737337562887,7.787902559391432,7.960001932068081,7.954196310386875,2.584962500721156,2.584962500721156,null,null,0.0,2.584962500721156,4.0,1.584962500721156,3.9068905956085187,5.643856189774724,3.700439718141092,null,4.169925001442312,3.321928094887362,2.0,0.0,2.0,2.807354922057604,2.807354922057604,6.459431618637297,7.459431618637297,5.247927513443585,4.169925001442312,5.0,4.584962500721156,2.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,3.0,null,3.584962500721156,4.906890595608519,null,null,5.321928094887363,2.584962500721156,3.0,3.321928094887362,3.321928094887362,6.832890014164741,6.794415866350106,5.426264754702098,6.066089190457772,6.794415866350106,6.507794640198696,6.321928094887363,6.247927513443585,7.787902559391432,8.108524456778168,7.459431618637297,5.129283016944966,6.643856189774724,7.303780748177103,6.6865005271832185,5.554588851677638,5.832890014164741,5.754887502163468,5.754887502163468,9.224001674198105,10.376125389276174,9.226412192788786,8.546894459887637,9.100662339005199,8.321928094887362,7.754887502163468,6.977279923499917,6.977279923499917,6.977279923499917,6.94251450533924,7.531381460516312,8.599912842187127,null,7.3750394313469245,9.733015321685963,6.569855608330948,6.569855608330948,7.507794640198696,0.0,7.499845887083206,8.129283016944967,8.118941072723507,5.491853096329675,5.459431618637297,3.321928094887362,4.321928094887363,5.20945336562895,5.169925001442312,6.066089190457772,4.584962500721156,6.94251450533924,7.845490050944375,6.426264754702098,4.169925001442312,5.0,5.584962500721156,4.523561956057013,4.523561956057013,3.169925001442312,5.087462841250339,5.087462841250339,8.451211111832329,9.52552080909507,7.693486957499325,6.6293566200796095,7.6653359171851765,6.954196310386875,6.643856189774724,5.930737337562887,5.930737337562887,5.930737337562887,5.906890595608519,6.189824558880018,7.303780748177103,null,5.392317422778761,9.113742166049189,4.247927513443585,4.247927513443585,7.6865005271832185,6.247927513443585,6.392317422778761,6.614709844115208,6.599912842187128,6.768184324776926,6.475733430966398,6.022367813028454,5.672425341971495,6.169925001442312,5.906890595608519,5.882643049361842,5.285402218862249,7.459431618637297,8.098032082960527,6.930737337562887,5.0,5.954196310386875,6.554588851677638,5.954196310386875,6.392317422778761,5.426264754702098,5.459431618637297,5.459431618637297,8.873444112515376,9.63662462054365,8.562242424221072,7.7615512324444795,8.442943495848729,7.918863237274595,7.303780748177103,6.491853096329675,6.475733430966398,6.475733430966398,6.459431618637297,7.3750394313469245,8.519636252843213,2.321928094887362,6.614709844115208,10.30720080914081,5.954196310386875,5.954196310386875,8.475733430966399,7.330916878114617,7.1799090900149345,7.651051691178929,7.643856189774724,7.129283016944966,7.2761244052742375,6.189824558880018,6.169925001442312,6.882643049361842,6.129283016944966,5.087462841250339,5.832890014164741,7.451211111832329,7.554588851677638,7.562242424221073,5.523561956057013,6.523561956057013,7.108524456778169,5.977279923499917,6.303780748177103,5.882643049361842,5.832890014164741,5.832890014164741,8.573647187493322,9.066089190457772,8.88264304936184,8.08214904135387,8.717676423066395,8.060695931687555,7.515699838284043,6.832890014164741,6.832890014164741,6.832890014164741,6.832890014164741,7.98299357469431,9.057991722759176,null,7.1799090900149345,10.481799431665753,6.321928094887363,6.321928094887363,6.9886846867721655,7.0,7.774787059601174,7.98299357469431,7.94251450533924,6.882643049361842,6.754887502163468,5.554588851677638,6.149747119504682,6.507794640198696,6.044394119358453,6.285402218862249,5.832890014164741,7.022367813028454,7.409390936137702,6.906890595608519,5.129283016944966,6.169925001442312,6.727920454563199,6.022367813028454,6.599912842187128,5.643856189774724,5.584962500721156,5.584962500721156,8.383704292474052,9.124121311829187,8.810571634741146,7.727920454563199,8.59618975614441,7.845490050944375,7.434628227636725,6.643856189774724,6.643856189774724,6.643856189774724,6.643856189774724,7.554588851677638,8.63662462054365,4.247927513443585,7.022367813028454,3.0,6.169925001442312,6.169925001442312,8.076815597050832,null,7.366322214245816,8.129283016944967,8.038918989292302,7.189824558880018,6.820178962415188,5.357552004618084,6.658211482751795,6.807354922057604,6.954196310386875,5.954196310386875,6.189824558880018,7.6865005271832185,7.546894459887636,7.546894459887636,5.0,6.189824558880018,6.643856189774724,6.392317422778761,6.977279923499917,5.727920454563199,6.0,6.0,8.784634845557521,9.259743263690781,9.060695931687555,8.022367813028454,8.787902559391432,8.290018846932618,7.7481928495894605,6.930737337562887,6.930737337562887,6.930737337562887,6.906890595608519,7.994353436858858,9.076815597050832,2.0,7.434628227636725,9.409390936137703,5.882643049361842,5.882643049361842,7.960001932068081,7.20945336562895,7.774787059601174,8.055282435501189,8.022367813028454,7.011227255423254,7.2761244052742375,5.857980995127572,6.129283016944966,7.159871336778389,6.20945336562895,6.149747119504682,6.523561956057013,7.845490050944375,7.366322214245816,8.108524456778168,5.906890595608519,6.539158811108031,7.20945336562895,6.339850002884624,6.700439718141092,6.129283016944966,5.727920454563199,5.727920454563199,8.344295907915816,8.915879378835774,8.930737337562887,7.936637939002571,8.778077129535358,8.405141463136344,7.994353436858858,7.22881869049588,7.219168520462161,7.219168520462161,7.20945336562895,8.326429487122303,9.383704292474052,1.0,7.6653359171851765,10.826548487290914,6.820178962415188,6.820178962415188,7.876516946564999,7.383704292474052,8.098032082960527,8.285402218862249,8.294620748891626,7.2384047393250786,6.754887502163468,5.930737337562887,6.066089190457772,6.754887502163468,6.189824558880018,5.700439718141092,5.977279923499917,7.417852514885898,7.149747119504682,7.22881869049588,4.584962500721156,5.643856189774724,6.554588851677638,5.977279923499917,6.285402218862249,6.108524456778169,5.906890595608519,5.906890595608519,8.044394119358454,8.569855608330949,8.554588851677638,7.839203788096944,8.546894459887637,8.022367813028454,7.303780748177103,6.442943495848728,6.426264754702098,6.426264754702098,6.426264754702098,7.876516946564999,8.927777962082342,2.807354922057604,6.832890014164741,9.4655664048094,6.20945336562895,6.20945336562895,7.734709620225838,6.820178962415188,7.219168520462161,7.857980995127572,7.807354922057604,6.882643049361842,6.614709844115208,5.857980995127572,5.954196310386875,6.3750394313469245,6.044394119358453,5.700439718141092,5.554588851677638,7.159871336778389,7.149747119504682,7.366322214245816,4.643856189774724,6.087462841250339,6.672425341971495,5.672425341971495,6.584962500721156,5.169925001442312,5.357552004618084,5.357552004618084,8.022367813028454,8.546894459887637,8.535275376620802,7.523561956057013,8.271463027904375,8.022367813028454,7.366322214245816,6.584962500721156,6.584962500721156,6.584962500721156,6.584962500721156,7.820178962415188,8.876516946565,2.0,7.011227255423254,9.154818109052105,6.087462841250339,6.087462841250339,7.139551352398794,6.700439718141092,7.693486957499325,7.599912842187128,7.569855608330948,4.169925001442312,5.087462841250339,4.459431618637297,4.321928094887363,5.247927513443585,4.584962500721156,4.0,4.321928094887363,5.087462841250339,4.169925001442312,4.392317422778761,2.321928094887362,4.584962500721156,4.169925001442312,4.754887502163468,5.491853096329675,2.807354922057604,3.321928094887362,3.321928094887362,5.247927513443585,6.584962500721156,6.392317422778761,5.807354922057604,6.321928094887363,6.087462841250339,4.807354922057604,3.9068905956085187,3.9068905956085187,3.9068905956085187,3.9068905956085187,6.247927513443585,7.312882955284356,0.0,4.906890595608519,6.584962500721156,3.807354922057604,3.807354922057604,5.044394119358453,5.392317422778761,5.392317422778761,6.169925001442312,6.129283016944966,6.266786540694901,6.0,5.247927513443585,5.882643049361842,5.977279923499917,5.930737337562887,5.321928094887363,5.321928094887363,6.857980995127572,6.599912842187128,6.087462841250339,3.584962500721156,5.614709844115208,5.614709844115208,5.044394119358453,6.20945336562895,4.392317422778761,5.044394119358453,5.044394119358453,7.417852514885898,8.326429487122303,8.108524456778168,7.159871336778389,7.839203788096944,7.409390936137702,6.794415866350106,6.0,5.977279923499917,5.977279923499917,5.954196310386875,7.169925001442312,8.243173983472952,2.321928094887362,6.491853096329675,8.539158811108031,5.754887502163468,5.754887502163468,7.303780748177103,6.22881869049588,7.076815597050831,7.098032082960526,7.087462841250339,6.247927513443585,6.6293566200796095,5.285402218862249,6.149747119504682,6.599912842187128,5.832890014164741,5.832890014164741,5.614709844115208,6.954196310386875,6.643856189774724,7.05528243550119,4.523561956057013,5.584962500721156,6.426264754702098,5.584962500721156,6.554588851677638,5.727920454563199,5.727920454563199,5.727920454563199,7.539158811108031,8.686500527183219,8.233619676759702,7.592457037268081,8.169925001442312,7.807354922057604,7.426264754702098,6.727920454563199,6.727920454563199,6.727920454563199,6.714245517666122,7.539158811108031,8.60733031374961,0.0,6.491853096329675,9.157346935362844,6.108524456778169,6.108524456778169,6.845490050944375,6.584962500721156,7.011227255423254,7.475733430966398,7.417852514885898,6.643856189774724,6.339850002884624,5.459431618637297,6.066089190457772,6.554588851677638,6.022367813028454,4.754887502163468,5.614709844115208,7.22881869049588,7.247927513443585,7.584962500721156,5.129283016944966,6.189824558880018,6.965784284662087,6.087462841250339,6.303780748177103,5.491853096329675,5.20945336562895,5.20945336562895,7.94251450533924,8.603626344986193,8.31741261376487,7.807354922057604,8.396604781181859,8.011227255423254,7.383704292474052,6.643856189774724,6.6293566200796095,6.6293566200796095,6.6293566200796095,7.546894459887636,8.611024797307353,2.0,6.339850002884624,10.303780748177102,5.906890595608519,5.906890595608519,7.960001932068081,6.918863237274595,7.409390936137702,7.679480099505446,7.651051691178929,7.918863237274595,7.357552004618084,6.832890014164741,6.9886846867721655,7.643856189774724,7.05528243550119,6.554588851677638,6.643856189774724,8.31741261376487,8.243173983472952,8.531381460516313,6.247927513443585,7.475733430966398,7.800899899920305,7.066089190457772,6.658211482751795,6.977279923499917,6.906890595608519,6.906890595608519,9.35974956032233,9.834471049984222,9.590587049915035,8.894817763307943,9.556506054671928,8.971543553950772,8.39231742277876,7.584962500721156,7.584962500721156,7.584962500721156,7.577428828035749,8.74819284958946,9.786269627648466,2.0,7.7481928495894605,10.386940245324311,7.22881869049588,7.22881869049588,8.422064766172813,7.971543553950772,8.573647187493322,8.870364719583405,8.832890014164741,6.614709844115208,6.22881869049588,5.169925001442312,5.930737337562887,5.977279923499917,5.727920454563199,5.906890595608519,5.491853096329675,6.539158811108031,6.857980995127572,7.20945336562895,4.459431618637297,5.930737337562887,5.906890595608519,5.643856189774724,5.954196310386875,5.357552004618084,4.906890595608519,4.906890595608519,7.651051691178929,8.353146825498083,8.20945336562895,7.491853096329675,8.038918989292302,7.672425341971495,7.098032082960526,6.285402218862249,6.285402218862249,6.285402218862249,6.189824558880018,7.357552004618084,8.430452551665532,4.584962500721156,6.658211482751795,3.4594316186372973,6.044394119358453,6.044394119358453,7.066089190457772,1.0,6.820178962415188,7.442943495848728,7.383704292474052,6.857980995127572,6.321928094887363,6.0,6.129283016944966,6.6865005271832185,5.614709844115208,5.247927513443585,5.426264754702098,6.658211482751795,6.9886846867721655,7.417852514885898,4.906890595608519,5.882643049361842,6.741466986401147,5.857980995127572,5.247927513443585,5.321928094887363,4.857980995127572,4.857980995127572,8.179909090014934,8.550746785383243,8.562242424221072,7.614709844115208,8.303780748177102,7.700439718141092,7.339850002884624,6.459431618637297,6.459431618637297,6.459431618637297,6.442943495848728,7.400879436282184,8.479780264029099,0.0,6.727920454563199,9.092757140919852,5.882643049361842,5.930737337562887,7.139551352398794,6.906890595608519,7.392317422778761,7.451211111832329,7.459431618637297,7.459431618637297,7.339850002884624,6.584962500721156,7.022367813028454,7.149747119504682,6.857980995127572,6.714245517666122,5.906890595608519,7.832890014164741,7.894817763307944,7.807354922057604,5.700439718141092,6.599912842187128,7.285402218862249,6.569855608330948,7.118941072723508,6.108524456778169,5.954196310386875,5.954196310386875,8.60733031374961,9.257387842692651,9.219168520462162,8.348728154231077,9.08214904135387,8.672425341971495,7.94251450533924,7.189824558880018,7.1799090900149345,7.1799090900149345,7.169925001442312,8.442943495848729,9.517669388133811,2.807354922057604,7.912889336229962,9.873444112515376,7.066089190457772,7.066089190457772,8.515699838284043,7.643856189774724,8.252665432450248,8.519636252843213,8.49585502688717,7.076815597050831,6.6865005271832185,5.614709844115208,6.539158811108031,6.658211482751795,6.539158811108031,6.189824558880018,6.247927513443585,7.400879436282184,7.348728154231077,8.011227255423254,5.044394119358453,6.087462841250339,6.918863237274595,6.599912842187128,6.599912842187128,5.906890595608519,5.807354922057604,5.807354922057604,8.252665432450248,8.86418614465428,8.668884984266247,7.679480099505446,8.451211111832329,8.0,7.219168520462161,6.523561956057013,6.523561956057013,6.523561956057013,6.507794640198696,8.224001674198105,9.243173983472952,1.0,7.321928094887363,9.61654884377899,6.129283016944966,6.129283016944966,8.103287808412022,7.022367813028454,7.888743248898259,7.800899899920305,7.7481928495894605,7.6865005271832185,7.098032082960526,5.807354922057604,6.491853096329675,7.451211111832329,6.918863237274595,6.491853096329675,6.475733430966398,7.658211482751795,7.774787059601174,8.228818690495881,5.129283016944966,6.918863237274595,7.321928094887363,6.832890014164741,6.700439718141092,5.584962500721156,5.954196310386875,5.954196310386875,8.658211482751796,9.087462841250339,9.019590728357882,8.262094845370179,8.912889336229961,8.519636252843213,7.98299357469431,7.149747119504682,7.139551352398794,7.139551352398794,7.118941072723508,8.339850002884624,9.368506461507693,2.0,7.515699838284043,9.831307243802051,6.6865005271832185,6.6865005271832185,7.159871336778389,7.392317422778761,8.118941072723507,8.247927513443585,8.228818690495881,6.523561956057013,6.672425341971495,5.643856189774724,5.930737337562887,6.658211482751795,5.906890595608519,5.554588851677638,5.672425341971495,7.03342300153745,6.78135971352466,7.599912842187128,5.321928094887363,5.930737337562887,6.794415866350106,6.189824558880018,5.78135971352466,5.78135971352466,5.832890014164741,5.832890014164741,7.7481928495894605,8.558420713268664,8.625708843064466,7.584962500721156,8.276124405274238,7.721099188707185,7.169925001442312,6.20945336562895,6.20945336562895,6.20945336562895,6.20945336562895,7.60733031374961,8.693486957499326,0.0,7.294620748891627,10.29232163280204,6.044394119358453,6.044394119358453,6.78135971352466,6.303780748177103,7.531381460516312,7.754887502163468,7.721099188707185,6.584962500721156,5.954196310386875,5.044394119358453,5.78135971352466,6.169925001442312,5.78135971352466,5.491853096329675,5.285402218862249,6.539158811108031,6.614709844115208,6.554588851677638,5.087462841250339,5.700439718141092,6.044394119358453,5.832890014164741,6.149747119504682,5.044394119358453,5.0,5.0,7.554588851677638,8.276124405274238,8.016808287686555,7.0,7.807354922057604,7.118941072723508,6.727920454563199,5.882643049361842,5.882643049361842,5.882643049361842,5.882643049361842,7.108524456778169,8.164906926675688,0.0,6.149747119504682,8.957102041562287,5.807354922057604,5.807354922057604,6.507794640198696,6.339850002884624,6.832890014164741,7.149747119504682,7.118941072723508,6.321928094887363,6.149747119504682,4.700439718141092,5.727920454563199,6.0,5.584962500721156,4.584962500721156,4.857980995127572,6.754887502163468,6.339850002884624,6.727920454563199,4.807354922057604,5.426264754702098,5.523561956057013,5.20945336562895,5.832890014164741,4.247927513443585,4.392317422778761,4.392317422778761,7.94251450533924,8.262094845370179,7.971543553950772,6.741466986401147,7.515699838284043,7.20945336562895,6.807354922057604,5.954196310386875,5.954196310386875,5.954196310386875,5.954196310386875,7.03342300153745,8.134426320220927,5.614709844115208,5.954196310386875,3.807354922057604,4.954196310386875,5.0,7.483815777264256,null,7.076815597050831,7.129283016944966,7.087462841250339,6.169925001442312,5.832890014164741,5.0,5.554588851677638,5.643856189774724,5.044394119358453,4.807354922057604,4.523561956057013,6.357552004618084,6.426264754702098,6.442943495848728,2.584962500721156,5.0,5.459431618637297,5.087462841250339,5.459431618637297,4.584962500721156,4.857980995127572,4.857980995127572,6.6865005271832185,7.912889336229962,7.839203788096944,6.918863237274595,7.636624620543649,7.05528243550119,6.442943495848728,5.643856189774724,5.643856189774724,5.643856189774724,5.614709844115208,6.906890595608519,7.954196310386875,0.0,6.108524456778169,9.499845887083206,5.247927513443585,5.247927513443585,6.022367813028454,6.022367813028454,6.357552004618084,6.894817763307944,6.845490050944375,6.807354922057604,6.087462841250339,5.426264754702098,5.954196310386875,5.930737337562887,5.906890595608519,5.285402218862249,5.285402218862249,6.832890014164741,7.022367813028454,6.857980995127572,4.247927513443585,5.930737337562887,6.285402218862249,5.700439718141092,5.832890014164741,4.807354922057604,4.954196310386875,4.954196310386875,8.060695931687555,8.668884984266247,8.344295907915816,7.3750394313469245,8.087462841250339,7.693486957499325,7.022367813028454,6.266786540694901,6.266786540694901,6.266786540694901,6.20945336562895,7.087462841250339,8.124121311829187,5.20945336562895,6.94251450533924,8.857980995127573,5.584962500721156,5.614709844115208,6.0,6.6865005271832185,7.507794640198696,7.247927513443585,7.20945336562895,3.321928094887362,2.807354922057604,null,2.0,null,2.584962500721156,1.584962500721156,2.0,2.807354922057604,2.321928094887362,3.321928094887362,2.0,1.584962500721156,1.0,1.584962500721156,null,2.321928094887362,2.584962500721156,2.584962500721156,3.807354922057604,3.807354922057604,4.754887502163468,3.584962500721156,4.0,3.700439718141092,3.9068905956085187,3.4594316186372973,3.4594316186372973,3.4594316186372973,3.4594316186372973,4.643856189774724,5.491853096329675,null,2.584962500721156,5.754887502163468,2.0,2.0,2.807354922057604,3.0,2.807354922057604,3.321928094887362,3.169925001442312,6.832890014164741,6.794415866350106,6.303780748177103,6.129283016944966,6.491853096329675,6.727920454563199,6.169925001442312,5.491853096329675,7.139551352398794,7.515699838284043,7.727920454563199,6.044394119358453,6.087462841250339,6.6865005271832185,6.247927513443585,6.149747119504682,5.491853096329675,5.754887502163468,5.754887502163468,8.442943495848729,8.370687406807217,8.92184093707449,7.727920454563199,8.569855608330949,8.098032082960527,7.357552004618084,6.643856189774724,6.643856189774724,6.643856189774724,6.643856189774724,7.727920454563199,8.807354922057604,2.807354922057604,7.149747119504682,9.594324603924848,6.357552004618084,6.357552004618084,7.159871336778389,7.219168520462161,7.851749041416057,7.888743248898259,7.845490050944375,5.554588851677638,5.78135971352466,4.459431618637297,4.906890595608519,5.491853096329675,5.0,4.906890595608519,4.807354922057604,6.108524456778169,5.807354922057604,5.78135971352466,3.321928094887362,4.807354922057604,5.614709844115208,4.392317422778761,4.087462841250339,4.459431618637297,4.754887502163468,4.754887502163468,7.098032082960526,7.507794640198696,7.3750394313469245,6.794415866350106,7.539158811108031,6.94251450533924,6.614709844115208,5.857980995127572,5.857980995127572,5.857980995127572,5.832890014164741,6.727920454563199,7.826548487290915,null,5.954196310386875,9.113742166049189,5.129283016944966,5.129283016944966,5.523561956057013,5.906890595608519,6.507794640198696,6.727920454563199,6.6293566200796095,7.0,6.754887502163468,5.754887502163468,6.539158811108031,6.820178962415188,6.507794640198696,6.129283016944966,5.954196310386875,7.409390936137702,7.523561956057013,7.839203788096944,4.169925001442312,5.857980995127572,6.78135971352466,6.392317422778761,6.954196310386875,5.954196310386875,6.149747119504682,6.149747119504682,8.154818109052105,8.92184093707449,8.832890014164741,8.071462362556623,8.727920454563199,8.103287808412022,7.60733031374961,6.870364719583405,6.870364719583405,6.870364719583405,6.870364719583405,7.94251450533924,8.980139577639157,1.0,7.022367813028454,9.642051692927977,6.672425341971495,6.672425341971495,7.7073591320808825,6.977279923499917,7.918863237274595,7.900866807980749,7.870364719583405,6.807354922057604,6.768184324776926,5.906890595608519,6.321928094887363,6.857980995127572,6.727920454563199,6.066089190457772,5.614709844115208,7.087462841250339,6.857980995127572,7.189824558880018,4.643856189774724,6.714245517666122,6.78135971352466,6.672425341971495,5.584962500721156,5.491853096329675,5.20945336562895,5.20945336562895,8.113742166049189,8.665335917185176,8.523561956057012,7.7073591320808825,8.388017285345136,7.930737337562887,7.554588851677638,6.643856189774724,6.643856189774724,6.643856189774724,6.6293566200796095,7.794415866350106,8.894817763307943,6.643856189774724,6.78135971352466,9.477758266443889,5.523561956057013,5.523561956057013,7.499845887083206,6.930737337562887,7.700439718141092,7.894817763307944,7.894817763307944,7.3750394313469245,7.2384047393250786,6.266786540694901,6.507794640198696,7.189824558880018,6.882643049361842,6.459431618637297,6.303780748177103,7.839203788096944,7.584962500721156,8.233619676759702,5.906890595608519,6.539158811108031,6.930737337562887,6.832890014164741,7.20945336562895,5.882643049361842,6.169925001442312,6.169925001442312,8.076815597050832,8.96289600533726,9.022367813028454,8.430452551665532,9.049848549450562,8.491853096329674,8.044394119358454,7.189824558880018,7.189824558880018,7.189824558880018,7.1799090900149345,8.285402218862249,9.337621901992508,1.0,7.643856189774724,9.933690654952233,6.614709844115208,6.614709844115208,7.247927513443585,7.643856189774724,8.118941072723507,8.285402218862249,8.252665432450248,null,null,null,null,null,null,null,null,null,0.0,1.0,null,1.0,null,null,null,null,null,null,null,2.807354922057604,1.584962500721156,0.0,0.0,0.0,1.0,null,null,null,null,0.0,3.169925001442312,null,null,2.321928094887362,0.0,0.0,1.0,null,null,null,0.0,5.584962500721156,5.700439718141092,2.807354922057604,3.584962500721156,4.857980995127572,5.459431618637297,5.392317422778761,5.285402218862249,7.098032082960526,8.199672344836364,6.539158811108031,3.700439718141092,5.285402218862249,5.321928094887363,4.857980995127572,4.584962500721156,4.392317422778761,4.807354922057604,4.807354922057604,9.377210530388552,10.127994320976393,7.643856189774724,6.599912842187128,7.426264754702098,6.930737337562887,6.459431618637297,5.727920454563199,5.727920454563199,5.727920454563199,5.672425341971495,6.0,7.149747119504682,3.584962500721156,5.426264754702098,9.002815015607053,5.357552004618084,5.357552004618084,8.507794640198696,6.426264754702098,6.066089190457772,7.03342300153745,7.03342300153745,6.266786540694901,4.954196310386875,4.459431618637297,4.247927513443585,5.392317422778761,5.807354922057604,4.857980995127572,5.321928094887363,7.03342300153745,7.044394119358453,6.700439718141092,3.700439718141092,6.285402218862249,5.906890595608519,4.523561956057013,3.169925001442312,4.954196310386875,3.9068905956085187,3.9068905956085187,8.558420713268664,8.954196310386875,8.405141463136344,7.523561956057013,8.361943773735241,6.658211482751795,6.977279923499917,6.357552004618084,6.357552004618084,6.357552004618084,6.339850002884624,6.321928094887363,7.383704292474052,2.321928094887362,6.523561956057013,8.787902559391432,4.169925001442312,4.169925001442312,7.636624620543649,5.321928094887363,7.03342300153745,6.672425341971495,6.658211482751795,5.727920454563199,5.584962500721156,3.700439718141092,3.584962500721156,5.0,4.643856189774724,3.807354922057604,3.9068905956085187,6.882643049361842,7.507794640198696,5.247927513443585,3.0,4.857980995127572,5.357552004618084,5.0,4.392317422778761,4.247927513443585,4.392317422778761,4.392317422778761,8.339850002884624,9.29920801838728,7.483815777264256,6.727920454563199,7.499845887083206,6.894817763307944,6.066089190457772,5.357552004618084,5.357552004618084,5.357552004618084,5.357552004618084,6.442943495848728,7.491853096329675,2.321928094887362,6.266786540694901,9.350939181546432,4.700439718141092,4.700439718141092,7.339850002884624,5.169925001442312,6.247927513443585,6.882643049361842,6.857980995127572,6.794415866350106,6.491853096329675,5.044394119358453,5.426264754702098,6.491853096329675,5.321928094887363,4.954196310386875,5.614709844115208,7.348728154231077,8.228818690495881,7.20945336562895,4.700439718141092,6.149747119504682,6.807354922057604,5.392317422778761,5.523561956057013,4.523561956057013,5.643856189774724,5.643856189774724,9.409390936137703,9.799281621521923,8.550746785383243,7.7481928495894605,8.467605550082997,7.577428828035749,6.845490050944375,6.108524456778169,6.108524456778169,6.108524456778169,6.108524456778169,7.622051819456376,8.658211482751796,3.169925001442312,6.700439718141092,9.337621901992508,4.906890595608519,4.906890595608519,8.098032082960527,6.266786540694901,7.20945336562895,7.614709844115208,7.562242424221073,5.169925001442312,4.906890595608519,3.807354922057604,3.9068905956085187,4.584962500721156,5.087462841250339,3.700439718141092,4.584962500721156,6.066089190457772,7.366322214245816,5.523561956057013,2.584962500721156,4.584962500721156,4.523561956057013,4.584962500721156,4.087462841250339,3.321928094887362,3.584962500721156,3.584962500721156,8.60733031374961,8.832890014164741,6.768184324776926,5.754887502163468,6.475733430966398,6.108524456778169,5.491853096329675,4.954196310386875,4.954196310386875,4.954196310386875,4.807354922057604,5.491853096329675,6.523561956057013,null,4.857980995127572,7.400879436282184,3.0,3.0,7.924812503605781,4.700439718141092,5.807354922057604,6.247927513443585,6.22881869049588,6.741466986401147,6.475733430966398,5.672425341971495,6.066089190457772,6.918863237274595,5.672425341971495,4.906890595608519,5.832890014164741,7.2384047393250786,6.894817763307944,6.714245517666122,4.321928094887363,5.906890595608519,6.672425341971495,6.044394119358453,5.523561956057013,5.700439718141092,5.882643049361842,5.882643049361842,8.247927513443585,8.951284714966972,8.79766152585376,7.651051691178929,8.471675214392045,7.954196310386875,7.22881869049588,6.426264754702098,6.426264754702098,6.426264754702098,6.409390936137702,7.977279923499917,9.022367813028454,1.0,6.523561956057013,10.24198314969433,5.584962500721156,5.584962500721156,7.139551352398794,7.05528243550119,7.169925001442312,7.714245517666122,7.658211482751795,null,2.807354922057604,5.523561956057013,5.392317422778761,6.658211482751795,null,null,0.0,null,0.0,null,1.0,null,1.0,3.584962500721156,5.754887502163468,null,2.584962500721156,2.584962500721156,null,1.0,0.0,0.0,null,2.584962500721156,4.0,0.0,0.0,0.0,0.0,7.426264754702098,8.467605550082997,null,1.0,3.0,2.584962500721156,2.584962500721156,null,6.643856189774724,null,4.459431618637297,4.392317422778761,6.357552004618084,6.285402218862249,3.807354922057604,4.523561956057013,5.044394119358453,5.930737337562887,5.357552004618084,5.285402218862249,7.794415866350106,8.820178962415188,6.94251450533924,3.9068905956085187,6.303780748177103,6.22881869049588,5.807354922057604,3.807354922057604,4.857980995127572,5.129283016944966,5.129283016944966,9.643856189774725,10.333155350310616,8.066089190457772,7.149747119504682,7.900866807980749,7.285402218862249,7.066089190457772,6.247927513443585,6.247927513443585,6.247927513443585,6.189824558880018,6.459431618637297,7.475733430966398,4.857980995127572,6.169925001442312,8.661778097771988,5.087462841250339,5.087462841250339,8.0,5.672425341971495,6.882643049361842,7.266786540694901,7.189824558880018,7.357552004618084,7.357552004618084,5.906890595608519,6.442943495848728,7.392317422778761,6.409390936137702,6.339850002884624,6.918863237274595,7.977279923499917,7.734709620225838,7.734709620225838,5.672425341971495,6.426264754702098,7.22881869049588,6.459431618637297,6.6293566200796095,5.672425341971495,6.247927513443585,6.247927513443585,8.654636028527968,9.432541900388259,9.116343961237469,8.519636252843213,9.219168520462162,8.625708843064466,7.994353436858858,7.2384047393250786,7.22881869049588,7.22881869049588,7.219168520462161,8.330916878114618,9.396604781181859,3.321928094887362,7.491853096329675,9.917372079476841,6.6865005271832185,6.6865005271832185,7.734709620225838,7.7615512324444795,8.060695931687555,8.285402218862249,8.257387842692651,6.442943495848728,6.022367813028454,5.491853096329675,5.554588851677638,6.247927513443585,5.727920454563199,4.857980995127572,5.643856189774724,7.108524456778169,8.134426320220927,6.643856189774724,4.459431618637297,5.754887502163468,6.22881869049588,5.357552004618084,5.20945336562895,5.129283016944966,5.392317422778761,5.392317422778761,8.839203788096944,9.684748620421626,8.499845887083206,7.199672344836364,8.194756854422248,7.491853096329675,6.714245517666122,5.930737337562887,5.930737337562887,5.930737337562887,5.906890595608519,7.0,8.087462841250339,null,6.9886846867721655,9.90839262077375,6.523561956057013,6.523561956057013,8.611024797307353,7.459431618637297,6.918863237274595,7.499845887083206,7.483815777264256,6.569855608330948,6.321928094887363,2.584962500721156,5.321928094887363,6.339850002884624,5.357552004618084,4.754887502163468,5.285402218862249,6.6865005271832185,7.643856189774724,6.475733430966398,5.169925001442312,5.523561956057013,6.554588851677638,5.285402218862249,4.754887502163468,4.807354922057604,5.321928094887363,5.321928094887363,8.744833837499545,9.550746785383243,8.321928094887362,7.22881869049588,8.055282435501189,7.614709844115208,6.807354922057604,5.930737337562887,5.930737337562887,5.930737337562887,5.906890595608519,7.467605550082998,8.573647187493322,1.0,6.303780748177103,9.915879378835774,5.0,5.0,7.832890014164741,6.6865005271832185,7.189824558880018,7.312882955284356,7.321928094887363,6.20945336562895,6.066089190457772,5.0,4.643856189774724,6.189824558880018,5.832890014164741,4.0,5.247927513443585,6.977279923499917,7.794415866350106,6.321928094887363,5.0,5.857980995127572,6.584962500721156,5.169925001442312,3.321928094887362,4.754887502163468,4.906890595608519,4.906890595608519,8.761551232444479,9.319672120946995,8.118941072723507,7.118941072723508,8.022367813028454,7.523561956057013,6.643856189774724,5.882643049361842,5.882643049361842,5.882643049361842,5.882643049361842,7.189824558880018,8.233619676759702,3.584962500721156,6.392317422778761,9.709083812550343,5.392317422778761,5.392317422778761,8.03342300153745,6.285402218862249,6.882643049361842,7.20945336562895,7.189824558880018,6.832890014164741,5.954196310386875,4.807354922057604,4.754887502163468,6.20945336562895,6.459431618637297,6.044394119358453,6.392317422778761,7.800899899920305,8.098032082960527,7.312882955284356,3.700439718141092,6.614709844115208,7.348728154231077,5.523561956057013,4.643856189774724,5.727920454563199,4.584962500721156,4.584962500721156,9.159871336778389,9.567956075415466,8.918863237274595,8.118941072723507,9.071462362556623,7.426264754702098,7.614709844115208,7.0,7.0,7.0,6.9886846867721655,6.930737337562887,8.08214904135387,3.4594316186372973,7.022367813028454,9.684748620421626,5.426264754702098,5.426264754702098,8.169925001442312,5.930737337562887,7.900866807980749,7.044394119358453,7.03342300153745,6.357552004618084,5.700439718141092,5.129283016944966,5.554588851677638,5.882643049361842,4.906890595608519,5.614709844115208,5.169925001442312,7.409390936137702,7.714245517666122,6.894817763307944,3.4594316186372973,5.954196310386875,5.807354922057604,4.643856189774724,5.392317422778761,4.087462841250339,5.169925001442312,5.169925001442312,9.116343961237469,9.4655664048094,7.994353436858858,7.417852514885898,8.03342300153745,7.515699838284043,6.584962500721156,5.832890014164741,5.832890014164741,5.832890014164741,5.832890014164741,6.768184324776926,7.876516946564999,1.0,6.491853096329675,8.731319031025064,5.807354922057604,5.832890014164741,8.103287808412022,5.954196310386875,6.930737337562887,7.303780748177103,7.22881869049588,6.599912842187128,6.149747119504682,4.584962500721156,4.857980995127572,6.149747119504682,5.727920454563199,5.857980995127572,5.491853096329675,7.199672344836364,8.262094845370179,7.321928094887363,4.0,6.3750394313469245,6.3750394313469245,5.554588851677638,5.930737337562887,4.584962500721156,4.700439718141092,4.700439718141092,9.353146825498083,9.850186837645774,8.370687406807217,7.357552004618084,8.124121311829187,7.651051691178929,6.954196310386875,6.129283016944966,6.129283016944966,6.129283016944966,6.108524456778169,6.9886846867721655,8.098032082960527,3.0,6.741466986401147,10.084808387804362,5.426264754702098,5.426264754702098,8.721099188707186,6.357552004618084,6.754887502163468,7.6293566200796095,7.614709844115208,6.426264754702098,6.0,5.523561956057013,5.129283016944966,5.954196310386875,6.0,4.954196310386875,5.087462841250339,7.118941072723508,7.787902559391432,6.78135971352466,5.0,5.700439718141092,6.392317422778761,5.285402218862249,4.754887502163468,4.857980995127572,5.392317422778761,5.392317422778761,9.18239435340453,9.77313920671969,8.199672344836364,7.312882955284356,7.936637939002571,7.643856189774724,6.754887502163468,5.906890595608519,5.906890595608519,5.906890595608519,5.832890014164741,6.794415866350106,7.912889336229962,0.0,6.169925001442312,8.980139577639157,5.523561956057013,5.523561956057013,7.400879436282184,null,6.965784284662087,7.2384047393250786,7.20945336562895,5.523561956057013,5.129283016944966,3.584962500721156,4.0,4.523561956057013,4.392317422778761,4.523561956057013,3.807354922057604,6.727920454563199,7.569855608330948,5.0,3.584962500721156,5.285402218862249,5.523561956057013,4.169925001442312,2.321928094887362,3.4594316186372973,3.4594316186372973,3.4594316186372973,9.066089190457772,8.927777962082342,7.2384047393250786,6.247927513443585,7.098032082960526,6.247927513443585,5.857980995127572,5.169925001442312,5.169925001442312,5.169925001442312,5.129283016944966,5.426264754702098,6.599912842187128,1.0,5.357552004618084,8.098032082960527,3.584962500721156,3.700439718141092,7.539158811108031,null,5.857980995127572,6.066089190457772,6.022367813028454,6.965784284662087,6.569855608330948,5.459431618637297,5.930737337562887,6.266786540694901,6.189824558880018,5.672425341971495,5.392317422778761,7.721099188707185,8.467605550082997,7.1799090900149345,5.20945336562895,6.658211482751795,6.906890595608519,5.727920454563199,5.78135971352466,5.169925001442312,5.643856189774724,5.643856189774724,9.829722735086058,10.199672344836364,8.51175265376738,7.672425341971495,8.370687406807217,7.906890595608519,7.483815777264256,6.507794640198696,6.507794640198696,6.507794640198696,6.409390936137702,7.303780748177103,8.366322214245816,0.0,6.539158811108031,10.330916878114618,5.754887502163468,5.754887502163468,8.531381460516313,7.199672344836364,7.05528243550119,7.727920454563199,7.643856189774724,2.584962500721156,6.807354922057604,3.321928094887362,3.9068905956085187,3.584962500721156,3.0,3.4594316186372973,3.700439718141092,4.0,5.0,4.459431618637297,5.643856189774724,3.807354922057604,3.0,6.044394119358453,3.584962500721156,3.169925001442312,6.066089190457772,6.066089190457772,6.044394119358453,6.882643049361842,6.303780748177103,6.569855608330948,5.754887502163468,8.906890595608518,4.643856189774724,4.0,4.0,4.0,3.9068905956085187,5.614709844115208,6.614709844115208,null,3.0,6.539158811108031,6.700439718141092,6.700439718141092,5.169925001442312,4.523561956057013,4.321928094887363,8.483815777264256,8.451211111832329,7.794415866350106,7.257387842692652,6.022367813028454,6.3750394313469245,7.2761244052742375,7.1799090900149345,7.129283016944966,6.658211482751795,8.519636252843213,9.113742166049189,7.507794640198696,6.6293566200796095,6.714245517666122,7.475733430966398,6.303780748177103,6.794415866350106,6.149747119504682,6.539158811108031,6.539158811108031,9.952741247186488,10.621136113274641,9.50382573799575,8.894817763307943,9.612868497291041,9.108524456778168,8.339850002884624,7.727920454563199,7.727920454563199,7.727920454563199,7.721099188707185,8.434628227636725,9.519636252843213,3.700439718141092,7.700439718141092,10.25502856981873,6.820178962415188,6.820178962415188,9.20212382383046,7.787902559391432,8.087462841250339,8.900866807980748,8.879583249612784,6.247927513443585,6.357552004618084,4.807354922057604,5.554588851677638,6.189824558880018,6.0,5.754887502163468,5.321928094887363,7.383704292474052,7.7481928495894605,6.754887502163468,3.807354922057604,5.832890014164741,6.303780748177103,5.129283016944966,6.303780748177103,4.392317422778761,5.087462841250339,5.087462841250339,9.060695931687555,9.632995197142957,8.353146825498083,7.357552004618084,8.247927513443585,7.643856189774724,6.78135971352466,6.0,6.0,6.0,5.977279923499917,7.219168520462161,8.330916878114618,5.426264754702098,6.554588851677638,8.906890595608518,5.700439718141092,5.700439718141092,8.271463027904375,6.426264754702098,7.022367813028454,7.562242424221073,7.554588851677638,6.727920454563199,6.303780748177103,4.807354922057604,5.977279923499917,6.569855608330948,5.321928094887363,3.9068905956085187,5.357552004618084,7.159871336778389,8.113742166049189,6.78135971352466,4.392317422778761,6.189824558880018,7.044394119358453,5.727920454563199,4.584962500721156,5.426264754702098,5.129283016944966,5.129283016944966,9.250298417906333,9.656424863277781,8.426264754702098,7.467605550082998,8.370687406807217,7.971543553950772,7.139551352398794,6.303780748177103,6.285402218862249,6.285402218862249,6.285402218862249,7.562242424221073,8.661778097771988,null,6.614709844115208,9.978710459106358,6.087462841250339,6.087462841250339,7.876516946564999,7.6865005271832185,6.906890595608519,7.6653359171851765,7.658211482751795,5.672425341971495,5.426264754702098,3.321928094887362,4.459431618637297,4.754887502163468,4.700439718141092,4.392317422778761,3.584962500721156,6.554588851677638,7.554588851677638,6.0,3.807354922057604,5.357552004618084,6.022367813028454,4.857980995127572,4.0,4.169925001442312,4.754887502163468,4.754887502163468,8.451211111832329,9.247927513443585,7.554588851677638,6.584962500721156,7.294620748891627,7.05528243550119,6.022367813028454,5.087462841250339,5.087462841250339,5.087462841250339,5.087462841250339,6.643856189774724,7.721099188707185,null,5.882643049361842,4.523561956057013,4.857980995127572,4.857980995127572,7.459431618637297,0.0,6.700439718141092,6.442943495848728,6.3750394313469245,6.339850002884624,5.672425341971495,3.4594316186372973,5.285402218862249,5.614709844115208,5.614709844115208,5.285402218862249,5.0,7.139551352398794,7.936637939002571,7.129283016944966,4.700439718141092,5.727920454563199,6.169925001442312,5.392317422778761,5.169925001442312,5.247927513443585,5.087462841250339,5.087462841250339,9.250298417906333,9.552669097514272,7.857980995127572,7.1799090900149345,7.794415866350106,7.189824558880018,6.672425341971495,5.882643049361842,5.857980995127572,5.857980995127572,5.832890014164741,6.965784284662087,8.08214904135387,1.0,6.392317422778761,8.918863237274595,5.426264754702098,5.426264754702098,8.060695931687555,5.930737337562887,7.076815597050831,7.0,6.954196310386875,6.832890014164741,6.714245517666122,5.459431618637297,5.807354922057604,6.658211482751795,5.321928094887363,5.754887502163468,5.672425341971495,7.491853096329675,8.199672344836364,6.741466986401147,5.357552004618084,5.882643049361842,7.076815597050831,5.643856189774724,5.954196310386875,5.20945336562895,5.614709844115208,5.614709844115208,9.312882955284355,9.733015321685963,8.515699838284043,7.741466986401147,8.569855608330949,7.98299357469431,7.339850002884624,6.658211482751795,6.643856189774724,6.643856189774724,6.599912842187128,7.6865005271832185,8.734709620225837,2.584962500721156,7.149747119504682,10.243173983472952,5.643856189774724,5.643856189774724,8.108524456778168,7.888743248898259,7.159871336778389,7.839203788096944,7.813781191217037,5.700439718141092,4.584962500721156,5.0,4.643856189774724,5.459431618637297,5.321928094887363,4.321928094887363,4.392317422778761,6.491853096329675,7.05528243550119,5.807354922057604,3.321928094887362,4.857980995127572,5.78135971352466,4.169925001442312,4.169925001442312,4.169925001442312,4.754887502163468,4.754887502163468,8.290018846932618,8.758223214726724,7.499845887083206,6.832890014164741,7.483815777264256,6.870364719583405,5.882643049361842,5.169925001442312,5.169925001442312,5.169925001442312,5.169925001442312,6.0,7.149747119504682,2.0,5.727920454563199,9.233619676759702,4.169925001442312,4.169925001442312,7.507794640198696,5.285402218862249,6.6293566200796095,6.569855608330948,6.491853096329675,5.754887502163468,5.129283016944966,3.321928094887362,4.0,5.0,5.882643049361842,4.643856189774724,4.0,6.426264754702098,7.614709844115208,5.754887502163468,3.700439718141092,5.357552004618084,5.882643049361842,5.321928094887363,3.0,4.247927513443585,4.0,4.0,8.603626344986193,9.129283016944967,7.562242424221073,6.044394119358453,6.845490050944375,6.539158811108031,5.832890014164741,5.087462841250339,5.087462841250339,5.087462841250339,4.906890595608519,6.108524456778169,7.199672344836364,4.321928094887363,5.087462841250339,9.03342300153745,4.906890595608519,4.906890595608519,7.7073591320808825,5.321928094887363,6.475733430966398,6.357552004618084,6.357552004618084,6.409390936137702,5.906890595608519,5.392317422778761,5.754887502163468,6.491853096329675,6.22881869049588,5.954196310386875,5.643856189774724,7.491853096329675,7.845490050944375,6.894817763307944,4.459431618637297,6.022367813028454,6.569855608330948,5.247927513443585,5.807354922057604,5.129283016944966,5.700439718141092,5.700439718141092,9.204571144249204,9.46352437327118,8.515699838284043,7.679480099505446,8.405141463136344,8.016808287686555,7.076815597050831,6.303780748177103,6.303780748177103,6.303780748177103,6.303780748177103,7.499845887083206,8.584962500721156,2.0,6.741466986401147,9.044394119358454,6.409390936137702,6.409390936137702,7.813781191217037,6.6293566200796095,7.383704292474052,7.584962500721156,7.531381460516312,6.442943495848728,6.3750394313469245,5.044394119358453,5.426264754702098,5.882643049361842,5.614709844115208,4.459431618637297,5.459431618637297,7.066089190457772,7.727920454563199,6.20945336562895,3.700439718141092,5.554588851677638,5.584962500721156,5.321928094887363,5.0,4.807354922057604,5.129283016944966,5.129283016944966,8.804131021183318,9.843921051289035,7.960001932068081,7.22881869049588,7.936637939002571,7.357552004618084,6.78135971352466,6.044394119358453,6.044394119358453,6.044394119358453,6.022367813028454,6.807354922057604,7.954196310386875,1.0,5.832890014164741,9.834471049984222,5.20945336562895,5.20945336562895,8.044394119358454,7.076815597050831,6.845490050944375,7.321928094887363,7.294620748891627,5.977279923499917,5.584962500721156,4.807354922057604,4.754887502163468,5.357552004618084,5.357552004618084,4.857980995127572,4.754887502163468,6.906890595608519,7.906890595608519,6.022367813028454,4.584962500721156,5.614709844115208,5.459431618637297,4.643856189774724,4.169925001442312,3.807354922057604,4.857980995127572,4.857980995127572,8.997179480937621,9.449148645375436,7.60733031374961,6.882643049361842,7.584962500721156,7.0,6.108524456778169,5.247927513443585,5.247927513443585,5.247927513443585,5.20945336562895,6.357552004618084,7.499845887083206,null,6.108524456778169,8.434628227636725,5.087462841250339,5.087462841250339,7.839203788096944,5.523561956057013,6.357552004618084,6.820178962415188,6.807354922057604,7.03342300153745,6.820178962415188,6.022367813028454,5.614709844115208,6.807354922057604,6.303780748177103,6.149747119504682,6.066089190457772,7.266786540694901,7.672425341971495,7.1799090900149345,5.129283016944966,6.108524456778169,7.011227255423254,5.857980995127572,5.906890595608519,5.727920454563199,5.954196310386875,5.954196310386875,9.052568050804153,9.375039431346925,8.751544059089099,8.044394119358454,8.861086905995395,8.247927513443585,7.475733430966398,6.6293566200796095,6.6293566200796095,6.6293566200796095,6.614709844115208,7.882643049361842,8.991521846075695,5.954196310386875,7.199672344836364,9.294620748891626,5.906890595608519,5.906890595608519,6.700439718141092,7.257387842692652,7.467605550082998,7.787902559391432,7.754887502163468,4.392317422778761,4.392317422778761,4.459431618637297,4.584962500721156,5.426264754702098,5.700439718141092,4.954196310386875,4.643856189774724,6.189824558880018,7.266786540694901,5.700439718141092,3.321928094887362,4.857980995127572,5.321928094887363,4.523561956057013,3.9068905956085187,3.584962500721156,4.700439718141092,4.700439718141092,8.060695931687555,8.79766152585376,7.2384047393250786,6.894817763307944,7.392317422778761,7.044394119358453,6.247927513443585,5.459431618637297,5.459431618637297,5.459431618637297,5.459431618637297,6.459431618637297,7.531381460516312,null,6.247927513443585,9.011227255423254,5.247927513443585,5.247927513443585,6.569855608330948,6.20945336562895,6.22881869049588,6.569855608330948,6.491853096329675,6.741466986401147,5.807354922057604,5.129283016944966,5.459431618637297,6.6293566200796095,5.426264754702098,5.087462841250339,5.857980995127572,7.098032082960526,7.383704292474052,6.768184324776926,4.584962500721156,6.554588851677638,6.409390936137702,5.807354922057604,5.584962500721156,5.554588851677638,4.906890595608519,4.906890595608519,8.622051819456376,9.303780748177102,8.308339030139408,7.577428828035749,8.396604781181859,7.693486957499325,7.219168520462161,6.392317422778761,6.392317422778761,6.392317422778761,6.3750394313469245,7.312882955284356,8.383704292474052,null,6.78135971352466,9.799281621521923,6.087462841250339,6.087462841250339,6.820178962415188,6.714245517666122,7.199672344836364,7.348728154231077,7.348728154231077,7.392317422778761,6.754887502163468,5.906890595608519,6.022367813028454,6.599912842187128,6.658211482751795,5.247927513443585,6.022367813028454,7.864186144654281,8.487840033823051,7.108524456778169,5.247927513443585,6.357552004618084,7.149747119504682,6.044394119358453,5.807354922057604,5.672425341971495,5.954196310386875,5.954196310386875,9.342074667999139,9.810571634741146,8.879583249612784,8.184875342908283,8.829722735086058,8.405141463136344,7.199672344836364,6.459431618637297,6.459431618637297,6.459431618637297,6.426264754702098,7.679480099505446,8.787902559391432,4.857980995127572,7.108524456778169,10.357552004618084,5.643856189774724,5.643856189774724,8.741466986401146,7.247927513443585,7.826548487290915,8.139551352398794,8.076815597050832,6.643856189774724,6.475733430966398,4.857980995127572,5.832890014164741,5.807354922057604,6.22881869049588,6.247927513443585,5.491853096329675,7.392317422778761,8.531381460516313,7.087462841250339,5.614709844115208,5.727920454563199,6.768184324776926,5.643856189774724,5.554588851677638,5.0,5.321928094887363,5.321928094887363,9.54882190845875,9.67065624911844,8.357552004618084,7.584962500721156,8.257387842692651,7.6293566200796095,7.139551352398794,6.303780748177103,6.303780748177103,6.303780748177103,6.266786540694901,7.011227255423254,8.076815597050832,0.0,6.741466986401147,10.312882955284355,5.672425341971495,5.672425341971495,8.46352437327118,7.442943495848728,7.392317422778761,7.636624620543649,7.592457037268081,6.108524456778169,5.459431618637297,4.459431618637297,4.700439718141092,5.20945336562895,5.169925001442312,4.754887502163468,5.129283016944966,6.3750394313469245,7.700439718141092,6.523561956057013,3.0,4.807354922057604,6.044394119358453,4.807354922057604,4.700439718141092,4.087462841250339,5.087462841250339,5.087462841250339,8.45532722030456,8.787902559391432,7.569855608330948,6.584962500721156,7.357552004618084,6.94251450533924,6.044394119358453,5.285402218862249,5.285402218862249,5.285402218862249,5.20945336562895,6.523561956057013,7.599912842187128,1.0,6.149747119504682,9.344295907915816,4.754887502163468,4.754887502163468,6.768184324776926,5.491853096329675,5.930737337562887,6.643856189774724,6.539158811108031,6.426264754702098,6.022367813028454,5.727920454563199,5.554588851677638,5.857980995127572,5.954196310386875,6.20945336562895,5.584962500721156,7.459431618637297,7.6865005271832185,6.741466986401147,4.523561956057013,5.584962500721156,6.266786540694901,5.78135971352466,5.523561956057013,5.392317422778761,4.807354922057604,4.807354922057604,8.965784284662087,9.787902559391432,8.51175265376738,7.562242424221073,8.247927513443585,7.672425341971495,6.930737337562887,6.303780748177103,6.303780748177103,6.303780748177103,6.285402218862249,7.129283016944966,8.184875342908283,0.0,6.672425341971495,10.186114239541643,5.672425341971495,5.672425341971495,8.233619676759702,7.491853096329675,6.954196310386875,7.577428828035749,7.539158811108031,5.672425341971495,5.321928094887363,3.807354922057604,5.129283016944966,5.882643049361842,5.129283016944966,4.321928094887363,5.321928094887363,6.569855608330948,7.400879436282184,6.321928094887363,4.459431618637297,5.882643049361842,6.087462841250339,5.614709844115208,4.247927513443585,4.954196310386875,5.20945336562895,5.20945336562895,8.321928094887362,9.057991722759176,7.679480099505446,6.894817763307944,7.562242424221073,7.159871336778389,6.491853096329675,5.672425341971495,5.672425341971495,5.672425341971495,5.643856189774724,6.857980995127572,7.960001932068081,4.523561956057013,5.700439718141092,8.59618975614441,4.523561956057013,4.523561956057013,8.204571144249204,5.754887502163468,6.658211482751795,7.087462841250339,7.044394119358453,5.930737337562887,5.523561956057013,4.087462841250339,4.807354922057604,5.491853096329675,5.087462841250339,3.807354922057604,4.169925001442312,6.9886846867721655,7.409390936137702,6.20945336562895,4.321928094887363,5.643856189774724,5.807354922057604,5.129283016944966,2.807354922057604,4.169925001442312,4.807354922057604,4.807354922057604,8.721099188707186,9.342074667999139,7.531381460516312,6.954196310386875,7.60733031374961,7.066089190457772,6.169925001442312,5.357552004618084,5.357552004618084,5.357552004618084,5.357552004618084,5.930737337562887,7.011227255423254,null,5.285402218862249,9.523561956057012,5.0,5.0,7.6653359171851765,5.554588851677638,6.507794640198696,6.754887502163468,6.672425341971495,6.409390936137702,5.584962500721156,3.807354922057604,4.857980995127572,5.357552004618084,5.954196310386875,5.78135971352466,5.285402218862249,7.2384047393250786,8.257387842692651,6.94251450533924,4.0,5.247927513443585,6.149747119504682,5.044394119358453,5.584962500721156,4.247927513443585,5.523561956057013,5.523561956057013,9.13699111208023,9.753216749178955,8.108524456778168,7.098032082960526,7.768184324776926,7.348728154231077,6.442943495848728,5.832890014164741,5.832890014164741,5.832890014164741,5.78135971352466,6.672425341971495,7.700439718141092,6.087462841250339,6.044394119358453,4.247927513443585,4.857980995127572,4.857980995127572,8.46352437327118,0.0,6.714245517666122,7.189824558880018,7.118941072723508,6.754887502163468,6.044394119358453,4.807354922057604,5.727920454563199,6.087462841250339,5.832890014164741,5.459431618637297,5.0,7.562242424221073,8.129283016944967,6.845490050944375,4.906890595608519,6.129283016944966,6.727920454563199,5.977279923499917,4.584962500721156,4.754887502163468,5.426264754702098,5.426264754702098,9.177419537989236,10.091435386323607,8.400879436282183,7.409390936137702,8.129283016944967,7.714245517666122,7.366322214245816,6.523561956057013,6.523561956057013,6.523561956057013,6.459431618637297,7.442943495848728,8.531381460516313,3.0,6.459431618637297,10.079484783826816,5.491853096329675,5.491853096329675,8.430452551665532,7.366322214245816,7.20945336562895,7.700439718141092,7.651051691178929,6.523561956057013,5.832890014164741,4.169925001442312,5.426264754702098,5.727920454563199,6.0,5.392317422778761,4.857980995127572,7.330916878114617,8.066089190457772,6.882643049361842,4.0,5.807354922057604,6.339850002884624,5.554588851677638,4.584962500721156,4.459431618637297,5.392317422778761,5.392317422778761,9.002815015607053,9.69522829149575,8.219168520462162,7.366322214245816,8.092757140919852,7.409390936137702,6.94251450533924,6.20945336562895,6.20945336562895,6.20945336562895,6.189824558880018,7.0,8.08214904135387,4.321928094887363,6.507794640198696,9.78953364497036,5.614709844115208,5.614709844115208,8.308339030139408,6.066089190457772,6.554588851677638,7.189824558880018,7.169925001442312,6.20945336562895,5.906890595608519,3.321928094887362,4.0,5.087462841250339,5.643856189774724,5.20945336562895,4.954196310386875,7.294620748891627,8.03342300153745,6.584962500721156,3.807354922057604,5.78135971352466,6.129283016944966,5.044394119358453,4.169925001442312,4.321928094887363,4.523561956057013,4.523561956057013,8.873444112515376,9.935165049603695,7.754887502163468,7.087462841250339,7.6653359171851765,7.417852514885898,6.507794640198696,5.754887502163468,5.754887502163468,5.754887502163468,5.672425341971495,6.149747119504682,7.294620748891627,3.4594316186372973,6.247927513443585,9.499845887083206,5.169925001442312,5.169925001442312,8.643856189774725,5.643856189774724,6.882643049361842,7.05528243550119,7.022367813028454,6.768184324776926,5.643856189774724,5.247927513443585,4.857980995127572,5.807354922057604,6.339850002884624,6.20945336562895,5.78135971352466,7.774787059601174,8.611024797307353,7.515699838284043,3.700439718141092,6.442943495848728,6.768184324776926,5.807354922057604,5.554588851677638,5.20945336562895,6.087462841250339,6.087462841250339,9.722807531169547,10.536247215688128,8.686500527183219,7.851749041416057,8.515699838284043,8.049848549450562,7.044394119358453,6.149747119504682,6.149747119504682,6.149747119504682,6.087462841250339,6.965784284662087,8.092757140919852,4.459431618637297,6.491853096329675,10.122827994807666,5.392317422778761,5.392317422778761,8.499845887083206,6.339850002884624,7.1799090900149345,7.523561956057013,7.499845887083206,6.022367813028454,5.523561956057013,4.954196310386875,4.523561956057013,4.954196310386875,5.700439718141092,4.643856189774724,5.129283016944966,7.076815597050831,7.257387842692652,6.409390936137702,4.392317422778761,5.247927513443585,5.700439718141092,4.906890595608519,5.0,4.523561956057013,4.754887502163468,4.754887502163468,8.703903573444663,9.479780264029099,7.577428828035749,7.098032082960526,7.672425341971495,7.149747119504682,6.6865005271832185,5.954196310386875,5.954196310386875,5.954196310386875,5.930737337562887,6.6865005271832185,7.813781191217037,3.807354922057604,6.3750394313469245,3.321928094887362,4.754887502163468,4.754887502163468,8.266786540694902,null,6.807354922057604,6.977279923499917,6.954196310386875,6.339850002884624,5.20945336562895,4.321928094887363,5.169925001442312,6.108524456778169,5.643856189774724,4.906890595608519,5.129283016944966,7.118941072723508,7.870364719583405,6.523561956057013,4.584962500721156,5.584962500721156,5.78135971352466,5.700439718141092,5.357552004618084,4.643856189774724,4.807354922057604,4.807354922057604,8.63662462054365,9.357552004618084,7.794415866350106,7.2384047393250786,7.794415866350106,7.599912842187128,6.247927513443585,5.554588851677638,5.554588851677638,5.554588851677638,5.554588851677638,6.870364719583405,7.948367231584678,null,6.22881869049588,9.784634845557521,4.459431618637297,4.459431618637297,7.954196310386875,7.108524456778169,6.845490050944375,7.3750394313469245,7.348728154231077,4.906890595608519,4.0,1.0,3.321928094887362,4.0,4.247927513443585,2.807354922057604,4.321928094887363,5.614709844115208,6.442943495848728,4.584962500721156,3.807354922057604,4.392317422778761,4.321928094887363,3.807354922057604,4.807354922057604,3.807354922057604,4.392317422778761,4.392317422778761,7.60733031374961,8.768184324776927,6.539158811108031,5.882643049361842,6.741466986401147,6.044394119358453,5.0,4.0,3.9068905956085187,3.9068905956085187,3.807354922057604,5.169925001442312,6.426264754702098,2.584962500721156,4.321928094887363,8.523561956057012,3.0,3.0,5.459431618637297,4.584962500721156,5.426264754702098,6.20945336562895,6.189824558880018,5.672425341971495,5.247927513443585,3.807354922057604,4.523561956057013,5.614709844115208,5.672425341971495,4.392317422778761,5.087462841250339,6.066089190457772,7.011227255423254,5.906890595608519,3.9068905956085187,4.321928094887363,5.491853096329675,4.700439718141092,4.459431618637297,3.4594316186372973,4.523561956057013,4.523561956057013,8.204571144249204,8.861086905995395,7.451211111832329,6.614709844115208,7.357552004618084,6.882643049361842,5.754887502163468,5.0,5.0,5.0,4.954196310386875,6.539158811108031,7.636624620543649,0.0,5.614709844115208,9.0,5.285402218862249,5.285402218862249,7.348728154231077,6.870364719583405,5.906890595608519,6.857980995127572,6.832890014164741,7.0,5.584962500721156,5.523561956057013,5.700439718141092,6.700439718141092,6.554588851677638,4.459431618637297,5.554588851677638,7.577428828035749,7.918863237274595,6.700439718141092,4.643856189774724,6.672425341971495,6.807354922057604,6.066089190457772,5.0,5.247927513443585,5.727920454563199,5.727920454563199,8.96289600533726,10.01262453886506,8.842350343413807,7.857980995127572,8.618385502258606,8.149747119504681,7.108524456778169,6.409390936137702,6.3750394313469245,6.3750394313469245,6.357552004618084,7.285402218862249,8.370687406807217,3.9068905956085187,6.870364719583405,10.12670447284319,6.569855608330948,6.569855608330948,8.400879436282183,7.820178962415188,7.219168520462161,7.888743248898259,7.870364719583405,1.0,1.0,null,1.584962500721156,1.0,null,1.584962500721156,null,2.321928094887362,4.0,1.0,null,2.0,1.0,0.0,1.0,0.0,null,null,4.954196310386875,5.584962500721156,2.807354922057604,1.584962500721156,2.807354922057604,3.321928094887362,0.0,null,null,null,null,0.0,2.0,null,2.807354922057604,4.700439718141092,null,null,3.584962500721156,2.0,null,2.807354922057604,2.807354922057604,6.918863237274595,5.807354922057604,5.169925001442312,5.321928094887363,5.954196310386875,6.066089190457772,5.321928094887363,5.584962500721156,7.383704292474052,7.754887502163468,7.330916878114617,4.321928094887363,5.672425341971495,6.442943495848728,5.285402218862249,5.321928094887363,4.906890595608519,5.087462841250339,5.087462841250339,9.167418145831737,9.642051692927977,8.400879436282183,7.794415866350106,8.467605550082997,7.813781191217037,7.118941072723508,6.409390936137702,6.409390936137702,6.409390936137702,6.357552004618084,7.303780748177103,8.361943773735241,0.0,6.584962500721156,2.0,5.426264754702098,5.426264754702098,7.977279923499917,0.0,7.118941072723508,7.577428828035749,7.531381460516312,5.20945336562895,4.700439718141092,3.321928094887362,3.584962500721156,4.247927513443585,3.321928094887362,4.643856189774724,4.0,6.303780748177103,7.159871336778389,5.247927513443585,2.584962500721156,4.321928094887363,4.954196310386875,4.321928094887363,1.0,3.0,3.169925001442312,3.169925001442312,8.066089190457772,8.951284714966972,6.894817763307944,6.066089190457772,6.794415866350106,6.285402218862249,5.459431618637297,4.643856189774724,4.643856189774724,4.643856189774724,4.643856189774724,5.247927513443585,6.285402218862249,null,4.321928094887363,7.2384047393250786,4.087462841250339,4.087462841250339,5.087462841250339,null,5.614709844115208,5.700439718141092,5.672425341971495,5.78135971352466,5.285402218862249,3.321928094887362,4.321928094887363,4.700439718141092,4.700439718141092,4.247927513443585,4.754887502163468,6.20945336562895,7.658211482751795,5.882643049361842,4.087462841250339,5.426264754702098,5.285402218862249,5.0,4.169925001442312,4.807354922057604,4.643856189774724,4.643856189774724,8.546894459887637,9.079484783826816,7.584962500721156,6.672425341971495,7.483815777264256,6.392317422778761,6.149747119504682,5.426264754702098,5.426264754702098,5.426264754702098,5.392317422778761,6.169925001442312,7.348728154231077,1.0,5.491853096329675,8.409390936137703,4.459431618637297,4.459431618637297,6.149747119504682,1.584962500721156,6.189824558880018,6.554588851677638,6.491853096329675,6.845490050944375,6.20945336562895,5.044394119358453,5.882643049361842,6.870364719583405,6.554588851677638,5.857980995127572,5.807354922057604,7.2761244052742375,7.366322214245816,6.78135971352466,5.700439718141092,6.584962500721156,6.6865005271832185,6.044394119358453,6.247927513443585,5.392317422778761,5.930737337562887,5.930737337562887,8.379378367071261,8.90388184573618,8.710806433699352,7.6293566200796095,8.50382573799575,7.94251450533924,7.658211482751795,6.930737337562887,6.918863237274595,6.918863237274595,6.906890595608519,7.787902559391432,8.873444112515376,2.0,6.954196310386875,10.084808387804362,6.129283016944966,6.129283016944966,6.965784284662087,7.22881869049588,7.467605550082998,7.7481928495894605,7.7073591320808825,6.599912842187128,6.022367813028454,5.857980995127572,6.0,6.954196310386875,5.285402218862249,5.672425341971495,6.303780748177103,7.129283016944966,7.339850002884624,6.845490050944375,5.247927513443585,6.266786540694901,6.442943495848728,5.643856189774724,6.149747119504682,4.954196310386875,5.727920454563199,5.727920454563199,7.98299357469431,8.804131021183318,8.703903573444663,7.754887502163468,8.523561956057012,8.08214904135387,7.149747119504682,6.303780748177103,6.303780748177103,6.303780748177103,6.303780748177103,7.906890595608519,8.968666793195208,null,6.794415866350106,10.099347810403193,6.087462841250339,6.087462841250339,7.118941072723508,7.960001932068081,7.451211111832329,7.577428828035749,7.577428828035749,6.303780748177103,5.20945336562895,5.930737337562887,5.78135971352466,6.442943495848728,6.108524456778169,5.044394119358453,5.832890014164741,6.741466986401147,6.918863237274595,6.965784284662087,4.247927513443585,6.321928094887363,6.569855608330948,5.459431618637297,5.807354922057604,5.169925001442312,5.906890595608519,5.906890595608519,7.734709620225838,8.475733430966399,8.276124405274238,7.577428828035749,8.169925001442312,7.864186144654281,6.870364719583405,6.0,5.977279923499917,5.977279923499917,5.930737337562887,7.339850002884624,8.442943495848729,null,6.614709844115208,9.912889336229961,5.954196310386875,5.954196310386875,7.0,7.442943495848728,7.451211111832329,7.426264754702098,7.409390936137702,5.459431618637297,4.643856189774724,5.087462841250339,5.882643049361842,6.599912842187128,5.087462841250339,3.9068905956085187,5.285402218862249,5.807354922057604,6.044394119358453,6.0,4.321928094887363,4.392317422778761,5.0,5.169925001442312,5.977279923499917,3.4594316186372973,4.321928094887363,4.321928094887363,6.741466986401147,7.679480099505446,7.098032082960526,6.554588851677638,7.247927513443585,7.20945336562895,6.189824558880018,5.392317422778761,5.392317422778761,5.392317422778761,5.392317422778761,7.266786540694901,8.31741261376487,null,5.807354922057604,7.857980995127572,4.643856189774724,4.643856189774724,5.954196310386875,6.554588851677638,5.857980995127572,6.599912842187128,6.584962500721156,7.108524456778169,6.409390936137702,5.459431618637297,6.108524456778169,6.832890014164741,6.459431618637297,4.906890595608519,6.149747119504682,7.400879436282184,7.098032082960526,7.022367813028454,4.807354922057604,6.870364719583405,6.6293566200796095,5.554588851677638,5.727920454563199,5.584962500721156,5.700439718141092,5.700439718141092,8.271463027904375,8.915879378835774,8.741466986401146,7.774787059601174,8.668884984266247,7.936637939002571,7.266786540694901,6.475733430966398,6.475733430966398,6.475733430966398,6.475733430966398,7.800899899920305,8.90388184573618,4.584962500721156,6.882643049361842,9.06339508128851,6.554588851677638,6.554588851677638,6.475733430966398,7.149747119504682,7.348728154231077,7.734709620225838,7.727920454563199,6.3750394313469245,6.149747119504682,5.285402218862249,5.491853096329675,6.169925001442312,5.857980995127572,5.491853096329675,5.357552004618084,6.741466986401147,6.6865005271832185,5.906890595608519,4.906890595608519,5.459431618637297,6.129283016944966,5.643856189774724,6.20945336562895,4.643856189774724,5.491853096329675,5.491853096329675,7.7481928495894605,7.971543553950772,8.087462841250339,7.2384047393250786,7.98299357469431,7.491853096329675,6.977279923499917,6.339850002884624,6.339850002884624,6.339850002884624,6.339850002884624,7.357552004618084,8.39231742277876,1.584962500721156,6.614709844115208,8.933690654952233,5.882643049361842,5.882643049361842,7.076815597050831,6.569855608330948,6.930737337562887,7.294620748891627,7.1799090900149345,6.491853096329675,5.392317422778761,4.584962500721156,4.754887502163468,5.643856189774724,5.584962500721156,5.321928094887363,5.087462841250339,6.523561956057013,6.700439718141092,5.954196310386875,4.0,5.044394119358453,5.832890014164741,5.285402218862249,6.0,4.584962500721156,4.954196310386875,4.954196310386875,7.22881869049588,8.375039431346925,7.754887502163468,7.189824558880018,7.672425341971495,7.348728154231077,6.599912842187128,5.754887502163468,5.754887502163468,5.754887502163468,5.727920454563199,7.247927513443585,8.308339030139408,0.0,6.3750394313469245,8.519636252843213,5.554588851677638,5.554588851677638,7.066089190457772,5.832890014164741,6.658211482751795,6.954196310386875,6.906890595608519,4.754887502163468,4.857980995127572,3.321928094887362,4.643856189774724,5.285402218862249,4.754887502163468,4.247927513443585,3.9068905956085187,5.700439718141092,5.614709844115208,5.727920454563199,3.169925001442312,4.459431618637297,4.392317422778761,4.392317422778761,3.584962500721156,3.321928094887362,4.584962500721156,4.584962500721156,6.426264754702098,7.383704292474052,6.965784284662087,6.169925001442312,7.0,6.066089190457772,5.643856189774724,4.700439718141092,4.700439718141092,4.700439718141092,4.700439718141092,6.129283016944966,7.247927513443585,null,4.584962500721156,7.467605550082998,4.392317422778761,4.459431618637297,5.321928094887363,5.321928094887363,6.266786540694901,6.022367813028454,6.022367813028454,5.614709844115208,5.584962500721156,4.0,4.584962500721156,5.523561956057013,4.754887502163468,5.0,4.700439718141092,5.672425341971495,6.321928094887363,6.475733430966398,4.169925001442312,5.247927513443585,5.129283016944966,4.643856189774724,5.321928094887363,4.523561956057013,4.643856189774724,4.643856189774724,7.139551352398794,7.523561956057013,7.357552004618084,6.643856189774724,7.303780748177103,6.906890595608519,6.507794640198696,5.700439718141092,5.700439718141092,5.700439718141092,5.672425341971495,6.539158811108031,7.599912842187128,null,5.392317422778761,9.330916878114618,4.807354922057604,4.807354922057604,6.442943495848728,6.820178962415188,6.247927513443585,6.845490050944375,6.794415866350106,5.643856189774724,4.807354922057604,4.321928094887363,5.0,5.426264754702098,5.584962500721156,4.906890595608519,5.285402218862249,6.266786540694901,6.599912842187128,6.129283016944966,4.643856189774724,4.459431618637297,5.78135971352466,5.169925001442312,5.930737337562887,4.700439718141092,4.087462841250339,4.087462841250339,7.312882955284356,8.134426320220927,7.845490050944375,6.857980995127572,7.714245517666122,7.159871336778389,6.507794640198696,5.930737337562887,5.930737337562887,5.930737337562887,5.882643049361842,6.894817763307944,7.930737337562887,1.0,6.149747119504682,8.588714635582264,5.247927513443585,5.247927513443585,6.672425341971495,5.807354922057604,6.539158811108031,6.658211482751795,6.614709844115208,5.807354922057604,5.426264754702098,4.0,4.459431618637297,5.459431618637297,4.169925001442312,4.954196310386875,5.044394119358453,5.584962500721156,5.857980995127572,6.0,3.584962500721156,4.584962500721156,5.392317422778761,4.807354922057604,4.459431618637297,3.807354922057604,4.247927513443585,4.247927513443585,6.930737337562887,7.499845887083206,7.491853096329675,6.491853096329675,7.266786540694901,6.741466986401147,5.977279923499917,5.129283016944966,5.129283016944966,5.129283016944966,5.129283016944966,6.643856189774724,7.7481928495894605,null,5.247927513443585,8.092757140919852,4.700439718141092,4.700439718141092,5.700439718141092,5.523561956057013,5.754887502163468,6.658211482751795,6.643856189774724,6.768184324776926,6.169925001442312,5.459431618637297,6.108524456778169,7.108524456778169,5.930737337562887,4.523561956057013,5.754887502163468,6.6865005271832185,6.78135971352466,7.1799090900149345,4.169925001442312,6.20945336562895,6.658211482751795,5.727920454563199,4.584962500721156,5.247927513443585,5.832890014164741,5.832890014164741,7.839203788096944,8.665335917185176,8.535275376620802,7.994353436858858,8.479780264029099,8.149747119504681,7.383704292474052,6.614709844115208,6.614709844115208,6.614709844115208,6.599912842187128,7.807354922057604,8.894817763307943,0.0,7.022367813028454,9.240791332161956,6.169925001442312,6.169925001442312,7.383704292474052,7.066089190457772,7.442943495848728,7.592457037268081,7.562242424221073,5.832890014164741,4.523561956057013,3.807354922057604,4.807354922057604,5.129283016944966,4.523561956057013,5.087462841250339,4.857980995127572,6.357552004618084,6.357552004618084,6.409390936137702,3.169925001442312,5.321928094887363,4.392317422778761,4.643856189774724,5.392317422778761,4.247927513443585,4.807354922057604,4.807354922057604,7.321928094887363,8.011227255423254,7.442943495848728,6.643856189774724,7.285402218862249,7.044394119358453,6.247927513443585,5.491853096329675,5.491853096329675,5.491853096329675,5.491853096329675,6.409390936137702,7.592457037268081,null,6.247927513443585,9.019590728357882,4.807354922057604,4.857980995127572,5.807354922057604,6.894817763307944,6.409390936137702,6.584962500721156,6.539158811108031,5.882643049361842,5.321928094887363,4.700439718141092,5.285402218862249,6.022367813028454,4.857980995127572,4.700439718141092,4.857980995127572,6.087462841250339,6.539158811108031,6.0,4.459431618637297,4.906890595608519,5.044394119358453,4.523561956057013,5.754887502163468,3.700439718141092,4.754887502163468,4.754887502163468,7.022367813028454,7.400879436282184,7.499845887083206,6.807354922057604,7.400879436282184,7.139551352398794,6.022367813028454,5.087462841250339,5.087462841250339,5.087462841250339,5.0,7.22881869049588,8.228818690495881,2.807354922057604,6.022367813028454,9.366322214245816,4.954196310386875,4.954196310386875,6.392317422778761,7.294620748891627,6.149747119504682,7.022367813028454,6.977279923499917,6.409390936137702,6.643856189774724,4.643856189774724,5.832890014164741,6.303780748177103,6.0,5.700439718141092,5.727920454563199,6.954196310386875,7.118941072723508,6.882643049361842,4.643856189774724,5.20945336562895,6.599912842187128,6.0,5.954196310386875,5.169925001442312,5.614709844115208,5.614709844115208,8.016808287686555,8.696967526234287,8.400879436282183,7.475733430966398,8.29920801838728,7.882643049361842,7.219168520462161,6.3750394313469245,6.3750394313469245,6.3750394313469245,6.357552004618084,7.531381460516312,8.682994583681683,3.584962500721156,7.108524456778169,9.932214751968385,6.087462841250339,6.087462841250339,6.845490050944375,7.787902559391432,7.2761244052742375,7.60733031374961,7.554588851677638,2.584962500721156,2.0,null,1.584962500721156,2.0,null,2.321928094887362,2.0,1.0,0.0,3.0,null,null,0.0,0.0,0.0,1.0,null,null,3.169925001442312,2.584962500721156,4.0,2.321928094887362,3.584962500721156,3.584962500721156,2.0,1.584962500721156,1.584962500721156,1.584962500721156,1.584962500721156,3.321928094887362,4.169925001442312,null,2.584962500721156,5.285402218862249,2.0,2.0,1.584962500721156,2.0,2.807354922057604,3.0,2.584962500721156,5.727920454563199,5.554588851677638,5.614709844115208,4.807354922057604,5.930737337562887,4.321928094887363,4.459431618637297,4.906890595608519,6.129283016944966,6.0,5.930737337562887,3.9068905956085187,4.906890595608519,5.832890014164741,4.584962500721156,4.0,4.392317422778761,4.392317422778761,4.392317422778761,7.159871336778389,7.643856189774724,7.442943495848728,6.658211482751795,7.409390936137702,6.845490050944375,6.066089190457772,5.169925001442312,5.169925001442312,5.169925001442312,5.169925001442312,6.754887502163468,7.888743248898259,1.0,6.022367813028454,9.12670447284319,5.357552004618084,5.357552004618084,6.247927513443585,7.022367813028454,6.6293566200796095,6.392317422778761,6.357552004618084,6.3750394313469245,6.087462841250339,4.584962500721156,5.129283016944966,6.108524456778169,5.357552004618084,4.906890595608519,5.169925001442312,6.584962500721156,6.539158811108031,6.0,4.0,6.0,6.0,5.614709844115208,5.321928094887363,4.523561956057013,4.700439718141092,4.700439718141092,7.693486957499325,8.108524456778168,7.900866807980749,7.159871336778389,7.832890014164741,7.451211111832329,7.05528243550119,6.22881869049588,6.22881869049588,6.22881869049588,6.20945336562895,7.257387842692652,8.361943773735241,null,6.643856189774724,8.43879185257826,5.392317422778761,5.392317422778761,6.022367813028454,0.0,7.022367813028454,7.189824558880018,7.098032082960526,5.392317422778761,5.044394119358453,4.459431618637297,4.754887502163468,5.426264754702098,4.459431618637297,4.643856189774724,4.247927513443585,5.78135971352466,5.857980995127572,5.78135971352466,3.169925001442312,4.523561956057013,5.044394119358453,4.459431618637297,4.392317422778761,3.321928094887362,3.700439718141092,3.700439718141092,6.643856189774724,7.294620748891627,7.321928094887363,6.303780748177103,7.066089190457772,6.409390936137702,5.700439718141092,5.044394119358453,5.044394119358453,5.044394119358453,5.0,6.129283016944966,7.257387842692652,1.584962500721156,5.954196310386875,8.787902559391432,5.044394119358453,5.044394119358453,5.20945336562895,5.392317422778761,6.087462841250339,6.189824558880018,6.108524456778169],\"y0\":\" \",\"yaxis\":\"y\",\"type\":\"box\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"],[\"3L\",\"AIM12\"],[\"3L\",\"AIM13\"],[\"3L\",\"AIM14\"],[\"3L\",\"AIM15\"],[\"3L\",\"AIM16\"],[\"3L\",\"AIM17\"],[\"3L\",\"Tep1A\"],[\"3L\",\"Tep1B\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003eamplicon=%{x}\\u003cbr\\u003elog_depth=%{y}\\u003cbr\\u003emutation=%{customdata[1]}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"3L\",\"marker\":{\"color\":\"#D62728\"},\"name\":\"3L\",\"notched\":false,\"offsetgroup\":\"3L\",\"orientation\":\"v\",\"showlegend\":true,\"x\":[\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\"],\"x0\":\" \",\"xaxis\":\"x\",\"y\":[null,6.321928094887363,3.700439718141092,8.717676423066395,5.643856189774724,7.721099188707185,6.906890595608519,6.087462841250339,null,3.584962500721156,3.0,4.247927513443585,1.584962500721156,1.0,3.584962500721156,2.0,null,null,null,1.584962500721156,null,null,null,1.584962500721156,null,1.0,null,1.0,1.0,2.0,2.321928094887362,2.321928094887362,null,3.4594316186372973,1.0,5.285402218862249,null,1.0,5.459431618637297,2.584962500721156,null,5.285402218862249,3.807354922057604,4.857980995127572,4.0,4.807354922057604,3.807354922057604,4.169925001442312,null,1.584962500721156,null,null,3.700439718141092,null,null,1.0,null,null,null,0.0,null,2.0,null,1.0,null,null,null,0.0,null,1.0,null,1.0,null,3.4594316186372973,1.0,2.584962500721156,2.0,4.643856189774724,3.169925001442312,3.321928094887362,null,2.584962500721156,1.0,2.321928094887362,3.0,3.0,1.584962500721156,2.0,null,1.584962500721156,null,3.0,1.0,0.0,null,2.0,null,4.459431618637297,3.584962500721156,5.087462841250339,4.321928094887363,3.807354922057604,4.584962500721156,4.087462841250339,null,4.169925001442312,4.0,5.491853096329675,3.700439718141092,4.954196310386875,4.584962500721156,3.584962500721156,0.0,3.169925001442312,null,1.584962500721156,0.0,1.584962500721156,3.584962500721156,3.0,null,3.321928094887362,2.321928094887362,4.906890595608519,1.584962500721156,4.0,4.754887502163468,3.584962500721156,null,4.0,1.584962500721156,4.392317422778761,2.584962500721156,3.9068905956085187,4.807354922057604,3.584962500721156,null,4.169925001442312,2.0,4.321928094887363,2.0,3.584962500721156,2.0,2.321928094887362,null,6.044394119358453,3.169925001442312,6.442943495848728,4.392317422778761,5.857980995127572,4.857980995127572,5.584962500721156,null,3.0,0.0,null,0.0,1.584962500721156,1.584962500721156,2.321928094887362,null,6.20945336562895,3.9068905956085187,5.044394119358453,4.169925001442312,5.78135971352466,3.169925001442312,3.584962500721156,null,3.807354922057604,1.584962500721156,4.392317422778761,3.700439718141092,3.321928094887362,4.169925001442312,2.584962500721156,null,0.0,null,1.0,0.0,2.807354922057604,2.0,0.0,null,0.0,null,0.0,null,null,null,1.0,null,7.515699838284043,2.0,3.0,2.807354922057604,6.266786540694901,2.0,6.845490050944375,null,6.491853096329675,4.392317422778761,6.321928094887363,4.584962500721156,5.523561956057013,6.6865005271832185,6.087462841250339,null,4.700439718141092,2.807354922057604,5.044394119358453,4.0,4.754887502163468,4.247927513443585,3.807354922057604,null,2.807354922057604,1.0,null,1.584962500721156,0.0,2.584962500721156,2.0,null,4.857980995127572,3.4594316186372973,4.321928094887363,3.584962500721156,4.754887502163468,5.0,4.700439718141092,null,7.03342300153745,4.247927513443585,7.2761244052742375,5.882643049361842,6.930737337562887,5.459431618637297,5.727920454563199,null,0.0,2.0,null,null,1.584962500721156,null,1.0,null,4.321928094887363,3.4594316186372973,2.807354922057604,3.169925001442312,3.9068905956085187,3.321928094887362,3.169925001442312,null,6.22881869049588,4.459431618637297,6.442943495848728,4.392317422778761,5.129283016944966,5.129283016944966,5.169925001442312,null,5.523561956057013,3.700439718141092,4.954196310386875,5.169925001442312,6.658211482751795,4.0,5.977279923499917,null,4.807354922057604,2.0,5.727920454563199,2.584962500721156,4.807354922057604,4.700439718141092,4.169925001442312,null,null,1.0,0.0,null,0.0,null,null,null,7.266786540694901,5.321928094887363,7.189824558880018,5.78135971352466,5.807354922057604,7.60733031374961,7.05528243550119,null,4.169925001442312,3.584962500721156,4.523561956057013,3.700439718141092,5.044394119358453,5.321928094887363,4.169925001442312,null,4.523561956057013,2.584962500721156,4.954196310386875,3.321928094887362,5.459431618637297,5.700439718141092,4.321928094887363,null,6.022367813028454,3.584962500721156,4.584962500721156,5.044394119358453,5.087462841250339,4.523561956057013,5.807354922057604,null,4.754887502163468,1.584962500721156,4.523561956057013,4.169925001442312,4.321928094887363,3.9068905956085187,3.321928094887362,null,4.700439718141092,3.0,3.4594316186372973,2.807354922057604,3.700439718141092,4.321928094887363,3.584962500721156,null,5.459431618637297,3.9068905956085187,6.3750394313469245,5.426264754702098,6.108524456778169,null,3.169925001442312,null,5.129283016944966,1.0,4.0,3.9068905956085187,5.0,1.0,null,null,5.087462841250339,3.584962500721156,4.247927513443585,3.169925001442312,2.321928094887362,4.807354922057604,4.906890595608519,null,3.0,1.584962500721156,3.807354922057604,3.0,3.9068905956085187,4.169925001442312,2.584962500721156,null,4.321928094887363,1.584962500721156,4.459431618637297,3.4594316186372973,4.700439718141092,4.523561956057013,3.807354922057604,null,null,null,0.0,null,2.0,null,null,null,7.554588851677638,4.906890595608519,7.6653359171851765,5.807354922057604,7.7073591320808825,7.651051691178929,7.066089190457772,null,7.507794640198696,5.169925001442312,6.977279923499917,6.285402218862249,7.392317422778761,6.614709844115208,6.78135971352466,7.6865005271832185,8.422064766172813,7.0,8.703903573444663,6.714245517666122,7.409390936137702,7.129283016944966,7.599912842187128,null,5.20945336562895,2.321928094887362,6.741466986401147,4.087462841250339,5.614709844115208,3.0,3.584962500721156,null,6.0,3.584962500721156,5.857980995127572,4.954196310386875,5.357552004618084,3.807354922057604,4.523561956057013,null,4.857980995127572,3.169925001442312,3.807354922057604,3.4594316186372973,4.0,4.0,3.807354922057604,null,6.409390936137702,4.0,7.321928094887363,5.169925001442312,6.6865005271832185,5.727920454563199,5.832890014164741,null,5.614709844115208,2.0,6.714245517666122,2.807354922057604,5.459431618637297,5.954196310386875,4.807354922057604,null,5.044394119358453,0.0,4.754887502163468,2.0,4.584962500721156,4.321928094887363,4.584962500721156,null,3.169925001442312,2.584962500721156,2.807354922057604,2.0,2.584962500721156,4.169925001442312,3.700439718141092,null,3.9068905956085187,2.321928094887362,5.523561956057013,2.807354922057604,4.954196310386875,5.169925001442312,3.700439718141092,null,null,null,0.0,null,null,1.0,0.0,1.0,8.707359132080883,7.312882955284356,8.491853096329674,7.832890014164741,8.243173983472952,8.214319120800766,8.558420713268664,null,7.20945336562895,5.044394119358453,7.839203788096944,5.882643049361842,6.845490050944375,6.409390936137702,6.754887502163468,null,4.954196310386875,2.584962500721156,5.554588851677638,3.4594316186372973,5.0,4.321928094887363,4.169925001442312,null,6.599912842187128,3.4594316186372973,7.066089190457772,6.022367813028454,7.066089190457772,6.087462841250339,5.754887502163468,null,1.0,null,null,0.0,null,2.0,null,null,4.321928094887363,1.0,3.169925001442312,3.169925001442312,2.807354922057604,null,1.584962500721156,null,5.247927513443585,2.807354922057604,5.754887502163468,3.321928094887362,5.0,5.357552004618084,4.906890595608519,null,4.247927513443585,1.0,5.129283016944966,2.0,4.321928094887363,3.584962500721156,3.9068905956085187,null,4.087462841250339,0.0,3.321928094887362,1.584962500721156,3.584962500721156,1.584962500721156,3.0,null,3.700439718141092,2.321928094887362,3.700439718141092,3.4594316186372973,4.247927513443585,3.0,3.807354922057604,null,2.0,0.0,2.321928094887362,null,2.0,0.0,1.0,null,null,null,0.0,null,1.0,0.0,null,null,5.672425341971495,4.584962500721156,5.554588851677638,5.169925001442312,5.832890014164741,5.044394119358453,5.882643049361842,null,5.906890595608519,3.0,5.614709844115208,5.357552004618084,5.523561956057013,5.459431618637297,5.754887502163468,null,5.857980995127572,2.321928094887362,3.807354922057604,5.0,5.584962500721156,3.9068905956085187,4.807354922057604,null,6.442943495848728,4.700439718141092,5.554588851677638,5.700439718141092,5.554588851677638,4.459431618637297,5.357552004618084,null,3.584962500721156,2.321928094887362,3.4594316186372973,2.584962500721156,4.169925001442312,2.0,3.321928094887362,null,4.584962500721156,1.584962500721156,4.906890595608519,4.754887502163468,4.584962500721156,3.700439718141092,3.9068905956085187,null,8.194756854422248,6.768184324776926,7.330916878114617,7.20945336562895,6.539158811108031,7.679480099505446,7.734709620225838,null,2.0,1.584962500721156,3.169925001442312,2.321928094887362,3.4594316186372973,2.584962500721156,3.9068905956085187,0.0,6.285402218862249,5.0,5.169925001442312,5.906890595608519,4.459431618637297,4.459431618637297,5.614709844115208,null,3.9068905956085187,2.807354922057604,2.584962500721156,3.700439718141092,3.0,1.0,null,null,4.087462841250339,1.0,4.0,4.087462841250339,4.169925001442312,3.4594316186372973,4.321928094887363,null,null,null,0.0,null,2.0,0.0,0.0,null,7.434628227636725,6.129283016944966,6.78135971352466,6.918863237274595,6.94251450533924,6.78135971352466,7.366322214245816,2.0,9.211888294546004,8.169925001442312,8.845490050944376,8.370687406807217,8.94251450533924,8.848622940429339,9.467605550082997,null,3.700439718141092,3.807354922057604,3.700439718141092,3.0,4.0,0.0,3.0,null,5.807354922057604,2.321928094887362,5.954196310386875,5.459431618637297,5.357552004618084,4.906890595608519,5.321928094887363,null,null,null,1.584962500721156,null,1.0,0.0,1.0,null,0.0,null,null,0.0,3.169925001442312,1.0,2.0,null,6.066089190457772,2.584962500721156,5.129283016944966,5.700439718141092,5.459431618637297,4.954196310386875,5.459431618637297,null,null,null,0.0,null,null,null,null,null,5.285402218862249,3.321928094887362,4.0,3.4594316186372973,4.087462841250339,5.044394119358453,5.357552004618084,0.0,null,null,1.584962500721156,null,1.0,null,0.0,null,5.977279923499917,3.169925001442312,4.392317422778761,4.392317422778761,5.321928094887363,5.087462841250339,5.392317422778761,null,null,null,1.0,null,0.0,0.0,1.0,0.0,2.807354922057604,0.0,5.247927513443585,null,3.0,5.044394119358453,3.0,null,0.0,1.0,null,0.0,null,0.0,1.0,6.820178962415188,6.189824558880018,5.169925001442312,7.098032082960526,4.807354922057604,6.599912842187128,6.569855608330948,5.954196310386875,null,4.0,5.087462841250339,4.169925001442312,6.339850002884624,2.0,6.741466986401147,5.882643049361842,null,2.0,3.321928094887362,4.0,4.087462841250339,1.0,6.6865005271832185,4.954196310386875,1.584962500721156,3.0,0.0,null,1.0,2.584962500721156,null,null,null,0.0,null,null,2.321928094887362,2.584962500721156,null,1.0,null,null,null,2.584962500721156,null,null,1.0,null,3.700439718141092,2.321928094887362,2.321928094887362,2.807354922057604,2.584962500721156,3.0,2.807354922057604,1.0,2.0,1.584962500721156,1.0,3.169925001442312,1.0,2.584962500721156,2.0,2.0,0.0,null,1.584962500721156,0.0,3.169925001442312,null,2.807354922057604,null,null,0.0,null,1.584962500721156,0.0,null,2.0,2.584962500721156,0.0,1.584962500721156,2.807354922057604,2.584962500721156,3.700439718141092,0.0,5.087462841250339,1.0,6.727920454563199,6.507794640198696,5.321928094887363,6.894817763307944,5.584962500721156,7.294620748891627,6.357552004618084,6.247927513443585,null,null,null,0.0,null,0.0,null,null,0.0,0.0,4.087462841250339,null,2.0,0.0,4.459431618637297,3.807354922057604,null,2.321928094887362,null,3.4594316186372973,null,2.584962500721156,2.0,0.0,null,0.0,null,3.584962500721156,null,2.321928094887362,2.807354922057604,1.0,null,0.0,1.584962500721156,2.321928094887362,3.0,0.0,4.584962500721156,3.0,null,null,null,0.0,0.0,0.0,3.0,3.0,3.169925001442312,2.584962500721156,1.0,4.392317422778761,null,4.087462841250339,2.0,2.0,null,1.0,1.0,null,1.0,1.0,5.169925001442312,null,2.321928094887362,2.807354922057604,0.0,3.0,2.0,4.247927513443585,3.9068905956085187,2.584962500721156,null,null,0.0,1.0,null,1.584962500721156,1.584962500721156,1.584962500721156,5.169925001442312,5.882643049361842,2.0,3.321928094887362,1.584962500721156,4.700439718141092,2.0,4.584962500721156,null,1.0,4.247927513443585,1.0,5.426264754702098,2.584962500721156,6.087462841250339,5.491853096329675,2.807354922057604,0.0,null,2.584962500721156,2.0,0.0,3.700439718141092,null,null,null,null,3.0,null,null,null,0.0,null,null,3.0,null,1.0,0.0,5.459431618637297,3.807354922057604,null,1.0,2.321928094887362,0.0,3.0,null,4.754887502163468,2.0,0.0,1.584962500721156,0.0,5.882643049361842,1.584962500721156,0.0,5.643856189774724,3.0,null,null,1.584962500721156,1.584962500721156,1.584962500721156,0.0,4.169925001442312,2.321928094887362,null,3.584962500721156,0.0,3.807354922057604,0.0,2.584962500721156,2.584962500721156,1.0,null,1.0,1.584962500721156,1.0,1.0,1.0,1.0,1.584962500721156,0.0,null,0.0,null,null,1.0,3.169925001442312,1.0,null,null,0.0,0.0,1.0,0.0,2.0,null,0.0,2.0,4.906890595608519,3.4594316186372973,5.491853096329675,1.0,6.9886846867721655,5.584962500721156,null,1.0,3.700439718141092,1.0,4.643856189774724,1.584962500721156,6.727920454563199,3.9068905956085187,3.4594316186372973,5.0,1.584962500721156,4.523561956057013,3.321928094887362,5.584962500721156,4.392317422778761,5.20945336562895,1.0,null,3.4594316186372973,2.0,5.247927513443585,1.584962500721156,3.321928094887362,4.523561956057013,null,null,null,null,1.0,0.0,0.0,1.0,null,null,null,2.807354922057604,2.807354922057604,0.0,2.584962500721156,3.0,2.321928094887362,1.584962500721156,0.0,3.321928094887362,null,3.0,2.0,2.584962500721156,null,0.0,0.0,2.0,1.0,null,1.584962500721156,1.0,null,null,1.584962500721156,null,3.321928094887362,null,4.169925001442312,3.584962500721156,null,null,null,null,null,0.0,2.0,2.0,0.0,null,0.0,null,null,null,2.0,null,0.0,null,null,null,0.0,0.0,3.0,null,null,1.584962500721156,0.0,3.4594316186372973,null,1.0,4.0,1.0,1.584962500721156,3.0,4.584962500721156,4.906890595608519,5.727920454563199,0.0,5.977279923499917,6.409390936137702,null,1.0,4.906890595608519,1.584962500721156,5.392317422778761,0.0,6.169925001442312,5.20945336562895,3.584962500721156,2.584962500721156,1.584962500721156,6.066089190457772,1.0,4.0,4.392317422778761,3.321928094887362,null,null,1.584962500721156,5.0,2.0,null,1.0,2.321928094887362,null,3.700439718141092,1.584962500721156,3.4594316186372973,1.0,2.584962500721156,4.392317422778761,3.321928094887362,null,1.0,1.0,3.321928094887362,2.584962500721156,0.0,4.584962500721156,1.0,null,0.0,1.584962500721156,2.321928094887362,1.584962500721156,2.584962500721156,3.584962500721156,null,3.4594316186372973,3.700439718141092,3.700439718141092,6.614709844115208,3.9068905956085187,3.4594316186372973,6.6865005271832185,4.807354922057604,null,0.0,1.584962500721156,3.169925001442312,2.0,0.0,4.754887502163468,2.584962500721156,null,null,null,2.321928094887362,2.584962500721156,null,2.0,2.321928094887362,0.0,null,null,1.584962500721156,1.0,0.0,4.643856189774724,3.0,null,null,null,3.4594316186372973,null,2.0,3.584962500721156,null,4.584962500721156,4.523561956057013,3.321928094887362,4.754887502163468,2.584962500721156,3.9068905956085187,5.087462841250339,4.087462841250339,0.0,1.584962500721156,null,4.754887502163468,3.321928094887362,0.0,6.022367813028454,1.0,2.0,3.584962500721156,5.129283016944966,5.129283016944966,5.906890595608519,0.0,6.614709844115208,5.285402218862249,null,null,null,1.0,null,null,2.0,null,null,1.584962500721156,1.584962500721156,4.523561956057013,2.321928094887362,null,2.584962500721156,1.0,null,null,0.0,null,0.0,null,1.0,1.0,null,null,0.0,4.169925001442312,1.0,0.0,3.321928094887362,null,null,0.0,1.584962500721156,null,2.0,0.0,3.4594316186372973,2.0,2.584962500721156,3.584962500721156,3.0,2.807354922057604,2.0,3.169925001442312,2.0,1.0,null,2.807354922057604,0.0,3.584962500721156,2.321928094887362,null,2.0,1.0,null,null,null,null,0.0,null,1.0,null,6.426264754702098,5.247927513443585,5.247927513443585,5.169925001442312,5.087462841250339,4.087462841250339,5.672425341971495,5.426264754702098,null,null,0.0,1.584962500721156,1.584962500721156,1.584962500721156,null,1.0,1.0,null,2.0,1.0,5.169925001442312,1.584962500721156,4.169925001442312,5.129283016944966,5.20945336562895,6.087462841250339,4.700439718141092,6.189824558880018,4.392317422778761,5.954196310386875,4.0,5.129283016944966,0.0,5.426264754702098,3.0,4.392317422778761,5.169925001442312,4.584962500721156,3.169925001442312,4.392317422778761,null,null,2.0,null,3.0,null,null,1.0,null,4.169925001442312,2.584962500721156,2.584962500721156,3.321928094887362,4.169925001442312,1.0,3.584962500721156,2.321928094887362,3.4594316186372973,0.0,3.0,2.321928094887362,2.0,1.584962500721156,3.321928094887362,null,null,1.584962500721156,1.584962500721156,3.9068905956085187,1.0,2.0,1.584962500721156,null,null,0.0,null,1.0,null,2.0,1.0,null,1.0,0.0,1.0,0.0,null,2.584962500721156,null,null,null,null,null,null,null,null,1.584962500721156,null,null,1.584962500721156,2.0,3.584962500721156,1.0,4.643856189774724,3.169925001442312,10.026523442519766,9.509775004326936,8.693486957499326,8.614709844115207,8.658211482751796,9.357552004618084,8.194756854422248,9.461479447286155,0.0,1.0,null,2.321928094887362,3.0,1.0,2.0,2.0,null,null,3.807354922057604,1.0,5.977279923499917,1.584962500721156,5.169925001442312,2.321928094887362,null,1.0,4.392317422778761,null,5.357552004618084,1.0,5.700439718141092,4.392317422778761,null,null,null,null,1.584962500721156,null,null,1.0,null,null,2.0,null,2.807354922057604,0.0,2.584962500721156,2.584962500721156,null,0.0,1.0,1.584962500721156,3.321928094887362,null,3.169925001442312,2.0,null,null,null,null,null,null,null,null,0.0,null,1.0,1.584962500721156,1.584962500721156,1.0,0.0,null,null,null,1.0,null,2.807354922057604,null,2.584962500721156,3.584962500721156,null,null,null,1.0,null,null,null,null,6.285402218862249,5.459431618637297,4.523561956057013,6.94251450533924,4.906890595608519,5.392317422778761,5.832890014164741,5.285402218862249,6.426264754702098,5.882643049361842,5.491853096329675,6.6865005271832185,4.459431618637297,5.321928094887363,5.285402218862249,5.459431618637297,7.845490050944375,7.3750394313469245,6.20945336562895,7.918863237274595,6.303780748177103,7.426264754702098,7.357552004618084,7.303780748177103,6.357552004618084,5.754887502163468,5.247927513443585,6.523561956057013,4.954196310386875,5.882643049361842,6.0,5.727920454563199,8.312882955284355,7.864186144654281,6.906890595608519,9.047123912114026,6.820178962415188,7.569855608330948,8.076815597050832,7.960001932068081,9.027905996569885,8.413627929024173,7.888743248898259,9.025139562278508,7.857980995127572,7.906890595608519,7.78135971352466,8.668884984266247,0.0,2.807354922057604,0.0,1.0,5.554588851677638,1.584962500721156,1.0,1.0,null,0.0,null,null,null,null,null,null,null,0.0,null,1.0,null,null,0.0,null,6.768184324776926,5.491853096329675,5.247927513443585,7.087462841250339,5.754887502163468,4.906890595608519,5.357552004618084,6.087462841250339,null,null,null,null,null,null,null,null,7.507794640198696,6.768184324776926,5.954196310386875,7.971543553950772,6.0,6.700439718141092,7.321928094887363,7.2384047393250786,7.7073591320808825,6.794415866350106,6.392317422778761,7.599912842187128,6.22881869049588,6.741466986401147,6.906890595608519,7.022367813028454,8.03342300153745,7.1799090900149345,6.442943495848728,7.467605550082998,6.672425341971495,7.1799090900149345,7.118941072723508,7.599912842187128,5.857980995127572,4.954196310386875,3.9068905956085187,5.857980995127572,4.954196310386875,5.614709844115208,5.285402218862249,5.087462841250339,6.857980995127572,6.426264754702098,6.523561956057013,7.169925001442312,5.129283016944966,6.741466986401147,6.475733430966398,6.22881869049588,7.592457037268081,6.569855608330948,6.22881869049588,7.199672344836364,5.78135971352466,6.78135971352466,7.066089190457772,6.672425341971495,7.044394119358453,6.857980995127572,5.832890014164741,7.6653359171851765,5.491853096329675,6.894817763307944,6.554588851677638,6.700439718141092,5.044394119358453,4.906890595608519,4.321928094887363,6.285402218862249,2.807354922057604,4.857980995127572,5.392317422778761,4.247927513443585,6.584962500721156,6.321928094887363,5.169925001442312,7.965784284662087,5.285402218862249,5.643856189774724,7.03342300153745,6.857980995127572,null,null,null,null,null,null,null,null,7.366322214245816,6.303780748177103,5.754887502163468,7.467605550082998,5.614709844115208,6.339850002884624,6.3750394313469245,6.392317422778761,null,null,null,1.0,0.0,null,null,null,6.475733430966398,5.044394119358453,4.906890595608519,7.409390936137702,4.643856189774724,5.78135971352466,6.149747119504682,5.614709844115208,6.066089190457772,5.78135971352466,2.807354922057604,3.321928094887362,3.0,5.643856189774724,2.0,5.20945336562895,6.169925001442312,5.523561956057013,3.807354922057604,6.672425341971495,4.807354922057604,6.044394119358453,5.807354922057604,5.700439718141092,5.129283016944966,4.643856189774724,4.087462841250339,5.523561956057013,4.321928094887363,5.643856189774724,5.754887502163468,4.906890595608519,7.0,6.475733430966398,5.523561956057013,7.467605550082998,5.426264754702098,6.066089190457772,6.643856189774724,6.857980995127572,6.700439718141092,6.044394119358453,4.954196310386875,7.149747119504682,5.357552004618084,5.930737337562887,5.78135971352466,6.3750394313469245,1.0,0.0,null,1.0,0.0,null,null,null,null,null,null,null,null,1.0,null,1.0,6.108524456778169,4.906890595608519,4.459431618637297,6.754887502163468,4.584962500721156,4.523561956057013,5.392317422778761,5.087462841250339,7.400879436282184,6.965784284662087,6.339850002884624,7.794415866350106,6.20945336562895,6.426264754702098,6.94251450533924,6.658211482751795,6.3750394313469245,5.643856189774724,5.357552004618084,5.807354922057604,5.044394119358453,5.584962500721156,6.108524456778169,5.459431618637297,null,null,null,1.0,null,null,null,1.0,6.442943495848728,5.930737337562887,5.584962500721156,7.303780748177103,4.954196310386875,6.0,5.977279923499917,6.20945336562895,5.977279923499917,5.491853096329675,5.0,6.129283016944966,4.754887502163468,4.247927513443585,5.285402218862249,5.523561956057013,6.392317422778761,5.977279923499917,5.087462841250339,7.076815597050831,5.321928094887363,5.20945336562895,6.22881869049588,5.882643049361842,6.442943495848728,5.700439718141092,4.459431618637297,6.94251450533924,4.906890595608519,6.459431618637297,5.977279923499917,6.169925001442312,6.459431618637297,6.22881869049588,5.20945336562895,6.714245517666122,5.129283016944966,5.754887502163468,5.807354922057604,6.426264754702098,6.6293566200796095,6.523561956057013,5.357552004618084,6.768184324776926,5.285402218862249,6.169925001442312,5.727920454563199,5.700439718141092,2.321928094887362,0.0,null,null,null,null,1.0,null,7.977279923499917,7.294620748891627,6.643856189774724,7.417852514885898,6.392317422778761,6.442943495848728,6.727920454563199,7.721099188707185,7.285402218862249,6.507794640198696,6.0,7.076815597050831,5.882643049361842,6.044394119358453,6.442943495848728,6.20945336562895,null,null,null,null,null,null,null,null,6.584962500721156,5.954196310386875,4.459431618637297,6.303780748177103,5.247927513443585,4.906890595608519,5.807354922057604,5.807354922057604,null,null,0.0,null,0.0,null,1.0,null,7.6865005271832185,7.312882955284356,6.357552004618084,8.361943773735241,6.169925001442312,6.870364719583405,7.515699838284043,7.700439718141092,6.285402218862249,6.087462841250339,5.459431618637297,6.321928094887363,4.584962500721156,5.700439718141092,5.285402218862249,6.0,6.906890595608519,6.614709844115208,5.523561956057013,7.22881869049588,5.554588851677638,6.189824558880018,6.087462841250339,6.523561956057013,0.0,0.0,1.584962500721156,3.0,1.0,2.321928094887362,2.321928094887362,2.584962500721156,5.882643049361842,5.044394119358453,4.643856189774724,6.672425341971495,4.169925001442312,5.285402218862249,5.882643049361842,5.643856189774724,6.700439718141092,5.882643049361842,5.044394119358453,7.257387842692652,4.954196310386875,5.247927513443585,5.930737337562887,6.108524456778169,1.584962500721156,3.321928094887362,null,4.169925001442312,null,1.0,null,null,4.807354922057604,4.700439718141092,3.584962500721156,5.584962500721156,3.0,5.247927513443585,5.584962500721156,4.087462841250339,7.098032082960526,6.614709844115208,5.672425341971495,7.247927513443585,5.882643049361842,6.6293566200796095,6.643856189774724,6.741466986401147,null,0.0,null,null,null,null,null,null,7.417852514885898,6.820178962415188,6.0,7.483815777264256,6.169925001442312,6.357552004618084,6.754887502163468,6.857980995127572,null,null,null,null,null,null,null,null,8.113742166049189,7.442943495848728,6.6865005271832185,8.247927513443585,6.599912842187128,6.768184324776926,7.357552004618084,7.459431618637297,8.055282435501189,7.434628227636725,6.303780748177103,7.794415866350106,6.870364719583405,7.139551352398794,6.832890014164741,7.658211482751795,7.108524456778169,6.357552004618084,5.832890014164741,7.577428828035749,5.807354922057604,6.247927513443585,6.523561956057013,6.392317422778761,6.700439718141092,5.906890595608519,4.954196310386875,6.658211482751795,4.169925001442312,6.20945336562895,6.189824558880018,6.189824558880018,8.276124405274238,8.005624549193879,7.1799090900149345,8.573647187493322,7.3750394313469245,7.357552004618084,7.636624620543649,8.243173983472952,2.807354922057604,3.0,1.0,5.087462841250339,0.0,1.0,4.392317422778761,2.584962500721156,2.0,2.321928094887362,2.584962500721156,2.584962500721156,0.0,2.0,1.0,3.0,null,null,null,null,null,null,null,null,6.523561956057013,5.754887502163468,5.672425341971495,6.882643049361842,4.954196310386875,5.807354922057604,5.491853096329675,6.022367813028454,null,null,null,null,null,null,null,null,6.845490050944375,5.78135971352466,5.357552004618084,6.6293566200796095,5.20945336562895,5.044394119358453,5.523561956057013,6.169925001442312,6.918863237274595,6.0,5.285402218862249,6.303780748177103,5.78135971352466,6.507794640198696,5.426264754702098,6.459431618637297,7.832890014164741,6.94251450533924,6.426264754702098,6.599912842187128,6.409390936137702,6.672425341971495,6.285402218862249,6.523561956057013,6.9886846867721655,6.523561956057013,5.754887502163468,6.087462841250339,5.392317422778761,5.906890595608519,5.459431618637297,6.491853096329675,6.727920454563199,6.129283016944966,5.727920454563199,6.149747119504682,5.672425341971495,5.357552004618084,5.584962500721156,6.20945336562895,7.0,5.754887502163468,4.700439718141092,5.044394119358453,5.614709844115208,5.584962500721156,4.459431618637297,6.22881869049588,6.754887502163468,5.727920454563199,5.321928094887363,6.491853096329675,5.832890014164741,5.754887502163468,5.129283016944966,6.044394119358453,7.554588851677638,6.9886846867721655,6.266786540694901,6.845490050944375,6.539158811108031,6.475733430966398,5.643856189774724,6.906890595608519,null,0.0,null,1.0,null,1.0,null,null,7.03342300153745,6.087462841250339,5.321928094887363,6.044394119358453,5.643856189774724,5.857980995127572,5.523561956057013,6.426264754702098,6.554588851677638,5.491853096329675,5.285402218862249,4.459431618637297,5.20945336562895,5.129283016944966,5.321928094887363,5.672425341971495,null,null,null,null,null,null,null,null,6.3750394313469245,5.392317422778761,5.285402218862249,4.906890595608519,5.392317422778761,5.672425341971495,4.392317422778761,5.930737337562887,7.199672344836364,6.857980995127572,6.022367813028454,6.22881869049588,6.169925001442312,6.0,6.022367813028454,6.426264754702098,7.451211111832329,6.870364719583405,5.930737337562887,6.807354922057604,6.169925001442312,6.554588851677638,5.906890595608519,6.832890014164741,8.060695931687555,7.6293566200796095,6.894817763307944,6.906890595608519,6.9886846867721655,7.199672344836364,6.459431618637297,7.330916878114617,6.78135971352466,6.303780748177103,5.523561956057013,5.727920454563199,5.954196310386875,6.066089190457772,5.169925001442312,6.554588851677638,3.807354922057604,3.584962500721156,3.169925001442312,2.584962500721156,3.321928094887362,4.459431618637297,2.584962500721156,3.584962500721156,7.546894459887636,7.483815777264256,6.554588851677638,7.066089190457772,6.965784284662087,6.794415866350106,5.882643049361842,7.426264754702098,5.906890595608519,5.321928094887363,4.0,5.392317422778761,4.807354922057604,4.906890595608519,4.857980995127572,4.807354922057604,null,0.0,null,null,null,null,null,null,6.409390936137702,5.426264754702098,4.857980995127572,5.832890014164741,4.857980995127572,5.523561956057013,5.247927513443585,5.700439718141092,6.977279923499917,6.78135971352466,6.20945336562895,6.475733430966398,6.266786540694901,5.614709844115208,5.700439718141092,6.339850002884624,5.954196310386875,4.906890595608519,3.584962500721156,5.426264754702098,4.523561956057013,4.643856189774724,5.20945336562895,4.584962500721156,6.599912842187128,5.700439718141092,5.882643049361842,6.044394119358453,5.357552004618084,5.523561956057013,5.321928094887363,6.357552004618084,7.515699838284043,6.894817763307944,6.285402218862249,6.507794640198696,6.149747119504682,6.285402218862249,5.672425341971495,7.159871336778389,null,null,null,null,null,null,null,null,8.820178962415188,8.897845456005511,7.294620748891627,9.324180546618742,7.139551352398794,8.569855608330949,8.558420713268664,6.894817763307944,6.9886846867721655,7.011227255423254,6.459431618637297,6.672425341971495,5.0,7.05528243550119,6.22881869049588,4.700439718141092,7.2384047393250786,8.422064766172813,5.727920454563199,8.134426320220927,6.409390936137702,7.754887502163468,6.672425341971495,6.189824558880018,6.820178962415188,6.894817763307944,5.20945336562895,7.400879436282184,4.857980995127572,6.794415866350106,5.169925001442312,4.392317422778761,6.507794640198696,7.851749041416057,5.169925001442312,8.876516946565,5.954196310386875,7.845490050944375,8.108524456778168,6.20945336562895,7.870364719583405,7.434628227636725,6.0,7.044394119358453,6.285402218862249,6.94251450533924,null,5.044394119358453,3.9068905956085187,4.523561956057013,null,null,6.266786540694901,4.954196310386875,null,2.584962500721156,6.727920454563199,6.754887502163468,5.129283016944966,7.826548487290915,4.247927513443585,6.977279923499917,6.149747119504682,5.0,null,null,null,1.584962500721156,null,0.0,0.0,1.0,5.672425341971495,6.768184324776926,2.807354922057604,6.491853096329675,4.523561956057013,6.426264754702098,6.303780748177103,4.700439718141092,6.066089190457772,7.451211111832329,4.906890595608519,6.087462841250339,6.022367813028454,7.022367813028454,6.584962500721156,5.78135971352466,7.754887502163468,7.554588851677638,6.392317422778761,8.426264754702098,5.491853096329675,7.442943495848728,0.0,5.426264754702098,7.584962500721156,8.370687406807217,5.807354922057604,7.994353436858858,6.741466986401147,8.224001674198105,7.807354922057604,6.022367813028454,8.285402218862249,9.129283016944967,7.066089190457772,8.778077129535358,7.6293566200796095,8.584962500721156,7.839203788096944,7.20945336562895,7.971543553950772,8.098032082960527,6.672425341971495,8.366322214245816,6.491853096329675,7.870364719583405,7.60733031374961,6.20945336562895,6.357552004618084,6.714245517666122,5.954196310386875,6.6865005271832185,4.906890595608519,5.754887502163468,5.754887502163468,4.857980995127572,6.392317422778761,7.1799090900149345,4.459431618637297,8.022367813028454,5.285402218862249,6.894817763307944,5.643856189774724,5.0,9.18239435340453,9.038918989292302,7.60733031374961,9.696967526234287,7.622051819456376,9.100662339005199,8.011227255423254,7.129283016944966,7.483815777264256,8.442943495848729,6.129283016944966,8.129283016944967,6.906890595608519,8.011227255423254,7.539158811108031,6.6293566200796095,5.643856189774724,6.794415866350106,3.700439718141092,6.6865005271832185,3.584962500721156,6.321928094887363,7.066089190457772,4.321928094887363,0.0,null,null,0.0,0.0,null,null,null,7.108524456778169,7.994353436858858,5.954196310386875,7.727920454563199,6.108524456778169,7.285402218862249,6.247927513443585,6.044394119358453,8.113742166049189,8.204571144249204,6.22881869049588,8.584962500721156,6.426264754702098,8.129283016944967,7.577428828035749,5.614709844115208,7.044394119358453,7.266786540694901,5.584962500721156,7.936637939002571,5.0,7.03342300153745,7.539158811108031,5.523561956057013,8.507794640198696,8.50382573799575,3.4594316186372973,5.523561956057013,3.9068905956085187,7.864186144654281,2.0,6.6293566200796095,7.044394119358453,7.400879436282184,5.129283016944966,7.7615512324444795,4.523561956057013,7.768184324776926,6.714245517666122,5.087462841250339,6.857980995127572,6.930737337562887,5.247927513443585,7.467605550082998,5.247927513443585,7.044394119358453,7.076815597050831,5.954196310386875,8.266786540694902,9.4655664048094,7.199672344836364,9.019590728357882,7.924812503605781,8.81698362325538,8.854868383260236,7.6293566200796095,7.285402218862249,8.066089190457772,5.491853096329675,8.312882955284355,6.285402218862249,8.022367813028454,8.45532722030456,5.954196310386875,7.622051819456376,7.475733430966398,5.977279923499917,8.539158811108031,5.832890014164741,7.507794640198696,6.6293566200796095,5.426264754702098,7.807354922057604,7.876516946564999,6.658211482751795,7.876516946564999,6.266786540694901,7.876516946564999,7.894817763307944,6.303780748177103,7.0,6.870364719583405,5.930737337562887,7.787902559391432,4.906890595608519,7.199672344836364,6.614709844115208,4.906890595608519,0.0,0.0,null,1.584962500721156,null,2.0,null,1.0,7.2384047393250786,7.247927513443585,5.672425341971495,7.459431618637297,5.247927513443585,7.0,0.0,4.169925001442312,6.339850002884624,7.658211482751795,4.700439718141092,8.154818109052105,4.954196310386875,7.658211482751795,6.906890595608519,5.584962500721156,6.820178962415188,6.523561956057013,5.523561956057013,7.483815777264256,4.523561956057013,6.882643049361842,6.6293566200796095,5.129283016944966,9.432541900388259,9.550746785383243,8.388017285345136,8.826548487290914,8.285402218862249,8.945443836377912,8.044394119358454,8.290018846932618,7.330916878114617,7.400879436282184,4.754887502163468,7.03342300153745,5.832890014164741,7.392317422778761,5.459431618637297,5.977279923499917,7.442943495848728,8.405141463136344,5.20945336562895,8.554588851677638,6.569855608330948,7.7073591320808825,7.451211111832329,6.599912842187128,8.888743248898258,8.527477006060396,7.2384047393250786,7.721099188707185,7.219168520462161,8.280770770130603,7.459431618637297,7.044394119358453,8.558420713268664,8.50382573799575,7.189824558880018,8.124121311829187,7.044394119358453,8.43879185257826,7.491853096329675,7.129283016944966,7.977279923499917,7.7073591320808825,6.169925001442312,8.044394119358454,6.129283016944966,7.807354922057604,6.491853096329675,5.754887502163468,2.0,8.67595703294175,1.584962500721156,7.614709844115208,7.285402218862249,8.108524456778168,7.312882955284356,6.930737337562887,6.491853096329675,6.807354922057604,5.087462841250339,7.247927513443585,4.459431618637297,6.768184324776926,1.584962500721156,4.321928094887363,null,null,0.0,0.0,null,null,0.0,2.0,7.118941072723508,8.252665432450248,5.807354922057604,8.149747119504681,6.3750394313469245,7.794415866350106,7.467605550082998,5.727920454563199,7.247927513443585,7.569855608330948,6.066089190457772,7.894817763307944,5.754887502163468,7.266786540694901,7.577428828035749,5.426264754702098,7.400879436282184,8.257387842692651,5.882643049361842,8.554588851677638,6.066089190457772,8.154818109052105,0.0,4.857980995127572,7.94251450533924,7.727920454563199,6.714245517666122,8.233619676759702,5.727920454563199,8.098032082960527,3.169925001442312,5.0,4.584962500721156,5.584962500721156,3.169925001442312,6.129283016944966,3.584962500721156,6.044394119358453,5.459431618637297,4.0,8.851749041416058,8.63662462054365,7.417852514885898,8.29920801838728,7.219168520462161,8.344295907915816,6.266786540694901,7.348728154231077,7.546894459887636,8.08214904135387,6.247927513443585,8.451211111832329,6.169925001442312,7.768184324776926,6.357552004618084,5.614709844115208,6.741466986401147,6.727920454563199,5.087462841250339,7.651051691178929,4.906890595608519,7.098032082960526,6.22881869049588,5.247927513443585,8.219168520462162,8.071462362556623,6.6293566200796095,8.339850002884624,6.599912842187128,8.139551352398794,null,5.392317422778761,6.643856189774724,8.022367813028454,4.906890595608519,8.81698362325538,6.087462841250339,7.523561956057013,8.0,6.22881869049588,6.523561956057013,6.599912842187128,5.20945336562895,7.383704292474052,3.321928094887362,7.129283016944966,4.169925001442312,4.0,0.0,null,null,null,null,1.0,1.584962500721156,null,8.335390354693924,8.430452551665532,6.807354922057604,8.839203788096944,6.409390936137702,8.527477006060396,3.0,5.754887502163468,6.189824558880018,7.3750394313469245,4.754887502163468,7.965784284662087,5.754887502163468,7.507794640198696,7.7615512324444795,4.954196310386875,6.491853096329675,7.768184324776926,4.857980995127572,7.948367231584678,5.807354922057604,7.584962500721156,7.936637939002571,5.169925001442312,8.0,8.915879378835774,6.714245517666122,8.930737337562887,7.339850002884624,8.67595703294175,8.144658242831882,6.614709844115208,8.442943495848729,8.308339030139408,6.6293566200796095,8.519636252843213,6.569855608330948,7.7073591320808825,7.417852514885898,6.22881869049588,9.850186837645774,9.479780264029099,8.108524456778168,8.933690654952233,8.144658242831882,8.813781191217037,7.876516946564999,7.6653359171851765,7.700439718141092,7.491853096329675,5.643856189774724,7.599912842187128,5.129283016944966,7.169925001442312,6.169925001442312,5.087462841250339,1.584962500721156,2.321928094887362,0.0,4.0,0.0,1.0,2.0,2.0,9.228818690495881,9.057991722759176,7.592457037268081,8.507794640198696,7.679480099505446,8.651051691178928,2.0,6.20945336562895,6.643856189774724,6.754887502163468,5.087462841250339,7.409390936137702,4.523561956057013,6.857980995127572,6.507794640198696,4.459431618637297,7.700439718141092,7.6293566200796095,6.3750394313469245,8.247927513443585,5.700439718141092,6.768184324776926,8.044394119358454,5.672425341971495,null,0.0,null,0.0,0.0,1.0,0.0,null,6.189824558880018,6.266786540694901,4.807354922057604,6.584962500721156,4.754887502163468,6.129283016944966,3.700439718141092,3.807354922057604,8.113742166049189,7.977279923499917,6.066089190457772,7.129283016944966,6.266786540694901,7.562242424221073,6.066089190457772,5.857980995127572,7.523561956057013,7.467605550082998,6.022367813028454,6.845490050944375,6.247927513443585,6.820178962415188,6.266786540694901,5.857980995127572,9.832890014164741,9.571752643503546,8.546894459887637,8.430452551665532,8.405141463136344,8.912889336229961,7.022367813028454,7.2761244052742375,9.285402218862249,9.12670447284319,8.005624549193879,8.50382573799575,7.882643049361842,8.562242424221072,7.851749041416057,7.129283016944966,9.810571634741146,9.459431618637296,8.049848549450562,8.149747119504681,8.467605550082997,9.098032082960527,7.6653359171851765,7.451211111832329,8.672425341971495,8.507794640198696,7.199672344836364,7.924812503605781,6.965784284662087,8.049848549450562,7.400879436282184,6.491853096329675,7.9886846867721655,8.651051691178928,5.857980995127572,8.060695931687555,7.426264754702098,8.199672344836364,7.219168520462161,7.087462841250339,7.614709844115208,8.049848549450562,6.108524456778169,8.08214904135387,7.05528243550119,7.562242424221073,6.918863237274595,5.426264754702098,8.257387842692651,8.087462841250339,6.9886846867721655,7.754887502163468,6.882643049361842,7.577428828035749,6.523561956057013,5.906890595608519,7.426264754702098,7.383704292474052,6.0,6.6865005271832185,5.727920454563199,6.584962500721156,6.768184324776926,4.954196310386875,null,null,null,null,null,1.0,null,null,6.523561956057013,7.400879436282184,4.906890595608519,5.930737337562887,6.108524456778169,7.417852514885898,1.0,4.523561956057013,8.066089190457772,8.087462841250339,6.894817763307944,7.679480099505446,6.20945336562895,7.7615512324444795,6.9886846867721655,5.727920454563199,6.930737337562887,6.741466986401147,5.700439718141092,5.247927513443585,4.857980995127572,6.247927513443585,5.20945336562895,4.523561956057013,10.049848549450562,9.792790294301064,8.640244936222345,8.957102041562287,8.731319031025064,9.50382573799575,7.219168520462161,7.954196310386875,7.754887502163468,7.330916878114617,5.882643049361842,6.539158811108031,5.78135971352466,6.94251450533924,5.584962500721156,4.643856189774724,9.079484783826816,8.991521846075695,7.820178962415188,8.73809225962049,7.392317422778761,8.703903573444663,6.9886846867721655,6.930737337562887,8.820178962415188,8.447083226209653,7.098032082960526,7.434628227636725,7.189824558880018,8.108524456778168,1.584962500721156,5.392317422778761,7.577428828035749,8.539158811108031,6.108524456778169,7.768184324776926,7.3750394313469245,8.129283016944967,7.118941072723508,6.807354922057604,2.807354922057604,1.584962500721156,0.0,1.584962500721156,0.0,null,1.0,2.584962500721156,8.308339030139408,7.807354922057604,6.491853096329675,7.011227255423254,6.266786540694901,7.257387842692652,7.139551352398794,5.807354922057604,5.832890014164741,6.832890014164741,4.954196310386875,6.087462841250339,5.584962500721156,5.906890595608519,5.247927513443585,5.426264754702098,null,1.0,null,null,null,null,null,0.0,6.643856189774724,7.348728154231077,5.20945336562895,7.022367813028454,6.022367813028454,7.383704292474052,5.554588851677638,4.321928094887363,6.857980995127572,8.124121311829187,5.882643049361842,7.6653359171851765,6.6865005271832185,7.6653359171851765,null,4.700439718141092,5.247927513443585,5.857980995127572,4.247927513443585,4.584962500721156,4.321928094887363,4.906890595608519,null,3.807354922057604,0.0,8.108524456778168,0.0,8.422064766172813,6.22881869049588,8.271463027904375,6.714245517666122,6.285402218862249,8.312882955284355,7.930737337562887,7.03342300153745,7.94251450533924,6.149747119504682,7.794415866350106,6.044394119358453,5.672425341971495,7.700439718141092,7.467605550082998,6.044394119358453,7.285402218862249,5.614709844115208,7.6653359171851765,6.820178962415188,5.426264754702098,7.149747119504682,7.011227255423254,5.643856189774724,7.159871336778389,5.426264754702098,6.882643049361842,7.22881869049588,4.700439718141092,8.344295907915816,7.7481928495894605,6.459431618637297,8.60733031374961,5.614709844115208,8.027905996569885,7.098032082960526,6.087462841250339,7.118941072723508,8.0,5.614709844115208,7.303780748177103,7.149747119504682,7.417852514885898,6.965784284662087,6.022367813028454,6.108524456778169,6.894817763307944,0.0,1.584962500721156,8.011227255423254,6.658211482751795,2.321928094887362,5.754887502163468,8.873444112515376,8.535275376620802,7.098032082960526,8.92481250360578,6.845490050944375,8.271463027904375,8.751544059089099,6.392317422778761,8.933690654952233,8.784634845557521,7.832890014164741,8.0,7.912889336229962,8.219168520462162,7.7615512324444795,6.672425341971495,6.870364719583405,7.7481928495894605,5.321928094887363,8.08214904135387,5.584962500721156,7.499845887083206,7.451211111832329,5.554588851677638,9.259743263690781,8.968666793195208,7.954196310386875,7.820178962415188,7.851749041416057,8.507794640198696,6.409390936137702,6.584962500721156,8.665335917185176,8.124121311829187,6.894817763307944,8.611024797307353,6.643856189774724,7.9886846867721655,0.0,5.832890014164741,6.9886846867721655,7.807354922057604,5.459431618637297,8.189824558880018,5.882643049361842,7.584962500721156,7.924812503605781,6.339850002884624,7.658211482751795,8.50382573799575,5.882643049361842,8.124121311829187,6.954196310386875,7.857980995127572,6.845490050944375,6.491853096329675,6.3750394313469245,7.294620748891627,4.954196310386875,7.294620748891627,5.672425341971495,7.266786540694901,6.087462841250339,4.906890595608519,7.614709844115208,8.417852514885897,6.672425341971495,7.936637939002571,6.523561956057013,8.204571144249204,7.599912842187128,5.906890595608519,8.906890595608518,8.471675214392045,7.303780748177103,8.88264304936184,7.022367813028454,8.539158811108031,6.409390936137702,6.930737337562887,9.162391328756906,8.539158811108031,7.366322214245816,8.758223214726724,7.199672344836364,8.113742166049189,6.727920454563199,6.321928094887363,7.515699838284043,8.475733430966399,6.22881869049588,7.592457037268081,7.05528243550119,7.888743248898259,6.22881869049588,6.442943495848728,7.392317422778761,8.092757140919852,5.554588851677638,7.643856189774724,6.658211482751795,8.03342300153745,null,6.149747119504682,9.276124405274238,9.057991722759176,7.6293566200796095,9.011227255423254,7.658211482751795,8.257387842692651,7.257387842692652,7.098032082960526,9.014020470314934,8.682994583681683,7.2761244052742375,8.562242424221072,6.832890014164741,8.409390936137703,8.076815597050832,6.794415866350106,8.7714894695006,8.071462362556623,6.9886846867721655,8.022367813028454,6.584962500721156,8.060695931687555,6.321928094887363,6.266786540694901,9.164906926675688,8.851749041416058,7.2384047393250786,9.285402218862249,7.0,9.022367813028454,8.357552004618084,7.189824558880018,6.426264754702098,7.768184324776926,3.0,2.0,2.584962500721156,7.2384047393250786,null,4.906890595608519,8.51175265376738,8.098032082960527,6.977279923499917,8.79766152585376,5.930737337562887,8.447083226209653,2.807354922057604,5.807354922057604,7.491853096329675,7.312882955284356,5.78135971352466,7.714245517666122,5.392317422778761,7.20945336562895,6.087462841250339,4.807354922057604,6.727920454563199,7.577428828035749,4.754887502163468,8.134426320220927,6.22881869049588,7.554588851677638,6.599912842187128,6.044394119358453,9.111135670234708,8.707359132080883,7.7073591320808825,8.96289600533726,7.2384047393250786,8.50382573799575,7.507794640198696,6.754887502163468,9.632995197142957,9.022367813028454,8.262094845370179,9.187352073200497,7.94251450533924,9.068778277985412,7.330916878114617,7.339850002884624,7.714245517666122,8.276124405274238,5.754887502163468,8.379378367071261,7.189824558880018,7.954196310386875,7.475733430966398,6.882643049361842,8.326429487122303,8.654636028527968,6.3750394313469245,9.044394119358454,7.3750394313469245,8.535275376620802,7.451211111832329,6.754887502163468,8.344295907915816,8.918863237274595,6.3750394313469245,9.321928094887362,6.965784284662087,8.531381460516313,4.247927513443585,6.129283016944966,8.826548487290914,9.3151495622563,7.285402218862249,8.721099188707186,8.290018846932618,8.936637939002571,8.507794640198696,7.768184324776926,7.864186144654281,8.679480099505446,6.491853096329675,8.49585502688717,6.918863237274595,8.204571144249204,7.169925001442312,6.807354922057604,7.139551352398794,8.005624549193879,5.614709844115208,8.294620748891626,6.78135971352466,8.29920801838728,7.78135971352466,6.321928094887363,6.794415866350106,6.727920454563199,4.954196310386875,7.219168520462161,4.392317422778761,6.965784284662087,5.906890595608519,4.087462841250339,7.159871336778389,6.3750394313469245,5.169925001442312,7.087462841250339,4.857980995127572,7.098032082960526,5.857980995127572,4.392317422778761,6.857980995127572,6.672425341971495,5.491853096329675,7.459431618637297,4.906890595608519,7.2761244052742375,6.339850002884624,4.247927513443585,7.357552004618084,7.2761244052742375,5.906890595608519,6.643856189774724,5.584962500721156,6.523561956057013,6.507794640198696,4.807354922057604,8.139551352398794,8.290018846932618,6.965784284662087,8.491853096329674,6.870364719583405,7.78135971352466,7.426264754702098,6.584962500721156,8.422064766172813,8.214319120800766,6.599912842187128,8.303780748177102,6.882643049361842,8.308339030139408,7.044394119358453,5.523561956057013,8.665335917185176,8.51175265376738,7.087462841250339,8.912889336229961,6.700439718141092,8.049848549450562,7.539158811108031,6.554588851677638,8.219168520462162,8.885696373339394,6.6293566200796095,8.672425341971495,7.434628227636725,8.479780264029099,4.584962500721156,6.965784284662087,6.714245517666122,7.658211482751795,4.700439718141092,7.6293566200796095,6.066089190457772,7.6865005271832185,6.392317422778761,5.087462841250339,7.936637939002571,7.577428828035749,6.022367813028454,8.169925001442312,5.882643049361842,7.507794640198696,6.0,5.426264754702098,8.214319120800766,8.055282435501189,6.794415866350106,8.479780264029099,6.6293566200796095,7.870364719583405,6.303780748177103,6.044394119358453,7.475733430966398,8.562242424221072,6.189824558880018,8.857980995127573,6.22881869049588,8.848622940429339,7.294620748891627,7.499845887083206,6.491853096329675,7.636624620543649,4.954196310386875,7.459431618637297,5.247927513443585,7.794415866350106,1.0,4.807354922057604,7.189824558880018,6.977279923499917,5.523561956057013,7.78135971352466,5.614709844115208,7.312882955284356,5.459431618637297,5.20945336562895,8.144658242831882,8.087462841250339,6.599912842187128,8.632995197142957,5.977279923499917,8.366322214245816,null,6.087462841250339,5.882643049361842,7.139551352398794,5.0,7.714245517666122,5.523561956057013,7.539158811108031,6.087462841250339,4.906890595608519,7.562242424221073,7.149747119504682,6.3750394313469245,8.139551352398794,5.459431618637297,7.339850002884624,7.491853096329675,5.523561956057013,7.011227255423254,7.918863237274595,5.643856189774724,7.857980995127572,5.977279923499917,7.741466986401147,7.330916878114617,5.554588851677638,8.813781191217037,8.714245517666123,7.118941072723508,9.294620748891626,6.599912842187128,9.011227255423254,7.918863237274595,6.554588851677638,7.400879436282184,8.554588851677638,6.321928094887363,8.83605035505807,6.022367813028454,8.434628227636725,7.169925001442312,6.247927513443585,8.49585502688717,9.194756854422248,6.614709844115208,8.900866807980748,7.546894459887636,8.89178370321831,8.906890595608518,7.330916878114617,7.60733031374961,8.353146825498083,5.78135971352466,8.238404739325079,6.700439718141092,8.049848549450562,6.845490050944375,6.426264754702098,8.294620748891626,8.199672344836364,6.977279923499917,8.939579214314692,6.491853096329675,8.422064766172813,7.339850002884624,6.599912842187128,7.442943495848728,8.103287808412022,5.614709844115208,8.422064766172813,6.108524456778169,8.118941072723507,8.46352437327118,6.266786540694901,7.813781191217037,8.20945336562895,6.930737337562887,8.413627929024173,6.149747119504682,7.491853096329675,7.78135971352466,6.426264754702098,6.442943495848728,6.20945336562895,4.643856189774724,6.22881869049588,4.169925001442312,6.357552004618084,5.807354922057604,3.584962500721156,7.357552004618084,7.05528243550119,5.643856189774724,7.714245517666122,4.584962500721156,7.312882955284356,6.303780748177103,3.0,7.459431618637297,8.312882955284355,6.066089190457772,7.507794640198696,6.977279923499917,8.262094845370179,7.936637939002571,6.954196310386875,4.807354922057604,4.857980995127572,2.807354922057604,5.614709844115208,1.0,4.954196310386875,3.0,2.584962500721156,8.754887502163468,8.326429487122303,6.794415866350106,8.927777962082342,6.303780748177103,8.459431618637296,7.266786540694901,6.087462841250339,7.066089190457772,6.882643049361842,5.169925001442312,7.768184324776926,4.643856189774724,7.475733430966398,4.584962500721156,5.285402218862249,8.055282435501189,7.832890014164741,6.426264754702098,8.118941072723507,6.149747119504682,7.614709844115208,6.339850002884624,6.087462841250339,7.20945336562895,7.864186144654281,5.584962500721156,7.0,7.108524456778169,7.417852514885898,4.906890595608519,6.129283016944966,6.78135971352466,7.7073591320808825,5.459431618637297,6.768184324776926,6.266786540694901,7.383704292474052,6.584962500721156,5.643856189774724,7.400879436282184,8.134426320220927,6.066089190457772,7.451211111832329,6.614709844115208,7.9886846867721655,1.584962500721156,5.459431618637297,7.285402218862249,8.266786540694902,6.022367813028454,7.475733430966398,7.098032082960526,7.754887502163468,6.906890595608519,5.906890595608519,7.108524456778169,7.900866807980749,5.977279923499917,6.768184324776926,6.569855608330948,7.247927513443585,6.3750394313469245,6.129283016944966,6.832890014164741,7.894817763307944,5.169925001442312,6.820178962415188,6.189824558880018,7.199672344836364,6.727920454563199,5.554588851677638,5.20945336562895,5.882643049361842,2.807354922057604,3.584962500721156,5.523561956057013,5.285402218862249,3.807354922057604,3.584962500721156,6.554588851677638,7.330916878114617,4.321928094887363,6.247927513443585,5.727920454563199,7.022367813028454,6.392317422778761,5.882643049361842,7.948367231584678,7.539158811108031,6.129283016944966,6.614709844115208,6.6865005271832185,7.03342300153745,5.554588851677638,5.954196310386875,8.022367813028454,7.787902559391432,6.727920454563199,6.614709844115208,6.507794640198696,7.348728154231077,5.491853096329675,6.129283016944966,9.189824558880018,8.800899899920305,7.599912842187128,8.027905996569885,7.672425341971495,8.625708843064466,6.442943495848728,6.754887502163468,7.727920454563199,7.599912842187128,6.149747119504682,6.965784284662087,6.392317422778761,7.2761244052742375,4.321928094887363,5.169925001442312,8.129283016944967,7.257387842692652,6.189824558880018,7.129283016944966,6.409390936137702,7.584962500721156,7.199672344836364,5.321928094887363,8.804131021183318,8.562242424221072,7.066089190457772,8.08214904135387,7.285402218862249,8.276124405274238,6.285402218862249,6.0,7.339850002884624,8.154818109052105,5.584962500721156,7.159871336778389,7.044394119358453,7.948367231584678,7.392317422778761,6.539158811108031,7.912889336229962,8.434628227636725,6.339850002884624,7.622051819456376,7.098032082960526,7.813781191217037,null,5.977279923499917,7.149747119504682,7.651051691178929,5.20945336562895,6.714245517666122,6.754887502163468,7.219168520462161,2.321928094887362,5.491853096329675,7.948367231584678,7.189824558880018,5.523561956057013,6.94251450533924,5.882643049361842,6.906890595608519,0.0,4.807354922057604,7.6293566200796095,7.22881869049588,5.857980995127572,6.475733430966398,6.285402218862249,6.700439718141092,5.930737337562887,5.285402218862249,7.366322214245816,6.584962500721156,5.727920454563199,6.169925001442312,5.523561956057013,6.426264754702098,4.392317422778761,4.700439718141092,6.727920454563199,7.409390936137702,5.491853096329675,6.189824558880018,5.977279923499917,7.392317422778761,5.087462841250339,4.807354922057604,3.807354922057604,3.584962500721156,null,2.584962500721156,1.584962500721156,3.4594316186372973,3.0,null,8.204571144249204,8.011227255423254,6.442943495848728,6.768184324776926,6.894817763307944,7.754887502163468,6.820178962415188,6.303780748177103,5.906890595608519,6.614709844115208,3.321928094887362,5.700439718141092,5.459431618637297,6.339850002884624,5.857980995127572,4.169925001442312,8.467605550082997,7.918863237274595,6.507794640198696,8.118941072723507,7.0,7.60733031374961,6.491853096329675,6.149747119504682,8.055282435501189,7.794415866350106,6.303780748177103,6.977279923499917,6.754887502163468,7.499845887083206,6.658211482751795,5.977279923499917,8.055282435501189,8.011227255423254,6.044394119358453,7.734709620225838,7.392317422778761,8.076815597050832,1.0,5.906890595608519,0.0,null,null,null,null,null,null,null,6.442943495848728,7.149747119504682,4.247927513443585,8.076815597050832,5.20945336562895,7.546894459887636,1.0,4.700439718141092,6.189824558880018,7.0,4.857980995127572,6.870364719583405,4.643856189774724,6.754887502163468,5.087462841250339,4.523561956057013,6.066089190457772,6.727920454563199,4.392317422778761,7.392317422778761,5.169925001442312,7.392317422778761,6.22881869049588,4.584962500721156,8.098032082960527,7.807354922057604,6.459431618637297,8.199672344836364,6.22881869049588,7.930737337562887,6.894817763307944,5.321928094887363,6.584962500721156,6.339850002884624,4.754887502163468,7.554588851677638,4.087462841250339,6.977279923499917,7.285402218862249,3.584962500721156,8.219168520462162,7.7481928495894605,6.3750394313469245,6.94251450533924,6.584962500721156,7.2761244052742375,5.700439718141092,5.906890595608519,4.954196310386875,4.459431618637297,null,0.0,5.700439718141092,5.247927513443585,null,2.584962500721156,6.727920454563199,7.60733031374961,4.700439718141092,8.169925001442312,5.044394119358453,8.118941072723507,7.960001932068081,5.321928094887363,7.491853096329675,8.184875342908283,6.266786540694901,7.734709620225838,7.499845887083206,7.888743248898259,7.011227255423254,6.321928094887363,8.005624549193879,7.614709844115208,6.3750394313469245,8.189824558880018,5.700439718141092,7.754887502163468,5.954196310386875,5.857980995127572,7.569855608330948,7.515699838284043,6.285402218862249,6.870364719583405,6.169925001442312,7.321928094887363,6.614709844115208,5.643856189774724,7.918863237274595,7.285402218862249,6.0,7.554588851677638,6.0,7.348728154231077,7.357552004618084,6.044394119358453,6.754887502163468,7.2761244052742375,6.044394119358453,7.546894459887636,5.554588851677638,7.321928094887363,6.169925001442312,5.087462841250339,7.569855608330948,7.199672344836364,5.491853096329675,7.599912842187128,6.044394119358453,7.409390936137702,7.599912842187128,6.169925001442312,7.839203788096944,7.714245517666122,6.409390936137702,8.321928094887362,5.584962500721156,7.954196310386875,7.294620748891627,4.857980995127572,6.894817763307944,7.383704292474052,5.0,8.060695931687555,5.954196310386875,7.6293566200796095,6.0,5.78135971352466,5.754887502163468,6.754887502163468,4.0,6.78135971352466,4.523561956057013,7.03342300153745,6.857980995127572,4.247927513443585,8.179909090014934,7.787902559391432,6.459431618637297,8.727920454563199,5.930737337562887,7.888743248898259,6.930737337562887,6.129283016944966,7.483815777264256,8.016808287686555,3.169925001442312,5.087462841250339,3.584962500721156,7.592457037268081,null,6.066089190457772,9.243173983472952,8.88264304936184,7.523561956057013,8.430452551665532,7.1799090900149345,8.90388184573618,7.366322214245816,7.098032082960526,7.971543553950772,7.515699838284043,6.507794640198696,8.0,6.129283016944966,7.539158811108031,5.672425341971495,5.754887502163468,6.870364719583405,7.539158811108031,5.129283016944966,7.584962500721156,6.392317422778761,7.294620748891627,5.754887502163468,5.700439718141092,7.0,6.965784284662087,4.906890595608519,7.876516946564999,5.0,7.159871336778389,6.9886846867721655,5.392317422778761,7.562242424221073,7.266786540694901,6.149747119504682,7.870364719583405,5.523561956057013,7.3750394313469245,6.965784284662087,5.857980995127572,7.266786540694901,7.807354922057604,5.554588851677638,8.124121311829187,6.339850002884624,7.820178962415188,4.584962500721156,4.857980995127572,6.108524456778169,6.714245517666122,4.0,6.754887502163468,4.807354922057604,7.087462841250339,5.614709844115208,5.169925001442312,7.129283016944966,6.9886846867721655,5.0,7.622051819456376,4.807354922057604,7.03342300153745,5.554588851677638,4.459431618637297,8.076815597050832,7.734709620225838,6.475733430966398,7.451211111832329,5.930737337562887,7.787902559391432,7.03342300153745,5.954196310386875,7.584962500721156,7.312882955284356,6.149747119504682,7.467605550082998,5.672425341971495,7.584962500721156,6.78135971352466,5.426264754702098,7.499845887083206,7.129283016944966,5.700439718141092,8.044394119358454,5.285402218862249,7.392317422778761,6.285402218862249,5.247927513443585,8.330916878114618,7.832890014164741,6.807354922057604,7.515699838284043,6.643856189774724,7.832890014164741,null,5.672425341971495,6.930737337562887,6.6865005271832185,5.169925001442312,6.870364719583405,4.954196310386875,6.491853096329675,5.491853096329675,4.584962500721156,7.912889336229962,7.409390936137702,6.409390936137702,7.383704292474052,6.20945336562895,6.807354922057604,6.977279923499917,6.022367813028454,7.303780748177103,8.266786540694902,5.554588851677638,8.370687406807217,6.768184324776926,8.022367813028454,7.303780748177103,6.426264754702098,7.965784284662087,7.721099188707185,5.977279923499917,8.483815777264256,5.672425341971495,7.894817763307944,6.700439718141092,4.954196310386875,5.882643049361842,6.6865005271832185,4.459431618637297,7.129283016944966,5.523561956057013,7.383704292474052,5.754887502163468,4.906890595608519,6.954196310386875,7.6293566200796095,5.129283016944966,8.144658242831882,5.643856189774724,7.426264754702098,6.321928094887363,5.20945336562895,7.442943495848728,7.139551352398794,5.807354922057604,6.894817763307944,5.584962500721156,6.894817763307944,7.257387842692652,5.321928094887363,6.108524456778169,6.870364719583405,4.523561956057013,7.658211482751795,4.584962500721156,6.9886846867721655,7.330916878114617,4.807354922057604,7.693486957499325,7.294620748891627,5.700439718141092,8.228818690495881,5.523561956057013,7.954196310386875,6.426264754702098,5.321928094887363,7.820178962415188,7.523561956057013,6.303780748177103,8.276124405274238,5.807354922057604,7.417852514885898,6.857980995127572,5.672425341971495,7.622051819456376,7.366322214245816,6.0,7.894817763307944,5.491853096329675,7.3750394313469245,7.044394119358453,5.129283016944966,7.523561956057013,7.459431618637297,5.614709844115208,8.044394119358454,5.357552004618084,7.741466986401147,0.0,4.906890595608519,7.348728154231077,8.134426320220927,5.459431618637297,8.113742166049189,5.930737337562887,8.118941072723507,6.266786540694901,5.754887502163468,6.491853096329675,7.098032082960526,4.643856189774724,7.294620748891627,5.087462841250339,7.011227255423254,6.6293566200796095,4.857980995127572,7.622051819456376,7.285402218862249,6.339850002884624,7.768184324776926,5.554588851677638,7.442943495848728,6.9886846867721655,5.882643049361842,null,6.303780748177103,null,6.554588851677638,5.169925001442312,6.266786540694901,5.129283016944966,4.584962500721156,7.499845887083206,6.569855608330948,5.700439718141092,7.434628227636725,5.129283016944966,6.741466986401147,4.169925001442312,4.392317422778761,null,7.894817763307944,null,7.577428828035749,6.20945336562895,7.870364719583405,6.599912842187128,5.906890595608519,2.584962500721156,3.169925001442312,1.584962500721156,2.0,0.0,1.584962500721156,2.0,1.0,6.832890014164741,7.7481928495894605,5.491853096329675,8.076815597050832,6.108524456778169,7.294620748891627,7.044394119358453,5.672425341971495,6.108524456778169,6.303780748177103,4.584962500721156,6.977279923499917,3.700439718141092,5.727920454563199,5.459431618637297,4.0,6.768184324776926,6.672425341971495,5.523561956057013,7.3750394313469245,5.321928094887363,6.832890014164741,5.584962500721156,4.321928094887363,7.426264754702098,7.741466986401147,5.357552004618084,6.870364719583405,6.554588851677638,7.149747119504682,5.930737337562887,5.882643049361842,7.417852514885898,7.78135971352466,5.459431618637297,7.303780748177103,6.894817763307944,7.20945336562895,5.129283016944966,6.066089190457772,7.845490050944375,7.339850002884624,6.285402218862249,7.285402218862249,6.339850002884624,7.05528243550119,5.392317422778761,5.459431618637297,7.434628227636725,7.076815597050831,5.169925001442312,5.247927513443585,6.22881869049588,6.491853096329675,4.169925001442312,4.584962500721156,6.977279923499917,7.693486957499325,5.20945336562895,7.011227255423254,6.714245517666122,7.451211111832329,2.0,5.672425341971495,6.614709844115208,7.108524456778169,4.700439718141092,6.392317422778761,6.149747119504682,6.714245517666122,6.0,5.906890595608519,7.303780748177103,6.857980995127572,6.087462841250339,6.357552004618084,5.857980995127572,6.794415866350106,4.584962500721156,4.807354922057604,5.129283016944966,6.22881869049588,3.584962500721156,5.614709844115208,5.087462841250339,6.066089190457772,4.523561956057013,3.700439718141092,5.78135971352466,6.658211482751795,4.321928094887363,5.727920454563199,5.643856189774724,6.339850002884624,4.169925001442312,4.392317422778761,7.483815777264256,6.599912842187128,5.523561956057013,6.807354922057604,5.700439718141092,6.6865005271832185,4.906890595608519,4.954196310386875,6.599912842187128,6.523561956057013,5.169925001442312,5.906890595608519,5.491853096329675,5.754887502163468,5.523561956057013,5.129283016944966,6.94251450533924,7.539158811108031,5.392317422778761,6.584962500721156,6.6865005271832185,7.330916878114617,6.0,6.658211482751795,6.977279923499917,6.303780748177103,5.247927513443585,6.507794640198696,5.584962500721156,6.554588851677638,4.459431618637297,4.954196310386875,7.800899899920305,6.845490050944375,5.754887502163468,6.794415866350106,5.357552004618084,6.658211482751795,4.247927513443585,4.954196310386875,6.882643049361842,7.523561956057013,5.20945336562895,6.339850002884624,6.491853096329675,7.475733430966398,4.906890595608519,5.392317422778761,2.584962500721156,2.584962500721156,2.321928094887362,1.584962500721156,1.0,1.584962500721156,null,2.0,5.954196310386875,6.832890014164741,4.857980995127572,6.066089190457772,5.832890014164741,6.727920454563199,4.643856189774724,5.0,6.599912842187128,7.076815597050831,4.643856189774724,6.169925001442312,5.906890595608519,7.139551352398794,4.954196310386875,4.906890595608519,5.614709844115208,6.6293566200796095,3.9068905956085187,5.0,5.129283016944966,5.754887502163468,5.754887502163468,4.700439718141092],\"y0\":\" \",\"yaxis\":\"y\",\"type\":\"box\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"],[\"X\",\"Cyp9k1_tag1\"],[\"X\",\"Cyp9k1_tag2\"],[\"X\",\"Cyp9k1_tag3\"],[\"X\",\"AIM25\"],[\"X\",\"AIM26\"],[\"X\",\"AIM27\"],[\"X\",\"AIM28\"],[\"X\",\"AIM29\"],[\"X\",\"AIM30\"],[\"X\",\"AIM31\"],[\"X\",\"AIM32\"],[\"X\",\"AIM33\"],[\"X\",\"AIM34\"],[\"X\",\"AIM35\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003eamplicon=%{x}\\u003cbr\\u003elog_depth=%{y}\\u003cbr\\u003emutation=%{customdata[1]}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"X\",\"marker\":{\"color\":\"#9467BD\"},\"name\":\"X\",\"notched\":false,\"offsetgroup\":\"X\",\"orientation\":\"v\",\"showlegend\":true,\"x\":[\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\"],\"x0\":\" \",\"xaxis\":\"x\",\"y\":[null,7.894817763307944,2.584962500721156,6.22881869049588,5.700439718141092,3.584962500721156,5.169925001442312,4.954196310386875,6.965784284662087,3.0,7.108524456778169,4.321928094887363,4.459431618637297,5.78135971352466,null,4.700439718141092,1.584962500721156,2.0,2.321928094887362,1.0,1.0,2.807354922057604,3.4594316186372973,0.0,3.321928094887362,3.0,0.0,4.0,null,null,null,0.0,null,null,null,null,null,null,0.0,null,1.0,null,null,2.807354922057604,0.0,1.0,null,1.0,0.0,1.0,3.169925001442312,1.0,3.0,null,2.321928094887362,null,null,4.584962500721156,null,2.321928094887362,1.584962500721156,2.0,1.0,1.584962500721156,3.321928094887362,0.0,3.807354922057604,1.0,1.584962500721156,0.0,null,6.189824558880018,3.321928094887362,5.044394119358453,3.169925001442312,3.0,3.584962500721156,4.643856189774724,4.321928094887363,3.584962500721156,1.584962500721156,3.0,1.584962500721156,4.906890595608519,null,4.321928094887363,null,1.0,null,3.0,null,3.807354922057604,null,1.0,null,null,1.0,null,null,null,null,1.0,null,null,null,null,null,null,0.0,0.0,1.584962500721156,0.0,null,null,null,null,0.0,null,null,null,null,null,0.0,null,1.0,null,null,5.0,2.0,3.0,2.321928094887362,null,1.584962500721156,1.584962500721156,4.321928094887363,2.0,2.584962500721156,1.0,1.0,1.0,null,2.807354922057604,1.0,1.584962500721156,1.0,2.0,2.807354922057604,1.0,null,2.0,2.0,2.584962500721156,2.807354922057604,2.584962500721156,null,0.0,null,1.0,0.0,0.0,1.0,0.0,null,null,null,1.0,2.321928094887362,null,null,5.882643049361842,4.392317422778761,3.584962500721156,3.807354922057604,3.169925001442312,3.9068905956085187,3.4594316186372973,4.807354922057604,1.584962500721156,4.754887502163468,3.584962500721156,3.4594316186372973,4.087462841250339,null,5.954196310386875,2.807354922057604,4.807354922057604,3.4594316186372973,3.0,3.584962500721156,4.169925001442312,4.700439718141092,2.584962500721156,4.700439718141092,3.0,2.0,4.087462841250339,null,3.321928094887362,null,2.0,2.321928094887362,0.0,2.0,2.584962500721156,2.321928094887362,0.0,3.169925001442312,1.584962500721156,2.807354922057604,2.321928094887362,null,4.0,2.321928094887362,3.0,2.584962500721156,0.0,2.0,2.807354922057604,4.459431618637297,2.321928094887362,3.807354922057604,1.0,2.0,3.4594316186372973,0.0,5.129283016944966,1.584962500721156,1.584962500721156,2.0,2.807354922057604,1.0,2.0,3.0,0.0,3.584962500721156,2.0,2.584962500721156,3.0,null,3.169925001442312,0.0,3.321928094887362,1.584962500721156,2.321928094887362,0.0,2.584962500721156,1.584962500721156,1.0,1.0,2.584962500721156,2.0,1.584962500721156,null,6.954196310386875,3.807354922057604,5.044394119358453,4.247927513443585,3.169925001442312,4.0,4.087462841250339,5.321928094887363,4.392317422778761,5.321928094887363,4.169925001442312,2.321928094887362,5.0,null,2.321928094887362,null,2.807354922057604,1.584962500721156,null,1.0,1.584962500721156,0.0,1.0,2.584962500721156,1.0,1.0,0.0,null,6.554588851677638,3.9068905956085187,5.20945336562895,3.9068905956085187,3.4594316186372973,3.584962500721156,4.247927513443585,5.426264754702098,2.0,5.523561956057013,3.807354922057604,1.0,5.0,null,5.087462841250339,1.0,1.0,1.0,1.584962500721156,2.0,2.321928094887362,2.584962500721156,1.584962500721156,2.0,null,0.0,1.0,null,1.0,1.0,null,null,null,1.0,0.0,1.584962500721156,1.0,null,null,0.0,2.321928094887362,null,0.0,null,null,null,null,null,null,null,null,null,null,1.584962500721156,null,0.0,7.693486957499325,2.584962500721156,6.339850002884624,2.321928094887362,2.584962500721156,5.857980995127572,3.169925001442312,3.0,2.0,3.0,5.754887502163468,null,2.0,null,7.129283016944966,4.247927513443585,4.087462841250339,4.807354922057604,3.700439718141092,4.754887502163468,4.754887502163468,5.754887502163468,4.643856189774724,5.643856189774724,4.169925001442312,2.807354922057604,5.906890595608519,null,5.247927513443585,1.584962500721156,3.9068905956085187,3.584962500721156,3.0,3.169925001442312,3.321928094887362,3.0,4.087462841250339,3.700439718141092,2.0,1.584962500721156,4.0,null,3.807354922057604,1.584962500721156,1.0,1.0,0.0,null,0.0,1.584962500721156,1.584962500721156,4.087462841250339,2.0,0.0,1.0,null,5.754887502163468,3.584962500721156,4.087462841250339,3.169925001442312,3.169925001442312,3.169925001442312,3.0,4.754887502163468,1.584962500721156,4.247927513443585,4.0,4.087462841250339,3.700439718141092,null,8.005624549193879,5.554588851677638,5.20945336562895,5.392317422778761,5.523561956057013,5.426264754702098,5.930737337562887,6.539158811108031,4.169925001442312,6.554588851677638,5.584962500721156,2.321928094887362,5.614709844115208,null,2.807354922057604,1.0,1.0,1.0,0.0,null,0.0,1.0,null,0.0,null,2.321928094887362,0.0,null,4.169925001442312,2.321928094887362,2.584962500721156,2.321928094887362,2.0,2.807354922057604,2.0,4.321928094887363,1.584962500721156,4.087462841250339,null,null,2.0,null,6.129283016944966,3.4594316186372973,4.754887502163468,3.700439718141092,3.807354922057604,4.087462841250339,4.523561956057013,5.0,1.584962500721156,6.108524456778169,3.584962500721156,1.0,4.807354922057604,null,6.6293566200796095,3.321928094887362,4.584962500721156,4.321928094887363,3.700439718141092,3.584962500721156,5.0,4.0,3.584962500721156,4.087462841250339,4.321928094887363,2.0,5.129283016944966,null,6.409390936137702,3.807354922057604,4.321928094887363,3.321928094887362,2.0,1.0,2.0,3.0,2.0,5.392317422778761,2.0,2.0,2.584962500721156,null,null,null,1.0,null,null,null,null,null,null,null,null,2.321928094887362,null,null,8.31741261376487,null,6.066089190457772,4.954196310386875,4.700439718141092,5.754887502163468,5.954196310386875,6.918863237274595,4.321928094887363,6.954196310386875,5.700439718141092,4.0,6.087462841250339,0.0,5.129283016944966,1.0,4.857980995127572,3.321928094887362,3.9068905956085187,3.169925001442312,3.584962500721156,4.0,4.0,2.807354922057604,3.807354922057604,2.321928094887362,3.584962500721156,null,5.491853096329675,3.169925001442312,3.807354922057604,2.584962500721156,2.0,2.0,2.807354922057604,4.169925001442312,1.0,5.044394119358453,3.0,2.321928094887362,3.169925001442312,null,6.832890014164741,4.700439718141092,5.169925001442312,4.0,4.087462841250339,2.584962500721156,4.906890595608519,5.129283016944966,4.169925001442312,5.78135971352466,3.700439718141092,1.0,4.700439718141092,null,5.357552004618084,2.584962500721156,3.321928094887362,3.321928094887362,0.0,3.4594316186372973,2.584962500721156,2.807354922057604,2.584962500721156,4.584962500721156,3.0,1.584962500721156,3.4594316186372973,null,4.954196310386875,2.321928094887362,2.0,1.0,0.0,2.584962500721156,3.169925001442312,3.4594316186372973,2.584962500721156,3.584962500721156,1.0,0.0,2.807354922057604,null,6.285402218862249,4.087462841250339,4.392317422778761,4.087462841250339,3.807354922057604,3.584962500721156,4.0,5.169925001442312,3.584962500721156,5.129283016944966,4.321928094887363,1.584962500721156,5.554588851677638,0.0,6.0,2.807354922057604,3.584962500721156,4.169925001442312,2.0,3.169925001442312,2.321928094887362,3.700439718141092,2.321928094887362,4.169925001442312,2.0,2.321928094887362,3.321928094887362,0.0,5.906890595608519,3.321928094887362,4.169925001442312,2.807354922057604,1.584962500721156,3.700439718141092,3.169925001442312,4.392317422778761,2.584962500721156,5.169925001442312,1.0,null,4.087462841250339,null,4.392317422778761,0.0,1.0,1.0,1.584962500721156,2.321928094887362,0.0,2.321928094887362,null,1.0,2.0,1.584962500721156,2.584962500721156,null,5.523561956057013,3.0,3.169925001442312,4.0,3.169925001442312,3.321928094887362,1.584962500721156,4.087462841250339,0.0,4.087462841250339,2.0,2.584962500721156,3.4594316186372973,null,0.0,null,1.0,null,0.0,null,null,null,0.0,null,null,0.0,null,null,8.531381460516313,null,5.930737337562887,6.108524456778169,5.247927513443585,5.807354922057604,5.584962500721156,7.321928094887363,5.285402218862249,7.3750394313469245,5.129283016944966,3.321928094887362,6.491853096329675,0.0,8.022367813028454,5.523561956057013,6.794415866350106,5.044394119358453,5.087462841250339,6.066089190457772,6.189824558880018,6.523561956057013,5.321928094887363,6.614709844115208,5.491853096329675,1.0,5.754887502163468,0.0,9.398743691938193,6.78135971352466,7.531381460516312,6.6865005271832185,6.392317422778761,7.05528243550119,6.845490050944375,8.103287808412022,6.129283016944966,8.154818109052105,6.491853096329675,1.584962500721156,7.507794640198696,null,6.700439718141092,3.4594316186372973,4.169925001442312,4.247927513443585,4.169925001442312,3.4594316186372973,4.0,4.954196310386875,3.700439718141092,4.857980995127572,2.584962500721156,2.0,4.321928094887363,null,6.965784284662087,4.392317422778761,4.643856189774724,4.0,4.0,4.754887502163468,5.044394119358453,6.20945336562895,4.0,4.523561956057013,3.9068905956085187,2.321928094887362,5.087462841250339,null,5.087462841250339,3.700439718141092,2.584962500721156,2.0,1.584962500721156,3.700439718141092,2.807354922057604,4.321928094887363,1.0,3.584962500721156,3.169925001442312,1.0,3.807354922057604,null,7.294620748891627,4.584962500721156,6.409390936137702,4.392317422778761,3.807354922057604,4.321928094887363,4.954196310386875,7.0,4.700439718141092,6.3750394313469245,5.087462841250339,1.584962500721156,5.906890595608519,null,6.930737337562887,3.807354922057604,3.321928094887362,4.169925001442312,2.321928094887362,3.807354922057604,3.0,5.906890595608519,3.700439718141092,6.321928094887363,4.169925001442312,2.0,4.643856189774724,null,5.087462841250339,1.584962500721156,4.0,1.584962500721156,0.0,1.584962500721156,2.584962500721156,4.247927513443585,2.0,5.087462841250339,2.321928094887362,1.584962500721156,4.459431618637297,null,5.169925001442312,0.0,1.584962500721156,1.0,null,1.584962500721156,1.0,1.584962500721156,null,3.584962500721156,1.0,1.584962500721156,2.0,1.0,5.727920454563199,2.321928094887362,3.584962500721156,3.4594316186372973,1.0,0.0,3.0,3.169925001442312,2.0,4.0,2.584962500721156,3.169925001442312,0.0,null,null,null,null,null,null,null,null,null,null,null,null,2.0,null,1.584962500721156,9.5980525001616,6.044394119358453,8.016808287686555,7.076815597050831,7.592457037268081,7.672425341971495,8.066089190457772,7.918863237274595,6.94251450533924,7.303780748177103,6.807354922057604,3.9068905956085187,8.447083226209653,1.0,8.011227255423254,5.491853096329675,5.954196310386875,5.321928094887363,4.0,5.087462841250339,5.426264754702098,7.044394119358453,4.584962500721156,6.044394119358453,5.285402218862249,3.0,5.906890595608519,null,6.0,3.4594316186372973,3.807354922057604,3.4594316186372973,3.584962500721156,3.321928094887362,3.584962500721156,4.247927513443585,1.0,2.584962500721156,2.584962500721156,3.0,3.584962500721156,1.584962500721156,7.257387842692652,4.807354922057604,5.754887502163468,5.087462841250339,4.087462841250339,5.129283016944966,5.584962500721156,5.426264754702098,5.584962500721156,6.614709844115208,4.584962500721156,2.807354922057604,6.066089190457772,null,2.0,null,1.0,0.0,null,null,null,2.0,null,null,null,null,0.0,2.321928094887362,4.087462841250339,1.584962500721156,3.321928094887362,1.584962500721156,3.321928094887362,1.0,3.584962500721156,3.700439718141092,2.0,null,2.0,1.584962500721156,4.0,1.0,5.614709844115208,2.321928094887362,4.459431618637297,3.807354922057604,2.807354922057604,2.584962500721156,3.169925001442312,5.129283016944966,2.0,4.584962500721156,3.9068905956085187,2.584962500721156,3.4594316186372973,null,5.20945336562895,0.0,3.4594316186372973,2.807354922057604,0.0,3.169925001442312,2.807354922057604,4.169925001442312,null,4.857980995127572,3.0,0.0,2.321928094887362,null,3.700439718141092,null,2.0,1.584962500721156,1.584962500721156,null,2.807354922057604,1.584962500721156,3.169925001442312,2.584962500721156,1.0,2.0,2.584962500721156,null,4.459431618637297,3.0,3.0,2.0,2.584962500721156,3.169925001442312,2.321928094887362,3.0,3.321928094887362,3.321928094887362,1.0,0.0,4.087462841250339,null,2.321928094887362,0.0,1.0,null,null,null,null,0.0,0.0,null,1.0,2.321928094887362,3.321928094887362,null,null,null,null,null,null,null,0.0,null,null,0.0,null,0.0,null,null,6.977279923499917,3.807354922057604,5.087462841250339,4.0,4.643856189774724,5.357552004618084,5.459431618637297,3.9068905956085187,4.857980995127572,4.247927513443585,4.459431618637297,3.0,5.832890014164741,1.0,6.741466986401147,4.321928094887363,5.247927513443585,4.169925001442312,4.584962500721156,4.169925001442312,5.044394119358453,3.807354922057604,4.0,4.0,4.321928094887363,1.0,5.357552004618084,null,6.475733430966398,3.0,4.584962500721156,3.0,4.247927513443585,3.321928094887362,4.857980995127572,3.321928094887362,1.0,0.0,2.584962500721156,1.0,5.087462841250339,0.0,6.954196310386875,4.584962500721156,6.266786540694901,4.584962500721156,5.0,5.169925001442312,5.857980995127572,4.857980995127572,4.169925001442312,4.0,4.459431618637297,2.807354922057604,5.832890014164741,null,4.857980995127572,null,3.0,1.584962500721156,1.0,3.0,3.0,2.0,2.584962500721156,null,3.807354922057604,0.0,3.169925001442312,0.0,5.906890595608519,3.0,2.0,2.321928094887362,3.584962500721156,3.0,3.584962500721156,3.4594316186372973,3.584962500721156,3.4594316186372973,1.0,1.0,4.247927513443585,0.0,8.64745842645492,6.339850002884624,6.94251450533924,6.189824558880018,5.727920454563199,7.098032082960526,6.918863237274595,5.906890595608519,5.977279923499917,6.714245517666122,5.906890595608519,2.584962500721156,7.643856189774724,null,4.321928094887363,1.0,2.807354922057604,1.0,1.584962500721156,2.0,2.321928094887362,1.0,1.0,3.0,1.0,2.0,3.584962500721156,1.584962500721156,7.066089190457772,4.584962500721156,5.584962500721156,4.807354922057604,4.700439718141092,5.523561956057013,5.643856189774724,4.700439718141092,4.523561956057013,5.491853096329675,5.357552004618084,2.584962500721156,5.930737337562887,null,5.0,1.0,3.321928094887362,2.807354922057604,2.321928094887362,2.321928094887362,3.321928094887362,2.0,3.584962500721156,1.584962500721156,3.700439718141092,2.584962500721156,3.584962500721156,null,4.954196310386875,2.0,2.584962500721156,2.807354922057604,2.807354922057604,3.169925001442312,3.4594316186372973,1.584962500721156,3.169925001442312,3.169925001442312,2.0,2.584962500721156,3.584962500721156,null,null,null,1.0,null,null,null,null,null,null,1.0,null,2.0,null,null,8.366322214245816,6.087462841250339,7.022367813028454,5.807354922057604,6.044394119358453,6.599912842187128,6.94251450533924,5.857980995127572,5.857980995127572,5.807354922057604,6.321928094887363,3.0,7.330916878114617,2.321928094887362,9.94251450533924,7.658211482751795,9.055282435501189,7.475733430966398,7.768184324776926,8.370687406807217,8.396604781181859,7.839203788096944,7.599912842187128,8.204571144249204,7.247927513443585,3.700439718141092,9.328674927327947,0.0,4.392317422778761,3.700439718141092,3.0,2.0,3.321928094887362,3.169925001442312,3.584962500721156,1.584962500721156,1.584962500721156,3.169925001442312,1.0,2.0,3.9068905956085187,1.0,6.392317422778761,4.321928094887363,5.169925001442312,4.700439718141092,4.584962500721156,4.169925001442312,5.169925001442312,4.643856189774724,4.087462841250339,4.087462841250339,4.247927513443585,2.0,5.426264754702098,null,null,null,1.584962500721156,null,null,null,0.0,0.0,null,1.0,1.0,3.169925001442312,null,null,3.0,null,1.0,0.0,null,0.0,1.584962500721156,null,null,null,null,null,2.584962500721156,0.0,6.672425341971495,4.523561956057013,3.807354922057604,4.0,4.321928094887363,5.129283016944966,5.20945336562895,4.247927513443585,4.523561956057013,2.807354922057604,4.087462841250339,0.0,5.614709844115208,null,null,null,0.0,null,null,null,null,null,null,null,null,0.0,null,null,5.78135971352466,4.392317422778761,4.459431618637297,3.0,3.321928094887362,3.4594316186372973,4.0,2.321928094887362,3.321928094887362,4.754887502163468,3.584962500721156,2.584962500721156,4.523561956057013,null,null,null,0.0,null,null,null,null,null,null,0.0,null,2.321928094887362,null,null,6.727920454563199,5.523561956057013,5.321928094887363,3.700439718141092,3.807354922057604,2.584962500721156,4.584962500721156,3.4594316186372973,2.0,4.523561956057013,4.321928094887363,2.321928094887362,4.857980995127572,null,null,null,0.0,null,null,null,null,null,1.0,1.584962500721156,null,2.321928094887362,null,1.0,0.0,1.0,0.0,0.0,0.0,null,0.0,2.584962500721156,0.0,5.321928094887363,1.0,5.554588851677638,1.584962500721156,null,0.0,null,0.0,0.0,0.0,null,null,null,0.0,null,1.0,3.584962500721156,null,6.832890014164741,7.499845887083206,6.266786540694901,6.044394119358453,6.0,3.169925001442312,4.700439718141092,5.129283016944966,6.066089190457772,3.584962500721156,6.321928094887363,5.169925001442312,11.877284133523196,5.087462841250339,1.584962500721156,7.366322214245816,null,null,6.108524456778169,5.129283016944966,6.044394119358453,4.459431618637297,null,5.459431618637297,7.930737337562887,4.087462841250339,6.768184324776926,6.6865005271832185,0.0,8.005624549193879,null,1.0,4.954196310386875,3.321928094887362,4.906890595608519,2.0,null,4.700439718141092,7.129283016944966,4.321928094887363,7.965784284662087,5.672425341971495,null,2.0,null,2.584962500721156,0.0,null,0.0,2.0,0.0,null,null,null,6.266786540694901,1.584962500721156,null,3.169925001442312,null,null,null,1.584962500721156,null,2.807354922057604,null,1.0,null,null,null,null,null,0.0,null,null,null,null,null,null,0.0,null,null,null,2.0,null,3.584962500721156,3.807354922057604,3.700439718141092,3.169925001442312,2.584962500721156,2.584962500721156,2.0,2.321928094887362,1.584962500721156,2.0,2.0,null,7.189824558880018,3.169925001442312,3.169925001442312,4.459431618637297,0.0,3.0,2.321928094887362,0.0,1.584962500721156,2.0,0.0,null,2.0,1.0,7.0,2.321928094887362,0.0,3.9068905956085187,null,null,1.0,1.584962500721156,2.0,1.0,null,0.0,1.0,1.0,2.321928094887362,3.321928094887362,null,0.0,null,1.0,0.0,null,0.0,0.0,null,null,1.0,null,3.4594316186372973,1.0,0.0,6.539158811108031,0.0,null,3.807354922057604,3.0,3.321928094887362,2.584962500721156,null,3.321928094887362,5.044394119358453,1.0,5.426264754702098,4.247927513443585,6.857980995127572,7.857980995127572,6.442943495848728,6.285402218862249,5.285402218862249,4.807354922057604,5.129283016944966,4.087462841250339,5.584962500721156,4.321928094887363,6.247927513443585,5.20945336562895,11.580729651598958,6.0,null,0.0,null,0.0,null,null,null,null,null,null,2.584962500721156,null,0.0,0.0,null,5.882643049361842,null,1.0,3.807354922057604,2.0,1.0,2.0,2.321928094887362,2.0,4.584962500721156,null,6.22881869049588,4.0,null,2.321928094887362,1.584962500721156,3.321928094887362,null,null,0.0,null,2.807354922057604,0.0,3.0,2.0,1.0,1.584962500721156,2.321928094887362,1.584962500721156,null,1.584962500721156,0.0,null,null,null,null,0.0,3.321928094887362,null,2.807354922057604,1.0,null,5.044394119358453,null,0.0,3.4594316186372973,1.584962500721156,3.4594316186372973,1.0,null,2.321928094887362,5.129283016944966,1.0,5.459431618637297,4.087462841250339,null,5.087462841250339,null,null,3.0,null,0.0,0.0,null,null,4.0,null,2.0,2.584962500721156,1.0,3.584962500721156,null,2.807354922057604,1.584962500721156,null,1.0,1.584962500721156,2.584962500721156,2.0,2.584962500721156,null,7.924812503605781,null,null,5.321928094887363,null,0.0,2.584962500721156,1.584962500721156,1.584962500721156,2.321928094887362,null,null,4.906890595608519,null,4.0,3.169925001442312,0.0,4.584962500721156,0.0,3.321928094887362,1.584962500721156,1.0,2.0,null,2.0,null,2.0,2.584962500721156,8.044394119358454,1.584962500721156,null,3.321928094887362,null,1.0,1.0,0.0,0.0,null,null,1.584962500721156,2.321928094887362,null,3.4594316186372973,0.0,1.0,5.672425341971495,1.0,5.584962500721156,1.0,2.321928094887362,4.247927513443585,1.584962500721156,1.584962500721156,1.0,2.0,4.459431618637297,7.417852514885898,2.0,1.0,8.027905996569885,null,0.0,5.930737337562887,3.321928094887362,5.357552004618084,3.169925001442312,1.0,3.807354922057604,7.0,4.392317422778761,6.357552004618084,5.523561956057013,3.321928094887362,3.169925001442312,2.321928094887362,null,1.0,0.0,1.0,0.0,3.4594316186372973,2.0,3.807354922057604,1.0,7.820178962415188,null,null,1.0,null,null,1.584962500721156,null,null,null,1.0,null,2.0,null,5.247927513443585,0.0,null,5.78135971352466,0.0,1.0,3.584962500721156,3.0,2.584962500721156,3.321928094887362,2.321928094887362,2.321928094887362,5.247927513443585,3.0,5.392317422778761,4.087462841250339,null,5.426264754702098,null,null,3.584962500721156,0.0,2.321928094887362,2.0,null,0.0,5.129283016944966,null,4.807354922057604,3.321928094887362,null,2.0,null,2.0,2.584962500721156,0.0,1.0,null,3.9068905956085187,2.0,5.0,3.0,4.643856189774724,0.0,null,3.700439718141092,null,null,2.0,1.584962500721156,2.0,1.0,null,1.0,3.807354922057604,1.0,4.169925001442312,1.0,null,4.807354922057604,2.321928094887362,2.0,2.0,null,2.0,0.0,3.169925001442312,null,3.584962500721156,null,0.0,1.584962500721156,null,2.0,1.0,2.584962500721156,1.584962500721156,0.0,1.584962500721156,2.0,2.0,null,null,null,null,2.0,0.0,3.700439718141092,null,1.0,2.0,0.0,2.321928094887362,null,null,1.0,3.700439718141092,null,2.584962500721156,0.0,null,3.321928094887362,null,null,null,null,0.0,null,null,null,2.0,null,2.584962500721156,0.0,null,7.569855608330948,null,1.584962500721156,5.285402218862249,4.087462841250339,5.087462841250339,3.4594316186372973,1.0,5.129283016944966,6.357552004618084,3.9068905956085187,6.357552004618084,6.022367813028454,1.0,6.882643049361842,0.0,1.584962500721156,4.321928094887363,2.807354922057604,3.9068905956085187,3.321928094887362,1.584962500721156,3.584962500721156,5.78135971352466,2.0,6.539158811108031,4.954196310386875,null,5.906890595608519,3.0,4.459431618637297,4.087462841250339,1.584962500721156,3.700439718141092,3.169925001442312,4.459431618637297,3.0,5.459431618637297,3.169925001442312,2.0,3.807354922057604,2.0,5.044394119358453,null,0.0,3.321928094887362,4.0,4.321928094887363,2.0,null,3.584962500721156,5.044394119358453,2.0,4.459431618637297,5.20945336562895,null,2.321928094887362,null,null,1.0,null,0.0,0.0,null,null,0.0,null,2.807354922057604,0.0,1.584962500721156,2.807354922057604,null,0.0,0.0,1.0,1.0,null,null,1.584962500721156,5.459431618637297,null,5.491853096329675,1.584962500721156,null,3.0,0.0,null,3.169925001442312,null,0.0,0.0,3.4594316186372973,null,null,null,6.78135971352466,1.584962500721156,null,3.0,null,0.0,3.321928094887362,null,null,0.0,null,2.0,4.459431618637297,null,3.584962500721156,1.584962500721156,null,4.754887502163468,null,null,3.0,2.807354922057604,3.0,2.0,null,3.584962500721156,4.700439718141092,1.0,3.4594316186372973,2.807354922057604,0.0,1.584962500721156,null,0.0,1.0,0.0,0.0,0.0,null,null,1.584962500721156,0.0,0.0,null,null,3.321928094887362,null,null,null,0.0,1.0,null,null,null,3.700439718141092,null,2.584962500721156,1.0,null,0.0,null,null,1.0,null,0.0,null,1.0,null,3.9068905956085187,null,2.0,0.0,1.584962500721156,2.321928094887362,null,0.0,null,null,0.0,null,2.321928094887362,null,4.247927513443585,null,0.0,null,2.0,8.038918989292302,null,1.0,4.906890595608519,5.20945336562895,5.523561956057013,4.523561956057013,null,4.954196310386875,7.357552004618084,3.807354922057604,6.22881869049588,6.3750394313469245,null,7.894817763307944,0.0,2.807354922057604,4.459431618637297,4.169925001442312,4.700439718141092,3.321928094887362,2.807354922057604,4.700439718141092,6.321928094887363,3.0,6.741466986401147,5.857980995127572,null,4.807354922057604,1.584962500721156,2.807354922057604,2.321928094887362,0.0,2.321928094887362,2.807354922057604,3.169925001442312,null,5.0,1.0,8.900866807980748,1.0,null,4.0,null,null,2.0,0.0,2.321928094887362,1.584962500721156,null,0.0,3.321928094887362,1.0,5.129283016944966,3.169925001442312,1.584962500721156,3.700439718141092,null,3.584962500721156,0.0,null,2.321928094887362,1.584962500721156,1.584962500721156,null,4.700439718141092,0.0,5.285402218862249,2.321928094887362,null,3.9068905956085187,null,0.0,2.321928094887362,1.584962500721156,1.584962500721156,null,2.807354922057604,1.0,4.643856189774724,null,5.044394119358453,2.584962500721156,null,4.807354922057604,null,null,2.584962500721156,null,2.584962500721156,null,2.584962500721156,null,1.584962500721156,2.584962500721156,4.169925001442312,1.0,2.807354922057604,5.087462841250339,null,1.0,4.087462841250339,1.0,2.807354922057604,3.321928094887362,5.285402218862249,3.807354922057604,7.851749041416057,4.584962500721156,7.1799090900149345,4.087462841250339,null,4.857980995127572,null,0.0,2.584962500721156,2.321928094887362,2.584962500721156,0.0,1.0,2.584962500721156,4.087462841250339,2.0,4.087462841250339,3.4594316186372973,0.0,4.523561956057013,null,null,2.584962500721156,1.0,0.0,1.0,null,2.0,3.169925001442312,null,3.0,2.0,null,4.700439718141092,null,null,0.0,null,1.584962500721156,null,0.0,null,3.169925001442312,1.0,3.169925001442312,1.584962500721156,null,null,null,1.0,null,null,null,null,null,null,0.0,null,3.0,null,0.0,4.954196310386875,0.0,2.584962500721156,3.584962500721156,2.0,2.584962500721156,0.0,4.247927513443585,1.0,3.700439718141092,3.0,9.348728154231077,2.807354922057604,null,5.044394119358453,null,null,2.0,1.584962500721156,2.321928094887362,2.321928094887362,2.321928094887362,2.0,4.523561956057013,null,4.523561956057013,3.9068905956085187,null,6.20945336562895,0.0,1.0,5.169925001442312,4.906890595608519,5.754887502163468,3.700439718141092,3.0,5.087462841250339,6.392317422778761,2.0,6.584962500721156,5.906890595608519,null,1.0,null,null,null,0.0,null,null,null,null,0.0,null,0.0,null,1.0,3.0,null,null,2.807354922057604,2.0,3.0,2.321928094887362,2.321928094887362,1.0,3.9068905956085187,1.0,4.643856189774724,2.584962500721156,null,1.584962500721156,null,null,null,1.0,1.0,1.0,null,1.0,2.807354922057604,null,3.584962500721156,1.0,0.0,3.584962500721156,null,null,2.321928094887362,2.0,0.0,null,null,null,3.584962500721156,1.0,4.0,2.0,null,2.584962500721156,null,null,0.0,2.321928094887362,2.584962500721156,2.321928094887362,null,2.584962500721156,1.584962500721156,null,2.584962500721156,3.0,4.392317422778761,3.0,2.807354922057604,2.584962500721156,2.321928094887362,1.0,2.321928094887362,2.584962500721156,2.584962500721156,2.807354922057604,1.0,1.0,6.321928094887363,2.584962500721156,null,3.4594316186372973,2.807354922057604,3.0,1.0,1.0,1.0,1.0,1.0,null,null,1.0,null,1.584962500721156,null,null,null,null,0.0,0.0,null,null,null,null,0.0,0.0,null,null,5.930737337562887,6.266786540694901,4.954196310386875,5.321928094887363,4.459431618637297,4.169925001442312,4.807354922057604,5.584962500721156,3.584962500721156,3.9068905956085187,5.0,3.584962500721156,9.850186837645774,4.954196310386875,null,1.584962500721156,null,1.584962500721156,1.584962500721156,null,1.584962500721156,1.584962500721156,null,1.0,2.584962500721156,3.0,4.169925001442312,0.0,null,5.20945336562895,1.0,null,3.321928094887362,4.954196310386875,3.807354922057604,4.584962500721156,0.0,5.614709844115208,3.321928094887362,2.0,4.0,4.169925001442312,6.189824558880018,6.247927513443585,5.491853096329675,6.247927513443585,4.700439718141092,3.169925001442312,4.643856189774724,4.392317422778761,4.0,3.584962500721156,3.807354922057604,4.857980995127572,9.18239435340453,5.129283016944966,1.584962500721156,5.954196310386875,3.321928094887362,4.392317422778761,3.807354922057604,3.169925001442312,4.643856189774724,4.321928094887363,2.584962500721156,3.321928094887362,4.0,4.321928094887363,1.0,5.0,null,3.321928094887362,0.0,null,1.0,1.584962500721156,2.0,1.0,null,1.0,1.0,2.0,2.0,1.584962500721156,null,3.807354922057604,3.0,3.169925001442312,2.0,2.321928094887362,2.584962500721156,3.0,1.0,1.0,null,1.0,null,2.807354922057604,0.0,3.700439718141092,3.4594316186372973,3.321928094887362,2.0,1.584962500721156,2.0,3.169925001442312,0.0,null,1.0,2.584962500721156,null,2.0,null,4.700439718141092,null,null,1.584962500721156,3.584962500721156,3.321928094887362,2.584962500721156,null,1.0,null,1.584962500721156,4.169925001442312,2.807354922057604,null,1.0,null,0.0,null,0.0,1.0,1.0,null,1.0,2.0,null,1.0,1.584962500721156,1.584962500721156,0.0,null,null,null,0.0,1.584962500721156,0.0,null,null,2.321928094887362,2.0,0.0,1.0,0.0,null,null,null,0.0,null,null,null,null,null,null,null,null,null,null,5.392317422778761,null,0.0,1.0,3.169925001442312,2.321928094887362,2.0,null,2.584962500721156,2.584962500721156,2.0,3.4594316186372973,3.584962500721156,9.79766152585376,10.080817527608327,9.319672120946995,9.566054038171092,8.179909090014934,8.139551352398794,8.20945336562895,8.897845456005511,7.906890595608519,7.864186144654281,8.164906926675688,8.339850002884624,13.12395971059229,9.487840033823051,null,3.584962500721156,null,1.0,1.584962500721156,null,0.0,2.807354922057604,null,1.0,2.807354922057604,0.0,3.700439718141092,2.807354922057604,0.0,6.754887502163468,null,0.0,3.807354922057604,5.044394119358453,4.392317422778761,4.321928094887363,1.0,4.700439718141092,4.459431618637297,4.087462841250339,4.700439718141092,6.0,0.0,6.539158811108031,null,1.0,4.321928094887363,4.087462841250339,5.357552004618084,4.247927513443585,null,5.491853096329675,5.459431618637297,3.0,5.357552004618084,6.0,null,null,null,null,null,null,0.0,0.0,null,null,1.0,null,1.0,0.0,0.0,3.700439718141092,null,null,1.584962500721156,2.0,2.584962500721156,2.584962500721156,0.0,2.584962500721156,3.169925001442312,1.0,2.584962500721156,3.4594316186372973,null,0.0,null,null,null,2.584962500721156,2.321928094887362,1.0,0.0,1.0,3.169925001442312,1.0,3.321928094887362,2.0,null,null,null,null,0.0,null,null,null,null,null,1.0,null,null,null,null,1.0,null,1.0,1.0,null,0.0,null,0.0,2.0,null,null,3.169925001442312,0.0,null,0.0,null,null,1.584962500721156,1.584962500721156,0.0,2.0,null,1.0,2.0,null,3.169925001442312,1.584962500721156,null,null,null,null,0.0,null,null,null,null,null,0.0,null,null,null,0.0,6.754887502163468,4.321928094887363,5.0,3.321928094887362,3.321928094887362,2.584962500721156,4.807354922057604,3.807354922057604,3.321928094887362,4.459431618637297,4.954196310386875,10.46352437327118,5.247927513443585,1.0,7.149747119504682,4.643856189774724,5.426264754702098,4.700439718141092,3.700439718141092,4.087462841250339,4.0,4.392317422778761,2.584962500721156,4.321928094887363,4.392317422778761,10.246740598493144,6.672425341971495,1.584962500721156,8.535275376620802,6.22881869049588,7.2384047393250786,6.266786540694901,5.977279923499917,5.882643049361842,6.3750394313469245,6.539158811108031,5.129283016944966,7.199672344836364,6.066089190457772,12.099676554859643,7.491853096329675,0.0,6.930737337562887,5.169925001442312,5.129283016944966,4.643856189774724,4.0,4.0,4.807354922057604,5.129283016944966,3.321928094887362,5.584962500721156,5.169925001442312,10.86573327085176,5.727920454563199,3.0,8.665335917185176,6.321928094887363,7.294620748891627,6.20945336562895,5.857980995127572,6.149747119504682,6.78135971352466,6.9886846867721655,5.882643049361842,7.826548487290915,6.426264754702098,12.480032814583948,7.794415866350106,3.584962500721156,9.30149619498255,6.918863237274595,8.74819284958946,7.066089190457772,7.098032082960526,7.2384047393250786,7.948367231584678,6.714245517666122,6.754887502163468,8.159871336778389,7.285402218862249,11.913637428049103,8.870364719583405,null,3.584962500721156,null,4.0,null,5.285402218862249,1.0,7.491853096329675,null,5.169925001442312,null,1.0,4.459431618637297,1.584962500721156,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.584962500721156,null,0.0,7.2761244052742375,4.523561956057013,5.700439718141092,5.044394119358453,4.523561956057013,4.321928094887363,5.491853096329675,4.321928094887363,5.426264754702098,5.700439718141092,4.906890595608519,10.140829770773001,6.266786540694901,null,null,null,null,null,null,null,null,null,null,null,null,1.0,null,1.584962500721156,7.954196310386875,6.149747119504682,6.820178962415188,6.129283016944966,5.357552004618084,5.857980995127572,6.3750394313469245,6.845490050944375,5.523561956057013,7.03342300153745,5.832890014164741,11.884170519108435,7.366322214245816,null,8.03342300153745,5.392317422778761,6.426264754702098,5.78135971352466,5.169925001442312,5.044394119358453,6.022367813028454,3.700439718141092,5.459431618637297,6.266786540694901,6.247927513443585,11.252074042796185,6.794415866350106,1.584962500721156,8.569855608330949,5.491853096329675,8.049848549450562,6.339850002884624,6.022367813028454,6.149747119504682,6.266786540694901,6.491853096329675,4.643856189774724,6.741466986401147,6.129283016944966,11.10459875356437,7.693486957499325,null,6.643856189774724,3.700439718141092,4.459431618637297,4.087462841250339,3.169925001442312,3.321928094887362,4.643856189774724,3.9068905956085187,2.0,3.9068905956085187,2.0,10.029287226968245,5.247927513443585,1.0,7.546894459887636,5.727920454563199,5.700439718141092,5.857980995127572,4.247927513443585,4.584962500721156,5.491853096329675,5.392317422778761,3.0,6.022367813028454,4.807354922057604,11.454813348512525,6.768184324776926,1.584962500721156,7.857980995127572,5.857980995127572,6.392317422778761,5.643856189774724,5.392317422778761,5.392317422778761,5.357552004618084,4.906890595608519,3.584962500721156,5.754887502163468,5.169925001442312,11.711666973564347,6.714245517666122,null,7.977279923499917,5.392317422778761,6.78135971352466,5.426264754702098,4.700439718141092,5.285402218862249,5.392317422778761,5.807354922057604,4.0,6.491853096329675,5.044394119358453,11.287135186086704,6.584962500721156,1.584962500721156,6.20945336562895,3.700439718141092,4.247927513443585,4.807354922057604,3.0,2.584962500721156,3.4594316186372973,3.169925001442312,1.584962500721156,3.4594316186372973,3.807354922057604,10.122827994807666,4.392317422778761,1.0,7.05528243550119,5.357552004618084,6.20945336562895,5.169925001442312,4.459431618637297,4.523561956057013,5.807354922057604,3.584962500721156,3.584962500721156,6.339850002884624,5.672425341971495,11.378294855911891,6.266786540694901,null,0.0,null,null,null,null,null,null,null,null,null,null,1.0,null,0.0,7.643856189774724,4.643856189774724,6.189824558880018,5.20945336562895,4.807354922057604,5.321928094887363,5.285402218862249,5.426264754702098,4.0,5.882643049361842,5.0,10.98299357469431,6.321928094887363,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,1.584962500721156,6.78135971352466,4.857980995127572,5.832890014164741,4.169925001442312,2.807354922057604,3.807354922057604,5.0,5.0,3.321928094887362,5.807354922057604,4.906890595608519,10.868050853745158,6.066089190457772,null,6.129283016944966,2.0,4.523561956057013,1.584962500721156,1.0,3.807354922057604,2.321928094887362,2.0,null,2.0,4.906890595608519,7.7073591320808825,3.0,0.0,7.108524456778169,4.584962500721156,5.321928094887363,4.857980995127572,3.321928094887362,4.0,3.9068905956085187,3.807354922057604,0.0,5.672425341971495,4.0,10.644757592516257,5.832890014164741,null,6.658211482751795,4.169925001442312,5.357552004618084,4.087462841250339,4.0,3.584962500721156,3.9068905956085187,4.584962500721156,1.0,4.954196310386875,4.0,9.851749041416058,4.954196310386875,1.584962500721156,7.303780748177103,4.857980995127572,5.906890595608519,4.857980995127572,5.129283016944966,5.044394119358453,5.882643049361842,4.459431618637297,4.459431618637297,5.882643049361842,5.459431618637297,11.101975670949232,6.303780748177103,1.0,7.366322214245816,4.459431618637297,5.906890595608519,5.087462841250339,4.247927513443585,5.0,4.459431618637297,5.954196310386875,4.0,5.523561956057013,3.4594316186372973,11.050528905530555,5.906890595608519,null,1.584962500721156,null,1.584962500721156,null,null,null,0.0,1.584962500721156,null,2.0,0.0,4.523561956057013,0.0,null,null,null,null,0.0,null,null,null,null,null,null,null,2.321928094887362,null,0.0,6.044394119358453,4.321928094887363,5.643856189774724,4.0,3.807354922057604,4.087462841250339,4.643856189774724,5.0,2.584962500721156,4.087462841250339,3.584962500721156,10.079484783826816,5.459431618637297,1.0,7.971543553950772,5.754887502163468,6.475733430966398,5.643856189774724,5.285402218862249,5.584962500721156,5.523561956057013,3.9068905956085187,4.169925001442312,5.754887502163468,5.954196310386875,11.316847183602473,7.2761244052742375,0.0,6.930737337562887,4.169925001442312,5.882643049361842,5.129283016944966,4.584962500721156,4.247927513443585,4.523561956057013,5.285402218862249,4.392317422778761,5.882643049361842,4.807354922057604,10.075479149488016,6.20945336562895,null,0.0,null,null,null,null,null,null,null,null,null,null,4.169925001442312,0.0,0.0,7.451211111832329,5.0,6.442943495848728,4.643856189774724,4.169925001442312,4.087462841250339,5.169925001442312,5.523561956057013,3.700439718141092,6.108524456778169,4.584962500721156,10.754052367528924,6.426264754702098,0.0,6.247927513443585,4.584962500721156,4.584962500721156,4.584962500721156,3.169925001442312,4.0,4.392317422778761,4.754887502163468,3.0,3.700439718141092,4.700439718141092,10.12670447284319,4.807354922057604,null,6.9886846867721655,4.392317422778761,5.906890595608519,4.169925001442312,3.700439718141092,4.087462841250339,4.584962500721156,5.491853096329675,3.0,5.807354922057604,5.169925001442312,10.960725994839057,6.087462841250339,0.0,7.2384047393250786,4.700439718141092,5.584962500721156,4.459431618637297,4.392317422778761,4.754887502163468,4.807354922057604,2.321928094887362,2.0,5.426264754702098,4.523561956057013,10.448116305409464,6.149747119504682,0.0,7.022367813028454,4.954196310386875,5.832890014164741,4.906890595608519,4.700439718141092,4.321928094887363,5.426264754702098,4.169925001442312,4.584962500721156,4.857980995127572,5.392317422778761,10.043027283594547,6.321928094887363,null,6.78135971352466,4.459431618637297,5.906890595608519,4.700439718141092,3.321928094887362,4.584962500721156,5.087462841250339,4.169925001442312,3.0,4.321928094887363,4.459431618637297,10.757390009366638,6.0,null,2.0,1.0,2.584962500721156,1.0,null,null,null,1.584962500721156,null,1.0,null,6.658211482751795,0.0,0.0,8.308339030139408,5.392317422778761,7.1799090900149345,6.22881869049588,5.857980995127572,6.149747119504682,6.426264754702098,3.169925001442312,5.20945336562895,6.066089190457772,6.285402218862249,10.62844554013718,7.768184324776926,1.584962500721156,7.658211482751795,5.0,7.098032082960526,5.357552004618084,4.754887502163468,4.906890595608519,5.700439718141092,5.169925001442312,5.129283016944966,5.906890595608519,5.459431618637297,10.604553229079038,6.554588851677638,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.584962500721156,7.531381460516312,4.906890595608519,5.754887502163468,5.087462841250339,4.392317422778761,4.459431618637297,4.754887502163468,2.0,3.807354922057604,5.807354922057604,4.754887502163468,10.7714894695006,5.584962500721156,null,0.0,null,null,null,null,1.584962500721156,null,null,null,null,null,2.584962500721156,0.0,null,8.413627929024173,5.700439718141092,7.011227255423254,6.108524456778169,5.554588851677638,5.392317422778761,6.129283016944966,6.0,5.357552004618084,6.918863237274595,5.930737337562887,11.336506559810255,7.247927513443585,null,7.05528243550119,4.392317422778761,5.754887502163468,4.459431618637297,4.247927513443585,4.392317422778761,5.285402218862249,4.321928094887363,3.0,5.584962500721156,4.459431618637297,10.129283016944967,6.321928094887363,2.0,7.483815777264256,5.169925001442312,6.442943495848728,5.247927513443585,4.643856189774724,5.044394119358453,5.643856189774724,6.022367813028454,4.247927513443585,5.426264754702098,4.857980995127572,10.837627933171404,6.459431618637297,null,3.321928094887362,0.0,2.0,null,null,0.0,0.0,1.0,0.0,null,1.0,6.169925001442312,null,0.0,6.794415866350106,3.807354922057604,5.459431618637297,4.169925001442312,3.169925001442312,4.0,4.247927513443585,4.459431618637297,3.321928094887362,5.554588851677638,4.584962500721156,10.03342300153745,4.954196310386875,null,7.266786540694901,4.087462841250339,5.727920454563199,5.0,4.700439718141092,4.169925001442312,4.807354922057604,4.906890595608519,3.584962500721156,4.459431618637297,4.247927513443585,10.037546953962178,6.169925001442312,null,3.321928094887362,1.584962500721156,0.0,2.0,null,null,null,0.0,null,1.0,null,7.721099188707185,0.0,null,6.409390936137702,3.700439718141092,4.906890595608519,3.0,3.0,2.0,2.321928094887362,4.169925001442312,2.807354922057604,4.584962500721156,3.807354922057604,9.957102041562287,4.643856189774724,null,7.459431618637297,5.0,6.6293566200796095,5.247927513443585,5.247927513443585,5.20945336562895,5.672425341971495,5.247927513443585,5.044394119358453,6.169925001442312,5.459431618637297,10.949097155729207,6.491853096329675,null,0.0,null,null,null,null,null,null,null,null,null,null,1.584962500721156,null,2.0,8.005624549193879,5.426264754702098,6.78135971352466,5.491853096329675,4.954196310386875,4.857980995127572,5.78135971352466,5.169925001442312,5.321928094887363,5.426264754702098,5.0,10.98299357469431,6.906890595608519,null,null,null,null,null,null,null,0.0,null,null,null,null,3.0,null,2.0,8.59618975614441,6.066089190457772,7.794415866350106,6.149747119504682,5.930737337562887,5.906890595608519,6.672425341971495,6.303780748177103,5.906890595608519,6.918863237274595,5.977279923499917,11.77313920671969,7.584962500721156,2.584962500721156,8.531381460516313,6.022367813028454,7.076815597050831,5.882643049361842,5.906890595608519,5.882643049361842,6.409390936137702,6.022367813028454,4.459431618637297,6.266786540694901,6.247927513443585,11.766528908598865,7.247927513443585,1.0,7.562242424221073,4.584962500721156,6.392317422778761,5.285402218862249,4.643856189774724,5.169925001442312,5.321928094887363,5.357552004618084,4.392317422778761,5.643856189774724,5.247927513443585,10.767356854125685,6.754887502163468,null,6.918863237274595,4.321928094887363,5.044394119358453,4.584962500721156,4.0,4.584962500721156,4.754887502163468,4.169925001442312,3.321928094887362,5.584962500721156,4.807354922057604,10.641148597411233,6.022367813028454,2.321928094887362,8.515699838284043,5.857980995127572,7.787902559391432,7.2384047393250786,6.108524456778169,7.219168520462161,7.60733031374961,6.357552004618084,6.507794640198696,8.29920801838728,7.285402218862249,10.97513145692134,8.144658242831882,0.0,4.0,1.584962500721156,2.584962500721156,2.321928094887362,1.0,1.0,0.0,4.169925001442312,null,4.392317422778761,2.0,8.717676423066395,1.0,null,4.321928094887363,2.0,2.807354922057604,3.0,0.0,0.0,1.584962500721156,2.807354922057604,1.0,null,null,8.59245703726808,2.584962500721156,null,0.0,null,null,null,null,null,null,null,null,null,null,null,0.0,2.321928094887362,6.930737337562887,4.523561956057013,5.906890595608519,4.523561956057013,4.643856189774724,4.392317422778761,5.169925001442312,5.392317422778761,3.0,5.169925001442312,4.087462841250339,10.542064542283443,6.022367813028454,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.0,6.977279923499917,4.807354922057604,5.554588851677638,5.321928094887363,4.857980995127572,4.754887502163468,6.022367813028454,3.0,4.169925001442312,4.321928094887363,4.700439718141092,9.79603960882977,5.930737337562887,1.0,7.3750394313469245,4.906890595608519,5.857980995127572,4.954196310386875,5.044394119358453,5.044394119358453,5.491853096329675,3.807354922057604,4.700439718141092,4.807354922057604,5.584962500721156,9.854868383260236,6.584962500721156,null,7.820178962415188,5.807354922057604,6.894817763307944,5.554588851677638,5.584962500721156,5.78135971352466,6.6293566200796095,4.169925001442312,5.247927513443585,5.392317422778761,5.392317422778761,10.591522346570734,7.199672344836364,0.0,7.507794640198696,5.087462841250339,6.3750394313469245,5.554588851677638,5.129283016944966,5.285402218862249,5.614709844115208,2.807354922057604,4.523561956057013,4.857980995127572,5.584962500721156,9.981567281903015,6.584962500721156,1.584962500721156,6.539158811108031,4.906890595608519,6.6865005271832185,5.285402218862249,5.129283016944966,4.643856189774724,5.954196310386875,4.584962500721156,4.321928094887363,4.523561956057013,4.321928094887363,9.943979914343739,6.392317422778761,0.0,7.366322214245816,4.459431618637297,6.459431618637297,3.9068905956085187,5.20945336562895,4.523561956057013,5.584962500721156,3.169925001442312,4.247927513443585,3.169925001442312,3.807354922057604,8.88264304936184,5.832890014164741,null,7.139551352398794,4.523561956057013,6.108524456778169,5.087462841250339,4.700439718141092,4.906890595608519,5.78135971352466,3.169925001442312,3.584962500721156,5.044394119358453,5.129283016944966,9.967226258835993,6.426264754702098,1.0,7.554588851677638,5.832890014164741,6.727920454563199,5.523561956057013,5.426264754702098,5.700439718141092,6.169925001442312,4.0,5.0,4.392317422778761,5.700439718141092,10.493855449240822,6.965784284662087,null,null,null,null,0.0,0.0,null,null,null,0.0,0.0,null,3.584962500721156,null,0.0,7.434628227636725,5.044394119358453,5.700439718141092,5.357552004618084,4.643856189774724,5.0,5.044394119358453,1.584962500721156,5.169925001442312,4.321928094887363,5.700439718141092,10.071462362556623,6.614709844115208,1.584962500721156,6.475733430966398,4.523561956057013,5.459431618637297,4.392317422778761,4.321928094887363,4.169925001442312,5.426264754702098,0.0,2.321928094887362,3.9068905956085187,4.0,9.469641817239516,6.129283016944966,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.918863237274595,3.584962500721156,6.321928094887363,4.700439718141092,4.0,4.906890595608519,5.169925001442312,3.700439718141092,3.0,4.169925001442312,4.700439718141092,9.152284842306582,6.0,null,7.734709620225838,5.285402218862249,6.339850002884624,4.906890595608519,5.459431618637297,5.20945336562895,5.954196310386875,4.459431618637297,4.906890595608519,4.906890595608519,5.087462841250339,10.158609688214478,6.954196310386875,2.321928094887362,7.924812503605781,5.169925001442312,6.741466986401147,5.285402218862249,5.523561956057013,5.700439718141092,6.108524456778169,4.169925001442312,4.321928094887363,5.0,5.0,10.231221180711186,7.044394119358453,1.0,8.071462362556623,6.569855608330948,7.139551352398794,5.832890014164741,5.807354922057604,6.108524456778169,6.6865005271832185,5.491853096329675,5.087462841250339,6.189824558880018,6.189824558880018,11.162391328756906,7.507794640198696,1.584962500721156,7.087462841250339,5.087462841250339,6.189824558880018,4.523561956057013,4.643856189774724,4.754887502163468,5.727920454563199,4.169925001442312,4.169925001442312,4.857980995127572,5.0,9.968666793195208,6.539158811108031,null,4.523561956057013,3.0,3.807354922057604,2.807354922057604,1.0,2.0,2.321928094887362,1.584962500721156,2.0,3.0,3.807354922057604,8.129283016944967,4.087462841250339,0.0,8.049848549450562,5.584962500721156,6.857980995127572,5.857980995127572,5.727920454563199,5.727920454563199,6.044394119358453,4.169925001442312,5.392317422778761,5.129283016944966,6.22881869049588,10.306061689428342,7.60733031374961,1.0,6.599912842187128,4.247927513443585,4.169925001442312,3.584962500721156,3.4594316186372973,3.9068905956085187,4.906890595608519,2.584962500721156,3.807354922057604,2.321928094887362,3.9068905956085187,9.319672120946995,5.523561956057013,null,null,null,1.0,null,null,null,null,null,null,null,null,2.584962500721156,null,2.0,6.918863237274595,4.321928094887363,5.554588851677638,4.807354922057604,4.857980995127572,4.0,5.129283016944966,3.807354922057604,4.169925001442312,4.0,4.754887502163468,9.426264754702098,6.459431618637297,1.584962500721156,7.6653359171851765,5.727920454563199,5.977279923499917,4.954196310386875,4.392317422778761,5.321928094887363,5.832890014164741,2.807354922057604,4.584962500721156,4.906890595608519,5.321928094887363,10.157346935362844,7.066089190457772,0.0,6.285402218862249,3.4594316186372973,5.807354922057604,3.584962500721156,2.584962500721156,3.700439718141092,4.247927513443585,4.087462841250339,3.807354922057604,3.584962500721156,2.321928094887362,8.79766152585376,5.285402218862249,null,6.965784284662087,4.906890595608519,6.149747119504682,4.700439718141092,4.584962500721156,4.247927513443585,5.554588851677638,1.0,4.584962500721156,5.044394119358453,4.807354922057604,10.00982861736811,6.303780748177103,2.584962500721156,7.977279923499917,5.169925001442312,7.0,5.523561956057013,5.491853096329675,5.523561956057013,6.409390936137702,4.459431618637297,5.169925001442312,4.523561956057013,5.700439718141092,10.11504365016171,7.539158811108031,null,null,null,null,null,null,0.0,null,null,null,null,null,1.584962500721156,null,8.562242424221072,8.768184324776927,7.539158811108031,7.569855608330948,6.426264754702098,6.149747119504682,7.129283016944966,7.774787059601174,8.475733430966399,6.475733430966398,8.625708843064466,6.94251450533924,5.0,7.826548487290915,8.89178370321831,7.149747119504682,7.257387842692652,5.426264754702098,4.807354922057604,4.392317422778761,5.977279923499917,5.523561956057013,6.285402218862249,4.584962500721156,7.22881869049588,4.857980995127572,4.584962500721156,7.0,9.139551352398794,8.344295907915816,7.247927513443585,7.118941072723508,5.78135971352466,5.930737337562887,6.539158811108031,6.918863237274595,7.857980995127572,5.754887502163468,7.700439718141092,6.78135971352466,1.584962500721156,7.219168520462161,7.118941072723508,6.392317422778761,4.954196310386875,4.584962500721156,4.087462841250339,3.169925001442312,3.700439718141092,4.459431618637297,5.954196310386875,4.169925001442312,5.491853096329675,4.392317422778761,2.807354922057604,5.044394119358453,8.651051691178928,8.50382573799575,6.754887502163468,6.78135971352466,5.857980995127572,5.700439718141092,6.321928094887363,6.303780748177103,7.7615512324444795,5.321928094887363,8.087462841250339,6.339850002884624,4.321928094887363,6.906890595608519,8.46352437327118,7.727920454563199,6.882643049361842,6.906890595608519,4.857980995127572,5.285402218862249,5.554588851677638,6.820178962415188,5.392317422778761,5.643856189774724,6.459431618637297,5.700439718141092,4.643856189774724,7.087462841250339,null,5.857980995127572,0.0,3.169925001442312,null,5.857980995127572,3.321928094887362,6.266786540694901,null,4.906890595608519,null,2.0,null,0.0,7.357552004618084,7.845490050944375,5.78135971352466,5.643856189774724,4.459431618637297,4.087462841250339,5.554588851677638,4.643856189774724,6.569855608330948,3.700439718141092,7.03342300153745,5.044394119358453,2.584962500721156,5.906890595608519,1.0,null,null,1.0,0.0,null,null,null,null,0.0,1.584962500721156,null,2.0,null,6.569855608330948,7.169925001442312,5.285402218862249,5.754887502163468,5.129283016944966,4.459431618637297,5.129283016944966,5.700439718141092,6.672425341971495,4.459431618637297,6.108524456778169,4.584962500721156,2.321928094887362,5.954196310386875,7.3750394313469245,6.507794640198696,5.672425341971495,5.044394119358453,3.807354922057604,4.807354922057604,5.584962500721156,5.643856189774724,4.754887502163468,4.087462841250339,4.906890595608519,5.285402218862249,3.700439718141092,6.087462841250339,8.39231742277876,8.430452551665532,6.475733430966398,6.321928094887363,5.554588851677638,5.426264754702098,6.321928094887363,6.442943495848728,7.011227255423254,5.584962500721156,7.044394119358453,6.20945336562895,1.584962500721156,6.894817763307944,1.0,8.479780264029099,6.539158811108031,7.348728154231077,6.108524456778169,6.426264754702098,6.94251450533924,7.442943495848728,7.442943495848728,6.643856189774724,7.475733430966398,6.392317422778761,3.169925001442312,7.679480099505446,10.116343961237469,9.29920801838728,8.422064766172813,8.087462841250339,6.569855608330948,6.965784284662087,7.679480099505446,8.400879436282183,7.94251450533924,7.523561956057013,8.451211111832329,7.189824558880018,4.807354922057604,8.417852514885897,9.0,8.118941072723507,7.22881869049588,6.894817763307944,5.954196310386875,5.857980995127572,6.845490050944375,7.266786540694901,7.392317422778761,6.339850002884624,7.321928094887363,6.247927513443585,2.584962500721156,7.366322214245816,8.405141463136344,7.149747119504682,7.129283016944966,5.754887502163468,4.584962500721156,4.169925001442312,3.807354922057604,5.554588851677638,6.087462841250339,3.807354922057604,6.491853096329675,3.4594316186372973,2.584962500721156,6.539158811108031,8.479780264029099,7.954196310386875,6.022367813028454,6.426264754702098,5.523561956057013,4.754887502163468,5.807354922057604,5.426264754702098,6.845490050944375,4.0,6.700439718141092,5.954196310386875,3.321928094887362,6.189824558880018,10.151016538892248,9.634811050171718,8.62935662007961,8.46352437327118,6.714245517666122,6.658211482751795,7.918863237274595,7.721099188707185,8.622051819456376,7.219168520462161,8.640244936222345,7.6293566200796095,2.807354922057604,8.434628227636725,8.618385502258606,9.022367813028454,7.330916878114617,7.857980995127572,6.584962500721156,6.169925001442312,7.118941072723508,7.442943495848728,7.451211111832329,6.321928094887363,8.060695931687555,6.20945336562895,3.169925001442312,7.7481928495894605,5.857980995127572,7.400879436282184,5.285402218862249,5.643856189774724,4.700439718141092,2.584962500721156,4.700439718141092,4.321928094887363,6.169925001442312,2.321928094887362,6.820178962415188,4.857980995127572,3.0,5.285402218862249,null,null,null,1.584962500721156,null,null,null,null,null,1.0,null,0.0,0.0,null,7.936637939002571,8.199672344836364,6.321928094887363,6.754887502163468,5.643856189774724,5.392317422778761,6.149747119504682,6.459431618637297,7.294620748891627,5.807354922057604,7.247927513443585,5.614709844115208,1.584962500721156,6.882643049361842,8.974414589805527,8.618385502258606,7.3750394313469245,7.531381460516312,6.189824558880018,5.614709844115208,6.599912842187128,7.05528243550119,7.882643049361842,5.700439718141092,8.005624549193879,6.087462841250339,2.0,7.219168520462161,8.179909090014934,8.174925682500678,6.392317422778761,6.22881869049588,5.727920454563199,3.321928094887362,5.727920454563199,5.129283016944966,6.954196310386875,4.0,7.129283016944966,5.247927513443585,4.584962500721156,5.954196310386875,5.857980995127572,8.011227255423254,4.459431618637297,7.531381460516312,3.700439718141092,4.0,6.741466986401147,5.0,3.0,4.0,4.459431618637297,6.6865005271832185,null,4.643856189774724,7.900866807980749,8.071462362556623,6.108524456778169,5.954196310386875,6.022367813028454,4.954196310386875,5.727920454563199,5.459431618637297,7.044394119358453,4.321928094887363,7.011227255423254,6.087462841250339,3.9068905956085187,6.087462841250339,6.94251450533924,7.721099188707185,5.087462841250339,5.857980995127572,5.087462841250339,4.459431618637297,5.169925001442312,5.832890014164741,7.076815597050831,5.044394119358453,6.108524456778169,4.392317422778761,1.584962500721156,5.882643049361842,10.320800548881637,9.41574176829009,8.79766152585376,8.103287808412022,7.149747119504682,7.392317422778761,7.6293566200796095,8.271463027904375,8.507794640198696,7.539158811108031,8.312882955284355,7.348728154231077,5.087462841250339,8.413627929024173,8.087462841250339,8.467605550082997,6.266786540694901,7.05528243550119,6.087462841250339,6.108524456778169,6.599912842187128,6.94251450533924,7.693486957499325,6.066089190457772,7.3750394313469245,6.569855608330948,4.523561956057013,7.266786540694901,7.577428828035749,8.103287808412022,6.247927513443585,6.539158811108031,5.672425341971495,5.169925001442312,6.357552004618084,6.285402218862249,6.954196310386875,5.357552004618084,7.321928094887363,5.357552004618084,3.584962500721156,6.754887502163468,7.820178962415188,8.379378367071261,6.807354922057604,6.6293566200796095,5.700439718141092,5.20945336562895,6.475733430966398,6.78135971352466,7.312882955284356,4.807354922057604,7.339850002884624,6.339850002884624,3.169925001442312,6.714245517666122,6.882643049361842,7.6293566200796095,5.554588851677638,5.832890014164741,4.857980995127572,4.087462841250339,6.022367813028454,5.584962500721156,6.820178962415188,4.0,6.894817763307944,5.169925001442312,3.9068905956085187,5.906890595608519,null,null,0.0,0.0,null,null,null,0.0,null,null,0.0,1.0,2.584962500721156,null,8.280770770130603,7.78135971352466,6.599912842187128,6.044394119358453,4.754887502163468,4.321928094887363,5.614709844115208,6.066089190457772,6.672425341971495,5.044394119358453,6.741466986401147,5.20945336562895,null,6.554588851677638,7.434628227636725,8.632995197142957,6.3750394313469245,6.614709844115208,5.954196310386875,4.0,5.906890595608519,5.614709844115208,7.569855608330948,4.392317422778761,7.636624620543649,5.584962500721156,2.321928094887362,6.392317422778761,7.2761244052742375,7.794415866350106,5.807354922057604,6.266786540694901,3.321928094887362,4.857980995127572,5.321928094887363,5.426264754702098,6.6293566200796095,4.459431618637297,6.459431618637297,4.169925001442312,2.0,5.672425341971495,9.519636252843213,9.537218400538595,8.614709844115207,8.857980995127573,7.417852514885898,7.727920454563199,7.960001932068081,8.679480099505446,7.857980995127572,7.936637939002571,8.271463027904375,7.330916878114617,3.4594316186372973,9.025139562278508,7.9886846867721655,7.562242424221073,6.78135971352466,6.22881869049588,5.169925001442312,4.954196310386875,6.169925001442312,5.643856189774724,6.303780748177103,5.0,6.845490050944375,5.247927513443585,3.321928094887362,6.108524456778169,9.224001674198105,8.870364719583405,7.78135971352466,7.693486957499325,5.857980995127572,6.108524456778169,6.918863237274595,7.0,7.78135971352466,6.129283016944966,7.459431618637297,6.20945336562895,3.4594316186372973,7.569855608330948,9.887220615468385,8.854868383260236,8.124121311829187,7.189824558880018,6.6865005271832185,6.672425341971495,7.189824558880018,7.584962500721156,7.392317422778761,6.599912842187128,8.124121311829187,6.643856189774724,3.0,7.78135971352466,8.459431618637296,8.573647187493322,7.20945336562895,7.247927513443585,5.882643049361842,6.20945336562895,7.285402218862249,7.622051819456376,7.442943495848728,6.392317422778761,7.531381460516312,6.906890595608519,4.0,7.679480099505446,8.948367231584678,8.271463027904375,6.9886846867721655,7.0,5.672425341971495,5.285402218862249,6.614709844115208,6.409390936137702,7.3750394313469245,4.954196310386875,7.098032082960526,6.129283016944966,2.584962500721156,7.011227255423254,8.550746785383243,9.03342300153745,7.2384047393250786,7.266786540694901,6.357552004618084,6.491853096329675,7.366322214245816,7.7615512324444795,7.924812503605781,6.266786540694901,8.108524456778168,7.285402218862249,3.321928094887362,8.049848549450562,6.3750394313469245,7.584962500721156,5.491853096329675,6.247927513443585,4.584962500721156,4.0,4.754887502163468,5.087462841250339,6.459431618637297,3.169925001442312,6.266786540694901,3.4594316186372973,5.357552004618084,5.321928094887363,null,null,null,null,null,null,null,null,null,1.0,2.0,null,0.0,null,9.324180546618742,8.78135971352466,7.794415866350106,7.149747119504682,6.303780748177103,5.584962500721156,7.076815597050831,7.149747119504682,8.124121311829187,5.643856189774724,8.154818109052105,7.022367813028454,2.584962500721156,7.459431618637297,8.588714635582264,8.139551352398794,6.78135971352466,6.442943495848728,5.392317422778761,5.321928094887363,6.0,6.22881869049588,7.011227255423254,5.285402218862249,7.05528243550119,5.727920454563199,3.169925001442312,6.714245517666122,8.144658242831882,8.74819284958946,6.906890595608519,6.700439718141092,6.22881869049588,5.754887502163468,6.507794640198696,6.392317422778761,7.6293566200796095,5.977279923499917,8.285402218862249,6.087462841250339,3.0,7.044394119358453,5.20945336562895,7.700439718141092,4.523561956057013,5.954196310386875,5.392317422778761,4.523561956057013,5.491853096329675,5.78135971352466,5.78135971352466,3.584962500721156,6.392317422778761,4.906890595608519,2.0,6.149747119504682,5.882643049361842,6.6293566200796095,4.906890595608519,4.523561956057013,4.523561956057013,3.321928094887362,4.169925001442312,5.044394119358453,5.614709844115208,3.321928094887362,4.459431618637297,3.584962500721156,4.169925001442312,4.523561956057013,9.912889336229961,8.912889336229961,8.388017285345136,7.475733430966398,6.3750394313469245,6.149747119504682,7.383704292474052,7.700439718141092,7.845490050944375,6.78135971352466,8.060695931687555,6.78135971352466,4.700439718141092,8.066089190457772,8.276124405274238,8.707359132080883,7.098032082960526,6.584962500721156,5.807354922057604,5.832890014164741,6.94251450533924,7.044394119358453,7.257387842692652,5.285402218862249,7.787902559391432,5.832890014164741,2.584962500721156,7.199672344836364,6.6293566200796095,7.515699838284043,5.554588851677638,5.392317422778761,5.426264754702098,4.247927513443585,5.129283016944966,5.169925001442312,6.108524456778169,4.584962500721156,6.426264754702098,5.554588851677638,3.0,6.066089190457772,8.98299357469431,8.49585502688717,7.285402218862249,6.569855608330948,5.954196310386875,5.392317422778761,6.6865005271832185,6.491853096329675,7.118941072723508,5.459431618637297,6.857980995127572,6.459431618637297,5.129283016944966,7.087462841250339,8.851749041416058,8.778077129535358,7.118941072723508,6.672425341971495,5.727920454563199,4.584962500721156,5.857980995127572,6.044394119358453,8.044394119358454,5.554588851677638,7.357552004618084,5.727920454563199,2.0,6.714245517666122,7.294620748891627,7.499845887083206,5.554588851677638,5.357552004618084,4.643856189774724,2.0,4.807354922057604,5.0,6.820178962415188,3.807354922057604,6.108524456778169,4.169925001442312,2.0,5.0,0.0,null,0.0,0.0,0.0,0.0,null,null,null,0.0,0.0,0.0,2.0,null,9.44086916761087,8.945443836377912,7.7073591320808825,7.044394119358453,6.285402218862249,6.285402218862249,6.754887502163468,7.087462841250339,8.098032082960527,6.066089190457772,8.228818690495881,6.108524456778169,3.0,7.562242424221073,7.994353436858858,8.108524456778168,6.357552004618084,6.491853096329675,5.20945336562895,4.754887502163468,6.022367813028454,6.087462841250339,7.129283016944966,5.321928094887363,7.257387842692652,4.807354922057604,3.0,6.459431618637297,8.467605550082997,8.204571144249204,6.741466986401147,6.189824558880018,5.584962500721156,5.247927513443585,6.0,5.727920454563199,7.189824558880018,4.857980995127572,7.139551352398794,5.392317422778761,3.0,6.584962500721156,3.4594316186372973,9.276124405274238,7.159871336778389,8.087462841250339,6.807354922057604,6.714245517666122,7.622051819456376,7.900866807980749,7.845490050944375,7.257387842692652,8.20945336562895,7.03342300153745,3.700439718141092,8.199672344836364,9.505811553919594,8.906890595608518,7.807354922057604,7.03342300153745,6.044394119358453,6.357552004618084,6.266786540694901,7.266786540694901,7.839203788096944,6.807354922057604,7.467605550082998,6.189824558880018,4.523561956057013,7.05528243550119,10.857203471508166,9.698704666770345,9.556506054671928,8.357552004618084,6.930737337562887,7.826548487290915,8.247927513443585,9.219168520462162,8.03342300153745,7.60733031374961,7.7481928495894605,7.118941072723508,3.9068905956085187,8.86418614465428,8.550746785383243,8.308339030139408,7.199672344836364,6.3750394313469245,4.700439718141092,4.392317422778761,5.426264754702098,6.554588851677638,6.189824558880018,5.727920454563199,6.066089190457772,5.321928094887363,3.4594316186372973,6.741466986401147,4.247927513443585,3.4594316186372973,3.321928094887362,1.0,2.0,0.0,null,null,3.321928094887362,null,3.807354922057604,null,null,null,10.303780748177102,9.417852514885897,8.936637939002571,7.820178962415188,6.768184324776926,7.066089190457772,7.592457037268081,8.011227255423254,8.087462841250339,7.247927513443585,8.682994583681683,7.321928094887363,2.0,8.224001674198105,6.727920454563199,7.348728154231077,5.129283016944966,5.554588851677638,4.857980995127572,4.087462841250339,4.392317422778761,4.523561956057013,6.303780748177103,4.643856189774724,6.857980995127572,4.459431618637297,1.584962500721156,5.491853096329675,8.876516946565,8.31741261376487,7.20945336562895,6.22881869049588,5.977279923499917,5.285402218862249,6.20945336562895,6.569855608330948,6.977279923499917,5.129283016944966,6.906890595608519,6.044394119358453,2.0,6.741466986401147,null,null,null,0.0,null,0.0,null,null,0.0,null,null,null,2.321928094887362,null,7.3750394313469245,6.523561956057013,5.614709844115208,5.247927513443585,4.459431618637297,4.392317422778761,4.807354922057604,5.643856189774724,5.169925001442312,4.169925001442312,5.321928094887363,4.857980995127572,2.321928094887362,5.426264754702098,8.965784284662087,8.199672344836364,7.1799090900149345,7.451211111832329,5.857980995127572,5.672425341971495,6.459431618637297,7.199672344836364,6.906890595608519,6.247927513443585,6.459431618637297,6.672425341971495,2.584962500721156,7.159871336778389,8.562242424221072,7.714245517666122,6.700439718141092,6.6293566200796095,5.044394119358453,5.700439718141092,5.672425341971495,6.857980995127572,5.321928094887363,4.754887502163468,5.643856189774724,5.78135971352466,2.0,6.6293566200796095,3.807354922057604,9.49585502688717,8.03342300153745,8.703903573444663,7.257387842692652,7.592457037268081,8.483815777264256,9.025139562278508,8.164906926675688,8.224001674198105,7.906890595608519,7.562242424221073,4.523561956057013,9.100662339005199,9.394462694610317,9.64565843240871,8.366322214245816,7.768184324776926,6.569855608330948,7.118941072723508,7.794415866350106,8.447083226209653,7.554588851677638,7.734709620225838,7.366322214245816,7.409390936137702,3.584962500721156,8.546894459887637,10.61194694181998,9.786269627648466,9.250298417906333,8.285402218862249,6.882643049361842,8.43879185257826,8.164906926675688,9.233619676759702,7.882643049361842,7.7615512324444795,7.022367813028454,7.888743248898259,4.087462841250339,8.727920454563199,9.605479518061669,9.079484783826816,8.366322214245816,7.507794640198696,6.20945336562895,6.6865005271832185,7.149747119504682,7.592457037268081,6.727920454563199,6.794415866350106,6.507794640198696,6.768184324776926,3.169925001442312,7.882643049361842,8.778077129535358,9.20212382383046,7.918863237274595,7.643856189774724,6.6293566200796095,6.78135971352466,7.409390936137702,7.864186144654281,6.894817763307944,6.475733430966398,7.098032082960526,6.954196310386875,1.584962500721156,8.20945336562895,9.319672120946995,8.800899899920305,8.169925001442312,7.366322214245816,6.247927513443585,6.507794640198696,7.087462841250339,7.592457037268081,6.507794640198696,6.599912842187128,6.523561956057013,6.894817763307944,3.584962500721156,7.864186144654281,9.51175265376738,8.721099188707186,8.108524456778168,7.219168520462161,5.78135971352466,6.129283016944966,6.741466986401147,7.348728154231077,6.475733430966398,6.321928094887363,6.409390936137702,6.820178962415188,2.584962500721156,7.7481928495894605,7.562242424221073,7.845490050944375,6.475733430966398,6.507794640198696,5.285402218862249,5.0,5.954196310386875,6.303780748177103,5.807354922057604,5.357552004618084,5.0,5.672425341971495,3.169925001442312,6.3750394313469245,null,null,null,0.0,null,null,null,0.0,null,0.0,null,null,1.0,null,8.271463027904375,7.700439718141092,6.754887502163468,6.357552004618084,4.459431618637297,5.700439718141092,6.303780748177103,6.357552004618084,5.754887502163468,5.392317422778761,5.459431618637297,5.614709844115208,2.0,6.918863237274595,8.228818690495881,8.475733430966399,7.066089190457772,7.434628227636725,6.044394119358453,5.426264754702098,6.658211482751795,7.303780748177103,6.169925001442312,6.189824558880018,6.426264754702098,5.700439718141092,4.247927513443585,7.383704292474052,7.622051819456376,7.03342300153745,6.149747119504682,5.906890595608519,4.523561956057013,4.643856189774724,5.523561956057013,5.672425341971495,5.20945336562895,3.9068905956085187,4.754887502163468,5.044394119358453,2.0,5.954196310386875,10.79603960882977,9.7714894695006,9.523561956057012,8.997179480937621,7.864186144654281,8.169925001442312,8.710806433699352,9.326429487122303,8.599912842187127,8.467605550082997,7.888743248898259,8.344295907915816,4.459431618637297,9.449148645375436,8.39231742277876,7.882643049361842,7.2384047393250786,6.459431618637297,4.523561956057013,5.426264754702098,6.22881869049588,6.523561956057013,5.857980995127572,5.807354922057604,6.0,5.643856189774724,3.807354922057604,7.0,9.377210530388552,9.20945336562895,7.876516946564999,7.954196310386875,6.845490050944375,6.906890595608519,7.754887502163468,8.219168520462162,6.9886846867721655,7.219168520462161,7.832890014164741,7.339850002884624,3.9068905956085187,8.523561956057012,9.709083812550343,8.700439718141093,8.238404739325079,7.118941072723508,5.906890595608519,6.94251450533924,7.199672344836364,7.807354922057604,6.977279923499917,6.392317422778761,6.357552004618084,6.906890595608519,3.321928094887362,7.562242424221073,9.682994583681683,8.909893083770042,8.092757140919852,7.05528243550119,5.832890014164741,6.6865005271832185,7.366322214245816,7.700439718141092,6.727920454563199,6.087462841250339,7.05528243550119,6.906890595608519,3.584962500721156,8.108524456778168,null,1.584962500721156,null,1.0,null,null,1.0,1.0,0.0,null,null,null,null,1.0,7.832890014164741,8.233619676759702,6.882643049361842,6.741466986401147,5.459431618637297,5.930737337562887,6.0,7.312882955284356,6.392317422778761,6.303780748177103,6.459431618637297,6.442943495848728,3.321928094887362,7.266786540694901,6.918863237274595,5.672425341971495,5.169925001442312,4.954196310386875,2.807354922057604,3.321928094887362,4.700439718141092,5.129283016944966,5.129283016944966,4.584962500721156,4.906890595608519,3.9068905956085187,2.807354922057604,5.584962500721156,null,null,null,null,null,null,null,null,null,null,null,null,0.0,null,7.467605550082998,7.807354922057604,6.321928094887363,6.507794640198696,5.087462841250339,5.643856189774724,6.3750394313469245,6.882643049361842,6.0,5.426264754702098,6.0,5.906890595608519,3.807354922057604,7.0,9.041659151637214,7.800899899920305,7.0,6.768184324776926,5.491853096329675,5.882643049361842,6.523561956057013,7.189824558880018,6.285402218862249,5.882643049361842,6.507794640198696,6.20945336562895,2.321928094887362,7.339850002884624,5.584962500721156,5.0,4.247927513443585,3.4594316186372973,1.0,3.0,3.169925001442312,2.584962500721156,3.0,2.584962500721156,3.4594316186372973,2.321928094887362,2.0,3.321928094887362,8.965784284662087,8.483815777264256,7.219168520462161,7.491853096329675,6.3750394313469245,5.954196310386875,6.584962500721156,6.392317422778761,7.845490050944375,5.087462841250339,8.375039431346925,6.247927513443585,2.807354922057604,7.348728154231077,8.353146825498083,8.224001674198105,7.357552004618084,6.614709844115208,6.066089190457772,5.882643049361842,6.022367813028454,6.78135971352466,7.03342300153745,4.857980995127572,7.693486957499325,5.727920454563199,1.584962500721156,7.257387842692652,8.558420713268664,8.144658242831882,7.169925001442312,6.614709844115208,5.672425341971495,4.643856189774724,5.614709844115208,6.044394119358453,6.727920454563199,4.906890595608519,6.807354922057604,6.066089190457772,3.584962500721156,6.442943495848728,6.918863237274595,7.60733031374961,6.022367813028454,6.339850002884624,5.426264754702098,4.807354922057604,5.523561956057013,5.584962500721156,6.303780748177103,4.700439718141092,6.714245517666122,4.523561956057013,3.169925001442312,6.20945336562895,8.64745842645492,8.588714635582264,7.05528243550119,6.20945336562895,5.754887502163468,5.727920454563199,6.303780748177103,6.392317422778761,7.523561956057013,5.584962500721156,7.98299357469431,6.247927513443585,1.584962500721156,6.845490050944375,8.960001932068081,7.948367231584678,7.426264754702098,6.870364719583405,6.066089190457772,5.882643049361842,6.303780748177103,6.870364719583405,6.491853096329675,5.930737337562887,6.189824558880018,5.614709844115208,3.807354922057604,7.266786540694901,null,7.820178962415188,null,5.727920454563199,2.321928094887362,7.129283016944966,5.857980995127572,8.098032082960527,0.0,7.20945336562895,null,5.392317422778761,null,2.0,8.243173983472952,9.095397022792557,7.294620748891627,7.515699838284043,6.339850002884624,6.087462841250339,7.087462841250339,7.339850002884624,8.169925001442312,5.754887502163468,8.118941072723507,7.0,1.584962500721156,7.636624620543649,9.832890014164741,8.906890595608518,8.741466986401146,7.531381460516312,6.807354922057604,7.03342300153745,7.400879436282184,7.864186144654281,6.870364719583405,6.475733430966398,6.965784284662087,7.066089190457772,3.4594316186372973,7.857980995127572,7.6865005271832185,8.383704292474052,6.794415866350106,6.658211482751795,5.882643049361842,5.087462841250339,6.392317422778761,6.321928094887363,6.882643049361842,6.066089190457772,7.098032082960526,6.491853096329675,4.247927513443585,6.584962500721156,9.988684686772165,9.005624549193879,8.721099188707186,7.257387842692652,6.741466986401147,7.247927513443585,7.636624620543649,7.912889336229962,6.426264754702098,6.845490050944375,7.022367813028454,7.6293566200796095,3.700439718141092,8.357552004618084,9.162391328756906,8.787902559391432,7.491853096329675,7.022367813028454,6.754887502163468,6.149747119504682,6.754887502163468,7.169925001442312,7.721099188707185,6.0,8.092757140919852,6.882643049361842,5.0,7.515699838284043,8.661778097771988,8.266786540694902,7.159871336778389,6.741466986401147,5.882643049361842,5.044394119358453,5.727920454563199,6.266786540694901,7.3750394313469245,4.392317422778761,7.011227255423254,6.523561956057013,1.584962500721156,7.076815597050831,9.370687406807217,8.900866807980748,8.055282435501189,7.2384047393250786,5.954196310386875,6.066089190457772,6.857980995127572,7.139551352398794,7.78135971352466,6.022367813028454,8.375039431346925,6.554588851677638,4.169925001442312,7.6293566200796095,7.409390936137702,8.055282435501189,6.169925001442312,6.108524456778169,5.491853096329675,5.20945336562895,5.584962500721156,5.930737337562887,6.672425341971495,4.700439718141092,6.539158811108031,5.584962500721156,2.807354922057604,6.022367813028454,8.73809225962049,8.661778097771988,7.918863237274595,6.714245517666122,6.807354922057604,5.954196310386875,6.392317422778761,6.832890014164741,7.426264754702098,5.857980995127572,7.813781191217037,6.20945336562895,2.0,8.184875342908283,8.96289600533726,9.08214904135387,7.539158811108031,7.60733031374961,6.584962500721156,6.554588851677638,7.044394119358453,7.285402218862249,7.794415866350106,5.954196310386875,8.321928094887362,6.3750394313469245,3.321928094887362,7.894817763307944,8.948367231584678,9.199672344836364,7.845490050944375,7.614709844115208,6.643856189774724,6.22881869049588,7.044394119358453,7.169925001442312,7.839203788096944,6.672425341971495,7.794415866350106,6.9886846867721655,2.807354922057604,7.651051691178929,8.744833837499545,8.813781191217037,7.636624620543649,7.491853096329675,6.169925001442312,6.129283016944966,6.794415866350106,6.845490050944375,7.169925001442312,6.303780748177103,6.882643049361842,6.475733430966398,2.807354922057604,7.672425341971495,9.13699111208023,8.658211482751796,7.948367231584678,6.965784284662087,6.3750394313469245,5.643856189774724,6.523561956057013,6.475733430966398,7.562242424221073,5.832890014164741,7.6653359171851765,6.426264754702098,2.0,7.312882955284356,9.967226258835993,9.46352437327118,8.977279923499916,7.679480099505446,7.03342300153745,7.022367813028454,7.05528243550119,7.554588851677638,8.134426320220927,7.076815597050831,8.409390936137703,7.303780748177103,2.584962500721156,7.845490050944375,9.868822554774999,9.129283016944967,8.611024797307353,7.584962500721156,6.894817763307944,6.741466986401147,6.930737337562887,7.219168520462161,8.049848549450562,6.339850002884624,8.154818109052105,6.954196310386875,3.169925001442312,8.076815597050832,9.442943495848729,8.774787059601174,8.049848549450562,7.149747119504682,6.149747119504682,6.426264754702098,6.442943495848728,7.257387842692652,7.199672344836364,6.3750394313469245,7.592457037268081,6.754887502163468,2.584962500721156,7.199672344836364,8.550746785383243,9.047123912114026,7.569855608330948,7.312882955284356,7.108524456778169,6.108524456778169,7.05528243550119,7.426264754702098,8.751544059089099,5.643856189774724,8.550746785383243,7.2761244052742375,4.392317422778761,7.643856189774724,5.426264754702098,7.546894459887636,3.700439718141092,6.459431618637297,2.321928094887362,2.321928094887362,6.20945336562895,3.807354922057604,3.807354922057604,2.584962500721156,4.459431618637297,5.78135971352466,null,2.321928094887362,8.092757140919852,8.67595703294175,6.94251450533924,6.727920454563199,6.189824558880018,5.357552004618084,6.700439718141092,6.149747119504682,7.857980995127572,6.066089190457772,7.936637939002571,6.584962500721156,1.0,7.199672344836364,8.475733430966399,7.977279923499917,7.0,6.285402218862249,5.614709844115208,5.20945336562895,5.614709844115208,6.129283016944966,6.94251450533924,5.491853096329675,6.539158811108031,5.392317422778761,3.9068905956085187,6.20945336562895,8.654636028527968,8.129283016944967,6.845490050944375,6.303780748177103,5.584962500721156,5.426264754702098,6.066089190457772,6.554588851677638,7.129283016944966,5.044394119358453,8.022367813028454,5.977279923499917,3.9068905956085187,6.754887502163468,8.784634845557521,9.273795599214264,7.592457037268081,7.78135971352466,6.554588851677638,5.954196310386875,7.129283016944966,7.451211111832329,8.03342300153745,6.409390936137702,8.154818109052105,7.22881869049588,2.321928094887362,7.569855608330948,10.462502272597265,9.52943055414615,9.111135670234708,8.62935662007961,7.247927513443585,7.22881869049588,7.924812503605781,8.169925001442312,8.303780748177102,7.076815597050831,8.507794640198696,7.658211482751795,4.087462841250339,8.584962500721156,8.426264754702098,8.845490050944376,7.658211482751795,7.442943495848728,6.426264754702098,6.22881869049588,6.714245517666122,7.266786540694901,7.426264754702098,6.820178962415188,7.467605550082998,6.491853096329675,2.321928094887362,7.577428828035749,10.071462362556623,9.361943773735241,8.791162888555018,8.071462362556623,7.05528243550119,6.285402218862249,7.011227255423254,7.531381460516312,8.344295907915816,6.658211482751795,8.179909090014934,7.189824558880018,5.954196310386875,8.016808287686555,10.019590728357882,9.407267764244732,8.791162888555018,7.599912842187128,7.066089190457772,6.599912842187128,7.348728154231077,7.426264754702098,8.087462841250339,6.442943495848728,8.625708843064466,7.330916878114617,3.0,7.924812503605781,9.717676423066395,9.923327485419192,8.744833837499545,8.214319120800766,7.426264754702098,7.714245517666122,7.977279923499917,8.262094845370179,8.276124405274238,7.483815777264256,8.76487159073609,7.658211482751795,1.584962500721156,8.62935662007961,9.842350343413807,9.266786540694902,8.467605550082997,7.531381460516312,6.754887502163468,6.442943495848728,7.118941072723508,7.139551352398794,7.930737337562887,6.169925001442312,7.912889336229962,7.0,2.321928094887362,7.426264754702098,8.531381460516313,8.751544059089099,7.159871336778389,7.129283016944966,6.442943495848728,6.442943495848728,6.672425341971495,6.491853096329675,7.794415866350106,5.754887502163468,8.149747119504681,6.658211482751795,1.584962500721156,7.434628227636725,7.807354922057604,7.459431618637297,6.22881869049588,5.930737337562887,5.285402218862249,4.523561956057013,4.807354922057604,5.169925001442312,5.700439718141092,4.169925001442312,6.741466986401147,5.044394119358453,null,5.643856189774724,7.832890014164741,7.599912842187128,6.303780748177103,5.906890595608519,5.247927513443585,4.169925001442312,4.392317422778761,4.906890595608519,6.22881869049588,3.321928094887362,7.2384047393250786,4.169925001442312,1.584962500721156,5.977279923499917,6.870364719583405,7.531381460516312,5.554588851677638,4.954196310386875,4.700439718141092,3.584962500721156,5.169925001442312,5.247927513443585,6.475733430966398,4.643856189774724,6.321928094887363,5.357552004618084,3.9068905956085187,5.087462841250339,8.379378367071261,7.219168520462161,6.794415866350106,6.189824558880018,4.807354922057604,5.0,5.392317422778761,6.20945336562895,5.906890595608519,4.700439718141092,5.954196310386875,5.247927513443585,2.807354922057604,6.20945336562895,8.321928094887362,8.483815777264256,6.930737337562887,7.0,6.189824558880018,6.149747119504682,6.807354922057604,6.930737337562887,7.700439718141092,6.169925001442312,8.071462362556623,6.569855608330948,4.247927513443585,6.94251450533924,9.379378367071261,8.499845887083206,7.577428828035749,6.714245517666122,5.832890014164741,6.266786540694901,6.754887502163468,6.965784284662087,7.714245517666122,6.0,7.20945336562895,6.357552004618084,2.0,7.451211111832329,8.076815597050832,8.76487159073609,7.22881869049588,7.539158811108031,6.189824558880018,6.189824558880018,6.820178962415188,6.870364719583405,7.643856189774724,6.044394119358453,8.257387842692651,6.409390936137702,3.807354922057604,7.6653359171851765,9.060695931687555,9.245552706255681,7.912889336229962,7.60733031374961,7.011227255423254,6.459431618637297,7.20945336562895,7.592457037268081,8.413627929024173,6.614709844115208,8.409390936137703,7.523561956057013,3.169925001442312,7.888743248898259,8.839203788096944,8.098032082960527,6.9886846867721655,6.614709844115208,5.754887502163468,5.20945336562895,6.0,6.459431618637297,6.906890595608519,5.491853096329675,7.614709844115208,6.169925001442312,4.169925001442312,6.672425341971495,7.851749041416057,8.129283016944967,6.6293566200796095,6.022367813028454,5.832890014164741,4.906890595608519,5.954196310386875,6.20945336562895,6.584962500721156,5.20945336562895,7.066089190457772,5.523561956057013,2.321928094887362,6.768184324776926,9.216745858195306,8.717676423066395,7.700439718141092,6.768184324776926,5.977279923499917,5.930737337562887,6.569855608330948,6.882643049361842,7.3750394313469245,5.087462841250339,7.614709844115208,6.189824558880018,2.584962500721156,7.149747119504682,9.335390354693924,9.00842862207058,7.6653359171851765,7.366322214245816,6.882643049361842,5.584962500721156,6.94251450533924,6.857980995127572,8.214319120800766,6.20945336562895,8.569855608330949,6.614709844115208,4.321928094887363,7.139551352398794,8.507794640198696,8.03342300153745,6.266786540694901,6.3750394313469245,6.169925001442312,5.0,5.954196310386875,6.149747119504682,7.05528243550119,4.392317422778761,6.442943495848728,5.643856189774724,2.321928094887362,6.0,7.0,7.714245517666122,6.022367813028454,5.78135971352466,5.169925001442312,5.129283016944966,5.700439718141092,5.0,6.247927513443585,3.700439718141092,6.357552004618084,5.807354922057604,3.0,6.169925001442312,9.090112419664289,8.939579214314692,7.6293566200796095,7.044394119358453,6.285402218862249,5.321928094887363,6.321928094887363,6.409390936137702,8.087462841250339,5.643856189774724,8.224001674198105,6.357552004618084,3.584962500721156,7.098032082960526,7.169925001442312,7.977279923499917,6.066089190457772,6.539158811108031,5.977279923499917,4.643856189774724,5.0,5.169925001442312,6.584962500721156,4.0,6.78135971352466,5.491853096329675,3.169925001442312,6.247927513443585,6.954196310386875,8.03342300153745,6.266786540694901,6.569855608330948,6.266786540694901,4.857980995127572,5.954196310386875,6.0,7.149747119504682,5.0,7.400879436282184,6.409390936137702,3.807354922057604,6.409390936137702,8.727920454563199,8.108524456778168,7.339850002884624,7.2384047393250786,6.247927513443585,5.584962500721156,5.906890595608519,6.285402218862249,7.108524456778169,4.906890595608519,7.426264754702098,6.339850002884624,4.392317422778761,6.768184324776926,8.50382573799575,9.20212382383046,7.339850002884624,7.672425341971495,7.149747119504682,5.977279923499917,6.807354922057604,6.672425341971495,8.169925001442312,6.22881869049588,8.842350343413807,6.523561956057013,4.087462841250339,7.531381460516312,8.174925682500678,8.980139577639157,7.348728154231077,7.2761244052742375,6.754887502163468,5.554588851677638,6.409390936137702,6.266786540694901,8.103287808412022,5.247927513443585,8.370687406807217,6.954196310386875,4.807354922057604,7.022367813028454,9.894817763307943,9.436711542137214,8.400879436282183,8.257387842692651,7.475733430966398,6.807354922057604,7.257387842692652,7.906890595608519,8.527477006060396,6.672425341971495,9.162391328756906,7.189824558880018,4.087462841250339,8.139551352398794,8.149747119504681,8.661778097771988,7.515699838284043,6.977279923499917,6.357552004618084,5.882643049361842,6.6293566200796095,6.714245517666122,7.434628227636725,5.247927513443585,7.523561956057013,6.507794640198696,2.584962500721156,7.467605550082998,8.044394119358454,8.758223214726724,6.977279923499917,7.285402218862249,6.20945336562895,6.189824558880018,6.614709844115208,6.94251450533924,7.977279923499917,6.459431618637297,8.118941072723507,6.768184324776926,0.0,7.303780748177103,9.044394119358454,8.778077129535358,7.330916878114617,6.832890014164741,6.475733430966398,5.491853096329675,6.303780748177103,6.3750394313469245,7.754887502163468,5.754887502163468,8.204571144249204,6.357552004618084,4.700439718141092,7.1799090900149345,8.071462362556623,8.257387842692651,6.672425341971495,6.554588851677638,5.491853096329675,5.857980995127572,6.523561956057013,6.700439718141092,7.20945336562895,5.044394119358453,7.546894459887636,6.321928094887363,3.4594316186372973,6.539158811108031,7.3750394313469245,7.442943495848728,5.807354922057604,5.614709844115208,5.129283016944966,4.459431618637297,4.169925001442312,4.321928094887363,6.339850002884624,4.754887502163468,5.977279923499917,4.584962500721156,1.584962500721156,5.247927513443585,6.965784284662087,7.912889336229962,5.977279923499917,6.044394119358453,5.129283016944966,4.392317422778761,5.285402218862249,5.087462841250339,6.426264754702098,3.9068905956085187,6.584962500721156,5.700439718141092,2.321928094887362,5.672425341971495,9.219168520462162,8.784634845557521,7.592457037268081,7.087462841250339,6.569855608330948,5.882643049361842,6.442943495848728,7.118941072723508,6.643856189774724,5.754887502163468,7.321928094887363,6.022367813028454,2.807354922057604,7.022367813028454,4.700439718141092,5.285402218862249,3.584962500721156,4.584962500721156,2.584962500721156,null,1.584962500721156,1.584962500721156,4.857980995127572,1.0,4.954196310386875,3.0,null,2.0,8.353146825498083,8.800899899920305,7.339850002884624,7.467605550082998,6.584962500721156,5.857980995127572,6.820178962415188,7.098032082960526,7.499845887083206,5.700439718141092,7.894817763307944,6.857980995127572,2.0,7.129283016944966,8.0,7.787902559391432,6.066089190457772,5.754887502163468,5.247927513443585,4.459431618637297,4.857980995127572,4.754887502163468,6.672425341971495,4.087462841250339,7.011227255423254,5.087462841250339,null,5.807354922057604,8.810571634741146,8.326429487122303,7.539158811108031,6.392317422778761,5.78135971352466,5.392317422778761,6.392317422778761,6.741466986401147,6.754887502163468,4.906890595608519,6.754887502163468,6.108524456778169,1.584962500721156,6.6293566200796095,8.98299357469431,8.005624549193879,7.531381460516312,7.03342300153745,5.672425341971495,5.930737337562887,6.22881869049588,7.05528243550119,6.189824558880018,5.523561956057013,6.426264754702098,6.303780748177103,1.584962500721156,7.312882955284356,7.599912842187128,8.016808287686555,6.768184324776926,6.614709844115208,5.78135971352466,6.087462841250339,6.409390936137702,6.832890014164741,6.768184324776926,5.491853096329675,7.03342300153745,6.321928094887363,4.247927513443585,7.05528243550119,8.204571144249204,8.31741261376487,7.2761244052742375,7.199672344836364,5.882643049361842,6.247927513443585,6.357552004618084,7.0,6.672425341971495,5.614709844115208,7.159871336778389,6.247927513443585,3.9068905956085187,7.330916878114617,9.149747119504681,8.290018846932618,7.658211482751795,7.2384047393250786,6.169925001442312,6.569855608330948,6.584962500721156,7.409390936137702,6.6293566200796095,6.149747119504682,6.954196310386875,6.044394119358453,2.584962500721156,7.800899899920305,8.784634845557521,7.7073591320808825,7.303780748177103,6.930737337562887,5.491853096329675,5.832890014164741,6.820178962415188,7.330916878114617,6.129283016944966,5.459431618637297,5.584962500721156,5.906890595608519,2.321928094887362,7.357552004618084,7.912889336229962,7.7481928495894605,6.768184324776926,6.918863237274595,5.930737337562887,5.169925001442312,6.741466986401147,6.700439718141092,6.022367813028454,4.954196310386875,6.189824558880018,6.0,2.584962500721156,7.199672344836364,6.442943495848728,6.303780748177103,4.584962500721156,5.614709844115208,3.0,4.906890595608519,4.807354922057604,5.459431618637297,4.087462841250339,4.169925001442312,3.9068905956085187,4.169925001442312,1.584962500721156,4.807354922057604,7.531381460516312,7.499845887083206,6.475733430966398,6.357552004618084,4.321928094887363,5.285402218862249,5.643856189774724,6.247927513443585,5.977279923499917,4.754887502163468,6.247927513443585,5.614709844115208,3.169925001442312,6.523561956057013,8.554588851677638,7.845490050944375,7.199672344836364,6.3750394313469245,5.426264754702098,5.754887502163468,6.066089190457772,6.321928094887363,5.672425341971495,4.954196310386875,6.459431618637297,6.357552004618084,3.321928094887362,6.6293566200796095,7.6865005271832185,8.092757140919852,7.118941072723508,6.807354922057604,5.832890014164741,5.954196310386875,6.189824558880018,6.714245517666122,6.442943495848728,5.754887502163468,6.442943495848728,5.584962500721156,3.584962500721156,7.189824558880018,9.802516365121223,8.88264304936184,8.353146825498083,8.022367813028454,6.20945336562895,6.832890014164741,7.2761244052742375,7.882643049361842,7.357552004618084,6.643856189774724,7.219168520462161,7.247927513443585,2.321928094887362,8.144658242831882,8.625708843064466,7.832890014164741,7.1799090900149345,6.491853096329675,5.459431618637297,5.643856189774724,6.044394119358453,6.247927513443585,6.044394119358453,5.954196310386875,6.022367813028454,5.392317422778761,2.584962500721156,7.139551352398794,8.73809225962049,7.936637939002571,7.108524456778169,6.78135971352466,5.584962500721156,5.832890014164741,6.20945336562895,6.569855608330948,6.339850002884624,5.643856189774724,6.149747119504682,6.0,3.321928094887362,7.348728154231077,8.651051691178928,8.710806433699352,7.787902559391432,7.339850002884624,6.321928094887363,6.832890014164741,7.139551352398794,7.693486957499325,6.700439718141092,6.459431618637297,6.409390936137702,6.475733430966398,2.321928094887362,7.700439718141092,9.294620748891626,8.43879185257826,7.960001932068081,7.467605550082998,5.727920454563199,6.20945336562895,6.507794640198696,7.098032082960526,6.392317422778761,6.266786540694901,6.044394119358453,6.554588851677638,3.169925001442312,7.383704292474052,9.4655664048094,8.573647187493322,8.20945336562895,7.022367813028454,6.339850002884624,6.475733430966398,6.977279923499917,7.383704292474052,6.392317422778761,6.6293566200796095,6.614709844115208,7.118941072723508,2.0,7.592457037268081,7.7615512324444795,7.924812503605781,6.954196310386875,6.426264754702098,5.882643049361842,5.426264754702098,6.442943495848728,7.087462841250339,5.906890595608519,5.977279923499917,5.459431618637297,6.22881869049588,2.0,7.2384047393250786,8.447083226209653,7.434628227636725,6.672425341971495,6.523561956057013,5.584962500721156,5.392317422778761,5.643856189774724,6.303780748177103,5.321928094887363,5.357552004618084,6.0,6.20945336562895,1.584962500721156,6.894817763307944,8.118941072723507,7.643856189774724,6.832890014164741,6.044394119358453,4.700439718141092,5.285402218862249,5.554588851677638,6.129283016944966,6.022367813028454,5.672425341971495,6.0,4.906890595608519,2.584962500721156,6.554588851677638,6.794415866350106,6.906890595608519,5.954196310386875,6.087462841250339,4.247927513443585,4.857980995127572,5.087462841250339,6.087462841250339,5.129283016944966,5.78135971352466,5.247927513443585,4.584962500721156,3.9068905956085187,6.303780748177103,8.383704292474052,7.491853096329675,6.700439718141092,5.754887502163468,5.129283016944966,5.426264754702098,6.169925001442312,6.523561956057013,5.491853096329675,5.459431618637297,6.554588851677638,6.247927513443585,3.169925001442312,7.066089190457772,5.643856189774724,4.0,3.321928094887362,2.0,1.584962500721156,2.807354922057604,2.584962500721156,3.0,0.0,1.0,1.584962500721156,2.584962500721156,0.0,3.4594316186372973,7.672425341971495,8.055282435501189,6.965784284662087,6.894817763307944,5.930737337562887,5.727920454563199,6.266786540694901,6.832890014164741,6.285402218862249,6.022367813028454,6.643856189774724,6.339850002884624,3.4594316186372973,7.409390936137702,7.94251450533924,6.741466986401147,6.539158811108031,5.807354922057604,4.459431618637297,4.954196310386875,5.247927513443585,5.977279923499917,5.0,4.906890595608519,5.0,4.754887502163468,0.0,5.977279923499917,8.348728154231077,8.321928094887362,7.442943495848728,7.330916878114617,5.700439718141092,6.339850002884624,6.794415866350106,7.20945336562895,6.426264754702098,5.614709844115208,6.285402218862249,6.189824558880018,2.0,7.507794640198696,7.971543553950772,8.108524456778168,7.159871336778389,6.977279923499917,6.129283016944966,5.754887502163468,6.20945336562895,6.6865005271832185,6.321928094887363,5.554588851677638,6.554588851677638,5.523561956057013,2.807354922057604,6.930737337562887,9.405141463136344,8.62935662007961,7.918863237274595,7.60733031374961,6.658211482751795,6.475733430966398,7.05528243550119,7.303780748177103,6.523561956057013,6.392317422778761,6.584962500721156,6.643856189774724,2.807354922057604,7.820178962415188,1.0,1.0,0.0,null,null,null,null,null,null,0.0,2.584962500721156,null,0.0,0.0,1.584962500721156,8.357552004618084,4.584962500721156,5.614709844115208,5.614709844115208,4.321928094887363,5.78135971352466,5.129283016944966,7.257387842692652,3.0,7.794415866350106,5.357552004618084,4.584962500721156,6.189824558880018,8.951284714966972,7.658211482751795,7.592457037268081,5.584962500721156,5.554588851677638,4.700439718141092,5.459431618637297,5.614709844115208,6.189824558880018,4.0,6.129283016944966,4.459431618637297,3.321928094887362,6.539158811108031,6.882643049361842,6.857980995127572,5.523561956057013,5.169925001442312,4.169925001442312,3.0,4.247927513443585,4.807354922057604,6.189824558880018,2.0,5.78135971352466,3.700439718141092,3.321928094887362,4.523561956057013,8.832890014164741,8.459431618637296,7.348728154231077,6.807354922057604,5.832890014164741,5.459431618637297,6.22881869049588,6.554588851677638,7.330916878114617,5.20945336562895,7.651051691178929,5.491853096329675,3.321928094887362,6.727920454563199,7.0,7.076815597050831,5.044394119358453,5.20945336562895,4.523561956057013,4.087462841250339,4.087462841250339,5.169925001442312,6.741466986401147,1.0,6.930737337562887,4.807354922057604,1.584962500721156,4.807354922057604,9.0,7.906890595608519,7.592457037268081,6.965784284662087,5.700439718141092,5.78135971352466,6.087462841250339,7.011227255423254,6.266786540694901,5.930737337562887,5.754887502163468,6.22881869049588,4.0,7.118941072723508,null,6.20945336562895,null,3.4594316186372973,null,6.129283016944966,3.169925001442312,6.700439718141092,null,5.857980995127572,1.0,2.584962500721156,1.0,null,8.303780748177102,8.523561956057012,6.643856189774724,6.727920454563199,6.149747119504682,4.584962500721156,6.22881869049588,5.930737337562887,7.768184324776926,4.700439718141092,8.219168520462162,6.0,4.523561956057013,6.066089190457772,8.339850002884624,8.59618975614441,7.475733430966398,7.189824558880018,5.977279923499917,6.6865005271832185,7.285402218862249,7.149747119504682,6.129283016944966,6.906890595608519,6.569855608330948,6.523561956057013,3.9068905956085187,7.851749041416057,8.72451385311995,8.257387842692651,7.20945336562895,6.3750394313469245,5.807354922057604,5.357552004618084,6.149747119504682,6.066089190457772,7.05528243550119,5.247927513443585,7.864186144654281,5.727920454563199,4.392317422778761,6.539158811108031,7.832890014164741,8.049848549450562,6.754887502163468,6.569855608330948,4.906890595608519,5.491853096329675,6.0,6.285402218862249,6.584962500721156,5.321928094887363,6.820178962415188,5.392317422778761,4.392317422778761,6.3750394313469245,7.303780748177103,8.262094845370179,6.741466986401147,5.672425341971495,5.643856189774724,5.20945336562895,5.906890595608519,6.339850002884624,6.965784284662087,5.169925001442312,6.894817763307944,6.169925001442312,2.0,6.554588851677638,9.417852514885897,8.189824558880018,7.693486957499325,6.303780748177103,6.20945336562895,4.0,5.832890014164741,5.491853096329675,6.9886846867721655,5.20945336562895,7.554588851677638,5.700439718141092,3.9068905956085187,7.2384047393250786,7.851749041416057,8.266786540694902,6.507794640198696,6.3750394313469245,5.0,5.169925001442312,5.906890595608519,6.169925001442312,7.312882955284356,5.285402218862249,7.22881869049588,5.807354922057604,3.321928094887362,6.475733430966398,8.566054038171092,8.682994583681683,6.977279923499917,6.658211482751795,6.22881869049588,5.0,5.807354922057604,5.459431618637297,7.044394119358453,4.754887502163468,7.569855608330948,6.6865005271832185,4.643856189774724,6.392317422778761,8.957102041562287,8.353146825498083,7.266786540694901,6.285402218862249,5.930737337562887,5.169925001442312,6.087462841250339,6.108524456778169,7.149747119504682,4.857980995127572,7.499845887083206,5.954196310386875,2.0,6.523561956057013,1.0,7.6865005271832185,5.129283016944966,5.20945336562895,5.392317422778761,3.321928094887362,5.426264754702098,4.857980995127572,6.832890014164741,3.321928094887362,7.087462841250339,5.087462841250339,4.169925001442312,5.832890014164741,7.800899899920305,8.873444112515376,7.066089190457772,6.714245517666122,6.285402218862249,5.459431618637297,6.78135971352466,6.539158811108031,7.622051819456376,5.554588851677638,8.149747119504681,6.266786540694901,4.807354922057604,6.700439718141092,4.807354922057604,8.243173983472952,4.321928094887363,7.044394119358453,2.321928094887362,2.0,6.614709844115208,4.0,4.169925001442312,2.584962500721156,4.459431618637297,6.087462841250339,null,3.169925001442312,9.994353436858859,9.303780748177102,8.774787059601174,7.562242424221073,6.954196310386875,6.459431618637297,7.169925001442312,7.076815597050831,8.357552004618084,6.129283016944966,8.348728154231077,6.832890014164741,3.9068905956085187,7.851749041416057,8.86418614465428,8.558420713268664,7.592457037268081,6.285402218862249,5.954196310386875,5.357552004618084,6.108524456778169,6.285402218862249,7.05528243550119,5.491853096329675,7.614709844115208,6.066089190457772,4.584962500721156,6.820178962415188,8.81698362325538,8.294620748891626,7.303780748177103,6.918863237274595,5.285402218862249,5.285402218862249,6.22881869049588,6.459431618637297,7.577428828035749,5.392317422778761,7.807354922057604,5.78135971352466,3.807354922057604,6.832890014164741,7.918863237274595,7.94251450533924,6.584962500721156,5.672425341971495,5.321928094887363,4.807354922057604,5.807354922057604,5.285402218862249,6.727920454563199,3.321928094887362,6.845490050944375,4.857980995127572,3.169925001442312,5.392317422778761,8.558420713268664,8.405141463136344,7.294620748891627,5.807354922057604,6.0,4.392317422778761,5.426264754702098,5.754887502163468,6.714245517666122,4.807354922057604,7.303780748177103,5.321928094887363,3.0,6.491853096329675,9.036173612553485,8.64745842645492,7.523561956057013,7.20945336562895,6.022367813028454,5.807354922057604,6.0,6.78135971352466,6.78135971352466,5.285402218862249,7.6293566200796095,6.169925001442312,4.754887502163468,6.658211482751795,6.906890595608519,7.734709620225838,6.169925001442312,5.906890595608519,5.426264754702098,4.459431618637297,4.754887502163468,5.044394119358453,6.614709844115208,3.584962500721156,6.189824558880018,4.857980995127572,1.584962500721156,6.0,7.546894459887636,8.321928094887362,6.569855608330948,6.087462841250339,5.614709844115208,4.321928094887363,4.754887502163468,5.357552004618084,6.409390936137702,3.169925001442312,6.918863237274595,5.169925001442312,4.954196310386875,5.584962500721156,7.515699838284043,8.361943773735241,6.845490050944375,6.22881869049588,5.614709844115208,5.614709844115208,6.066089190457772,6.357552004618084,6.321928094887363,4.754887502163468,7.554588851677638,6.044394119358453,3.584962500721156,6.643856189774724,8.467605550082997,8.535275376620802,7.321928094887363,6.392317422778761,5.882643049361842,5.044394119358453,5.459431618637297,5.882643049361842,6.599912842187128,5.614709844115208,7.05528243550119,5.523561956057013,3.700439718141092,6.459431618637297,8.154818109052105,8.370687406807217,6.954196310386875,5.672425341971495,5.426264754702098,4.807354922057604,5.906890595608519,5.426264754702098,6.700439718141092,3.4594316186372973,7.108524456778169,4.700439718141092,4.247927513443585,6.066089190457772,9.164906926675688,8.50382573799575,7.936637939002571,7.554588851677638,6.129283016944966,6.247927513443585,5.977279923499917,7.022367813028454,7.044394119358453,5.954196310386875,6.78135971352466,6.321928094887363,3.4594316186372973,7.22881869049588,7.794415866350106,7.499845887083206,6.523561956057013,5.491853096329675,5.20945336562895,4.169925001442312,5.247927513443585,5.129283016944966,6.442943495848728,4.584962500721156,5.614709844115208,4.643856189774724,2.321928094887362,5.459431618637297,7.864186144654281,8.066089190457772,6.965784284662087,6.78135971352466,5.459431618637297,5.584962500721156,5.930737337562887,6.569855608330948,6.569855608330948,4.754887502163468,7.159871336778389,5.754887502163468,1.0,6.491853096329675,8.022367813028454,8.968666793195208,7.531381460516312,7.285402218862249,6.247927513443585,5.727920454563199,6.700439718141092,6.845490050944375,7.129283016944966,6.303780748177103,7.022367813028454,6.22881869049588,2.321928094887362,7.118941072723508,9.131856960608793,8.81698362325538,7.459431618637297,6.339850002884624,6.108524456778169,5.129283016944966,6.392317422778761,6.022367813028454,7.2761244052742375,5.285402218862249,7.499845887083206,6.392317422778761,3.0,6.882643049361842,8.076815597050832,7.643856189774724,6.554588851677638,5.584962500721156,4.700439718141092,4.169925001442312,5.357552004618084,5.930737337562887,6.044394119358453,4.169925001442312,6.569855608330948,5.0,2.584962500721156,5.906890595608519,8.965784284662087,8.45532722030456,7.467605550082998,6.539158811108031,5.807354922057604,4.643856189774724,6.0,6.087462841250339,6.569855608330948,4.321928094887363,7.266786540694901,5.700439718141092,3.700439718141092,6.491853096329675,7.348728154231077,8.238404739325079,6.539158811108031,6.044394119358453,5.392317422778761,5.044394119358453,5.523561956057013,5.930737337562887,6.357552004618084,4.392317422778761,6.741466986401147,5.954196310386875,3.584962500721156,6.044394119358453,7.199672344836364,8.335390354693924,6.149747119504682,5.614709844115208,5.321928094887363,4.459431618637297,5.882643049361842,5.247927513443585,6.599912842187128,4.087462841250339,6.6293566200796095,4.807354922057604,3.9068905956085187,5.491853096329675,8.357552004618084,8.366322214245816,6.9886846867721655,6.22881869049588,5.807354922057604,5.0,5.78135971352466,5.523561956057013,7.247927513443585,5.169925001442312,7.409390936137702,5.700439718141092,3.321928094887362,6.3750394313469245,8.857980995127573,8.668884984266247,7.499845887083206,6.599912842187128,5.857980995127572,5.392317422778761,6.523561956057013,6.339850002884624,7.584962500721156,5.0,7.22881869049588,6.189824558880018,5.129283016944966,6.820178962415188,8.707359132080883,8.546894459887637,6.820178962415188,6.491853096329675,6.066089190457772,4.523561956057013,5.954196310386875,6.0,6.977279923499917,4.807354922057604,7.169925001442312,6.22881869049588,4.643856189774724,6.129283016944966,7.303780748177103,8.62935662007961,6.426264754702098,6.266786540694901,5.832890014164741,4.459431618637297,5.78135971352466,5.285402218862249,7.247927513443585,4.247927513443585,7.562242424221073,5.523561956057013,1.584962500721156,5.807354922057604,9.087462841250339,9.036173612553485,7.6865005271832185,6.78135971352466,6.727920454563199,5.087462841250339,6.569855608330948,5.727920454563199,8.08214904135387,4.857980995127572,8.370687406807217,6.614709844115208,4.700439718141092,6.599912842187128,7.03342300153745,8.344295907915816,6.357552004618084,6.475733430966398,5.459431618637297,4.392317422778761,5.857980995127572,5.491853096329675,7.20945336562895,4.247927513443585,7.076815597050831,5.169925001442312,4.321928094887363,6.189824558880018,7.400879436282184,8.154818109052105,6.584962500721156,6.3750394313469245,5.321928094887363,4.857980995127572,5.906890595608519,6.129283016944966,6.78135971352466,4.321928094887363,7.312882955284356,5.044394119358453,3.584962500721156,6.554588851677638,6.442943495848728,7.20945336562895,4.954196310386875,5.0,4.754887502163468,3.0,4.906890595608519,4.392317422778761,5.857980995127572,4.087462841250339,5.643856189774724,4.321928094887363,2.321928094887362,4.754887502163468,8.238404739325079,7.507794640198696,6.845490050944375,5.614709844115208,4.392317422778761,4.523561956057013,5.0,5.392317422778761,6.149747119504682,3.0,6.459431618637297,4.807354922057604,4.700439718141092,5.954196310386875,9.381542951184585,8.810571634741146,7.94251450533924,6.459431618637297,6.0,5.807354922057604,6.189824558880018,6.426264754702098,7.076815597050831,5.754887502163468,7.734709620225838,6.584962500721156,3.4594316186372973,6.857980995127572,4.087462841250339,3.0,0.0,1.0,1.0,0.0,0.0,1.0,3.169925001442312,null,2.584962500721156,1.0,0.0,2.0,9.060695931687555,8.566054038171092,7.562242424221073,6.3750394313469245,6.285402218862249,4.954196310386875,6.321928094887363,6.066089190457772,7.087462841250339,5.087462841250339,7.499845887083206,5.857980995127572,2.321928094887362,6.507794640198696,7.592457037268081,7.087462841250339,5.584962500721156,5.0,4.700439718141092,3.169925001442312,4.754887502163468,3.584962500721156,6.459431618637297,3.0,6.870364719583405,4.807354922057604,2.0,4.754887502163468,8.087462841250339,7.599912842187128,6.169925001442312,5.672425341971495,5.392317422778761,4.523561956057013,5.392317422778761,5.584962500721156,6.339850002884624,4.906890595608519,6.392317422778761,4.700439718141092,1.584962500721156,5.727920454563199,9.204571144249204,8.252665432450248,7.679480099505446,6.820178962415188,5.357552004618084,5.247927513443585,6.554588851677638,6.882643049361842,6.066089190457772,5.584962500721156,6.247927513443585,6.20945336562895,2.321928094887362,7.257387842692652,8.092757140919852,8.103287808412022,7.044394119358453,7.1799090900149345,5.426264754702098,6.507794640198696,6.426264754702098,6.94251450533924,5.426264754702098,6.129283016944966,6.285402218862249,6.0,2.807354922057604,6.930737337562887,8.754887502163468,8.276124405274238,7.7615512324444795,6.491853096329675,5.321928094887363,5.857980995127572,6.303780748177103,6.700439718141092,5.754887502163468,6.303780748177103,6.22881869049588,5.857980995127572,3.321928094887362,6.599912842187128,7.826548487290915,7.6865005271832185,6.714245517666122,5.614709844115208,4.807354922057604,5.954196310386875,6.108524456778169,6.321928094887363,4.857980995127572,6.129283016944966,5.087462841250339,4.459431618637297,2.584962500721156,5.807354922057604,8.262094845370179,8.179909090014934,7.22881869049588,6.94251450533924,5.643856189774724,6.409390936137702,6.108524456778169,6.906890595608519,5.882643049361842,5.247927513443585,6.303780748177103,5.832890014164741,5.169925001442312,6.870364719583405,7.400879436282184,7.60733031374961,6.569855608330948,5.78135971352466,5.169925001442312,5.169925001442312,5.672425341971495,6.303780748177103,5.554588851677638,5.459431618637297,5.954196310386875,5.754887502163468,3.807354922057604,6.857980995127572,6.882643049361842,7.930737337562887,6.614709844115208,6.459431618637297,4.584962500721156,5.285402218862249,5.727920454563199,6.0,5.459431618637297,4.0,4.643856189774724,5.643856189774724,3.0,6.714245517666122,7.247927513443585,6.554588851677638,6.129283016944966,5.727920454563199,4.584962500721156,4.584962500721156,4.857980995127572,5.491853096329675,4.906890595608519,3.807354922057604,5.285402218862249,3.169925001442312,2.321928094887362,5.426264754702098,7.894817763307944,7.2761244052742375,6.965784284662087,5.727920454563199,5.169925001442312,4.906890595608519,5.321928094887363,5.491853096329675,4.643856189774724,4.321928094887363,4.392317422778761,5.285402218862249,1.0,6.044394119358453,8.08214904135387,7.6293566200796095,6.930737337562887,5.906890595608519,5.169925001442312,5.247927513443585,5.459431618637297,5.882643049361842,5.392317422778761,4.700439718141092,5.554588851677638,5.584962500721156,1.0,6.044394119358453,6.426264754702098,6.727920454563199,5.700439718141092,5.754887502163468,4.754887502163468,4.523561956057013,5.0,5.584962500721156,4.459431618637297,4.754887502163468,5.672425341971495,4.169925001442312,3.0,5.523561956057013,2.0,8.326429487122303,6.169925001442312,6.845490050944375,5.247927513443585,6.087462841250339,6.22881869049588,6.930737337562887,5.807354922057604,5.727920454563199,5.906890595608519,5.727920454563199,3.584962500721156,7.321928094887363,8.038918989292302,7.3750394313469245,6.94251450533924,5.523561956057013,4.247927513443585,5.169925001442312,5.78135971352466,5.954196310386875,4.754887502163468,5.044394119358453,4.906890595608519,5.044394119358453,3.4594316186372973,5.930737337562887,8.149747119504681,7.499845887083206,7.2384047393250786,6.0,4.700439718141092,5.044394119358453,5.754887502163468,5.643856189774724,5.672425341971495,5.247927513443585,5.357552004618084,5.169925001442312,2.0,6.614709844115208,8.78135971352466,7.807354922057604,7.357552004618084,6.108524456778169,5.426264754702098,5.700439718141092,6.614709844115208,6.539158811108031,5.906890595608519,5.643856189774724,5.857980995127572,6.266786540694901,4.523561956057013,6.539158811108031,4.700439718141092,3.0,2.321928094887362,null,1.0,0.0,1.584962500721156,2.807354922057604,0.0,1.0,1.0,2.0,1.0,2.0,6.906890595608519,6.930737337562887,6.022367813028454,5.754887502163468,4.954196310386875,5.169925001442312,5.554588851677638,5.807354922057604,5.129283016944966,5.169925001442312,4.643856189774724,5.0,2.807354922057604,6.247927513443585,8.194756854422248,7.491853096329675,7.044394119358453,6.087462841250339,5.247927513443585,5.672425341971495,6.108524456778169,6.392317422778761,5.247927513443585,5.044394119358453,5.285402218862249,5.643856189774724,3.169925001442312,6.321928094887363,7.636624620543649,6.523561956057013,6.339850002884624,5.523561956057013,4.523561956057013,4.584962500721156,5.20945336562895,5.727920454563199,5.20945336562895,4.459431618637297,5.0,5.044394119358453,2.321928094887362,5.882643049361842],\"y0\":\" \",\"yaxis\":\"y\",\"type\":\"box\"}],                        {\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"amplicon\"},\"categoryorder\":\"array\",\"categoryarray\":[\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_44\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_64\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_79\",\"Agam_80\",\"Agam_81\",\"Agam_82\"]},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"log_depth\"}},\"legend\":{\"title\":{\"text\":\"contig\"},\"tracegroupgap\":0},\"margin\":{\"t\":60},\"boxmode\":\"group\",\"width\":1000},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('e8b04d23-9640-4c24-9fcf-3e775b11b2e8');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["target_cov_df = target_cov_df.assign(log_depth=lambda x: np.log2(x.depth))\n", "fig = px.box(target_cov_df, x='amplicon', y='log_depth', color='contig', hover_data=['contig', 'mutation'], width=1000, template='simple_white')\n", "fig.update_xaxes(categoryorder='array', categoryarray= snp_targets_sorted )\n", "fig.show()"]}, {"cell_type": "markdown", "id": "333562ca", "metadata": {"papermill": {"duration": 0.756113, "end_time": "2024-12-04T12:14:56.261805", "exception": false, "start_time": "2024-12-04T12:14:55.505692", "status": "completed"}, "tags": []}, "source": ["#### Coverage by sample"]}, {"cell_type": "code", "execution_count": 9, "id": "b7f509db", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:14:57.730934Z", "iopub.status.busy": "2024-12-04T12:14:57.729651Z", "iopub.status.idle": "2024-12-04T12:14:57.964083Z", "shell.execute_reply": "2024-12-04T12:14:57.963027Z"}, "papermill": {"duration": 0.933873, "end_time": "2024-12-04T12:14:57.970941", "exception": false, "start_time": "2024-12-04T12:14:57.037068", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [{"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"alignmentgroup": "True", "customdata": [["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"], ["2L"]], "hovertemplate": "contig=%{customdata[0]}<br>sample_id=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "2L", "marker": {"color": "#1F77B4", "pattern": {"shape": ""}}, "name": "2L", "offsetgroup": "2L", "orientation": "v", "showlegend": true, "textposition": "auto", "type": "bar", "x": ["GH_01", "GH_02", "GH_03", "GH_04", "GH_05", "GH_06", "GH_07", "GH_08", "GH_09", "GH_10", "GH_11", "GH_12", "GH_13", "GH_14", "GH_15", "GH_16", "GH_17", "GH_18", "GH_19", "GH_20", "GH_21", "GH_22", "GH_23", "GH_24", "GH_25", "GH_26", "GH_27", "GH_28", "GH_29", "GH_30", "GH_31", "GH_32", "GH_33", "GH_34", "GH_35", "GH_36", "GH_37", "GH_38", "GH_39", "GH_40_low_vol", "GH_41", "GH_42", "GH_43", "GH_44", "GH_45", "GH_46", "GH_47", "GH_48", "GH_49", "GH_50", "GH_51", "GH_52", "GH_53", "GH_54", "GH_55", "GH_56", "GH_57", "GH_58", "GH_59", "GH_60", "GH_61", "GH_62", "GH_63", "GH_64", "GH_65_low_vol", "GH_66", "GH_67", "GH_68", "GH_69", "GH_70", "GH_71", "GH_72", "GH_73", "GH_74", "GH_75", "GH_76", "GH_77", "GH_78", "GH_79", "GH_80_low_vol", "GH_81", "GH_82", "GH_83", "GH_84", "GH_85", "GH_86", "GH_87", "GH_88", "GH_89", "GH_90", "GH_91", "GH_92", "GH_93", "GH_94", "GH_95", "GH_Negative", "GM_01", "GM_02", "GM_03", "GM_04", "GM_05", "GM_06", "GM_07", "GM_08", "GM_09", "GM_10", "GM_11", "GM_12", "GM_13", "GM_14", "GM_15", "GM_16", "GM_17", "GM_18", "GM_19", "GM_20", "GM_21", "GM_22", "GM_23", "GM_24", "GM_25", "GM_26", "GM_27", "GM_28", "GM_29", "GM_30", "GM_31", "GM_32", "GM_33", "GM_34", "GM_35", "GM_36", "GM_37", "GM_38", "GM_39", "GM_40", "GM_41", "GM_42", "GM_43", "GM_44", "GM_45", "GM_46", "GM_47", "GM_48", "GM_49", "GM_50", "GM_51", "GM_52", "GM_53", "GM_54", "GM_55", "GM_56", "GM_57", "GM_58", "GM_59", "GM_60", "GM_61", "GM_62", "GM_63", "GM_64", "GM_65", "GM_66", "GM_67", "GM_68", "GM_69", "GM_70", "GM_71", "GM_72", "GM_73", "GM_74", "GM_75", "GM_76", "GM_77", "GM_78", "GM_79", "GM_80", "GM_81", "GM_82", "GM_83", "GM_84", "GM_85", "GM_86", "GM_87", "GM_88", "GM_89", "GM_90", "GM_91", "GM_92", "GM_93", "GM_94", "GM_95", "GM_96", "Siaya_Delta_Alive_01", "Siaya_Delta_Alive_02", "Siaya_Delta_Alive_03", "Siaya_Delta_Alive_04", "Siaya_Delta_Alive_05", "Siaya_Delta_Alive_06", "Siaya_Delta_Alive_07", "Siaya_Delta_Alive_08", "Siaya_Delta_Alive_09", "Siaya_Delta_Alive_10", "Siaya_Delta_Alive_100", "Siaya_Delta_Alive_101", "Siaya_Delta_Alive_102", "Siaya_Delta_Alive_103", "Siaya_Delta_Alive_104", "Siaya_Delta_Alive_105", "Siaya_Delta_Alive_106", "Siaya_Delta_Alive_107", "Siaya_Delta_Alive_108", "Siaya_Delta_Alive_109", "Siaya_Delta_Alive_11", "Siaya_Delta_Alive_110", "Siaya_Delta_Alive_111", "Siaya_Delta_Alive_112", "Siaya_Delta_Alive_113", "Siaya_Delta_Alive_114", "Siaya_Delta_Alive_115", "Siaya_Delta_Alive_116", "Siaya_Delta_Alive_117", "Siaya_Delta_Alive_118", "Siaya_Delta_Alive_119", "Siaya_Delta_Alive_12", "Siaya_Delta_Alive_120", "Siaya_Delta_Alive_121", "Siaya_Delta_Alive_122", "Siaya_Delta_Alive_123", "Siaya_Delta_Alive_124", "Siaya_Delta_Alive_125", "Siaya_Delta_Alive_126", "Siaya_Delta_Alive_127", "Siaya_Delta_Alive_128", "Siaya_Delta_Alive_129", "Siaya_Delta_Alive_13", "Siaya_Delta_Alive_130", "Siaya_Delta_Alive_131", "Siaya_Delta_Alive_14", "Siaya_Delta_Alive_15", "Siaya_Delta_Alive_16", "Siaya_Delta_Alive_17", "Siaya_Delta_Alive_18", "Siaya_Delta_Alive_19", "Siaya_Delta_Alive_20", "Siaya_Delta_Alive_21", "Siaya_Delta_Alive_22", "Siaya_Delta_Alive_23", "Siaya_Delta_Alive_24", "Siaya_Delta_Alive_25", "Siaya_Delta_Alive_26", "Siaya_Delta_Alive_27", "Siaya_Delta_Alive_28", "Siaya_Delta_Alive_29", "Siaya_Delta_Alive_30", "Siaya_Delta_Alive_31", "Siaya_Delta_Alive_32", "Siaya_Delta_Alive_33", "Siaya_Delta_Alive_34", "Siaya_Delta_Alive_35", "Siaya_Delta_Alive_36", "Siaya_Delta_Alive_37", "Siaya_Delta_Alive_38", "Siaya_Delta_Alive_39", "Siaya_Delta_Alive_40", "Siaya_Delta_Alive_41", "Siaya_Delta_Alive_42", "Siaya_Delta_Alive_43", "Siaya_Delta_Alive_44", "Siaya_Delta_Alive_45", "Siaya_Delta_Alive_46", "Siaya_Delta_Alive_47", "Siaya_Delta_Alive_48", "Siaya_Delta_Alive_49", "Siaya_Delta_Alive_50", "Siaya_Delta_Alive_51", "Siaya_Delta_Alive_52", "Siaya_Delta_Alive_53", "Siaya_Delta_Alive_54", "Siaya_Delta_Alive_55", "Siaya_Delta_Alive_56", "Siaya_Delta_Alive_57", "Siaya_Delta_Alive_58", "Siaya_Delta_Alive_59", "Siaya_Delta_Alive_60", "Siaya_Delta_Alive_61", "Siaya_Delta_Alive_62", "Siaya_Delta_Alive_63", "Siaya_Delta_Alive_64", "Siaya_Delta_Alive_65", "Siaya_Delta_Alive_66", "Siaya_Delta_Alive_67", "Siaya_Delta_Alive_68", "Siaya_Delta_Alive_69", "Siaya_Delta_Alive_70", "Siaya_Delta_Alive_71", "Siaya_Delta_Alive_72", "Siaya_Delta_Alive_73", "Siaya_Delta_Alive_74", "Siaya_Delta_Alive_75", "Siaya_Delta_Alive_76", "Siaya_Delta_Alive_77", "Siaya_Delta_Alive_78", "Siaya_Delta_Alive_79", "Siaya_Delta_Alive_80", "Siaya_Delta_Alive_81", "Siaya_Delta_Alive_82", "Siaya_Delta_Alive_83", "Siaya_Delta_Alive_84", "Siaya_Delta_Alive_85", "Siaya_Delta_Alive_86", "Siaya_Delta_Alive_87", "Siaya_Delta_Alive_88", "Siaya_Delta_Alive_89", "Siaya_Delta_Alive_90", "Siaya_Delta_Alive_91", "Siaya_Delta_Alive_92", "Siaya_Delta_Alive_93", "Siaya_Delta_Alive_94", "Siaya_Delta_Alive_95", "Siaya_Delta_Alive_96", "Siaya_Delta_Alive_97", "Siaya_Delta_Alive_98", "Siaya_Delta_Alive_99", "Siaya_Delta_Alive_Negative", "Siaya_Delta_Dead_01", "Siaya_Delta_Dead_02", "Siaya_Delta_Dead_03", "Siaya_Delta_Dead_04", "Siaya_Delta_Dead_05", "Siaya_Delta_Dead_06", "Siaya_Delta_Dead_07", "Siaya_Delta_Dead_08", "Siaya_Delta_Dead_09", "Siaya_Delta_Dead_10", "Siaya_Delta_Dead_100", "Siaya_Delta_Dead_101", "Siaya_Delta_Dead_102", "Siaya_Delta_Dead_103", "Siaya_Delta_Dead_104", "Siaya_Delta_Dead_105", "Siaya_Delta_Dead_106", "Siaya_Delta_Dead_107", "Siaya_Delta_Dead_108", "Siaya_Delta_Dead_109", "Siaya_Delta_Dead_11", "Siaya_Delta_Dead_110", "Siaya_Delta_Dead_111", "Siaya_Delta_Dead_112", "Siaya_Delta_Dead_113", "Siaya_Delta_Dead_114", "Siaya_Delta_Dead_115", "Siaya_Delta_Dead_116", "Siaya_Delta_Dead_117", "Siaya_Delta_Dead_118", "Siaya_Delta_Dead_119", "Siaya_Delta_Dead_12", "Siaya_Delta_Dead_120", "Siaya_Delta_Dead_121", "Siaya_Delta_Dead_122", "Siaya_Delta_Dead_123", "Siaya_Delta_Dead_124", "Siaya_Delta_Dead_125", "Siaya_Delta_Dead_126", "Siaya_Delta_Dead_127", "Siaya_Delta_Dead_128", "Siaya_Delta_Dead_129", "Siaya_Delta_Dead_13", "Siaya_Delta_Dead_130", "Siaya_Delta_Dead_131", "Siaya_Delta_Dead_14", "Siaya_Delta_Dead_15", "Siaya_Delta_Dead_16", "Siaya_Delta_Dead_17", "Siaya_Delta_Dead_18", "Siaya_Delta_Dead_19", "Siaya_Delta_Dead_20", "Siaya_Delta_Dead_21", "Siaya_Delta_Dead_22", "Siaya_Delta_Dead_23", "Siaya_Delta_Dead_24", "Siaya_Delta_Dead_25", "Siaya_Delta_Dead_26", "Siaya_Delta_Dead_27", "Siaya_Delta_Dead_28", "Siaya_Delta_Dead_29", "Siaya_Delta_Dead_30", "Siaya_Delta_Dead_31", "Siaya_Delta_Dead_32", "Siaya_Delta_Dead_33", "Siaya_Delta_Dead_34", "Siaya_Delta_Dead_35", "Siaya_Delta_Dead_36", "Siaya_Delta_Dead_37", "Siaya_Delta_Dead_38", "Siaya_Delta_Dead_39", "Siaya_Delta_Dead_40", "Siaya_Delta_Dead_41", "Siaya_Delta_Dead_42", "Siaya_Delta_Dead_43", "Siaya_Delta_Dead_44", "Siaya_Delta_Dead_45", "Siaya_Delta_Dead_46", "Siaya_Delta_Dead_47", "Siaya_Delta_Dead_48", "Siaya_Delta_Dead_49", "Siaya_Delta_Dead_50", "Siaya_Delta_Dead_51", "Siaya_Delta_Dead_52", "Siaya_Delta_Dead_53", "Siaya_Delta_Dead_54", "Siaya_Delta_Dead_55", "Siaya_Delta_Dead_56", "Siaya_Delta_Dead_57", "Siaya_Delta_Dead_58", "Siaya_Delta_Dead_59", "Siaya_Delta_Dead_60", "Siaya_Delta_Dead_61", "Siaya_Delta_Dead_62", "Siaya_Delta_Dead_63", "Siaya_Delta_Dead_64", "Siaya_Delta_Dead_65", "Siaya_Delta_Dead_66", "Siaya_Delta_Dead_67", "Siaya_Delta_Dead_68", "Siaya_Delta_Dead_69", "Siaya_Delta_Dead_70", "Siaya_Delta_Dead_71", "Siaya_Delta_Dead_72", "Siaya_Delta_Dead_73", "Siaya_Delta_Dead_74", "Siaya_Delta_Dead_75", "Siaya_Delta_Dead_76", "Siaya_Delta_Dead_77", "Siaya_Delta_Dead_78", "Siaya_Delta_Dead_79", "Siaya_Delta_Dead_80", "Siaya_Delta_Dead_81", "Siaya_Delta_Dead_82", "Siaya_Delta_Dead_83", "Siaya_Delta_Dead_84", "Siaya_Delta_Dead_85", "Siaya_Delta_Dead_86", "Siaya_Delta_Dead_87", "Siaya_Delta_Dead_88", "Siaya_Delta_Dead_89", "Siaya_Delta_Dead_90", "Siaya_Delta_Dead_91", "Siaya_Delta_Dead_92", "Siaya_Delta_Dead_93", "Siaya_Delta_Dead_94", "Siaya_Delta_Dead_95", "Siaya_Delta_Dead_96", "Siaya_Delta_Dead_97", "Siaya_Delta_Dead_98", "Siaya_Delta_Dead_99", "Siaya_Delta_Dead_Negative", "VK7_Negative", "VK7_alive_01", "VK7_alive_02", "VK7_alive_03", "VK7_alive_04", "VK7_alive_05", "VK7_alive_06", "VK7_alive_07", "VK7_alive_08", "VK7_alive_09", "VK7_alive_10", "VK7_alive_11", "VK7_alive_12", "VK7_alive_13", "VK7_alive_14", "VK7_alive_15", "VK7_alive_16", "VK7_alive_17", "VK7_alive_18", "VK7_alive_19", "VK7_alive_20", "VK7_alive_21", "VK7_alive_22", "VK7_alive_23", "VK7_alive_24", "VK7_alive_25", "VK7_alive_26", "VK7_alive_27", "VK7_alive_28", "VK7_alive_29", "VK7_alive_30", "VK7_alive_31", "VK7_alive_32", "VK7_alive_33", "VK7_alive_34", "VK7_alive_35", "VK7_alive_36", "VK7_alive_37", "VK7_alive_38", "VK7_alive_39", "VK7_alive_40", "VK7_alive_41", "VK7_alive_42", "VK7_alive_43", "VK7_alive_44", "VK7_alive_45", "VK7_alive_46", "VK7_alive_47", "VK7_dead_01", "VK7_dead_02", "VK7_dead_03", "VK7_dead_04", "VK7_dead_04_dil", "VK7_dead_05", "VK7_dead_06", "VK7_dead_07", "VK7_dead_08", "VK7_dead_09", "VK7_dead_10", "VK7_dead_10_dil", "VK7_dead_11", "VK7_dead_12", "VK7_dead_13", "VK7_dead_14", "VK7_dead_15", "VK7_dead_16", "VK7_dead_16_dil", "VK7_dead_17", "VK7_dead_18", "VK7_dead_19", "VK7_dead_20", "VK7_dead_21", "VK7_dead_22", "VK7_dead_22_dil", "VK7_dead_23", "VK7_dead_24", "VK7_dead_25", "VK7_dead_26", "VK7_dead_27", "VK7_dead_28", "VK7_dead_28_dil", "VK7_dead_29", "VK7_dead_30", "VK7_dead_31", "VK7_dead_32", "VK7_dead_33", "VK7_dead_34", "VK7_dead_34_dil", "VK7_dead_35", "VK7_dead_36", "VK7_dead_37", "VK7_dead_38", "VK7_dead_39", "VK7_dead_40", "VK7_dead_41", "VK7_dead_42"], "xaxis": "x", "y": [58362, 4212, 23578, 1100, 2566, 10668, 326, 27796, 67070, 4934, 64574, 24951, 8825, 15926, 3231, 4032, 3756, 2886, 23750, 1193, 17723, 3498, 40622, 22571, 10779, 24790, 5554, 1557, 6154, 50225, 20576, 2699, 19808, 15796, 9137, 24167, 56458, 8754, 7587, 15013, 4267, 4655, 20582, 9643, 8299, 2098, 7610, 28414, 110302, 61087, 217222, 17196, 19980, 5970, 34759, 16433, 7157, 5518, 4310, 34949, 261663, 55052, 7984, 35341, 143, 3291, 5041, 4075, 3150, 4044, 25161, 27323, 26809, 22665, 8113, 28594, 4197, 7255, 110721, 1693, 28800, 4206, 6863, 36657, 82651, 403104, 4593, 17754, 58187, 197, 20986, 28664, 11082, 72103, 17341, 84586, 3011, 26669, 39240, 112783, 51979, 665, 207, 136, 1611, 858, 2541, 1961, 25403, 61353, 16774, 5588, 1598, 16196, 6819, 4160, 1300, 3635, 2605, 16250, 4424, 61208, 2412, 19039, 9807, 5545, 1637, 2599, 1202, 520, 1806, 1086, 38485, 28296, 4126, 11488, 413, 1674, 422, 1618, 4540, 626, 480, 403, 1242, 55684, 54089, 4401, 3771, 3050, 2822, 2965, 11992, 4182, 1184, 2447, 53904, 6736, 8833, 62756, 187, 3433, 504, 1860, 1657, 1028, 463, 16569, 20007, 68779, 9795, 15615, 9408, 1634, 1457, 1564, 2341, 664, 791, 24087, 10156, 603447, 3238, 23739, 32757, 156, 2236, 1853, 21390, 209, 2070, 12473, 168251, 153693, 73580, 63937, 156238, 121904, 25950, 247958, 268786, 96790, 163044, 107676, 68161, 217683, 120751, 132342, 46899, 67497, 72937, 202332, 374303, 170024, 60251, 161517, 136469, 99993, 172792, 80333, 771, 105129, 19654, 215881, 63140, 124541, 69493, 51029, 28250, 45177, 45466, 115593, 711, 43517, 110116, 61373, 27991, 210071, 58414, 235981, 234621, 280872, 191699, 161907, 342547, 233588, 174727, 297477, 15281, 143297, 71833, 100228, 290838, 496208, 197805, 242823, 388214, 540133, 213817, 175974, 47962, 39653, 59296, 40902, 128795, 156049, 211288, 334698, 101588, 93103, 179326, 268982, 67651, 43170, 199594, 65619, 96233, 143510, 296644, 188196, 438074, 175125, 190464, 147934, 153116, 27214, 81476, 145512, 2996, 188781, 50826, 115472, 149692, 86498, 136319, 146311, 100123, 86734, 13504, 55786, 73919, 98006, 249985, 55896, 91725, 168292, 125181, 147958, 98402, 59304, 48106, 50543, 81496, 1293, 120434, 34331, 119758, 110234, 147443, 131756, 7314, 128809, 175198, 25854, 328423, 79963, 196524, 69930, 185738, 98701, 5152, 68220, 62413, 48909, 43731, 132395, 124352, 103952, 148966, 94624, 40941, 317599, 118267, 149810, 88458, 67294, 122265, 135593, 87822, 123612, 45444, 139059, 72136, 104137, 92591, 129783, 107989, 36231, 75076, 180745, 128456, 96122, 36294, 124439, 40022, 104869, 234345, 54187, 56459, 498507, 189242, 59638, 93724, 420569, 348243, 50646, 11542, 130622, 176870, 77125, 27293, 109906, 64574, 510906, 192756, 137249, 135771, 67811, 55344, 69306, 117719, 65634, 444900, 80743, 210655, 227018, 199798, 122204, 287614, 51991, 28113, 232576, 93616, 175970, 149328, 19766, 286386, 190482, 52903, 144011, 119176, 48500, 35203, 225777, 93210, 117325, 447584, 203443, 531850, 86303, 949, 413153, 29719, 122574, 54787, 28010, 87192, 74436, 663438, 408684, 436288, 213212, 275426, 170019, 180767, 53705, 48214, 69229, 153741, 27741, 779359, 71376, 322468, 273969, 256379, 400, 128919, 51884, 39872, 92695, 118384, 94006, 70900, 78383, 135404, 15573, 12760, 1866, 16, 12, 18305, 17, 59667, 8236, 33753, 2, 33920, 4, 23299, 8235, 13148, 51584, 17094, 54, 24563, 66135, 34569, 0, 23077, 44, 58631, 6095, 36632, 19, 39325, 13, 75947, 25, 15432, 8, 14268, 20568, 31584, 20180, 12926, 12, 12911, 33739, 33391, 13246, 27494, 8033, 18824, 37345, 16343, 17504, 77308, 20488, 13087, 127735, 222467, 40970, 73838, 6252, 38837, 469, 52458, 45488, 2605, 17754, 6803, 30143, 1128, 24641, 12723, 19294, 19295, 16389, 20336, 1229, 14824, 34217, 23995, 12736, 15484, 81050, 10504, 26068, 23944, 110864, 1631, 21909, 19603, 32, 9804, 20806, 38201, 83936, 23262, 3418, 46605, 9389], "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"], ["2R"]], "hovertemplate": "contig=%{customdata[0]}<br>sample_id=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "2R", "marker": {"color": "#FF7F0E", "pattern": {"shape": ""}}, "name": "2R", "offsetgroup": "2R", "orientation": "v", "showlegend": true, "textposition": "auto", "type": "bar", "x": ["GH_01", "GH_02", "GH_03", "GH_04", "GH_05", "GH_06", "GH_07", "GH_08", "GH_09", "GH_10", "GH_11", "GH_12", "GH_13", "GH_14", "GH_15", "GH_16", "GH_17", "GH_18", "GH_19", "GH_20", "GH_21", "GH_22", "GH_23", "GH_24", "GH_25", "GH_26", "GH_27", "GH_28", "GH_29", "GH_30", "GH_31", "GH_32", "GH_33", "GH_34", "GH_35", "GH_36", "GH_37", "GH_38", "GH_39", "GH_40_low_vol", "GH_41", "GH_42", "GH_43", "GH_44", "GH_45", "GH_46", "GH_47", "GH_48", "GH_49", "GH_50", "GH_51", "GH_52", "GH_53", "GH_54", "GH_55", "GH_56", "GH_57", "GH_58", "GH_59", "GH_60", "GH_61", "GH_62", "GH_63", "GH_64", "GH_65_low_vol", "GH_66", "GH_67", "GH_68", "GH_69", "GH_70", "GH_71", "GH_72", "GH_73", "GH_74", "GH_75", "GH_76", "GH_77", "GH_78", "GH_79", "GH_80_low_vol", "GH_81", "GH_82", "GH_83", "GH_84", "GH_85", "GH_86", "GH_87", "GH_88", "GH_89", "GH_90", "GH_91", "GH_92", "GH_93", "GH_94", "GH_95", "GH_Negative", "GM_01", "GM_02", "GM_03", "GM_04", "GM_05", "GM_06", "GM_07", "GM_08", "GM_09", "GM_10", "GM_11", "GM_12", "GM_13", "GM_14", "GM_15", "GM_16", "GM_17", "GM_18", "GM_19", "GM_20", "GM_21", "GM_22", "GM_23", "GM_24", "GM_25", "GM_26", "GM_27", "GM_28", "GM_29", "GM_30", "GM_31", "GM_32", "GM_33", "GM_34", "GM_35", "GM_36", "GM_37", "GM_38", "GM_39", "GM_40", "GM_41", "GM_42", "GM_43", "GM_44", "GM_45", "GM_46", "GM_47", "GM_48", "GM_49", "GM_50", "GM_51", "GM_52", "GM_53", "GM_54", "GM_55", "GM_56", "GM_57", "GM_58", "GM_59", "GM_60", "GM_61", "GM_62", "GM_63", "GM_64", "GM_65", "GM_66", "GM_67", "GM_68", "GM_69", "GM_70", "GM_71", "GM_72", "GM_73", "GM_74", "GM_75", "GM_76", "GM_77", "GM_78", "GM_79", "GM_80", "GM_81", "GM_82", "GM_83", "GM_84", "GM_85", "GM_86", "GM_87", "GM_88", "GM_89", "GM_90", "GM_91", "GM_92", "GM_93", "GM_94", "GM_95", "GM_96", "Siaya_Delta_Alive_01", "Siaya_Delta_Alive_02", "Siaya_Delta_Alive_03", "Siaya_Delta_Alive_04", "Siaya_Delta_Alive_05", "Siaya_Delta_Alive_06", "Siaya_Delta_Alive_07", "Siaya_Delta_Alive_08", "Siaya_Delta_Alive_09", "Siaya_Delta_Alive_10", "Siaya_Delta_Alive_100", "Siaya_Delta_Alive_101", "Siaya_Delta_Alive_102", "Siaya_Delta_Alive_103", "Siaya_Delta_Alive_104", "Siaya_Delta_Alive_105", "Siaya_Delta_Alive_106", "Siaya_Delta_Alive_107", "Siaya_Delta_Alive_108", "Siaya_Delta_Alive_109", "Siaya_Delta_Alive_11", "Siaya_Delta_Alive_110", "Siaya_Delta_Alive_111", "Siaya_Delta_Alive_112", "Siaya_Delta_Alive_113", "Siaya_Delta_Alive_114", "Siaya_Delta_Alive_115", "Siaya_Delta_Alive_116", "Siaya_Delta_Alive_117", "Siaya_Delta_Alive_118", "Siaya_Delta_Alive_119", "Siaya_Delta_Alive_12", "Siaya_Delta_Alive_120", "Siaya_Delta_Alive_121", "Siaya_Delta_Alive_122", "Siaya_Delta_Alive_123", "Siaya_Delta_Alive_124", "Siaya_Delta_Alive_125", "Siaya_Delta_Alive_126", "Siaya_Delta_Alive_127", "Siaya_Delta_Alive_128", "Siaya_Delta_Alive_129", "Siaya_Delta_Alive_13", "Siaya_Delta_Alive_130", "Siaya_Delta_Alive_131", "Siaya_Delta_Alive_14", "Siaya_Delta_Alive_15", "Siaya_Delta_Alive_16", "Siaya_Delta_Alive_17", "Siaya_Delta_Alive_18", "Siaya_Delta_Alive_19", "Siaya_Delta_Alive_20", "Siaya_Delta_Alive_21", "Siaya_Delta_Alive_22", "Siaya_Delta_Alive_23", "Siaya_Delta_Alive_24", "Siaya_Delta_Alive_25", "Siaya_Delta_Alive_26", "Siaya_Delta_Alive_27", "Siaya_Delta_Alive_28", "Siaya_Delta_Alive_29", "Siaya_Delta_Alive_30", "Siaya_Delta_Alive_31", "Siaya_Delta_Alive_32", "Siaya_Delta_Alive_33", "Siaya_Delta_Alive_34", "Siaya_Delta_Alive_35", "Siaya_Delta_Alive_36", "Siaya_Delta_Alive_37", "Siaya_Delta_Alive_38", "Siaya_Delta_Alive_39", "Siaya_Delta_Alive_40", "Siaya_Delta_Alive_41", "Siaya_Delta_Alive_42", "Siaya_Delta_Alive_43", "Siaya_Delta_Alive_44", "Siaya_Delta_Alive_45", "Siaya_Delta_Alive_46", "Siaya_Delta_Alive_47", "Siaya_Delta_Alive_48", "Siaya_Delta_Alive_49", "Siaya_Delta_Alive_50", "Siaya_Delta_Alive_51", "Siaya_Delta_Alive_52", "Siaya_Delta_Alive_53", "Siaya_Delta_Alive_54", "Siaya_Delta_Alive_55", "Siaya_Delta_Alive_56", "Siaya_Delta_Alive_57", "Siaya_Delta_Alive_58", "Siaya_Delta_Alive_59", "Siaya_Delta_Alive_60", "Siaya_Delta_Alive_61", "Siaya_Delta_Alive_62", "Siaya_Delta_Alive_63", "Siaya_Delta_Alive_64", "Siaya_Delta_Alive_65", "Siaya_Delta_Alive_66", "Siaya_Delta_Alive_67", "Siaya_Delta_Alive_68", "Siaya_Delta_Alive_69", "Siaya_Delta_Alive_70", "Siaya_Delta_Alive_71", "Siaya_Delta_Alive_72", "Siaya_Delta_Alive_73", "Siaya_Delta_Alive_74", "Siaya_Delta_Alive_75", "Siaya_Delta_Alive_76", "Siaya_Delta_Alive_77", "Siaya_Delta_Alive_78", "Siaya_Delta_Alive_79", "Siaya_Delta_Alive_80", "Siaya_Delta_Alive_81", "Siaya_Delta_Alive_82", "Siaya_Delta_Alive_83", "Siaya_Delta_Alive_84", "Siaya_Delta_Alive_85", "Siaya_Delta_Alive_86", "Siaya_Delta_Alive_87", "Siaya_Delta_Alive_88", "Siaya_Delta_Alive_89", "Siaya_Delta_Alive_90", "Siaya_Delta_Alive_91", "Siaya_Delta_Alive_92", "Siaya_Delta_Alive_93", "Siaya_Delta_Alive_94", "Siaya_Delta_Alive_95", "Siaya_Delta_Alive_96", "Siaya_Delta_Alive_97", "Siaya_Delta_Alive_98", "Siaya_Delta_Alive_99", "Siaya_Delta_Alive_Negative", "Siaya_Delta_Dead_01", "Siaya_Delta_Dead_02", "Siaya_Delta_Dead_03", "Siaya_Delta_Dead_04", "Siaya_Delta_Dead_05", "Siaya_Delta_Dead_06", "Siaya_Delta_Dead_07", "Siaya_Delta_Dead_08", "Siaya_Delta_Dead_09", "Siaya_Delta_Dead_10", "Siaya_Delta_Dead_100", "Siaya_Delta_Dead_101", "Siaya_Delta_Dead_102", "Siaya_Delta_Dead_103", "Siaya_Delta_Dead_104", "Siaya_Delta_Dead_105", "Siaya_Delta_Dead_106", "Siaya_Delta_Dead_107", "Siaya_Delta_Dead_108", "Siaya_Delta_Dead_109", "Siaya_Delta_Dead_11", "Siaya_Delta_Dead_110", "Siaya_Delta_Dead_111", "Siaya_Delta_Dead_112", "Siaya_Delta_Dead_113", "Siaya_Delta_Dead_114", "Siaya_Delta_Dead_115", "Siaya_Delta_Dead_116", "Siaya_Delta_Dead_117", "Siaya_Delta_Dead_118", "Siaya_Delta_Dead_119", "Siaya_Delta_Dead_12", "Siaya_Delta_Dead_120", "Siaya_Delta_Dead_121", "Siaya_Delta_Dead_122", "Siaya_Delta_Dead_123", "Siaya_Delta_Dead_124", "Siaya_Delta_Dead_125", "Siaya_Delta_Dead_126", "Siaya_Delta_Dead_127", "Siaya_Delta_Dead_128", "Siaya_Delta_Dead_129", "Siaya_Delta_Dead_13", "Siaya_Delta_Dead_130", "Siaya_Delta_Dead_131", "Siaya_Delta_Dead_14", "Siaya_Delta_Dead_15", "Siaya_Delta_Dead_16", "Siaya_Delta_Dead_17", "Siaya_Delta_Dead_18", "Siaya_Delta_Dead_19", "Siaya_Delta_Dead_20", "Siaya_Delta_Dead_21", "Siaya_Delta_Dead_22", "Siaya_Delta_Dead_23", "Siaya_Delta_Dead_24", "Siaya_Delta_Dead_25", "Siaya_Delta_Dead_26", "Siaya_Delta_Dead_27", "Siaya_Delta_Dead_28", "Siaya_Delta_Dead_29", "Siaya_Delta_Dead_30", "Siaya_Delta_Dead_31", "Siaya_Delta_Dead_32", "Siaya_Delta_Dead_33", "Siaya_Delta_Dead_34", "Siaya_Delta_Dead_35", "Siaya_Delta_Dead_36", "Siaya_Delta_Dead_37", "Siaya_Delta_Dead_38", "Siaya_Delta_Dead_39", "Siaya_Delta_Dead_40", "Siaya_Delta_Dead_41", "Siaya_Delta_Dead_42", "Siaya_Delta_Dead_43", "Siaya_Delta_Dead_44", "Siaya_Delta_Dead_45", "Siaya_Delta_Dead_46", "Siaya_Delta_Dead_47", "Siaya_Delta_Dead_48", "Siaya_Delta_Dead_49", "Siaya_Delta_Dead_50", "Siaya_Delta_Dead_51", "Siaya_Delta_Dead_52", "Siaya_Delta_Dead_53", "Siaya_Delta_Dead_54", "Siaya_Delta_Dead_55", "Siaya_Delta_Dead_56", "Siaya_Delta_Dead_57", "Siaya_Delta_Dead_58", "Siaya_Delta_Dead_59", "Siaya_Delta_Dead_60", "Siaya_Delta_Dead_61", "Siaya_Delta_Dead_62", "Siaya_Delta_Dead_63", "Siaya_Delta_Dead_64", "Siaya_Delta_Dead_65", "Siaya_Delta_Dead_66", "Siaya_Delta_Dead_67", "Siaya_Delta_Dead_68", "Siaya_Delta_Dead_69", "Siaya_Delta_Dead_70", "Siaya_Delta_Dead_71", "Siaya_Delta_Dead_72", "Siaya_Delta_Dead_73", "Siaya_Delta_Dead_74", "Siaya_Delta_Dead_75", "Siaya_Delta_Dead_76", "Siaya_Delta_Dead_77", "Siaya_Delta_Dead_78", "Siaya_Delta_Dead_79", "Siaya_Delta_Dead_80", "Siaya_Delta_Dead_81", "Siaya_Delta_Dead_82", "Siaya_Delta_Dead_83", "Siaya_Delta_Dead_84", "Siaya_Delta_Dead_85", "Siaya_Delta_Dead_86", "Siaya_Delta_Dead_87", "Siaya_Delta_Dead_88", "Siaya_Delta_Dead_89", "Siaya_Delta_Dead_90", "Siaya_Delta_Dead_91", "Siaya_Delta_Dead_92", "Siaya_Delta_Dead_93", "Siaya_Delta_Dead_94", "Siaya_Delta_Dead_95", "Siaya_Delta_Dead_96", "Siaya_Delta_Dead_97", "Siaya_Delta_Dead_98", "Siaya_Delta_Dead_99", "Siaya_Delta_Dead_Negative", "VK7_Negative", "VK7_alive_01", "VK7_alive_02", "VK7_alive_03", "VK7_alive_04", "VK7_alive_05", "VK7_alive_06", "VK7_alive_07", "VK7_alive_08", "VK7_alive_09", "VK7_alive_10", "VK7_alive_11", "VK7_alive_12", "VK7_alive_13", "VK7_alive_14", "VK7_alive_15", "VK7_alive_16", "VK7_alive_17", "VK7_alive_18", "VK7_alive_19", "VK7_alive_20", "VK7_alive_21", "VK7_alive_22", "VK7_alive_23", "VK7_alive_24", "VK7_alive_25", "VK7_alive_26", "VK7_alive_27", "VK7_alive_28", "VK7_alive_29", "VK7_alive_30", "VK7_alive_31", "VK7_alive_32", "VK7_alive_33", "VK7_alive_34", "VK7_alive_35", "VK7_alive_36", "VK7_alive_37", "VK7_alive_38", "VK7_alive_39", "VK7_alive_40", "VK7_alive_41", "VK7_alive_42", "VK7_alive_43", "VK7_alive_44", "VK7_alive_45", "VK7_alive_46", "VK7_alive_47", "VK7_dead_01", "VK7_dead_02", "VK7_dead_03", "VK7_dead_04", "VK7_dead_04_dil", "VK7_dead_05", "VK7_dead_06", "VK7_dead_07", "VK7_dead_08", "VK7_dead_09", "VK7_dead_10", "VK7_dead_10_dil", "VK7_dead_11", "VK7_dead_12", "VK7_dead_13", "VK7_dead_14", "VK7_dead_15", "VK7_dead_16", "VK7_dead_16_dil", "VK7_dead_17", "VK7_dead_18", "VK7_dead_19", "VK7_dead_20", "VK7_dead_21", "VK7_dead_22", "VK7_dead_22_dil", "VK7_dead_23", "VK7_dead_24", "VK7_dead_25", "VK7_dead_26", "VK7_dead_27", "VK7_dead_28", "VK7_dead_28_dil", "VK7_dead_29", "VK7_dead_30", "VK7_dead_31", "VK7_dead_32", "VK7_dead_33", "VK7_dead_34", "VK7_dead_34_dil", "VK7_dead_35", "VK7_dead_36", "VK7_dead_37", "VK7_dead_38", "VK7_dead_39", "VK7_dead_40", "VK7_dead_41", "VK7_dead_42"], "xaxis": "x", "y": [99258, 3401, 8783, 1425, 4494, 6668, 533, 18024, 5793, 3637, 10324, 4629, 6614, 6625, 2489, 3056, 3496, 4312, 16907, 1711, 10874, 4541, 10585, 7559, 2284, 29385, 4172, 2138, 5544, 18303, 5249, 2887, 16147, 16949, 18235, 7783, 20677, 5434, 5204, 5521, 2350, 2621, 9050, 5948, 2889, 1791, 8721, 7626, 43798, 24721, 107159, 10601, 11106, 4484, 20911, 16272, 4960, 3470, 4300, 9325, 108377, 19804, 7088, 16888, 131, 3080, 8423, 2403, 2464, 1581, 2093, 3233, 15333, 12038, 3725, 10244, 1664, 4274, 76678, 1479, 19992, 4568, 3619, 4022, 38134, 168534, 4766, 13451, 6352, 106, 9367, 1850, 6932, 7859, 11742, 12128, 8426, 10436, 40530, 50578, 38101, 1046, 71, 696, 1764, 1472, 4878, 3755, 22198, 28289, 6222, 6562, 4222, 7030, 6711, 5100, 1566, 3229, 3624, 10478, 554, 42482, 3659, 7451, 14768, 3336, 2618, 3560, 2597, 642, 4523, 1758, 17575, 17600, 5450, 11344, 1110, 4196, 572, 1508, 3100, 2356, 1251, 1946, 4245, 32685, 52634, 5879, 4540, 4780, 3741, 3800, 26629, 3726, 2609, 6698, 9304, 5797, 14478, 35613, 37, 4516, 292, 3744, 2124, 993, 561, 1943, 18375, 13112, 5645, 13164, 6238, 1393, 1127, 1130, 2568, 950, 664, 1671, 8379, 284985, 7056, 12810, 22660, 33, 1568, 1570, 1245, 612, 4355, 1781, 298939, 141445, 127828, 61466, 233115, 79475, 13285, 354730, 200104, 136018, 165515, 115212, 101674, 237771, 125974, 119209, 52253, 93742, 64390, 159444, 180985, 166561, 38532, 162058, 116400, 167832, 218465, 119099, 1519, 132812, 41026, 254851, 70538, 72673, 43451, 39102, 20087, 27117, 27165, 72613, 309, 31531, 127392, 44146, 23769, 199461, 93201, 188644, 271437, 199848, 171766, 209125, 276863, 205940, 171740, 440507, 3602, 249365, 105892, 141717, 352209, 419029, 149021, 334890, 360930, 413012, 259389, 247448, 57380, 68549, 99987, 50416, 121429, 170629, 234985, 291256, 103121, 100759, 188674, 345308, 129642, 78327, 240521, 93778, 124517, 144705, 413560, 337881, 502981, 200090, 279936, 216353, 155417, 45106, 97611, 195105, 8483, 217852, 100082, 146530, 81254, 100233, 122297, 93391, 71132, 67150, 16001, 50049, 86612, 63650, 186182, 58051, 77394, 143852, 102536, 98002, 62288, 49415, 52566, 40627, 59453, 388, 79769, 26064, 99316, 91713, 128873, 60735, 2941, 201717, 114635, 5410, 288262, 56510, 200048, 61468, 256130, 57343, 3147, 100529, 5163, 60984, 74044, 108182, 83503, 91466, 113418, 125109, 4516, 278729, 125507, 116761, 58639, 98699, 104720, 115872, 114417, 79865, 53562, 135743, 75961, 104308, 145546, 137103, 92080, 42126, 64214, 133724, 80832, 52808, 23883, 77624, 24619, 64643, 171200, 30281, 28651, 250371, 148553, 43543, 101848, 365465, 242121, 63446, 6867, 147045, 172882, 115272, 7009, 118688, 77306, 356879, 191660, 104696, 148222, 74799, 21217, 72965, 122917, 66346, 297127, 81423, 218108, 136035, 191491, 138154, 218078, 67469, 6560, 217895, 112431, 224568, 175167, 28812, 185547, 149775, 60448, 112603, 193882, 73585, 15143, 219177, 127790, 118357, 306841, 170389, 277052, 75056, 4191, 325498, 55954, 128734, 5772, 18907, 81639, 47058, 318080, 176659, 216723, 117344, 164785, 107361, 105511, 50134, 4674, 40307, 81751, 25183, 443756, 49896, 173698, 139376, 124386, 155, 76831, 32030, 3025, 61200, 96199, 139506, 50170, 87016, 128704, 15720, 748, 512, 1, 5, 13006, 4, 21420, 5401, 31713, 12, 27763, 8, 22042, 1678, 10691, 32941, 20157, 44, 15292, 24961, 42822, 28, 14833, 40, 36989, 6245, 44483, 0, 22677, 4, 88944, 25, 13074, 0, 15412, 15817, 19658, 9224, 9542, 0, 11174, 14122, 15645, 10835, 14180, 4585, 4840, 19531, 15992, 15709, 66679, 6895, 4274, 59902, 139098, 43741, 64288, 6060, 41498, 1576, 42078, 69280, 722, 23759, 12426, 20486, 1746, 21601, 7922, 13063, 22133, 8243, 19338, 765, 9468, 34670, 8623, 12903, 12018, 58701, 857, 19713, 16784, 73963, 3449, 16232, 17848, 3, 5824, 15967, 9268, 39418, 11803, 3575, 25509, 7899], "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"], ["3L"]], "hovertemplate": "contig=%{customdata[0]}<br>sample_id=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "3L", "marker": {"color": "#2CA02C", "pattern": {"shape": ""}}, "name": "3L", "offsetgroup": "3L", "orientation": "v", "showlegend": true, "textposition": "auto", "type": "bar", "x": ["GH_01", "GH_02", "GH_03", "GH_04", "GH_05", "GH_06", "GH_07", "GH_08", "GH_09", "GH_10", "GH_11", "GH_12", "GH_13", "GH_14", "GH_15", "GH_16", "GH_17", "GH_18", "GH_19", "GH_20", "GH_21", "GH_22", "GH_23", "GH_24", "GH_25", "GH_26", "GH_27", "GH_28", "GH_29", "GH_30", "GH_31", "GH_32", "GH_33", "GH_34", "GH_35", "GH_36", "GH_37", "GH_38", "GH_39", "GH_40_low_vol", "GH_41", "GH_42", "GH_43", "GH_44", "GH_45", "GH_46", "GH_47", "GH_48", "GH_49", "GH_50", "GH_51", "GH_52", "GH_53", "GH_54", "GH_55", "GH_56", "GH_57", "GH_58", "GH_59", "GH_60", "GH_61", "GH_62", "GH_63", "GH_64", "GH_65_low_vol", "GH_66", "GH_67", "GH_68", "GH_69", "GH_70", "GH_71", "GH_72", "GH_73", "GH_74", "GH_75", "GH_76", "GH_77", "GH_78", "GH_79", "GH_80_low_vol", "GH_81", "GH_82", "GH_83", "GH_84", "GH_85", "GH_86", "GH_87", "GH_88", "GH_89", "GH_90", "GH_91", "GH_92", "GH_93", "GH_94", "GH_95", "GH_Negative", "GM_01", "GM_02", "GM_03", "GM_04", "GM_05", "GM_06", "GM_07", "GM_08", "GM_09", "GM_10", "GM_11", "GM_12", "GM_13", "GM_14", "GM_15", "GM_16", "GM_17", "GM_18", "GM_19", "GM_20", "GM_21", "GM_22", "GM_23", "GM_24", "GM_25", "GM_26", "GM_27", "GM_28", "GM_29", "GM_30", "GM_31", "GM_32", "GM_33", "GM_34", "GM_35", "GM_36", "GM_37", "GM_38", "GM_39", "GM_40", "GM_41", "GM_42", "GM_43", "GM_44", "GM_45", "GM_46", "GM_47", "GM_48", "GM_49", "GM_50", "GM_51", "GM_52", "GM_53", "GM_54", "GM_55", "GM_56", "GM_57", "GM_58", "GM_59", "GM_60", "GM_61", "GM_62", "GM_63", "GM_64", "GM_65", "GM_66", "GM_67", "GM_68", "GM_69", "GM_70", "GM_71", "GM_72", "GM_73", "GM_74", "GM_75", "GM_76", "GM_77", "GM_78", "GM_79", "GM_80", "GM_81", "GM_82", "GM_83", "GM_84", "GM_85", "GM_86", "GM_87", "GM_88", "GM_89", "GM_90", "GM_91", "GM_92", "GM_93", "GM_94", "GM_95", "GM_96", "Siaya_Delta_Alive_01", "Siaya_Delta_Alive_02", "Siaya_Delta_Alive_03", "Siaya_Delta_Alive_04", "Siaya_Delta_Alive_05", "Siaya_Delta_Alive_06", "Siaya_Delta_Alive_07", "Siaya_Delta_Alive_08", "Siaya_Delta_Alive_09", "Siaya_Delta_Alive_10", "Siaya_Delta_Alive_100", "Siaya_Delta_Alive_101", "Siaya_Delta_Alive_102", "Siaya_Delta_Alive_103", "Siaya_Delta_Alive_104", "Siaya_Delta_Alive_105", "Siaya_Delta_Alive_106", "Siaya_Delta_Alive_107", "Siaya_Delta_Alive_108", "Siaya_Delta_Alive_109", "Siaya_Delta_Alive_11", "Siaya_Delta_Alive_110", "Siaya_Delta_Alive_111", "Siaya_Delta_Alive_112", "Siaya_Delta_Alive_113", "Siaya_Delta_Alive_114", "Siaya_Delta_Alive_115", "Siaya_Delta_Alive_116", "Siaya_Delta_Alive_117", "Siaya_Delta_Alive_118", "Siaya_Delta_Alive_119", "Siaya_Delta_Alive_12", "Siaya_Delta_Alive_120", "Siaya_Delta_Alive_121", "Siaya_Delta_Alive_122", "Siaya_Delta_Alive_123", "Siaya_Delta_Alive_124", "Siaya_Delta_Alive_125", "Siaya_Delta_Alive_126", "Siaya_Delta_Alive_127", "Siaya_Delta_Alive_128", "Siaya_Delta_Alive_129", "Siaya_Delta_Alive_13", "Siaya_Delta_Alive_130", "Siaya_Delta_Alive_131", "Siaya_Delta_Alive_14", "Siaya_Delta_Alive_15", "Siaya_Delta_Alive_16", "Siaya_Delta_Alive_17", "Siaya_Delta_Alive_18", "Siaya_Delta_Alive_19", "Siaya_Delta_Alive_20", "Siaya_Delta_Alive_21", "Siaya_Delta_Alive_22", "Siaya_Delta_Alive_23", "Siaya_Delta_Alive_24", "Siaya_Delta_Alive_25", "Siaya_Delta_Alive_26", "Siaya_Delta_Alive_27", "Siaya_Delta_Alive_28", "Siaya_Delta_Alive_29", "Siaya_Delta_Alive_30", "Siaya_Delta_Alive_31", "Siaya_Delta_Alive_32", "Siaya_Delta_Alive_33", "Siaya_Delta_Alive_34", "Siaya_Delta_Alive_35", "Siaya_Delta_Alive_36", "Siaya_Delta_Alive_37", "Siaya_Delta_Alive_38", "Siaya_Delta_Alive_39", "Siaya_Delta_Alive_40", "Siaya_Delta_Alive_41", "Siaya_Delta_Alive_42", "Siaya_Delta_Alive_43", "Siaya_Delta_Alive_44", "Siaya_Delta_Alive_45", "Siaya_Delta_Alive_46", "Siaya_Delta_Alive_47", "Siaya_Delta_Alive_48", "Siaya_Delta_Alive_49", "Siaya_Delta_Alive_50", "Siaya_Delta_Alive_51", "Siaya_Delta_Alive_52", "Siaya_Delta_Alive_53", "Siaya_Delta_Alive_54", "Siaya_Delta_Alive_55", "Siaya_Delta_Alive_56", "Siaya_Delta_Alive_57", "Siaya_Delta_Alive_58", "Siaya_Delta_Alive_59", "Siaya_Delta_Alive_60", "Siaya_Delta_Alive_61", "Siaya_Delta_Alive_62", "Siaya_Delta_Alive_63", "Siaya_Delta_Alive_64", "Siaya_Delta_Alive_65", "Siaya_Delta_Alive_66", "Siaya_Delta_Alive_67", "Siaya_Delta_Alive_68", "Siaya_Delta_Alive_69", "Siaya_Delta_Alive_70", "Siaya_Delta_Alive_71", "Siaya_Delta_Alive_72", "Siaya_Delta_Alive_73", "Siaya_Delta_Alive_74", "Siaya_Delta_Alive_75", "Siaya_Delta_Alive_76", "Siaya_Delta_Alive_77", "Siaya_Delta_Alive_78", "Siaya_Delta_Alive_79", "Siaya_Delta_Alive_80", "Siaya_Delta_Alive_81", "Siaya_Delta_Alive_82", "Siaya_Delta_Alive_83", "Siaya_Delta_Alive_84", "Siaya_Delta_Alive_85", "Siaya_Delta_Alive_86", "Siaya_Delta_Alive_87", "Siaya_Delta_Alive_88", "Siaya_Delta_Alive_89", "Siaya_Delta_Alive_90", "Siaya_Delta_Alive_91", "Siaya_Delta_Alive_92", "Siaya_Delta_Alive_93", "Siaya_Delta_Alive_94", "Siaya_Delta_Alive_95", "Siaya_Delta_Alive_96", "Siaya_Delta_Alive_97", "Siaya_Delta_Alive_98", "Siaya_Delta_Alive_99", "Siaya_Delta_Alive_Negative", "Siaya_Delta_Dead_01", "Siaya_Delta_Dead_02", "Siaya_Delta_Dead_03", "Siaya_Delta_Dead_04", "Siaya_Delta_Dead_05", "Siaya_Delta_Dead_06", "Siaya_Delta_Dead_07", "Siaya_Delta_Dead_08", "Siaya_Delta_Dead_09", "Siaya_Delta_Dead_10", "Siaya_Delta_Dead_100", "Siaya_Delta_Dead_101", "Siaya_Delta_Dead_102", "Siaya_Delta_Dead_103", "Siaya_Delta_Dead_104", "Siaya_Delta_Dead_105", "Siaya_Delta_Dead_106", "Siaya_Delta_Dead_107", "Siaya_Delta_Dead_108", "Siaya_Delta_Dead_109", "Siaya_Delta_Dead_11", "Siaya_Delta_Dead_110", "Siaya_Delta_Dead_111", "Siaya_Delta_Dead_112", "Siaya_Delta_Dead_113", "Siaya_Delta_Dead_114", "Siaya_Delta_Dead_115", "Siaya_Delta_Dead_116", "Siaya_Delta_Dead_117", "Siaya_Delta_Dead_118", "Siaya_Delta_Dead_119", "Siaya_Delta_Dead_12", "Siaya_Delta_Dead_120", "Siaya_Delta_Dead_121", "Siaya_Delta_Dead_122", "Siaya_Delta_Dead_123", "Siaya_Delta_Dead_124", "Siaya_Delta_Dead_125", "Siaya_Delta_Dead_126", "Siaya_Delta_Dead_127", "Siaya_Delta_Dead_128", "Siaya_Delta_Dead_129", "Siaya_Delta_Dead_13", "Siaya_Delta_Dead_130", "Siaya_Delta_Dead_131", "Siaya_Delta_Dead_14", "Siaya_Delta_Dead_15", "Siaya_Delta_Dead_16", "Siaya_Delta_Dead_17", "Siaya_Delta_Dead_18", "Siaya_Delta_Dead_19", "Siaya_Delta_Dead_20", "Siaya_Delta_Dead_21", "Siaya_Delta_Dead_22", "Siaya_Delta_Dead_23", "Siaya_Delta_Dead_24", "Siaya_Delta_Dead_25", "Siaya_Delta_Dead_26", "Siaya_Delta_Dead_27", "Siaya_Delta_Dead_28", "Siaya_Delta_Dead_29", "Siaya_Delta_Dead_30", "Siaya_Delta_Dead_31", "Siaya_Delta_Dead_32", "Siaya_Delta_Dead_33", "Siaya_Delta_Dead_34", "Siaya_Delta_Dead_35", "Siaya_Delta_Dead_36", "Siaya_Delta_Dead_37", "Siaya_Delta_Dead_38", "Siaya_Delta_Dead_39", "Siaya_Delta_Dead_40", "Siaya_Delta_Dead_41", "Siaya_Delta_Dead_42", "Siaya_Delta_Dead_43", "Siaya_Delta_Dead_44", "Siaya_Delta_Dead_45", "Siaya_Delta_Dead_46", "Siaya_Delta_Dead_47", "Siaya_Delta_Dead_48", "Siaya_Delta_Dead_49", "Siaya_Delta_Dead_50", "Siaya_Delta_Dead_51", "Siaya_Delta_Dead_52", "Siaya_Delta_Dead_53", "Siaya_Delta_Dead_54", "Siaya_Delta_Dead_55", "Siaya_Delta_Dead_56", "Siaya_Delta_Dead_57", "Siaya_Delta_Dead_58", "Siaya_Delta_Dead_59", "Siaya_Delta_Dead_60", "Siaya_Delta_Dead_61", "Siaya_Delta_Dead_62", "Siaya_Delta_Dead_63", "Siaya_Delta_Dead_64", "Siaya_Delta_Dead_65", "Siaya_Delta_Dead_66", "Siaya_Delta_Dead_67", "Siaya_Delta_Dead_68", "Siaya_Delta_Dead_69", "Siaya_Delta_Dead_70", "Siaya_Delta_Dead_71", "Siaya_Delta_Dead_72", "Siaya_Delta_Dead_73", "Siaya_Delta_Dead_74", "Siaya_Delta_Dead_75", "Siaya_Delta_Dead_76", "Siaya_Delta_Dead_77", "Siaya_Delta_Dead_78", "Siaya_Delta_Dead_79", "Siaya_Delta_Dead_80", "Siaya_Delta_Dead_81", "Siaya_Delta_Dead_82", "Siaya_Delta_Dead_83", "Siaya_Delta_Dead_84", "Siaya_Delta_Dead_85", "Siaya_Delta_Dead_86", "Siaya_Delta_Dead_87", "Siaya_Delta_Dead_88", "Siaya_Delta_Dead_89", "Siaya_Delta_Dead_90", "Siaya_Delta_Dead_91", "Siaya_Delta_Dead_92", "Siaya_Delta_Dead_93", "Siaya_Delta_Dead_94", "Siaya_Delta_Dead_95", "Siaya_Delta_Dead_96", "Siaya_Delta_Dead_97", "Siaya_Delta_Dead_98", "Siaya_Delta_Dead_99", "Siaya_Delta_Dead_Negative", "VK7_Negative", "VK7_alive_01", "VK7_alive_02", "VK7_alive_03", "VK7_alive_04", "VK7_alive_05", "VK7_alive_06", "VK7_alive_07", "VK7_alive_08", "VK7_alive_09", "VK7_alive_10", "VK7_alive_11", "VK7_alive_12", "VK7_alive_13", "VK7_alive_14", "VK7_alive_15", "VK7_alive_16", "VK7_alive_17", "VK7_alive_18", "VK7_alive_19", "VK7_alive_20", "VK7_alive_21", "VK7_alive_22", "VK7_alive_23", "VK7_alive_24", "VK7_alive_25", "VK7_alive_26", "VK7_alive_27", "VK7_alive_28", "VK7_alive_29", "VK7_alive_30", "VK7_alive_31", "VK7_alive_32", "VK7_alive_33", "VK7_alive_34", "VK7_alive_35", "VK7_alive_36", "VK7_alive_37", "VK7_alive_38", "VK7_alive_39", "VK7_alive_40", "VK7_alive_41", "VK7_alive_42", "VK7_alive_43", "VK7_alive_44", "VK7_alive_45", "VK7_alive_46", "VK7_alive_47", "VK7_dead_01", "VK7_dead_02", "VK7_dead_03", "VK7_dead_04", "VK7_dead_04_dil", "VK7_dead_05", "VK7_dead_06", "VK7_dead_07", "VK7_dead_08", "VK7_dead_09", "VK7_dead_10", "VK7_dead_10_dil", "VK7_dead_11", "VK7_dead_12", "VK7_dead_13", "VK7_dead_14", "VK7_dead_15", "VK7_dead_16", "VK7_dead_16_dil", "VK7_dead_17", "VK7_dead_18", "VK7_dead_19", "VK7_dead_20", "VK7_dead_21", "VK7_dead_22", "VK7_dead_22_dil", "VK7_dead_23", "VK7_dead_24", "VK7_dead_25", "VK7_dead_26", "VK7_dead_27", "VK7_dead_28", "VK7_dead_28_dil", "VK7_dead_29", "VK7_dead_30", "VK7_dead_31", "VK7_dead_32", "VK7_dead_33", "VK7_dead_34", "VK7_dead_34_dil", "VK7_dead_35", "VK7_dead_36", "VK7_dead_37", "VK7_dead_38", "VK7_dead_39", "VK7_dead_40", "VK7_dead_41", "VK7_dead_42"], "xaxis": "x", "y": [10717, 503, 131, 187, 1070, 1347, 86, 307, 478, 724, 938, 653, 1249, 1558, 429, 811, 800, 529, 2380, 265, 2611, 604, 434, 166, 3063, 4744, 1316, 268, 1267, 6568, 118, 681, 2498, 2778, 1379, 134, 9239, 1482, 1751, 2300, 1035, 913, 2928, 823, 1288, 463, 1066, 211, 12707, 8982, 28915, 2085, 2747, 1234, 4903, 3896, 1411, 540, 1076, 104, 40822, 10223, 1475, 7304, 20, 733, 1770, 820, 845, 403, 279, 82, 4903, 3769, 1653, 4701, 816, 1410, 21544, 324, 3851, 1014, 1146, 343, 12399, 83927, 886, 3188, 108, 53, 4227, 196, 1978, 520, 4296, 474, 2151, 1558, 8037, 5968, 2810, 282, 66, 226, 589, 278, 729, 676, 2476, 11952, 451, 968, 1044, 1561, 639, 781, 598, 574, 955, 545, 793, 2539, 933, 711, 1582, 614, 1784, 415, 483, 120, 440, 422, 3316, 2652, 2043, 1413, 143, 751, 169, 319, 265, 435, 104, 418, 1174, 3005, 2549, 1552, 722, 1592, 709, 533, 4394, 546, 317, 1349, 2411, 2042, 1623, 4407, 19, 757, 22, 419, 418, 315, 249, 133, 6160, 1661, 1769, 4769, 2249, 308, 492, 476, 291, 128, 169, 151, 2442, 150367, 1271, 1831, 2808, 21, 206, 298, 245, 177, 483, 45, 17147, 30065, 14327, 13150, 23090, 21103, 6713, 47848, 58808, 13426, 21832, 15495, 9274, 21829, 18017, 15949, 7097, 11254, 14444, 25466, 74173, 23118, 7503, 22444, 16325, 13522, 23770, 10120, 122, 14033, 3432, 36980, 8585, 14413, 9315, 8942, 3458, 6295, 8834, 14466, 105, 8425, 18594, 7642, 4986, 24973, 11360, 29163, 45191, 45318, 26005, 21132, 65515, 60918, 32469, 57943, 5647, 30968, 12484, 17766, 57416, 86916, 28981, 48488, 44240, 66702, 27861, 28028, 6849, 8142, 10454, 10830, 28280, 31877, 51499, 43040, 13173, 18903, 27903, 38280, 14811, 10493, 25532, 9615, 22693, 22216, 54278, 28033, 76742, 24235, 30911, 24193, 27221, 4501, 13665, 26522, 788, 37274, 9567, 24203, 16324, 15842, 19795, 24249, 20490, 15639, 2664, 11100, 17396, 16626, 55688, 15450, 22220, 43521, 21307, 28274, 11933, 12206, 12009, 9043, 11302, 204, 25473, 4485, 22644, 21360, 27500, 21744, 1298, 15401, 28848, 119, 59390, 10439, 29402, 8763, 22693, 17303, 1177, 12226, 271, 7625, 5406, 24421, 18690, 18461, 13180, 17554, 8503, 58173, 22792, 16264, 15940, 14031, 24327, 20109, 18077, 22811, 5961, 14687, 14886, 9721, 14199, 18104, 17965, 4557, 10794, 16227, 20869, 15061, 9318, 16720, 7687, 16075, 22557, 6827, 12941, 53470, 25715, 6977, 11962, 87466, 35363, 7324, 53, 22618, 28850, 17495, 12462, 15475, 11418, 87956, 28933, 21456, 22856, 9186, 605, 12021, 18253, 8027, 84818, 15697, 34923, 40210, 34854, 23704, 28393, 9217, 168, 23152, 18725, 26267, 27952, 2868, 44929, 24580, 10980, 24635, 22535, 7781, 143, 37298, 13030, 17795, 57691, 35630, 109360, 12803, 95, 56627, 5303, 21251, 203, 3583, 20631, 15613, 106301, 63610, 98997, 43195, 43629, 24123, 25357, 10626, 97, 12406, 26089, 6869, 150974, 16605, 69927, 48626, 28695, 104, 23834, 6959, 100, 11817, 23784, 10366, 7191, 8603, 20833, 3783, 20, 409, 4, 13, 5858, 0, 16397, 2440, 10525, 0, 11372, 8, 7297, 33, 4350, 15214, 5049, 8, 7678, 19291, 10909, 0, 4769, 23, 22685, 2607, 11124, 4, 12616, 0, 23839, 0, 4683, 0, 5546, 6548, 13907, 7133, 4924, 0, 4174, 8418, 11207, 4691, 8113, 2957, 5500, 11005, 5627, 4368, 22567, 5514, 74, 40624, 67739, 13386, 18442, 2542, 12063, 67, 13204, 13582, 1524, 4598, 2535, 11930, 243, 7383, 2981, 5951, 5144, 5670, 7010, 133, 3412, 8088, 1417, 4208, 6895, 19457, 87, 9650, 8219, 34854, 449, 6981, 6716, 4, 4859, 4720, 9920, 22950, 6633, 950, 14511, 3525], "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"], ["3R"]], "hovertemplate": "contig=%{customdata[0]}<br>sample_id=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "3R", "marker": {"color": "#D62728", "pattern": {"shape": ""}}, "name": "3R", "offsetgroup": "3R", "orientation": "v", "showlegend": true, "textposition": "auto", "type": "bar", "x": ["GH_01", "GH_02", "GH_03", "GH_04", "GH_05", "GH_06", "GH_07", "GH_08", "GH_09", "GH_10", "GH_11", "GH_12", "GH_13", "GH_14", "GH_15", "GH_16", "GH_17", "GH_18", "GH_19", "GH_20", "GH_21", "GH_22", "GH_23", "GH_24", "GH_25", "GH_26", "GH_27", "GH_28", "GH_29", "GH_30", "GH_31", "GH_32", "GH_33", "GH_34", "GH_35", "GH_36", "GH_37", "GH_38", "GH_39", "GH_40_low_vol", "GH_41", "GH_42", "GH_43", "GH_44", "GH_45", "GH_46", "GH_47", "GH_48", "GH_49", "GH_50", "GH_51", "GH_52", "GH_53", "GH_54", "GH_55", "GH_56", "GH_57", "GH_58", "GH_59", "GH_60", "GH_61", "GH_62", "GH_63", "GH_64", "GH_65_low_vol", "GH_66", "GH_67", "GH_68", "GH_69", "GH_70", "GH_71", "GH_72", "GH_73", "GH_74", "GH_75", "GH_76", "GH_77", "GH_78", "GH_79", "GH_80_low_vol", "GH_81", "GH_82", "GH_83", "GH_84", "GH_85", "GH_86", "GH_87", "GH_88", "GH_89", "GH_90", "GH_91", "GH_92", "GH_93", "GH_94", "GH_95", "GH_Negative", "GM_01", "GM_02", "GM_03", "GM_04", "GM_05", "GM_06", "GM_07", "GM_08", "GM_09", "GM_10", "GM_11", "GM_12", "GM_13", "GM_14", "GM_15", "GM_16", "GM_17", "GM_18", "GM_19", "GM_20", "GM_21", "GM_22", "GM_23", "GM_24", "GM_25", "GM_26", "GM_27", "GM_28", "GM_29", "GM_30", "GM_31", "GM_32", "GM_33", "GM_34", "GM_35", "GM_36", "GM_37", "GM_38", "GM_39", "GM_40", "GM_41", "GM_42", "GM_43", "GM_44", "GM_45", "GM_46", "GM_47", "GM_48", "GM_49", "GM_50", "GM_51", "GM_52", "GM_53", "GM_54", "GM_55", "GM_56", "GM_57", "GM_58", "GM_59", "GM_60", "GM_61", "GM_62", "GM_63", "GM_64", "GM_65", "GM_66", "GM_67", "GM_68", "GM_69", "GM_70", "GM_71", "GM_72", "GM_73", "GM_74", "GM_75", "GM_76", "GM_77", "GM_78", "GM_79", "GM_80", "GM_81", "GM_82", "GM_83", "GM_84", "GM_85", "GM_86", "GM_87", "GM_88", "GM_89", "GM_90", "GM_91", "GM_92", "GM_93", "GM_94", "GM_95", "GM_96", "Siaya_Delta_Alive_01", "Siaya_Delta_Alive_02", "Siaya_Delta_Alive_03", "Siaya_Delta_Alive_04", "Siaya_Delta_Alive_05", "Siaya_Delta_Alive_06", "Siaya_Delta_Alive_07", "Siaya_Delta_Alive_08", "Siaya_Delta_Alive_09", "Siaya_Delta_Alive_10", "Siaya_Delta_Alive_100", "Siaya_Delta_Alive_101", "Siaya_Delta_Alive_102", "Siaya_Delta_Alive_103", "Siaya_Delta_Alive_104", "Siaya_Delta_Alive_105", "Siaya_Delta_Alive_106", "Siaya_Delta_Alive_107", "Siaya_Delta_Alive_108", "Siaya_Delta_Alive_109", "Siaya_Delta_Alive_11", "Siaya_Delta_Alive_110", "Siaya_Delta_Alive_111", "Siaya_Delta_Alive_112", "Siaya_Delta_Alive_113", "Siaya_Delta_Alive_114", "Siaya_Delta_Alive_115", "Siaya_Delta_Alive_116", "Siaya_Delta_Alive_117", "Siaya_Delta_Alive_118", "Siaya_Delta_Alive_119", "Siaya_Delta_Alive_12", "Siaya_Delta_Alive_120", "Siaya_Delta_Alive_121", "Siaya_Delta_Alive_122", "Siaya_Delta_Alive_123", "Siaya_Delta_Alive_124", "Siaya_Delta_Alive_125", "Siaya_Delta_Alive_126", "Siaya_Delta_Alive_127", "Siaya_Delta_Alive_128", "Siaya_Delta_Alive_129", "Siaya_Delta_Alive_13", "Siaya_Delta_Alive_130", "Siaya_Delta_Alive_131", "Siaya_Delta_Alive_14", "Siaya_Delta_Alive_15", "Siaya_Delta_Alive_16", "Siaya_Delta_Alive_17", "Siaya_Delta_Alive_18", "Siaya_Delta_Alive_19", "Siaya_Delta_Alive_20", "Siaya_Delta_Alive_21", "Siaya_Delta_Alive_22", "Siaya_Delta_Alive_23", "Siaya_Delta_Alive_24", "Siaya_Delta_Alive_25", "Siaya_Delta_Alive_26", "Siaya_Delta_Alive_27", "Siaya_Delta_Alive_28", "Siaya_Delta_Alive_29", "Siaya_Delta_Alive_30", "Siaya_Delta_Alive_31", "Siaya_Delta_Alive_32", "Siaya_Delta_Alive_33", "Siaya_Delta_Alive_34", "Siaya_Delta_Alive_35", "Siaya_Delta_Alive_36", "Siaya_Delta_Alive_37", "Siaya_Delta_Alive_38", "Siaya_Delta_Alive_39", "Siaya_Delta_Alive_40", "Siaya_Delta_Alive_41", "Siaya_Delta_Alive_42", "Siaya_Delta_Alive_43", "Siaya_Delta_Alive_44", "Siaya_Delta_Alive_45", "Siaya_Delta_Alive_46", "Siaya_Delta_Alive_47", "Siaya_Delta_Alive_48", "Siaya_Delta_Alive_49", "Siaya_Delta_Alive_50", "Siaya_Delta_Alive_51", "Siaya_Delta_Alive_52", "Siaya_Delta_Alive_53", "Siaya_Delta_Alive_54", "Siaya_Delta_Alive_55", "Siaya_Delta_Alive_56", "Siaya_Delta_Alive_57", "Siaya_Delta_Alive_58", "Siaya_Delta_Alive_59", "Siaya_Delta_Alive_60", "Siaya_Delta_Alive_61", "Siaya_Delta_Alive_62", "Siaya_Delta_Alive_63", "Siaya_Delta_Alive_64", "Siaya_Delta_Alive_65", "Siaya_Delta_Alive_66", "Siaya_Delta_Alive_67", "Siaya_Delta_Alive_68", "Siaya_Delta_Alive_69", "Siaya_Delta_Alive_70", "Siaya_Delta_Alive_71", "Siaya_Delta_Alive_72", "Siaya_Delta_Alive_73", "Siaya_Delta_Alive_74", "Siaya_Delta_Alive_75", "Siaya_Delta_Alive_76", "Siaya_Delta_Alive_77", "Siaya_Delta_Alive_78", "Siaya_Delta_Alive_79", "Siaya_Delta_Alive_80", "Siaya_Delta_Alive_81", "Siaya_Delta_Alive_82", "Siaya_Delta_Alive_83", "Siaya_Delta_Alive_84", "Siaya_Delta_Alive_85", "Siaya_Delta_Alive_86", "Siaya_Delta_Alive_87", "Siaya_Delta_Alive_88", "Siaya_Delta_Alive_89", "Siaya_Delta_Alive_90", "Siaya_Delta_Alive_91", "Siaya_Delta_Alive_92", "Siaya_Delta_Alive_93", "Siaya_Delta_Alive_94", "Siaya_Delta_Alive_95", "Siaya_Delta_Alive_96", "Siaya_Delta_Alive_97", "Siaya_Delta_Alive_98", "Siaya_Delta_Alive_99", "Siaya_Delta_Alive_Negative", "Siaya_Delta_Dead_01", "Siaya_Delta_Dead_02", "Siaya_Delta_Dead_03", "Siaya_Delta_Dead_04", "Siaya_Delta_Dead_05", "Siaya_Delta_Dead_06", "Siaya_Delta_Dead_07", "Siaya_Delta_Dead_08", "Siaya_Delta_Dead_09", "Siaya_Delta_Dead_10", "Siaya_Delta_Dead_100", "Siaya_Delta_Dead_101", "Siaya_Delta_Dead_102", "Siaya_Delta_Dead_103", "Siaya_Delta_Dead_104", "Siaya_Delta_Dead_105", "Siaya_Delta_Dead_106", "Siaya_Delta_Dead_107", "Siaya_Delta_Dead_108", "Siaya_Delta_Dead_109", "Siaya_Delta_Dead_11", "Siaya_Delta_Dead_110", "Siaya_Delta_Dead_111", "Siaya_Delta_Dead_112", "Siaya_Delta_Dead_113", "Siaya_Delta_Dead_114", "Siaya_Delta_Dead_115", "Siaya_Delta_Dead_116", "Siaya_Delta_Dead_117", "Siaya_Delta_Dead_118", "Siaya_Delta_Dead_119", "Siaya_Delta_Dead_12", "Siaya_Delta_Dead_120", "Siaya_Delta_Dead_121", "Siaya_Delta_Dead_122", "Siaya_Delta_Dead_123", "Siaya_Delta_Dead_124", "Siaya_Delta_Dead_125", "Siaya_Delta_Dead_126", "Siaya_Delta_Dead_127", "Siaya_Delta_Dead_128", "Siaya_Delta_Dead_129", "Siaya_Delta_Dead_13", "Siaya_Delta_Dead_130", "Siaya_Delta_Dead_131", "Siaya_Delta_Dead_14", "Siaya_Delta_Dead_15", "Siaya_Delta_Dead_16", "Siaya_Delta_Dead_17", "Siaya_Delta_Dead_18", "Siaya_Delta_Dead_19", "Siaya_Delta_Dead_20", "Siaya_Delta_Dead_21", "Siaya_Delta_Dead_22", "Siaya_Delta_Dead_23", "Siaya_Delta_Dead_24", "Siaya_Delta_Dead_25", "Siaya_Delta_Dead_26", "Siaya_Delta_Dead_27", "Siaya_Delta_Dead_28", "Siaya_Delta_Dead_29", "Siaya_Delta_Dead_30", "Siaya_Delta_Dead_31", "Siaya_Delta_Dead_32", "Siaya_Delta_Dead_33", "Siaya_Delta_Dead_34", "Siaya_Delta_Dead_35", "Siaya_Delta_Dead_36", "Siaya_Delta_Dead_37", "Siaya_Delta_Dead_38", "Siaya_Delta_Dead_39", "Siaya_Delta_Dead_40", "Siaya_Delta_Dead_41", "Siaya_Delta_Dead_42", "Siaya_Delta_Dead_43", "Siaya_Delta_Dead_44", "Siaya_Delta_Dead_45", "Siaya_Delta_Dead_46", "Siaya_Delta_Dead_47", "Siaya_Delta_Dead_48", "Siaya_Delta_Dead_49", "Siaya_Delta_Dead_50", "Siaya_Delta_Dead_51", "Siaya_Delta_Dead_52", "Siaya_Delta_Dead_53", "Siaya_Delta_Dead_54", "Siaya_Delta_Dead_55", "Siaya_Delta_Dead_56", "Siaya_Delta_Dead_57", "Siaya_Delta_Dead_58", "Siaya_Delta_Dead_59", "Siaya_Delta_Dead_60", "Siaya_Delta_Dead_61", "Siaya_Delta_Dead_62", "Siaya_Delta_Dead_63", "Siaya_Delta_Dead_64", "Siaya_Delta_Dead_65", "Siaya_Delta_Dead_66", "Siaya_Delta_Dead_67", "Siaya_Delta_Dead_68", "Siaya_Delta_Dead_69", "Siaya_Delta_Dead_70", "Siaya_Delta_Dead_71", "Siaya_Delta_Dead_72", "Siaya_Delta_Dead_73", "Siaya_Delta_Dead_74", "Siaya_Delta_Dead_75", "Siaya_Delta_Dead_76", "Siaya_Delta_Dead_77", "Siaya_Delta_Dead_78", "Siaya_Delta_Dead_79", "Siaya_Delta_Dead_80", "Siaya_Delta_Dead_81", "Siaya_Delta_Dead_82", "Siaya_Delta_Dead_83", "Siaya_Delta_Dead_84", "Siaya_Delta_Dead_85", "Siaya_Delta_Dead_86", "Siaya_Delta_Dead_87", "Siaya_Delta_Dead_88", "Siaya_Delta_Dead_89", "Siaya_Delta_Dead_90", "Siaya_Delta_Dead_91", "Siaya_Delta_Dead_92", "Siaya_Delta_Dead_93", "Siaya_Delta_Dead_94", "Siaya_Delta_Dead_95", "Siaya_Delta_Dead_96", "Siaya_Delta_Dead_97", "Siaya_Delta_Dead_98", "Siaya_Delta_Dead_99", "Siaya_Delta_Dead_Negative", "VK7_Negative", "VK7_alive_01", "VK7_alive_02", "VK7_alive_03", "VK7_alive_04", "VK7_alive_05", "VK7_alive_06", "VK7_alive_07", "VK7_alive_08", "VK7_alive_09", "VK7_alive_10", "VK7_alive_11", "VK7_alive_12", "VK7_alive_13", "VK7_alive_14", "VK7_alive_15", "VK7_alive_16", "VK7_alive_17", "VK7_alive_18", "VK7_alive_19", "VK7_alive_20", "VK7_alive_21", "VK7_alive_22", "VK7_alive_23", "VK7_alive_24", "VK7_alive_25", "VK7_alive_26", "VK7_alive_27", "VK7_alive_28", "VK7_alive_29", "VK7_alive_30", "VK7_alive_31", "VK7_alive_32", "VK7_alive_33", "VK7_alive_34", "VK7_alive_35", "VK7_alive_36", "VK7_alive_37", "VK7_alive_38", "VK7_alive_39", "VK7_alive_40", "VK7_alive_41", "VK7_alive_42", "VK7_alive_43", "VK7_alive_44", "VK7_alive_45", "VK7_alive_46", "VK7_alive_47", "VK7_dead_01", "VK7_dead_02", "VK7_dead_03", "VK7_dead_04", "VK7_dead_04_dil", "VK7_dead_05", "VK7_dead_06", "VK7_dead_07", "VK7_dead_08", "VK7_dead_09", "VK7_dead_10", "VK7_dead_10_dil", "VK7_dead_11", "VK7_dead_12", "VK7_dead_13", "VK7_dead_14", "VK7_dead_15", "VK7_dead_16", "VK7_dead_16_dil", "VK7_dead_17", "VK7_dead_18", "VK7_dead_19", "VK7_dead_20", "VK7_dead_21", "VK7_dead_22", "VK7_dead_22_dil", "VK7_dead_23", "VK7_dead_24", "VK7_dead_25", "VK7_dead_26", "VK7_dead_27", "VK7_dead_28", "VK7_dead_28_dil", "VK7_dead_29", "VK7_dead_30", "VK7_dead_31", "VK7_dead_32", "VK7_dead_33", "VK7_dead_34", "VK7_dead_34_dil", "VK7_dead_35", "VK7_dead_36", "VK7_dead_37", "VK7_dead_38", "VK7_dead_39", "VK7_dead_40", "VK7_dead_41", "VK7_dead_42"], "xaxis": "x", "y": [33885, 1261, 790, 1205, 2259, 2998, 170, 1009, 1484, 2208, 2724, 1170, 4137, 8938, 1765, 2898, 2062, 1168, 7315, 960, 7371, 2025, 1438, 992, 1871, 9514, 3783, 1259, 4859, 19442, 1312, 1834, 6117, 5678, 6059, 696, 24563, 4865, 3855, 4431, 1806, 1744, 10257, 2481, 4302, 977, 3391, 1079, 41500, 24293, 72760, 10185, 13396, 3672, 15348, 10345, 6224, 2890, 3150, 1365, 90253, 26492, 2792, 14904, 118, 1533, 2836, 3575, 1933, 833, 1093, 1305, 9897, 8665, 3739, 9301, 1621, 3036, 42850, 1235, 12679, 2408, 2668, 1922, 29971, 147296, 2665, 6874, 2059, 62, 7791, 1062, 3760, 3147, 6355, 2780, 3712, 3891, 21119, 42154, 37798, 440, 129, 426, 989, 489, 1585, 2063, 11184, 16464, 1551, 4465, 1870, 2809, 4798, 2431, 662, 722, 1668, 1326, 1113, 32194, 1767, 1591, 7649, 5905, 1551, 1808, 1009, 306, 1154, 848, 16683, 12723, 4232, 6503, 594, 3466, 531, 1215, 2272, 930, 410, 890, 2112, 21156, 19874, 4053, 2492, 2150, 3089, 2850, 11182, 2274, 1783, 2751, 5121, 3848, 6017, 25002, 91, 3538, 170, 2165, 917, 457, 311, 349, 11461, 5179, 4942, 9124, 6204, 715, 830, 747, 1019, 479, 438, 330, 4789, 174622, 3098, 10761, 12439, 45, 710, 734, 816, 280, 2090, 273, 110246, 68475, 41518, 25013, 87819, 40817, 13854, 159695, 99794, 58688, 85658, 52592, 47840, 91645, 53831, 51180, 35786, 39100, 36844, 80159, 90644, 73354, 19838, 78759, 51795, 62277, 103179, 47021, 566, 52097, 17532, 89563, 30060, 41353, 34866, 21153, 7277, 15060, 14611, 49685, 155, 15493, 73565, 18432, 10298, 103662, 34155, 91058, 99851, 94983, 81644, 73311, 151955, 108672, 67753, 161153, 3963, 66417, 31082, 65042, 141179, 189260, 75888, 124842, 174842, 166627, 83443, 92465, 25082, 28768, 27109, 21947, 84209, 58942, 86176, 137934, 39074, 42085, 86103, 114438, 40316, 31003, 83049, 29076, 50712, 47897, 136283, 117740, 196779, 99543, 94223, 60040, 75556, 21489, 26186, 55258, 3122, 85752, 35830, 61464, 41382, 45120, 52372, 46837, 38543, 36723, 6125, 24473, 34068, 35094, 109900, 33419, 48743, 74165, 50160, 68048, 31352, 20852, 28946, 19409, 30007, 455, 50116, 13952, 46129, 40852, 43022, 45510, 1947, 85697, 76600, 578, 177469, 37726, 92161, 32920, 109756, 43770, 3386, 37701, 2392, 34914, 27127, 55371, 50708, 46847, 61154, 47176, 3954, 136665, 69849, 72828, 41077, 37946, 61118, 53522, 41286, 72605, 28102, 62819, 34061, 46665, 64241, 60233, 47223, 23255, 27611, 78374, 46341, 34969, 19760, 49233, 18268, 45659, 123304, 20596, 17376, 160169, 97121, 23741, 53428, 226756, 118726, 22798, 434, 66861, 87471, 63634, 7217, 51355, 42316, 209343, 94162, 54207, 64426, 34439, 2173, 38497, 64699, 31609, 169319, 39164, 103851, 96395, 94107, 60198, 137385, 25415, 1075, 116192, 54565, 100989, 81600, 16433, 99817, 88149, 34953, 61298, 100442, 26081, 1471, 125848, 63626, 52317, 166272, 115506, 197763, 42089, 646, 166943, 24809, 60518, 913, 17882, 51310, 35860, 236884, 155171, 171703, 102631, 113550, 68810, 70965, 23487, 1782, 24450, 54356, 12660, 329478, 26007, 126732, 89572, 87295, 240, 54792, 20535, 664, 35258, 64428, 77538, 25630, 42877, 70955, 6076, 262, 2047, 4, 1, 15723, 4, 25130, 4274, 19827, 4, 15389, 6, 17327, 196, 8824, 22537, 11196, 30, 14384, 27310, 23886, 1, 12914, 12, 39610, 4552, 19510, 13, 22673, 8, 33312, 7, 8265, 1, 9524, 12890, 15053, 11847, 8923, 4, 4956, 17416, 17018, 7964, 11178, 4412, 10267, 19560, 11209, 9644, 44109, 10608, 352, 68822, 80971, 19804, 34341, 4282, 17027, 726, 20787, 23470, 1044, 12821, 6595, 17805, 645, 15363, 7914, 10238, 9009, 11061, 8844, 872, 6940, 19625, 5911, 7526, 11286, 39202, 288, 16227, 11498, 43972, 1767, 14396, 8934, 13, 5604, 6256, 15006, 29036, 11197, 2750, 22142, 5726], "yaxis": "y"}, {"alignmentgroup": "True", "customdata": [["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"], ["X"]], "hovertemplate": "contig=%{customdata[0]}<br>sample_id=%{x}<br>depth=%{y}<extra></extra>", "legendgroup": "X", "marker": {"color": "#9467BD", "pattern": {"shape": ""}}, "name": "X", "offsetgroup": "X", "orientation": "v", "showlegend": true, "textposition": "auto", "type": "bar", "x": ["GH_01", "GH_02", "GH_03", "GH_04", "GH_05", "GH_06", "GH_07", "GH_08", "GH_09", "GH_10", "GH_11", "GH_12", "GH_13", "GH_14", "GH_15", "GH_16", "GH_17", "GH_18", "GH_19", "GH_20", "GH_21", "GH_22", "GH_23", "GH_24", "GH_25", "GH_26", "GH_27", "GH_28", "GH_29", "GH_30", "GH_31", "GH_32", "GH_33", "GH_34", "GH_35", "GH_36", "GH_37", "GH_38", "GH_39", "GH_40_low_vol", "GH_41", "GH_42", "GH_43", "GH_44", "GH_45", "GH_46", "GH_47", "GH_48", "GH_49", "GH_50", "GH_51", "GH_52", "GH_53", "GH_54", "GH_55", "GH_56", "GH_57", "GH_58", "GH_59", "GH_60", "GH_61", "GH_62", "GH_63", "GH_64", "GH_65_low_vol", "GH_66", "GH_67", "GH_68", "GH_69", "GH_70", "GH_71", "GH_72", "GH_73", "GH_74", "GH_75", "GH_76", "GH_77", "GH_78", "GH_79", "GH_80_low_vol", "GH_81", "GH_82", "GH_83", "GH_84", "GH_85", "GH_86", "GH_87", "GH_88", "GH_89", "GH_90", "GH_91", "GH_92", "GH_93", "GH_94", "GH_95", "GH_Negative", "GM_01", "GM_02", "GM_03", "GM_04", "GM_05", "GM_06", "GM_07", "GM_08", "GM_09", "GM_10", "GM_11", "GM_12", "GM_13", "GM_14", "GM_15", "GM_16", "GM_17", "GM_18", "GM_19", "GM_20", "GM_21", "GM_22", "GM_23", "GM_24", "GM_25", "GM_26", "GM_27", "GM_28", "GM_29", "GM_30", "GM_31", "GM_32", "GM_33", "GM_34", "GM_35", "GM_36", "GM_37", "GM_38", "GM_39", "GM_40", "GM_41", "GM_42", "GM_43", "GM_44", "GM_45", "GM_46", "GM_47", "GM_48", "GM_49", "GM_50", "GM_51", "GM_52", "GM_53", "GM_54", "GM_55", "GM_56", "GM_57", "GM_58", "GM_59", "GM_60", "GM_61", "GM_62", "GM_63", "GM_64", "GM_65", "GM_66", "GM_67", "GM_68", "GM_69", "GM_70", "GM_71", "GM_72", "GM_73", "GM_74", "GM_75", "GM_76", "GM_77", "GM_78", "GM_79", "GM_80", "GM_81", "GM_82", "GM_83", "GM_84", "GM_85", "GM_86", "GM_87", "GM_88", "GM_89", "GM_90", "GM_91", "GM_92", "GM_93", "GM_94", "GM_95", "GM_96", "Siaya_Delta_Alive_01", "Siaya_Delta_Alive_02", "Siaya_Delta_Alive_03", "Siaya_Delta_Alive_04", "Siaya_Delta_Alive_05", "Siaya_Delta_Alive_06", "Siaya_Delta_Alive_07", "Siaya_Delta_Alive_08", "Siaya_Delta_Alive_09", "Siaya_Delta_Alive_10", "Siaya_Delta_Alive_100", "Siaya_Delta_Alive_101", "Siaya_Delta_Alive_102", "Siaya_Delta_Alive_103", "Siaya_Delta_Alive_104", "Siaya_Delta_Alive_105", "Siaya_Delta_Alive_106", "Siaya_Delta_Alive_107", "Siaya_Delta_Alive_108", "Siaya_Delta_Alive_109", "Siaya_Delta_Alive_11", "Siaya_Delta_Alive_110", "Siaya_Delta_Alive_111", "Siaya_Delta_Alive_112", "Siaya_Delta_Alive_113", "Siaya_Delta_Alive_114", "Siaya_Delta_Alive_115", "Siaya_Delta_Alive_116", "Siaya_Delta_Alive_117", "Siaya_Delta_Alive_118", "Siaya_Delta_Alive_119", "Siaya_Delta_Alive_12", "Siaya_Delta_Alive_120", "Siaya_Delta_Alive_121", "Siaya_Delta_Alive_122", "Siaya_Delta_Alive_123", "Siaya_Delta_Alive_124", "Siaya_Delta_Alive_125", "Siaya_Delta_Alive_126", "Siaya_Delta_Alive_127", "Siaya_Delta_Alive_128", "Siaya_Delta_Alive_129", "Siaya_Delta_Alive_13", "Siaya_Delta_Alive_130", "Siaya_Delta_Alive_131", "Siaya_Delta_Alive_14", "Siaya_Delta_Alive_15", "Siaya_Delta_Alive_16", "Siaya_Delta_Alive_17", "Siaya_Delta_Alive_18", "Siaya_Delta_Alive_19", "Siaya_Delta_Alive_20", "Siaya_Delta_Alive_21", "Siaya_Delta_Alive_22", "Siaya_Delta_Alive_23", "Siaya_Delta_Alive_24", "Siaya_Delta_Alive_25", "Siaya_Delta_Alive_26", "Siaya_Delta_Alive_27", "Siaya_Delta_Alive_28", "Siaya_Delta_Alive_29", "Siaya_Delta_Alive_30", "Siaya_Delta_Alive_31", "Siaya_Delta_Alive_32", "Siaya_Delta_Alive_33", "Siaya_Delta_Alive_34", "Siaya_Delta_Alive_35", "Siaya_Delta_Alive_36", "Siaya_Delta_Alive_37", "Siaya_Delta_Alive_38", "Siaya_Delta_Alive_39", "Siaya_Delta_Alive_40", "Siaya_Delta_Alive_41", "Siaya_Delta_Alive_42", "Siaya_Delta_Alive_43", "Siaya_Delta_Alive_44", "Siaya_Delta_Alive_45", "Siaya_Delta_Alive_46", "Siaya_Delta_Alive_47", "Siaya_Delta_Alive_48", "Siaya_Delta_Alive_49", "Siaya_Delta_Alive_50", "Siaya_Delta_Alive_51", "Siaya_Delta_Alive_52", "Siaya_Delta_Alive_53", "Siaya_Delta_Alive_54", "Siaya_Delta_Alive_55", "Siaya_Delta_Alive_56", "Siaya_Delta_Alive_57", "Siaya_Delta_Alive_58", "Siaya_Delta_Alive_59", "Siaya_Delta_Alive_60", "Siaya_Delta_Alive_61", "Siaya_Delta_Alive_62", "Siaya_Delta_Alive_63", "Siaya_Delta_Alive_64", "Siaya_Delta_Alive_65", "Siaya_Delta_Alive_66", "Siaya_Delta_Alive_67", "Siaya_Delta_Alive_68", "Siaya_Delta_Alive_69", "Siaya_Delta_Alive_70", "Siaya_Delta_Alive_71", "Siaya_Delta_Alive_72", "Siaya_Delta_Alive_73", "Siaya_Delta_Alive_74", "Siaya_Delta_Alive_75", "Siaya_Delta_Alive_76", "Siaya_Delta_Alive_77", "Siaya_Delta_Alive_78", "Siaya_Delta_Alive_79", "Siaya_Delta_Alive_80", "Siaya_Delta_Alive_81", "Siaya_Delta_Alive_82", "Siaya_Delta_Alive_83", "Siaya_Delta_Alive_84", "Siaya_Delta_Alive_85", "Siaya_Delta_Alive_86", "Siaya_Delta_Alive_87", "Siaya_Delta_Alive_88", "Siaya_Delta_Alive_89", "Siaya_Delta_Alive_90", "Siaya_Delta_Alive_91", "Siaya_Delta_Alive_92", "Siaya_Delta_Alive_93", "Siaya_Delta_Alive_94", "Siaya_Delta_Alive_95", "Siaya_Delta_Alive_96", "Siaya_Delta_Alive_97", "Siaya_Delta_Alive_98", "Siaya_Delta_Alive_99", "Siaya_Delta_Alive_Negative", "Siaya_Delta_Dead_01", "Siaya_Delta_Dead_02", "Siaya_Delta_Dead_03", "Siaya_Delta_Dead_04", "Siaya_Delta_Dead_05", "Siaya_Delta_Dead_06", "Siaya_Delta_Dead_07", "Siaya_Delta_Dead_08", "Siaya_Delta_Dead_09", "Siaya_Delta_Dead_10", "Siaya_Delta_Dead_100", "Siaya_Delta_Dead_101", "Siaya_Delta_Dead_102", "Siaya_Delta_Dead_103", "Siaya_Delta_Dead_104", "Siaya_Delta_Dead_105", "Siaya_Delta_Dead_106", "Siaya_Delta_Dead_107", "Siaya_Delta_Dead_108", "Siaya_Delta_Dead_109", "Siaya_Delta_Dead_11", "Siaya_Delta_Dead_110", "Siaya_Delta_Dead_111", "Siaya_Delta_Dead_112", "Siaya_Delta_Dead_113", "Siaya_Delta_Dead_114", "Siaya_Delta_Dead_115", "Siaya_Delta_Dead_116", "Siaya_Delta_Dead_117", "Siaya_Delta_Dead_118", "Siaya_Delta_Dead_119", "Siaya_Delta_Dead_12", "Siaya_Delta_Dead_120", "Siaya_Delta_Dead_121", "Siaya_Delta_Dead_122", "Siaya_Delta_Dead_123", "Siaya_Delta_Dead_124", "Siaya_Delta_Dead_125", "Siaya_Delta_Dead_126", "Siaya_Delta_Dead_127", "Siaya_Delta_Dead_128", "Siaya_Delta_Dead_129", "Siaya_Delta_Dead_13", "Siaya_Delta_Dead_130", "Siaya_Delta_Dead_131", "Siaya_Delta_Dead_14", "Siaya_Delta_Dead_15", "Siaya_Delta_Dead_16", "Siaya_Delta_Dead_17", "Siaya_Delta_Dead_18", "Siaya_Delta_Dead_19", "Siaya_Delta_Dead_20", "Siaya_Delta_Dead_21", "Siaya_Delta_Dead_22", "Siaya_Delta_Dead_23", "Siaya_Delta_Dead_24", "Siaya_Delta_Dead_25", "Siaya_Delta_Dead_26", "Siaya_Delta_Dead_27", "Siaya_Delta_Dead_28", "Siaya_Delta_Dead_29", "Siaya_Delta_Dead_30", "Siaya_Delta_Dead_31", "Siaya_Delta_Dead_32", "Siaya_Delta_Dead_33", "Siaya_Delta_Dead_34", "Siaya_Delta_Dead_35", "Siaya_Delta_Dead_36", "Siaya_Delta_Dead_37", "Siaya_Delta_Dead_38", "Siaya_Delta_Dead_39", "Siaya_Delta_Dead_40", "Siaya_Delta_Dead_41", "Siaya_Delta_Dead_42", "Siaya_Delta_Dead_43", "Siaya_Delta_Dead_44", "Siaya_Delta_Dead_45", "Siaya_Delta_Dead_46", "Siaya_Delta_Dead_47", "Siaya_Delta_Dead_48", "Siaya_Delta_Dead_49", "Siaya_Delta_Dead_50", "Siaya_Delta_Dead_51", "Siaya_Delta_Dead_52", "Siaya_Delta_Dead_53", "Siaya_Delta_Dead_54", "Siaya_Delta_Dead_55", "Siaya_Delta_Dead_56", "Siaya_Delta_Dead_57", "Siaya_Delta_Dead_58", "Siaya_Delta_Dead_59", "Siaya_Delta_Dead_60", "Siaya_Delta_Dead_61", "Siaya_Delta_Dead_62", "Siaya_Delta_Dead_63", "Siaya_Delta_Dead_64", "Siaya_Delta_Dead_65", "Siaya_Delta_Dead_66", "Siaya_Delta_Dead_67", "Siaya_Delta_Dead_68", "Siaya_Delta_Dead_69", "Siaya_Delta_Dead_70", "Siaya_Delta_Dead_71", "Siaya_Delta_Dead_72", "Siaya_Delta_Dead_73", "Siaya_Delta_Dead_74", "Siaya_Delta_Dead_75", "Siaya_Delta_Dead_76", "Siaya_Delta_Dead_77", "Siaya_Delta_Dead_78", "Siaya_Delta_Dead_79", "Siaya_Delta_Dead_80", "Siaya_Delta_Dead_81", "Siaya_Delta_Dead_82", "Siaya_Delta_Dead_83", "Siaya_Delta_Dead_84", "Siaya_Delta_Dead_85", "Siaya_Delta_Dead_86", "Siaya_Delta_Dead_87", "Siaya_Delta_Dead_88", "Siaya_Delta_Dead_89", "Siaya_Delta_Dead_90", "Siaya_Delta_Dead_91", "Siaya_Delta_Dead_92", "Siaya_Delta_Dead_93", "Siaya_Delta_Dead_94", "Siaya_Delta_Dead_95", "Siaya_Delta_Dead_96", "Siaya_Delta_Dead_97", "Siaya_Delta_Dead_98", "Siaya_Delta_Dead_99", "Siaya_Delta_Dead_Negative", "VK7_Negative", "VK7_alive_01", "VK7_alive_02", "VK7_alive_03", "VK7_alive_04", "VK7_alive_05", "VK7_alive_06", "VK7_alive_07", "VK7_alive_08", "VK7_alive_09", "VK7_alive_10", "VK7_alive_11", "VK7_alive_12", "VK7_alive_13", "VK7_alive_14", "VK7_alive_15", "VK7_alive_16", "VK7_alive_17", "VK7_alive_18", "VK7_alive_19", "VK7_alive_20", "VK7_alive_21", "VK7_alive_22", "VK7_alive_23", "VK7_alive_24", "VK7_alive_25", "VK7_alive_26", "VK7_alive_27", "VK7_alive_28", "VK7_alive_29", "VK7_alive_30", "VK7_alive_31", "VK7_alive_32", "VK7_alive_33", "VK7_alive_34", "VK7_alive_35", "VK7_alive_36", "VK7_alive_37", "VK7_alive_38", "VK7_alive_39", "VK7_alive_40", "VK7_alive_41", "VK7_alive_42", "VK7_alive_43", "VK7_alive_44", "VK7_alive_45", "VK7_alive_46", "VK7_alive_47", "VK7_dead_01", "VK7_dead_02", "VK7_dead_03", "VK7_dead_04", "VK7_dead_04_dil", "VK7_dead_05", "VK7_dead_06", "VK7_dead_07", "VK7_dead_08", "VK7_dead_09", "VK7_dead_10", "VK7_dead_10_dil", "VK7_dead_11", "VK7_dead_12", "VK7_dead_13", "VK7_dead_14", "VK7_dead_15", "VK7_dead_16", "VK7_dead_16_dil", "VK7_dead_17", "VK7_dead_18", "VK7_dead_19", "VK7_dead_20", "VK7_dead_21", "VK7_dead_22", "VK7_dead_22_dil", "VK7_dead_23", "VK7_dead_24", "VK7_dead_25", "VK7_dead_26", "VK7_dead_27", "VK7_dead_28", "VK7_dead_28_dil", "VK7_dead_29", "VK7_dead_30", "VK7_dead_31", "VK7_dead_32", "VK7_dead_33", "VK7_dead_34", "VK7_dead_34_dil", "VK7_dead_35", "VK7_dead_36", "VK7_dead_37", "VK7_dead_38", "VK7_dead_39", "VK7_dead_40", "VK7_dead_41", "VK7_dead_42"], "xaxis": "x", "y": [24623, 2364, 2703, 981, 1870, 5874, 759, 2648, 4011, 2459, 8034, 3945, 5288, 4783, 1565, 1890, 3326, 1286, 12522, 892, 7675, 3128, 4274, 3496, 15676, 13181, 3326, 1779, 4938, 29289, 1524, 1307, 6469, 8243, 5167, 1516, 34847, 4775, 3246, 9664, 2375, 2112, 7186, 4932, 5081, 1342, 4459, 1877, 40263, 28935, 96941, 8452, 10775, 3191, 15257, 8886, 2859, 3091, 3541, 3525, 124364, 27464, 5379, 18176, 54, 2135, 2719, 2962, 2879, 1723, 2804, 1888, 16560, 11646, 7455, 14140, 2206, 4482, 47435, 2364, 16643, 2959, 2722, 4940, 46529, 179081, 3228, 11630, 3949, 153, 8515, 3847, 7200, 8191, 11293, 7133, 8413, 11333, 133386, 24039, 26600, 1210, 196, 1409, 3191, 2944, 4640, 3388, 12424, 112656, 5252, 7082, 5767, 7358, 4641, 3562, 4541, 3604, 6428, 8047, 4343, 23177, 6773, 6103, 10536, 4112, 1892, 3423, 3304, 843, 3024, 2808, 16523, 15107, 6650, 6273, 1510, 4609, 1597, 2898, 1846, 4098, 1126, 2331, 7853, 27773, 20446, 11224, 5388, 5276, 2843, 4051, 15922, 3032, 2656, 6704, 18950, 12830, 7706, 15564, 61, 5157, 218, 2474, 1782, 1598, 1295, 741, 48816, 12803, 9545, 22747, 9317, 2137, 1585, 2757, 2981, 936, 1274, 1599, 11506, 675960, 8140, 12541, 11723, 23, 1510, 1186, 1799, 1273, 4613, 1211, 64510, 58366, 48779, 29016, 62932, 53420, 30589, 102361, 147273, 57257, 74227, 62988, 25545, 72175, 63313, 75332, 25707, 42039, 36774, 83874, 178204, 88221, 28991, 82592, 77077, 53922, 95377, 49623, 379, 62521, 17320, 92542, 32735, 58371, 37976, 36702, 17214, 21398, 28233, 46784, 406, 17449, 61909, 34701, 15724, 104749, 33543, 81733, 112273, 123497, 89595, 90531, 154997, 145163, 96328, 97902, 15774, 64243, 45716, 61272, 135267, 252880, 82349, 178320, 176454, 217151, 147583, 74623, 25709, 29676, 24027, 28577, 63419, 94656, 87103, 131977, 55833, 45054, 81943, 114566, 44093, 27877, 93218, 35728, 42078, 57559, 99737, 91137, 192826, 75085, 82521, 78686, 56810, 22402, 36490, 93395, 2296, 85126, 29304, 57661, 62720, 45075, 56125, 71107, 57166, 35994, 9850, 34438, 52081, 48090, 130972, 47995, 57979, 87838, 68779, 92959, 44750, 33389, 38867, 22803, 35549, 1005, 44230, 18406, 58036, 48958, 103781, 59262, 7393, 60005, 79929, 1617, 105325, 48267, 73497, 17262, 74076, 46292, 4258, 36910, 6741, 24802, 15358, 63584, 42797, 49182, 66065, 53760, 28381, 144708, 74685, 67154, 25219, 42615, 53304, 60633, 47511, 66283, 28127, 74546, 42847, 45862, 53977, 63554, 42546, 17850, 33386, 88854, 57782, 58221, 31317, 61142, 16545, 40601, 62220, 33512, 38588, 191941, 77017, 29141, 47523, 222840, 103569, 24783, 1165, 55582, 94201, 51968, 25983, 46647, 32951, 210338, 73899, 44380, 56502, 32296, 6949, 39754, 60433, 34694, 159482, 44877, 96844, 114690, 70681, 71597, 116400, 29588, 3799, 104311, 60642, 72988, 32634, 13961, 158429, 76041, 27087, 79487, 89473, 26318, 4804, 122081, 44180, 59367, 125271, 121425, 319124, 57391, 457, 186457, 16649, 68528, 3930, 14865, 65830, 47387, 197357, 195869, 279119, 132023, 132865, 100283, 110711, 35926, 2603, 36951, 71397, 21529, 366663, 50329, 149834, 124536, 119636, 56, 55073, 14316, 2857, 37812, 63152, 36609, 54237, 16922, 70505, 6307, 820, 4146, 0, 8, 28081, 4, 108953, 20592, 67063, 8, 59659, 5, 61003, 764, 25518, 68858, 29025, 48, 61442, 72054, 44806, 1, 42525, 33, 98075, 21801, 56442, 12, 70732, 21, 158379, 14, 38506, 0, 26057, 28700, 52856, 34729, 16921, 0, 23992, 41967, 45904, 19248, 37907, 12899, 34098, 51879, 35375, 53348, 197151, 50518, 2246, 282235, 263106, 80348, 86921, 20077, 99982, 2659, 98412, 87936, 5476, 33254, 17958, 62385, 2896, 63418, 18789, 46898, 34643, 27310, 38478, 4004, 22585, 51952, 7803, 17690, 26120, 125424, 515, 51728, 41876, 87441, 3230, 40767, 32344, 19, 20157, 28342, 47936, 103065, 36197, 7174, 51767, 17361], "yaxis": "y"}], "layout": {"barmode": "relative", "legend": {"title": {"text": "contig"}, "tracegroupgap": 0}, "margin": {"t": 60}, "template": {"data": {"bar": [{"error_x": {"color": "rgb(36,36,36)"}, "error_y": {"color": "rgb(36,36,36)"}, "marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "white", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "baxis": {"endlinecolor": "rgb(36,36,36)", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "rgb(36,36,36)"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmapgl"}], "histogram": [{"marker": {"line": {"color": "white", "width": 0.6}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}, "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "rgb(237,237,237)"}, "line": {"color": "white"}}, "header": {"fill": {"color": "rgb(217,217,217)"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 1, "tickcolor": "rgb(36,36,36)", "ticks": "outside"}}, "colorscale": {"diverging": [[0.0, "rgb(103,0,31)"], [0.1, "rgb(178,24,43)"], [0.2, "rgb(214,96,77)"], [0.3, "rgb(244,165,130)"], [0.4, "rgb(253,219,199)"], [0.5, "rgb(247,247,247)"], [0.6, "rgb(209,229,240)"], [0.7, "rgb(146,197,222)"], [0.8, "rgb(67,147,195)"], [0.9, "rgb(33,102,172)"], [1.0, "rgb(5,48,97)"]], "sequential": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "sequentialminus": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]]}, "colorway": ["#1F77B4", "#FF7F0E", "#2CA02C", "#D62728", "#9467BD", "#8C564B", "#E377C2", "#7F7F7F", "#BCBD22", "#17BECF"], "font": {"color": "rgb(36,36,36)"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "white", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "white", "polar": {"angularaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "radialaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "scene": {"xaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "zaxis": {"backgroundcolor": "white", "gridcolor": "rgb(232,232,232)", "gridwidth": 2, "linecolor": "rgb(36,36,36)", "showbackground": true, "showgrid": false, "showline": true, "ticks": "outside", "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}, "shapedefaults": {"fillcolor": "black", "line": {"width": 0}, "opacity": 0.3}, "ternary": {"aaxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "baxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}, "bgcolor": "white", "caxis": {"gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside"}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}, "yaxis": {"automargin": true, "gridcolor": "rgb(232,232,232)", "linecolor": "rgb(36,36,36)", "showgrid": false, "showline": true, "ticks": "outside", "title": {"standoff": 15}, "zeroline": false, "zerolinecolor": "rgb(36,36,36)"}}}, "width": 1000, "xaxis": {"anchor": "y", "domain": [0.0, 1.0], "title": {"text": "sample_id"}}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0], "title": {"text": "depth"}}}}, "text/html": ["<div>                            <div id=\"7515d5be-e716-4bc5-afcc-126a93ce5033\" class=\"plotly-graph-div\" style=\"height:525px; width:1000px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"7515d5be-e716-4bc5-afcc-126a93ce5033\")) {                    Plotly.newPlot(                        \"7515d5be-e716-4bc5-afcc-126a93ce5033\",                        [{\"alignmentgroup\":\"True\",\"customdata\":[[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"],[\"2L\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003esample_id=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"2L\",\"marker\":{\"color\":\"#1F77B4\",\"pattern\":{\"shape\":\"\"}},\"name\":\"2L\",\"offsetgroup\":\"2L\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"auto\",\"x\":[\"GH_01\",\"GH_02\",\"GH_03\",\"GH_04\",\"GH_05\",\"GH_06\",\"GH_07\",\"GH_08\",\"GH_09\",\"GH_10\",\"GH_11\",\"GH_12\",\"GH_13\",\"GH_14\",\"GH_15\",\"GH_16\",\"GH_17\",\"GH_18\",\"GH_19\",\"GH_20\",\"GH_21\",\"GH_22\",\"GH_23\",\"GH_24\",\"GH_25\",\"GH_26\",\"GH_27\",\"GH_28\",\"GH_29\",\"GH_30\",\"GH_31\",\"GH_32\",\"GH_33\",\"GH_34\",\"GH_35\",\"GH_36\",\"GH_37\",\"GH_38\",\"GH_39\",\"GH_40_low_vol\",\"GH_41\",\"GH_42\",\"GH_43\",\"GH_44\",\"GH_45\",\"GH_46\",\"GH_47\",\"GH_48\",\"GH_49\",\"GH_50\",\"GH_51\",\"GH_52\",\"GH_53\",\"GH_54\",\"GH_55\",\"GH_56\",\"GH_57\",\"GH_58\",\"GH_59\",\"GH_60\",\"GH_61\",\"GH_62\",\"GH_63\",\"GH_64\",\"GH_65_low_vol\",\"GH_66\",\"GH_67\",\"GH_68\",\"GH_69\",\"GH_70\",\"GH_71\",\"GH_72\",\"GH_73\",\"GH_74\",\"GH_75\",\"GH_76\",\"GH_77\",\"GH_78\",\"GH_79\",\"GH_80_low_vol\",\"GH_81\",\"GH_82\",\"GH_83\",\"GH_84\",\"GH_85\",\"GH_86\",\"GH_87\",\"GH_88\",\"GH_89\",\"GH_90\",\"GH_91\",\"GH_92\",\"GH_93\",\"GH_94\",\"GH_95\",\"GH_Negative\",\"GM_01\",\"GM_02\",\"GM_03\",\"GM_04\",\"GM_05\",\"GM_06\",\"GM_07\",\"GM_08\",\"GM_09\",\"GM_10\",\"GM_11\",\"GM_12\",\"GM_13\",\"GM_14\",\"GM_15\",\"GM_16\",\"GM_17\",\"GM_18\",\"GM_19\",\"GM_20\",\"GM_21\",\"GM_22\",\"GM_23\",\"GM_24\",\"GM_25\",\"GM_26\",\"GM_27\",\"GM_28\",\"GM_29\",\"GM_30\",\"GM_31\",\"GM_32\",\"GM_33\",\"GM_34\",\"GM_35\",\"GM_36\",\"GM_37\",\"GM_38\",\"GM_39\",\"GM_40\",\"GM_41\",\"GM_42\",\"GM_43\",\"GM_44\",\"GM_45\",\"GM_46\",\"GM_47\",\"GM_48\",\"GM_49\",\"GM_50\",\"GM_51\",\"GM_52\",\"GM_53\",\"GM_54\",\"GM_55\",\"GM_56\",\"GM_57\",\"GM_58\",\"GM_59\",\"GM_60\",\"GM_61\",\"GM_62\",\"GM_63\",\"GM_64\",\"GM_65\",\"GM_66\",\"GM_67\",\"GM_68\",\"GM_69\",\"GM_70\",\"GM_71\",\"GM_72\",\"GM_73\",\"GM_74\",\"GM_75\",\"GM_76\",\"GM_77\",\"GM_78\",\"GM_79\",\"GM_80\",\"GM_81\",\"GM_82\",\"GM_83\",\"GM_84\",\"GM_85\",\"GM_86\",\"GM_87\",\"GM_88\",\"GM_89\",\"GM_90\",\"GM_91\",\"GM_92\",\"GM_93\",\"GM_94\",\"GM_95\",\"GM_96\",\"Siaya_Delta_Alive_01\",\"Siaya_Delta_Alive_02\",\"Siaya_Delta_Alive_03\",\"Siaya_Delta_Alive_04\",\"Siaya_Delta_Alive_05\",\"Siaya_Delta_Alive_06\",\"Siaya_Delta_Alive_07\",\"Siaya_Delta_Alive_08\",\"Siaya_Delta_Alive_09\",\"Siaya_Delta_Alive_10\",\"Siaya_Delta_Alive_100\",\"Siaya_Delta_Alive_101\",\"Siaya_Delta_Alive_102\",\"Siaya_Delta_Alive_103\",\"Siaya_Delta_Alive_104\",\"Siaya_Delta_Alive_105\",\"Siaya_Delta_Alive_106\",\"Siaya_Delta_Alive_107\",\"Siaya_Delta_Alive_108\",\"Siaya_Delta_Alive_109\",\"Siaya_Delta_Alive_11\",\"Siaya_Delta_Alive_110\",\"Siaya_Delta_Alive_111\",\"Siaya_Delta_Alive_112\",\"Siaya_Delta_Alive_113\",\"Siaya_Delta_Alive_114\",\"Siaya_Delta_Alive_115\",\"Siaya_Delta_Alive_116\",\"Siaya_Delta_Alive_117\",\"Siaya_Delta_Alive_118\",\"Siaya_Delta_Alive_119\",\"Siaya_Delta_Alive_12\",\"Siaya_Delta_Alive_120\",\"Siaya_Delta_Alive_121\",\"Siaya_Delta_Alive_122\",\"Siaya_Delta_Alive_123\",\"Siaya_Delta_Alive_124\",\"Siaya_Delta_Alive_125\",\"Siaya_Delta_Alive_126\",\"Siaya_Delta_Alive_127\",\"Siaya_Delta_Alive_128\",\"Siaya_Delta_Alive_129\",\"Siaya_Delta_Alive_13\",\"Siaya_Delta_Alive_130\",\"Siaya_Delta_Alive_131\",\"Siaya_Delta_Alive_14\",\"Siaya_Delta_Alive_15\",\"Siaya_Delta_Alive_16\",\"Siaya_Delta_Alive_17\",\"Siaya_Delta_Alive_18\",\"Siaya_Delta_Alive_19\",\"Siaya_Delta_Alive_20\",\"Siaya_Delta_Alive_21\",\"Siaya_Delta_Alive_22\",\"Siaya_Delta_Alive_23\",\"Siaya_Delta_Alive_24\",\"Siaya_Delta_Alive_25\",\"Siaya_Delta_Alive_26\",\"Siaya_Delta_Alive_27\",\"Siaya_Delta_Alive_28\",\"Siaya_Delta_Alive_29\",\"Siaya_Delta_Alive_30\",\"Siaya_Delta_Alive_31\",\"Siaya_Delta_Alive_32\",\"Siaya_Delta_Alive_33\",\"Siaya_Delta_Alive_34\",\"Siaya_Delta_Alive_35\",\"Siaya_Delta_Alive_36\",\"Siaya_Delta_Alive_37\",\"Siaya_Delta_Alive_38\",\"Siaya_Delta_Alive_39\",\"Siaya_Delta_Alive_40\",\"Siaya_Delta_Alive_41\",\"Siaya_Delta_Alive_42\",\"Siaya_Delta_Alive_43\",\"Siaya_Delta_Alive_44\",\"Siaya_Delta_Alive_45\",\"Siaya_Delta_Alive_46\",\"Siaya_Delta_Alive_47\",\"Siaya_Delta_Alive_48\",\"Siaya_Delta_Alive_49\",\"Siaya_Delta_Alive_50\",\"Siaya_Delta_Alive_51\",\"Siaya_Delta_Alive_52\",\"Siaya_Delta_Alive_53\",\"Siaya_Delta_Alive_54\",\"Siaya_Delta_Alive_55\",\"Siaya_Delta_Alive_56\",\"Siaya_Delta_Alive_57\",\"Siaya_Delta_Alive_58\",\"Siaya_Delta_Alive_59\",\"Siaya_Delta_Alive_60\",\"Siaya_Delta_Alive_61\",\"Siaya_Delta_Alive_62\",\"Siaya_Delta_Alive_63\",\"Siaya_Delta_Alive_64\",\"Siaya_Delta_Alive_65\",\"Siaya_Delta_Alive_66\",\"Siaya_Delta_Alive_67\",\"Siaya_Delta_Alive_68\",\"Siaya_Delta_Alive_69\",\"Siaya_Delta_Alive_70\",\"Siaya_Delta_Alive_71\",\"Siaya_Delta_Alive_72\",\"Siaya_Delta_Alive_73\",\"Siaya_Delta_Alive_74\",\"Siaya_Delta_Alive_75\",\"Siaya_Delta_Alive_76\",\"Siaya_Delta_Alive_77\",\"Siaya_Delta_Alive_78\",\"Siaya_Delta_Alive_79\",\"Siaya_Delta_Alive_80\",\"Siaya_Delta_Alive_81\",\"Siaya_Delta_Alive_82\",\"Siaya_Delta_Alive_83\",\"Siaya_Delta_Alive_84\",\"Siaya_Delta_Alive_85\",\"Siaya_Delta_Alive_86\",\"Siaya_Delta_Alive_87\",\"Siaya_Delta_Alive_88\",\"Siaya_Delta_Alive_89\",\"Siaya_Delta_Alive_90\",\"Siaya_Delta_Alive_91\",\"Siaya_Delta_Alive_92\",\"Siaya_Delta_Alive_93\",\"Siaya_Delta_Alive_94\",\"Siaya_Delta_Alive_95\",\"Siaya_Delta_Alive_96\",\"Siaya_Delta_Alive_97\",\"Siaya_Delta_Alive_98\",\"Siaya_Delta_Alive_99\",\"Siaya_Delta_Alive_Negative\",\"Siaya_Delta_Dead_01\",\"Siaya_Delta_Dead_02\",\"Siaya_Delta_Dead_03\",\"Siaya_Delta_Dead_04\",\"Siaya_Delta_Dead_05\",\"Siaya_Delta_Dead_06\",\"Siaya_Delta_Dead_07\",\"Siaya_Delta_Dead_08\",\"Siaya_Delta_Dead_09\",\"Siaya_Delta_Dead_10\",\"Siaya_Delta_Dead_100\",\"Siaya_Delta_Dead_101\",\"Siaya_Delta_Dead_102\",\"Siaya_Delta_Dead_103\",\"Siaya_Delta_Dead_104\",\"Siaya_Delta_Dead_105\",\"Siaya_Delta_Dead_106\",\"Siaya_Delta_Dead_107\",\"Siaya_Delta_Dead_108\",\"Siaya_Delta_Dead_109\",\"Siaya_Delta_Dead_11\",\"Siaya_Delta_Dead_110\",\"Siaya_Delta_Dead_111\",\"Siaya_Delta_Dead_112\",\"Siaya_Delta_Dead_113\",\"Siaya_Delta_Dead_114\",\"Siaya_Delta_Dead_115\",\"Siaya_Delta_Dead_116\",\"Siaya_Delta_Dead_117\",\"Siaya_Delta_Dead_118\",\"Siaya_Delta_Dead_119\",\"Siaya_Delta_Dead_12\",\"Siaya_Delta_Dead_120\",\"Siaya_Delta_Dead_121\",\"Siaya_Delta_Dead_122\",\"Siaya_Delta_Dead_123\",\"Siaya_Delta_Dead_124\",\"Siaya_Delta_Dead_125\",\"Siaya_Delta_Dead_126\",\"Siaya_Delta_Dead_127\",\"Siaya_Delta_Dead_128\",\"Siaya_Delta_Dead_129\",\"Siaya_Delta_Dead_13\",\"Siaya_Delta_Dead_130\",\"Siaya_Delta_Dead_131\",\"Siaya_Delta_Dead_14\",\"Siaya_Delta_Dead_15\",\"Siaya_Delta_Dead_16\",\"Siaya_Delta_Dead_17\",\"Siaya_Delta_Dead_18\",\"Siaya_Delta_Dead_19\",\"Siaya_Delta_Dead_20\",\"Siaya_Delta_Dead_21\",\"Siaya_Delta_Dead_22\",\"Siaya_Delta_Dead_23\",\"Siaya_Delta_Dead_24\",\"Siaya_Delta_Dead_25\",\"Siaya_Delta_Dead_26\",\"Siaya_Delta_Dead_27\",\"Siaya_Delta_Dead_28\",\"Siaya_Delta_Dead_29\",\"Siaya_Delta_Dead_30\",\"Siaya_Delta_Dead_31\",\"Siaya_Delta_Dead_32\",\"Siaya_Delta_Dead_33\",\"Siaya_Delta_Dead_34\",\"Siaya_Delta_Dead_35\",\"Siaya_Delta_Dead_36\",\"Siaya_Delta_Dead_37\",\"Siaya_Delta_Dead_38\",\"Siaya_Delta_Dead_39\",\"Siaya_Delta_Dead_40\",\"Siaya_Delta_Dead_41\",\"Siaya_Delta_Dead_42\",\"Siaya_Delta_Dead_43\",\"Siaya_Delta_Dead_44\",\"Siaya_Delta_Dead_45\",\"Siaya_Delta_Dead_46\",\"Siaya_Delta_Dead_47\",\"Siaya_Delta_Dead_48\",\"Siaya_Delta_Dead_49\",\"Siaya_Delta_Dead_50\",\"Siaya_Delta_Dead_51\",\"Siaya_Delta_Dead_52\",\"Siaya_Delta_Dead_53\",\"Siaya_Delta_Dead_54\",\"Siaya_Delta_Dead_55\",\"Siaya_Delta_Dead_56\",\"Siaya_Delta_Dead_57\",\"Siaya_Delta_Dead_58\",\"Siaya_Delta_Dead_59\",\"Siaya_Delta_Dead_60\",\"Siaya_Delta_Dead_61\",\"Siaya_Delta_Dead_62\",\"Siaya_Delta_Dead_63\",\"Siaya_Delta_Dead_64\",\"Siaya_Delta_Dead_65\",\"Siaya_Delta_Dead_66\",\"Siaya_Delta_Dead_67\",\"Siaya_Delta_Dead_68\",\"Siaya_Delta_Dead_69\",\"Siaya_Delta_Dead_70\",\"Siaya_Delta_Dead_71\",\"Siaya_Delta_Dead_72\",\"Siaya_Delta_Dead_73\",\"Siaya_Delta_Dead_74\",\"Siaya_Delta_Dead_75\",\"Siaya_Delta_Dead_76\",\"Siaya_Delta_Dead_77\",\"Siaya_Delta_Dead_78\",\"Siaya_Delta_Dead_79\",\"Siaya_Delta_Dead_80\",\"Siaya_Delta_Dead_81\",\"Siaya_Delta_Dead_82\",\"Siaya_Delta_Dead_83\",\"Siaya_Delta_Dead_84\",\"Siaya_Delta_Dead_85\",\"Siaya_Delta_Dead_86\",\"Siaya_Delta_Dead_87\",\"Siaya_Delta_Dead_88\",\"Siaya_Delta_Dead_89\",\"Siaya_Delta_Dead_90\",\"Siaya_Delta_Dead_91\",\"Siaya_Delta_Dead_92\",\"Siaya_Delta_Dead_93\",\"Siaya_Delta_Dead_94\",\"Siaya_Delta_Dead_95\",\"Siaya_Delta_Dead_96\",\"Siaya_Delta_Dead_97\",\"Siaya_Delta_Dead_98\",\"Siaya_Delta_Dead_99\",\"Siaya_Delta_Dead_Negative\",\"VK7_Negative\",\"VK7_alive_01\",\"VK7_alive_02\",\"VK7_alive_03\",\"VK7_alive_04\",\"VK7_alive_05\",\"VK7_alive_06\",\"VK7_alive_07\",\"VK7_alive_08\",\"VK7_alive_09\",\"VK7_alive_10\",\"VK7_alive_11\",\"VK7_alive_12\",\"VK7_alive_13\",\"VK7_alive_14\",\"VK7_alive_15\",\"VK7_alive_16\",\"VK7_alive_17\",\"VK7_alive_18\",\"VK7_alive_19\",\"VK7_alive_20\",\"VK7_alive_21\",\"VK7_alive_22\",\"VK7_alive_23\",\"VK7_alive_24\",\"VK7_alive_25\",\"VK7_alive_26\",\"VK7_alive_27\",\"VK7_alive_28\",\"VK7_alive_29\",\"VK7_alive_30\",\"VK7_alive_31\",\"VK7_alive_32\",\"VK7_alive_33\",\"VK7_alive_34\",\"VK7_alive_35\",\"VK7_alive_36\",\"VK7_alive_37\",\"VK7_alive_38\",\"VK7_alive_39\",\"VK7_alive_40\",\"VK7_alive_41\",\"VK7_alive_42\",\"VK7_alive_43\",\"VK7_alive_44\",\"VK7_alive_45\",\"VK7_alive_46\",\"VK7_alive_47\",\"VK7_dead_01\",\"VK7_dead_02\",\"VK7_dead_03\",\"VK7_dead_04\",\"VK7_dead_04_dil\",\"VK7_dead_05\",\"VK7_dead_06\",\"VK7_dead_07\",\"VK7_dead_08\",\"VK7_dead_09\",\"VK7_dead_10\",\"VK7_dead_10_dil\",\"VK7_dead_11\",\"VK7_dead_12\",\"VK7_dead_13\",\"VK7_dead_14\",\"VK7_dead_15\",\"VK7_dead_16\",\"VK7_dead_16_dil\",\"VK7_dead_17\",\"VK7_dead_18\",\"VK7_dead_19\",\"VK7_dead_20\",\"VK7_dead_21\",\"VK7_dead_22\",\"VK7_dead_22_dil\",\"VK7_dead_23\",\"VK7_dead_24\",\"VK7_dead_25\",\"VK7_dead_26\",\"VK7_dead_27\",\"VK7_dead_28\",\"VK7_dead_28_dil\",\"VK7_dead_29\",\"VK7_dead_30\",\"VK7_dead_31\",\"VK7_dead_32\",\"VK7_dead_33\",\"VK7_dead_34\",\"VK7_dead_34_dil\",\"VK7_dead_35\",\"VK7_dead_36\",\"VK7_dead_37\",\"VK7_dead_38\",\"VK7_dead_39\",\"VK7_dead_40\",\"VK7_dead_41\",\"VK7_dead_42\"],\"xaxis\":\"x\",\"y\":[58362,4212,23578,1100,2566,10668,326,27796,67070,4934,64574,24951,8825,15926,3231,4032,3756,2886,23750,1193,17723,3498,40622,22571,10779,24790,5554,1557,6154,50225,20576,2699,19808,15796,9137,24167,56458,8754,7587,15013,4267,4655,20582,9643,8299,2098,7610,28414,110302,61087,217222,17196,19980,5970,34759,16433,7157,5518,4310,34949,261663,55052,7984,35341,143,3291,5041,4075,3150,4044,25161,27323,26809,22665,8113,28594,4197,7255,110721,1693,28800,4206,6863,36657,82651,403104,4593,17754,58187,197,20986,28664,11082,72103,17341,84586,3011,26669,39240,112783,51979,665,207,136,1611,858,2541,1961,25403,61353,16774,5588,1598,16196,6819,4160,1300,3635,2605,16250,4424,61208,2412,19039,9807,5545,1637,2599,1202,520,1806,1086,38485,28296,4126,11488,413,1674,422,1618,4540,626,480,403,1242,55684,54089,4401,3771,3050,2822,2965,11992,4182,1184,2447,53904,6736,8833,62756,187,3433,504,1860,1657,1028,463,16569,20007,68779,9795,15615,9408,1634,1457,1564,2341,664,791,24087,10156,603447,3238,23739,32757,156,2236,1853,21390,209,2070,12473,168251,153693,73580,63937,156238,121904,25950,247958,268786,96790,163044,107676,68161,217683,120751,132342,46899,67497,72937,202332,374303,170024,60251,161517,136469,99993,172792,80333,771,105129,19654,215881,63140,124541,69493,51029,28250,45177,45466,115593,711,43517,110116,61373,27991,210071,58414,235981,234621,280872,191699,161907,342547,233588,174727,297477,15281,143297,71833,100228,290838,496208,197805,242823,388214,540133,213817,175974,47962,39653,59296,40902,128795,156049,211288,334698,101588,93103,179326,268982,67651,43170,199594,65619,96233,143510,296644,188196,438074,175125,190464,147934,153116,27214,81476,145512,2996,188781,50826,115472,149692,86498,136319,146311,100123,86734,13504,55786,73919,98006,249985,55896,91725,168292,125181,147958,98402,59304,48106,50543,81496,1293,120434,34331,119758,110234,147443,131756,7314,128809,175198,25854,328423,79963,196524,69930,185738,98701,5152,68220,62413,48909,43731,132395,124352,103952,148966,94624,40941,317599,118267,149810,88458,67294,122265,135593,87822,123612,45444,139059,72136,104137,92591,129783,107989,36231,75076,180745,128456,96122,36294,124439,40022,104869,234345,54187,56459,498507,189242,59638,93724,420569,348243,50646,11542,130622,176870,77125,27293,109906,64574,510906,192756,137249,135771,67811,55344,69306,117719,65634,444900,80743,210655,227018,199798,122204,287614,51991,28113,232576,93616,175970,149328,19766,286386,190482,52903,144011,119176,48500,35203,225777,93210,117325,447584,203443,531850,86303,949,413153,29719,122574,54787,28010,87192,74436,663438,408684,436288,213212,275426,170019,180767,53705,48214,69229,153741,27741,779359,71376,322468,273969,256379,400,128919,51884,39872,92695,118384,94006,70900,78383,135404,15573,12760,1866,16,12,18305,17,59667,8236,33753,2,33920,4,23299,8235,13148,51584,17094,54,24563,66135,34569,0,23077,44,58631,6095,36632,19,39325,13,75947,25,15432,8,14268,20568,31584,20180,12926,12,12911,33739,33391,13246,27494,8033,18824,37345,16343,17504,77308,20488,13087,127735,222467,40970,73838,6252,38837,469,52458,45488,2605,17754,6803,30143,1128,24641,12723,19294,19295,16389,20336,1229,14824,34217,23995,12736,15484,81050,10504,26068,23944,110864,1631,21909,19603,32,9804,20806,38201,83936,23262,3418,46605,9389],\"yaxis\":\"y\",\"type\":\"bar\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"],[\"2R\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003esample_id=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"2R\",\"marker\":{\"color\":\"#FF7F0E\",\"pattern\":{\"shape\":\"\"}},\"name\":\"2R\",\"offsetgroup\":\"2R\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"auto\",\"x\":[\"GH_01\",\"GH_02\",\"GH_03\",\"GH_04\",\"GH_05\",\"GH_06\",\"GH_07\",\"GH_08\",\"GH_09\",\"GH_10\",\"GH_11\",\"GH_12\",\"GH_13\",\"GH_14\",\"GH_15\",\"GH_16\",\"GH_17\",\"GH_18\",\"GH_19\",\"GH_20\",\"GH_21\",\"GH_22\",\"GH_23\",\"GH_24\",\"GH_25\",\"GH_26\",\"GH_27\",\"GH_28\",\"GH_29\",\"GH_30\",\"GH_31\",\"GH_32\",\"GH_33\",\"GH_34\",\"GH_35\",\"GH_36\",\"GH_37\",\"GH_38\",\"GH_39\",\"GH_40_low_vol\",\"GH_41\",\"GH_42\",\"GH_43\",\"GH_44\",\"GH_45\",\"GH_46\",\"GH_47\",\"GH_48\",\"GH_49\",\"GH_50\",\"GH_51\",\"GH_52\",\"GH_53\",\"GH_54\",\"GH_55\",\"GH_56\",\"GH_57\",\"GH_58\",\"GH_59\",\"GH_60\",\"GH_61\",\"GH_62\",\"GH_63\",\"GH_64\",\"GH_65_low_vol\",\"GH_66\",\"GH_67\",\"GH_68\",\"GH_69\",\"GH_70\",\"GH_71\",\"GH_72\",\"GH_73\",\"GH_74\",\"GH_75\",\"GH_76\",\"GH_77\",\"GH_78\",\"GH_79\",\"GH_80_low_vol\",\"GH_81\",\"GH_82\",\"GH_83\",\"GH_84\",\"GH_85\",\"GH_86\",\"GH_87\",\"GH_88\",\"GH_89\",\"GH_90\",\"GH_91\",\"GH_92\",\"GH_93\",\"GH_94\",\"GH_95\",\"GH_Negative\",\"GM_01\",\"GM_02\",\"GM_03\",\"GM_04\",\"GM_05\",\"GM_06\",\"GM_07\",\"GM_08\",\"GM_09\",\"GM_10\",\"GM_11\",\"GM_12\",\"GM_13\",\"GM_14\",\"GM_15\",\"GM_16\",\"GM_17\",\"GM_18\",\"GM_19\",\"GM_20\",\"GM_21\",\"GM_22\",\"GM_23\",\"GM_24\",\"GM_25\",\"GM_26\",\"GM_27\",\"GM_28\",\"GM_29\",\"GM_30\",\"GM_31\",\"GM_32\",\"GM_33\",\"GM_34\",\"GM_35\",\"GM_36\",\"GM_37\",\"GM_38\",\"GM_39\",\"GM_40\",\"GM_41\",\"GM_42\",\"GM_43\",\"GM_44\",\"GM_45\",\"GM_46\",\"GM_47\",\"GM_48\",\"GM_49\",\"GM_50\",\"GM_51\",\"GM_52\",\"GM_53\",\"GM_54\",\"GM_55\",\"GM_56\",\"GM_57\",\"GM_58\",\"GM_59\",\"GM_60\",\"GM_61\",\"GM_62\",\"GM_63\",\"GM_64\",\"GM_65\",\"GM_66\",\"GM_67\",\"GM_68\",\"GM_69\",\"GM_70\",\"GM_71\",\"GM_72\",\"GM_73\",\"GM_74\",\"GM_75\",\"GM_76\",\"GM_77\",\"GM_78\",\"GM_79\",\"GM_80\",\"GM_81\",\"GM_82\",\"GM_83\",\"GM_84\",\"GM_85\",\"GM_86\",\"GM_87\",\"GM_88\",\"GM_89\",\"GM_90\",\"GM_91\",\"GM_92\",\"GM_93\",\"GM_94\",\"GM_95\",\"GM_96\",\"Siaya_Delta_Alive_01\",\"Siaya_Delta_Alive_02\",\"Siaya_Delta_Alive_03\",\"Siaya_Delta_Alive_04\",\"Siaya_Delta_Alive_05\",\"Siaya_Delta_Alive_06\",\"Siaya_Delta_Alive_07\",\"Siaya_Delta_Alive_08\",\"Siaya_Delta_Alive_09\",\"Siaya_Delta_Alive_10\",\"Siaya_Delta_Alive_100\",\"Siaya_Delta_Alive_101\",\"Siaya_Delta_Alive_102\",\"Siaya_Delta_Alive_103\",\"Siaya_Delta_Alive_104\",\"Siaya_Delta_Alive_105\",\"Siaya_Delta_Alive_106\",\"Siaya_Delta_Alive_107\",\"Siaya_Delta_Alive_108\",\"Siaya_Delta_Alive_109\",\"Siaya_Delta_Alive_11\",\"Siaya_Delta_Alive_110\",\"Siaya_Delta_Alive_111\",\"Siaya_Delta_Alive_112\",\"Siaya_Delta_Alive_113\",\"Siaya_Delta_Alive_114\",\"Siaya_Delta_Alive_115\",\"Siaya_Delta_Alive_116\",\"Siaya_Delta_Alive_117\",\"Siaya_Delta_Alive_118\",\"Siaya_Delta_Alive_119\",\"Siaya_Delta_Alive_12\",\"Siaya_Delta_Alive_120\",\"Siaya_Delta_Alive_121\",\"Siaya_Delta_Alive_122\",\"Siaya_Delta_Alive_123\",\"Siaya_Delta_Alive_124\",\"Siaya_Delta_Alive_125\",\"Siaya_Delta_Alive_126\",\"Siaya_Delta_Alive_127\",\"Siaya_Delta_Alive_128\",\"Siaya_Delta_Alive_129\",\"Siaya_Delta_Alive_13\",\"Siaya_Delta_Alive_130\",\"Siaya_Delta_Alive_131\",\"Siaya_Delta_Alive_14\",\"Siaya_Delta_Alive_15\",\"Siaya_Delta_Alive_16\",\"Siaya_Delta_Alive_17\",\"Siaya_Delta_Alive_18\",\"Siaya_Delta_Alive_19\",\"Siaya_Delta_Alive_20\",\"Siaya_Delta_Alive_21\",\"Siaya_Delta_Alive_22\",\"Siaya_Delta_Alive_23\",\"Siaya_Delta_Alive_24\",\"Siaya_Delta_Alive_25\",\"Siaya_Delta_Alive_26\",\"Siaya_Delta_Alive_27\",\"Siaya_Delta_Alive_28\",\"Siaya_Delta_Alive_29\",\"Siaya_Delta_Alive_30\",\"Siaya_Delta_Alive_31\",\"Siaya_Delta_Alive_32\",\"Siaya_Delta_Alive_33\",\"Siaya_Delta_Alive_34\",\"Siaya_Delta_Alive_35\",\"Siaya_Delta_Alive_36\",\"Siaya_Delta_Alive_37\",\"Siaya_Delta_Alive_38\",\"Siaya_Delta_Alive_39\",\"Siaya_Delta_Alive_40\",\"Siaya_Delta_Alive_41\",\"Siaya_Delta_Alive_42\",\"Siaya_Delta_Alive_43\",\"Siaya_Delta_Alive_44\",\"Siaya_Delta_Alive_45\",\"Siaya_Delta_Alive_46\",\"Siaya_Delta_Alive_47\",\"Siaya_Delta_Alive_48\",\"Siaya_Delta_Alive_49\",\"Siaya_Delta_Alive_50\",\"Siaya_Delta_Alive_51\",\"Siaya_Delta_Alive_52\",\"Siaya_Delta_Alive_53\",\"Siaya_Delta_Alive_54\",\"Siaya_Delta_Alive_55\",\"Siaya_Delta_Alive_56\",\"Siaya_Delta_Alive_57\",\"Siaya_Delta_Alive_58\",\"Siaya_Delta_Alive_59\",\"Siaya_Delta_Alive_60\",\"Siaya_Delta_Alive_61\",\"Siaya_Delta_Alive_62\",\"Siaya_Delta_Alive_63\",\"Siaya_Delta_Alive_64\",\"Siaya_Delta_Alive_65\",\"Siaya_Delta_Alive_66\",\"Siaya_Delta_Alive_67\",\"Siaya_Delta_Alive_68\",\"Siaya_Delta_Alive_69\",\"Siaya_Delta_Alive_70\",\"Siaya_Delta_Alive_71\",\"Siaya_Delta_Alive_72\",\"Siaya_Delta_Alive_73\",\"Siaya_Delta_Alive_74\",\"Siaya_Delta_Alive_75\",\"Siaya_Delta_Alive_76\",\"Siaya_Delta_Alive_77\",\"Siaya_Delta_Alive_78\",\"Siaya_Delta_Alive_79\",\"Siaya_Delta_Alive_80\",\"Siaya_Delta_Alive_81\",\"Siaya_Delta_Alive_82\",\"Siaya_Delta_Alive_83\",\"Siaya_Delta_Alive_84\",\"Siaya_Delta_Alive_85\",\"Siaya_Delta_Alive_86\",\"Siaya_Delta_Alive_87\",\"Siaya_Delta_Alive_88\",\"Siaya_Delta_Alive_89\",\"Siaya_Delta_Alive_90\",\"Siaya_Delta_Alive_91\",\"Siaya_Delta_Alive_92\",\"Siaya_Delta_Alive_93\",\"Siaya_Delta_Alive_94\",\"Siaya_Delta_Alive_95\",\"Siaya_Delta_Alive_96\",\"Siaya_Delta_Alive_97\",\"Siaya_Delta_Alive_98\",\"Siaya_Delta_Alive_99\",\"Siaya_Delta_Alive_Negative\",\"Siaya_Delta_Dead_01\",\"Siaya_Delta_Dead_02\",\"Siaya_Delta_Dead_03\",\"Siaya_Delta_Dead_04\",\"Siaya_Delta_Dead_05\",\"Siaya_Delta_Dead_06\",\"Siaya_Delta_Dead_07\",\"Siaya_Delta_Dead_08\",\"Siaya_Delta_Dead_09\",\"Siaya_Delta_Dead_10\",\"Siaya_Delta_Dead_100\",\"Siaya_Delta_Dead_101\",\"Siaya_Delta_Dead_102\",\"Siaya_Delta_Dead_103\",\"Siaya_Delta_Dead_104\",\"Siaya_Delta_Dead_105\",\"Siaya_Delta_Dead_106\",\"Siaya_Delta_Dead_107\",\"Siaya_Delta_Dead_108\",\"Siaya_Delta_Dead_109\",\"Siaya_Delta_Dead_11\",\"Siaya_Delta_Dead_110\",\"Siaya_Delta_Dead_111\",\"Siaya_Delta_Dead_112\",\"Siaya_Delta_Dead_113\",\"Siaya_Delta_Dead_114\",\"Siaya_Delta_Dead_115\",\"Siaya_Delta_Dead_116\",\"Siaya_Delta_Dead_117\",\"Siaya_Delta_Dead_118\",\"Siaya_Delta_Dead_119\",\"Siaya_Delta_Dead_12\",\"Siaya_Delta_Dead_120\",\"Siaya_Delta_Dead_121\",\"Siaya_Delta_Dead_122\",\"Siaya_Delta_Dead_123\",\"Siaya_Delta_Dead_124\",\"Siaya_Delta_Dead_125\",\"Siaya_Delta_Dead_126\",\"Siaya_Delta_Dead_127\",\"Siaya_Delta_Dead_128\",\"Siaya_Delta_Dead_129\",\"Siaya_Delta_Dead_13\",\"Siaya_Delta_Dead_130\",\"Siaya_Delta_Dead_131\",\"Siaya_Delta_Dead_14\",\"Siaya_Delta_Dead_15\",\"Siaya_Delta_Dead_16\",\"Siaya_Delta_Dead_17\",\"Siaya_Delta_Dead_18\",\"Siaya_Delta_Dead_19\",\"Siaya_Delta_Dead_20\",\"Siaya_Delta_Dead_21\",\"Siaya_Delta_Dead_22\",\"Siaya_Delta_Dead_23\",\"Siaya_Delta_Dead_24\",\"Siaya_Delta_Dead_25\",\"Siaya_Delta_Dead_26\",\"Siaya_Delta_Dead_27\",\"Siaya_Delta_Dead_28\",\"Siaya_Delta_Dead_29\",\"Siaya_Delta_Dead_30\",\"Siaya_Delta_Dead_31\",\"Siaya_Delta_Dead_32\",\"Siaya_Delta_Dead_33\",\"Siaya_Delta_Dead_34\",\"Siaya_Delta_Dead_35\",\"Siaya_Delta_Dead_36\",\"Siaya_Delta_Dead_37\",\"Siaya_Delta_Dead_38\",\"Siaya_Delta_Dead_39\",\"Siaya_Delta_Dead_40\",\"Siaya_Delta_Dead_41\",\"Siaya_Delta_Dead_42\",\"Siaya_Delta_Dead_43\",\"Siaya_Delta_Dead_44\",\"Siaya_Delta_Dead_45\",\"Siaya_Delta_Dead_46\",\"Siaya_Delta_Dead_47\",\"Siaya_Delta_Dead_48\",\"Siaya_Delta_Dead_49\",\"Siaya_Delta_Dead_50\",\"Siaya_Delta_Dead_51\",\"Siaya_Delta_Dead_52\",\"Siaya_Delta_Dead_53\",\"Siaya_Delta_Dead_54\",\"Siaya_Delta_Dead_55\",\"Siaya_Delta_Dead_56\",\"Siaya_Delta_Dead_57\",\"Siaya_Delta_Dead_58\",\"Siaya_Delta_Dead_59\",\"Siaya_Delta_Dead_60\",\"Siaya_Delta_Dead_61\",\"Siaya_Delta_Dead_62\",\"Siaya_Delta_Dead_63\",\"Siaya_Delta_Dead_64\",\"Siaya_Delta_Dead_65\",\"Siaya_Delta_Dead_66\",\"Siaya_Delta_Dead_67\",\"Siaya_Delta_Dead_68\",\"Siaya_Delta_Dead_69\",\"Siaya_Delta_Dead_70\",\"Siaya_Delta_Dead_71\",\"Siaya_Delta_Dead_72\",\"Siaya_Delta_Dead_73\",\"Siaya_Delta_Dead_74\",\"Siaya_Delta_Dead_75\",\"Siaya_Delta_Dead_76\",\"Siaya_Delta_Dead_77\",\"Siaya_Delta_Dead_78\",\"Siaya_Delta_Dead_79\",\"Siaya_Delta_Dead_80\",\"Siaya_Delta_Dead_81\",\"Siaya_Delta_Dead_82\",\"Siaya_Delta_Dead_83\",\"Siaya_Delta_Dead_84\",\"Siaya_Delta_Dead_85\",\"Siaya_Delta_Dead_86\",\"Siaya_Delta_Dead_87\",\"Siaya_Delta_Dead_88\",\"Siaya_Delta_Dead_89\",\"Siaya_Delta_Dead_90\",\"Siaya_Delta_Dead_91\",\"Siaya_Delta_Dead_92\",\"Siaya_Delta_Dead_93\",\"Siaya_Delta_Dead_94\",\"Siaya_Delta_Dead_95\",\"Siaya_Delta_Dead_96\",\"Siaya_Delta_Dead_97\",\"Siaya_Delta_Dead_98\",\"Siaya_Delta_Dead_99\",\"Siaya_Delta_Dead_Negative\",\"VK7_Negative\",\"VK7_alive_01\",\"VK7_alive_02\",\"VK7_alive_03\",\"VK7_alive_04\",\"VK7_alive_05\",\"VK7_alive_06\",\"VK7_alive_07\",\"VK7_alive_08\",\"VK7_alive_09\",\"VK7_alive_10\",\"VK7_alive_11\",\"VK7_alive_12\",\"VK7_alive_13\",\"VK7_alive_14\",\"VK7_alive_15\",\"VK7_alive_16\",\"VK7_alive_17\",\"VK7_alive_18\",\"VK7_alive_19\",\"VK7_alive_20\",\"VK7_alive_21\",\"VK7_alive_22\",\"VK7_alive_23\",\"VK7_alive_24\",\"VK7_alive_25\",\"VK7_alive_26\",\"VK7_alive_27\",\"VK7_alive_28\",\"VK7_alive_29\",\"VK7_alive_30\",\"VK7_alive_31\",\"VK7_alive_32\",\"VK7_alive_33\",\"VK7_alive_34\",\"VK7_alive_35\",\"VK7_alive_36\",\"VK7_alive_37\",\"VK7_alive_38\",\"VK7_alive_39\",\"VK7_alive_40\",\"VK7_alive_41\",\"VK7_alive_42\",\"VK7_alive_43\",\"VK7_alive_44\",\"VK7_alive_45\",\"VK7_alive_46\",\"VK7_alive_47\",\"VK7_dead_01\",\"VK7_dead_02\",\"VK7_dead_03\",\"VK7_dead_04\",\"VK7_dead_04_dil\",\"VK7_dead_05\",\"VK7_dead_06\",\"VK7_dead_07\",\"VK7_dead_08\",\"VK7_dead_09\",\"VK7_dead_10\",\"VK7_dead_10_dil\",\"VK7_dead_11\",\"VK7_dead_12\",\"VK7_dead_13\",\"VK7_dead_14\",\"VK7_dead_15\",\"VK7_dead_16\",\"VK7_dead_16_dil\",\"VK7_dead_17\",\"VK7_dead_18\",\"VK7_dead_19\",\"VK7_dead_20\",\"VK7_dead_21\",\"VK7_dead_22\",\"VK7_dead_22_dil\",\"VK7_dead_23\",\"VK7_dead_24\",\"VK7_dead_25\",\"VK7_dead_26\",\"VK7_dead_27\",\"VK7_dead_28\",\"VK7_dead_28_dil\",\"VK7_dead_29\",\"VK7_dead_30\",\"VK7_dead_31\",\"VK7_dead_32\",\"VK7_dead_33\",\"VK7_dead_34\",\"VK7_dead_34_dil\",\"VK7_dead_35\",\"VK7_dead_36\",\"VK7_dead_37\",\"VK7_dead_38\",\"VK7_dead_39\",\"VK7_dead_40\",\"VK7_dead_41\",\"VK7_dead_42\"],\"xaxis\":\"x\",\"y\":[99258,3401,8783,1425,4494,6668,533,18024,5793,3637,10324,4629,6614,6625,2489,3056,3496,4312,16907,1711,10874,4541,10585,7559,2284,29385,4172,2138,5544,18303,5249,2887,16147,16949,18235,7783,20677,5434,5204,5521,2350,2621,9050,5948,2889,1791,8721,7626,43798,24721,107159,10601,11106,4484,20911,16272,4960,3470,4300,9325,108377,19804,7088,16888,131,3080,8423,2403,2464,1581,2093,3233,15333,12038,3725,10244,1664,4274,76678,1479,19992,4568,3619,4022,38134,168534,4766,13451,6352,106,9367,1850,6932,7859,11742,12128,8426,10436,40530,50578,38101,1046,71,696,1764,1472,4878,3755,22198,28289,6222,6562,4222,7030,6711,5100,1566,3229,3624,10478,554,42482,3659,7451,14768,3336,2618,3560,2597,642,4523,1758,17575,17600,5450,11344,1110,4196,572,1508,3100,2356,1251,1946,4245,32685,52634,5879,4540,4780,3741,3800,26629,3726,2609,6698,9304,5797,14478,35613,37,4516,292,3744,2124,993,561,1943,18375,13112,5645,13164,6238,1393,1127,1130,2568,950,664,1671,8379,284985,7056,12810,22660,33,1568,1570,1245,612,4355,1781,298939,141445,127828,61466,233115,79475,13285,354730,200104,136018,165515,115212,101674,237771,125974,119209,52253,93742,64390,159444,180985,166561,38532,162058,116400,167832,218465,119099,1519,132812,41026,254851,70538,72673,43451,39102,20087,27117,27165,72613,309,31531,127392,44146,23769,199461,93201,188644,271437,199848,171766,209125,276863,205940,171740,440507,3602,249365,105892,141717,352209,419029,149021,334890,360930,413012,259389,247448,57380,68549,99987,50416,121429,170629,234985,291256,103121,100759,188674,345308,129642,78327,240521,93778,124517,144705,413560,337881,502981,200090,279936,216353,155417,45106,97611,195105,8483,217852,100082,146530,81254,100233,122297,93391,71132,67150,16001,50049,86612,63650,186182,58051,77394,143852,102536,98002,62288,49415,52566,40627,59453,388,79769,26064,99316,91713,128873,60735,2941,201717,114635,5410,288262,56510,200048,61468,256130,57343,3147,100529,5163,60984,74044,108182,83503,91466,113418,125109,4516,278729,125507,116761,58639,98699,104720,115872,114417,79865,53562,135743,75961,104308,145546,137103,92080,42126,64214,133724,80832,52808,23883,77624,24619,64643,171200,30281,28651,250371,148553,43543,101848,365465,242121,63446,6867,147045,172882,115272,7009,118688,77306,356879,191660,104696,148222,74799,21217,72965,122917,66346,297127,81423,218108,136035,191491,138154,218078,67469,6560,217895,112431,224568,175167,28812,185547,149775,60448,112603,193882,73585,15143,219177,127790,118357,306841,170389,277052,75056,4191,325498,55954,128734,5772,18907,81639,47058,318080,176659,216723,117344,164785,107361,105511,50134,4674,40307,81751,25183,443756,49896,173698,139376,124386,155,76831,32030,3025,61200,96199,139506,50170,87016,128704,15720,748,512,1,5,13006,4,21420,5401,31713,12,27763,8,22042,1678,10691,32941,20157,44,15292,24961,42822,28,14833,40,36989,6245,44483,0,22677,4,88944,25,13074,0,15412,15817,19658,9224,9542,0,11174,14122,15645,10835,14180,4585,4840,19531,15992,15709,66679,6895,4274,59902,139098,43741,64288,6060,41498,1576,42078,69280,722,23759,12426,20486,1746,21601,7922,13063,22133,8243,19338,765,9468,34670,8623,12903,12018,58701,857,19713,16784,73963,3449,16232,17848,3,5824,15967,9268,39418,11803,3575,25509,7899],\"yaxis\":\"y\",\"type\":\"bar\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"],[\"3L\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003esample_id=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"3L\",\"marker\":{\"color\":\"#2CA02C\",\"pattern\":{\"shape\":\"\"}},\"name\":\"3L\",\"offsetgroup\":\"3L\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"auto\",\"x\":[\"GH_01\",\"GH_02\",\"GH_03\",\"GH_04\",\"GH_05\",\"GH_06\",\"GH_07\",\"GH_08\",\"GH_09\",\"GH_10\",\"GH_11\",\"GH_12\",\"GH_13\",\"GH_14\",\"GH_15\",\"GH_16\",\"GH_17\",\"GH_18\",\"GH_19\",\"GH_20\",\"GH_21\",\"GH_22\",\"GH_23\",\"GH_24\",\"GH_25\",\"GH_26\",\"GH_27\",\"GH_28\",\"GH_29\",\"GH_30\",\"GH_31\",\"GH_32\",\"GH_33\",\"GH_34\",\"GH_35\",\"GH_36\",\"GH_37\",\"GH_38\",\"GH_39\",\"GH_40_low_vol\",\"GH_41\",\"GH_42\",\"GH_43\",\"GH_44\",\"GH_45\",\"GH_46\",\"GH_47\",\"GH_48\",\"GH_49\",\"GH_50\",\"GH_51\",\"GH_52\",\"GH_53\",\"GH_54\",\"GH_55\",\"GH_56\",\"GH_57\",\"GH_58\",\"GH_59\",\"GH_60\",\"GH_61\",\"GH_62\",\"GH_63\",\"GH_64\",\"GH_65_low_vol\",\"GH_66\",\"GH_67\",\"GH_68\",\"GH_69\",\"GH_70\",\"GH_71\",\"GH_72\",\"GH_73\",\"GH_74\",\"GH_75\",\"GH_76\",\"GH_77\",\"GH_78\",\"GH_79\",\"GH_80_low_vol\",\"GH_81\",\"GH_82\",\"GH_83\",\"GH_84\",\"GH_85\",\"GH_86\",\"GH_87\",\"GH_88\",\"GH_89\",\"GH_90\",\"GH_91\",\"GH_92\",\"GH_93\",\"GH_94\",\"GH_95\",\"GH_Negative\",\"GM_01\",\"GM_02\",\"GM_03\",\"GM_04\",\"GM_05\",\"GM_06\",\"GM_07\",\"GM_08\",\"GM_09\",\"GM_10\",\"GM_11\",\"GM_12\",\"GM_13\",\"GM_14\",\"GM_15\",\"GM_16\",\"GM_17\",\"GM_18\",\"GM_19\",\"GM_20\",\"GM_21\",\"GM_22\",\"GM_23\",\"GM_24\",\"GM_25\",\"GM_26\",\"GM_27\",\"GM_28\",\"GM_29\",\"GM_30\",\"GM_31\",\"GM_32\",\"GM_33\",\"GM_34\",\"GM_35\",\"GM_36\",\"GM_37\",\"GM_38\",\"GM_39\",\"GM_40\",\"GM_41\",\"GM_42\",\"GM_43\",\"GM_44\",\"GM_45\",\"GM_46\",\"GM_47\",\"GM_48\",\"GM_49\",\"GM_50\",\"GM_51\",\"GM_52\",\"GM_53\",\"GM_54\",\"GM_55\",\"GM_56\",\"GM_57\",\"GM_58\",\"GM_59\",\"GM_60\",\"GM_61\",\"GM_62\",\"GM_63\",\"GM_64\",\"GM_65\",\"GM_66\",\"GM_67\",\"GM_68\",\"GM_69\",\"GM_70\",\"GM_71\",\"GM_72\",\"GM_73\",\"GM_74\",\"GM_75\",\"GM_76\",\"GM_77\",\"GM_78\",\"GM_79\",\"GM_80\",\"GM_81\",\"GM_82\",\"GM_83\",\"GM_84\",\"GM_85\",\"GM_86\",\"GM_87\",\"GM_88\",\"GM_89\",\"GM_90\",\"GM_91\",\"GM_92\",\"GM_93\",\"GM_94\",\"GM_95\",\"GM_96\",\"Siaya_Delta_Alive_01\",\"Siaya_Delta_Alive_02\",\"Siaya_Delta_Alive_03\",\"Siaya_Delta_Alive_04\",\"Siaya_Delta_Alive_05\",\"Siaya_Delta_Alive_06\",\"Siaya_Delta_Alive_07\",\"Siaya_Delta_Alive_08\",\"Siaya_Delta_Alive_09\",\"Siaya_Delta_Alive_10\",\"Siaya_Delta_Alive_100\",\"Siaya_Delta_Alive_101\",\"Siaya_Delta_Alive_102\",\"Siaya_Delta_Alive_103\",\"Siaya_Delta_Alive_104\",\"Siaya_Delta_Alive_105\",\"Siaya_Delta_Alive_106\",\"Siaya_Delta_Alive_107\",\"Siaya_Delta_Alive_108\",\"Siaya_Delta_Alive_109\",\"Siaya_Delta_Alive_11\",\"Siaya_Delta_Alive_110\",\"Siaya_Delta_Alive_111\",\"Siaya_Delta_Alive_112\",\"Siaya_Delta_Alive_113\",\"Siaya_Delta_Alive_114\",\"Siaya_Delta_Alive_115\",\"Siaya_Delta_Alive_116\",\"Siaya_Delta_Alive_117\",\"Siaya_Delta_Alive_118\",\"Siaya_Delta_Alive_119\",\"Siaya_Delta_Alive_12\",\"Siaya_Delta_Alive_120\",\"Siaya_Delta_Alive_121\",\"Siaya_Delta_Alive_122\",\"Siaya_Delta_Alive_123\",\"Siaya_Delta_Alive_124\",\"Siaya_Delta_Alive_125\",\"Siaya_Delta_Alive_126\",\"Siaya_Delta_Alive_127\",\"Siaya_Delta_Alive_128\",\"Siaya_Delta_Alive_129\",\"Siaya_Delta_Alive_13\",\"Siaya_Delta_Alive_130\",\"Siaya_Delta_Alive_131\",\"Siaya_Delta_Alive_14\",\"Siaya_Delta_Alive_15\",\"Siaya_Delta_Alive_16\",\"Siaya_Delta_Alive_17\",\"Siaya_Delta_Alive_18\",\"Siaya_Delta_Alive_19\",\"Siaya_Delta_Alive_20\",\"Siaya_Delta_Alive_21\",\"Siaya_Delta_Alive_22\",\"Siaya_Delta_Alive_23\",\"Siaya_Delta_Alive_24\",\"Siaya_Delta_Alive_25\",\"Siaya_Delta_Alive_26\",\"Siaya_Delta_Alive_27\",\"Siaya_Delta_Alive_28\",\"Siaya_Delta_Alive_29\",\"Siaya_Delta_Alive_30\",\"Siaya_Delta_Alive_31\",\"Siaya_Delta_Alive_32\",\"Siaya_Delta_Alive_33\",\"Siaya_Delta_Alive_34\",\"Siaya_Delta_Alive_35\",\"Siaya_Delta_Alive_36\",\"Siaya_Delta_Alive_37\",\"Siaya_Delta_Alive_38\",\"Siaya_Delta_Alive_39\",\"Siaya_Delta_Alive_40\",\"Siaya_Delta_Alive_41\",\"Siaya_Delta_Alive_42\",\"Siaya_Delta_Alive_43\",\"Siaya_Delta_Alive_44\",\"Siaya_Delta_Alive_45\",\"Siaya_Delta_Alive_46\",\"Siaya_Delta_Alive_47\",\"Siaya_Delta_Alive_48\",\"Siaya_Delta_Alive_49\",\"Siaya_Delta_Alive_50\",\"Siaya_Delta_Alive_51\",\"Siaya_Delta_Alive_52\",\"Siaya_Delta_Alive_53\",\"Siaya_Delta_Alive_54\",\"Siaya_Delta_Alive_55\",\"Siaya_Delta_Alive_56\",\"Siaya_Delta_Alive_57\",\"Siaya_Delta_Alive_58\",\"Siaya_Delta_Alive_59\",\"Siaya_Delta_Alive_60\",\"Siaya_Delta_Alive_61\",\"Siaya_Delta_Alive_62\",\"Siaya_Delta_Alive_63\",\"Siaya_Delta_Alive_64\",\"Siaya_Delta_Alive_65\",\"Siaya_Delta_Alive_66\",\"Siaya_Delta_Alive_67\",\"Siaya_Delta_Alive_68\",\"Siaya_Delta_Alive_69\",\"Siaya_Delta_Alive_70\",\"Siaya_Delta_Alive_71\",\"Siaya_Delta_Alive_72\",\"Siaya_Delta_Alive_73\",\"Siaya_Delta_Alive_74\",\"Siaya_Delta_Alive_75\",\"Siaya_Delta_Alive_76\",\"Siaya_Delta_Alive_77\",\"Siaya_Delta_Alive_78\",\"Siaya_Delta_Alive_79\",\"Siaya_Delta_Alive_80\",\"Siaya_Delta_Alive_81\",\"Siaya_Delta_Alive_82\",\"Siaya_Delta_Alive_83\",\"Siaya_Delta_Alive_84\",\"Siaya_Delta_Alive_85\",\"Siaya_Delta_Alive_86\",\"Siaya_Delta_Alive_87\",\"Siaya_Delta_Alive_88\",\"Siaya_Delta_Alive_89\",\"Siaya_Delta_Alive_90\",\"Siaya_Delta_Alive_91\",\"Siaya_Delta_Alive_92\",\"Siaya_Delta_Alive_93\",\"Siaya_Delta_Alive_94\",\"Siaya_Delta_Alive_95\",\"Siaya_Delta_Alive_96\",\"Siaya_Delta_Alive_97\",\"Siaya_Delta_Alive_98\",\"Siaya_Delta_Alive_99\",\"Siaya_Delta_Alive_Negative\",\"Siaya_Delta_Dead_01\",\"Siaya_Delta_Dead_02\",\"Siaya_Delta_Dead_03\",\"Siaya_Delta_Dead_04\",\"Siaya_Delta_Dead_05\",\"Siaya_Delta_Dead_06\",\"Siaya_Delta_Dead_07\",\"Siaya_Delta_Dead_08\",\"Siaya_Delta_Dead_09\",\"Siaya_Delta_Dead_10\",\"Siaya_Delta_Dead_100\",\"Siaya_Delta_Dead_101\",\"Siaya_Delta_Dead_102\",\"Siaya_Delta_Dead_103\",\"Siaya_Delta_Dead_104\",\"Siaya_Delta_Dead_105\",\"Siaya_Delta_Dead_106\",\"Siaya_Delta_Dead_107\",\"Siaya_Delta_Dead_108\",\"Siaya_Delta_Dead_109\",\"Siaya_Delta_Dead_11\",\"Siaya_Delta_Dead_110\",\"Siaya_Delta_Dead_111\",\"Siaya_Delta_Dead_112\",\"Siaya_Delta_Dead_113\",\"Siaya_Delta_Dead_114\",\"Siaya_Delta_Dead_115\",\"Siaya_Delta_Dead_116\",\"Siaya_Delta_Dead_117\",\"Siaya_Delta_Dead_118\",\"Siaya_Delta_Dead_119\",\"Siaya_Delta_Dead_12\",\"Siaya_Delta_Dead_120\",\"Siaya_Delta_Dead_121\",\"Siaya_Delta_Dead_122\",\"Siaya_Delta_Dead_123\",\"Siaya_Delta_Dead_124\",\"Siaya_Delta_Dead_125\",\"Siaya_Delta_Dead_126\",\"Siaya_Delta_Dead_127\",\"Siaya_Delta_Dead_128\",\"Siaya_Delta_Dead_129\",\"Siaya_Delta_Dead_13\",\"Siaya_Delta_Dead_130\",\"Siaya_Delta_Dead_131\",\"Siaya_Delta_Dead_14\",\"Siaya_Delta_Dead_15\",\"Siaya_Delta_Dead_16\",\"Siaya_Delta_Dead_17\",\"Siaya_Delta_Dead_18\",\"Siaya_Delta_Dead_19\",\"Siaya_Delta_Dead_20\",\"Siaya_Delta_Dead_21\",\"Siaya_Delta_Dead_22\",\"Siaya_Delta_Dead_23\",\"Siaya_Delta_Dead_24\",\"Siaya_Delta_Dead_25\",\"Siaya_Delta_Dead_26\",\"Siaya_Delta_Dead_27\",\"Siaya_Delta_Dead_28\",\"Siaya_Delta_Dead_29\",\"Siaya_Delta_Dead_30\",\"Siaya_Delta_Dead_31\",\"Siaya_Delta_Dead_32\",\"Siaya_Delta_Dead_33\",\"Siaya_Delta_Dead_34\",\"Siaya_Delta_Dead_35\",\"Siaya_Delta_Dead_36\",\"Siaya_Delta_Dead_37\",\"Siaya_Delta_Dead_38\",\"Siaya_Delta_Dead_39\",\"Siaya_Delta_Dead_40\",\"Siaya_Delta_Dead_41\",\"Siaya_Delta_Dead_42\",\"Siaya_Delta_Dead_43\",\"Siaya_Delta_Dead_44\",\"Siaya_Delta_Dead_45\",\"Siaya_Delta_Dead_46\",\"Siaya_Delta_Dead_47\",\"Siaya_Delta_Dead_48\",\"Siaya_Delta_Dead_49\",\"Siaya_Delta_Dead_50\",\"Siaya_Delta_Dead_51\",\"Siaya_Delta_Dead_52\",\"Siaya_Delta_Dead_53\",\"Siaya_Delta_Dead_54\",\"Siaya_Delta_Dead_55\",\"Siaya_Delta_Dead_56\",\"Siaya_Delta_Dead_57\",\"Siaya_Delta_Dead_58\",\"Siaya_Delta_Dead_59\",\"Siaya_Delta_Dead_60\",\"Siaya_Delta_Dead_61\",\"Siaya_Delta_Dead_62\",\"Siaya_Delta_Dead_63\",\"Siaya_Delta_Dead_64\",\"Siaya_Delta_Dead_65\",\"Siaya_Delta_Dead_66\",\"Siaya_Delta_Dead_67\",\"Siaya_Delta_Dead_68\",\"Siaya_Delta_Dead_69\",\"Siaya_Delta_Dead_70\",\"Siaya_Delta_Dead_71\",\"Siaya_Delta_Dead_72\",\"Siaya_Delta_Dead_73\",\"Siaya_Delta_Dead_74\",\"Siaya_Delta_Dead_75\",\"Siaya_Delta_Dead_76\",\"Siaya_Delta_Dead_77\",\"Siaya_Delta_Dead_78\",\"Siaya_Delta_Dead_79\",\"Siaya_Delta_Dead_80\",\"Siaya_Delta_Dead_81\",\"Siaya_Delta_Dead_82\",\"Siaya_Delta_Dead_83\",\"Siaya_Delta_Dead_84\",\"Siaya_Delta_Dead_85\",\"Siaya_Delta_Dead_86\",\"Siaya_Delta_Dead_87\",\"Siaya_Delta_Dead_88\",\"Siaya_Delta_Dead_89\",\"Siaya_Delta_Dead_90\",\"Siaya_Delta_Dead_91\",\"Siaya_Delta_Dead_92\",\"Siaya_Delta_Dead_93\",\"Siaya_Delta_Dead_94\",\"Siaya_Delta_Dead_95\",\"Siaya_Delta_Dead_96\",\"Siaya_Delta_Dead_97\",\"Siaya_Delta_Dead_98\",\"Siaya_Delta_Dead_99\",\"Siaya_Delta_Dead_Negative\",\"VK7_Negative\",\"VK7_alive_01\",\"VK7_alive_02\",\"VK7_alive_03\",\"VK7_alive_04\",\"VK7_alive_05\",\"VK7_alive_06\",\"VK7_alive_07\",\"VK7_alive_08\",\"VK7_alive_09\",\"VK7_alive_10\",\"VK7_alive_11\",\"VK7_alive_12\",\"VK7_alive_13\",\"VK7_alive_14\",\"VK7_alive_15\",\"VK7_alive_16\",\"VK7_alive_17\",\"VK7_alive_18\",\"VK7_alive_19\",\"VK7_alive_20\",\"VK7_alive_21\",\"VK7_alive_22\",\"VK7_alive_23\",\"VK7_alive_24\",\"VK7_alive_25\",\"VK7_alive_26\",\"VK7_alive_27\",\"VK7_alive_28\",\"VK7_alive_29\",\"VK7_alive_30\",\"VK7_alive_31\",\"VK7_alive_32\",\"VK7_alive_33\",\"VK7_alive_34\",\"VK7_alive_35\",\"VK7_alive_36\",\"VK7_alive_37\",\"VK7_alive_38\",\"VK7_alive_39\",\"VK7_alive_40\",\"VK7_alive_41\",\"VK7_alive_42\",\"VK7_alive_43\",\"VK7_alive_44\",\"VK7_alive_45\",\"VK7_alive_46\",\"VK7_alive_47\",\"VK7_dead_01\",\"VK7_dead_02\",\"VK7_dead_03\",\"VK7_dead_04\",\"VK7_dead_04_dil\",\"VK7_dead_05\",\"VK7_dead_06\",\"VK7_dead_07\",\"VK7_dead_08\",\"VK7_dead_09\",\"VK7_dead_10\",\"VK7_dead_10_dil\",\"VK7_dead_11\",\"VK7_dead_12\",\"VK7_dead_13\",\"VK7_dead_14\",\"VK7_dead_15\",\"VK7_dead_16\",\"VK7_dead_16_dil\",\"VK7_dead_17\",\"VK7_dead_18\",\"VK7_dead_19\",\"VK7_dead_20\",\"VK7_dead_21\",\"VK7_dead_22\",\"VK7_dead_22_dil\",\"VK7_dead_23\",\"VK7_dead_24\",\"VK7_dead_25\",\"VK7_dead_26\",\"VK7_dead_27\",\"VK7_dead_28\",\"VK7_dead_28_dil\",\"VK7_dead_29\",\"VK7_dead_30\",\"VK7_dead_31\",\"VK7_dead_32\",\"VK7_dead_33\",\"VK7_dead_34\",\"VK7_dead_34_dil\",\"VK7_dead_35\",\"VK7_dead_36\",\"VK7_dead_37\",\"VK7_dead_38\",\"VK7_dead_39\",\"VK7_dead_40\",\"VK7_dead_41\",\"VK7_dead_42\"],\"xaxis\":\"x\",\"y\":[10717,503,131,187,1070,1347,86,307,478,724,938,653,1249,1558,429,811,800,529,2380,265,2611,604,434,166,3063,4744,1316,268,1267,6568,118,681,2498,2778,1379,134,9239,1482,1751,2300,1035,913,2928,823,1288,463,1066,211,12707,8982,28915,2085,2747,1234,4903,3896,1411,540,1076,104,40822,10223,1475,7304,20,733,1770,820,845,403,279,82,4903,3769,1653,4701,816,1410,21544,324,3851,1014,1146,343,12399,83927,886,3188,108,53,4227,196,1978,520,4296,474,2151,1558,8037,5968,2810,282,66,226,589,278,729,676,2476,11952,451,968,1044,1561,639,781,598,574,955,545,793,2539,933,711,1582,614,1784,415,483,120,440,422,3316,2652,2043,1413,143,751,169,319,265,435,104,418,1174,3005,2549,1552,722,1592,709,533,4394,546,317,1349,2411,2042,1623,4407,19,757,22,419,418,315,249,133,6160,1661,1769,4769,2249,308,492,476,291,128,169,151,2442,150367,1271,1831,2808,21,206,298,245,177,483,45,17147,30065,14327,13150,23090,21103,6713,47848,58808,13426,21832,15495,9274,21829,18017,15949,7097,11254,14444,25466,74173,23118,7503,22444,16325,13522,23770,10120,122,14033,3432,36980,8585,14413,9315,8942,3458,6295,8834,14466,105,8425,18594,7642,4986,24973,11360,29163,45191,45318,26005,21132,65515,60918,32469,57943,5647,30968,12484,17766,57416,86916,28981,48488,44240,66702,27861,28028,6849,8142,10454,10830,28280,31877,51499,43040,13173,18903,27903,38280,14811,10493,25532,9615,22693,22216,54278,28033,76742,24235,30911,24193,27221,4501,13665,26522,788,37274,9567,24203,16324,15842,19795,24249,20490,15639,2664,11100,17396,16626,55688,15450,22220,43521,21307,28274,11933,12206,12009,9043,11302,204,25473,4485,22644,21360,27500,21744,1298,15401,28848,119,59390,10439,29402,8763,22693,17303,1177,12226,271,7625,5406,24421,18690,18461,13180,17554,8503,58173,22792,16264,15940,14031,24327,20109,18077,22811,5961,14687,14886,9721,14199,18104,17965,4557,10794,16227,20869,15061,9318,16720,7687,16075,22557,6827,12941,53470,25715,6977,11962,87466,35363,7324,53,22618,28850,17495,12462,15475,11418,87956,28933,21456,22856,9186,605,12021,18253,8027,84818,15697,34923,40210,34854,23704,28393,9217,168,23152,18725,26267,27952,2868,44929,24580,10980,24635,22535,7781,143,37298,13030,17795,57691,35630,109360,12803,95,56627,5303,21251,203,3583,20631,15613,106301,63610,98997,43195,43629,24123,25357,10626,97,12406,26089,6869,150974,16605,69927,48626,28695,104,23834,6959,100,11817,23784,10366,7191,8603,20833,3783,20,409,4,13,5858,0,16397,2440,10525,0,11372,8,7297,33,4350,15214,5049,8,7678,19291,10909,0,4769,23,22685,2607,11124,4,12616,0,23839,0,4683,0,5546,6548,13907,7133,4924,0,4174,8418,11207,4691,8113,2957,5500,11005,5627,4368,22567,5514,74,40624,67739,13386,18442,2542,12063,67,13204,13582,1524,4598,2535,11930,243,7383,2981,5951,5144,5670,7010,133,3412,8088,1417,4208,6895,19457,87,9650,8219,34854,449,6981,6716,4,4859,4720,9920,22950,6633,950,14511,3525],\"yaxis\":\"y\",\"type\":\"bar\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"],[\"3R\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003esample_id=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"3R\",\"marker\":{\"color\":\"#D62728\",\"pattern\":{\"shape\":\"\"}},\"name\":\"3R\",\"offsetgroup\":\"3R\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"auto\",\"x\":[\"GH_01\",\"GH_02\",\"GH_03\",\"GH_04\",\"GH_05\",\"GH_06\",\"GH_07\",\"GH_08\",\"GH_09\",\"GH_10\",\"GH_11\",\"GH_12\",\"GH_13\",\"GH_14\",\"GH_15\",\"GH_16\",\"GH_17\",\"GH_18\",\"GH_19\",\"GH_20\",\"GH_21\",\"GH_22\",\"GH_23\",\"GH_24\",\"GH_25\",\"GH_26\",\"GH_27\",\"GH_28\",\"GH_29\",\"GH_30\",\"GH_31\",\"GH_32\",\"GH_33\",\"GH_34\",\"GH_35\",\"GH_36\",\"GH_37\",\"GH_38\",\"GH_39\",\"GH_40_low_vol\",\"GH_41\",\"GH_42\",\"GH_43\",\"GH_44\",\"GH_45\",\"GH_46\",\"GH_47\",\"GH_48\",\"GH_49\",\"GH_50\",\"GH_51\",\"GH_52\",\"GH_53\",\"GH_54\",\"GH_55\",\"GH_56\",\"GH_57\",\"GH_58\",\"GH_59\",\"GH_60\",\"GH_61\",\"GH_62\",\"GH_63\",\"GH_64\",\"GH_65_low_vol\",\"GH_66\",\"GH_67\",\"GH_68\",\"GH_69\",\"GH_70\",\"GH_71\",\"GH_72\",\"GH_73\",\"GH_74\",\"GH_75\",\"GH_76\",\"GH_77\",\"GH_78\",\"GH_79\",\"GH_80_low_vol\",\"GH_81\",\"GH_82\",\"GH_83\",\"GH_84\",\"GH_85\",\"GH_86\",\"GH_87\",\"GH_88\",\"GH_89\",\"GH_90\",\"GH_91\",\"GH_92\",\"GH_93\",\"GH_94\",\"GH_95\",\"GH_Negative\",\"GM_01\",\"GM_02\",\"GM_03\",\"GM_04\",\"GM_05\",\"GM_06\",\"GM_07\",\"GM_08\",\"GM_09\",\"GM_10\",\"GM_11\",\"GM_12\",\"GM_13\",\"GM_14\",\"GM_15\",\"GM_16\",\"GM_17\",\"GM_18\",\"GM_19\",\"GM_20\",\"GM_21\",\"GM_22\",\"GM_23\",\"GM_24\",\"GM_25\",\"GM_26\",\"GM_27\",\"GM_28\",\"GM_29\",\"GM_30\",\"GM_31\",\"GM_32\",\"GM_33\",\"GM_34\",\"GM_35\",\"GM_36\",\"GM_37\",\"GM_38\",\"GM_39\",\"GM_40\",\"GM_41\",\"GM_42\",\"GM_43\",\"GM_44\",\"GM_45\",\"GM_46\",\"GM_47\",\"GM_48\",\"GM_49\",\"GM_50\",\"GM_51\",\"GM_52\",\"GM_53\",\"GM_54\",\"GM_55\",\"GM_56\",\"GM_57\",\"GM_58\",\"GM_59\",\"GM_60\",\"GM_61\",\"GM_62\",\"GM_63\",\"GM_64\",\"GM_65\",\"GM_66\",\"GM_67\",\"GM_68\",\"GM_69\",\"GM_70\",\"GM_71\",\"GM_72\",\"GM_73\",\"GM_74\",\"GM_75\",\"GM_76\",\"GM_77\",\"GM_78\",\"GM_79\",\"GM_80\",\"GM_81\",\"GM_82\",\"GM_83\",\"GM_84\",\"GM_85\",\"GM_86\",\"GM_87\",\"GM_88\",\"GM_89\",\"GM_90\",\"GM_91\",\"GM_92\",\"GM_93\",\"GM_94\",\"GM_95\",\"GM_96\",\"Siaya_Delta_Alive_01\",\"Siaya_Delta_Alive_02\",\"Siaya_Delta_Alive_03\",\"Siaya_Delta_Alive_04\",\"Siaya_Delta_Alive_05\",\"Siaya_Delta_Alive_06\",\"Siaya_Delta_Alive_07\",\"Siaya_Delta_Alive_08\",\"Siaya_Delta_Alive_09\",\"Siaya_Delta_Alive_10\",\"Siaya_Delta_Alive_100\",\"Siaya_Delta_Alive_101\",\"Siaya_Delta_Alive_102\",\"Siaya_Delta_Alive_103\",\"Siaya_Delta_Alive_104\",\"Siaya_Delta_Alive_105\",\"Siaya_Delta_Alive_106\",\"Siaya_Delta_Alive_107\",\"Siaya_Delta_Alive_108\",\"Siaya_Delta_Alive_109\",\"Siaya_Delta_Alive_11\",\"Siaya_Delta_Alive_110\",\"Siaya_Delta_Alive_111\",\"Siaya_Delta_Alive_112\",\"Siaya_Delta_Alive_113\",\"Siaya_Delta_Alive_114\",\"Siaya_Delta_Alive_115\",\"Siaya_Delta_Alive_116\",\"Siaya_Delta_Alive_117\",\"Siaya_Delta_Alive_118\",\"Siaya_Delta_Alive_119\",\"Siaya_Delta_Alive_12\",\"Siaya_Delta_Alive_120\",\"Siaya_Delta_Alive_121\",\"Siaya_Delta_Alive_122\",\"Siaya_Delta_Alive_123\",\"Siaya_Delta_Alive_124\",\"Siaya_Delta_Alive_125\",\"Siaya_Delta_Alive_126\",\"Siaya_Delta_Alive_127\",\"Siaya_Delta_Alive_128\",\"Siaya_Delta_Alive_129\",\"Siaya_Delta_Alive_13\",\"Siaya_Delta_Alive_130\",\"Siaya_Delta_Alive_131\",\"Siaya_Delta_Alive_14\",\"Siaya_Delta_Alive_15\",\"Siaya_Delta_Alive_16\",\"Siaya_Delta_Alive_17\",\"Siaya_Delta_Alive_18\",\"Siaya_Delta_Alive_19\",\"Siaya_Delta_Alive_20\",\"Siaya_Delta_Alive_21\",\"Siaya_Delta_Alive_22\",\"Siaya_Delta_Alive_23\",\"Siaya_Delta_Alive_24\",\"Siaya_Delta_Alive_25\",\"Siaya_Delta_Alive_26\",\"Siaya_Delta_Alive_27\",\"Siaya_Delta_Alive_28\",\"Siaya_Delta_Alive_29\",\"Siaya_Delta_Alive_30\",\"Siaya_Delta_Alive_31\",\"Siaya_Delta_Alive_32\",\"Siaya_Delta_Alive_33\",\"Siaya_Delta_Alive_34\",\"Siaya_Delta_Alive_35\",\"Siaya_Delta_Alive_36\",\"Siaya_Delta_Alive_37\",\"Siaya_Delta_Alive_38\",\"Siaya_Delta_Alive_39\",\"Siaya_Delta_Alive_40\",\"Siaya_Delta_Alive_41\",\"Siaya_Delta_Alive_42\",\"Siaya_Delta_Alive_43\",\"Siaya_Delta_Alive_44\",\"Siaya_Delta_Alive_45\",\"Siaya_Delta_Alive_46\",\"Siaya_Delta_Alive_47\",\"Siaya_Delta_Alive_48\",\"Siaya_Delta_Alive_49\",\"Siaya_Delta_Alive_50\",\"Siaya_Delta_Alive_51\",\"Siaya_Delta_Alive_52\",\"Siaya_Delta_Alive_53\",\"Siaya_Delta_Alive_54\",\"Siaya_Delta_Alive_55\",\"Siaya_Delta_Alive_56\",\"Siaya_Delta_Alive_57\",\"Siaya_Delta_Alive_58\",\"Siaya_Delta_Alive_59\",\"Siaya_Delta_Alive_60\",\"Siaya_Delta_Alive_61\",\"Siaya_Delta_Alive_62\",\"Siaya_Delta_Alive_63\",\"Siaya_Delta_Alive_64\",\"Siaya_Delta_Alive_65\",\"Siaya_Delta_Alive_66\",\"Siaya_Delta_Alive_67\",\"Siaya_Delta_Alive_68\",\"Siaya_Delta_Alive_69\",\"Siaya_Delta_Alive_70\",\"Siaya_Delta_Alive_71\",\"Siaya_Delta_Alive_72\",\"Siaya_Delta_Alive_73\",\"Siaya_Delta_Alive_74\",\"Siaya_Delta_Alive_75\",\"Siaya_Delta_Alive_76\",\"Siaya_Delta_Alive_77\",\"Siaya_Delta_Alive_78\",\"Siaya_Delta_Alive_79\",\"Siaya_Delta_Alive_80\",\"Siaya_Delta_Alive_81\",\"Siaya_Delta_Alive_82\",\"Siaya_Delta_Alive_83\",\"Siaya_Delta_Alive_84\",\"Siaya_Delta_Alive_85\",\"Siaya_Delta_Alive_86\",\"Siaya_Delta_Alive_87\",\"Siaya_Delta_Alive_88\",\"Siaya_Delta_Alive_89\",\"Siaya_Delta_Alive_90\",\"Siaya_Delta_Alive_91\",\"Siaya_Delta_Alive_92\",\"Siaya_Delta_Alive_93\",\"Siaya_Delta_Alive_94\",\"Siaya_Delta_Alive_95\",\"Siaya_Delta_Alive_96\",\"Siaya_Delta_Alive_97\",\"Siaya_Delta_Alive_98\",\"Siaya_Delta_Alive_99\",\"Siaya_Delta_Alive_Negative\",\"Siaya_Delta_Dead_01\",\"Siaya_Delta_Dead_02\",\"Siaya_Delta_Dead_03\",\"Siaya_Delta_Dead_04\",\"Siaya_Delta_Dead_05\",\"Siaya_Delta_Dead_06\",\"Siaya_Delta_Dead_07\",\"Siaya_Delta_Dead_08\",\"Siaya_Delta_Dead_09\",\"Siaya_Delta_Dead_10\",\"Siaya_Delta_Dead_100\",\"Siaya_Delta_Dead_101\",\"Siaya_Delta_Dead_102\",\"Siaya_Delta_Dead_103\",\"Siaya_Delta_Dead_104\",\"Siaya_Delta_Dead_105\",\"Siaya_Delta_Dead_106\",\"Siaya_Delta_Dead_107\",\"Siaya_Delta_Dead_108\",\"Siaya_Delta_Dead_109\",\"Siaya_Delta_Dead_11\",\"Siaya_Delta_Dead_110\",\"Siaya_Delta_Dead_111\",\"Siaya_Delta_Dead_112\",\"Siaya_Delta_Dead_113\",\"Siaya_Delta_Dead_114\",\"Siaya_Delta_Dead_115\",\"Siaya_Delta_Dead_116\",\"Siaya_Delta_Dead_117\",\"Siaya_Delta_Dead_118\",\"Siaya_Delta_Dead_119\",\"Siaya_Delta_Dead_12\",\"Siaya_Delta_Dead_120\",\"Siaya_Delta_Dead_121\",\"Siaya_Delta_Dead_122\",\"Siaya_Delta_Dead_123\",\"Siaya_Delta_Dead_124\",\"Siaya_Delta_Dead_125\",\"Siaya_Delta_Dead_126\",\"Siaya_Delta_Dead_127\",\"Siaya_Delta_Dead_128\",\"Siaya_Delta_Dead_129\",\"Siaya_Delta_Dead_13\",\"Siaya_Delta_Dead_130\",\"Siaya_Delta_Dead_131\",\"Siaya_Delta_Dead_14\",\"Siaya_Delta_Dead_15\",\"Siaya_Delta_Dead_16\",\"Siaya_Delta_Dead_17\",\"Siaya_Delta_Dead_18\",\"Siaya_Delta_Dead_19\",\"Siaya_Delta_Dead_20\",\"Siaya_Delta_Dead_21\",\"Siaya_Delta_Dead_22\",\"Siaya_Delta_Dead_23\",\"Siaya_Delta_Dead_24\",\"Siaya_Delta_Dead_25\",\"Siaya_Delta_Dead_26\",\"Siaya_Delta_Dead_27\",\"Siaya_Delta_Dead_28\",\"Siaya_Delta_Dead_29\",\"Siaya_Delta_Dead_30\",\"Siaya_Delta_Dead_31\",\"Siaya_Delta_Dead_32\",\"Siaya_Delta_Dead_33\",\"Siaya_Delta_Dead_34\",\"Siaya_Delta_Dead_35\",\"Siaya_Delta_Dead_36\",\"Siaya_Delta_Dead_37\",\"Siaya_Delta_Dead_38\",\"Siaya_Delta_Dead_39\",\"Siaya_Delta_Dead_40\",\"Siaya_Delta_Dead_41\",\"Siaya_Delta_Dead_42\",\"Siaya_Delta_Dead_43\",\"Siaya_Delta_Dead_44\",\"Siaya_Delta_Dead_45\",\"Siaya_Delta_Dead_46\",\"Siaya_Delta_Dead_47\",\"Siaya_Delta_Dead_48\",\"Siaya_Delta_Dead_49\",\"Siaya_Delta_Dead_50\",\"Siaya_Delta_Dead_51\",\"Siaya_Delta_Dead_52\",\"Siaya_Delta_Dead_53\",\"Siaya_Delta_Dead_54\",\"Siaya_Delta_Dead_55\",\"Siaya_Delta_Dead_56\",\"Siaya_Delta_Dead_57\",\"Siaya_Delta_Dead_58\",\"Siaya_Delta_Dead_59\",\"Siaya_Delta_Dead_60\",\"Siaya_Delta_Dead_61\",\"Siaya_Delta_Dead_62\",\"Siaya_Delta_Dead_63\",\"Siaya_Delta_Dead_64\",\"Siaya_Delta_Dead_65\",\"Siaya_Delta_Dead_66\",\"Siaya_Delta_Dead_67\",\"Siaya_Delta_Dead_68\",\"Siaya_Delta_Dead_69\",\"Siaya_Delta_Dead_70\",\"Siaya_Delta_Dead_71\",\"Siaya_Delta_Dead_72\",\"Siaya_Delta_Dead_73\",\"Siaya_Delta_Dead_74\",\"Siaya_Delta_Dead_75\",\"Siaya_Delta_Dead_76\",\"Siaya_Delta_Dead_77\",\"Siaya_Delta_Dead_78\",\"Siaya_Delta_Dead_79\",\"Siaya_Delta_Dead_80\",\"Siaya_Delta_Dead_81\",\"Siaya_Delta_Dead_82\",\"Siaya_Delta_Dead_83\",\"Siaya_Delta_Dead_84\",\"Siaya_Delta_Dead_85\",\"Siaya_Delta_Dead_86\",\"Siaya_Delta_Dead_87\",\"Siaya_Delta_Dead_88\",\"Siaya_Delta_Dead_89\",\"Siaya_Delta_Dead_90\",\"Siaya_Delta_Dead_91\",\"Siaya_Delta_Dead_92\",\"Siaya_Delta_Dead_93\",\"Siaya_Delta_Dead_94\",\"Siaya_Delta_Dead_95\",\"Siaya_Delta_Dead_96\",\"Siaya_Delta_Dead_97\",\"Siaya_Delta_Dead_98\",\"Siaya_Delta_Dead_99\",\"Siaya_Delta_Dead_Negative\",\"VK7_Negative\",\"VK7_alive_01\",\"VK7_alive_02\",\"VK7_alive_03\",\"VK7_alive_04\",\"VK7_alive_05\",\"VK7_alive_06\",\"VK7_alive_07\",\"VK7_alive_08\",\"VK7_alive_09\",\"VK7_alive_10\",\"VK7_alive_11\",\"VK7_alive_12\",\"VK7_alive_13\",\"VK7_alive_14\",\"VK7_alive_15\",\"VK7_alive_16\",\"VK7_alive_17\",\"VK7_alive_18\",\"VK7_alive_19\",\"VK7_alive_20\",\"VK7_alive_21\",\"VK7_alive_22\",\"VK7_alive_23\",\"VK7_alive_24\",\"VK7_alive_25\",\"VK7_alive_26\",\"VK7_alive_27\",\"VK7_alive_28\",\"VK7_alive_29\",\"VK7_alive_30\",\"VK7_alive_31\",\"VK7_alive_32\",\"VK7_alive_33\",\"VK7_alive_34\",\"VK7_alive_35\",\"VK7_alive_36\",\"VK7_alive_37\",\"VK7_alive_38\",\"VK7_alive_39\",\"VK7_alive_40\",\"VK7_alive_41\",\"VK7_alive_42\",\"VK7_alive_43\",\"VK7_alive_44\",\"VK7_alive_45\",\"VK7_alive_46\",\"VK7_alive_47\",\"VK7_dead_01\",\"VK7_dead_02\",\"VK7_dead_03\",\"VK7_dead_04\",\"VK7_dead_04_dil\",\"VK7_dead_05\",\"VK7_dead_06\",\"VK7_dead_07\",\"VK7_dead_08\",\"VK7_dead_09\",\"VK7_dead_10\",\"VK7_dead_10_dil\",\"VK7_dead_11\",\"VK7_dead_12\",\"VK7_dead_13\",\"VK7_dead_14\",\"VK7_dead_15\",\"VK7_dead_16\",\"VK7_dead_16_dil\",\"VK7_dead_17\",\"VK7_dead_18\",\"VK7_dead_19\",\"VK7_dead_20\",\"VK7_dead_21\",\"VK7_dead_22\",\"VK7_dead_22_dil\",\"VK7_dead_23\",\"VK7_dead_24\",\"VK7_dead_25\",\"VK7_dead_26\",\"VK7_dead_27\",\"VK7_dead_28\",\"VK7_dead_28_dil\",\"VK7_dead_29\",\"VK7_dead_30\",\"VK7_dead_31\",\"VK7_dead_32\",\"VK7_dead_33\",\"VK7_dead_34\",\"VK7_dead_34_dil\",\"VK7_dead_35\",\"VK7_dead_36\",\"VK7_dead_37\",\"VK7_dead_38\",\"VK7_dead_39\",\"VK7_dead_40\",\"VK7_dead_41\",\"VK7_dead_42\"],\"xaxis\":\"x\",\"y\":[33885,1261,790,1205,2259,2998,170,1009,1484,2208,2724,1170,4137,8938,1765,2898,2062,1168,7315,960,7371,2025,1438,992,1871,9514,3783,1259,4859,19442,1312,1834,6117,5678,6059,696,24563,4865,3855,4431,1806,1744,10257,2481,4302,977,3391,1079,41500,24293,72760,10185,13396,3672,15348,10345,6224,2890,3150,1365,90253,26492,2792,14904,118,1533,2836,3575,1933,833,1093,1305,9897,8665,3739,9301,1621,3036,42850,1235,12679,2408,2668,1922,29971,147296,2665,6874,2059,62,7791,1062,3760,3147,6355,2780,3712,3891,21119,42154,37798,440,129,426,989,489,1585,2063,11184,16464,1551,4465,1870,2809,4798,2431,662,722,1668,1326,1113,32194,1767,1591,7649,5905,1551,1808,1009,306,1154,848,16683,12723,4232,6503,594,3466,531,1215,2272,930,410,890,2112,21156,19874,4053,2492,2150,3089,2850,11182,2274,1783,2751,5121,3848,6017,25002,91,3538,170,2165,917,457,311,349,11461,5179,4942,9124,6204,715,830,747,1019,479,438,330,4789,174622,3098,10761,12439,45,710,734,816,280,2090,273,110246,68475,41518,25013,87819,40817,13854,159695,99794,58688,85658,52592,47840,91645,53831,51180,35786,39100,36844,80159,90644,73354,19838,78759,51795,62277,103179,47021,566,52097,17532,89563,30060,41353,34866,21153,7277,15060,14611,49685,155,15493,73565,18432,10298,103662,34155,91058,99851,94983,81644,73311,151955,108672,67753,161153,3963,66417,31082,65042,141179,189260,75888,124842,174842,166627,83443,92465,25082,28768,27109,21947,84209,58942,86176,137934,39074,42085,86103,114438,40316,31003,83049,29076,50712,47897,136283,117740,196779,99543,94223,60040,75556,21489,26186,55258,3122,85752,35830,61464,41382,45120,52372,46837,38543,36723,6125,24473,34068,35094,109900,33419,48743,74165,50160,68048,31352,20852,28946,19409,30007,455,50116,13952,46129,40852,43022,45510,1947,85697,76600,578,177469,37726,92161,32920,109756,43770,3386,37701,2392,34914,27127,55371,50708,46847,61154,47176,3954,136665,69849,72828,41077,37946,61118,53522,41286,72605,28102,62819,34061,46665,64241,60233,47223,23255,27611,78374,46341,34969,19760,49233,18268,45659,123304,20596,17376,160169,97121,23741,53428,226756,118726,22798,434,66861,87471,63634,7217,51355,42316,209343,94162,54207,64426,34439,2173,38497,64699,31609,169319,39164,103851,96395,94107,60198,137385,25415,1075,116192,54565,100989,81600,16433,99817,88149,34953,61298,100442,26081,1471,125848,63626,52317,166272,115506,197763,42089,646,166943,24809,60518,913,17882,51310,35860,236884,155171,171703,102631,113550,68810,70965,23487,1782,24450,54356,12660,329478,26007,126732,89572,87295,240,54792,20535,664,35258,64428,77538,25630,42877,70955,6076,262,2047,4,1,15723,4,25130,4274,19827,4,15389,6,17327,196,8824,22537,11196,30,14384,27310,23886,1,12914,12,39610,4552,19510,13,22673,8,33312,7,8265,1,9524,12890,15053,11847,8923,4,4956,17416,17018,7964,11178,4412,10267,19560,11209,9644,44109,10608,352,68822,80971,19804,34341,4282,17027,726,20787,23470,1044,12821,6595,17805,645,15363,7914,10238,9009,11061,8844,872,6940,19625,5911,7526,11286,39202,288,16227,11498,43972,1767,14396,8934,13,5604,6256,15006,29036,11197,2750,22142,5726],\"yaxis\":\"y\",\"type\":\"bar\"},{\"alignmentgroup\":\"True\",\"customdata\":[[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"],[\"X\"]],\"hovertemplate\":\"contig=%{customdata[0]}\\u003cbr\\u003esample_id=%{x}\\u003cbr\\u003edepth=%{y}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\",\"legendgroup\":\"X\",\"marker\":{\"color\":\"#9467BD\",\"pattern\":{\"shape\":\"\"}},\"name\":\"X\",\"offsetgroup\":\"X\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"auto\",\"x\":[\"GH_01\",\"GH_02\",\"GH_03\",\"GH_04\",\"GH_05\",\"GH_06\",\"GH_07\",\"GH_08\",\"GH_09\",\"GH_10\",\"GH_11\",\"GH_12\",\"GH_13\",\"GH_14\",\"GH_15\",\"GH_16\",\"GH_17\",\"GH_18\",\"GH_19\",\"GH_20\",\"GH_21\",\"GH_22\",\"GH_23\",\"GH_24\",\"GH_25\",\"GH_26\",\"GH_27\",\"GH_28\",\"GH_29\",\"GH_30\",\"GH_31\",\"GH_32\",\"GH_33\",\"GH_34\",\"GH_35\",\"GH_36\",\"GH_37\",\"GH_38\",\"GH_39\",\"GH_40_low_vol\",\"GH_41\",\"GH_42\",\"GH_43\",\"GH_44\",\"GH_45\",\"GH_46\",\"GH_47\",\"GH_48\",\"GH_49\",\"GH_50\",\"GH_51\",\"GH_52\",\"GH_53\",\"GH_54\",\"GH_55\",\"GH_56\",\"GH_57\",\"GH_58\",\"GH_59\",\"GH_60\",\"GH_61\",\"GH_62\",\"GH_63\",\"GH_64\",\"GH_65_low_vol\",\"GH_66\",\"GH_67\",\"GH_68\",\"GH_69\",\"GH_70\",\"GH_71\",\"GH_72\",\"GH_73\",\"GH_74\",\"GH_75\",\"GH_76\",\"GH_77\",\"GH_78\",\"GH_79\",\"GH_80_low_vol\",\"GH_81\",\"GH_82\",\"GH_83\",\"GH_84\",\"GH_85\",\"GH_86\",\"GH_87\",\"GH_88\",\"GH_89\",\"GH_90\",\"GH_91\",\"GH_92\",\"GH_93\",\"GH_94\",\"GH_95\",\"GH_Negative\",\"GM_01\",\"GM_02\",\"GM_03\",\"GM_04\",\"GM_05\",\"GM_06\",\"GM_07\",\"GM_08\",\"GM_09\",\"GM_10\",\"GM_11\",\"GM_12\",\"GM_13\",\"GM_14\",\"GM_15\",\"GM_16\",\"GM_17\",\"GM_18\",\"GM_19\",\"GM_20\",\"GM_21\",\"GM_22\",\"GM_23\",\"GM_24\",\"GM_25\",\"GM_26\",\"GM_27\",\"GM_28\",\"GM_29\",\"GM_30\",\"GM_31\",\"GM_32\",\"GM_33\",\"GM_34\",\"GM_35\",\"GM_36\",\"GM_37\",\"GM_38\",\"GM_39\",\"GM_40\",\"GM_41\",\"GM_42\",\"GM_43\",\"GM_44\",\"GM_45\",\"GM_46\",\"GM_47\",\"GM_48\",\"GM_49\",\"GM_50\",\"GM_51\",\"GM_52\",\"GM_53\",\"GM_54\",\"GM_55\",\"GM_56\",\"GM_57\",\"GM_58\",\"GM_59\",\"GM_60\",\"GM_61\",\"GM_62\",\"GM_63\",\"GM_64\",\"GM_65\",\"GM_66\",\"GM_67\",\"GM_68\",\"GM_69\",\"GM_70\",\"GM_71\",\"GM_72\",\"GM_73\",\"GM_74\",\"GM_75\",\"GM_76\",\"GM_77\",\"GM_78\",\"GM_79\",\"GM_80\",\"GM_81\",\"GM_82\",\"GM_83\",\"GM_84\",\"GM_85\",\"GM_86\",\"GM_87\",\"GM_88\",\"GM_89\",\"GM_90\",\"GM_91\",\"GM_92\",\"GM_93\",\"GM_94\",\"GM_95\",\"GM_96\",\"Siaya_Delta_Alive_01\",\"Siaya_Delta_Alive_02\",\"Siaya_Delta_Alive_03\",\"Siaya_Delta_Alive_04\",\"Siaya_Delta_Alive_05\",\"Siaya_Delta_Alive_06\",\"Siaya_Delta_Alive_07\",\"Siaya_Delta_Alive_08\",\"Siaya_Delta_Alive_09\",\"Siaya_Delta_Alive_10\",\"Siaya_Delta_Alive_100\",\"Siaya_Delta_Alive_101\",\"Siaya_Delta_Alive_102\",\"Siaya_Delta_Alive_103\",\"Siaya_Delta_Alive_104\",\"Siaya_Delta_Alive_105\",\"Siaya_Delta_Alive_106\",\"Siaya_Delta_Alive_107\",\"Siaya_Delta_Alive_108\",\"Siaya_Delta_Alive_109\",\"Siaya_Delta_Alive_11\",\"Siaya_Delta_Alive_110\",\"Siaya_Delta_Alive_111\",\"Siaya_Delta_Alive_112\",\"Siaya_Delta_Alive_113\",\"Siaya_Delta_Alive_114\",\"Siaya_Delta_Alive_115\",\"Siaya_Delta_Alive_116\",\"Siaya_Delta_Alive_117\",\"Siaya_Delta_Alive_118\",\"Siaya_Delta_Alive_119\",\"Siaya_Delta_Alive_12\",\"Siaya_Delta_Alive_120\",\"Siaya_Delta_Alive_121\",\"Siaya_Delta_Alive_122\",\"Siaya_Delta_Alive_123\",\"Siaya_Delta_Alive_124\",\"Siaya_Delta_Alive_125\",\"Siaya_Delta_Alive_126\",\"Siaya_Delta_Alive_127\",\"Siaya_Delta_Alive_128\",\"Siaya_Delta_Alive_129\",\"Siaya_Delta_Alive_13\",\"Siaya_Delta_Alive_130\",\"Siaya_Delta_Alive_131\",\"Siaya_Delta_Alive_14\",\"Siaya_Delta_Alive_15\",\"Siaya_Delta_Alive_16\",\"Siaya_Delta_Alive_17\",\"Siaya_Delta_Alive_18\",\"Siaya_Delta_Alive_19\",\"Siaya_Delta_Alive_20\",\"Siaya_Delta_Alive_21\",\"Siaya_Delta_Alive_22\",\"Siaya_Delta_Alive_23\",\"Siaya_Delta_Alive_24\",\"Siaya_Delta_Alive_25\",\"Siaya_Delta_Alive_26\",\"Siaya_Delta_Alive_27\",\"Siaya_Delta_Alive_28\",\"Siaya_Delta_Alive_29\",\"Siaya_Delta_Alive_30\",\"Siaya_Delta_Alive_31\",\"Siaya_Delta_Alive_32\",\"Siaya_Delta_Alive_33\",\"Siaya_Delta_Alive_34\",\"Siaya_Delta_Alive_35\",\"Siaya_Delta_Alive_36\",\"Siaya_Delta_Alive_37\",\"Siaya_Delta_Alive_38\",\"Siaya_Delta_Alive_39\",\"Siaya_Delta_Alive_40\",\"Siaya_Delta_Alive_41\",\"Siaya_Delta_Alive_42\",\"Siaya_Delta_Alive_43\",\"Siaya_Delta_Alive_44\",\"Siaya_Delta_Alive_45\",\"Siaya_Delta_Alive_46\",\"Siaya_Delta_Alive_47\",\"Siaya_Delta_Alive_48\",\"Siaya_Delta_Alive_49\",\"Siaya_Delta_Alive_50\",\"Siaya_Delta_Alive_51\",\"Siaya_Delta_Alive_52\",\"Siaya_Delta_Alive_53\",\"Siaya_Delta_Alive_54\",\"Siaya_Delta_Alive_55\",\"Siaya_Delta_Alive_56\",\"Siaya_Delta_Alive_57\",\"Siaya_Delta_Alive_58\",\"Siaya_Delta_Alive_59\",\"Siaya_Delta_Alive_60\",\"Siaya_Delta_Alive_61\",\"Siaya_Delta_Alive_62\",\"Siaya_Delta_Alive_63\",\"Siaya_Delta_Alive_64\",\"Siaya_Delta_Alive_65\",\"Siaya_Delta_Alive_66\",\"Siaya_Delta_Alive_67\",\"Siaya_Delta_Alive_68\",\"Siaya_Delta_Alive_69\",\"Siaya_Delta_Alive_70\",\"Siaya_Delta_Alive_71\",\"Siaya_Delta_Alive_72\",\"Siaya_Delta_Alive_73\",\"Siaya_Delta_Alive_74\",\"Siaya_Delta_Alive_75\",\"Siaya_Delta_Alive_76\",\"Siaya_Delta_Alive_77\",\"Siaya_Delta_Alive_78\",\"Siaya_Delta_Alive_79\",\"Siaya_Delta_Alive_80\",\"Siaya_Delta_Alive_81\",\"Siaya_Delta_Alive_82\",\"Siaya_Delta_Alive_83\",\"Siaya_Delta_Alive_84\",\"Siaya_Delta_Alive_85\",\"Siaya_Delta_Alive_86\",\"Siaya_Delta_Alive_87\",\"Siaya_Delta_Alive_88\",\"Siaya_Delta_Alive_89\",\"Siaya_Delta_Alive_90\",\"Siaya_Delta_Alive_91\",\"Siaya_Delta_Alive_92\",\"Siaya_Delta_Alive_93\",\"Siaya_Delta_Alive_94\",\"Siaya_Delta_Alive_95\",\"Siaya_Delta_Alive_96\",\"Siaya_Delta_Alive_97\",\"Siaya_Delta_Alive_98\",\"Siaya_Delta_Alive_99\",\"Siaya_Delta_Alive_Negative\",\"Siaya_Delta_Dead_01\",\"Siaya_Delta_Dead_02\",\"Siaya_Delta_Dead_03\",\"Siaya_Delta_Dead_04\",\"Siaya_Delta_Dead_05\",\"Siaya_Delta_Dead_06\",\"Siaya_Delta_Dead_07\",\"Siaya_Delta_Dead_08\",\"Siaya_Delta_Dead_09\",\"Siaya_Delta_Dead_10\",\"Siaya_Delta_Dead_100\",\"Siaya_Delta_Dead_101\",\"Siaya_Delta_Dead_102\",\"Siaya_Delta_Dead_103\",\"Siaya_Delta_Dead_104\",\"Siaya_Delta_Dead_105\",\"Siaya_Delta_Dead_106\",\"Siaya_Delta_Dead_107\",\"Siaya_Delta_Dead_108\",\"Siaya_Delta_Dead_109\",\"Siaya_Delta_Dead_11\",\"Siaya_Delta_Dead_110\",\"Siaya_Delta_Dead_111\",\"Siaya_Delta_Dead_112\",\"Siaya_Delta_Dead_113\",\"Siaya_Delta_Dead_114\",\"Siaya_Delta_Dead_115\",\"Siaya_Delta_Dead_116\",\"Siaya_Delta_Dead_117\",\"Siaya_Delta_Dead_118\",\"Siaya_Delta_Dead_119\",\"Siaya_Delta_Dead_12\",\"Siaya_Delta_Dead_120\",\"Siaya_Delta_Dead_121\",\"Siaya_Delta_Dead_122\",\"Siaya_Delta_Dead_123\",\"Siaya_Delta_Dead_124\",\"Siaya_Delta_Dead_125\",\"Siaya_Delta_Dead_126\",\"Siaya_Delta_Dead_127\",\"Siaya_Delta_Dead_128\",\"Siaya_Delta_Dead_129\",\"Siaya_Delta_Dead_13\",\"Siaya_Delta_Dead_130\",\"Siaya_Delta_Dead_131\",\"Siaya_Delta_Dead_14\",\"Siaya_Delta_Dead_15\",\"Siaya_Delta_Dead_16\",\"Siaya_Delta_Dead_17\",\"Siaya_Delta_Dead_18\",\"Siaya_Delta_Dead_19\",\"Siaya_Delta_Dead_20\",\"Siaya_Delta_Dead_21\",\"Siaya_Delta_Dead_22\",\"Siaya_Delta_Dead_23\",\"Siaya_Delta_Dead_24\",\"Siaya_Delta_Dead_25\",\"Siaya_Delta_Dead_26\",\"Siaya_Delta_Dead_27\",\"Siaya_Delta_Dead_28\",\"Siaya_Delta_Dead_29\",\"Siaya_Delta_Dead_30\",\"Siaya_Delta_Dead_31\",\"Siaya_Delta_Dead_32\",\"Siaya_Delta_Dead_33\",\"Siaya_Delta_Dead_34\",\"Siaya_Delta_Dead_35\",\"Siaya_Delta_Dead_36\",\"Siaya_Delta_Dead_37\",\"Siaya_Delta_Dead_38\",\"Siaya_Delta_Dead_39\",\"Siaya_Delta_Dead_40\",\"Siaya_Delta_Dead_41\",\"Siaya_Delta_Dead_42\",\"Siaya_Delta_Dead_43\",\"Siaya_Delta_Dead_44\",\"Siaya_Delta_Dead_45\",\"Siaya_Delta_Dead_46\",\"Siaya_Delta_Dead_47\",\"Siaya_Delta_Dead_48\",\"Siaya_Delta_Dead_49\",\"Siaya_Delta_Dead_50\",\"Siaya_Delta_Dead_51\",\"Siaya_Delta_Dead_52\",\"Siaya_Delta_Dead_53\",\"Siaya_Delta_Dead_54\",\"Siaya_Delta_Dead_55\",\"Siaya_Delta_Dead_56\",\"Siaya_Delta_Dead_57\",\"Siaya_Delta_Dead_58\",\"Siaya_Delta_Dead_59\",\"Siaya_Delta_Dead_60\",\"Siaya_Delta_Dead_61\",\"Siaya_Delta_Dead_62\",\"Siaya_Delta_Dead_63\",\"Siaya_Delta_Dead_64\",\"Siaya_Delta_Dead_65\",\"Siaya_Delta_Dead_66\",\"Siaya_Delta_Dead_67\",\"Siaya_Delta_Dead_68\",\"Siaya_Delta_Dead_69\",\"Siaya_Delta_Dead_70\",\"Siaya_Delta_Dead_71\",\"Siaya_Delta_Dead_72\",\"Siaya_Delta_Dead_73\",\"Siaya_Delta_Dead_74\",\"Siaya_Delta_Dead_75\",\"Siaya_Delta_Dead_76\",\"Siaya_Delta_Dead_77\",\"Siaya_Delta_Dead_78\",\"Siaya_Delta_Dead_79\",\"Siaya_Delta_Dead_80\",\"Siaya_Delta_Dead_81\",\"Siaya_Delta_Dead_82\",\"Siaya_Delta_Dead_83\",\"Siaya_Delta_Dead_84\",\"Siaya_Delta_Dead_85\",\"Siaya_Delta_Dead_86\",\"Siaya_Delta_Dead_87\",\"Siaya_Delta_Dead_88\",\"Siaya_Delta_Dead_89\",\"Siaya_Delta_Dead_90\",\"Siaya_Delta_Dead_91\",\"Siaya_Delta_Dead_92\",\"Siaya_Delta_Dead_93\",\"Siaya_Delta_Dead_94\",\"Siaya_Delta_Dead_95\",\"Siaya_Delta_Dead_96\",\"Siaya_Delta_Dead_97\",\"Siaya_Delta_Dead_98\",\"Siaya_Delta_Dead_99\",\"Siaya_Delta_Dead_Negative\",\"VK7_Negative\",\"VK7_alive_01\",\"VK7_alive_02\",\"VK7_alive_03\",\"VK7_alive_04\",\"VK7_alive_05\",\"VK7_alive_06\",\"VK7_alive_07\",\"VK7_alive_08\",\"VK7_alive_09\",\"VK7_alive_10\",\"VK7_alive_11\",\"VK7_alive_12\",\"VK7_alive_13\",\"VK7_alive_14\",\"VK7_alive_15\",\"VK7_alive_16\",\"VK7_alive_17\",\"VK7_alive_18\",\"VK7_alive_19\",\"VK7_alive_20\",\"VK7_alive_21\",\"VK7_alive_22\",\"VK7_alive_23\",\"VK7_alive_24\",\"VK7_alive_25\",\"VK7_alive_26\",\"VK7_alive_27\",\"VK7_alive_28\",\"VK7_alive_29\",\"VK7_alive_30\",\"VK7_alive_31\",\"VK7_alive_32\",\"VK7_alive_33\",\"VK7_alive_34\",\"VK7_alive_35\",\"VK7_alive_36\",\"VK7_alive_37\",\"VK7_alive_38\",\"VK7_alive_39\",\"VK7_alive_40\",\"VK7_alive_41\",\"VK7_alive_42\",\"VK7_alive_43\",\"VK7_alive_44\",\"VK7_alive_45\",\"VK7_alive_46\",\"VK7_alive_47\",\"VK7_dead_01\",\"VK7_dead_02\",\"VK7_dead_03\",\"VK7_dead_04\",\"VK7_dead_04_dil\",\"VK7_dead_05\",\"VK7_dead_06\",\"VK7_dead_07\",\"VK7_dead_08\",\"VK7_dead_09\",\"VK7_dead_10\",\"VK7_dead_10_dil\",\"VK7_dead_11\",\"VK7_dead_12\",\"VK7_dead_13\",\"VK7_dead_14\",\"VK7_dead_15\",\"VK7_dead_16\",\"VK7_dead_16_dil\",\"VK7_dead_17\",\"VK7_dead_18\",\"VK7_dead_19\",\"VK7_dead_20\",\"VK7_dead_21\",\"VK7_dead_22\",\"VK7_dead_22_dil\",\"VK7_dead_23\",\"VK7_dead_24\",\"VK7_dead_25\",\"VK7_dead_26\",\"VK7_dead_27\",\"VK7_dead_28\",\"VK7_dead_28_dil\",\"VK7_dead_29\",\"VK7_dead_30\",\"VK7_dead_31\",\"VK7_dead_32\",\"VK7_dead_33\",\"VK7_dead_34\",\"VK7_dead_34_dil\",\"VK7_dead_35\",\"VK7_dead_36\",\"VK7_dead_37\",\"VK7_dead_38\",\"VK7_dead_39\",\"VK7_dead_40\",\"VK7_dead_41\",\"VK7_dead_42\"],\"xaxis\":\"x\",\"y\":[24623,2364,2703,981,1870,5874,759,2648,4011,2459,8034,3945,5288,4783,1565,1890,3326,1286,12522,892,7675,3128,4274,3496,15676,13181,3326,1779,4938,29289,1524,1307,6469,8243,5167,1516,34847,4775,3246,9664,2375,2112,7186,4932,5081,1342,4459,1877,40263,28935,96941,8452,10775,3191,15257,8886,2859,3091,3541,3525,124364,27464,5379,18176,54,2135,2719,2962,2879,1723,2804,1888,16560,11646,7455,14140,2206,4482,47435,2364,16643,2959,2722,4940,46529,179081,3228,11630,3949,153,8515,3847,7200,8191,11293,7133,8413,11333,133386,24039,26600,1210,196,1409,3191,2944,4640,3388,12424,112656,5252,7082,5767,7358,4641,3562,4541,3604,6428,8047,4343,23177,6773,6103,10536,4112,1892,3423,3304,843,3024,2808,16523,15107,6650,6273,1510,4609,1597,2898,1846,4098,1126,2331,7853,27773,20446,11224,5388,5276,2843,4051,15922,3032,2656,6704,18950,12830,7706,15564,61,5157,218,2474,1782,1598,1295,741,48816,12803,9545,22747,9317,2137,1585,2757,2981,936,1274,1599,11506,675960,8140,12541,11723,23,1510,1186,1799,1273,4613,1211,64510,58366,48779,29016,62932,53420,30589,102361,147273,57257,74227,62988,25545,72175,63313,75332,25707,42039,36774,83874,178204,88221,28991,82592,77077,53922,95377,49623,379,62521,17320,92542,32735,58371,37976,36702,17214,21398,28233,46784,406,17449,61909,34701,15724,104749,33543,81733,112273,123497,89595,90531,154997,145163,96328,97902,15774,64243,45716,61272,135267,252880,82349,178320,176454,217151,147583,74623,25709,29676,24027,28577,63419,94656,87103,131977,55833,45054,81943,114566,44093,27877,93218,35728,42078,57559,99737,91137,192826,75085,82521,78686,56810,22402,36490,93395,2296,85126,29304,57661,62720,45075,56125,71107,57166,35994,9850,34438,52081,48090,130972,47995,57979,87838,68779,92959,44750,33389,38867,22803,35549,1005,44230,18406,58036,48958,103781,59262,7393,60005,79929,1617,105325,48267,73497,17262,74076,46292,4258,36910,6741,24802,15358,63584,42797,49182,66065,53760,28381,144708,74685,67154,25219,42615,53304,60633,47511,66283,28127,74546,42847,45862,53977,63554,42546,17850,33386,88854,57782,58221,31317,61142,16545,40601,62220,33512,38588,191941,77017,29141,47523,222840,103569,24783,1165,55582,94201,51968,25983,46647,32951,210338,73899,44380,56502,32296,6949,39754,60433,34694,159482,44877,96844,114690,70681,71597,116400,29588,3799,104311,60642,72988,32634,13961,158429,76041,27087,79487,89473,26318,4804,122081,44180,59367,125271,121425,319124,57391,457,186457,16649,68528,3930,14865,65830,47387,197357,195869,279119,132023,132865,100283,110711,35926,2603,36951,71397,21529,366663,50329,149834,124536,119636,56,55073,14316,2857,37812,63152,36609,54237,16922,70505,6307,820,4146,0,8,28081,4,108953,20592,67063,8,59659,5,61003,764,25518,68858,29025,48,61442,72054,44806,1,42525,33,98075,21801,56442,12,70732,21,158379,14,38506,0,26057,28700,52856,34729,16921,0,23992,41967,45904,19248,37907,12899,34098,51879,35375,53348,197151,50518,2246,282235,263106,80348,86921,20077,99982,2659,98412,87936,5476,33254,17958,62385,2896,63418,18789,46898,34643,27310,38478,4004,22585,51952,7803,17690,26120,125424,515,51728,41876,87441,3230,40767,32344,19,20157,28342,47936,103065,36197,7174,51767,17361],\"yaxis\":\"y\",\"type\":\"bar\"}],                        {\"template\":{\"data\":{\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"sample_id\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"depth\"}},\"legend\":{\"title\":{\"text\":\"contig\"},\"tracegroupgap\":0},\"margin\":{\"t\":60},\"barmode\":\"relative\",\"width\":1000},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('7515d5be-e716-4bc5-afcc-126a93ce5033');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["samples_cov = cov_df.groupby(['sample_id', 'contig']).agg({'depth':'sum'})\n", "fig = px.bar(samples_cov.reset_index(), x='sample_id', y='depth', hover_data='contig', color='contig', width=1000, template='simple_white')\n", "fig.show()"]}, {"cell_type": "markdown", "id": "ca654c0b", "metadata": {"papermill": {"duration": 0.707761, "end_time": "2024-12-04T12:14:59.474618", "exception": false, "start_time": "2024-12-04T12:14:58.766857", "status": "completed"}, "tags": []}, "source": ["#### Coverage by amplicon and sample"]}, {"cell_type": "code", "execution_count": 10, "id": "00bace05", "metadata": {"execution": {"iopub.execute_input": "2024-12-04T12:15:01.058429Z", "iopub.status.busy": "2024-12-04T12:15:01.056988Z", "iopub.status.idle": "2024-12-04T12:15:01.857448Z", "shell.execute_reply": "2024-12-04T12:15:01.856788Z"}, "papermill": {"duration": 1.638552, "end_time": "2024-12-04T12:15:01.899833", "exception": false, "start_time": "2024-12-04T12:15:00.261281", "status": "completed"}, "tags": ["remove-input"]}, "outputs": [{"data": {"text/markdown": ["<a href=\"/home/snagi/lstm_projects/ampseq-agvampir002/results/coverage/amplicon_by_sample_depth.xlsx\">Amplicon by sample read depth (.xlsx)</a>"], "text/plain": ["<IPython.core.display.Markdown object>"]}, "metadata": {}, "output_type": "display_data"}, {"data": {"application/vnd.plotly.v1+json": {"config": {"plotlyServerURL": "https://plot.ly"}, "data": [{"coloraxis": "coloraxis", "hovertemplate": "sample_id: %{x}<br>amplicon: %{y}<br>color: %{z}<extra></extra>", "name": "0", "type": "heatmap", "x": ["GH_01", "GH_02", "GH_03", "GH_04", "GH_05", "GH_06", "GH_07", "GH_08", "GH_09", "GH_10", "GH_11", "GH_12", "GH_13", "GH_14", "GH_15", "GH_16", "GH_17", "GH_18", "GH_19", "GH_20", "GH_21", "GH_22", "GH_23", "GH_24", "GH_25", "GH_26", "GH_27", "GH_28", "GH_29", "GH_30", "GH_31", "GH_32", "GH_33", "GH_34", "GH_35", "GH_36", "GH_37", "GH_38", "GH_39", "GH_40_low_vol", "GH_41", "GH_42", "GH_43", "GH_44", "GH_45", "GH_46", "GH_47", "GH_48", "GH_49", "GH_50", "GH_51", "GH_52", "GH_53", "GH_54", "GH_55", "GH_56", "GH_57", "GH_58", "GH_59", "GH_60", "GH_61", "GH_62", "GH_63", "GH_64", "GH_65_low_vol", "GH_66", "GH_67", "GH_68", "GH_69", "GH_70", "GH_71", "GH_72", "GH_73", "GH_74", "GH_75", "GH_76", "GH_77", "GH_78", "GH_79", "GH_80_low_vol", "GH_81", "GH_82", "GH_83", "GH_84", "GH_85", "GH_86", "GH_87", "GH_88", "GH_89", "GH_90", "GH_91", "GH_92", "GH_93", "GH_94", "GH_95", "GH_Negative", "GM_01", "GM_02", "GM_03", "GM_04", "GM_05", "GM_06", "GM_07", "GM_08", "GM_09", "GM_10", "GM_11", "GM_12", "GM_13", "GM_14", "GM_15", "GM_16", "GM_17", "GM_18", "GM_19", "GM_20", "GM_21", "GM_22", "GM_23", "GM_24", "GM_25", "GM_26", "GM_27", "GM_28", "GM_29", "GM_30", "GM_31", "GM_32", "GM_33", "GM_34", "GM_35", "GM_36", "GM_37", "GM_38", "GM_39", "GM_40", "GM_41", "GM_42", "GM_43", "GM_44", "GM_45", "GM_46", "GM_47", "GM_48", "GM_49", "GM_50", "GM_51", "GM_52", "GM_53", "GM_54", "GM_55", "GM_56", "GM_57", "GM_58", "GM_59", "GM_60", "GM_61", "GM_62", "GM_63", "GM_64", "GM_65", "GM_66", "GM_67", "GM_68", "GM_69", "GM_70", "GM_71", "GM_72", "GM_73", "GM_74", "GM_75", "GM_76", "GM_77", "GM_78", "GM_79", "GM_80", "GM_81", "GM_82", "GM_83", "GM_84", "GM_85", "GM_86", "GM_87", "GM_88", "GM_89", "GM_90", "GM_91", "GM_92", "GM_93", "GM_94", "GM_95", "GM_96", "Siaya_Delta_Alive_01", "Siaya_Delta_Alive_02", "Siaya_Delta_Alive_03", "Siaya_Delta_Alive_04", "Siaya_Delta_Alive_05", "Siaya_Delta_Alive_06", "Siaya_Delta_Alive_07", "Siaya_Delta_Alive_08", "Siaya_Delta_Alive_09", "Siaya_Delta_Alive_10", "Siaya_Delta_Alive_100", "Siaya_Delta_Alive_101", "Siaya_Delta_Alive_102", "Siaya_Delta_Alive_103", "Siaya_Delta_Alive_104", "Siaya_Delta_Alive_105", "Siaya_Delta_Alive_106", "Siaya_Delta_Alive_107", "Siaya_Delta_Alive_108", "Siaya_Delta_Alive_109", "Siaya_Delta_Alive_11", "Siaya_Delta_Alive_110", "Siaya_Delta_Alive_111", "Siaya_Delta_Alive_112", "Siaya_Delta_Alive_113", "Siaya_Delta_Alive_114", "Siaya_Delta_Alive_115", "Siaya_Delta_Alive_116", "Siaya_Delta_Alive_117", "Siaya_Delta_Alive_118", "Siaya_Delta_Alive_119", "Siaya_Delta_Alive_12", "Siaya_Delta_Alive_120", "Siaya_Delta_Alive_121", "Siaya_Delta_Alive_122", "Siaya_Delta_Alive_123", "Siaya_Delta_Alive_124", "Siaya_Delta_Alive_125", "Siaya_Delta_Alive_126", "Siaya_Delta_Alive_127", "Siaya_Delta_Alive_128", "Siaya_Delta_Alive_129", "Siaya_Delta_Alive_13", "Siaya_Delta_Alive_130", "Siaya_Delta_Alive_131", "Siaya_Delta_Alive_14", "Siaya_Delta_Alive_15", "Siaya_Delta_Alive_16", "Siaya_Delta_Alive_17", "Siaya_Delta_Alive_18", "Siaya_Delta_Alive_19", "Siaya_Delta_Alive_20", "Siaya_Delta_Alive_21", "Siaya_Delta_Alive_22", "Siaya_Delta_Alive_23", "Siaya_Delta_Alive_24", "Siaya_Delta_Alive_25", "Siaya_Delta_Alive_26", "Siaya_Delta_Alive_27", "Siaya_Delta_Alive_28", "Siaya_Delta_Alive_29", "Siaya_Delta_Alive_30", "Siaya_Delta_Alive_31", "Siaya_Delta_Alive_32", "Siaya_Delta_Alive_33", "Siaya_Delta_Alive_34", "Siaya_Delta_Alive_35", "Siaya_Delta_Alive_36", "Siaya_Delta_Alive_37", "Siaya_Delta_Alive_38", "Siaya_Delta_Alive_39", "Siaya_Delta_Alive_40", "Siaya_Delta_Alive_41", "Siaya_Delta_Alive_42", "Siaya_Delta_Alive_43", "Siaya_Delta_Alive_44", "Siaya_Delta_Alive_45", "Siaya_Delta_Alive_46", "Siaya_Delta_Alive_47", "Siaya_Delta_Alive_48", "Siaya_Delta_Alive_49", "Siaya_Delta_Alive_50", "Siaya_Delta_Alive_51", "Siaya_Delta_Alive_52", "Siaya_Delta_Alive_53", "Siaya_Delta_Alive_54", "Siaya_Delta_Alive_55", "Siaya_Delta_Alive_56", "Siaya_Delta_Alive_57", "Siaya_Delta_Alive_58", "Siaya_Delta_Alive_59", "Siaya_Delta_Alive_60", "Siaya_Delta_Alive_61", "Siaya_Delta_Alive_62", "Siaya_Delta_Alive_63", "Siaya_Delta_Alive_64", "Siaya_Delta_Alive_65", "Siaya_Delta_Alive_66", "Siaya_Delta_Alive_67", "Siaya_Delta_Alive_68", "Siaya_Delta_Alive_69", "Siaya_Delta_Alive_70", "Siaya_Delta_Alive_71", "Siaya_Delta_Alive_72", "Siaya_Delta_Alive_73", "Siaya_Delta_Alive_74", "Siaya_Delta_Alive_75", "Siaya_Delta_Alive_76", "Siaya_Delta_Alive_77", "Siaya_Delta_Alive_78", "Siaya_Delta_Alive_79", "Siaya_Delta_Alive_80", "Siaya_Delta_Alive_81", "Siaya_Delta_Alive_82", "Siaya_Delta_Alive_83", "Siaya_Delta_Alive_84", "Siaya_Delta_Alive_85", "Siaya_Delta_Alive_86", "Siaya_Delta_Alive_87", "Siaya_Delta_Alive_88", "Siaya_Delta_Alive_89", "Siaya_Delta_Alive_90", "Siaya_Delta_Alive_91", "Siaya_Delta_Alive_92", "Siaya_Delta_Alive_93", "Siaya_Delta_Alive_94", "Siaya_Delta_Alive_95", "Siaya_Delta_Alive_96", "Siaya_Delta_Alive_97", "Siaya_Delta_Alive_98", "Siaya_Delta_Alive_99", "Siaya_Delta_Alive_Negative", "Siaya_Delta_Dead_01", "Siaya_Delta_Dead_02", "Siaya_Delta_Dead_03", "Siaya_Delta_Dead_04", "Siaya_Delta_Dead_05", "Siaya_Delta_Dead_06", "Siaya_Delta_Dead_07", "Siaya_Delta_Dead_08", "Siaya_Delta_Dead_09", "Siaya_Delta_Dead_10", "Siaya_Delta_Dead_100", "Siaya_Delta_Dead_101", "Siaya_Delta_Dead_102", "Siaya_Delta_Dead_103", "Siaya_Delta_Dead_104", "Siaya_Delta_Dead_105", "Siaya_Delta_Dead_106", "Siaya_Delta_Dead_107", "Siaya_Delta_Dead_108", "Siaya_Delta_Dead_109", "Siaya_Delta_Dead_11", "Siaya_Delta_Dead_110", "Siaya_Delta_Dead_111", "Siaya_Delta_Dead_112", "Siaya_Delta_Dead_113", "Siaya_Delta_Dead_114", "Siaya_Delta_Dead_115", "Siaya_Delta_Dead_116", "Siaya_Delta_Dead_117", "Siaya_Delta_Dead_118", "Siaya_Delta_Dead_119", "Siaya_Delta_Dead_12", "Siaya_Delta_Dead_120", "Siaya_Delta_Dead_121", "Siaya_Delta_Dead_122", "Siaya_Delta_Dead_123", "Siaya_Delta_Dead_124", "Siaya_Delta_Dead_125", "Siaya_Delta_Dead_126", "Siaya_Delta_Dead_127", "Siaya_Delta_Dead_128", "Siaya_Delta_Dead_129", "Siaya_Delta_Dead_13", "Siaya_Delta_Dead_130", "Siaya_Delta_Dead_131", "Siaya_Delta_Dead_14", "Siaya_Delta_Dead_15", "Siaya_Delta_Dead_16", "Siaya_Delta_Dead_17", "Siaya_Delta_Dead_18", "Siaya_Delta_Dead_19", "Siaya_Delta_Dead_20", "Siaya_Delta_Dead_21", "Siaya_Delta_Dead_22", "Siaya_Delta_Dead_23", "Siaya_Delta_Dead_24", "Siaya_Delta_Dead_25", "Siaya_Delta_Dead_26", "Siaya_Delta_Dead_27", "Siaya_Delta_Dead_28", "Siaya_Delta_Dead_29", "Siaya_Delta_Dead_30", "Siaya_Delta_Dead_31", "Siaya_Delta_Dead_32", "Siaya_Delta_Dead_33", "Siaya_Delta_Dead_34", "Siaya_Delta_Dead_35", "Siaya_Delta_Dead_36", "Siaya_Delta_Dead_37", "Siaya_Delta_Dead_38", "Siaya_Delta_Dead_39", "Siaya_Delta_Dead_40", "Siaya_Delta_Dead_41", "Siaya_Delta_Dead_42", "Siaya_Delta_Dead_43", "Siaya_Delta_Dead_44", "Siaya_Delta_Dead_45", "Siaya_Delta_Dead_46", "Siaya_Delta_Dead_47", "Siaya_Delta_Dead_48", "Siaya_Delta_Dead_49", "Siaya_Delta_Dead_50", "Siaya_Delta_Dead_51", "Siaya_Delta_Dead_52", "Siaya_Delta_Dead_53", "Siaya_Delta_Dead_54", "Siaya_Delta_Dead_55", "Siaya_Delta_Dead_56", "Siaya_Delta_Dead_57", "Siaya_Delta_Dead_58", "Siaya_Delta_Dead_59", "Siaya_Delta_Dead_60", "Siaya_Delta_Dead_61", "Siaya_Delta_Dead_62", "Siaya_Delta_Dead_63", "Siaya_Delta_Dead_64", "Siaya_Delta_Dead_65", "Siaya_Delta_Dead_66", "Siaya_Delta_Dead_67", "Siaya_Delta_Dead_68", "Siaya_Delta_Dead_69", "Siaya_Delta_Dead_70", "Siaya_Delta_Dead_71", "Siaya_Delta_Dead_72", "Siaya_Delta_Dead_73", "Siaya_Delta_Dead_74", "Siaya_Delta_Dead_75", "Siaya_Delta_Dead_76", "Siaya_Delta_Dead_77", "Siaya_Delta_Dead_78", "Siaya_Delta_Dead_79", "Siaya_Delta_Dead_80", "Siaya_Delta_Dead_81", "Siaya_Delta_Dead_82", "Siaya_Delta_Dead_83", "Siaya_Delta_Dead_84", "Siaya_Delta_Dead_85", "Siaya_Delta_Dead_86", "Siaya_Delta_Dead_87", "Siaya_Delta_Dead_88", "Siaya_Delta_Dead_89", "Siaya_Delta_Dead_90", "Siaya_Delta_Dead_91", "Siaya_Delta_Dead_92", "Siaya_Delta_Dead_93", "Siaya_Delta_Dead_94", "Siaya_Delta_Dead_95", "Siaya_Delta_Dead_96", "Siaya_Delta_Dead_97", "Siaya_Delta_Dead_98", "Siaya_Delta_Dead_99", "Siaya_Delta_Dead_Negative", "VK7_Negative", "VK7_alive_01", "VK7_alive_02", "VK7_alive_03", "VK7_alive_04", "VK7_alive_05", "VK7_alive_06", "VK7_alive_07", "VK7_alive_08", "VK7_alive_09", "VK7_alive_10", "VK7_alive_11", "VK7_alive_12", "VK7_alive_13", "VK7_alive_14", "VK7_alive_15", "VK7_alive_16", "VK7_alive_17", "VK7_alive_18", "VK7_alive_19", "VK7_alive_20", "VK7_alive_21", "VK7_alive_22", "VK7_alive_23", "VK7_alive_24", "VK7_alive_25", "VK7_alive_26", "VK7_alive_27", "VK7_alive_28", "VK7_alive_29", "VK7_alive_30", "VK7_alive_31", "VK7_alive_32", "VK7_alive_33", "VK7_alive_34", "VK7_alive_35", "VK7_alive_36", "VK7_alive_37", "VK7_alive_38", "VK7_alive_39", "VK7_alive_40", "VK7_alive_41", "VK7_alive_42", "VK7_alive_43", "VK7_alive_44", "VK7_alive_45", "VK7_alive_46", "VK7_alive_47", "VK7_dead_01", "VK7_dead_02", "VK7_dead_03", "VK7_dead_04", "VK7_dead_04_dil", "VK7_dead_05", "VK7_dead_06", "VK7_dead_07", "VK7_dead_08", "VK7_dead_09", "VK7_dead_10", "VK7_dead_10_dil", "VK7_dead_11", "VK7_dead_12", "VK7_dead_13", "VK7_dead_14", "VK7_dead_15", "VK7_dead_16", "VK7_dead_16_dil", "VK7_dead_17", "VK7_dead_18", "VK7_dead_19", "VK7_dead_20", "VK7_dead_21", "VK7_dead_22", "VK7_dead_22_dil", "VK7_dead_23", "VK7_dead_24", "VK7_dead_25", "VK7_dead_26", "VK7_dead_27", "VK7_dead_28", "VK7_dead_28_dil", "VK7_dead_29", "VK7_dead_30", "VK7_dead_31", "VK7_dead_32", "VK7_dead_33", "VK7_dead_34", "VK7_dead_34_dil", "VK7_dead_35", "VK7_dead_36", "VK7_dead_37", "VK7_dead_38", "VK7_dead_39", "VK7_dead_40", "VK7_dead_41", "VK7_dead_42"], "xaxis": "x", "y": ["Agam_1", "Agam_2", "Agam_3", "Agam_4", "Agam_5", "Agam_6", "Agam_7", "Agam_8", "Agam_9", "Agam_10", "Agam_11", "Agam_12", "Agam_13", "Agam_14", "Agam_15", "Agam_16", "Agam_17", "Agam_18", "Agam_19", "Agam_20", "Agam_21", "Agam_22", "Agam_23", "Agam_24", "Agam_25", "Agam_26", "Agam_27", "Agam_28", "Agam_29", "Agam_30", "Agam_31", "Agam_32", "Agam_33", "Agam_34", "Agam_35", "Agam_36", "Agam_37", "Agam_38", "Agam_39", "Agam_40", "Agam_41", "Agam_42", "Agam_43", "Agam_44", "Agam_45", "Agam_46", "Agam_47", "Agam_48", "Agam_49", "Agam_50", "Agam_51", "Agam_52", "Agam_53", "Agam_54", "Agam_55", "Agam_56", "Agam_57", "Agam_58", "Agam_59", "Agam_60", "Agam_61", "Agam_62", "Agam_63", "Agam_64", "Agam_65", "Agam_66", "Agam_67", "Agam_68", "Agam_69", "Agam_70", "Agam_71", "Agam_72", "Agam_73", "Agam_74", "Agam_75", "Agam_76", "Agam_77", "Agam_78", "Agam_79", "Agam_80", "Agam_81", "Agam_82"], "yaxis": "y", "z": [[32, 17, 0, 2, 7, 20, 0, 0, 0, 4, 5, 0, 13, 20, 0, 8, 2, 1, 21, 4, 18, 6, 0, 0, 7, 55, 7, 3, 21, 54, 0, 8, 25, 33, 8, 0, 55, 16, 9, 24, 12, 8, 31, 14, 19, 3, 13, 0, 80, 70, 142, 16, 23, 12, 38, 12, 13, 8, 8, 1, 247, 68, 6, 47, 2, 6, 10, 9, 5, 10, 3, 0, 40, 25, 22, 51, 16, 10, 111, 2, 39, 10, 11, 1, 123, 359, 5, 36, 1, 2, 28, 0, 21, 0, 18, 0, 1, 0, 26, 76, 73, 3, 1, 0, 8, 1, 3, 5, 20, 22, 0, 26, 1, 2, 12, 8, 1, 8, 5, 0, 4, 50, 5, 0, 16, 5, 1, 2, 2, 3, 4, 3, 36, 35, 9, 34, 1, 4, 3, 2, 8, 1, 0, 0, 0, 72, 59, 4, 11, 8, 1, 6, 20, 13, 6, 2, 0, 5, 13, 64, 1, 3, 0, 3, 6, 2, 2, 0, 22, 1, 12, 25, 24, 5, 10, 7, 8, 4, 7, 0, 14, 433, 3, 48, 60, 0, 7, 8, 0, 2, 5, 0, 115, 149, 88, 78, 108, 105, 2, 182, 229, 106, 97, 86, 46, 125, 81, 114, 52, 54, 107, 168, 245, 100, 69, 108, 92, 74, 109, 65, 2, 121, 37, 170, 55, 115, 83, 90, 27, 49, 50, 85, 6, 53, 115, 83, 42, 169, 68, 201, 187, 224, 177, 141, 228, 186, 129, 200, 6, 141, 57, 65, 188, 313, 155, 242, 225, 330, 184, 155, 41, 50, 57, 73, 140, 158, 126, 257, 96, 86, 115, 184, 100, 64, 132, 74, 85, 114, 193, 141, 322, 133, 150, 123, 109, 24, 74, 134, 6, 114, 45, 109, 140, 118, 146, 129, 151, 118, 18, 77, 76, 100, 242, 98, 116, 176, 135, 206, 92, 96, 80, 72, 112, 10, 114, 47, 128, 112, 166, 107, 0, 82, 164, 0, 197, 81, 109, 68, 73, 69, 1, 60, 1, 27, 36, 87, 95, 74, 114, 82, 6, 222, 76, 106, 68, 51, 85, 87, 63, 131, 21, 86, 51, 61, 85, 58, 81, 30, 51, 128, 97, 79, 44, 138, 56, 109, 138, 57, 59, 261, 144, 65, 48, 224, 111, 37, 0, 71, 111, 62, 17, 59, 65, 236, 140, 73, 99, 57, 0, 62, 58, 52, 312, 66, 147, 188, 181, 97, 143, 37, 0, 138, 76, 132, 98, 27, 198, 107, 62, 79, 104, 25, 1, 143, 63, 68, 208, 147, 353, 48, 1, 278, 46, 109, 1, 33, 113, 80, 373, 313, 230, 124, 184, 145, 133, 64, 0, 72, 123, 49, 494, 73, 234, 161, 151, 5, 117, 50, 0, 80, 146, 48, 77, 53, 111, 19, 0, 0, 0, 0, 30, 0, 63, 22, 31, 0, 45, 0, 19, 0, 17, 52, 26, 0, 48, 99, 37, 0, 23, 0, 59, 10, 50, 0, 77, 0, 103, 0, 26, 0, 36, 42, 70, 43, 25, 0, 46, 63, 50, 27, 49, 25, 43, 64, 25, 42, 76, 32, 1, 99, 175, 48, 89, 20, 55, 4, 54, 57, 2, 28, 16, 49, 3, 20, 23, 34, 24, 50, 21, 4, 40, 57, 2, 20, 22, 105, 1, 47, 27, 162, 6, 39, 34, 0, 22, 55, 73, 94, 51, 5, 61, 26], [29, 4, 0, 2, 2, 25, 2, 0, 0, 2, 2, 0, 13, 13, 3, 2, 4, 1, 24, 1, 23, 0, 0, 0, 78, 38, 5, 5, 13, 39, 0, 4, 17, 14, 3, 0, 46, 6, 1, 20, 10, 8, 12, 10, 12, 0, 8, 0, 59, 70, 104, 18, 28, 27, 30, 9, 9, 2, 6, 0, 205, 56, 10, 52, 0, 4, 8, 6, 8, 5, 1, 0, 41, 28, 16, 28, 5, 8, 116, 6, 33, 6, 5, 0, 85, 235, 1, 26, 0, 0, 27, 0, 10, 0, 27, 0, 2, 0, 110, 359, 145, 7, 1, 0, 32, 6, 24, 9, 91, 202, 1, 26, 3, 2, 40, 10, 7, 14, 29, 5, 120, 214, 9, 2, 32, 45, 5, 16, 1, 2, 4, 10, 205, 65, 10, 94, 8, 5, 2, 9, 24, 4, 8, 2, 1, 250, 152, 16, 26, 2, 21, 4, 66, 18, 11, 13, 1, 30, 8, 131, 0, 20, 5, 16, 25, 18, 2, 1, 60, 9, 75, 87, 21, 17, 8, 5, 29, 12, 3, 0, 50, 1486, 9, 171, 215, 1, 38, 30, 1, 3, 15, 0, 131, 83, 56, 50, 69, 111, 20, 132, 153, 65, 71, 64, 35, 95, 51, 105, 24, 35, 56, 108, 195, 89, 44, 66, 57, 60, 50, 46, 2, 56, 26, 121, 39, 74, 71, 42, 29, 48, 28, 100, 4, 47, 115, 68, 33, 124, 52, 112, 141, 128, 89, 68, 151, 106, 98, 168, 93, 98, 68, 68, 179, 203, 97, 133, 143, 244, 118, 100, 28, 31, 51, 70, 127, 87, 136, 172, 71, 50, 102, 144, 64, 36, 109, 65, 83, 69, 134, 119, 208, 127, 119, 111, 106, 30, 54, 100, 6, 111, 44, 89, 155, 108, 113, 155, 108, 98, 34, 64, 99, 81, 164, 75, 80, 162, 103, 137, 102, 62, 71, 57, 68, 7, 111, 55, 108, 109, 151, 89, 7, 78, 164, 0, 180, 56, 95, 48, 63, 70, 1, 49, 0, 27, 30, 65, 80, 67, 62, 52, 112, 153, 82, 79, 78, 43, 60, 83, 48, 113, 21, 65, 40, 46, 48, 56, 37, 16, 38, 48, 65, 37, 25, 85, 43, 72, 136, 23, 40, 240, 115, 25, 51, 178, 126, 25, 0, 81, 89, 37, 138, 52, 31, 244, 89, 55, 88, 51, 0, 57, 66, 39, 336, 46, 107, 201, 159, 83, 152, 37, 0, 123, 49, 86, 100, 20, 150, 69, 30, 84, 54, 18, 0, 117, 44, 55, 188, 102, 264, 41, 0, 185, 10, 36, 0, 38, 94, 63, 307, 195, 230, 115, 142, 71, 72, 52, 0, 66, 90, 32, 436, 59, 216, 146, 134, 2, 81, 37, 0, 77, 111, 52, 31, 48, 90, 21, 0, 0, 0, 0, 11, 0, 18, 15, 17, 0, 17, 0, 12, 0, 7, 32, 17, 0, 16, 26, 26, 0, 27, 0, 15, 6, 9, 0, 25, 0, 28, 0, 16, 0, 13, 15, 19, 19, 15, 0, 14, 23, 19, 13, 12, 7, 21, 26, 4, 11, 40, 18, 0, 43, 83, 30, 28, 12, 16, 0, 37, 39, 11, 9, 7, 13, 0, 21, 8, 15, 13, 18, 18, 3, 13, 18, 1, 16, 10, 39, 0, 18, 9, 36, 0, 21, 20, 0, 17, 16, 29, 39, 16, 4, 27, 15], [4, 4, 1, 0, 2, 17, 4, 0, 0, 2, 2, 0, 4, 6, 4, 0, 0, 4, 6, 2, 6, 2, 0, 0, 4, 20, 4, 4, 4, 37, 0, 0, 8, 14, 0, 0, 29, 2, 4, 14, 0, 0, 10, 7, 4, 2, 1, 0, 39, 52, 52, 2, 32, 12, 12, 0, 6, 4, 2, 0, 135, 26, 4, 20, 0, 2, 6, 2, 0, 0, 2, 0, 16, 10, 14, 32, 3, 11, 43, 2, 11, 10, 8, 0, 66, 169, 4, 22, 0, 0, 22, 0, 16, 0, 8, 0, 0, 0, 28, 47, 14, 0, 1, 0, 2, 2, 7, 2, 6, 15, 0, 0, 0, 2, 12, 0, 0, 6, 0, 0, 4, 16, 0, 0, 2, 4, 0, 0, 1, 0, 0, 2, 16, 14, 6, 11, 0, 4, 0, 0, 4, 4, 3, 0, 2, 47, 14, 0, 3, 1, 0, 2, 8, 2, 2, 0, 0, 5, 6, 22, 2, 0, 0, 0, 2, 2, 6, 0, 14, 2, 10, 31, 27, 2, 8, 2, 6, 2, 0, 0, 4, 248, 4, 32, 37, 5, 8, 8, 1, 2, 2, 0, 52, 37, 11, 36, 24, 62, 92, 44, 82, 39, 24, 46, 12, 44, 11, 44, 32, 10, 35, 60, 100, 29, 22, 28, 18, 10, 38, 31, 0, 36, 10, 85, 10, 33, 39, 24, 10, 16, 20, 25, 0, 49, 42, 24, 22, 67, 41, 38, 96, 66, 71, 42, 58, 129, 41, 52, 2, 47, 24, 32, 77, 92, 58, 84, 80, 152, 54, 35, 32, 16, 26, 24, 54, 67, 47, 67, 41, 28, 58, 42, 25, 18, 20, 16, 23, 42, 57, 44, 119, 44, 64, 44, 41, 16, 20, 59, 0, 43, 10, 65, 73, 47, 41, 58, 61, 58, 22, 38, 39, 44, 114, 36, 64, 96, 49, 56, 50, 33, 26, 32, 43, 0, 79, 22, 54, 60, 77, 51, 46, 14, 60, 0, 92, 26, 53, 14, 26, 61, 35, 20, 1, 24, 14, 45, 6, 32, 28, 35, 10, 65, 28, 28, 49, 10, 42, 33, 28, 65, 22, 53, 14, 17, 14, 23, 20, 2, 14, 46, 58, 61, 34, 44, 16, 44, 40, 14, 26, 96, 58, 10, 20, 111, 58, 20, 0, 30, 43, 14, 8, 16, 18, 129, 43, 40, 20, 24, 0, 24, 20, 12, 152, 26, 48, 98, 51, 47, 48, 23, 0, 28, 47, 36, 25, 22, 48, 53, 10, 77, 46, 14, 0, 64, 30, 32, 82, 46, 177, 38, 0, 91, 10, 30, 0, 28, 48, 24, 198, 100, 213, 70, 88, 92, 72, 34, 0, 34, 60, 27, 202, 51, 106, 100, 65, 2, 37, 39, 0, 35, 35, 7, 22, 13, 33, 16, 0, 84, 0, 2, 18, 0, 50, 14, 28, 0, 35, 0, 12, 0, 12, 38, 22, 0, 26, 66, 29, 0, 15, 0, 31, 2, 16, 0, 38, 0, 60, 0, 18, 0, 27, 24, 51, 28, 16, 0, 21, 47, 30, 28, 38, 10, 26, 52, 7, 15, 52, 22, 0, 72, 127, 29, 60, 8, 8, 0, 40, 14, 2, 10, 8, 40, 0, 21, 17, 14, 20, 24, 20, 0, 34, 25, 0, 14, 30, 58, 1, 24, 10, 104, 0, 28, 22, 0, 36, 20, 45, 56, 29, 0, 58, 12], [13, 5, 0, 0, 1, 11, 2, 0, 0, 5, 2, 0, 6, 4, 3, 2, 1, 0, 8, 0, 5, 3, 1, 0, 9, 21, 8, 1, 6, 28, 1, 2, 14, 14, 8, 0, 28, 7, 3, 15, 5, 6, 4, 7, 4, 3, 6, 0, 32, 37, 68, 9, 8, 7, 13, 2, 2, 1, 2, 0, 177, 35, 2, 23, 0, 5, 2, 1, 0, 2, 1, 0, 33, 20, 16, 30, 2, 8, 76, 0, 21, 2, 4, 0, 78, 241, 2, 26, 0, 1, 24, 0, 11, 0, 12, 0, 0, 1, 12, 46, 19, 0, 2, 0, 2, 2, 9, 0, 5, 23, 0, 4, 0, 1, 2, 2, 2, 0, 2, 1, 5, 14, 1, 0, 5, 8, 0, 7, 0, 1, 0, 1, 30, 9, 7, 12, 1, 1, 1, 1, 4, 1, 0, 0, 0, 38, 23, 3, 3, 3, 0, 1, 10, 1, 1, 1, 0, 3, 3, 22, 1, 3, 1, 1, 1, 2, 1, 0, 23, 3, 32, 17, 13, 3, 5, 1, 4, 1, 0, 0, 10, 326, 5, 26, 26, 2, 7, 0, 0, 0, 2, 0, 54, 71, 34, 24, 52, 73, 168, 61, 123, 49, 29, 35, 16, 61, 39, 56, 25, 16, 44, 65, 191, 57, 26, 53, 43, 16, 29, 23, 3, 40, 12, 65, 20, 59, 45, 27, 25, 24, 32, 57, 3, 28, 56, 35, 27, 75, 40, 55, 98, 93, 74, 71, 103, 94, 75, 71, 7, 45, 37, 28, 85, 178, 101, 107, 110, 177, 85, 70, 30, 20, 18, 24, 62, 83, 84, 102, 53, 42, 85, 53, 41, 23, 52, 38, 24, 48, 67, 61, 122, 59, 81, 55, 52, 9, 28, 47, 0, 67, 20, 51, 72, 71, 101, 70, 67, 62, 20, 59, 71, 67, 127, 61, 70, 130, 93, 90, 61, 55, 53, 47, 62, 4, 70, 30, 93, 80, 91, 67, 42, 23, 87, 0, 101, 22, 72, 23, 34, 41, 26, 16, 0, 15, 15, 47, 40, 25, 27, 47, 15, 83, 47, 63, 48, 22, 54, 43, 27, 49, 24, 47, 35, 28, 29, 32, 36, 10, 23, 52, 64, 55, 59, 69, 22, 69, 66, 28, 39, 118, 63, 20, 27, 116, 78, 12, 0, 37, 43, 19, 15, 19, 18, 178, 55, 48, 48, 16, 0, 21, 22, 18, 198, 40, 67, 87, 63, 31, 74, 18, 0, 54, 31, 48, 57, 13, 104, 52, 14, 53, 28, 7, 0, 68, 20, 21, 108, 64, 231, 37, 1, 124, 15, 58, 0, 25, 66, 44, 236, 152, 347, 93, 121, 75, 105, 33, 0, 36, 76, 27, 332, 43, 147, 107, 81, 1, 60, 44, 0, 51, 66, 12, 19, 12, 43, 14, 0, 33, 0, 0, 26, 0, 69, 8, 37, 0, 34, 0, 23, 0, 20, 47, 25, 0, 25, 70, 36, 0, 26, 0, 53, 11, 30, 0, 55, 0, 95, 0, 19, 0, 34, 42, 49, 33, 22, 0, 16, 34, 50, 25, 46, 16, 39, 46, 11, 17, 61, 11, 0, 91, 190, 45, 61, 16, 25, 0, 28, 33, 4, 11, 6, 37, 2, 17, 16, 20, 26, 26, 30, 1, 22, 35, 1, 17, 20, 52, 0, 24, 12, 100, 0, 32, 30, 1, 26, 29, 48, 69, 37, 9, 60, 12], [21, 6, 0, 0, 2, 12, 12, 0, 0, 0, 3, 0, 19, 7, 3, 1, 3, 2, 26, 1, 24, 4, 1, 0, 10, 31, 13, 2, 10, 42, 2, 5, 24, 17, 11, 0, 30, 11, 8, 28, 12, 9, 22, 9, 8, 5, 10, 0, 46, 79, 169, 21, 19, 9, 35, 4, 3, 3, 4, 0, 287, 55, 12, 40, 0, 7, 3, 7, 5, 19, 1, 0, 41, 34, 38, 34, 9, 12, 173, 5, 56, 11, 10, 0, 117, 393, 8, 40, 0, 0, 38, 0, 20, 0, 29, 0, 0, 0, 17, 73, 34, 0, 7, 1, 2, 1, 4, 2, 8, 35, 0, 6, 3, 0, 2, 0, 2, 3, 2, 0, 1, 27, 5, 0, 18, 2, 2, 4, 0, 2, 1, 0, 34, 12, 7, 18, 1, 2, 0, 0, 8, 0, 0, 0, 0, 74, 37, 2, 2, 6, 1, 0, 5, 4, 2, 1, 0, 5, 7, 33, 2, 6, 1, 2, 4, 4, 2, 2, 17, 3, 36, 25, 22, 1, 6, 2, 8, 1, 2, 0, 13, 390, 10, 39, 58, 0, 0, 4, 0, 0, 1, 0, 124, 79, 56, 27, 68, 122, 289, 109, 209, 69, 71, 62, 23, 77, 49, 101, 44, 32, 99, 97, 255, 56, 37, 68, 53, 34, 56, 31, 2, 62, 19, 121, 26, 117, 72, 50, 39, 46, 43, 79, 4, 61, 85, 69, 43, 147, 71, 114, 168, 151, 125, 74, 264, 149, 106, 116, 10, 61, 47, 71, 159, 269, 154, 172, 173, 326, 114, 105, 40, 21, 38, 48, 125, 114, 117, 155, 66, 76, 89, 84, 50, 34, 69, 47, 51, 67, 106, 73, 165, 84, 92, 70, 84, 18, 32, 109, 1, 111, 37, 72, 118, 91, 112, 143, 108, 83, 38, 63, 97, 94, 200, 63, 103, 142, 101, 175, 101, 72, 64, 50, 61, 0, 90, 45, 113, 116, 146, 121, 101, 33, 168, 0, 155, 61, 115, 35, 69, 88, 60, 22, 0, 23, 24, 76, 81, 73, 74, 59, 12, 155, 73, 95, 56, 27, 90, 59, 41, 112, 43, 58, 59, 45, 41, 73, 69, 16, 49, 104, 124, 87, 97, 114, 44, 138, 134, 35, 65, 256, 118, 22, 27, 198, 145, 12, 0, 54, 78, 39, 33, 15, 30, 279, 76, 54, 88, 37, 0, 45, 45, 31, 364, 52, 97, 153, 157, 75, 146, 16, 1, 114, 62, 80, 71, 18, 199, 114, 31, 94, 69, 17, 1, 108, 29, 45, 206, 83, 447, 68, 0, 199, 30, 58, 0, 28, 106, 61, 459, 234, 528, 173, 202, 145, 148, 64, 0, 54, 86, 43, 465, 75, 198, 169, 162, 5, 134, 46, 0, 86, 102, 29, 42, 32, 90, 21, 1, 43, 0, 0, 29, 1, 72, 17, 23, 0, 40, 0, 14, 0, 17, 53, 26, 0, 36, 80, 39, 0, 28, 0, 52, 8, 54, 0, 40, 1, 93, 0, 21, 0, 29, 47, 74, 37, 20, 0, 23, 49, 55, 30, 46, 14, 27, 68, 19, 23, 74, 26, 0, 121, 230, 59, 88, 16, 29, 0, 56, 53, 10, 18, 11, 40, 1, 26, 13, 25, 24, 28, 26, 0, 22, 48, 2, 16, 22, 90, 0, 41, 33, 156, 2, 47, 30, 0, 39, 49, 81, 109, 56, 6, 82, 16], [30, 5, 0, 0, 0, 14, 0, 2, 1, 0, 0, 0, 14, 7, 0, 4, 4, 0, 16, 0, 16, 8, 0, 0, 6, 18, 5, 1, 10, 46, 1, 2, 8, 12, 9, 0, 52, 6, 2, 10, 0, 7, 9, 9, 6, 2, 8, 0, 57, 42, 76, 6, 18, 14, 18, 22, 7, 4, 6, 1, 162, 32, 0, 15, 0, 10, 12, 8, 2, 4, 1, 2, 19, 11, 22, 27, 9, 13, 106, 4, 19, 3, 10, 1, 88, 239, 7, 8, 2, 0, 18, 0, 5, 0, 31, 1, 2, 1, 33, 46, 39, 0, 0, 0, 2, 8, 8, 0, 5, 53, 2, 27, 3, 0, 6, 2, 0, 10, 3, 2, 2, 26, 12, 0, 26, 7, 0, 6, 1, 2, 2, 0, 26, 25, 22, 16, 0, 4, 0, 2, 6, 0, 2, 1, 4, 38, 41, 2, 6, 0, 18, 4, 22, 2, 1, 1, 1, 18, 6, 28, 0, 6, 0, 4, 6, 2, 4, 0, 26, 6, 2, 31, 9, 2, 3, 5, 8, 1, 0, 0, 12, 286, 8, 44, 43, 0, 4, 0, 2, 1, 6, 0, 63, 117, 34, 40, 76, 57, 0, 97, 111, 48, 53, 64, 21, 73, 49, 40, 40, 59, 43, 101, 148, 75, 36, 57, 64, 50, 81, 52, 0, 67, 10, 91, 26, 94, 58, 48, 27, 27, 48, 64, 0, 20, 56, 41, 22, 84, 30, 129, 119, 124, 120, 70, 147, 144, 60, 164, 2, 76, 57, 72, 129, 211, 71, 115, 128, 254, 105, 105, 27, 21, 40, 54, 96, 122, 93, 114, 52, 43, 107, 109, 42, 53, 98, 33, 77, 71, 98, 72, 142, 42, 107, 88, 99, 28, 28, 94, 6, 91, 36, 60, 70, 66, 124, 74, 73, 66, 24, 61, 57, 65, 133, 53, 49, 116, 93, 121, 60, 55, 48, 33, 60, 6, 106, 32, 91, 106, 118, 51, 0, 61, 85, 0, 114, 73, 68, 43, 58, 77, 0, 26, 1, 27, 34, 53, 41, 57, 88, 30, 8, 145, 64, 40, 52, 26, 75, 49, 41, 79, 52, 62, 35, 34, 62, 70, 50, 19, 51, 94, 39, 69, 34, 88, 18, 61, 162, 23, 29, 151, 111, 42, 45, 184, 106, 29, 0, 67, 96, 29, 16, 51, 48, 208, 83, 45, 74, 60, 1, 55, 56, 31, 279, 26, 101, 137, 107, 54, 179, 14, 0, 115, 28, 85, 91, 14, 130, 119, 42, 119, 91, 21, 2, 104, 57, 76, 94, 89, 235, 46, 4, 191, 15, 59, 0, 36, 53, 56, 267, 226, 294, 97, 153, 106, 108, 52, 1, 35, 120, 25, 363, 70, 198, 107, 113, 2, 88, 40, 0, 70, 109, 44, 56, 25, 40, 24, 1, 0, 0, 0, 29, 0, 52, 16, 24, 0, 25, 0, 25, 0, 21, 61, 23, 0, 33, 76, 28, 0, 29, 0, 57, 14, 51, 0, 46, 0, 69, 0, 20, 0, 13, 26, 49, 28, 14, 0, 21, 42, 46, 19, 32, 10, 20, 60, 15, 23, 76, 26, 0, 95, 155, 29, 91, 20, 43, 0, 40, 32, 4, 24, 14, 43, 4, 20, 22, 25, 18, 30, 32, 3, 10, 42, 1, 25, 29, 87, 0, 25, 32, 151, 2, 30, 35, 0, 18, 20, 58, 71, 27, 10, 86, 15], [21, 6, 0, 0, 2, 12, 1, 0, 0, 3, 3, 0, 5, 8, 1, 3, 0, 3, 6, 0, 17, 3, 0, 0, 2, 22, 3, 2, 4, 40, 1, 6, 7, 11, 10, 0, 32, 14, 3, 15, 2, 2, 14, 6, 7, 0, 6, 0, 50, 25, 93, 6, 19, 6, 21, 18, 3, 2, 1, 0, 146, 32, 3, 23, 3, 7, 7, 8, 5, 4, 0, 0, 23, 10, 6, 24, 3, 8, 45, 3, 16, 4, 3, 0, 82, 184, 4, 9, 0, 1, 19, 0, 8, 0, 7, 0, 1, 0, 7, 25, 14, 1, 0, 0, 2, 1, 1, 0, 7, 38, 0, 7, 0, 0, 8, 0, 0, 7, 2, 0, 0, 0, 0, 1, 10, 0, 0, 1, 5, 2, 0, 0, 0, 1, 5, 25, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 38, 5, 2, 1, 0, 7, 11, 2, 1, 0, 0, 8, 7, 9, 0, 2, 0, 0, 1, 0, 0, 1, 17, 0, 2, 5, 14, 0, 6, 3, 0, 1, 0, 0, 11, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 82, 88, 31, 23, 70, 35, 0, 142, 151, 62, 58, 31, 23, 51, 39, 54, 20, 25, 34, 38, 90, 76, 27, 44, 42, 37, 74, 25, 3, 40, 25, 93, 19, 58, 45, 40, 19, 32, 30, 52, 5, 22, 56, 30, 25, 102, 19, 97, 112, 64, 75, 36, 99, 57, 83, 186, 3, 87, 39, 46, 107, 120, 51, 92, 82, 156, 113, 53, 46, 29, 26, 20, 83, 96, 123, 129, 45, 41, 77, 66, 68, 39, 59, 24, 42, 38, 76, 100, 187, 78, 83, 74, 61, 15, 37, 58, 16, 80, 67, 59, 34, 78, 62, 71, 52, 52, 16, 40, 57, 27, 94, 60, 38, 105, 73, 90, 47, 45, 24, 28, 39, 3, 72, 30, 70, 67, 88, 30, 0, 41, 81, 0, 120, 62, 66, 17, 48, 24, 1, 34, 0, 24, 13, 29, 27, 16, 66, 49, 11, 140, 54, 15, 48, 21, 62, 22, 29, 71, 31, 74, 20, 14, 55, 38, 30, 7, 21, 22, 51, 33, 15, 30, 31, 23, 72, 34, 26, 79, 47, 42, 47, 147, 86, 38, 0, 71, 63, 41, 12, 25, 30, 134, 73, 45, 49, 10, 0, 62, 21, 16, 135, 51, 76, 144, 78, 39, 149, 20, 0, 57, 34, 66, 75, 12, 117, 66, 43, 71, 63, 26, 0, 79, 53, 32, 105, 43, 91, 25, 2, 85, 52, 48, 0, 15, 51, 30, 197, 122, 117, 27, 60, 44, 53, 36, 0, 43, 49, 10, 195, 65, 111, 107, 103, 3, 51, 22, 0, 51, 58, 42, 29, 14, 31, 10, 0, 0, 0, 0, 28, 0, 54, 12, 35, 0, 27, 0, 24, 0, 15, 37, 15, 0, 23, 39, 33, 0, 20, 0, 26, 9, 42, 0, 35, 0, 69, 0, 20, 0, 16, 17, 40, 26, 10, 0, 10, 40, 45, 16, 26, 6, 17, 37, 11, 13, 57, 20, 1, 64, 112, 38, 50, 13, 42, 0, 54, 39, 3, 16, 13, 25, 0, 16, 13, 26, 22, 34, 37, 3, 23, 16, 2, 12, 14, 49, 0, 21, 20, 95, 7, 24, 24, 0, 18, 24, 49, 61, 37, 5, 30, 18], [14, 3, 0, 0, 4, 8, 0, 0, 0, 3, 2, 1, 5, 11, 2, 7, 4, 1, 13, 0, 13, 1, 0, 0, 4, 15, 6, 0, 3, 25, 0, 6, 14, 13, 5, 0, 20, 1, 5, 9, 6, 6, 18, 8, 7, 1, 9, 0, 37, 38, 75, 12, 16, 10, 18, 9, 3, 2, 4, 0, 108, 29, 5, 33, 0, 7, 3, 2, 2, 5, 0, 0, 19, 10, 8, 19, 7, 11, 55, 4, 27, 5, 5, 0, 51, 198, 7, 22, 0, 1, 21, 0, 8, 0, 11, 0, 1, 0, 4, 0, 0, 3, 0, 0, 7, 2, 0, 0, 0, 22, 0, 2, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 0, 3, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 3, 0, 2, 0, 1, 0, 0, 1, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 11, 0, 0, 8, 13, 1, 2, 0, 0, 0, 1, 0, 0, 194, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 85, 109, 43, 38, 42, 57, 4, 82, 112, 34, 45, 34, 14, 42, 32, 51, 21, 16, 58, 65, 150, 45, 35, 32, 29, 31, 55, 35, 0, 48, 16, 85, 27, 56, 41, 34, 15, 26, 39, 53, 4, 30, 46, 36, 19, 60, 37, 140, 102, 83, 74, 77, 128, 89, 71, 100, 2, 45, 23, 26, 85, 163, 112, 111, 97, 170, 69, 75, 22, 20, 24, 34, 79, 69, 82, 117, 49, 42, 61, 78, 51, 32, 67, 47, 42, 41, 73, 50, 135, 64, 65, 80, 43, 19, 16, 58, 3, 76, 24, 39, 57, 57, 73, 92, 63, 47, 20, 40, 49, 49, 100, 45, 43, 60, 76, 89, 51, 39, 29, 23, 39, 4, 45, 28, 62, 49, 79, 57, 1, 39, 121, 0, 93, 51, 58, 18, 34, 37, 0, 17, 0, 15, 24, 50, 39, 38, 84, 36, 13, 101, 40, 41, 28, 12, 50, 44, 27, 67, 25, 48, 40, 18, 39, 36, 35, 20, 34, 47, 79, 57, 39, 71, 33, 54, 86, 29, 29, 110, 53, 40, 34, 104, 56, 9, 0, 40, 45, 15, 12, 30, 23, 146, 61, 22, 66, 30, 0, 31, 28, 17, 218, 32, 56, 96, 82, 33, 78, 16, 0, 68, 34, 53, 36, 13, 119, 51, 19, 52, 45, 24, 0, 61, 29, 27, 105, 60, 162, 24, 1, 142, 17, 35, 0, 14, 36, 35, 183, 158, 164, 73, 100, 62, 58, 35, 0, 30, 44, 19, 182, 45, 120, 89, 99, 1, 65, 25, 0, 46, 74, 39, 40, 15, 49, 8, 0, 0, 0, 0, 18, 0, 39, 2, 20, 0, 18, 0, 10, 0, 7, 22, 16, 0, 25, 36, 25, 0, 9, 0, 30, 1, 21, 0, 26, 0, 34, 0, 11, 0, 15, 15, 25, 12, 14, 0, 12, 25, 18, 15, 19, 6, 10, 30, 6, 15, 43, 9, 1, 53, 84, 27, 62, 9, 27, 0, 21, 20, 3, 6, 9, 23, 4, 16, 9, 16, 25, 10, 7, 3, 10, 18, 1, 4, 6, 45, 0, 20, 13, 105, 1, 16, 12, 0, 6, 13, 40, 32, 20, 2, 43, 7], [82, 6, 0, 1, 4, 10, 0, 0, 0, 8, 3, 2, 30, 19, 3, 29, 9, 2, 47, 1, 57, 1, 3, 0, 9, 43, 20, 2, 13, 70, 2, 7, 27, 41, 25, 0, 126, 6, 22, 36, 13, 14, 42, 22, 18, 6, 17, 0, 151, 89, 232, 47, 51, 28, 81, 53, 10, 15, 11, 0, 281, 98, 16, 39, 2, 13, 24, 11, 3, 12, 0, 0, 30, 32, 19, 39, 18, 20, 203, 5, 55, 12, 18, 0, 112, 438, 6, 42, 0, 1, 35, 0, 16, 0, 19, 0, 0, 0, 63, 155, 96, 5, 0, 0, 11, 4, 3, 5, 34, 94, 1, 20, 10, 1, 23, 20, 8, 13, 6, 1, 3, 104, 3, 0, 31, 14, 4, 14, 9, 3, 6, 5, 82, 41, 21, 32, 4, 5, 3, 5, 21, 0, 4, 0, 4, 108, 109, 15, 16, 10, 13, 10, 30, 19, 11, 7, 1, 17, 35, 99, 3, 19, 5, 11, 7, 5, 3, 2, 28, 9, 16, 38, 33, 2, 12, 3, 11, 4, 6, 0, 15, 528, 14, 52, 53, 3, 12, 7, 0, 1, 11, 0, 231, 231, 143, 96, 202, 144, 14, 277, 259, 174, 147, 139, 106, 211, 141, 180, 90, 86, 137, 233, 309, 168, 83, 189, 161, 157, 219, 135, 5, 167, 79, 254, 74, 155, 107, 92, 52, 51, 77, 124, 2, 70, 204, 96, 55, 236, 105, 350, 270, 258, 253, 223, 352, 292, 194, 382, 11, 224, 143, 162, 408, 451, 251, 362, 406, 430, 306, 270, 87, 82, 95, 89, 214, 250, 252, 373, 141, 162, 195, 316, 141, 104, 264, 140, 128, 150, 362, 320, 497, 238, 292, 211, 172, 81, 103, 202, 15, 221, 123, 176, 175, 130, 206, 230, 171, 143, 34, 116, 124, 150, 319, 93, 101, 228, 169, 202, 131, 93, 108, 82, 114, 7, 141, 69, 170, 136, 229, 151, 0, 222, 252, 0, 300, 148, 228, 104, 190, 98, 3, 129, 1, 73, 67, 138, 103, 126, 223, 170, 16, 367, 167, 143, 115, 94, 180, 134, 120, 154, 73, 176, 95, 127, 151, 143, 139, 49, 67, 191, 140, 107, 56, 169, 48, 103, 264, 82, 68, 426, 186, 124, 140, 498, 253, 75, 0, 174, 206, 120, 23, 133, 100, 454, 250, 154, 174, 113, 0, 125, 154, 84, 488, 144, 265, 274, 268, 142, 359, 98, 0, 303, 146, 198, 217, 37, 282, 222, 96, 163, 217, 92, 0, 305, 103, 157, 288, 185, 466, 121, 3, 349, 73, 159, 1, 54, 128, 90, 438, 403, 407, 247, 290, 187, 196, 69, 0, 104, 184, 60, 642, 132, 303, 243, 220, 3, 167, 88, 0, 129, 205, 137, 131, 118, 163, 38, 0, 2, 1, 0, 47, 0, 85, 26, 55, 0, 54, 0, 50, 0, 23, 84, 41, 0, 52, 112, 60, 0, 43, 2, 115, 19, 69, 0, 84, 0, 121, 1, 33, 0, 43, 64, 75, 48, 23, 0, 48, 51, 68, 34, 62, 13, 37, 98, 32, 45, 120, 35, 0, 183, 254, 69, 142, 33, 101, 2, 105, 70, 2, 35, 21, 80, 1, 51, 30, 44, 53, 42, 54, 14, 42, 58, 3, 22, 37, 122, 0, 46, 40, 143, 9, 65, 38, 0, 17, 48, 69, 145, 53, 9, 107, 23], [221, 10, 0, 15, 24, 28, 0, 0, 0, 24, 10, 3, 43, 51, 25, 27, 32, 8, 109, 5, 75, 16, 4, 0, 27, 99, 28, 11, 49, 245, 1, 25, 84, 87, 80, 0, 237, 44, 32, 88, 16, 11, 67, 36, 66, 17, 39, 0, 344, 193, 579, 91, 84, 29, 103, 95, 29, 29, 14, 0, 494, 220, 47, 129, 6, 14, 56, 34, 11, 21, 1, 0, 56, 31, 31, 60, 23, 39, 176, 6, 70, 7, 18, 0, 147, 543, 6, 55, 0, 2, 54, 0, 17, 0, 31, 0, 22, 1, 78, 56, 64, 3, 0, 1, 6, 6, 4, 7, 13, 155, 0, 21, 1, 5, 2, 8, 10, 22, 7, 0, 6, 64, 6, 0, 23, 7, 13, 20, 10, 4, 12, 2, 17, 8, 41, 0, 1, 2, 3, 3, 10, 1, 2, 1, 0, 23, 22, 2, 0, 19, 7, 7, 30, 5, 3, 3, 0, 10, 28, 51, 0, 11, 3, 2, 0, 1, 2, 0, 23, 2, 1, 12, 21, 4, 7, 6, 2, 0, 3, 1, 4, 396, 15, 12, 13, 0, 3, 5, 0, 0, 0, 0, 438, 241, 189, 141, 386, 169, 3, 516, 279, 267, 307, 221, 190, 354, 245, 294, 133, 196, 167, 359, 269, 370, 208, 280, 268, 262, 391, 153, 16, 216, 143, 291, 202, 165, 103, 104, 49, 80, 97, 139, 1, 64, 306, 93, 58, 362, 197, 391, 383, 296, 302, 386, 457, 465, 370, 578, 16, 357, 200, 310, 528, 662, 341, 544, 601, 558, 485, 407, 129, 176, 221, 101, 336, 314, 434, 521, 244, 261, 308, 569, 227, 125, 389, 233, 215, 237, 578, 392, 566, 298, 389, 402, 330, 85, 222, 351, 50, 276, 230, 274, 188, 170, 187, 165, 142, 142, 18, 97, 100, 152, 303, 116, 127, 238, 163, 219, 110, 98, 81, 86, 130, 5, 183, 56, 184, 116, 192, 119, 1, 452, 213, 1, 569, 157, 307, 152, 491, 122, 0, 213, 0, 205, 165, 281, 200, 222, 274, 210, 32, 554, 215, 277, 115, 188, 230, 212, 240, 204, 154, 206, 169, 170, 306, 233, 234, 87, 129, 242, 162, 121, 66, 137, 58, 110, 418, 82, 93, 542, 279, 143, 210, 655, 485, 169, 1, 241, 435, 243, 40, 291, 176, 627, 425, 263, 261, 152, 0, 192, 316, 176, 514, 179, 447, 287, 410, 248, 378, 146, 1, 475, 176, 394, 298, 87, 339, 367, 158, 240, 309, 123, 0, 333, 211, 296, 503, 336, 568, 193, 16, 447, 164, 297, 0, 86, 152, 96, 564, 401, 380, 239, 256, 202, 199, 84, 0, 85, 154, 109, 623, 146, 291, 273, 305, 2, 160, 83, 0, 147, 148, 294, 132, 182, 300, 34, 0, 0, 1, 0, 82, 0, 191, 48, 157, 0, 139, 1, 95, 0, 69, 171, 79, 3, 102, 138, 105, 0, 109, 1, 190, 41, 139, 0, 141, 0, 213, 0, 88, 0, 57, 80, 73, 52, 33, 0, 33, 72, 72, 44, 61, 18, 45, 80, 85, 73, 253, 96, 0, 349, 290, 140, 190, 58, 138, 6, 148, 149, 13, 81, 46, 119, 11, 105, 53, 107, 93, 77, 79, 19, 45, 92, 6, 35, 61, 208, 0, 93, 89, 320, 22, 29, 31, 0, 37, 56, 75, 91, 64, 8, 86, 38], [2, 0, 0, 3, 2, 6, 0, 0, 0, 0, 0, 0, 3, 8, 0, 0, 0, 0, 7, 1, 2, 2, 0, 0, 20, 5, 3, 0, 6, 11, 0, 0, 4, 6, 4, 0, 18, 4, 0, 5, 0, 6, 6, 4, 2, 1, 2, 1, 8, 25, 30, 5, 3, 2, 12, 2, 2, 0, 0, 1, 122, 12, 0, 4, 0, 2, 6, 0, 2, 0, 0, 0, 24, 16, 6, 14, 4, 2, 40, 2, 12, 6, 14, 1, 63, 198, 0, 9, 1, 2, 10, 0, 4, 0, 8, 0, 0, 0, 18, 2, 2, 1, 0, 0, 2, 0, 0, 0, 2, 18, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 15, 2, 0, 0, 0, 2, 2, 0, 1, 0, 0, 0, 4, 6, 2, 1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 18, 0, 7, 0, 2, 2, 0, 0, 0, 0, 3, 3, 6, 0, 4, 2, 0, 0, 0, 0, 0, 0, 0, 12, 0, 2, 10, 2, 2, 0, 4, 0, 0, 0, 0, 4, 261, 2, 4, 1, 0, 0, 3, 0, 0, 0, 0, 32, 18, 16, 23, 33, 32, 14, 63, 59, 18, 16, 32, 12, 37, 26, 41, 10, 13, 24, 38, 106, 49, 8, 30, 16, 14, 13, 21, 0, 20, 6, 47, 17, 52, 30, 16, 9, 18, 25, 25, 0, 15, 18, 16, 9, 37, 21, 28, 31, 57, 51, 28, 55, 43, 22, 20, 24, 34, 12, 24, 51, 137, 60, 64, 66, 90, 55, 41, 20, 16, 13, 16, 36, 51, 55, 86, 24, 32, 55, 35, 22, 12, 39, 24, 32, 36, 61, 38, 75, 44, 42, 22, 26, 16, 14, 30, 0, 35, 18, 32, 46, 35, 32, 60, 24, 25, 5, 12, 23, 35, 76, 22, 30, 52, 33, 35, 40, 34, 28, 6, 19, 4, 66, 10, 18, 25, 60, 20, 2, 15, 51, 0, 58, 1, 34, 19, 26, 17, 0, 14, 0, 16, 6, 22, 36, 32, 13, 11, 50, 99, 14, 21, 26, 14, 22, 13, 24, 35, 10, 23, 22, 20, 16, 39, 24, 14, 15, 25, 38, 19, 20, 28, 12, 18, 47, 9, 22, 76, 26, 14, 22, 74, 55, 5, 0, 25, 28, 16, 32, 20, 20, 59, 42, 30, 26, 15, 1, 20, 22, 5, 154, 13, 35, 76, 62, 31, 53, 21, 0, 41, 20, 38, 28, 9, 22, 38, 20, 46, 25, 14, 0, 54, 5, 14, 66, 27, 188, 26, 0, 75, 4, 30, 0, 20, 41, 15, 117, 108, 98, 38, 59, 42, 45, 7, 0, 12, 26, 6, 134, 18, 50, 57, 75, 1, 48, 9, 0, 38, 33, 13, 13, 8, 26, 6, 0, 0, 0, 0, 34, 0, 59, 2, 46, 0, 26, 0, 24, 2, 13, 58, 31, 0, 37, 98, 39, 0, 28, 0, 87, 14, 48, 0, 58, 0, 108, 0, 28, 0, 36, 16, 80, 42, 23, 0, 26, 46, 43, 26, 36, 14, 28, 77, 16, 24, 91, 19, 2, 110, 179, 42, 80, 8, 21, 1, 47, 30, 32, 10, 18, 43, 0, 36, 25, 24, 32, 17, 37, 0, 40, 53, 0, 20, 26, 57, 0, 36, 40, 154, 6, 44, 36, 2, 20, 41, 40, 79, 49, 9, 61, 21], [39, 6, 0, 0, 3, 15, 0, 4, 3, 7, 5, 2, 7, 22, 4, 2, 7, 0, 14, 0, 8, 4, 3, 1, 4, 22, 5, 0, 9, 54, 3, 9, 12, 18, 18, 2, 53, 2, 8, 14, 6, 8, 30, 12, 12, 9, 5, 1, 51, 43, 89, 28, 21, 3, 24, 17, 0, 6, 6, 3, 120, 51, 10, 43, 0, 6, 5, 2, 7, 6, 0, 0, 14, 22, 10, 35, 6, 8, 98, 2, 58, 8, 12, 3, 109, 306, 7, 40, 1, 2, 24, 1, 8, 0, 3, 1, 4, 1, 33, 13, 7, 0, 0, 2, 4, 3, 0, 1, 6, 41, 0, 9, 1, 7, 1, 0, 0, 3, 0, 0, 0, 12, 8, 1, 1, 3, 1, 0, 0, 2, 2, 1, 6, 2, 12, 2, 0, 2, 0, 1, 1, 1, 1, 1, 2, 17, 7, 6, 1, 9, 1, 0, 9, 0, 1, 1, 0, 2, 5, 3, 0, 1, 0, 2, 0, 2, 4, 0, 24, 0, 4, 19, 21, 0, 14, 0, 2, 0, 1, 1, 5, 271, 1, 5, 4, 0, 0, 3, 0, 0, 1, 1, 62, 132, 56, 37, 95, 87, 2, 100, 124, 74, 83, 52, 39, 101, 53, 59, 29, 41, 94, 82, 158, 53, 28, 70, 56, 55, 87, 38, 4, 51, 20, 99, 43, 96, 44, 33, 22, 38, 22, 37, 0, 30, 85, 64, 23, 94, 53, 148, 108, 110, 77, 75, 129, 92, 66, 134, 6, 104, 64, 57, 104, 136, 80, 120, 106, 196, 68, 95, 52, 46, 37, 46, 111, 76, 117, 123, 56, 38, 80, 110, 58, 33, 95, 35, 59, 82, 131, 76, 164, 93, 91, 96, 76, 18, 38, 77, 18, 100, 32, 62, 92, 72, 73, 93, 50, 68, 24, 49, 48, 73, 178, 61, 59, 97, 68, 121, 61, 52, 43, 32, 61, 3, 68, 28, 58, 105, 93, 60, 0, 79, 86, 2, 124, 88, 132, 57, 57, 72, 0, 31, 3, 36, 24, 54, 46, 58, 98, 62, 14, 105, 57, 73, 42, 41, 65, 47, 49, 69, 29, 48, 59, 50, 38, 61, 48, 21, 20, 102, 77, 80, 21, 117, 24, 74, 106, 40, 30, 217, 78, 63, 53, 208, 100, 29, 0, 82, 106, 58, 18, 66, 70, 213, 115, 36, 96, 27, 1, 47, 85, 21, 276, 50, 123, 147, 89, 62, 129, 41, 2, 121, 56, 115, 55, 33, 139, 95, 47, 94, 52, 23, 0, 148, 56, 84, 185, 84, 236, 67, 2, 178, 22, 72, 2, 26, 97, 71, 327, 204, 192, 153, 134, 90, 116, 57, 0, 38, 84, 29, 355, 58, 183, 119, 61, 0, 101, 51, 2, 58, 153, 39, 78, 29, 71, 14, 0, 0, 0, 0, 22, 0, 64, 20, 28, 0, 32, 0, 35, 0, 12, 51, 28, 0, 38, 45, 45, 0, 38, 0, 58, 17, 34, 0, 58, 0, 62, 0, 34, 0, 29, 40, 57, 42, 23, 0, 29, 36, 44, 36, 51, 30, 19, 53, 17, 25, 67, 19, 1, 81, 128, 43, 72, 11, 74, 2, 33, 21, 2, 25, 14, 48, 3, 18, 12, 14, 29, 36, 17, 6, 16, 38, 5, 12, 24, 69, 0, 33, 28, 238, 7, 24, 36, 0, 10, 42, 67, 89, 35, 7, 71, 16], [44, 8, 0, 0, 2, 3, 0, 0, 0, 5, 0, 3, 17, 32, 3, 14, 5, 3, 14, 6, 30, 3, 1, 0, 8, 42, 10, 3, 11, 54, 0, 1, 25, 14, 12, 0, 65, 9, 10, 30, 8, 10, 26, 15, 16, 2, 14, 0, 86, 107, 183, 11, 38, 11, 65, 17, 12, 9, 7, 0, 206, 53, 5, 48, 0, 4, 12, 3, 8, 5, 0, 1, 21, 26, 15, 47, 7, 14, 153, 1, 35, 7, 12, 0, 103, 360, 10, 30, 0, 2, 31, 0, 15, 0, 21, 0, 0, 0, 3, 68, 28, 0, 0, 0, 1, 2, 3, 3, 22, 16, 0, 12, 2, 3, 8, 2, 0, 9, 1, 3, 4, 43, 2, 0, 6, 18, 3, 9, 3, 0, 3, 1, 48, 22, 16, 20, 2, 1, 0, 7, 19, 0, 1, 2, 0, 75, 40, 0, 6, 5, 0, 5, 18, 3, 2, 4, 0, 1, 24, 48, 1, 6, 0, 3, 1, 1, 0, 0, 12, 5, 7, 1, 15, 2, 1, 6, 12, 0, 1, 0, 14, 263, 6, 33, 41, 3, 12, 5, 0, 0, 2, 0, 143, 162, 115, 61, 106, 118, 0, 158, 205, 75, 83, 84, 46, 120, 72, 135, 55, 59, 85, 142, 271, 109, 66, 106, 81, 70, 109, 52, 2, 87, 31, 141, 39, 103, 70, 57, 21, 35, 55, 97, 1, 57, 91, 64, 33, 149, 70, 238, 168, 226, 147, 114, 209, 178, 133, 198, 8, 89, 69, 97, 193, 359, 169, 203, 240, 396, 168, 163, 54, 41, 37, 79, 134, 133, 145, 202, 114, 98, 120, 201, 65, 66, 117, 61, 97, 100, 191, 151, 204, 136, 150, 109, 133, 42, 49, 158, 10, 158, 48, 94, 138, 106, 100, 148, 94, 102, 18, 49, 86, 125, 223, 60, 107, 156, 121, 160, 111, 66, 46, 44, 78, 2, 103, 49, 110, 110, 122, 102, 2, 75, 150, 0, 170, 69, 129, 57, 68, 71, 0, 26, 2, 46, 23, 75, 94, 96, 163, 56, 8, 178, 79, 132, 79, 65, 95, 48, 44, 129, 40, 77, 68, 56, 71, 65, 55, 20, 45, 112, 87, 95, 32, 99, 42, 101, 154, 21, 33, 210, 159, 98, 62, 266, 163, 25, 0, 68, 102, 49, 21, 49, 35, 271, 108, 88, 94, 40, 0, 65, 61, 37, 454, 52, 134, 182, 170, 99, 161, 29, 0, 123, 63, 83, 78, 34, 219, 106, 37, 82, 109, 26, 1, 122, 49, 75, 160, 105, 248, 59, 2, 226, 36, 60, 0, 23, 81, 55, 332, 211, 224, 150, 142, 92, 111, 40, 1, 54, 109, 38, 443, 49, 202, 94, 145, 3, 90, 56, 1, 51, 98, 40, 60, 41, 112, 18, 1, 1, 0, 0, 57, 0, 100, 18, 41, 0, 53, 0, 41, 0, 18, 62, 27, 0, 41, 99, 58, 0, 41, 1, 85, 16, 53, 0, 84, 0, 104, 0, 39, 0, 34, 42, 91, 51, 25, 0, 25, 58, 55, 31, 55, 23, 48, 81, 26, 37, 94, 44, 0, 152, 261, 75, 84, 25, 74, 0, 72, 50, 10, 18, 19, 42, 3, 30, 28, 50, 35, 48, 48, 0, 47, 73, 3, 30, 36, 113, 1, 57, 38, 151, 5, 56, 53, 0, 18, 52, 87, 133, 43, 10, 88, 23], [25, 7, 0, 0, 5, 8, 1, 0, 0, 1, 3, 0, 11, 6, 3, 1, 4, 0, 9, 0, 14, 4, 0, 0, 52, 18, 5, 0, 2, 21, 0, 2, 12, 11, 4, 0, 41, 4, 3, 8, 6, 8, 13, 6, 6, 2, 5, 0, 45, 22, 106, 8, 17, 7, 36, 12, 6, 4, 5, 0, 147, 31, 6, 16, 0, 2, 7, 3, 1, 3, 3, 0, 24, 16, 8, 27, 1, 3, 90, 3, 28, 0, 10, 0, 63, 249, 4, 13, 0, 0, 23, 0, 7, 0, 21, 0, 4, 0, 30, 11, 19, 1, 3, 0, 5, 1, 0, 0, 5, 20, 0, 1, 4, 0, 5, 1, 3, 4, 3, 1, 22, 26, 2, 0, 3, 4, 0, 1, 3, 2, 0, 2, 18, 4, 4, 7, 2, 0, 1, 1, 3, 1, 1, 0, 0, 11, 25, 5, 3, 4, 0, 1, 1, 0, 0, 2, 0, 11, 6, 21, 0, 1, 0, 1, 2, 7, 1, 0, 14, 0, 4, 32, 14, 0, 7, 2, 6, 3, 2, 0, 5, 307, 2, 16, 33, 1, 7, 2, 0, 1, 3, 0, 82, 55, 52, 27, 58, 67, 42, 93, 135, 60, 47, 39, 18, 53, 42, 50, 18, 40, 56, 66, 144, 50, 28, 63, 47, 33, 56, 30, 1, 39, 20, 84, 32, 66, 50, 39, 21, 25, 36, 64, 1, 24, 63, 49, 22, 76, 43, 65, 96, 116, 65, 78, 127, 89, 67, 111, 68, 63, 32, 44, 101, 167, 92, 132, 124, 172, 83, 95, 25, 24, 20, 43, 57, 74, 72, 107, 60, 45, 87, 86, 48, 42, 76, 46, 59, 63, 101, 83, 125, 78, 56, 70, 48, 28, 29, 92, 4, 103, 23, 62, 63, 65, 84, 81, 63, 51, 27, 33, 48, 68, 134, 50, 58, 95, 97, 114, 73, 57, 37, 34, 52, 3, 76, 21, 84, 102, 114, 66, 12, 56, 88, 0, 121, 16, 88, 30, 63, 73, 8, 31, 0, 31, 24, 41, 39, 36, 46, 25, 66, 79, 35, 53, 64, 29, 38, 40, 25, 58, 23, 55, 49, 35, 33, 38, 52, 14, 26, 67, 50, 44, 36, 47, 28, 53, 92, 25, 23, 174, 77, 15, 60, 164, 101, 22, 0, 50, 55, 39, 107, 38, 27, 164, 65, 64, 38, 35, 0, 38, 30, 19, 186, 27, 66, 90, 72, 61, 125, 31, 0, 61, 48, 58, 59, 15, 137, 70, 24, 78, 57, 25, 0, 76, 38, 51, 100, 69, 185, 43, 1, 157, 21, 66, 0, 19, 47, 56, 212, 176, 176, 117, 121, 83, 81, 52, 0, 41, 84, 30, 299, 39, 106, 88, 86, 1, 82, 38, 0, 56, 81, 29, 23, 32, 42, 9, 0, 4, 0, 0, 42, 0, 79, 12, 64, 0, 49, 0, 28, 0, 28, 67, 27, 2, 22, 99, 41, 0, 28, 0, 88, 13, 58, 0, 69, 0, 113, 1, 34, 0, 26, 40, 79, 41, 34, 0, 32, 70, 77, 29, 67, 22, 49, 96, 38, 15, 89, 34, 0, 114, 174, 63, 104, 12, 30, 1, 45, 58, 24, 33, 17, 54, 1, 31, 32, 46, 33, 38, 41, 3, 36, 48, 1, 22, 25, 89, 0, 50, 32, 173, 1, 41, 46, 0, 31, 37, 91, 91, 39, 11, 88, 24], [19, 1, 0, 1, 6, 13, 6, 0, 1, 2, 2, 0, 6, 6, 2, 2, 15, 2, 16, 0, 10, 0, 0, 0, 2, 26, 3, 2, 3, 42, 1, 2, 19, 8, 2, 2, 40, 5, 1, 9, 2, 3, 16, 2, 14, 6, 6, 1, 26, 30, 82, 14, 23, 9, 32, 7, 4, 2, 8, 0, 171, 37, 4, 38, 0, 5, 8, 10, 0, 19, 0, 1, 30, 20, 16, 32, 5, 8, 104, 2, 63, 8, 16, 4, 74, 275, 4, 34, 0, 3, 22, 0, 11, 0, 20, 2, 4, 1, 14, 27, 18, 0, 12, 0, 0, 0, 4, 2, 2, 25, 0, 6, 1, 0, 2, 0, 4, 2, 1, 2, 0, 15, 2, 0, 0, 2, 0, 0, 1, 2, 2, 0, 9, 11, 6, 4, 0, 2, 0, 0, 8, 2, 0, 0, 0, 12, 9, 10, 0, 7, 1, 0, 14, 1, 0, 2, 1, 11, 0, 21, 0, 0, 0, 0, 0, 4, 4, 0, 31, 5, 8, 21, 15, 0, 14, 8, 0, 2, 1, 0, 3, 221, 13, 22, 8, 2, 4, 3, 0, 0, 2, 0, 80, 55, 41, 21, 40, 67, 108, 87, 165, 51, 61, 27, 5, 55, 36, 62, 18, 8, 48, 56, 166, 47, 26, 24, 24, 18, 47, 32, 2, 40, 2, 102, 18, 76, 74, 64, 12, 40, 61, 62, 1, 16, 45, 40, 21, 87, 16, 53, 75, 93, 86, 53, 129, 108, 79, 117, 13, 75, 40, 38, 82, 141, 68, 95, 79, 129, 105, 75, 30, 17, 32, 32, 74, 87, 97, 143, 70, 66, 96, 60, 52, 56, 55, 23, 58, 50, 66, 59, 163, 68, 78, 103, 71, 7, 27, 68, 1, 47, 23, 84, 79, 97, 126, 104, 78, 96, 45, 74, 94, 79, 101, 62, 38, 139, 97, 104, 55, 71, 57, 44, 57, 0, 71, 17, 124, 48, 148, 46, 54, 14, 99, 0, 131, 48, 75, 50, 42, 68, 74, 8, 0, 49, 17, 37, 27, 10, 25, 42, 12, 111, 79, 24, 96, 16, 56, 32, 18, 60, 15, 46, 19, 7, 48, 35, 41, 28, 22, 32, 71, 56, 63, 53, 22, 24, 93, 42, 54, 78, 49, 12, 56, 107, 86, 14, 0, 77, 77, 18, 25, 27, 24, 157, 58, 59, 59, 8, 0, 68, 28, 21, 172, 58, 126, 137, 69, 38, 129, 34, 1, 58, 42, 63, 56, 37, 116, 46, 46, 66, 46, 18, 1, 106, 46, 42, 110, 93, 277, 52, 0, 71, 22, 55, 1, 26, 90, 51, 375, 220, 398, 50, 115, 73, 85, 62, 0, 97, 64, 24, 266, 100, 199, 148, 163, 0, 62, 39, 0, 85, 86, 24, 9, 21, 46, 5, 0, 60, 0, 0, 52, 0, 75, 20, 42, 0, 27, 0, 21, 0, 18, 38, 39, 0, 37, 70, 39, 0, 23, 0, 66, 12, 68, 0, 63, 0, 97, 0, 38, 0, 45, 50, 96, 64, 20, 0, 32, 81, 84, 32, 52, 30, 49, 64, 14, 10, 70, 22, 0, 98, 151, 61, 58, 7, 36, 0, 51, 61, 0, 21, 8, 45, 6, 32, 21, 20, 25, 34, 35, 3, 26, 51, 2, 22, 28, 88, 0, 24, 28, 169, 4, 56, 40, 0, 79, 34, 71, 98, 57, 15, 77, 18], [15, 2, 0, 0, 0, 2, 0, 0, 0, 3, 1, 0, 3, 8, 4, 5, 3, 4, 10, 3, 4, 3, 0, 0, 1, 9, 2, 0, 6, 13, 0, 0, 10, 13, 2, 0, 17, 4, 5, 15, 3, 7, 6, 5, 7, 4, 1, 0, 30, 31, 74, 6, 19, 2, 13, 6, 5, 0, 2, 0, 108, 30, 9, 11, 0, 0, 5, 4, 1, 7, 1, 0, 21, 13, 3, 18, 2, 8, 54, 0, 14, 4, 5, 0, 53, 170, 4, 8, 0, 1, 19, 0, 5, 0, 9, 0, 3, 0, 11, 0, 1, 3, 0, 0, 3, 0, 0, 0, 1, 13, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 4, 0, 0, 0, 1, 0, 3, 0, 0, 0, 0, 0, 4, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 4, 0, 3, 1, 0, 3, 0, 0, 0, 0, 8, 1, 1, 0, 1, 0, 0, 0, 1, 2, 0, 6, 0, 1, 8, 12, 0, 2, 3, 1, 0, 0, 0, 0, 157, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 56, 75, 23, 38, 35, 56, 1, 66, 90, 33, 24, 29, 11, 36, 38, 37, 18, 19, 47, 51, 78, 32, 17, 27, 22, 20, 37, 23, 1, 30, 8, 55, 28, 42, 25, 24, 10, 23, 26, 36, 2, 21, 45, 23, 10, 67, 23, 115, 94, 92, 38, 51, 84, 73, 75, 82, 5, 31, 17, 37, 79, 127, 52, 74, 98, 140, 60, 50, 20, 20, 11, 19, 75, 56, 61, 102, 32, 37, 51, 56, 28, 28, 63, 24, 34, 48, 71, 73, 119, 56, 54, 48, 58, 12, 18, 65, 4, 57, 9, 43, 59, 50, 53, 70, 69, 36, 7, 21, 53, 45, 126, 41, 40, 69, 60, 48, 55, 33, 19, 24, 28, 5, 45, 22, 62, 45, 59, 52, 0, 29, 51, 0, 98, 40, 50, 38, 50, 43, 0, 21, 0, 18, 10, 35, 28, 27, 53, 17, 9, 71, 21, 43, 23, 18, 35, 28, 14, 53, 12, 42, 31, 18, 19, 27, 25, 14, 11, 38, 31, 36, 11, 48, 14, 38, 71, 19, 13, 119, 92, 25, 23, 135, 73, 9, 0, 46, 40, 34, 4, 24, 21, 157, 43, 26, 57, 24, 0, 19, 30, 26, 181, 23, 69, 88, 92, 48, 89, 25, 0, 43, 23, 54, 47, 12, 86, 59, 29, 54, 27, 12, 0, 56, 35, 27, 79, 58, 139, 36, 0, 109, 10, 45, 0, 12, 48, 39, 189, 159, 155, 90, 93, 64, 43, 27, 0, 51, 50, 23, 205, 43, 102, 75, 79, 1, 59, 29, 0, 46, 76, 21, 31, 19, 23, 13, 1, 0, 0, 0, 15, 0, 41, 7, 22, 0, 22, 0, 13, 0, 4, 26, 21, 0, 17, 35, 16, 0, 15, 0, 39, 5, 33, 0, 42, 0, 44, 0, 14, 0, 25, 19, 34, 30, 12, 0, 19, 38, 34, 12, 37, 4, 21, 48, 19, 27, 40, 13, 0, 76, 85, 36, 34, 7, 40, 4, 27, 24, 0, 1, 13, 21, 1, 13, 17, 18, 20, 10, 20, 1, 18, 18, 0, 12, 20, 44, 0, 29, 26, 84, 0, 17, 15, 0, 12, 29, 52, 55, 35, 2, 68, 7], [15, 1, 0, 1, 1, 11, 1, 0, 0, 0, 3, 0, 5, 9, 1, 0, 0, 0, 22, 0, 7, 0, 0, 0, 31, 9, 6, 1, 4, 20, 1, 3, 11, 16, 3, 0, 34, 2, 3, 19, 5, 4, 17, 5, 5, 3, 5, 0, 30, 34, 74, 17, 10, 2, 14, 6, 3, 0, 2, 0, 102, 29, 10, 35, 1, 2, 2, 1, 2, 5, 0, 0, 16, 14, 6, 14, 0, 6, 87, 0, 25, 2, 4, 0, 58, 191, 2, 18, 0, 0, 16, 0, 10, 0, 8, 0, 0, 0, 8, 37, 15, 0, 1, 0, 3, 1, 1, 1, 10, 19, 0, 3, 0, 0, 4, 3, 1, 1, 0, 1, 13, 24, 1, 0, 5, 9, 0, 1, 1, 2, 2, 0, 13, 10, 7, 12, 1, 0, 0, 3, 4, 2, 1, 0, 0, 49, 15, 3, 5, 0, 6, 0, 16, 4, 0, 0, 0, 5, 5, 18, 0, 4, 0, 1, 3, 1, 2, 0, 8, 1, 10, 19, 7, 1, 2, 1, 3, 1, 2, 0, 6, 168, 8, 26, 15, 1, 3, 2, 0, 0, 4, 0, 58, 40, 42, 21, 44, 46, 9, 59, 95, 45, 26, 42, 11, 50, 34, 49, 27, 16, 30, 62, 129, 40, 34, 43, 42, 23, 68, 27, 0, 34, 9, 61, 25, 61, 45, 31, 24, 25, 17, 49, 0, 21, 41, 26, 13, 71, 32, 39, 61, 75, 77, 53, 136, 83, 54, 92, 48, 70, 36, 44, 96, 127, 65, 94, 91, 189, 66, 50, 23, 24, 21, 31, 86, 56, 65, 130, 40, 30, 71, 86, 45, 30, 57, 30, 20, 46, 93, 69, 115, 59, 74, 60, 59, 23, 35, 42, 7, 54, 34, 44, 57, 48, 64, 53, 60, 41, 10, 33, 53, 37, 120, 30, 29, 62, 56, 62, 57, 32, 21, 29, 31, 6, 54, 27, 71, 37, 72, 59, 6, 35, 76, 0, 101, 20, 76, 35, 41, 47, 6, 21, 0, 25, 12, 42, 40, 30, 24, 36, 67, 93, 34, 35, 36, 27, 52, 35, 29, 62, 26, 28, 37, 28, 46, 61, 28, 21, 23, 53, 53, 60, 20, 52, 19, 57, 87, 28, 27, 143, 51, 12, 24, 105, 77, 16, 0, 50, 48, 35, 75, 25, 29, 135, 73, 46, 63, 36, 0, 29, 27, 24, 188, 27, 87, 112, 109, 69, 101, 13, 0, 89, 31, 75, 58, 18, 126, 55, 9, 52, 59, 20, 0, 51, 34, 33, 83, 74, 212, 33, 3, 122, 13, 60, 0, 21, 61, 38, 186, 174, 154, 100, 95, 79, 67, 34, 0, 53, 71, 25, 234, 38, 144, 94, 104, 2, 53, 24, 1, 51, 66, 28, 15, 21, 50, 8, 0, 0, 0, 0, 16, 0, 40, 3, 16, 0, 24, 0, 15, 0, 10, 23, 11, 0, 18, 49, 22, 0, 18, 0, 32, 3, 33, 0, 29, 1, 47, 0, 11, 0, 12, 19, 30, 18, 22, 0, 11, 28, 24, 11, 28, 8, 17, 31, 11, 7, 41, 12, 0, 51, 102, 26, 46, 9, 12, 1, 34, 25, 12, 12, 6, 20, 0, 21, 13, 19, 19, 23, 18, 1, 20, 28, 0, 21, 15, 48, 0, 27, 17, 87, 0, 20, 23, 1, 14, 22, 41, 59, 34, 5, 38, 12], [536, 47, 0, 9, 33, 64, 0, 1, 0, 46, 5, 1, 102, 108, 37, 40, 29, 12, 149, 9, 155, 52, 2, 0, 26, 231, 44, 17, 31, 383, 11, 32, 150, 152, 154, 0, 475, 43, 95, 98, 49, 29, 155, 80, 78, 30, 69, 0, 592, 298, 813, 116, 173, 55, 291, 167, 67, 42, 48, 0, 915, 404, 83, 162, 1, 25, 72, 52, 7, 39, 6, 0, 60, 88, 38, 101, 18, 31, 426, 7, 111, 29, 24, 0, 290, 828, 18, 64, 1, 1, 80, 0, 51, 1, 59, 0, 16, 4, 314, 610, 552, 3, 0, 0, 8, 11, 18, 27, 191, 321, 0, 26, 18, 28, 93, 63, 13, 61, 41, 18, 16, 409, 31, 4, 65, 67, 14, 12, 14, 11, 13, 23, 288, 233, 104, 79, 2, 19, 12, 24, 67, 6, 10, 5, 1, 339, 318, 59, 33, 22, 28, 45, 112, 49, 15, 15, 1, 64, 98, 395, 5, 55, 8, 11, 17, 3, 5, 0, 86, 7, 47, 55, 39, 14, 6, 8, 23, 4, 6, 0, 43, 1045, 19, 92, 83, 0, 15, 17, 1, 0, 9, 1, 1017, 649, 393, 310, 837, 301, 3, 1186, 389, 479, 654, 581, 536, 910, 609, 636, 313, 389, 394, 649, 635, 749, 351, 579, 513, 469, 845, 417, 31, 575, 268, 1023, 374, 333, 215, 150, 86, 141, 159, 259, 9, 143, 695, 207, 100, 763, 445, 847, 842, 759, 637, 704, 960, 788, 555, 1113, 46, 684, 412, 540, 880, 1494, 770, 1086, 1317, 1280, 1007, 734, 321, 326, 329, 211, 679, 624, 814, 1230, 474, 452, 553, 968, 319, 211, 699, 409, 451, 450, 1083, 717, 1191, 724, 813, 684, 532, 225, 480, 613, 88, 598, 350, 469, 381, 334, 441, 325, 264, 260, 38, 171, 186, 246, 657, 201, 290, 390, 305, 404, 215, 188, 246, 103, 267, 14, 348, 137, 285, 277, 270, 304, 0, 800, 403, 0, 1095, 269, 444, 327, 952, 266, 2, 471, 1, 288, 390, 458, 429, 434, 572, 555, 66, 991, 534, 609, 195, 350, 590, 447, 511, 531, 267, 500, 320, 422, 563, 588, 398, 195, 295, 499, 253, 213, 107, 309, 122, 229, 888, 160, 130, 1101, 728, 194, 415, 1388, 1019, 300, 1, 710, 722, 380, 85, 587, 437, 1316, 577, 488, 664, 393, 3, 326, 597, 275, 1277, 323, 889, 802, 782, 544, 723, 300, 0, 862, 523, 717, 506, 125, 652, 689, 179, 570, 499, 243, 1, 780, 413, 366, 1180, 711, 991, 230, 35, 851, 332, 595, 0, 151, 321, 209, 924, 573, 553, 486, 495, 392, 356, 226, 1, 186, 279, 130, 1204, 206, 686, 459, 424, 5, 324, 126, 0, 183, 207, 665, 377, 324, 680, 60, 0, 4, 0, 0, 120, 0, 394, 86, 279, 0, 248, 0, 128, 1, 79, 290, 141, 1, 161, 231, 190, 0, 183, 1, 257, 73, 216, 1, 215, 0, 384, 1, 126, 0, 83, 108, 125, 106, 73, 1, 50, 164, 130, 68, 131, 49, 85, 113, 120, 109, 397, 171, 3, 825, 551, 294, 293, 106, 285, 5, 383, 288, 17, 132, 110, 237, 16, 183, 121, 203, 193, 135, 169, 9, 109, 194, 12, 97, 128, 440, 2, 234, 211, 263, 61, 119, 68, 0, 48, 92, 160, 226, 127, 17, 199, 68], [822, 50, 9, 24, 78, 107, 1, 13, 15, 76, 27, 24, 126, 139, 45, 42, 65, 56, 295, 18, 282, 52, 15, 9, 68, 276, 93, 27, 113, 519, 13, 65, 176, 214, 157, 5, 566, 47, 108, 168, 110, 60, 154, 188, 94, 41, 151, 5, 994, 519, 1608, 219, 269, 92, 412, 397, 118, 86, 101, 11, 923, 631, 143, 306, 13, 47, 171, 107, 19, 66, 13, 13, 119, 143, 41, 211, 28, 59, 578, 12, 156, 36, 50, 15, 323, 1253, 54, 130, 26, 4, 155, 22, 60, 17, 73, 23, 41, 11, 448, 752, 672, 13, 4, 7, 20, 14, 28, 36, 252, 437, 4, 60, 14, 33, 103, 108, 18, 67, 21, 21, 14, 519, 45, 7, 137, 118, 58, 55, 45, 3, 49, 7, 356, 335, 98, 83, 1, 22, 23, 31, 70, 5, 18, 6, 41, 593, 523, 99, 44, 40, 71, 39, 129, 94, 38, 64, 17, 89, 189, 439, 10, 35, 24, 61, 41, 14, 15, 5, 99, 33, 41, 115, 58, 18, 25, 10, 31, 9, 12, 0, 73, 1438, 19, 114, 182, 2, 24, 34, 6, 0, 27, 0, 1620, 780, 818, 498, 1340, 399, 9, 1822, 705, 787, 923, 875, 487, 1176, 751, 851, 433, 560, 632, 898, 715, 815, 442, 1091, 829, 979, 1485, 714, 48, 799, 495, 1435, 541, 479, 251, 332, 167, 184, 281, 415, 6, 200, 1011, 276, 157, 1022, 533, 987, 1250, 1104, 909, 1061, 1625, 1124, 901, 2077, 65, 1280, 624, 892, 1821, 1744, 1186, 1780, 2009, 1922, 1493, 1521, 444, 494, 497, 368, 1047, 960, 969, 1799, 583, 695, 1142, 1838, 758, 464, 1500, 535, 815, 826, 2146, 1640, 2095, 1314, 1499, 1276, 1026, 507, 601, 1001, 176, 1329, 737, 796, 536, 558, 613, 483, 380, 374, 96, 321, 412, 389, 913, 327, 375, 612, 466, 544, 377, 310, 307, 241, 407, 14, 331, 182, 485, 406, 499, 495, 2, 1290, 691, 7, 1783, 434, 1141, 564, 1457, 325, 0, 623, 25, 439, 456, 823, 750, 639, 759, 707, 118, 1575, 794, 807, 217, 608, 706, 919, 699, 664, 445, 884, 533, 649, 863, 922, 656, 436, 465, 1033, 447, 356, 205, 483, 181, 406, 1024, 258, 169, 1443, 690, 272, 656, 2004, 1348, 444, 2, 825, 1050, 688, 118, 731, 525, 1853, 1187, 844, 918, 593, 18, 539, 895, 584, 1721, 641, 1276, 986, 1245, 706, 1413, 583, 8, 1457, 699, 1313, 1000, 201, 1166, 1141, 511, 938, 1270, 568, 4, 1367, 803, 927, 1820, 1045, 1510, 664, 70, 1892, 586, 932, 8, 224, 611, 322, 1429, 953, 931, 771, 809, 572, 648, 304, 4, 299, 499, 182, 1595, 307, 931, 624, 876, 4, 461, 259, 5, 386, 426, 1119, 496, 630, 891, 97, 4, 2, 0, 0, 141, 0, 449, 108, 354, 1, 277, 0, 277, 4, 139, 427, 195, 0, 204, 292, 256, 0, 233, 2, 443, 104, 287, 3, 311, 0, 514, 2, 198, 0, 100, 147, 206, 134, 71, 2, 94, 156, 167, 81, 180, 51, 127, 162, 150, 145, 676, 244, 5, 951, 634, 345, 511, 95, 314, 21, 452, 400, 22, 200, 161, 353, 36, 255, 147, 263, 227, 162, 197, 40, 198, 277, 13, 178, 169, 444, 5, 337, 230, 504, 105, 119, 116, 0, 68, 142, 180, 278, 129, 45, 247, 55], [59, 27, 0, 3, 2, 41, 1, 0, 0, 13, 9, 0, 20, 60, 13, 14, 25, 14, 66, 2, 65, 13, 3, 0, 35, 62, 26, 6, 24, 136, 1, 16, 57, 68, 39, 0, 134, 25, 24, 58, 23, 17, 52, 33, 32, 7, 33, 0, 197, 196, 434, 47, 79, 11, 125, 38, 17, 20, 23, 0, 505, 142, 32, 125, 0, 18, 36, 19, 14, 38, 0, 0, 68, 60, 29, 92, 19, 34, 292, 3, 83, 16, 23, 0, 210, 698, 14, 63, 0, 0, 68, 0, 37, 0, 53, 0, 1, 0, 80, 204, 65, 3, 1, 0, 11, 9, 20, 6, 29, 116, 0, 29, 2, 1, 26, 5, 1, 17, 9, 3, 14, 91, 3, 0, 38, 22, 0, 9, 6, 3, 9, 3, 116, 47, 20, 47, 2, 6, 4, 4, 17, 4, 2, 0, 0, 170, 114, 14, 10, 7, 3, 6, 7, 21, 7, 8, 0, 13, 14, 109, 2, 8, 2, 13, 10, 7, 3, 1, 44, 3, 26, 46, 40, 7, 20, 11, 13, 4, 6, 0, 20, 895, 8, 93, 99, 1, 21, 13, 1, 4, 11, 0, 319, 464, 198, 161, 273, 341, 9, 437, 564, 253, 221, 202, 106, 267, 183, 297, 146, 90, 264, 373, 609, 249, 130, 225, 219, 169, 298, 170, 5, 288, 89, 399, 140, 280, 202, 175, 100, 129, 163, 246, 8, 135, 294, 185, 106, 452, 170, 560, 576, 546, 435, 362, 673, 548, 406, 598, 48, 354, 170, 223, 521, 890, 458, 562, 676, 926, 438, 438, 131, 123, 129, 190, 447, 380, 424, 601, 242, 250, 352, 385, 184, 171, 279, 152, 199, 277, 485, 407, 774, 402, 460, 312, 307, 97, 171, 450, 25, 461, 151, 282, 346, 299, 351, 342, 301, 246, 68, 186, 240, 280, 614, 221, 256, 434, 277, 394, 251, 176, 145, 160, 219, 14, 296, 148, 346, 272, 437, 278, 0, 190, 481, 1, 447, 223, 301, 135, 175, 165, 0, 71, 0, 99, 71, 220, 208, 199, 408, 216, 74, 629, 234, 254, 164, 126, 272, 197, 155, 364, 143, 246, 154, 159, 177, 154, 186, 83, 131, 312, 292, 239, 123, 313, 122, 306, 349, 128, 140, 621, 271, 162, 138, 629, 370, 70, 1, 232, 223, 136, 102, 122, 101, 680, 286, 161, 237, 166, 1, 144, 164, 112, 992, 145, 305, 498, 423, 222, 382, 80, 0, 362, 141, 300, 247, 50, 459, 285, 89, 237, 228, 63, 0, 302, 145, 173, 477, 316, 827, 173, 8, 797, 107, 242, 1, 96, 215, 158, 913, 625, 663, 382, 486, 351, 324, 137, 0, 152, 267, 92, 1076, 179, 550, 349, 396, 8, 285, 119, 2, 182, 258, 134, 256, 143, 284, 44, 1, 0, 0, 0, 54, 1, 123, 25, 72, 0, 115, 0, 55, 0, 48, 102, 58, 1, 76, 178, 119, 0, 66, 0, 165, 17, 99, 1, 136, 0, 182, 1, 56, 0, 64, 73, 134, 81, 48, 0, 37, 114, 114, 51, 93, 29, 59, 161, 25, 76, 224, 81, 1, 188, 430, 158, 171, 40, 126, 0, 160, 124, 19, 40, 25, 100, 3, 76, 51, 67, 72, 70, 70, 9, 67, 101, 3, 38, 65, 220, 2, 114, 76, 198, 9, 94, 73, 0, 40, 79, 157, 209, 97, 24, 176, 44], [54, 19, 0, 5, 5, 41, 2, 0, 0, 13, 3, 1, 19, 47, 8, 11, 21, 6, 59, 4, 60, 14, 2, 0, 227, 70, 27, 6, 20, 133, 4, 15, 46, 63, 28, 0, 143, 21, 18, 68, 12, 28, 59, 36, 20, 10, 30, 0, 163, 139, 345, 28, 72, 15, 82, 45, 9, 17, 13, 0, 577, 149, 26, 95, 0, 17, 19, 7, 10, 19, 2, 0, 66, 63, 48, 83, 22, 33, 317, 11, 78, 10, 26, 0, 196, 789, 12, 50, 0, 3, 79, 0, 39, 0, 38, 0, 0, 0, 46, 143, 54, 5, 1, 0, 9, 7, 8, 6, 28, 105, 2, 15, 1, 2, 10, 6, 7, 6, 10, 1, 63, 85, 9, 2, 24, 30, 3, 9, 3, 0, 4, 1, 85, 62, 17, 47, 0, 9, 1, 4, 15, 1, 2, 4, 1, 138, 102, 6, 15, 8, 6, 8, 38, 14, 6, 8, 2, 10, 17, 70, 3, 12, 4, 11, 12, 10, 5, 2, 42, 4, 59, 61, 43, 5, 14, 10, 11, 3, 3, 0, 15, 792, 11, 68, 105, 3, 18, 9, 0, 0, 5, 0, 219, 233, 175, 122, 198, 290, 75, 353, 540, 229, 201, 200, 76, 240, 146, 253, 117, 93, 207, 339, 513, 198, 123, 210, 170, 171, 265, 142, 10, 225, 78, 289, 84, 246, 180, 163, 67, 120, 143, 236, 12, 115, 268, 175, 85, 353, 157, 304, 454, 451, 340, 338, 567, 435, 335, 488, 313, 300, 160, 173, 390, 740, 435, 457, 503, 760, 418, 355, 103, 127, 108, 146, 407, 340, 367, 528, 190, 201, 276, 378, 163, 144, 257, 131, 168, 213, 450, 306, 580, 342, 362, 251, 274, 70, 128, 328, 24, 320, 124, 242, 267, 230, 313, 339, 260, 260, 68, 170, 224, 258, 502, 204, 208, 408, 256, 367, 211, 139, 148, 133, 207, 13, 274, 123, 275, 244, 360, 248, 6, 156, 395, 1, 352, 99, 321, 112, 182, 222, 14, 85, 0, 90, 69, 180, 196, 184, 172, 183, 480, 552, 200, 251, 219, 133, 259, 164, 128, 304, 132, 204, 143, 134, 163, 155, 194, 66, 118, 284, 271, 233, 148, 245, 107, 284, 389, 132, 141, 587, 275, 77, 157, 570, 369, 83, 1, 208, 243, 150, 433, 154, 125, 600, 268, 188, 233, 122, 1, 151, 179, 101, 758, 167, 312, 517, 486, 248, 527, 80, 0, 367, 168, 291, 237, 62, 459, 273, 113, 285, 297, 96, 1, 354, 178, 175, 504, 393, 837, 180, 7, 639, 92, 253, 0, 95, 244, 185, 806, 755, 940, 422, 509, 431, 401, 207, 0, 150, 329, 108, 935, 182, 578, 376, 490, 11, 298, 135, 0, 210, 274, 122, 101, 119, 191, 63, 0, 1, 1, 0, 42, 0, 78, 21, 61, 0, 77, 0, 29, 0, 33, 102, 61, 0, 65, 156, 68, 0, 54, 1, 132, 22, 93, 1, 100, 0, 125, 0, 43, 0, 71, 52, 93, 90, 48, 1, 57, 108, 84, 47, 78, 29, 61, 111, 25, 26, 157, 53, 1, 191, 331, 101, 214, 29, 50, 0, 96, 93, 41, 41, 30, 66, 7, 50, 37, 60, 56, 45, 67, 3, 52, 75, 2, 42, 45, 164, 0, 81, 51, 245, 6, 65, 77, 1, 55, 57, 133, 158, 88, 9, 167, 38], [30, 7, 0, 2, 7, 17, 0, 0, 0, 4, 0, 2, 6, 10, 0, 7, 8, 4, 11, 1, 12, 2, 0, 0, 6, 15, 6, 1, 10, 36, 1, 5, 18, 32, 5, 0, 58, 8, 6, 22, 5, 7, 18, 6, 10, 5, 4, 0, 69, 58, 139, 8, 29, 8, 36, 17, 5, 2, 3, 0, 267, 55, 6, 33, 0, 9, 7, 7, 1, 12, 1, 0, 27, 23, 7, 34, 10, 12, 152, 0, 53, 4, 13, 0, 101, 378, 6, 12, 0, 3, 30, 0, 13, 1, 29, 0, 0, 2, 16, 65, 29, 2, 1, 0, 6, 2, 2, 2, 12, 35, 0, 14, 1, 2, 3, 2, 1, 6, 4, 1, 1, 49, 3, 0, 6, 6, 2, 6, 0, 2, 1, 3, 40, 37, 3, 29, 0, 8, 0, 3, 11, 0, 1, 0, 5, 72, 33, 3, 6, 10, 3, 2, 15, 7, 4, 1, 0, 1, 16, 38, 0, 8, 2, 1, 5, 4, 1, 2, 22, 3, 14, 11, 17, 0, 6, 10, 6, 0, 1, 0, 10, 428, 4, 45, 48, 0, 5, 7, 0, 1, 7, 0, 132, 132, 63, 43, 124, 122, 17, 189, 193, 90, 80, 69, 40, 107, 66, 112, 40, 37, 96, 99, 170, 91, 44, 105, 83, 60, 82, 70, 0, 95, 28, 158, 48, 137, 90, 62, 30, 59, 66, 96, 3, 42, 84, 86, 36, 144, 56, 211, 160, 206, 146, 145, 223, 185, 126, 186, 12, 90, 61, 85, 174, 318, 130, 235, 206, 392, 165, 133, 57, 51, 44, 76, 154, 115, 158, 241, 85, 86, 96, 159, 52, 57, 108, 56, 61, 70, 154, 126, 252, 129, 137, 119, 116, 34, 39, 138, 3, 143, 68, 102, 127, 114, 140, 170, 100, 109, 17, 72, 119, 112, 220, 88, 102, 165, 103, 163, 88, 68, 72, 57, 87, 11, 112, 65, 132, 117, 169, 98, 4, 87, 171, 0, 146, 65, 136, 48, 72, 80, 4, 36, 2, 39, 33, 69, 71, 67, 141, 64, 17, 234, 73, 90, 80, 40, 90, 74, 44, 114, 50, 87, 58, 47, 62, 56, 52, 18, 36, 94, 91, 73, 48, 102, 40, 111, 137, 51, 39, 202, 120, 77, 36, 230, 147, 17, 0, 69, 107, 68, 27, 40, 50, 256, 103, 85, 99, 45, 1, 44, 72, 33, 324, 50, 123, 189, 169, 113, 234, 32, 0, 130, 46, 80, 106, 18, 128, 87, 44, 93, 88, 28, 0, 107, 55, 59, 170, 95, 289, 58, 1, 267, 26, 77, 0, 44, 98, 66, 286, 190, 246, 122, 177, 124, 141, 73, 0, 59, 111, 41, 413, 78, 214, 136, 182, 1, 109, 51, 0, 73, 88, 59, 90, 46, 78, 25, 1, 1, 0, 0, 55, 1, 101, 14, 59, 0, 50, 0, 30, 0, 34, 74, 42, 1, 36, 162, 61, 0, 42, 0, 108, 9, 80, 0, 92, 0, 145, 0, 40, 1, 50, 56, 109, 56, 31, 0, 45, 116, 109, 40, 81, 39, 52, 115, 26, 45, 103, 33, 1, 139, 262, 69, 136, 11, 62, 0, 65, 70, 6, 30, 21, 56, 3, 44, 23, 40, 27, 34, 39, 2, 50, 70, 2, 27, 35, 125, 0, 71, 31, 190, 6, 70, 50, 0, 27, 67, 100, 135, 57, 13, 141, 34], [70, 20, 2, 5, 6, 70, 35, 4, 4, 7, 19, 8, 40, 42, 14, 6, 20, 18, 56, 3, 53, 16, 4, 7, 25, 80, 23, 10, 25, 169, 3, 21, 80, 60, 34, 2, 138, 27, 27, 53, 21, 38, 70, 26, 28, 8, 40, 1, 154, 219, 369, 47, 72, 34, 96, 15, 20, 10, 17, 3, 805, 148, 39, 109, 1, 21, 22, 15, 18, 48, 4, 2, 149, 134, 105, 112, 39, 31, 399, 16, 133, 21, 39, 1, 393, 1192, 33, 103, 2, 7, 127, 4, 43, 7, 90, 2, 1, 1, 84, 205, 103, 5, 22, 0, 17, 9, 25, 11, 41, 152, 1, 15, 3, 3, 20, 8, 4, 12, 12, 3, 10, 86, 12, 0, 28, 18, 3, 13, 3, 4, 14, 1, 188, 84, 28, 70, 6, 7, 3, 2, 27, 5, 6, 1, 3, 142, 103, 9, 18, 8, 5, 7, 33, 9, 7, 8, 3, 23, 21, 111, 0, 9, 5, 4, 22, 19, 7, 2, 88, 8, 126, 65, 71, 12, 23, 18, 28, 4, 11, 2, 40, 1334, 23, 131, 132, 1, 31, 10, 1, 0, 21, 1, 345, 283, 195, 141, 267, 386, 921, 396, 622, 201, 200, 176, 70, 244, 198, 316, 103, 108, 246, 323, 728, 199, 143, 272, 199, 114, 199, 164, 2, 243, 58, 430, 117, 345, 250, 234, 111, 143, 181, 298, 14, 172, 219, 241, 111, 433, 157, 337, 482, 486, 426, 299, 609, 474, 401, 425, 44, 226, 131, 236, 440, 838, 491, 539, 569, 948, 370, 336, 119, 92, 95, 166, 378, 324, 382, 579, 199, 213, 316, 320, 142, 151, 268, 137, 181, 235, 303, 269, 589, 327, 337, 311, 280, 71, 121, 441, 5, 286, 115, 266, 393, 293, 397, 494, 361, 348, 117, 223, 288, 289, 656, 254, 263, 540, 452, 492, 304, 212, 206, 184, 207, 35, 330, 166, 375, 349, 479, 386, 263, 133, 498, 5, 486, 147, 309, 118, 200, 206, 326, 89, 4, 95, 68, 200, 279, 223, 196, 172, 73, 540, 235, 297, 190, 155, 282, 180, 131, 372, 136, 215, 182, 95, 155, 208, 182, 61, 146, 243, 370, 255, 236, 351, 157, 350, 363, 139, 225, 746, 318, 94, 148, 580, 414, 53, 0, 201, 253, 83, 94, 110, 92, 818, 298, 177, 274, 164, 4, 118, 128, 88, 925, 158, 405, 493, 418, 245, 477, 70, 2, 326, 202, 237, 253, 62, 527, 293, 115, 301, 199, 52, 4, 305, 134, 147, 625, 316, 1065, 149, 6, 655, 89, 189, 3, 116, 253, 214, 1123, 849, 1464, 451, 616, 378, 397, 214, 0, 188, 388, 92, 1472, 176, 686, 482, 455, 2, 348, 114, 2, 219, 338, 103, 123, 133, 300, 54, 0, 135, 0, 0, 122, 0, 276, 32, 149, 0, 170, 0, 70, 1, 72, 220, 113, 0, 103, 317, 179, 0, 114, 0, 246, 27, 144, 0, 219, 0, 325, 0, 108, 1, 138, 167, 268, 150, 86, 0, 106, 203, 210, 99, 206, 54, 143, 287, 54, 57, 262, 89, 0, 425, 746, 221, 293, 59, 128, 6, 151, 126, 9, 53, 47, 142, 4, 109, 68, 90, 102, 124, 93, 10, 105, 142, 7, 82, 101, 248, 0, 148, 57, 405, 5, 173, 106, 0, 156, 139, 257, 349, 167, 17, 358, 61], [80, 6, 0, 4, 8, 10, 0, 0, 0, 32, 0, 1, 18, 19, 0, 2, 8, 0, 30, 0, 33, 25, 0, 1, 8, 68, 10, 1, 12, 48, 0, 22, 48, 26, 12, 0, 42, 13, 8, 16, 5, 4, 23, 5, 16, 12, 2, 0, 98, 68, 159, 46, 30, 8, 41, 70, 20, 7, 11, 0, 101, 66, 9, 36, 2, 6, 20, 0, 0, 6, 1, 0, 14, 4, 2, 12, 8, 12, 83, 5, 12, 10, 14, 0, 66, 196, 2, 18, 0, 0, 18, 0, 0, 0, 14, 1, 58, 7, 279, 904, 748, 16, 0, 0, 8, 4, 18, 36, 318, 619, 6, 70, 10, 1, 121, 91, 46, 78, 66, 4, 16, 674, 27, 12, 143, 78, 39, 36, 10, 0, 54, 20, 328, 236, 18, 144, 9, 16, 6, 24, 106, 16, 14, 4, 8, 487, 375, 54, 38, 26, 133, 59, 294, 58, 50, 36, 12, 95, 219, 793, 10, 46, 22, 48, 24, 7, 0, 0, 160, 15, 72, 46, 34, 35, 0, 4, 26, 11, 6, 0, 51, 1040, 28, 140, 180, 5, 26, 16, 0, 6, 18, 0, 12, 3, 1, 4, 10, 1, 0, 4, 3, 5, 8, 1, 2, 1, 2, 6, 4, 20, 0, 29, 4, 1, 2, 8, 20, 11, 22, 14, 0, 1, 0, 18, 2, 4, 3, 1, 0, 0, 2, 12, 0, 2, 108, 0, 3, 6, 0, 21, 0, 0, 4, 1, 1, 44, 6, 31, 0, 34, 14, 14, 43, 11, 11, 22, 32, 28, 2, 1, 16, 0, 0, 2, 48, 6, 48, 14, 0, 0, 8, 29, 0, 0, 12, 0, 26, 8, 24, 13, 26, 17, 2, 32, 38, 0, 1, 0, 0, 0, 0, 5, 0, 19, 4, 2, 7, 4, 1, 5, 1, 4, 4, 24, 1, 7, 2, 4, 1, 1, 49, 1, 37, 0, 7, 0, 2, 100, 2, 2, 0, 29, 10, 0, 37, 72, 158, 2, 16, 1, 0, 11, 0, 10, 0, 0, 2, 12, 11, 2, 0, 13, 43, 0, 0, 0, 4, 2, 0, 62, 0, 1, 23, 0, 68, 4, 0, 6, 1, 15, 0, 0, 0, 24, 0, 1, 22, 0, 7, 1, 7, 0, 5, 1, 11, 0, 2, 1, 92, 8, 0, 17, 0, 46, 3, 1, 11, 0, 0, 0, 10, 5, 16, 90, 155, 6, 0, 6, 3, 1, 0, 13, 0, 2, 15, 2, 19, 1, 9, 0, 5, 9, 0, 76, 4, 0, 18, 22, 26, 1, 4, 0, 0, 0, 0, 0, 2, 0, 138, 12, 18, 3, 10, 0, 4, 1, 0, 1, 5, 0, 18, 1, 1, 6, 3, 0, 0, 1, 1, 21, 1, 12, 5, 5, 9, 0, 0, 0, 0, 0, 16, 2, 148, 24, 148, 0, 26, 0, 48, 0, 30, 52, 21, 0, 42, 23, 29, 0, 21, 0, 50, 12, 52, 0, 29, 0, 77, 0, 16, 0, 8, 16, 32, 28, 22, 0, 8, 23, 12, 12, 24, 9, 8, 14, 16, 4, 75, 46, 0, 126, 38, 14, 20, 16, 31, 2, 56, 40, 4, 38, 12, 26, 2, 24, 17, 35, 14, 6, 32, 2, 18, 20, 0, 19, 26, 42, 0, 26, 14, 95, 8, 20, 12, 0, 4, 14, 30, 24, 16, 8, 23, 6], [36, 10, 4, 5, 2, 32, 0, 0, 5, 4, 0, 2, 18, 41, 19, 8, 8, 5, 13, 5, 40, 8, 12, 4, 8, 50, 4, 4, 16, 67, 2, 18, 30, 18, 20, 0, 65, 16, 12, 30, 12, 11, 26, 22, 12, 4, 14, 0, 71, 84, 121, 17, 21, 6, 64, 13, 8, 5, 2, 0, 247, 72, 6, 33, 0, 17, 8, 6, 6, 6, 6, 0, 53, 41, 23, 25, 10, 8, 222, 11, 49, 9, 22, 5, 143, 537, 6, 34, 4, 2, 47, 0, 28, 6, 37, 2, 6, 0, 49, 116, 23, 2, 0, 0, 4, 6, 16, 6, 8, 36, 0, 20, 8, 2, 12, 2, 3, 2, 4, 2, 6, 62, 6, 2, 30, 8, 4, 8, 2, 2, 4, 6, 43, 45, 16, 30, 0, 2, 2, 6, 11, 1, 4, 1, 2, 77, 31, 4, 5, 5, 8, 0, 27, 6, 4, 4, 9, 13, 8, 59, 0, 8, 0, 6, 9, 7, 0, 0, 41, 12, 16, 23, 30, 0, 4, 6, 12, 5, 1, 2, 26, 564, 3, 48, 30, 0, 21, 6, 3, 2, 9, 0, 98, 120, 84, 55, 109, 142, 3, 167, 255, 109, 107, 72, 41, 93, 84, 142, 53, 34, 110, 138, 322, 107, 71, 88, 91, 76, 90, 83, 7, 96, 20, 161, 45, 124, 98, 83, 24, 42, 71, 138, 6, 65, 149, 100, 62, 197, 58, 215, 242, 190, 220, 126, 201, 200, 127, 215, 6, 153, 101, 104, 208, 395, 188, 233, 225, 371, 239, 166, 44, 62, 56, 75, 160, 142, 151, 237, 117, 76, 143, 156, 72, 55, 154, 58, 86, 121, 177, 160, 272, 159, 115, 143, 145, 44, 76, 133, 12, 166, 42, 98, 145, 130, 173, 203, 114, 129, 30, 90, 90, 81, 215, 101, 106, 241, 160, 183, 157, 71, 62, 69, 123, 6, 142, 62, 130, 110, 200, 92, 2, 72, 180, 0, 175, 120, 179, 82, 101, 75, 0, 54, 2, 45, 29, 127, 79, 84, 130, 90, 8, 208, 94, 98, 131, 59, 107, 57, 69, 147, 76, 102, 52, 39, 66, 81, 75, 20, 49, 117, 111, 98, 56, 118, 38, 130, 200, 76, 65, 375, 171, 81, 95, 339, 252, 42, 1, 121, 144, 59, 26, 88, 35, 419, 147, 95, 114, 68, 6, 82, 82, 40, 493, 84, 131, 287, 173, 121, 225, 62, 4, 158, 92, 146, 98, 43, 241, 144, 49, 163, 118, 29, 0, 188, 76, 81, 280, 177, 490, 60, 2, 317, 56, 118, 2, 20, 145, 76, 509, 408, 375, 213, 292, 211, 234, 85, 2, 90, 160, 43, 585, 121, 214, 273, 200, 0, 160, 79, 6, 128, 175, 43, 92, 77, 104, 37, 0, 0, 0, 0, 70, 0, 115, 23, 65, 0, 79, 0, 46, 0, 34, 116, 51, 0, 51, 164, 56, 0, 39, 0, 125, 11, 63, 0, 110, 2, 123, 0, 36, 0, 53, 54, 101, 43, 37, 0, 48, 87, 92, 37, 71, 29, 44, 124, 25, 54, 133, 36, 1, 147, 351, 87, 224, 21, 87, 0, 70, 68, 5, 40, 25, 61, 2, 43, 33, 54, 60, 52, 31, 6, 44, 60, 9, 31, 32, 117, 4, 64, 38, 216, 2, 87, 69, 0, 26, 78, 121, 144, 83, 6, 148, 35], [1, 0, 3, 1, 3, 4, 0, 5, 5, 3, 6, 1, 6, 1, 5, 2, 2, 1, 2, 1, 1, 5, 3, 2, 1, 2, 6, 2, 4, 4, 2, 4, 3, 1, 0, 3, 4, 3, 1, 0, 4, 1, 4, 3, 1, 2, 5, 1, 3, 2, 9, 1, 9, 2, 4, 2, 2, 6, 2, 6, 14, 0, 2, 5, 0, 3, 1, 0, 7, 4, 1, 4, 13, 2, 0, 3, 1, 3, 2, 1, 1, 6, 1, 6, 6, 10, 3, 4, 4, 0, 3, 3, 7, 2, 7, 4, 2, 3, 2, 8, 3, 1, 0, 0, 17, 0, 2, 0, 2, 2, 2, 5, 1, 0, 2, 1, 3, 1, 3, 1, 0, 24, 1, 0, 3, 2, 2, 1, 2, 0, 1, 1, 0, 8, 0, 0, 0, 3, 1, 1, 2, 1, 0, 0, 2, 2, 1, 2, 1, 2, 1, 1, 7, 0, 1, 4, 3, 2, 3, 1, 0, 0, 3, 1, 0, 0, 0, 0, 3, 4, 9, 11, 3, 0, 0, 0, 1, 0, 1, 1, 6, 17, 8, 1, 3, 1, 1, 0, 0, 0, 0, 0, 1323, 944, 492, 719, 542, 1314, 1, 826, 1125, 559, 1086, 505, 274, 1288, 484, 1212, 602, 524, 891, 1312, 2605, 1272, 650, 1082, 885, 724, 1115, 10, 26, 4, 151, 911, 340, 1086, 489, 367, 177, 644, 385, 977, 39, 559, 9, 347, 442, 1661, 709, 2070, 1124, 1949, 870, 722, 1334, 1154, 822, 1165, 2, 602, 797, 986, 1081, 1657, 1667, 1068, 2369, 3100, 815, 6, 537, 271, 254, 342, 673, 823, 909, 1216, 986, 482, 1527, 1901, 446, 365, 1460, 654, 535, 1241, 2132, 793, 2814, 814, 1016, 661, 1241, 385, 688, 759, 30, 851, 554, 1267, 1430, 8, 680, 1816, 707, 570, 96, 372, 571, 1264, 1339, 11, 546, 938, 785, 911, 1254, 497, 14, 724, 464, 54, 773, 554, 799, 713, 978, 1211, 8, 405, 967, 5, 2103, 17, 1838, 828, 1164, 1245, 5, 587, 3, 272, 169, 961, 966, 837, 823, 425, 93, 1222, 480, 1009, 572, 23, 528, 913, 346, 628, 516, 1165, 387, 736, 19, 995, 882, 368, 512, 1118, 1097, 964, 232, 535, 273, 605, 1035, 519, 660, 2890, 1728, 563, 981, 1760, 2297, 488, 3, 31, 830, 397, 1, 870, 630, 3424, 1569, 1271, 1252, 792, 2, 485, 921, 700, 1977, 15, 838, 1031, 961, 656, 1232, 276, 6, 1815, 461, 882, 753, 7, 1157, 1380, 254, 731, 640, 226, 4, 1230, 874, 1053, 1412, 894, 3582, 411, 8, 2763, 360, 552, 4, 455, 13, 514, 4225, 1718, 1664, 908, 1261, 885, 1591, 432, 0, 894, 1725, 339, 3098, 520, 1335, 2084, 2127, 19, 715, 751, 0, 1153, 793, 513, 442, 653, 647, 120, 1, 0, 0, 0, 5, 0, 5, 2, 4, 0, 17, 0, 7, 1, 3, 10, 1, 0, 6, 4, 7, 0, 4, 0, 10, 7, 9, 0, 7, 0, 12, 0, 5, 0, 4, 2, 16, 4, 4, 0, 2, 6, 9, 1, 10, 0, 5, 3, 4, 3, 8, 4, 1, 17, 10, 3, 6, 1, 12, 2, 10, 4, 2, 11, 12, 2, 3, 5, 5, 1, 3, 3, 1, 1, 4, 5, 1, 5, 9, 17, 0, 6, 4, 8, 0, 5, 5, 0, 4, 4, 4, 11, 4, 3, 8, 3], [24, 6, 0, 0, 4, 8, 0, 4, 7, 4, 3, 0, 10, 13, 4, 2, 2, 0, 16, 6, 20, 2, 0, 0, 74, 36, 4, 2, 11, 40, 2, 4, 15, 13, 6, 4, 39, 13, 8, 18, 4, 0, 14, 6, 6, 2, 0, 2, 44, 50, 97, 11, 32, 12, 45, 6, 15, 2, 11, 0, 226, 48, 4, 35, 0, 8, 4, 3, 3, 2, 8, 2, 24, 34, 24, 37, 14, 24, 140, 2, 34, 6, 10, 1, 116, 363, 9, 28, 2, 0, 28, 5, 12, 2, 25, 2, 0, 2, 23, 64, 26, 0, 2, 0, 0, 0, 4, 0, 16, 26, 2, 6, 3, 6, 4, 2, 4, 8, 0, 2, 38, 50, 4, 5, 5, 11, 1, 2, 2, 1, 2, 0, 29, 20, 10, 6, 2, 9, 0, 1, 5, 0, 0, 0, 14, 45, 42, 4, 2, 14, 6, 2, 28, 0, 0, 0, 2, 3, 2, 41, 0, 6, 0, 4, 2, 8, 3, 4, 28, 2, 18, 38, 18, 4, 3, 2, 6, 4, 4, 4, 6, 334, 3, 52, 24, 2, 4, 6, 0, 2, 8, 2, 68, 50, 42, 36, 60, 80, 22, 107, 119, 54, 43, 46, 12, 54, 43, 50, 18, 30, 68, 50, 174, 51, 27, 45, 49, 36, 42, 27, 0, 43, 17, 73, 22, 70, 59, 47, 21, 28, 38, 68, 4, 41, 55, 42, 33, 127, 26, 57, 117, 143, 68, 75, 133, 113, 58, 99, 50, 76, 46, 38, 104, 167, 91, 132, 118, 203, 146, 91, 28, 35, 20, 36, 89, 94, 99, 145, 57, 34, 92, 109, 25, 29, 39, 54, 50, 66, 119, 83, 137, 75, 89, 80, 47, 12, 30, 70, 0, 95, 19, 62, 80, 72, 59, 113, 74, 68, 14, 54, 69, 60, 150, 66, 60, 134, 70, 103, 66, 56, 31, 38, 48, 4, 82, 35, 102, 46, 98, 48, 6, 34, 103, 1, 93, 29, 52, 30, 43, 78, 4, 19, 0, 25, 8, 92, 32, 42, 43, 56, 104, 113, 52, 68, 71, 29, 85, 37, 34, 60, 38, 51, 23, 32, 29, 65, 22, 8, 39, 95, 68, 62, 25, 94, 26, 72, 93, 28, 31, 225, 83, 28, 51, 168, 90, 21, 0, 64, 70, 31, 108, 26, 32, 137, 71, 70, 34, 29, 4, 38, 40, 26, 212, 45, 73, 144, 102, 72, 129, 35, 1, 84, 65, 72, 82, 14, 116, 105, 38, 82, 69, 15, 0, 120, 56, 56, 139, 83, 177, 54, 2, 139, 39, 60, 4, 25, 87, 31, 200, 291, 220, 130, 117, 68, 79, 31, 0, 60, 91, 34, 265, 58, 141, 111, 162, 2, 88, 22, 0, 71, 69, 41, 18, 26, 30, 13, 1, 0, 0, 0, 30, 0, 47, 10, 13, 0, 42, 0, 25, 0, 6, 35, 30, 0, 18, 78, 75, 0, 22, 0, 55, 6, 52, 0, 46, 0, 79, 0, 16, 0, 14, 32, 38, 46, 22, 0, 30, 72, 50, 30, 34, 10, 38, 60, 20, 14, 60, 21, 0, 104, 164, 50, 146, 24, 30, 2, 24, 32, 20, 18, 11, 29, 2, 29, 28, 14, 18, 38, 18, 4, 14, 40, 0, 16, 20, 63, 0, 28, 21, 136, 2, 30, 20, 0, 32, 37, 64, 80, 35, 6, 68, 20], [389, 32, 2, 19, 57, 38, 0, 3, 2, 58, 4, 4, 26, 62, 24, 2, 34, 4, 112, 2, 92, 50, 2, 2, 20, 115, 69, 10, 75, 201, 10, 14, 84, 103, 24, 1, 108, 42, 56, 67, 20, 39, 126, 69, 60, 6, 73, 1, 352, 244, 639, 134, 56, 42, 96, 196, 27, 18, 41, 2, 396, 347, 63, 49, 8, 26, 86, 78, 16, 40, 4, 2, 92, 61, 16, 109, 13, 14, 133, 4, 50, 19, 18, 2, 172, 731, 21, 41, 1, 4, 105, 1, 36, 0, 41, 2, 85, 4, 152, 470, 346, 6, 0, 4, 6, 9, 6, 47, 148, 112, 11, 26, 6, 6, 85, 51, 10, 67, 38, 16, 4, 339, 36, 7, 101, 63, 125, 45, 18, 14, 35, 2, 184, 160, 64, 64, 11, 12, 6, 4, 54, 13, 8, 17, 52, 203, 240, 54, 18, 54, 68, 42, 147, 54, 19, 20, 15, 16, 117, 155, 8, 18, 23, 2, 28, 4, 11, 4, 19, 13, 37, 79, 21, 9, 5, 18, 15, 14, 10, 2, 8, 474, 13, 77, 110, 4, 12, 19, 0, 2, 19, 0, 350, 406, 115, 162, 417, 97, 2, 737, 345, 266, 422, 169, 186, 370, 267, 276, 182, 209, 113, 428, 193, 353, 109, 345, 317, 400, 362, 308, 12, 252, 34, 512, 71, 125, 135, 134, 40, 87, 102, 115, 3, 76, 261, 65, 37, 405, 145, 242, 417, 392, 249, 186, 440, 549, 400, 466, 16, 497, 279, 152, 731, 369, 216, 294, 560, 461, 540, 377, 179, 194, 257, 90, 466, 294, 481, 317, 201, 241, 371, 740, 218, 142, 534, 215, 260, 239, 479, 547, 589, 258, 472, 488, 202, 147, 226, 343, 40, 182, 206, 356, 127, 270, 249, 235, 213, 141, 33, 158, 115, 249, 343, 134, 141, 366, 275, 143, 110, 91, 179, 65, 64, 7, 143, 46, 209, 181, 152, 141, 0, 256, 213, 2, 540, 193, 427, 181, 390, 245, 0, 195, 3, 276, 243, 391, 228, 262, 288, 275, 36, 589, 309, 235, 89, 176, 225, 264, 229, 104, 95, 301, 295, 203, 353, 398, 248, 44, 163, 338, 139, 128, 62, 89, 52, 167, 423, 56, 84, 782, 411, 112, 188, 779, 552, 162, 0, 424, 501, 218, 35, 360, 170, 794, 300, 281, 250, 181, 1, 198, 246, 140, 676, 183, 359, 228, 320, 195, 683, 177, 5, 406, 386, 532, 489, 157, 497, 562, 122, 466, 477, 253, 3, 283, 313, 332, 779, 353, 505, 164, 32, 717, 179, 432, 5, 95, 130, 125, 648, 565, 323, 306, 352, 349, 219, 179, 1, 95, 203, 62, 929, 125, 515, 270, 325, 6, 183, 123, 0, 239, 107, 364, 199, 162, 274, 53, 0, 2, 0, 0, 110, 0, 185, 55, 153, 0, 131, 0, 53, 1, 48, 128, 53, 0, 106, 159, 102, 0, 104, 2, 302, 40, 104, 0, 118, 0, 211, 0, 72, 0, 43, 86, 66, 63, 26, 0, 40, 62, 66, 51, 33, 19, 30, 53, 92, 74, 209, 58, 0, 257, 290, 163, 162, 41, 85, 10, 122, 155, 4, 82, 74, 100, 2, 55, 71, 44, 111, 57, 47, 8, 58, 95, 10, 71, 61, 150, 0, 94, 79, 395, 22, 62, 29, 0, 26, 69, 60, 88, 47, 7, 63, 48], [75, 9, 0, 2, 9, 19, 4, 0, 1, 7, 10, 2, 12, 27, 17, 3, 0, 9, 43, 0, 7, 1, 1, 0, 0, 44, 21, 7, 5, 73, 1, 2, 10, 23, 11, 1, 18, 13, 7, 81, 16, 21, 22, 15, 18, 4, 7, 0, 102, 89, 0, 54, 14, 6, 53, 3, 3, 6, 5, 0, 330, 82, 3, 46, 0, 13, 2, 2, 4, 17, 0, 0, 8, 56, 43, 58, 0, 19, 153, 2, 110, 28, 24, 0, 107, 359, 12, 14, 0, 2, 9, 0, 21, 0, 56, 0, 5, 0, 36, 0, 1, 0, 3, 0, 4, 2, 0, 0, 1, 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 3, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 4, 1, 1, 6, 1, 0, 1, 0, 23, 0, 1, 0, 7, 0, 0, 1, 5, 0, 0, 0, 3, 1, 3, 0, 1, 0, 0, 1, 0, 1, 0, 0, 662, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 124, 105, 65, 44, 98, 129, 2, 173, 222, 71, 82, 0, 0, 147, 61, 237, 39, 40, 105, 152, 217, 174, 45, 165, 67, 50, 81, 0, 4, 1, 0, 156, 3, 150, 95, 57, 40, 113, 56, 221, 4, 130, 3, 1, 42, 270, 48, 92, 185, 419, 1, 0, 239, 188, 155, 165, 0, 103, 126, 1, 155, 4, 177, 7, 189, 346, 168, 1, 78, 1, 44, 49, 99, 122, 133, 204, 103, 53, 243, 120, 49, 54, 104, 62, 0, 75, 138, 94, 239, 133, 144, 91, 116, 27, 69, 122, 6, 1, 76, 161, 128, 0, 148, 167, 113, 104, 42, 75, 96, 121, 251, 2, 120, 200, 130, 168, 79, 81, 0, 65, 103, 8, 149, 60, 126, 122, 200, 133, 100, 51, 217, 0, 312, 1, 202, 43, 58, 93, 105, 17, 0, 40, 26, 176, 103, 78, 61, 62, 23, 221, 86, 206, 68, 1, 99, 135, 46, 153, 74, 180, 54, 47, 1, 170, 138, 24, 117, 226, 249, 174, 94, 142, 46, 134, 149, 119, 157, 426, 137, 37, 33, 224, 325, 43, 0, 7, 83, 41, 1, 61, 31, 474, 103, 125, 79, 52, 1, 51, 44, 69, 401, 0, 116, 173, 164, 71, 175, 31, 0, 122, 57, 100, 73, 0, 182, 91, 37, 122, 78, 21, 0, 99, 87, 57, 173, 138, 314, 72, 0, 467, 75, 69, 0, 68, 1, 81, 772, 275, 540, 142, 244, 186, 288, 46, 1, 128, 193, 42, 2, 60, 241, 340, 333, 4, 89, 112, 0, 141, 114, 86, 40, 36, 77, 1, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 0, 0, 0, 18, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 1, 0, 1, 0, 0, 27, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [84, 16, 0, 2, 4, 14, 0, 1, 1, 8, 4, 7, 26, 14, 4, 16, 12, 19, 36, 8, 20, 15, 1, 0, 10, 66, 18, 6, 11, 91, 4, 12, 68, 12, 14, 1, 94, 37, 11, 18, 18, 36, 29, 7, 6, 18, 18, 1, 97, 64, 242, 36, 60, 34, 94, 29, 12, 12, 14, 0, 284, 60, 24, 62, 2, 8, 18, 2, 4, 13, 0, 1, 57, 77, 32, 79, 13, 2, 195, 19, 63, 16, 15, 2, 196, 608, 16, 34, 0, 0, 64, 0, 23, 0, 52, 0, 1, 0, 48, 55, 59, 4, 0, 0, 4, 2, 8, 8, 16, 83, 2, 25, 1, 1, 28, 2, 5, 18, 10, 3, 6, 56, 2, 1, 30, 26, 7, 16, 4, 2, 12, 0, 44, 2, 20, 46, 0, 2, 3, 2, 11, 0, 2, 0, 0, 143, 53, 10, 9, 7, 8, 7, 26, 8, 2, 6, 4, 6, 18, 31, 0, 14, 2, 2, 16, 9, 2, 0, 38, 0, 36, 42, 19, 8, 9, 6, 9, 0, 2, 0, 30, 770, 10, 59, 33, 0, 12, 11, 1, 0, 4, 0, 153, 222, 184, 100, 122, 199, 2, 272, 293, 173, 108, 125, 58, 133, 135, 143, 99, 89, 147, 227, 425, 168, 61, 148, 94, 118, 145, 112, 0, 139, 49, 242, 73, 177, 122, 101, 77, 76, 93, 155, 7, 99, 131, 130, 68, 209, 127, 268, 277, 233, 216, 168, 272, 292, 177, 341, 12, 162, 110, 123, 254, 459, 223, 321, 323, 508, 302, 210, 66, 69, 97, 95, 207, 199, 233, 352, 125, 146, 194, 273, 126, 82, 194, 96, 141, 200, 237, 221, 425, 188, 244, 208, 165, 39, 122, 221, 8, 181, 84, 145, 219, 165, 219, 274, 149, 207, 42, 135, 129, 170, 381, 113, 168, 305, 237, 278, 185, 114, 135, 82, 182, 7, 231, 91, 242, 208, 278, 144, 0, 118, 267, 0, 260, 171, 132, 70, 122, 133, 0, 58, 2, 49, 56, 121, 146, 118, 239, 122, 20, 272, 130, 120, 148, 104, 167, 115, 82, 177, 75, 124, 101, 91, 105, 165, 115, 43, 60, 149, 175, 175, 58, 163, 54, 174, 177, 85, 71, 373, 170, 112, 126, 379, 194, 23, 0, 105, 146, 80, 32, 103, 63, 363, 138, 113, 116, 58, 4, 80, 78, 58, 464, 99, 187, 215, 197, 166, 258, 50, 0, 199, 115, 178, 126, 32, 196, 140, 55, 166, 121, 34, 0, 182, 72, 97, 292, 162, 543, 82, 6, 347, 32, 133, 1, 43, 173, 100, 629, 396, 440, 212, 253, 207, 152, 102, 0, 126, 195, 100, 834, 115, 271, 200, 204, 4, 146, 79, 0, 145, 164, 67, 131, 76, 148, 45, 0, 1, 0, 0, 42, 0, 104, 16, 62, 0, 67, 0, 39, 0, 37, 81, 39, 0, 49, 105, 57, 0, 49, 0, 87, 14, 70, 0, 107, 0, 83, 1, 23, 0, 27, 69, 132, 72, 47, 0, 28, 66, 85, 56, 81, 28, 73, 94, 12, 48, 89, 34, 0, 159, 288, 72, 117, 13, 75, 0, 60, 49, 7, 29, 18, 68, 6, 25, 36, 38, 30, 67, 43, 0, 32, 57, 0, 29, 55, 102, 0, 53, 38, 130, 4, 75, 64, 0, 20, 65, 96, 101, 48, 10, 92, 44], [89, 11, 0, 2, 11, 28, 2, 0, 0, 7, 7, 1, 24, 54, 15, 10, 16, 6, 62, 4, 53, 12, 1, 0, 215, 84, 27, 10, 32, 117, 3, 18, 63, 39, 28, 1, 138, 10, 32, 67, 20, 20, 32, 40, 24, 7, 28, 0, 248, 174, 363, 33, 65, 41, 81, 41, 22, 16, 19, 0, 522, 157, 35, 128, 1, 20, 25, 9, 9, 29, 2, 0, 100, 76, 45, 53, 23, 42, 289, 4, 98, 18, 33, 0, 247, 885, 27, 75, 1, 4, 81, 0, 33, 0, 44, 0, 3, 0, 38, 268, 64, 2, 2, 0, 12, 6, 15, 4, 55, 134, 0, 15, 2, 0, 24, 9, 5, 12, 7, 5, 75, 112, 4, 2, 36, 24, 8, 6, 12, 2, 10, 6, 88, 77, 34, 55, 1, 5, 7, 5, 30, 0, 5, 0, 1, 190, 108, 7, 25, 4, 5, 17, 24, 22, 7, 8, 0, 20, 19, 140, 0, 15, 6, 6, 17, 8, 4, 1, 53, 7, 69, 73, 51, 8, 19, 15, 9, 6, 1, 0, 30, 902, 9, 55, 66, 3, 13, 4, 0, 0, 5, 1, 233, 216, 138, 98, 194, 225, 78, 316, 426, 174, 197, 149, 66, 206, 126, 227, 92, 82, 163, 276, 456, 196, 96, 204, 145, 131, 182, 125, 7, 188, 51, 238, 92, 212, 151, 122, 65, 113, 99, 191, 7, 83, 215, 141, 71, 368, 109, 322, 361, 376, 309, 248, 491, 352, 326, 406, 191, 241, 138, 167, 381, 603, 322, 365, 459, 714, 311, 287, 92, 87, 120, 104, 275, 247, 380, 455, 188, 188, 231, 334, 138, 120, 233, 126, 135, 183, 340, 303, 541, 256, 280, 269, 254, 53, 103, 248, 10, 279, 97, 200, 249, 271, 263, 313, 228, 192, 71, 136, 174, 203, 462, 170, 175, 364, 219, 302, 213, 140, 138, 117, 150, 9, 233, 102, 236, 238, 308, 206, 21, 150, 309, 0, 395, 108, 275, 113, 166, 161, 12, 93, 1, 95, 75, 180, 159, 147, 131, 154, 354, 474, 188, 202, 128, 85, 188, 158, 112, 218, 92, 188, 134, 105, 142, 125, 164, 73, 115, 235, 191, 171, 96, 212, 100, 191, 301, 94, 128, 593, 237, 69, 125, 527, 326, 64, 1, 183, 242, 102, 345, 114, 109, 576, 244, 145, 186, 95, 0, 135, 130, 87, 675, 94, 328, 385, 338, 183, 368, 83, 1, 346, 133, 224, 218, 39, 398, 355, 95, 169, 176, 77, 0, 280, 146, 178, 408, 277, 728, 153, 0, 466, 78, 203, 1, 56, 202, 147, 884, 571, 768, 313, 382, 283, 297, 142, 1, 164, 193, 69, 956, 150, 454, 333, 321, 5, 227, 101, 1, 174, 265, 131, 101, 117, 192, 50, 0, 3, 1, 0, 7, 0, 131, 7, 68, 0, 21, 0, 37, 0, 9, 91, 8, 1, 14, 117, 128, 0, 53, 1, 83, 16, 10, 0, 165, 0, 41, 1, 44, 0, 13, 55, 110, 62, 69, 0, 55, 24, 75, 49, 76, 38, 59, 87, 26, 13, 178, 27, 1, 179, 399, 78, 220, 10, 28, 1, 158, 71, 72, 43, 12, 66, 1, 62, 46, 17, 40, 62, 44, 9, 46, 55, 0, 56, 46, 142, 1, 17, 66, 156, 2, 72, 44, 0, 48, 46, 177, 208, 26, 8, 106, 11], [144, 34, 0, 6, 13, 56, 45, 0, 0, 10, 6, 6, 81, 66, 18, 10, 16, 16, 100, 0, 86, 24, 4, 0, 30, 171, 37, 18, 38, 146, 4, 12, 46, 129, 22, 0, 262, 143, 32, 100, 16, 34, 89, 50, 50, 12, 48, 0, 285, 391, 450, 44, 170, 60, 187, 18, 32, 16, 19, 0, 991, 330, 58, 165, 0, 45, 23, 18, 18, 46, 0, 0, 459, 226, 234, 122, 32, 40, 912, 28, 157, 34, 66, 0, 623, 2714, 52, 102, 2, 18, 268, 0, 102, 0, 107, 2, 0, 0, 22, 40, 10, 0, 2, 0, 0, 0, 2, 0, 8, 19, 0, 2, 0, 0, 6, 0, 0, 0, 2, 0, 2, 12, 2, 1, 14, 4, 6, 2, 0, 0, 3, 0, 22, 24, 2, 20, 0, 0, 4, 2, 6, 0, 0, 0, 0, 38, 26, 0, 0, 2, 2, 4, 15, 0, 0, 0, 0, 6, 0, 24, 0, 0, 0, 6, 4, 4, 0, 0, 7, 2, 32, 12, 6, 4, 0, 4, 2, 0, 0, 0, 8, 274, 4, 8, 36, 0, 4, 0, 0, 2, 4, 0, 44, 24, 22, 24, 22, 52, 96, 42, 60, 22, 33, 33, 6, 20, 14, 20, 12, 20, 40, 47, 89, 21, 18, 21, 28, 16, 24, 10, 0, 16, 6, 32, 12, 40, 28, 34, 20, 16, 29, 39, 0, 22, 16, 26, 16, 22, 24, 30, 50, 63, 38, 30, 66, 78, 33, 36, 2, 20, 25, 32, 48, 114, 40, 76, 59, 115, 58, 20, 6, 8, 12, 8, 36, 32, 38, 36, 46, 32, 37, 22, 12, 12, 22, 12, 21, 24, 24, 26, 80, 27, 27, 19, 22, 8, 2, 28, 0, 30, 14, 24, 40, 26, 43, 58, 32, 42, 14, 15, 22, 39, 32, 22, 26, 61, 76, 64, 33, 14, 36, 18, 12, 4, 34, 0, 38, 30, 56, 30, 18, 16, 78, 0, 51, 18, 36, 9, 20, 31, 22, 13, 0, 0, 4, 24, 22, 40, 14, 18, 10, 76, 34, 58, 27, 11, 18, 20, 8, 52, 9, 28, 24, 14, 16, 20, 22, 12, 26, 42, 57, 42, 40, 66, 14, 37, 29, 26, 30, 70, 20, 8, 8, 80, 43, 5, 0, 22, 18, 11, 14, 8, 9, 106, 14, 22, 18, 6, 2, 12, 8, 6, 104, 13, 34, 56, 54, 18, 49, 8, 0, 30, 8, 25, 32, 2, 94, 56, 8, 57, 22, 8, 0, 23, 4, 32, 64, 23, 187, 28, 2, 113, 12, 24, 0, 20, 40, 16, 189, 119, 182, 54, 72, 83, 63, 26, 0, 30, 35, 12, 220, 30, 111, 60, 47, 0, 41, 16, 0, 39, 19, 10, 4, 8, 36, 6, 0, 0, 0, 0, 70, 0, 78, 14, 0, 0, 56, 4, 22, 0, 32, 58, 28, 0, 54, 94, 88, 0, 170, 2, 304, 16, 56, 0, 72, 0, 120, 0, 50, 0, 46, 104, 265, 333, 52, 0, 54, 108, 58, 46, 61, 108, 30, 118, 35, 49, 54, 18, 0, 356, 288, 62, 96, 22, 28, 0, 64, 48, 4, 38, 50, 39, 0, 25, 62, 34, 39, 50, 24, 4, 30, 52, 1, 19, 64, 86, 0, 48, 28, 157, 0, 55, 69, 0, 55, 48, 64, 100, 32, 8, 60, 41], [16, 2, 0, 1, 2, 8, 9, 0, 1, 2, 2, 1, 10, 12, 1, 0, 5, 5, 10, 0, 9, 5, 0, 0, 4, 17, 5, 1, 5, 15, 0, 0, 12, 19, 5, 0, 30, 10, 7, 15, 0, 5, 19, 9, 8, 1, 10, 0, 36, 35, 67, 11, 12, 7, 15, 6, 6, 0, 3, 0, 200, 41, 5, 26, 0, 2, 5, 6, 5, 9, 0, 0, 30, 11, 17, 27, 3, 6, 96, 1, 59, 4, 6, 0, 57, 265, 7, 6, 1, 0, 30, 0, 14, 1, 19, 0, 1, 0, 18, 15, 8, 4, 3, 0, 6, 4, 2, 0, 2, 31, 0, 2, 0, 0, 9, 0, 0, 1, 1, 1, 4, 12, 3, 2, 7, 2, 1, 0, 1, 0, 0, 0, 19, 11, 6, 7, 0, 0, 1, 1, 3, 0, 0, 0, 0, 23, 13, 2, 3, 1, 1, 0, 6, 1, 3, 0, 0, 9, 3, 19, 0, 1, 2, 0, 4, 2, 0, 0, 27, 3, 16, 32, 13, 0, 3, 4, 0, 2, 0, 0, 4, 372, 2, 14, 17, 0, 4, 0, 0, 0, 2, 0, 80, 97, 41, 52, 65, 107, 226, 118, 167, 80, 54, 61, 19, 39, 52, 108, 61, 30, 97, 94, 255, 62, 49, 69, 53, 21, 67, 47, 4, 68, 30, 109, 29, 106, 70, 81, 30, 38, 49, 96, 2, 55, 66, 67, 29, 121, 68, 70, 159, 118, 141, 107, 221, 172, 130, 124, 15, 92, 47, 76, 138, 244, 142, 156, 166, 296, 136, 101, 34, 19, 30, 48, 112, 81, 148, 161, 66, 65, 94, 81, 42, 54, 76, 34, 55, 57, 90, 76, 224, 113, 120, 75, 108, 24, 17, 106, 6, 98, 42, 77, 121, 93, 111, 86, 125, 96, 40, 60, 101, 85, 193, 81, 80, 190, 145, 150, 101, 69, 75, 64, 76, 4, 125, 49, 109, 103, 184, 74, 62, 49, 174, 1, 160, 39, 111, 53, 47, 72, 80, 25, 1, 30, 16, 62, 82, 76, 50, 66, 22, 130, 83, 88, 73, 33, 96, 49, 40, 112, 48, 65, 61, 33, 38, 69, 56, 20, 35, 93, 105, 90, 81, 127, 74, 121, 164, 64, 56, 244, 134, 30, 53, 213, 124, 17, 0, 75, 83, 21, 28, 30, 44, 200, 84, 76, 80, 52, 0, 51, 32, 27, 317, 68, 104, 183, 158, 77, 170, 27, 0, 115, 66, 78, 99, 25, 149, 90, 49, 99, 60, 12, 0, 97, 52, 55, 187, 134, 358, 51, 0, 217, 23, 90, 0, 31, 107, 92, 405, 281, 530, 174, 248, 172, 136, 57, 0, 52, 112, 56, 476, 97, 250, 174, 158, 4, 128, 50, 0, 91, 114, 28, 38, 38, 76, 27, 0, 45, 0, 0, 38, 0, 41, 8, 23, 0, 31, 0, 6, 0, 12, 40, 18, 0, 26, 68, 33, 0, 32, 0, 51, 5, 26, 0, 50, 0, 59, 1, 24, 0, 23, 41, 38, 32, 16, 0, 41, 40, 58, 15, 49, 18, 28, 51, 14, 23, 45, 20, 1, 66, 201, 47, 94, 16, 23, 0, 61, 42, 4, 13, 22, 20, 2, 24, 15, 16, 32, 30, 26, 6, 31, 36, 0, 10, 25, 74, 0, 43, 22, 115, 4, 43, 29, 0, 50, 24, 52, 63, 30, 4, 69, 24], [39, 5, 0, 2, 3, 13, 0, 0, 0, 5, 1, 3, 8, 16, 2, 4, 1, 0, 12, 3, 13, 1, 0, 0, 8, 48, 4, 4, 13, 37, 0, 0, 11, 20, 21, 0, 55, 11, 9, 19, 5, 5, 23, 9, 8, 0, 4, 0, 89, 47, 169, 14, 14, 11, 59, 12, 11, 3, 7, 0, 290, 51, 5, 44, 0, 11, 11, 2, 2, 6, 1, 0, 12, 20, 14, 34, 3, 3, 112, 1, 15, 4, 7, 0, 157, 277, 9, 7, 0, 0, 16, 0, 6, 0, 17, 0, 1, 0, 26, 107, 37, 3, 0, 0, 4, 3, 4, 0, 12, 41, 0, 13, 2, 0, 3, 6, 2, 5, 4, 1, 1, 42, 0, 0, 8, 4, 3, 1, 1, 0, 5, 0, 37, 25, 7, 10, 0, 2, 1, 2, 6, 0, 2, 0, 1, 31, 40, 4, 3, 1, 2, 5, 24, 3, 2, 2, 0, 3, 21, 64, 0, 6, 0, 5, 2, 0, 2, 0, 23, 0, 1, 13, 13, 0, 2, 3, 1, 3, 0, 0, 9, 489, 1, 30, 9, 0, 6, 4, 0, 2, 4, 0, 104, 9, 7, 3, 6, 10, 0, 5, 8, 3, 24, 16, 2, 12, 11, 4, 2, 5, 6, 5, 14, 12, 6, 9, 7, 5, 12, 37, 0, 2, 2, 39, 3, 9, 4, 1, 3, 3, 0, 11, 0, 8, 11, 10, 5, 128, 2, 11, 8, 5, 7, 25, 4, 4, 2, 22, 1, 16, 0, 7, 20, 15, 5, 44, 14, 9, 4, 15, 2, 12, 0, 2, 11, 7, 8, 18, 10, 5, 78, 14, 7, 8, 20, 49, 5, 4, 5, 4, 126, 16, 14, 20, 8, 0, 5, 29, 1, 12, 5, 106, 1, 7, 9, 8, 10, 12, 1, 4, 10, 6, 9, 6, 3, 9, 2, 7, 7, 2, 3, 3, 3, 2, 2, 0, 5, 9, 7, 81, 0, 9, 76, 0, 25, 7, 10, 39, 14, 7, 0, 6, 0, 2, 4, 7, 8, 16, 11, 6, 1, 19, 2, 16, 3, 5, 1, 57, 3, 1, 4, 13, 3, 7, 2, 106, 4, 2, 2, 8, 7, 5, 3, 3, 3, 21, 43, 3, 26, 10, 13, 6, 2, 5, 12, 1, 0, 7, 3, 2, 4, 40, 5, 75, 17, 6, 5, 1, 0, 7, 5, 3, 32, 3, 27, 9, 12, 17, 14, 4, 0, 88, 7, 5, 4, 4, 8, 5, 1, 31, 1, 5, 0, 5, 6, 7, 63, 7, 13, 3, 0, 201, 4, 2, 0, 4, 8, 10, 27, 18, 10, 4, 9, 6, 2, 6, 0, 2, 11, 2, 110, 6, 25, 9, 11, 0, 5, 3, 0, 5, 11, 2, 6, 7, 6, 2, 0, 0, 0, 0, 18, 0, 84, 0, 0, 0, 10, 0, 18, 0, 0, 0, 30, 0, 28, 4, 0, 1, 15, 0, 87, 1, 43, 0, 97, 0, 10, 1, 1, 0, 24, 4, 22, 15, 0, 0, 50, 1, 2, 0, 0, 1, 18, 5, 16, 114, 243, 72, 0, 0, 60, 208, 298, 47, 213, 0, 205, 2, 9, 64, 68, 122, 1, 72, 52, 89, 165, 86, 50, 4, 76, 140, 3, 64, 58, 330, 0, 163, 94, 389, 4, 78, 22, 0, 57, 129, 26, 197, 95, 11, 107, 0], [319, 21, 0, 8, 30, 27, 3, 0, 0, 19, 6, 3, 61, 80, 32, 21, 48, 16, 113, 5, 144, 8, 0, 0, 9, 161, 40, 9, 90, 251, 6, 26, 115, 31, 75, 0, 277, 67, 48, 93, 31, 27, 95, 56, 44, 22, 39, 0, 509, 260, 931, 77, 136, 44, 257, 63, 47, 46, 60, 0, 588, 349, 67, 150, 11, 64, 101, 37, 8, 36, 4, 0, 31, 73, 29, 105, 23, 31, 333, 7, 207, 20, 22, 0, 175, 782, 13, 75, 0, 2, 56, 0, 40, 0, 49, 0, 10, 1, 125, 256, 191, 1, 0, 0, 7, 9, 4, 4, 67, 132, 1, 26, 2, 3, 23, 36, 2, 22, 6, 0, 9, 156, 16, 2, 19, 21, 25, 8, 3, 2, 11, 1, 107, 43, 52, 38, 0, 6, 0, 1, 13, 4, 7, 0, 7, 100, 154, 12, 5, 26, 21, 11, 97, 6, 13, 16, 2, 12, 32, 77, 0, 13, 5, 5, 9, 3, 3, 0, 31, 0, 12, 44, 9, 2, 3, 4, 7, 1, 2, 0, 2, 600, 4, 55, 51, 0, 1, 6, 0, 0, 7, 1, 488, 271, 271, 102, 557, 165, 14, 538, 188, 236, 399, 238, 158, 376, 240, 323, 128, 178, 160, 380, 246, 285, 144, 291, 199, 329, 454, 170, 10, 281, 131, 406, 165, 177, 80, 81, 37, 68, 71, 121, 2, 38, 300, 94, 43, 266, 191, 352, 459, 467, 263, 368, 428, 364, 249, 558, 24, 372, 223, 237, 505, 570, 402, 589, 582, 677, 426, 436, 162, 127, 135, 100, 348, 272, 364, 579, 148, 203, 264, 604, 163, 206, 397, 202, 189, 264, 648, 354, 778, 397, 436, 353, 274, 124, 157, 370, 70, 426, 196, 286, 140, 193, 219, 140, 160, 128, 22, 73, 83, 142, 260, 92, 111, 232, 158, 235, 85, 46, 66, 72, 108, 4, 146, 74, 153, 124, 193, 117, 4, 440, 153, 1, 625, 106, 409, 121, 491, 110, 5, 198, 0, 110, 120, 206, 157, 193, 243, 195, 31, 493, 149, 272, 90, 147, 222, 244, 211, 167, 86, 212, 147, 169, 189, 228, 189, 85, 110, 276, 141, 71, 36, 106, 33, 148, 262, 88, 51, 361, 217, 55, 231, 840, 518, 165, 0, 162, 201, 149, 39, 220, 171, 616, 478, 173, 213, 103, 0, 118, 229, 93, 523, 121, 437, 243, 238, 218, 252, 107, 0, 446, 146, 364, 282, 51, 323, 254, 87, 198, 339, 86, 0, 317, 223, 317, 412, 310, 538, 126, 24, 659, 167, 190, 1, 70, 138, 104, 511, 280, 282, 206, 206, 201, 164, 96, 1, 73, 140, 23, 400, 106, 298, 210, 215, 1, 112, 79, 0, 131, 98, 359, 164, 154, 388, 20, 0, 3, 0, 0, 57, 0, 150, 24, 83, 0, 119, 0, 73, 0, 62, 146, 80, 0, 65, 132, 154, 0, 88, 0, 235, 36, 135, 0, 122, 1, 283, 1, 36, 0, 50, 89, 58, 48, 32, 0, 15, 91, 46, 50, 67, 14, 45, 76, 120, 67, 261, 52, 2, 306, 204, 143, 218, 40, 76, 0, 175, 317, 3, 68, 43, 110, 8, 104, 38, 115, 69, 55, 37, 3, 56, 104, 3, 73, 63, 238, 1, 97, 69, 308, 41, 66, 67, 0, 18, 38, 55, 62, 45, 12, 103, 41], [18, 3, 0, 0, 0, 6, 0, 0, 0, 5, 1, 0, 9, 7, 0, 2, 3, 3, 7, 0, 13, 2, 0, 0, 4, 10, 1, 6, 2, 13, 0, 2, 6, 11, 4, 0, 26, 0, 2, 7, 3, 3, 6, 3, 1, 0, 7, 0, 43, 30, 68, 7, 16, 2, 9, 7, 2, 1, 0, 0, 206, 25, 7, 10, 2, 2, 4, 3, 0, 3, 1, 0, 29, 11, 2, 13, 4, 5, 36, 0, 26, 4, 1, 0, 50, 166, 0, 18, 1, 0, 6, 0, 6, 0, 5, 0, 3, 1, 12, 30, 5, 0, 0, 0, 0, 1, 0, 0, 4, 12, 0, 5, 0, 0, 0, 0, 1, 5, 1, 1, 0, 32, 0, 0, 2, 2, 2, 3, 2, 0, 2, 0, 6, 7, 6, 8, 0, 0, 2, 1, 1, 0, 1, 0, 1, 19, 12, 0, 1, 6, 0, 0, 9, 5, 2, 3, 0, 3, 4, 22, 1, 1, 0, 0, 2, 0, 3, 0, 10, 0, 9, 8, 2, 3, 2, 2, 1, 2, 1, 0, 2, 197, 5, 21, 5, 0, 1, 1, 0, 0, 2, 0, 27, 31, 25, 13, 42, 29, 2, 35, 51, 36, 26, 19, 11, 40, 21, 25, 19, 19, 23, 40, 80, 25, 13, 27, 24, 27, 42, 23, 1, 30, 10, 54, 16, 19, 19, 20, 5, 17, 4, 29, 1, 15, 45, 24, 6, 31, 15, 71, 57, 76, 37, 45, 55, 44, 29, 62, 0, 31, 24, 40, 71, 82, 50, 80, 88, 85, 58, 67, 13, 14, 10, 8, 64, 41, 63, 68, 37, 24, 25, 70, 27, 10, 32, 14, 25, 24, 71, 36, 60, 51, 40, 45, 52, 12, 14, 39, 6, 43, 35, 26, 24, 34, 27, 42, 23, 14, 4, 15, 30, 25, 59, 21, 22, 35, 29, 36, 28, 24, 15, 22, 13, 1, 34, 10, 33, 26, 55, 8, 1, 35, 41, 0, 38, 27, 57, 13, 38, 22, 0, 31, 0, 19, 17, 27, 20, 22, 35, 18, 4, 44, 26, 28, 22, 21, 22, 23, 16, 37, 6, 27, 13, 17, 21, 16, 25, 7, 11, 32, 23, 29, 7, 25, 7, 20, 51, 17, 13, 71, 47, 16, 27, 87, 31, 11, 0, 45, 41, 21, 5, 15, 13, 58, 39, 40, 43, 17, 0, 26, 24, 14, 81, 21, 42, 82, 76, 28, 56, 18, 0, 35, 22, 36, 30, 10, 57, 50, 9, 26, 32, 10, 0, 46, 20, 26, 66, 48, 124, 33, 0, 69, 26, 31, 0, 14, 26, 14, 78, 80, 94, 53, 54, 46, 60, 16, 0, 25, 24, 6, 140, 19, 103, 49, 41, 3, 32, 16, 0, 33, 31, 29, 20, 20, 22, 5, 0, 0, 0, 0, 25, 0, 23, 7, 18, 0, 46, 0, 18, 0, 15, 33, 22, 0, 18, 49, 29, 0, 8, 0, 39, 5, 30, 0, 14, 0, 65, 0, 18, 0, 25, 27, 38, 21, 16, 0, 15, 44, 32, 16, 23, 6, 12, 46, 20, 24, 80, 9, 0, 63, 106, 53, 66, 10, 39, 0, 33, 71, 0, 18, 20, 15, 0, 26, 6, 19, 22, 14, 13, 0, 18, 29, 1, 18, 21, 31, 0, 26, 8, 59, 0, 26, 30, 0, 8, 20, 25, 35, 22, 2, 72, 20], [269, 18, 0, 9, 27, 14, 0, 0, 0, 22, 10, 2, 11, 48, 6, 23, 22, 7, 62, 1, 107, 3, 4, 0, 14, 67, 18, 10, 31, 70, 0, 4, 80, 39, 41, 0, 2, 11, 28, 47, 26, 6, 65, 40, 24, 4, 22, 0, 158, 98, 428, 64, 61, 36, 112, 56, 17, 5, 6, 0, 478, 9, 39, 94, 3, 6, 48, 24, 6, 6, 1, 0, 35, 22, 15, 59, 10, 9, 94, 1, 48, 6, 6, 0, 142, 538, 13, 57, 0, 0, 10, 0, 24, 0, 20, 0, 9, 1, 150, 175, 139, 7, 0, 0, 2, 2, 1, 5, 38, 67, 0, 6, 4, 1, 26, 17, 10, 14, 11, 2, 10, 109, 8, 4, 30, 22, 7, 13, 4, 1, 13, 2, 68, 46, 20, 43, 4, 0, 3, 8, 13, 9, 7, 1, 0, 111, 48, 19, 4, 10, 9, 1, 43, 25, 7, 3, 0, 22, 38, 68, 0, 13, 3, 4, 9, 1, 1, 0, 11, 4, 16, 42, 0, 3, 1, 2, 9, 1, 0, 0, 7, 542, 0, 28, 29, 0, 4, 2, 1, 1, 2, 0, 526, 242, 298, 157, 240, 146, 9, 461, 208, 161, 290, 210, 219, 314, 185, 233, 105, 165, 153, 239, 200, 271, 87, 219, 220, 220, 344, 184, 13, 239, 81, 364, 113, 110, 88, 80, 30, 52, 78, 143, 0, 44, 226, 106, 51, 293, 169, 232, 401, 346, 244, 251, 416, 351, 227, 526, 8, 347, 165, 249, 500, 483, 231, 416, 414, 526, 430, 316, 98, 123, 148, 82, 211, 210, 288, 372, 156, 142, 236, 341, 197, 121, 371, 147, 207, 200, 505, 400, 566, 318, 321, 317, 199, 100, 129, 272, 29, 366, 157, 207, 121, 209, 194, 143, 105, 105, 16, 76, 132, 103, 279, 93, 104, 214, 123, 174, 84, 93, 84, 41, 86, 4, 146, 38, 160, 129, 145, 85, 3, 328, 181, 0, 426, 107, 270, 110, 403, 85, 4, 225, 0, 101, 138, 238, 173, 166, 226, 206, 23, 370, 213, 219, 65, 179, 194, 143, 185, 202, 95, 212, 209, 138, 186, 278, 153, 65, 107, 188, 110, 87, 33, 182, 41, 88, 232, 42, 49, 344, 305, 121, 176, 589, 360, 111, 0, 252, 341, 183, 27, 194, 171, 483, 316, 255, 234, 134, 0, 130, 242, 113, 461, 171, 278, 250, 316, 290, 282, 77, 0, 337, 229, 347, 302, 72, 243, 209, 100, 243, 428, 159, 0, 292, 196, 208, 428, 311, 444, 136, 21, 516, 144, 182, 0, 61, 148, 82, 381, 284, 306, 203, 258, 187, 200, 79, 2, 95, 125, 63, 498, 91, 270, 173, 181, 2, 144, 80, 0, 119, 123, 256, 126, 149, 258, 41, 1, 0, 0, 0, 78, 0, 195, 23, 153, 0, 191, 0, 78, 0, 92, 193, 125, 2, 112, 101, 192, 0, 96, 1, 258, 36, 244, 0, 83, 0, 412, 1, 64, 0, 83, 137, 92, 53, 52, 0, 42, 97, 49, 37, 87, 27, 22, 106, 122, 101, 398, 56, 4, 372, 359, 253, 225, 44, 179, 0, 180, 352, 11, 124, 85, 110, 7, 107, 70, 143, 158, 90, 68, 5, 55, 135, 2, 67, 116, 236, 0, 123, 78, 162, 47, 63, 86, 0, 21, 57, 84, 123, 54, 4, 174, 50], [171, 13, 0, 2, 19, 32, 5, 1, 1, 44, 2, 0, 62, 40, 5, 1, 12, 8, 65, 17, 45, 13, 2, 3, 35, 115, 28, 14, 70, 159, 2, 11, 62, 88, 32, 0, 115, 36, 44, 89, 27, 34, 47, 24, 39, 13, 50, 1, 256, 149, 540, 78, 61, 26, 88, 77, 12, 11, 51, 1, 417, 74, 105, 89, 6, 12, 61, 9, 12, 3, 3, 0, 43, 54, 18, 55, 18, 13, 171, 8, 64, 8, 20, 2, 38, 438, 13, 25, 0, 0, 11, 0, 27, 0, 17, 1, 7, 0, 63, 161, 135, 4, 2, 0, 3, 15, 3, 2, 30, 60, 1, 12, 3, 1, 19, 3, 3, 30, 8, 3, 9, 138, 25, 1, 9, 22, 4, 2, 1, 6, 2, 6, 82, 35, 27, 30, 0, 4, 6, 2, 11, 0, 7, 2, 2, 77, 79, 10, 1, 5, 4, 18, 22, 19, 8, 10, 4, 19, 39, 69, 0, 27, 0, 10, 14, 1, 0, 1, 11, 3, 18, 47, 10, 0, 2, 0, 2, 1, 0, 0, 5, 454, 5, 31, 49, 0, 9, 8, 0, 0, 9, 0, 359, 172, 90, 73, 200, 99, 64, 336, 182, 136, 152, 112, 89, 192, 118, 161, 96, 128, 101, 136, 207, 189, 87, 135, 91, 128, 267, 113, 3, 195, 96, 271, 90, 95, 55, 59, 36, 55, 60, 64, 0, 30, 268, 70, 41, 243, 84, 212, 266, 283, 227, 191, 304, 310, 197, 447, 18, 254, 150, 166, 379, 469, 199, 314, 408, 424, 286, 279, 63, 64, 90, 75, 238, 201, 191, 313, 131, 129, 226, 355, 117, 91, 243, 148, 122, 146, 352, 353, 448, 136, 292, 218, 117, 45, 121, 207, 45, 145, 90, 183, 115, 134, 133, 108, 86, 77, 16, 55, 92, 54, 203, 59, 118, 128, 110, 150, 98, 46, 51, 50, 57, 9, 62, 15, 115, 102, 117, 97, 18, 173, 145, 0, 257, 76, 186, 105, 212, 47, 27, 68, 2, 82, 127, 187, 95, 119, 181, 144, 27, 389, 152, 175, 46, 131, 182, 141, 100, 152, 87, 135, 135, 100, 234, 158, 103, 81, 73, 152, 104, 92, 33, 146, 41, 66, 246, 46, 25, 202, 128, 53, 178, 393, 237, 58, 0, 139, 249, 145, 42, 113, 94, 340, 191, 159, 263, 97, 3, 133, 143, 104, 307, 91, 124, 143, 287, 205, 232, 69, 2, 236, 112, 186, 213, 44, 201, 156, 101, 191, 240, 111, 0, 258, 150, 135, 303, 198, 275, 116, 14, 326, 123, 186, 0, 47, 89, 47, 333, 173, 324, 143, 234, 138, 182, 47, 0, 51, 88, 26, 294, 64, 287, 99, 211, 1, 129, 42, 2, 92, 96, 97, 110, 96, 213, 8, 0, 0, 0, 0, 69, 0, 152, 17, 135, 0, 204, 0, 85, 0, 75, 169, 86, 4, 95, 87, 200, 0, 110, 0, 280, 53, 212, 0, 138, 0, 349, 0, 67, 0, 94, 116, 55, 43, 38, 0, 40, 117, 67, 46, 93, 21, 53, 77, 95, 102, 353, 49, 3, 370, 286, 144, 105, 47, 143, 2, 182, 309, 9, 98, 77, 116, 3, 72, 37, 107, 124, 71, 36, 1, 57, 133, 2, 86, 94, 184, 0, 107, 79, 376, 41, 64, 81, 0, 48, 91, 69, 67, 47, 9, 115, 45], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 4, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 1, 0, 0, 1, 2, 0, 0, 3, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 1, 1, 0, 3, 2, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 2, 2, 1, 1, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 5, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 3, 6, 0, 0, 2, 0, 1, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 2, 0, 5, 0, 1, 0, 3, 2, 0, 0, 2, 5, 3, 0, 1, 0, 3, 0, 2, 0, 3, 0, 7, 0, 0, 0, 4, 5, 6, 0, 1, 0, 0, 0, 3, 0, 4, 2, 0, 3, 0, 0, 2, 1, 0, 2, 11, 1, 4, 0, 3, 0, 1, 2, 1, 2, 1, 2, 0, 0, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 3, 0, 4, 0, 0, 2, 0, 0, 5, 0, 2, 1, 0, 5, 0], [29, 8, 1, 1, 8, 14, 30, 1, 1, 5, 7, 3, 7, 8, 3, 13, 7, 4, 36, 1, 36, 2, 0, 0, 6, 27, 28, 0, 14, 24, 9, 4, 24, 25, 15, 0, 2, 21, 16, 40, 8, 3, 42, 14, 18, 13, 6, 0, 52, 88, 100, 40, 46, 4, 36, 6, 12, 10, 3, 3, 230, 46, 26, 38, 1, 7, 4, 10, 5, 14, 2, 1, 39, 15, 92, 81, 37, 7, 270, 3, 31, 25, 14, 1, 298, 292, 17, 26, 1, 4, 70, 0, 53, 2, 60, 2, 0, 0, 28, 8, 29, 1, 6, 0, 0, 4, 4, 4, 13, 53, 0, 4, 4, 0, 0, 1, 5, 2, 1, 0, 6, 3, 6, 2, 4, 2, 4, 2, 0, 2, 4, 0, 9, 4, 2, 2, 3, 6, 4, 2, 0, 2, 2, 1, 2, 85, 28, 8, 0, 6, 0, 0, 6, 0, 1, 4, 2, 5, 2, 1, 2, 0, 0, 2, 0, 10, 2, 0, 43, 1, 12, 30, 28, 1, 17, 3, 1, 0, 0, 0, 26, 877, 6, 36, 8, 0, 2, 0, 0, 2, 10, 0, 136, 177, 131, 104, 156, 239, 659, 268, 462, 166, 136, 154, 27, 170, 104, 206, 115, 46, 176, 274, 597, 150, 85, 150, 140, 62, 103, 81, 3, 161, 38, 254, 94, 286, 173, 145, 70, 127, 98, 171, 5, 117, 140, 120, 79, 208, 134, 263, 367, 318, 182, 230, 440, 403, 261, 279, 25, 161, 106, 175, 324, 407, 278, 428, 345, 567, 210, 325, 56, 39, 55, 109, 212, 211, 254, 312, 167, 174, 150, 206, 61, 80, 155, 64, 122, 165, 202, 152, 296, 217, 197, 183, 175, 53, 61, 159, 11, 216, 48, 143, 274, 215, 274, 297, 205, 192, 70, 135, 238, 183, 511, 215, 218, 427, 271, 304, 227, 136, 142, 142, 185, 6, 301, 101, 303, 263, 322, 201, 235, 99, 423, 8, 323, 66, 208, 44, 164, 129, 260, 43, 1, 46, 62, 133, 116, 136, 135, 143, 52, 362, 177, 213, 104, 81, 148, 109, 85, 262, 92, 97, 78, 65, 81, 130, 128, 55, 105, 162, 183, 216, 155, 268, 110, 195, 299, 109, 101, 429, 224, 68, 122, 412, 323, 41, 1, 118, 178, 77, 46, 35, 73, 538, 175, 114, 179, 76, 2, 81, 66, 73, 685, 90, 222, 294, 223, 144, 206, 38, 4, 194, 99, 148, 169, 32, 291, 192, 85, 172, 100, 27, 2, 199, 91, 108, 364, 245, 735, 143, 0, 448, 76, 163, 0, 75, 231, 128, 704, 547, 1026, 288, 440, 299, 300, 135, 0, 113, 216, 52, 992, 141, 478, 292, 275, 6, 209, 80, 1, 158, 221, 58, 78, 68, 165, 27, 0, 50, 0, 1, 58, 0, 93, 4, 13, 0, 52, 0, 14, 0, 42, 79, 25, 2, 20, 56, 67, 0, 93, 2, 64, 17, 81, 0, 149, 0, 90, 0, 8, 0, 33, 70, 47, 74, 22, 0, 50, 57, 28, 30, 41, 21, 73, 64, 11, 33, 109, 22, 1, 110, 184, 130, 55, 25, 40, 0, 79, 83, 4, 16, 12, 63, 0, 14, 6, 60, 14, 48, 15, 2, 23, 29, 2, 31, 35, 147, 1, 24, 9, 174, 6, 52, 44, 0, 32, 32, 60, 80, 23, 8, 74, 26], [26, 2, 0, 1, 2, 7, 0, 0, 0, 5, 2, 0, 14, 21, 1, 7, 3, 2, 18, 0, 37, 4, 0, 0, 5, 35, 8, 4, 11, 65, 0, 8, 24, 33, 5, 0, 61, 11, 10, 20, 4, 4, 12, 12, 8, 10, 9, 0, 84, 93, 165, 10, 26, 20, 45, 10, 10, 1, 4, 0, 415, 73, 11, 35, 0, 11, 8, 2, 4, 6, 1, 0, 40, 32, 9, 38, 7, 4, 131, 3, 36, 4, 4, 0, 171, 598, 4, 28, 0, 0, 26, 0, 25, 0, 17, 0, 0, 1, 19, 64, 14, 2, 0, 0, 0, 3, 3, 0, 10, 41, 0, 10, 0, 1, 8, 3, 0, 2, 3, 0, 0, 26, 1, 0, 5, 11, 1, 1, 2, 1, 4, 1, 30, 14, 7, 9, 3, 1, 0, 3, 7, 2, 2, 0, 0, 39, 17, 1, 1, 1, 1, 1, 7, 4, 4, 3, 0, 1, 6, 27, 0, 5, 1, 1, 2, 1, 0, 0, 7, 0, 16, 21, 10, 3, 3, 3, 9, 2, 3, 0, 7, 379, 1, 30, 25, 0, 7, 2, 0, 0, 6, 0, 120, 159, 59, 33, 80, 89, 4, 124, 177, 81, 65, 60, 27, 91, 71, 120, 46, 40, 90, 102, 221, 73, 59, 90, 71, 66, 74, 43, 2, 94, 19, 157, 33, 118, 66, 60, 27, 52, 44, 91, 4, 42, 92, 61, 25, 126, 50, 178, 206, 175, 105, 122, 187, 170, 114, 169, 9, 113, 60, 74, 151, 297, 181, 191, 206, 325, 155, 150, 47, 37, 40, 43, 127, 114, 162, 202, 89, 63, 130, 120, 56, 56, 111, 57, 61, 87, 136, 93, 241, 98, 170, 76, 112, 28, 50, 133, 6, 140, 49, 105, 95, 102, 108, 112, 91, 82, 18, 64, 78, 65, 218, 73, 74, 164, 103, 122, 84, 58, 47, 46, 67, 7, 92, 1, 116, 92, 153, 122, 1, 53, 144, 0, 155, 71, 101, 60, 68, 61, 1, 19, 0, 26, 26, 87, 70, 82, 122, 66, 11, 225, 77, 76, 68, 33, 76, 79, 48, 109, 40, 79, 70, 33, 51, 56, 78, 19, 44, 101, 75, 78, 43, 115, 32, 118, 147, 51, 45, 216, 126, 63, 56, 233, 152, 23, 0, 62, 88, 33, 20, 35, 45, 236, 89, 69, 83, 49, 0, 30, 48, 23, 359, 59, 111, 174, 133, 96, 199, 36, 0, 146, 75, 95, 95, 21, 171, 129, 44, 91, 80, 25, 0, 124, 67, 46, 146, 109, 391, 42, 2, 292, 33, 93, 0, 27, 87, 44, 326, 263, 344, 165, 189, 133, 118, 63, 0, 41, 103, 22, 503, 76, 168, 124, 140, 6, 86, 51, 0, 61, 91, 36, 73, 41, 88, 16, 0, 0, 0, 0, 62, 0, 73, 11, 10, 0, 114, 0, 34, 0, 28, 99, 80, 2, 45, 156, 140, 0, 58, 1, 145, 12, 111, 0, 71, 0, 242, 0, 50, 0, 94, 118, 103, 65, 49, 0, 42, 143, 71, 80, 109, 39, 43, 130, 38, 81, 186, 27, 0, 161, 324, 108, 177, 20, 92, 0, 96, 169, 4, 46, 31, 61, 2, 57, 25, 67, 76, 53, 32, 1, 43, 79, 1, 46, 59, 155, 0, 80, 42, 242, 3, 83, 112, 0, 36, 54, 99, 115, 64, 12, 212, 67], [6, 2, 0, 1, 1, 3, 0, 0, 0, 2, 0, 0, 8, 6, 2, 0, 0, 2, 4, 0, 14, 2, 0, 0, 6, 8, 0, 0, 0, 8, 0, 1, 6, 5, 3, 0, 49, 6, 3, 2, 2, 2, 8, 0, 4, 0, 0, 0, 39, 32, 1, 12, 15, 6, 0, 4, 2, 0, 2, 1, 88, 23, 0, 14, 0, 4, 2, 0, 2, 8, 1, 1, 30, 2, 7, 2, 6, 0, 67, 2, 1, 2, 0, 0, 51, 92, 0, 0, 0, 2, 14, 0, 13, 0, 8, 0, 3, 0, 23, 34, 22, 0, 0, 0, 4, 0, 0, 0, 4, 12, 0, 8, 0, 0, 4, 0, 2, 6, 2, 0, 0, 10, 1, 0, 0, 8, 4, 0, 0, 0, 4, 0, 19, 10, 0, 12, 0, 0, 0, 0, 4, 0, 2, 0, 2, 18, 17, 0, 3, 4, 0, 0, 2, 0, 2, 2, 3, 4, 6, 24, 0, 0, 2, 2, 0, 0, 0, 0, 20, 0, 6, 24, 7, 0, 4, 0, 4, 1, 0, 0, 2, 371, 18, 12, 14, 0, 4, 2, 1, 0, 3, 0, 134, 108, 65, 37, 144, 175, 1, 149, 167, 64, 72, 90, 24, 118, 55, 116, 75, 53, 79, 125, 304, 93, 50, 103, 80, 76, 118, 38, 0, 85, 19, 79, 59, 125, 64, 101, 43, 51, 35, 102, 2, 55, 67, 96, 42, 101, 84, 179, 151, 248, 123, 124, 152, 136, 94, 160, 12, 59, 52, 87, 162, 318, 173, 274, 190, 340, 122, 120, 44, 23, 27, 53, 97, 104, 246, 250, 70, 70, 87, 144, 39, 54, 108, 32, 47, 104, 184, 118, 195, 111, 181, 44, 80, 24, 61, 95, 2, 132, 19, 61, 129, 72, 141, 180, 149, 120, 22, 51, 56, 109, 165, 63, 85, 131, 96, 223, 89, 57, 71, 62, 97, 6, 96, 71, 102, 84, 191, 65, 0, 103, 129, 0, 209, 43, 65, 37, 125, 113, 2, 47, 0, 30, 11, 40, 59, 51, 131, 46, 15, 142, 34, 128, 69, 38, 63, 55, 49, 85, 40, 50, 16, 35, 13, 80, 42, 25, 33, 102, 174, 36, 30, 130, 22, 88, 134, 43, 44, 151, 90, 80, 43, 321, 210, 58, 0, 32, 46, 36, 22, 41, 39, 382, 181, 66, 65, 38, 1, 42, 12, 38, 266, 16, 107, 134, 73, 81, 72, 32, 2, 102, 43, 92, 76, 20, 161, 129, 36, 79, 40, 16, 0, 69, 43, 102, 182, 160, 606, 42, 2, 341, 27, 29, 0, 32, 116, 91, 647, 273, 193, 179, 200, 150, 138, 59, 0, 133, 98, 16, 427, 79, 205, 223, 110, 4, 50, 98, 1, 87, 47, 65, 83, 56, 130, 19, 0, 2, 0, 0, 24, 0, 65, 12, 50, 0, 105, 0, 20, 0, 26, 72, 47, 0, 54, 170, 126, 0, 58, 0, 103, 10, 77, 0, 24, 0, 199, 2, 50, 0, 112, 118, 121, 35, 38, 0, 38, 118, 65, 80, 85, 30, 30, 122, 37, 82, 158, 24, 0, 170, 317, 92, 156, 26, 81, 0, 68, 135, 4, 64, 26, 38, 2, 50, 28, 46, 46, 38, 20, 2, 41, 62, 0, 25, 66, 86, 0, 76, 20, 94, 2, 90, 96, 0, 26, 70, 64, 107, 40, 2, 186, 53], [204, 3, 0, 0, 13, 8, 0, 0, 0, 9, 0, 2, 32, 38, 3, 1, 9, 3, 49, 3, 10, 15, 1, 1, 6, 63, 12, 7, 33, 75, 0, 13, 27, 15, 39, 0, 76, 16, 7, 48, 9, 15, 47, 45, 9, 13, 18, 2, 193, 143, 335, 40, 48, 15, 100, 78, 16, 20, 10, 0, 313, 81, 42, 76, 0, 12, 31, 19, 8, 6, 0, 0, 15, 57, 9, 34, 7, 14, 108, 2, 55, 4, 3, 0, 76, 216, 4, 12, 0, 1, 37, 0, 14, 1, 6, 1, 9, 2, 53, 55, 11, 3, 0, 0, 3, 1, 3, 4, 6, 67, 0, 10, 6, 1, 18, 0, 0, 0, 4, 1, 0, 25, 12, 0, 4, 5, 19, 6, 2, 3, 0, 1, 16, 0, 25, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 67, 31, 12, 0, 23, 4, 0, 49, 0, 6, 4, 0, 18, 22, 38, 0, 2, 3, 3, 0, 3, 0, 0, 10, 1, 0, 11, 10, 0, 1, 3, 0, 0, 0, 0, 5, 165, 3, 0, 2, 0, 1, 1, 0, 2, 1, 0, 343, 134, 131, 47, 232, 68, 1, 263, 124, 74, 168, 115, 108, 168, 116, 147, 95, 118, 98, 154, 126, 134, 91, 134, 102, 197, 194, 118, 7, 138, 52, 203, 81, 55, 49, 48, 15, 33, 52, 54, 0, 28, 191, 36, 39, 250, 91, 179, 226, 228, 85, 205, 327, 192, 101, 256, 12, 179, 94, 149, 233, 251, 170, 218, 316, 254, 184, 169, 29, 119, 85, 57, 169, 136, 158, 305, 91, 68, 163, 258, 105, 81, 165, 100, 93, 126, 310, 250, 446, 235, 262, 173, 100, 49, 110, 175, 10, 216, 83, 190, 69, 98, 107, 77, 78, 64, 7, 44, 76, 80, 141, 52, 68, 81, 59, 68, 60, 36, 36, 24, 47, 0, 47, 35, 73, 92, 81, 78, 1, 165, 102, 0, 209, 66, 131, 78, 170, 59, 0, 62, 0, 35, 76, 121, 105, 104, 98, 102, 10, 227, 121, 185, 34, 101, 125, 131, 100, 102, 42, 141, 81, 94, 85, 165, 129, 40, 54, 133, 54, 59, 27, 75, 24, 47, 124, 29, 53, 151, 116, 65, 76, 377, 233, 44, 0, 103, 112, 99, 21, 181, 97, 247, 203, 99, 75, 53, 0, 37, 131, 52, 234, 34, 151, 160, 139, 77, 164, 32, 0, 302, 92, 188, 104, 24, 156, 213, 64, 96, 193, 60, 0, 149, 128, 126, 150, 174, 231, 48, 10, 294, 92, 101, 0, 24, 66, 39, 201, 144, 132, 102, 133, 100, 83, 22, 0, 41, 58, 15, 177, 33, 159, 93, 77, 3, 30, 19, 0, 73, 64, 151, 95, 130, 163, 9, 0, 1, 0, 0, 24, 0, 54, 21, 18, 0, 55, 0, 22, 0, 18, 42, 39, 0, 29, 28, 64, 0, 36, 0, 82, 17, 37, 0, 48, 0, 82, 0, 25, 0, 15, 34, 20, 21, 4, 0, 3, 34, 12, 7, 12, 4, 17, 34, 33, 26, 108, 37, 0, 111, 89, 57, 91, 17, 47, 1, 45, 96, 0, 57, 24, 47, 0, 25, 10, 46, 36, 15, 12, 1, 18, 43, 0, 21, 40, 54, 0, 67, 44, 191, 13, 30, 31, 0, 9, 18, 13, 27, 26, 3, 47, 18], [1176, 53, 0, 5, 83, 68, 1, 0, 0, 39, 16, 6, 45, 48, 15, 50, 24, 58, 267, 21, 67, 63, 6, 0, 79, 501, 65, 4, 35, 166, 7, 72, 204, 300, 275, 0, 132, 23, 47, 60, 32, 18, 39, 56, 21, 5, 107, 0, 227, 116, 196, 89, 79, 15, 130, 272, 40, 30, 35, 0, 202, 169, 39, 115, 5, 12, 184, 17, 17, 14, 2, 0, 78, 109, 25, 58, 7, 65, 548, 2, 189, 55, 14, 0, 135, 300, 20, 102, 0, 3, 110, 0, 56, 0, 95, 1, 44, 0, 458, 602, 452, 4, 1, 2, 16, 33, 26, 35, 274, 291, 3, 95, 12, 22, 111, 53, 18, 38, 51, 1, 25, 465, 28, 7, 234, 7, 51, 60, 36, 11, 85, 19, 229, 253, 113, 184, 1, 29, 5, 2, 84, 5, 27, 4, 25, 455, 758, 51, 6, 24, 79, 34, 283, 63, 35, 56, 4, 46, 147, 442, 5, 58, 12, 42, 27, 21, 8, 4, 72, 3, 2, 69, 25, 1, 13, 6, 44, 6, 10, 0, 3, 1416, 18, 95, 282, 3, 20, 41, 0, 2, 18, 0, 2778, 1531, 1205, 914, 2233, 810, 80, 3109, 1411, 1251, 1627, 1290, 1181, 2164, 1330, 1401, 850, 1089, 919, 1472, 1270, 1677, 654, 1577, 1301, 1723, 2169, 1284, 92, 1554, 741, 2349, 889, 749, 517, 511, 259, 379, 430, 749, 17, 374, 1418, 473, 296, 1837, 943, 1924, 2242, 1881, 1399, 1821, 2637, 1914, 1649, 3509, 111, 2274, 1046, 1394, 2853, 3083, 1667, 2511, 3097, 3198, 2443, 2085, 678, 911, 948, 591, 1572, 1769, 1891, 2720, 1236, 1085, 1694, 3216, 1460, 958, 2282, 962, 1372, 1271, 3272, 2936, 3855, 2056, 2427, 2163, 1488, 632, 1098, 2029, 338, 2105, 1204, 1378, 982, 1062, 1218, 979, 688, 724, 141, 559, 730, 757, 1600, 555, 712, 1114, 922, 983, 586, 560, 457, 388, 648, 28, 777, 366, 975, 715, 1051, 739, 16, 2165, 1008, 2, 2598, 567, 1836, 836, 2448, 582, 20, 1190, 2, 765, 1023, 1308, 953, 1118, 1289, 1334, 180, 2897, 1255, 1393, 533, 992, 1333, 1244, 1162, 1041, 732, 1413, 784, 1148, 1296, 1471, 1020, 569, 771, 1379, 748, 568, 262, 679, 252, 673, 2062, 429, 319, 2330, 1469, 584, 1195, 3181, 2059, 803, 2, 1524, 1636, 1329, 195, 1504, 935, 3211, 1956, 1125, 1493, 923, 1, 892, 1640, 787, 2742, 823, 2034, 1454, 1776, 1390, 2166, 823, 0, 2194, 1164, 2284, 1708, 418, 1828, 1626, 819, 1237, 1908, 853, 1, 2119, 1392, 1347, 2448, 1809, 2091, 851, 157, 2692, 1047, 1550, 0, 398, 928, 522, 2155, 1448, 1723, 1102, 1351, 966, 1038, 527, 1, 555, 811, 325, 2796, 556, 1581, 1140, 1316, 13, 709, 391, 1, 629, 918, 1592, 759, 1001, 1476, 205, 0, 0, 0, 1, 83, 0, 3, 77, 454, 2, 172, 0, 136, 0, 74, 260, 201, 3, 130, 207, 314, 3, 142, 1, 8, 73, 375, 0, 171, 0, 614, 1, 200, 0, 176, 1, 115, 7, 79, 0, 104, 2, 192, 102, 110, 33, 2, 119, 94, 89, 2, 0, 1, 26, 798, 208, 496, 81, 403, 31, 280, 426, 25, 215, 155, 201, 17, 181, 93, 3, 245, 0, 263, 1, 112, 355, 5, 151, 0, 302, 1, 167, 148, 619, 131, 95, 104, 0, 39, 139, 1, 153, 162, 14, 1, 49], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 206, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 113, 0, 0, 3, 0, 0, 13, 4, 1, 0, 1, 106, 0, 1, 0, 0, 0, 0, 9, 0, 5, 0, 36, 0, 7, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 11, 2, 0, 0, 5, 0, 0, 0, 1, 1, 0, 3, 0, 12, 0, 0, 0, 0, 11, 0, 0, 1, 0, 24, 1, 4, 0, 0, 0, 0, 0, 6, 0, 0, 86, 0, 2, 37, 1, 0, 0, 5, 0, 0, 0, 0, 0, 1043, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 318, 208, 142, 325, 139, 69, 469, 489, 117, 229, 119, 54, 290, 189, 154, 69, 140, 241, 158, 613, 250, 59, 226, 197, 184, 163, 90, 6, 114, 69, 406, 109, 172, 98, 158, 35, 55, 179, 118, 6, 62, 127, 97, 49, 202, 83, 196, 480, 573, 183, 168, 620, 517, 437, 574, 86, 365, 180, 106, 553, 794, 210, 321, 325, 454, 233, 141, 111, 143, 116, 164, 282, 343, 406, 298, 105, 245, 297, 178, 90, 146, 283, 59, 189, 129, 450, 169, 361, 195, 314, 174, 225, 87, 164, 176, 28, 432, 134, 266, 148, 110, 169, 156, 138, 114, 37, 94, 247, 260, 584, 212, 280, 447, 162, 241, 142, 247, 198, 165, 106, 14, 295, 60, 354, 266, 266, 298, 31, 106, 180, 1, 452, 127, 151, 113, 91, 234, 15, 106, 0, 51, 96, 257, 190, 242, 108, 190, 179, 606, 251, 117, 67, 128, 270, 192, 181, 322, 122, 124, 174, 69, 207, 216, 197, 0, 181, 0, 171, 230, 173, 126, 97, 123, 192, 126, 223, 312, 251, 82, 84, 581, 179, 50, 1, 138, 277, 132, 364, 132, 116, 308, 156, 197, 224, 128, 1, 151, 81, 113, 691, 161, 174, 474, 377, 252, 4, 90, 0, 139, 152, 169, 246, 24, 462, 187, 107, 298, 100, 92, 1, 323, 73, 90, 256, 348, 923, 208, 3, 600, 100, 208, 0, 73, 277, 184, 912, 624, 898, 408, 254, 196, 306, 172, 0, 92, 268, 122, 1060, 216, 541, 452, 191, 7, 317, 57, 0, 100, 116, 87, 73, 67, 274, 38, 0, 1, 0, 0, 109, 0, 182, 33, 96, 0, 165, 0, 89, 0, 69, 169, 83, 0, 87, 252, 156, 0, 96, 0, 206, 28, 137, 0, 171, 0, 277, 0, 92, 0, 115, 121, 228, 131, 94, 0, 83, 147, 175, 85, 126, 62, 97, 183, 78, 86, 230, 82, 2, 318, 522, 209, 262, 58, 116, 5, 193, 132, 67, 72, 35, 128, 3, 104, 63, 84, 87, 88, 99, 4, 78, 120, 1, 59, 104, 266, 0, 138, 104, 310, 7, 127, 106, 0, 128, 108, 188, 267, 110, 14, 187, 60], [80, 12, 0, 2, 11, 39, 3, 0, 0, 11, 6, 3, 22, 18, 9, 10, 16, 18, 66, 8, 74, 14, 1, 1, 183, 90, 26, 7, 29, 131, 1, 20, 75, 46, 28, 0, 154, 18, 23, 65, 27, 26, 44, 35, 34, 8, 20, 0, 188, 182, 343, 37, 64, 29, 85, 49, 33, 9, 15, 0, 418, 148, 31, 97, 2, 20, 38, 19, 17, 13, 4, 0, 51, 60, 58, 87, 12, 24, 293, 4, 78, 15, 17, 0, 173, 593, 13, 56, 0, 1, 67, 0, 39, 0, 63, 0, 7, 1, 73, 16, 4, 8, 1, 0, 5, 3, 0, 1, 3, 91, 0, 1, 5, 1, 1, 0, 6, 2, 7, 0, 59, 2, 1, 0, 0, 2, 3, 0, 12, 2, 0, 0, 4, 2, 32, 0, 0, 0, 3, 1, 0, 0, 0, 0, 3, 8, 2, 6, 0, 13, 2, 1, 13, 1, 0, 0, 0, 23, 3, 12, 0, 3, 0, 0, 1, 12, 7, 0, 38, 0, 0, 68, 43, 0, 18, 11, 0, 0, 2, 0, 0, 729, 2, 0, 2, 0, 0, 1, 0, 0, 0, 0, 276, 244, 177, 129, 215, 256, 119, 371, 441, 215, 210, 167, 108, 221, 154, 224, 105, 127, 170, 308, 501, 211, 103, 184, 165, 176, 281, 137, 9, 215, 79, 279, 102, 214, 138, 116, 75, 101, 97, 184, 6, 114, 224, 135, 99, 363, 157, 342, 355, 372, 356, 273, 533, 411, 269, 462, 218, 274, 159, 191, 418, 520, 310, 403, 484, 637, 410, 257, 106, 83, 102, 155, 313, 297, 365, 473, 202, 191, 266, 378, 199, 126, 272, 141, 142, 242, 420, 376, 586, 327, 294, 275, 296, 74, 133, 318, 29, 321, 118, 228, 233, 209, 281, 308, 239, 238, 59, 161, 186, 221, 446, 194, 153, 378, 285, 346, 201, 146, 150, 96, 170, 12, 258, 98, 242, 222, 258, 215, 22, 195, 291, 0, 477, 129, 343, 119, 231, 173, 23, 108, 0, 109, 81, 196, 183, 156, 155, 147, 259, 472, 183, 186, 175, 125, 213, 159, 140, 228, 103, 198, 141, 117, 157, 188, 156, 79, 95, 238, 220, 162, 135, 207, 92, 186, 331, 79, 115, 560, 274, 105, 145, 526, 348, 111, 0, 255, 295, 154, 363, 169, 122, 707, 268, 178, 235, 117, 1, 152, 202, 92, 750, 169, 339, 369, 363, 209, 409, 112, 0, 305, 190, 306, 212, 48, 398, 271, 106, 269, 260, 97, 0, 345, 166, 218, 483, 317, 714, 180, 5, 533, 108, 198, 1, 77, 252, 177, 761, 559, 704, 364, 402, 265, 272, 167, 0, 169, 272, 107, 887, 161, 509, 349, 372, 3, 224, 114, 2, 163, 279, 142, 128, 106, 224, 58, 0, 7, 1, 1, 45, 0, 109, 30, 80, 0, 79, 0, 33, 0, 30, 125, 50, 0, 61, 157, 91, 0, 62, 0, 159, 26, 98, 1, 113, 0, 174, 0, 54, 0, 55, 64, 123, 68, 45, 0, 42, 116, 117, 43, 110, 30, 52, 119, 44, 59, 166, 54, 1, 233, 341, 111, 145, 31, 86, 1, 95, 116, 55, 46, 25, 89, 10, 66, 45, 63, 52, 75, 92, 5, 68, 98, 1, 33, 59, 173, 1, 82, 60, 257, 8, 92, 70, 1, 54, 53, 127, 198, 79, 12, 179, 40], [13, 8, 0, 0, 2, 14, 0, 0, 0, 2, 2, 0, 12, 16, 0, 5, 3, 4, 9, 1, 15, 3, 0, 0, 4, 21, 7, 2, 11, 19, 4, 11, 22, 13, 4, 2, 40, 12, 6, 12, 3, 8, 15, 2, 12, 3, 3, 0, 30, 36, 128, 5, 12, 9, 16, 4, 1, 6, 5, 0, 159, 33, 6, 11, 0, 2, 7, 2, 1, 5, 1, 0, 24, 8, 5, 26, 5, 3, 109, 3, 32, 7, 2, 0, 70, 288, 14, 5, 0, 0, 6, 0, 10, 0, 9, 0, 1, 2, 36, 34, 10, 1, 0, 0, 5, 2, 3, 0, 7, 40, 0, 17, 0, 0, 3, 0, 2, 2, 1, 1, 4, 19, 0, 0, 8, 5, 1, 3, 1, 3, 1, 1, 30, 13, 3, 11, 0, 0, 1, 1, 3, 0, 1, 0, 1, 24, 30, 3, 3, 3, 2, 3, 13, 3, 0, 0, 0, 10, 0, 35, 0, 3, 1, 1, 3, 8, 1, 0, 38, 1, 4, 26, 8, 4, 6, 1, 3, 1, 1, 0, 3, 414, 0, 14, 21, 0, 4, 2, 0, 2, 2, 0, 1, 131, 66, 50, 88, 49, 1, 137, 228, 40, 85, 32, 16, 88, 71, 47, 16, 32, 85, 47, 248, 63, 22, 79, 64, 49, 44, 25, 3, 45, 24, 119, 46, 41, 26, 68, 12, 20, 46, 37, 5, 29, 44, 25, 15, 59, 31, 102, 158, 165, 75, 47, 198, 155, 127, 151, 8, 126, 55, 27, 209, 307, 54, 83, 83, 156, 90, 49, 31, 36, 45, 60, 125, 97, 136, 99, 26, 65, 111, 73, 31, 46, 97, 32, 83, 50, 139, 80, 98, 55, 126, 49, 122, 25, 50, 67, 7, 111, 36, 86, 48, 44, 67, 65, 63, 36, 7, 20, 70, 106, 194, 71, 73, 134, 48, 81, 37, 46, 58, 53, 45, 0, 87, 10, 91, 79, 66, 83, 0, 26, 77, 0, 157, 88, 53, 37, 36, 64, 0, 35, 0, 7, 27, 83, 78, 64, 66, 45, 9, 184, 91, 35, 30, 30, 89, 71, 52, 112, 36, 35, 56, 23, 52, 84, 81, 0, 52, 0, 44, 78, 36, 37, 36, 42, 56, 38, 54, 134, 102, 62, 22, 195, 70, 13, 0, 62, 75, 48, 11, 35, 38, 147, 45, 63, 101, 61, 0, 51, 26, 46, 335, 27, 37, 151, 146, 72, 3, 34, 1, 56, 67, 59, 105, 9, 171, 76, 34, 99, 30, 37, 0, 112, 27, 29, 105, 99, 276, 50, 1, 193, 34, 83, 0, 28, 67, 65, 374, 257, 265, 147, 58, 69, 127, 64, 0, 30, 119, 52, 399, 59, 226, 137, 69, 1, 90, 31, 0, 37, 59, 19, 29, 21, 88, 19, 0, 1, 0, 0, 38, 0, 62, 20, 36, 0, 54, 0, 30, 0, 22, 81, 41, 0, 48, 100, 64, 0, 22, 1, 82, 12, 51, 0, 64, 0, 103, 0, 51, 0, 41, 39, 86, 40, 39, 0, 39, 65, 61, 29, 74, 12, 59, 78, 23, 45, 74, 38, 0, 120, 237, 84, 87, 15, 92, 0, 75, 57, 7, 14, 17, 46, 0, 31, 32, 34, 22, 37, 41, 6, 44, 46, 3, 25, 33, 79, 0, 57, 31, 145, 2, 54, 53, 0, 26, 40, 77, 119, 46, 9, 94, 16], [421, 19, 3, 2, 39, 29, 0, 1, 1, 6, 5, 8, 34, 45, 3, 30, 21, 20, 87, 0, 33, 21, 2, 1, 8, 80, 33, 0, 20, 155, 0, 7, 87, 31, 53, 1, 146, 23, 31, 24, 23, 11, 83, 16, 19, 14, 22, 1, 203, 126, 417, 107, 58, 14, 160, 105, 27, 7, 46, 1, 360, 229, 47, 134, 0, 9, 54, 35, 10, 13, 5, 1, 47, 49, 14, 47, 11, 30, 161, 9, 36, 6, 16, 1, 110, 460, 13, 62, 3, 0, 35, 1, 16, 3, 21, 2, 38, 0, 137, 18, 16, 0, 0, 6, 7, 9, 1, 3, 6, 119, 1, 0, 11, 12, 5, 1, 21, 0, 8, 2, 10, 2, 6, 8, 0, 1, 59, 3, 14, 2, 0, 1, 11, 2, 23, 4, 0, 7, 10, 4, 0, 0, 0, 0, 11, 30, 3, 67, 32, 11, 10, 5, 98, 9, 5, 3, 11, 27, 27, 35, 2, 23, 0, 18, 0, 7, 12, 0, 36, 3, 2, 73, 21, 0, 6, 8, 3, 0, 2, 0, 4, 392, 5, 2, 0, 0, 0, 3, 0, 3, 0, 2, 343, 246, 156, 143, 390, 158, 3, 486, 256, 271, 320, 267, 110, 424, 234, 279, 108, 197, 167, 331, 226, 358, 140, 310, 238, 264, 277, 157, 4, 270, 126, 391, 166, 117, 84, 82, 49, 53, 112, 81, 3, 67, 292, 72, 32, 279, 157, 245, 472, 433, 193, 200, 516, 378, 260, 624, 4, 445, 210, 281, 499, 583, 333, 528, 640, 422, 361, 314, 149, 136, 176, 100, 360, 316, 482, 408, 198, 288, 357, 464, 176, 220, 397, 210, 282, 232, 628, 457, 478, 302, 491, 343, 341, 75, 210, 182, 49, 487, 218, 278, 128, 109, 175, 178, 109, 113, 12, 76, 98, 98, 261, 125, 140, 271, 143, 197, 105, 123, 89, 72, 73, 6, 109, 52, 278, 126, 213, 123, 1, 288, 213, 0, 641, 102, 281, 169, 470, 132, 0, 227, 3, 90, 188, 292, 117, 188, 187, 194, 34, 345, 256, 192, 68, 235, 175, 177, 264, 183, 117, 283, 119, 202, 300, 344, 218, 94, 173, 191, 158, 156, 38, 129, 60, 96, 255, 91, 111, 439, 330, 103, 260, 830, 280, 103, 1, 212, 384, 245, 46, 217, 177, 519, 318, 372, 235, 221, 3, 176, 285, 179, 454, 131, 376, 211, 279, 264, 196, 152, 1, 284, 238, 376, 301, 70, 315, 350, 201, 324, 451, 167, 0, 458, 250, 247, 488, 367, 489, 194, 16, 364, 170, 304, 1, 96, 140, 115, 345, 363, 284, 243, 267, 271, 216, 103, 0, 61, 205, 38, 497, 93, 427, 173, 218, 3, 129, 68, 0, 130, 203, 270, 117, 168, 294, 24, 0, 2, 0, 2, 136, 0, 251, 78, 250, 0, 177, 2, 170, 0, 108, 222, 56, 2, 158, 171, 135, 0, 79, 0, 329, 48, 152, 0, 179, 0, 304, 0, 118, 0, 99, 79, 97, 66, 22, 0, 30, 75, 112, 57, 89, 43, 66, 91, 123, 103, 242, 92, 2, 529, 521, 194, 177, 58, 144, 0, 147, 203, 10, 102, 46, 177, 18, 142, 70, 135, 123, 105, 109, 6, 80, 150, 8, 102, 153, 222, 2, 191, 101, 381, 34, 68, 71, 0, 33, 90, 115, 120, 53, 6, 134, 42], [50, 3, 0, 2, 0, 16, 13, 0, 0, 4, 8, 2, 20, 13, 1, 3, 6, 4, 21, 1, 18, 13, 1, 0, 7, 24, 16, 3, 12, 59, 0, 9, 21, 36, 6, 0, 55, 13, 10, 33, 18, 7, 43, 15, 9, 8, 11, 0, 56, 78, 105, 17, 31, 11, 36, 7, 4, 4, 7, 0, 228, 59, 11, 65, 1, 9, 10, 4, 3, 11, 0, 0, 36, 41, 32, 52, 6, 27, 148, 5, 60, 13, 17, 0, 121, 331, 8, 44, 0, 1, 52, 0, 11, 0, 21, 0, 0, 1, 28, 81, 17, 2, 5, 0, 6, 2, 9, 1, 13, 48, 0, 4, 0, 0, 8, 1, 0, 2, 4, 0, 3, 43, 4, 0, 2, 8, 3, 3, 1, 2, 0, 2, 45, 25, 10, 38, 2, 7, 0, 2, 10, 0, 0, 1, 0, 53, 42, 2, 4, 2, 6, 3, 15, 4, 6, 2, 0, 6, 10, 60, 0, 5, 1, 2, 4, 4, 5, 1, 34, 3, 36, 21, 36, 8, 10, 5, 15, 2, 1, 0, 12, 404, 8, 63, 41, 3, 7, 10, 0, 3, 7, 0, 75, 71, 49, 43, 49, 142, 258, 115, 241, 48, 48, 62, 23, 61, 46, 81, 28, 28, 74, 109, 231, 51, 46, 56, 45, 41, 61, 34, 1, 69, 13, 100, 40, 94, 71, 58, 34, 50, 52, 90, 2, 57, 59, 60, 35, 124, 51, 92, 130, 147, 133, 101, 202, 114, 96, 128, 6, 61, 42, 75, 151, 246, 146, 166, 125, 313, 121, 110, 21, 29, 30, 48, 117, 118, 104, 173, 67, 59, 99, 75, 38, 49, 63, 46, 44, 63, 97, 65, 187, 104, 90, 69, 71, 18, 24, 126, 2, 79, 25, 71, 138, 77, 98, 137, 95, 73, 46, 53, 103, 91, 204, 84, 85, 156, 132, 137, 108, 59, 78, 46, 63, 3, 119, 44, 128, 108, 168, 96, 52, 33, 181, 0, 141, 32, 85, 29, 62, 78, 77, 19, 0, 23, 17, 52, 72, 64, 47, 66, 12, 145, 70, 84, 65, 32, 61, 51, 39, 100, 31, 50, 48, 24, 46, 45, 47, 36, 35, 74, 119, 81, 75, 105, 45, 103, 107, 48, 41, 198, 90, 30, 39, 197, 120, 12, 1, 69, 86, 32, 15, 23, 38, 243, 78, 57, 77, 30, 0, 38, 31, 23, 312, 57, 95, 149, 132, 70, 156, 22, 0, 83, 54, 67, 53, 12, 149, 72, 30, 97, 68, 10, 0, 85, 54, 56, 162, 95, 283, 35, 1, 205, 23, 52, 1, 27, 77, 76, 339, 236, 354, 125, 172, 133, 118, 53, 0, 69, 74, 29, 425, 55, 168, 146, 166, 1, 77, 48, 0, 65, 103, 37, 25, 36, 75, 20, 0, 47, 0, 0, 54, 0, 64, 7, 39, 0, 49, 1, 25, 0, 24, 74, 33, 0, 31, 84, 59, 0, 38, 1, 72, 8, 59, 0, 72, 0, 97, 0, 31, 0, 37, 55, 85, 50, 37, 0, 42, 72, 72, 29, 77, 23, 41, 71, 30, 22, 79, 31, 1, 113, 232, 75, 102, 31, 35, 0, 55, 45, 8, 28, 20, 43, 0, 41, 27, 40, 30, 35, 39, 1, 24, 47, 2, 18, 31, 117, 0, 56, 18, 166, 1, 42, 51, 0, 49, 57, 93, 127, 62, 10, 125, 28], [211, 2, 0, 4, 2, 28, 0, 4, 2, 25, 8, 1, 14, 31, 3, 16, 15, 12, 58, 3, 55, 10, 7, 0, 77, 46, 27, 1, 27, 122, 3, 15, 35, 101, 28, 1, 56, 33, 44, 34, 20, 13, 69, 32, 5, 15, 26, 4, 209, 168, 170, 49, 41, 16, 103, 44, 24, 6, 31, 0, 303, 115, 32, 134, 0, 7, 32, 20, 12, 19, 4, 2, 57, 46, 48, 47, 18, 24, 93, 11, 22, 8, 18, 4, 123, 492, 16, 41, 2, 9, 44, 0, 17, 2, 40, 1, 8, 0, 97, 4, 2, 6, 6, 0, 8, 6, 0, 0, 1, 157, 1, 1, 6, 5, 1, 1, 17, 2, 19, 3, 26, 6, 1, 0, 1, 0, 1, 1, 6, 2, 2, 1, 2, 3, 48, 3, 1, 1, 8, 0, 0, 1, 0, 1, 2, 1, 1, 16, 0, 6, 1, 6, 11, 1, 0, 1, 4, 15, 1, 1, 0, 0, 0, 1, 1, 9, 0, 0, 17, 3, 3, 62, 24, 0, 18, 4, 2, 0, 0, 0, 2, 656, 2, 3, 2, 0, 1, 0, 0, 2, 0, 0, 309, 222, 203, 118, 261, 171, 101, 309, 298, 181, 248, 198, 131, 237, 166, 226, 136, 131, 112, 260, 364, 238, 167, 171, 166, 214, 278, 129, 3, 157, 53, 254, 114, 142, 105, 111, 67, 81, 103, 178, 3, 106, 192, 141, 54, 232, 154, 295, 372, 277, 237, 262, 306, 340, 267, 520, 151, 349, 148, 188, 363, 537, 248, 371, 370, 490, 295, 315, 125, 137, 155, 92, 220, 317, 265, 357, 206, 182, 234, 461, 222, 159, 330, 186, 162, 214, 516, 346, 475, 265, 343, 278, 180, 82, 159, 307, 31, 352, 178, 196, 171, 167, 254, 216, 152, 147, 39, 130, 131, 163, 395, 155, 192, 310, 247, 225, 149, 120, 104, 86, 168, 11, 216, 81, 195, 181, 270, 155, 38, 278, 237, 0, 380, 133, 216, 111, 230, 123, 31, 126, 1, 86, 126, 216, 160, 163, 160, 170, 193, 479, 186, 157, 130, 143, 221, 192, 168, 228, 90, 172, 119, 127, 248, 174, 174, 77, 107, 234, 148, 133, 90, 175, 54, 161, 299, 94, 101, 384, 234, 54, 119, 549, 258, 80, 0, 156, 280, 131, 233, 218, 132, 451, 260, 182, 235, 147, 4, 128, 202, 118, 493, 168, 209, 311, 347, 224, 276, 109, 0, 222, 154, 285, 274, 66, 325, 218, 137, 282, 184, 140, 2, 369, 182, 192, 409, 209, 450, 144, 2, 402, 116, 109, 2, 70, 189, 113, 482, 378, 548, 265, 294, 189, 191, 96, 2, 171, 217, 76, 726, 123, 417, 276, 280, 0, 153, 60, 0, 167, 203, 187, 108, 168, 244, 30, 0, 3, 0, 0, 30, 0, 104, 29, 50, 0, 81, 0, 55, 2, 23, 86, 48, 0, 64, 87, 66, 0, 30, 0, 117, 38, 99, 0, 82, 0, 109, 0, 56, 0, 33, 91, 102, 58, 35, 0, 51, 64, 94, 46, 49, 25, 46, 78, 42, 40, 172, 59, 0, 190, 240, 107, 145, 49, 107, 0, 110, 119, 50, 66, 50, 67, 2, 61, 19, 37, 88, 54, 72, 4, 52, 73, 5, 39, 38, 141, 2, 76, 74, 164, 2, 60, 41, 0, 48, 54, 89, 147, 67, 22, 111, 30], [120, 12, 0, 5, 44, 14, 0, 0, 0, 9, 3, 0, 24, 24, 12, 27, 28, 4, 29, 3, 9, 18, 4, 0, 4, 103, 19, 6, 32, 44, 0, 10, 35, 16, 26, 0, 195, 40, 52, 23, 15, 20, 0, 2, 28, 18, 23, 0, 201, 98, 140, 8, 14, 16, 53, 62, 20, 18, 36, 2, 297, 85, 20, 68, 4, 0, 41, 12, 3, 8, 1, 1, 33, 44, 15, 22, 4, 13, 205, 6, 22, 2, 11, 1, 110, 461, 1, 30, 1, 2, 31, 0, 33, 0, 34, 1, 33, 1, 95, 107, 103, 0, 0, 2, 7, 4, 7, 4, 34, 82, 0, 22, 4, 7, 24, 8, 4, 36, 15, 3, 4, 68, 13, 0, 44, 27, 50, 18, 6, 2, 9, 4, 127, 106, 21, 10, 1, 6, 4, 3, 18, 4, 4, 8, 16, 63, 72, 21, 2, 21, 24, 12, 103, 27, 4, 25, 12, 34, 65, 98, 4, 6, 2, 10, 11, 4, 4, 2, 51, 0, 18, 16, 9, 0, 2, 3, 4, 4, 6, 0, 25, 293, 4, 36, 52, 0, 6, 9, 0, 1, 6, 0, 105, 66, 113, 150, 137, 125, 5, 431, 217, 175, 157, 64, 116, 122, 125, 24, 49, 47, 126, 158, 85, 104, 54, 116, 132, 1, 77, 99, 4, 132, 44, 1, 48, 61, 64, 24, 23, 18, 30, 30, 0, 25, 243, 31, 54, 115, 68, 194, 85, 106, 75, 0, 153, 270, 80, 328, 0, 7, 68, 97, 182, 161, 178, 175, 19, 364, 144, 220, 60, 58, 81, 91, 172, 132, 186, 24, 84, 64, 79, 157, 2, 44, 0, 68, 180, 161, 242, 144, 480, 115, 162, 353, 220, 56, 79, 245, 8, 154, 24, 81, 30, 96, 3, 120, 83, 106, 14, 84, 47, 45, 87, 20, 147, 78, 168, 0, 5, 1, 61, 21, 34, 8, 113, 58, 90, 101, 2, 52, 0, 249, 129, 0, 377, 75, 102, 36, 276, 0, 0, 71, 1, 79, 156, 62, 98, 164, 72, 194, 0, 165, 51, 54, 96, 127, 131, 110, 78, 0, 45, 80, 153, 161, 86, 1, 127, 35, 18, 97, 35, 42, 18, 4, 46, 64, 224, 22, 19, 229, 195, 54, 50, 258, 186, 134, 0, 76, 191, 186, 4, 105, 135, 463, 351, 99, 238, 98, 0, 1, 120, 99, 264, 44, 175, 176, 180, 90, 159, 3, 1, 177, 191, 1, 9, 44, 77, 82, 75, 0, 256, 18, 3, 8, 217, 245, 283, 171, 235, 72, 4, 4, 91, 264, 1, 13, 67, 77, 130, 231, 203, 169, 149, 121, 92, 109, 0, 2, 127, 37, 149, 48, 127, 3, 139, 2, 141, 38, 0, 47, 0, 2, 34, 75, 119, 0, 0, 2, 0, 1, 41, 0, 160, 42, 131, 0, 83, 0, 71, 0, 42, 123, 69, 0, 63, 106, 87, 0, 56, 2, 183, 48, 100, 0, 108, 0, 164, 0, 45, 0, 46, 43, 78, 46, 40, 0, 21, 65, 60, 38, 52, 37, 40, 51, 57, 39, 164, 64, 0, 270, 220, 120, 139, 39, 89, 2, 134, 94, 4, 56, 54, 100, 0, 55, 39, 75, 63, 56, 53, 2, 39, 68, 5, 59, 61, 114, 0, 92, 73, 199, 21, 44, 48, 0, 22, 35, 50, 88, 36, 6, 59, 29], [68, 4, 3, 5, 6, 18, 2, 2, 2, 10, 4, 4, 17, 12, 8, 12, 12, 5, 48, 5, 12, 6, 1, 2, 115, 68, 14, 4, 26, 53, 2, 9, 36, 63, 18, 0, 133, 18, 20, 56, 10, 12, 9, 0, 30, 6, 14, 0, 134, 110, 194, 12, 23, 14, 57, 28, 24, 13, 13, 1, 377, 108, 18, 54, 0, 3, 30, 15, 8, 14, 2, 0, 59, 54, 28, 41, 10, 15, 213, 15, 49, 0, 20, 1, 165, 708, 8, 40, 2, 4, 44, 0, 41, 1, 42, 2, 8, 2, 62, 59, 31, 0, 2, 0, 2, 4, 0, 6, 2, 76, 0, 14, 1, 2, 8, 8, 4, 0, 6, 3, 24, 45, 0, 1, 14, 4, 8, 5, 2, 3, 2, 0, 48, 15, 37, 23, 2, 8, 6, 2, 12, 4, 0, 0, 2, 85, 37, 10, 5, 10, 2, 0, 28, 6, 5, 8, 0, 17, 2, 39, 0, 2, 2, 0, 4, 2, 2, 0, 43, 2, 35, 35, 21, 2, 12, 10, 3, 2, 0, 3, 9, 705, 4, 5, 21, 2, 6, 4, 0, 0, 12, 0, 78, 51, 43, 26, 68, 65, 54, 84, 102, 47, 29, 55, 19, 70, 58, 29, 36, 22, 65, 86, 96, 31, 30, 51, 35, 30, 54, 29, 2, 51, 16, 57, 20, 59, 60, 28, 13, 21, 31, 42, 4, 32, 81, 30, 26, 90, 30, 60, 122, 80, 87, 71, 137, 111, 77, 146, 30, 56, 28, 66, 108, 162, 118, 108, 70, 218, 112, 80, 17, 21, 19, 28, 96, 46, 94, 125, 34, 43, 66, 181, 28, 37, 68, 30, 46, 47, 94, 76, 161, 86, 97, 77, 86, 12, 8, 124, 6, 68, 39, 68, 70, 50, 44, 60, 70, 47, 12, 59, 62, 70, 108, 36, 40, 64, 93, 63, 45, 28, 39, 26, 28, 0, 79, 18, 71, 63, 60, 60, 6, 40, 80, 0, 119, 26, 73, 21, 74, 33, 6, 32, 2, 26, 12, 58, 50, 66, 34, 72, 67, 137, 54, 52, 55, 42, 62, 43, 38, 51, 24, 37, 40, 28, 40, 43, 59, 24, 21, 60, 67, 44, 24, 51, 35, 101, 65, 31, 31, 148, 74, 29, 32, 140, 99, 20, 0, 66, 49, 46, 99, 34, 62, 198, 62, 43, 79, 30, 2, 18, 48, 35, 313, 63, 97, 132, 140, 54, 122, 20, 4, 53, 43, 29, 32, 16, 163, 49, 38, 42, 75, 16, 0, 54, 31, 36, 98, 75, 203, 34, 4, 74, 22, 51, 0, 14, 58, 58, 155, 140, 175, 90, 136, 43, 60, 31, 0, 23, 53, 23, 248, 25, 122, 42, 112, 6, 56, 43, 1, 20, 26, 26, 23, 24, 40, 14, 0, 2, 0, 0, 68, 0, 151, 19, 116, 0, 84, 0, 49, 2, 34, 101, 44, 2, 74, 211, 74, 0, 56, 0, 208, 17, 107, 0, 116, 0, 176, 0, 65, 0, 72, 88, 92, 86, 51, 0, 61, 86, 114, 52, 81, 24, 82, 143, 39, 44, 158, 53, 0, 249, 407, 130, 194, 34, 75, 0, 102, 104, 37, 52, 30, 116, 0, 83, 46, 59, 72, 86, 52, 8, 64, 92, 6, 50, 69, 202, 0, 84, 73, 303, 6, 90, 74, 0, 75, 66, 120, 161, 94, 12, 172, 28], [695, 38, 4, 19, 56, 60, 1, 4, 0, 55, 2, 6, 75, 151, 47, 54, 43, 22, 118, 23, 203, 50, 10, 0, 44, 231, 78, 28, 129, 373, 7, 48, 198, 142, 143, 3, 488, 42, 116, 111, 61, 50, 191, 52, 95, 29, 78, 0, 784, 486, 1085, 188, 268, 84, 325, 274, 129, 84, 78, 0, 969, 496, 71, 303, 12, 34, 145, 86, 15, 30, 1, 0, 85, 92, 46, 160, 28, 54, 529, 15, 147, 29, 36, 0, 342, 912, 37, 65, 0, 3, 78, 0, 55, 0, 80, 0, 31, 3, 355, 613, 548, 12, 1, 8, 9, 12, 16, 33, 176, 281, 6, 68, 12, 11, 134, 59, 18, 33, 34, 16, 28, 565, 12, 13, 140, 127, 54, 44, 36, 15, 36, 10, 271, 152, 111, 95, 4, 44, 24, 19, 80, 12, 8, 5, 15, 361, 391, 65, 47, 33, 61, 68, 191, 65, 38, 31, 5, 46, 91, 330, 7, 53, 15, 56, 22, 19, 4, 0, 74, 11, 36, 119, 58, 10, 26, 10, 22, 8, 11, 0, 11, 1036, 19, 118, 157, 5, 15, 16, 1, 2, 15, 1, 1448, 758, 633, 411, 1137, 417, 11, 1487, 646, 657, 890, 618, 623, 988, 618, 689, 431, 544, 523, 687, 561, 811, 335, 802, 654, 800, 1122, 588, 48, 760, 379, 1051, 427, 345, 298, 232, 91, 176, 186, 371, 8, 158, 889, 226, 135, 936, 488, 965, 1134, 1066, 781, 859, 1215, 1120, 802, 1747, 47, 944, 524, 721, 1258, 1570, 872, 1378, 1528, 1480, 1194, 1067, 366, 449, 473, 322, 834, 810, 839, 1213, 522, 609, 998, 1182, 630, 447, 1096, 553, 620, 672, 1533, 1314, 1650, 1008, 1184, 966, 732, 308, 549, 753, 142, 1171, 634, 796, 513, 530, 508, 455, 357, 359, 76, 268, 333, 322, 764, 284, 454, 552, 423, 559, 278, 218, 294, 182, 352, 14, 412, 176, 465, 375, 451, 394, 3, 1031, 527, 1, 1649, 445, 1045, 414, 1241, 349, 0, 622, 1, 387, 495, 685, 562, 454, 681, 554, 86, 1310, 728, 689, 276, 532, 661, 590, 592, 686, 348, 731, 425, 466, 690, 733, 570, 304, 349, 757, 336, 268, 184, 395, 156, 303, 1008, 211, 202, 1196, 899, 305, 619, 1793, 1221, 368, 0, 688, 918, 706, 102, 626, 546, 1583, 1015, 626, 770, 455, 1, 519, 826, 443, 1412, 450, 1046, 867, 891, 677, 1038, 350, 2, 1193, 716, 1231, 859, 211, 873, 938, 414, 676, 1055, 437, 0, 1299, 807, 727, 1393, 932, 1187, 462, 62, 1586, 524, 790, 0, 231, 471, 336, 1347, 831, 798, 695, 765, 510, 624, 242, 2, 263, 412, 139, 1407, 265, 849, 539, 613, 6, 411, 206, 0, 322, 378, 851, 378, 504, 727, 75, 0, 3, 0, 0, 213, 1, 456, 122, 336, 1, 268, 1, 189, 0, 136, 338, 177, 1, 234, 324, 293, 0, 210, 1, 449, 124, 303, 1, 298, 0, 494, 1, 172, 0, 144, 174, 198, 144, 85, 0, 95, 173, 171, 102, 111, 53, 125, 191, 163, 162, 538, 206, 3, 926, 664, 318, 473, 98, 333, 18, 401, 306, 21, 207, 139, 259, 15, 221, 149, 185, 213, 170, 182, 34, 175, 240, 11, 133, 199, 490, 1, 348, 190, 506, 99, 149, 120, 1, 77, 134, 188, 228, 123, 32, 211, 76], [39, 10, 1, 2, 4, 39, 22, 1, 1, 8, 5, 3, 28, 37, 6, 5, 3, 10, 45, 2, 14, 4, 1, 0, 8, 76, 30, 4, 10, 118, 1, 7, 39, 66, 22, 0, 75, 28, 3, 60, 8, 6, 29, 20, 18, 6, 18, 0, 91, 138, 215, 26, 44, 22, 70, 8, 15, 10, 9, 2, 434, 96, 14, 53, 4, 6, 10, 14, 12, 20, 5, 0, 58, 79, 81, 72, 22, 21, 270, 9, 102, 26, 22, 1, 243, 680, 28, 57, 1, 2, 71, 2, 30, 1, 35, 1, 3, 0, 50, 102, 32, 6, 19, 1, 5, 9, 12, 4, 21, 97, 2, 4, 0, 0, 9, 6, 0, 4, 9, 3, 4, 57, 2, 5, 18, 8, 0, 3, 0, 0, 5, 4, 73, 29, 9, 24, 1, 4, 0, 2, 6, 0, 7, 0, 1, 86, 69, 14, 4, 2, 4, 0, 22, 10, 5, 2, 2, 10, 14, 86, 0, 8, 4, 7, 15, 6, 4, 0, 44, 12, 83, 64, 42, 5, 16, 19, 25, 11, 4, 0, 25, 538, 5, 86, 39, 0, 14, 10, 0, 0, 10, 1, 180, 158, 98, 76, 177, 161, 555, 249, 472, 121, 95, 135, 29, 123, 121, 209, 53, 47, 151, 192, 480, 120, 61, 165, 103, 52, 130, 79, 2, 108, 33, 186, 59, 206, 133, 84, 55, 124, 126, 217, 6, 91, 187, 116, 89, 273, 133, 190, 332, 374, 256, 171, 316, 271, 195, 261, 14, 173, 108, 142, 276, 510, 272, 308, 289, 623, 230, 255, 90, 79, 69, 130, 228, 202, 218, 354, 177, 127, 218, 179, 113, 72, 143, 48, 134, 156, 209, 189, 408, 214, 204, 179, 166, 46, 56, 209, 0, 178, 69, 148, 187, 212, 237, 206, 207, 189, 71, 122, 191, 136, 357, 179, 172, 361, 271, 308, 169, 157, 102, 92, 138, 16, 196, 110, 207, 200, 353, 188, 90, 92, 254, 1, 317, 126, 272, 102, 126, 194, 169, 58, 1, 77, 53, 179, 113, 121, 95, 116, 15, 347, 112, 174, 176, 57, 124, 106, 81, 164, 57, 109, 122, 77, 70, 143, 162, 61, 69, 176, 210, 185, 179, 233, 86, 151, 385, 110, 76, 528, 296, 59, 96, 422, 323, 59, 0, 160, 201, 73, 31, 78, 101, 636, 250, 175, 165, 93, 0, 124, 97, 106, 642, 147, 283, 365, 321, 173, 327, 101, 0, 251, 133, 202, 238, 50, 383, 212, 79, 151, 143, 53, 2, 208, 132, 130, 429, 248, 612, 164, 0, 439, 54, 163, 2, 92, 259, 182, 743, 556, 936, 354, 403, 304, 281, 162, 2, 147, 245, 120, 1030, 203, 511, 311, 389, 8, 262, 101, 3, 225, 293, 37, 80, 61, 144, 46, 1, 126, 0, 0, 32, 0, 112, 33, 77, 0, 66, 0, 36, 2, 29, 102, 59, 0, 64, 135, 78, 0, 42, 0, 120, 16, 71, 0, 89, 0, 183, 0, 26, 0, 59, 71, 84, 76, 41, 2, 47, 110, 82, 45, 80, 31, 48, 105, 27, 22, 77, 39, 3, 128, 325, 85, 171, 30, 55, 0, 65, 70, 14, 30, 27, 72, 2, 63, 16, 39, 51, 37, 36, 2, 30, 67, 6, 18, 53, 113, 0, 70, 29, 319, 2, 77, 38, 0, 57, 47, 68, 119, 44, 10, 102, 25], [34, 7, 1, 2, 2, 23, 0, 1, 1, 8, 1, 4, 7, 24, 0, 2, 1, 5, 23, 2, 22, 0, 0, 0, 6, 60, 8, 12, 9, 40, 0, 12, 12, 30, 10, 0, 60, 5, 13, 30, 8, 3, 18, 11, 11, 0, 9, 3, 60, 82, 183, 12, 22, 6, 26, 28, 6, 5, 0, 2, 393, 68, 8, 50, 2, 3, 8, 6, 17, 12, 2, 1, 56, 11, 14, 64, 8, 8, 163, 3, 56, 8, 3, 3, 163, 569, 7, 64, 0, 0, 49, 1, 30, 3, 19, 2, 3, 1, 26, 110, 39, 0, 0, 1, 14, 2, 3, 0, 16, 33, 1, 14, 2, 0, 8, 2, 3, 4, 2, 2, 2, 80, 0, 0, 25, 5, 0, 2, 0, 4, 7, 6, 37, 30, 11, 27, 1, 0, 1, 2, 15, 2, 2, 1, 0, 77, 43, 4, 2, 8, 1, 5, 39, 6, 4, 6, 0, 1, 12, 58, 0, 5, 0, 1, 0, 5, 4, 2, 29, 10, 18, 38, 15, 0, 15, 5, 0, 2, 8, 0, 14, 581, 10, 63, 46, 0, 8, 4, 0, 0, 11, 2, 92, 145, 69, 56, 108, 139, 0, 154, 223, 64, 61, 75, 12, 54, 73, 85, 37, 26, 65, 126, 276, 75, 58, 67, 52, 42, 99, 47, 0, 76, 14, 165, 29, 97, 84, 71, 22, 47, 53, 48, 2, 68, 81, 69, 60, 154, 45, 146, 168, 147, 189, 87, 191, 193, 164, 196, 4, 98, 59, 58, 168, 343, 147, 193, 207, 322, 149, 111, 38, 52, 26, 42, 150, 136, 156, 258, 81, 82, 95, 99, 80, 57, 109, 41, 68, 80, 139, 120, 220, 122, 119, 111, 84, 36, 34, 109, 4, 119, 40, 107, 111, 88, 129, 141, 127, 118, 20, 82, 103, 141, 256, 80, 101, 219, 119, 155, 102, 76, 59, 49, 77, 4, 94, 79, 183, 128, 171, 105, 0, 53, 190, 4, 179, 83, 147, 59, 108, 127, 0, 35, 1, 48, 21, 89, 56, 58, 125, 78, 18, 181, 76, 85, 113, 41, 63, 51, 40, 128, 31, 88, 52, 50, 57, 98, 50, 26, 45, 110, 75, 162, 38, 81, 49, 125, 186, 73, 60, 275, 168, 65, 82, 302, 185, 29, 0, 101, 147, 65, 12, 55, 67, 299, 131, 95, 130, 43, 2, 59, 76, 45, 379, 75, 138, 183, 166, 107, 246, 13, 2, 154, 76, 83, 100, 46, 170, 121, 46, 150, 104, 14, 2, 154, 85, 90, 181, 120, 459, 100, 0, 227, 38, 124, 0, 35, 138, 79, 522, 403, 426, 154, 221, 243, 150, 69, 0, 74, 197, 48, 595, 88, 254, 180, 186, 4, 123, 68, 1, 95, 149, 45, 56, 38, 82, 16, 0, 2, 0, 0, 60, 0, 95, 16, 67, 0, 65, 0, 48, 0, 37, 106, 50, 2, 26, 200, 84, 0, 39, 0, 123, 6, 82, 0, 121, 0, 134, 0, 65, 0, 50, 59, 111, 68, 39, 0, 34, 95, 150, 43, 77, 33, 56, 132, 33, 70, 128, 30, 1, 144, 368, 97, 199, 20, 80, 2, 74, 59, 4, 31, 29, 75, 1, 65, 26, 47, 39, 26, 50, 2, 35, 79, 5, 39, 42, 132, 0, 80, 32, 299, 4, 95, 77, 2, 34, 48, 96, 133, 58, 16, 126, 38], [14, 2, 4, 5, 3, 6, 0, 2, 1, 5, 8, 1, 11, 16, 5, 7, 3, 1, 11, 6, 11, 2, 4, 3, 37, 8, 12, 3, 12, 24, 3, 1, 10, 8, 4, 2, 30, 13, 7, 15, 5, 4, 18, 8, 6, 2, 9, 3, 26, 48, 288, 12, 8, 7, 24, 12, 5, 3, 6, 3, 130, 23, 7, 24, 0, 5, 6, 5, 6, 5, 3, 0, 36, 20, 10, 19, 6, 8, 50, 4, 28, 3, 6, 2, 57, 198, 4, 26, 4, 1, 14, 1, 17, 5, 14, 3, 7, 0, 128, 25, 2, 4, 3, 0, 11, 20, 1, 4, 9, 101, 0, 5, 1, 8, 0, 4, 2, 2, 9, 4, 58, 14, 8, 3, 10, 9, 17, 4, 4, 0, 0, 0, 6, 6, 7, 4, 0, 2, 0, 2, 4, 1, 1, 1, 5, 17, 11, 24, 5, 4, 4, 0, 11, 0, 8, 9, 2, 25, 8, 1, 1, 5, 0, 1, 1, 20, 3, 0, 59, 2, 0, 82, 15, 1, 5, 7, 0, 2, 0, 0, 8, 1273, 3, 1, 17, 1, 1, 1, 3, 2, 12, 1, 429, 297, 216, 83, 158, 383, 131, 514, 401, 281, 246, 137, 119, 286, 113, 161, 115, 100, 157, 381, 424, 35, 128, 168, 211, 172, 162, 157, 6, 176, 83, 68, 94, 188, 258, 198, 90, 154, 99, 415, 16, 191, 166, 150, 102, 467, 189, 300, 511, 584, 425, 223, 321, 407, 457, 480, 316, 57, 49, 311, 95, 861, 417, 614, 586, 970, 70, 385, 110, 82, 45, 122, 378, 85, 93, 321, 212, 136, 336, 386, 220, 127, 448, 100, 131, 242, 446, 229, 434, 318, 179, 386, 318, 107, 128, 198, 6, 368, 122, 75, 415, 233, 226, 512, 192, 323, 78, 121, 296, 407, 664, 301, 256, 332, 417, 506, 461, 148, 165, 149, 226, 19, 385, 156, 318, 397, 238, 296, 0, 136, 496, 2, 561, 111, 240, 189, 130, 313, 21, 86, 1, 179, 106, 250, 206, 183, 161, 129, 211, 321, 247, 318, 169, 84, 287, 135, 151, 239, 135, 234, 118, 150, 108, 177, 164, 89, 126, 307, 361, 320, 167, 157, 178, 371, 561, 101, 166, 459, 367, 46, 213, 810, 325, 104, 3, 268, 367, 70, 263, 197, 181, 445, 241, 188, 259, 191, 4, 31, 177, 127, 595, 63, 259, 307, 547, 155, 570, 83, 2, 246, 212, 184, 333, 69, 374, 386, 156, 204, 284, 77, 3, 232, 228, 132, 632, 236, 1025, 220, 0, 427, 47, 120, 3, 76, 392, 237, 1215, 916, 1177, 459, 568, 258, 503, 152, 1, 208, 460, 155, 1543, 189, 580, 539, 601, 2, 403, 118, 1, 86, 392, 65, 135, 125, 259, 63, 0, 2, 0, 0, 144, 0, 183, 43, 214, 0, 180, 0, 111, 0, 116, 216, 129, 8, 142, 375, 212, 0, 161, 0, 255, 33, 187, 4, 207, 2, 306, 0, 129, 0, 91, 197, 213, 143, 118, 0, 110, 241, 253, 135, 193, 70, 172, 260, 52, 87, 234, 107, 4, 374, 579, 183, 362, 62, 102, 2, 170, 180, 104, 101, 52, 141, 2, 75, 72, 99, 99, 124, 96, 13, 94, 167, 6, 90, 143, 287, 1, 153, 95, 321, 2, 215, 143, 0, 133, 111, 214, 347, 135, 25, 277, 103], [40, 6, 0, 2, 3, 13, 0, 0, 0, 7, 8, 0, 10, 17, 2, 7, 8, 3, 22, 0, 12, 8, 0, 0, 79, 66, 18, 7, 22, 68, 0, 1, 8, 21, 12, 0, 79, 34, 9, 38, 8, 9, 23, 18, 13, 0, 15, 0, 106, 79, 163, 22, 32, 10, 39, 23, 9, 5, 3, 0, 425, 54, 16, 52, 2, 8, 13, 6, 7, 11, 1, 0, 75, 37, 34, 62, 10, 15, 145, 2, 49, 10, 9, 0, 178, 576, 8, 41, 0, 3, 59, 0, 15, 0, 28, 0, 0, 0, 29, 76, 34, 4, 1, 0, 2, 4, 9, 5, 14, 72, 1, 1, 1, 0, 11, 4, 1, 4, 3, 0, 25, 43, 4, 0, 9, 14, 3, 4, 2, 0, 4, 0, 51, 39, 18, 23, 0, 4, 2, 9, 7, 1, 3, 0, 1, 48, 26, 0, 5, 2, 4, 1, 21, 3, 5, 3, 0, 12, 13, 36, 0, 1, 1, 9, 16, 3, 1, 0, 25, 0, 36, 31, 36, 6, 3, 13, 5, 2, 1, 0, 12, 500, 4, 53, 47, 1, 11, 3, 0, 2, 3, 0, 113, 90, 75, 61, 71, 128, 21, 170, 248, 92, 83, 98, 33, 141, 76, 107, 53, 67, 97, 155, 301, 138, 63, 111, 99, 72, 102, 69, 1, 125, 28, 135, 67, 121, 93, 69, 28, 62, 80, 118, 4, 63, 89, 93, 56, 163, 71, 96, 174, 158, 134, 133, 208, 168, 114, 169, 86, 132, 75, 83, 236, 328, 146, 186, 239, 327, 164, 153, 54, 48, 53, 54, 138, 159, 200, 266, 109, 91, 160, 155, 85, 74, 133, 78, 91, 101, 169, 161, 299, 144, 175, 119, 123, 27, 55, 145, 8, 140, 41, 99, 113, 122, 140, 172, 133, 132, 46, 84, 112, 140, 261, 95, 106, 193, 185, 157, 141, 94, 71, 84, 130, 4, 150, 69, 173, 140, 190, 102, 4, 69, 192, 0, 141, 49, 94, 44, 70, 90, 6, 40, 1, 37, 38, 88, 102, 98, 76, 93, 124, 186, 85, 89, 100, 59, 112, 112, 80, 152, 60, 104, 81, 83, 82, 72, 64, 34, 62, 124, 99, 93, 73, 145, 68, 119, 143, 61, 66, 260, 110, 33, 53, 234, 192, 44, 0, 79, 132, 47, 139, 64, 53, 250, 113, 98, 89, 41, 0, 72, 73, 41, 336, 68, 140, 161, 160, 111, 193, 51, 0, 137, 78, 100, 99, 23, 163, 116, 39, 103, 100, 20, 0, 114, 61, 70, 199, 130, 407, 50, 0, 248, 27, 100, 0, 40, 131, 89, 347, 271, 380, 134, 172, 143, 154, 82, 1, 77, 142, 28, 460, 88, 265, 177, 151, 6, 129, 52, 0, 91, 125, 36, 52, 54, 123, 16, 0, 1, 0, 0, 7, 0, 2, 1, 41, 0, 47, 0, 19, 0, 1, 5, 55, 0, 29, 6, 4, 0, 27, 0, 115, 0, 31, 0, 54, 0, 10, 0, 25, 0, 1, 1, 67, 39, 5, 0, 1, 48, 2, 1, 1, 21, 20, 128, 14, 39, 6, 18, 0, 65, 135, 0, 66, 14, 2, 0, 1, 1, 29, 12, 22, 64, 1, 25, 1, 20, 0, 0, 28, 0, 19, 1, 0, 1, 25, 73, 0, 38, 2, 99, 1, 2, 23, 0, 25, 17, 59, 4, 36, 6, 60, 36], [41, 4, 2, 1, 2, 19, 9, 0, 1, 6, 3, 0, 23, 33, 5, 2, 6, 4, 10, 0, 28, 7, 0, 1, 4, 40, 23, 2, 0, 60, 0, 6, 34, 7, 4, 0, 59, 25, 15, 11, 12, 0, 27, 15, 8, 4, 11, 1, 60, 80, 134, 22, 14, 6, 35, 12, 4, 8, 9, 0, 355, 76, 8, 44, 0, 15, 10, 6, 10, 8, 0, 0, 91, 59, 44, 54, 10, 14, 191, 4, 75, 19, 18, 0, 171, 401, 2, 41, 0, 2, 37, 0, 22, 1, 45, 0, 0, 0, 40, 4, 0, 0, 8, 0, 10, 2, 0, 2, 0, 34, 0, 1, 6, 1, 0, 0, 0, 0, 0, 1, 0, 4, 8, 2, 2, 4, 2, 0, 2, 0, 0, 0, 0, 1, 10, 0, 0, 0, 2, 1, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 2, 0, 4, 0, 1, 0, 0, 0, 6, 2, 0, 16, 4, 0, 40, 26, 0, 6, 4, 4, 0, 0, 0, 5, 237, 1, 6, 7, 0, 0, 0, 1, 0, 2, 0, 117, 88, 72, 41, 60, 132, 246, 159, 250, 76, 50, 66, 38, 104, 70, 109, 59, 44, 69, 136, 289, 81, 46, 66, 79, 54, 78, 51, 0, 98, 28, 143, 81, 117, 108, 88, 45, 74, 68, 122, 0, 52, 65, 84, 62, 199, 75, 169, 206, 155, 137, 101, 223, 199, 183, 157, 10, 67, 61, 78, 167, 291, 162, 185, 192, 319, 121, 166, 24, 31, 32, 55, 166, 125, 123, 213, 76, 94, 112, 109, 71, 50, 98, 45, 66, 80, 144, 103, 226, 130, 165, 120, 71, 34, 50, 151, 2, 100, 28, 77, 129, 111, 190, 207, 177, 121, 52, 54, 126, 131, 197, 63, 135, 197, 185, 194, 136, 91, 109, 84, 65, 6, 158, 70, 159, 129, 191, 148, 88, 51, 219, 0, 189, 55, 94, 55, 60, 90, 116, 43, 2, 41, 30, 68, 111, 99, 66, 90, 18, 192, 97, 126, 106, 43, 118, 75, 32, 108, 52, 95, 86, 35, 71, 68, 64, 41, 81, 111, 155, 158, 107, 171, 78, 101, 167, 68, 58, 233, 175, 27, 84, 232, 148, 20, 0, 94, 108, 25, 32, 32, 54, 288, 72, 76, 92, 42, 1, 63, 43, 23, 309, 76, 147, 154, 150, 95, 144, 33, 2, 127, 42, 77, 107, 24, 208, 88, 36, 100, 76, 23, 0, 134, 45, 52, 240, 146, 383, 65, 0, 312, 27, 92, 1, 49, 85, 64, 396, 366, 515, 173, 253, 133, 198, 88, 1, 96, 127, 52, 628, 115, 303, 169, 188, 6, 112, 65, 2, 99, 146, 48, 44, 53, 84, 28, 0, 59, 0, 0, 36, 0, 82, 6, 38, 0, 68, 0, 29, 0, 14, 72, 20, 0, 54, 72, 58, 0, 37, 0, 90, 2, 60, 0, 30, 2, 100, 0, 21, 0, 49, 60, 46, 62, 21, 0, 45, 48, 70, 27, 53, 14, 56, 90, 10, 6, 111, 36, 0, 80, 226, 53, 127, 31, 28, 2, 48, 54, 8, 22, 6, 31, 4, 40, 18, 32, 28, 36, 30, 8, 25, 88, 3, 18, 36, 63, 2, 54, 31, 105, 2, 52, 32, 0, 40, 68, 74, 123, 66, 4, 47, 16], [36, 10, 0, 2, 2, 22, 2, 0, 0, 4, 5, 5, 7, 15, 6, 11, 2, 3, 21, 1, 10, 4, 3, 3, 2, 10, 2, 2, 6, 39, 0, 4, 4, 16, 0, 0, 29, 14, 4, 24, 5, 6, 16, 14, 6, 2, 13, 0, 62, 58, 184, 10, 35, 20, 20, 4, 10, 4, 5, 1, 334, 30, 12, 37, 4, 3, 2, 8, 0, 13, 6, 0, 74, 44, 18, 51, 10, 12, 99, 2, 52, 0, 10, 1, 151, 569, 1, 34, 0, 0, 45, 0, 16, 0, 30, 3, 2, 2, 43, 92, 19, 0, 0, 0, 2, 0, 7, 2, 18, 42, 2, 13, 0, 0, 10, 2, 6, 0, 0, 0, 0, 62, 2, 2, 7, 10, 4, 11, 2, 2, 4, 2, 6, 25, 8, 10, 2, 2, 0, 2, 2, 1, 0, 2, 0, 49, 16, 1, 2, 4, 1, 0, 6, 6, 0, 0, 1, 7, 2, 46, 0, 2, 0, 10, 6, 0, 4, 0, 41, 3, 5, 18, 13, 2, 4, 2, 4, 8, 6, 0, 4, 425, 11, 16, 41, 0, 0, 6, 0, 0, 2, 0, 82, 135, 66, 59, 76, 173, 0, 136, 186, 100, 77, 74, 30, 66, 56, 72, 46, 40, 53, 113, 211, 86, 62, 49, 54, 71, 102, 57, 2, 59, 18, 127, 35, 105, 66, 57, 37, 39, 55, 92, 2, 53, 76, 68, 44, 133, 56, 113, 159, 162, 127, 96, 175, 144, 142, 126, 8, 125, 38, 107, 153, 246, 170, 175, 186, 259, 105, 134, 64, 33, 38, 29, 84, 102, 123, 174, 73, 80, 125, 116, 86, 55, 125, 52, 90, 114, 158, 127, 183, 126, 115, 89, 100, 32, 50, 124, 0, 95, 36, 69, 116, 110, 104, 164, 85, 119, 19, 71, 115, 114, 179, 98, 137, 129, 147, 93, 120, 73, 56, 81, 93, 10, 164, 46, 126, 132, 162, 91, 0, 23, 168, 0, 200, 75, 115, 41, 68, 112, 0, 34, 2, 32, 46, 81, 83, 79, 118, 69, 4, 188, 82, 57, 73, 40, 69, 44, 42, 96, 26, 75, 41, 63, 49, 55, 41, 25, 54, 95, 132, 92, 51, 73, 59, 115, 155, 60, 71, 266, 104, 75, 67, 248, 172, 32, 0, 88, 142, 33, 8, 37, 56, 199, 90, 84, 81, 37, 0, 63, 58, 51, 240, 50, 103, 107, 111, 86, 212, 30, 0, 105, 75, 111, 98, 24, 179, 47, 45, 97, 96, 26, 0, 87, 79, 76, 201, 149, 349, 65, 2, 147, 26, 68, 0, 47, 112, 86, 451, 368, 283, 144, 203, 151, 105, 70, 1, 66, 173, 59, 596, 120, 213, 161, 142, 4, 133, 56, 0, 110, 153, 48, 76, 34, 79, 31, 0, 2, 0, 0, 64, 0, 146, 15, 154, 0, 87, 0, 60, 0, 56, 130, 71, 0, 105, 216, 91, 0, 90, 2, 188, 13, 83, 0, 154, 0, 195, 0, 63, 0, 84, 99, 155, 126, 68, 0, 48, 133, 138, 100, 134, 30, 82, 186, 44, 76, 143, 41, 0, 179, 403, 90, 170, 21, 90, 0, 78, 89, 8, 12, 17, 102, 2, 39, 64, 52, 38, 70, 32, 0, 64, 76, 1, 68, 63, 152, 0, 103, 43, 331, 2, 92, 105, 0, 17, 71, 114, 152, 73, 16, 164, 56], [25, 15, 0, 4, 4, 26, 17, 0, 0, 4, 3, 0, 14, 13, 10, 6, 4, 3, 16, 1, 42, 7, 0, 0, 16, 43, 8, 5, 13, 41, 1, 12, 22, 26, 4, 0, 70, 16, 12, 22, 6, 12, 3, 19, 10, 3, 10, 0, 70, 83, 166, 28, 46, 16, 64, 14, 15, 11, 3, 0, 339, 73, 14, 67, 3, 12, 13, 16, 2, 4, 3, 0, 70, 43, 16, 62, 15, 28, 164, 4, 55, 6, 14, 0, 160, 423, 13, 31, 0, 2, 58, 3, 20, 0, 38, 0, 1, 0, 38, 93, 10, 3, 3, 0, 7, 3, 7, 4, 13, 76, 0, 4, 2, 0, 7, 6, 4, 4, 4, 0, 11, 39, 1, 1, 14, 7, 2, 6, 2, 3, 1, 0, 42, 31, 6, 37, 2, 2, 2, 1, 9, 1, 5, 0, 1, 89, 40, 0, 4, 5, 1, 2, 11, 5, 3, 2, 1, 5, 8, 55, 0, 5, 1, 5, 13, 5, 2, 1, 30, 1, 58, 28, 33, 2, 12, 7, 14, 4, 0, 0, 10, 531, 5, 54, 62, 1, 6, 5, 1, 0, 5, 0, 123, 95, 87, 47, 92, 108, 240, 185, 276, 109, 77, 83, 32, 68, 80, 142, 54, 32, 107, 138, 344, 84, 50, 124, 55, 47, 102, 40, 4, 108, 40, 166, 50, 178, 144, 93, 40, 84, 95, 118, 3, 65, 96, 87, 44, 151, 69, 154, 198, 189, 184, 178, 272, 196, 142, 124, 31, 91, 84, 102, 237, 306, 188, 252, 262, 397, 145, 125, 36, 32, 74, 72, 158, 176, 169, 231, 89, 81, 133, 116, 61, 62, 96, 56, 65, 65, 141, 107, 225, 137, 151, 101, 106, 35, 50, 151, 0, 132, 27, 153, 157, 113, 241, 183, 195, 129, 57, 94, 124, 144, 256, 102, 164, 216, 156, 195, 147, 103, 93, 67, 81, 8, 142, 55, 186, 124, 191, 145, 113, 59, 165, 1, 182, 72, 105, 39, 103, 105, 122, 29, 0, 28, 27, 94, 96, 72, 95, 99, 30, 217, 113, 125, 113, 38, 119, 75, 36, 168, 38, 87, 83, 39, 57, 72, 59, 14, 75, 109, 164, 130, 133, 140, 59, 107, 149, 70, 82, 296, 137, 35, 49, 281, 204, 26, 0, 63, 70, 42, 56, 35, 48, 345, 115, 90, 92, 61, 0, 75, 52, 55, 424, 54, 140, 198, 135, 124, 202, 37, 0, 129, 65, 116, 93, 22, 185, 130, 42, 117, 73, 27, 1, 167, 60, 72, 194, 127, 327, 84, 2, 307, 49, 88, 0, 42, 125, 89, 460, 315, 733, 266, 208, 169, 180, 68, 0, 84, 124, 54, 597, 88, 278, 209, 195, 7, 147, 62, 0, 141, 207, 39, 54, 52, 97, 25, 0, 34, 0, 0, 24, 0, 84, 9, 16, 0, 29, 0, 19, 0, 10, 66, 14, 1, 31, 138, 45, 0, 59, 0, 45, 6, 52, 0, 17, 0, 63, 0, 10, 0, 27, 24, 72, 33, 37, 0, 14, 51, 91, 42, 58, 15, 33, 108, 19, 18, 113, 32, 0, 123, 193, 30, 78, 10, 39, 1, 25, 59, 5, 16, 11, 42, 2, 16, 25, 23, 36, 22, 47, 0, 8, 23, 2, 9, 23, 105, 0, 37, 36, 88, 2, 56, 16, 0, 47, 25, 72, 109, 37, 13, 113, 15], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 57, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 42, 0, 0, 0, 0, 0, 1, 0, 3, 0, 22, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 17, 0, 0, 0, 0, 2, 0, 5, 0, 1, 0, 0, 1, 1, 0, 2, 0, 0, 1, 5, 0, 34, 18, 0, 16, 0, 3, 0, 1, 7, 0, 0, 0, 3, 105, 24, 0, 2, 4, 1, 0, 0, 0, 2, 4, 0, 0, 0, 41, 0, 0, 1, 2, 2, 6, 0, 1, 2, 0, 1, 14, 2, 3, 0, 0, 6, 0, 1, 0, 0, 27, 3, 1, 0, 0, 5, 0, 0, 0, 0, 0, 288, 331, 173, 106, 206, 228, 3, 345, 440, 195, 207, 181, 110, 212, 132, 263, 100, 117, 219, 243, 474, 216, 123, 186, 154, 144, 250, 114, 9, 192, 56, 281, 93, 268, 155, 140, 68, 94, 130, 231, 5, 117, 240, 137, 92, 387, 228, 501, 402, 371, 295, 305, 460, 404, 308, 463, 18, 306, 141, 181, 485, 678, 371, 504, 456, 792, 381, 336, 98, 80, 103, 179, 329, 262, 328, 523, 232, 178, 316, 338, 157, 155, 232, 109, 180, 200, 413, 298, 539, 327, 384, 237, 259, 82, 98, 354, 20, 350, 110, 230, 249, 279, 277, 333, 283, 206, 55, 159, 224, 205, 475, 198, 218, 379, 236, 308, 198, 143, 105, 111, 174, 20, 277, 130, 276, 230, 312, 211, 2, 135, 335, 0, 334, 223, 331, 130, 191, 155, 1, 80, 0, 99, 73, 171, 167, 216, 317, 168, 31, 507, 227, 270, 167, 119, 212, 140, 123, 359, 95, 184, 200, 119, 162, 176, 170, 54, 125, 253, 222, 182, 90, 220, 99, 208, 342, 125, 83, 591, 417, 171, 145, 596, 367, 84, 0, 219, 267, 133, 57, 142, 138, 675, 314, 172, 238, 118, 0, 172, 173, 99, 792, 168, 326, 548, 389, 209, 388, 89, 0, 357, 214, 245, 288, 80, 481, 313, 87, 236, 226, 67, 0, 314, 136, 171, 466, 365, 775, 159, 5, 524, 92, 190, 0, 79, 220, 160, 879, 564, 788, 376, 435, 321, 337, 130, 0, 155, 257, 75, 982, 186, 491, 392, 341, 7, 236, 130, 1, 188, 281, 115, 202, 125, 220, 54, 0, 0, 0, 0, 0, 0, 51, 0, 22, 0, 0, 0, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 49, 0, 41, 0, 39, 0, 7, 0, 0, 0, 0, 0, 0, 0, 30, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 91, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0], [30, 4, 2, 4, 0, 0, 0, 0, 2, 4, 0, 2, 18, 2, 0, 0, 5, 0, 16, 0, 16, 6, 0, 0, 16, 24, 0, 0, 3, 28, 0, 8, 24, 4, 13, 0, 30, 16, 2, 0, 8, 3, 16, 6, 1, 2, 5, 0, 38, 22, 64, 10, 24, 0, 6, 14, 4, 3, 2, 0, 41, 4, 6, 17, 0, 0, 4, 0, 4, 0, 0, 0, 8, 2, 4, 12, 2, 0, 28, 0, 17, 2, 6, 0, 26, 74, 2, 8, 0, 0, 14, 0, 4, 0, 11, 0, 0, 0, 35, 43, 32, 2, 0, 0, 6, 1, 4, 0, 17, 21, 0, 8, 2, 2, 6, 8, 2, 6, 2, 0, 10, 54, 2, 0, 12, 30, 3, 2, 10, 4, 0, 0, 15, 8, 20, 16, 0, 0, 2, 4, 5, 3, 0, 2, 1, 39, 21, 2, 6, 8, 4, 18, 9, 2, 4, 0, 1, 12, 14, 32, 0, 14, 0, 2, 0, 10, 2, 0, 3, 3, 0, 4, 6, 0, 6, 2, 4, 0, 2, 0, 18, 149, 2, 40, 50, 0, 0, 6, 0, 0, 1, 0, 79, 82, 67, 43, 97, 40, 48, 110, 71, 65, 57, 53, 46, 100, 51, 73, 38, 65, 88, 49, 95, 82, 32, 50, 48, 56, 86, 61, 2, 79, 14, 83, 62, 42, 31, 25, 26, 29, 18, 37, 2, 14, 95, 58, 24, 114, 72, 85, 97, 102, 69, 74, 120, 71, 89, 189, 70, 86, 63, 91, 185, 182, 88, 113, 100, 165, 116, 133, 53, 50, 39, 37, 90, 88, 69, 118, 60, 38, 80, 100, 67, 31, 92, 81, 56, 46, 127, 111, 156, 84, 108, 121, 94, 36, 64, 121, 16, 98, 58, 81, 81, 66, 96, 74, 79, 61, 18, 37, 70, 50, 103, 42, 53, 106, 119, 99, 68, 54, 50, 40, 41, 0, 38, 45, 67, 60, 104, 84, 16, 81, 105, 0, 86, 40, 82, 10, 78, 26, 12, 25, 0, 30, 68, 54, 54, 75, 59, 59, 89, 158, 90, 79, 33, 64, 57, 51, 62, 80, 30, 51, 40, 43, 56, 68, 38, 16, 34, 35, 68, 24, 34, 38, 18, 38, 83, 12, 18, 147, 52, 40, 59, 98, 69, 38, 0, 97, 46, 87, 104, 63, 32, 158, 103, 31, 67, 40, 2, 46, 70, 11, 156, 74, 78, 101, 66, 44, 76, 39, 0, 72, 44, 38, 66, 30, 115, 62, 44, 45, 61, 46, 0, 87, 64, 60, 90, 50, 151, 28, 0, 94, 20, 31, 2, 22, 34, 43, 140, 90, 125, 41, 75, 38, 23, 36, 0, 39, 63, 24, 254, 19, 77, 49, 40, 0, 46, 11, 0, 27, 88, 54, 32, 45, 50, 14, 0, 0, 0, 0, 14, 0, 31, 16, 18, 0, 26, 0, 22, 2, 15, 26, 16, 0, 24, 36, 20, 0, 24, 0, 20, 10, 33, 0, 20, 0, 48, 0, 10, 0, 24, 18, 24, 32, 16, 0, 16, 21, 18, 20, 8, 10, 19, 16, 18, 8, 30, 11, 0, 56, 101, 27, 34, 4, 12, 4, 26, 38, 7, 20, 12, 18, 0, 16, 14, 22, 14, 6, 8, 4, 11, 26, 4, 9, 7, 34, 0, 18, 19, 26, 0, 32, 17, 2, 16, 4, 21, 29, 8, 4, 24, 21], [15, 1, 1, 0, 0, 9, 1, 0, 0, 1, 1, 0, 0, 6, 1, 2, 3, 1, 8, 0, 7, 0, 0, 1, 5, 6, 6, 0, 0, 16, 5, 0, 0, 12, 0, 0, 20, 16, 5, 13, 2, 1, 11, 0, 10, 0, 0, 0, 25, 22, 48, 7, 5, 7, 6, 1, 3, 0, 2, 0, 83, 40, 6, 5, 0, 2, 4, 2, 2, 3, 1, 0, 9, 27, 7, 0, 0, 9, 34, 5, 15, 3, 4, 0, 0, 190, 10, 6, 0, 2, 24, 0, 17, 0, 12, 0, 1, 0, 17, 130, 1, 1, 0, 0, 4, 0, 0, 0, 14, 12, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 1, 26, 1, 0, 12, 3, 4, 9, 0, 1, 1, 0, 13, 21, 1, 20, 1, 0, 0, 0, 2, 2, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 12, 0, 7, 1, 0, 1, 17, 0, 0, 3, 0, 3, 3, 0, 1, 0, 13, 0, 0, 18, 13, 0, 1, 1, 0, 2, 0, 0, 8, 308, 0, 78, 34, 0, 9, 0, 0, 0, 17, 1, 74, 75, 38, 32, 53, 84, 197, 69, 161, 41, 43, 36, 11, 42, 28, 58, 25, 20, 64, 68, 176, 42, 27, 55, 38, 18, 31, 33, 0, 53, 10, 77, 21, 81, 41, 45, 15, 37, 41, 55, 2, 39, 46, 35, 32, 104, 22, 46, 68, 132, 77, 53, 124, 150, 80, 87, 4, 33, 37, 44, 88, 122, 107, 111, 118, 176, 102, 65, 33, 17, 23, 24, 64, 69, 85, 109, 53, 45, 52, 86, 32, 28, 48, 34, 26, 40, 61, 56, 124, 84, 81, 66, 62, 18, 25, 98, 1, 77, 26, 57, 93, 73, 99, 105, 70, 92, 27, 45, 73, 66, 147, 88, 39, 125, 75, 99, 73, 63, 41, 34, 49, 4, 81, 35, 104, 74, 129, 90, 57, 43, 125, 0, 91, 23, 82, 39, 50, 61, 64, 13, 0, 21, 13, 47, 45, 33, 35, 44, 5, 83, 63, 64, 50, 23, 56, 29, 24, 76, 19, 27, 31, 27, 26, 40, 40, 12, 36, 77, 62, 67, 65, 68, 30, 86, 76, 56, 41, 169, 95, 16, 27, 186, 93, 12, 0, 55, 54, 23, 9, 14, 30, 210, 56, 46, 60, 38, 0, 33, 19, 16, 213, 63, 71, 115, 85, 52, 102, 22, 0, 67, 46, 42, 50, 20, 90, 66, 20, 52, 55, 12, 0, 55, 36, 38, 150, 87, 229, 34, 1, 136, 27, 32, 1, 21, 73, 45, 252, 240, 349, 129, 143, 117, 82, 54, 0, 29, 84, 43, 350, 51, 193, 129, 84, 2, 88, 40, 0, 68, 93, 32, 32, 21, 37, 20, 0, 65, 1, 0, 47, 0, 116, 20, 29, 0, 97, 0, 63, 0, 13, 138, 75, 0, 58, 201, 118, 0, 31, 0, 152, 14, 79, 0, 109, 0, 42, 0, 45, 0, 61, 85, 76, 82, 64, 0, 69, 122, 153, 19, 37, 45, 100, 194, 47, 53, 133, 44, 0, 127, 203, 74, 200, 8, 10, 3, 108, 61, 4, 37, 26, 56, 0, 31, 43, 56, 48, 27, 28, 0, 37, 98, 5, 50, 32, 165, 0, 98, 56, 222, 1, 113, 77, 0, 87, 61, 147, 12, 78, 11, 166, 43], [67, 4, 2, 0, 0, 2, 2, 2, 2, 2, 3, 3, 1, 16, 0, 2, 10, 2, 53, 1, 13, 0, 6, 2, 0, 16, 10, 6, 0, 1, 0, 4, 1, 6, 0, 0, 32, 9, 5, 22, 0, 10, 5, 0, 4, 0, 1, 2, 66, 0, 52, 10, 1, 8, 9, 3, 1, 12, 2, 6, 31, 0, 4, 16, 0, 0, 10, 3, 0, 0, 0, 0, 18, 12, 2, 12, 3, 12, 14, 2, 4, 6, 11, 2, 36, 73, 3, 0, 0, 0, 9, 1, 6, 3, 0, 3, 13, 4, 25, 32, 22, 1, 0, 0, 1, 0, 0, 2, 4, 0, 0, 9, 0, 0, 8, 9, 1, 8, 2, 0, 0, 22, 0, 2, 38, 1, 0, 0, 0, 2, 3, 2, 14, 9, 0, 15, 0, 0, 2, 0, 0, 0, 0, 0, 0, 26, 26, 4, 0, 8, 6, 0, 40, 0, 0, 0, 0, 2, 11, 14, 2, 0, 0, 12, 0, 0, 0, 0, 13, 0, 8, 4, 9, 0, 0, 2, 0, 2, 0, 0, 0, 4, 3, 5, 10, 0, 2, 4, 0, 0, 6, 2, 178, 91, 100, 70, 185, 30, 4, 244, 77, 71, 117, 73, 57, 112, 51, 93, 42, 93, 39, 54, 57, 124, 30, 105, 54, 76, 132, 74, 4, 87, 46, 152, 49, 50, 22, 22, 10, 14, 21, 20, 0, 8, 100, 44, 14, 103, 29, 158, 49, 148, 64, 46, 127, 120, 103, 259, 14, 145, 65, 108, 150, 220, 123, 179, 160, 209, 180, 154, 90, 38, 37, 47, 62, 117, 114, 125, 59, 58, 105, 125, 50, 38, 116, 65, 58, 120, 171, 184, 196, 106, 134, 115, 97, 33, 61, 86, 18, 70, 46, 42, 46, 58, 62, 67, 38, 21, 6, 37, 40, 44, 100, 36, 77, 43, 73, 66, 55, 16, 28, 24, 20, 2, 22, 28, 36, 22, 53, 19, 0, 134, 34, 0, 160, 25, 62, 25, 188, 18, 0, 35, 2, 30, 29, 66, 62, 52, 55, 72, 12, 167, 113, 97, 23, 52, 68, 69, 50, 53, 28, 89, 80, 55, 59, 118, 73, 42, 41, 128, 74, 45, 40, 24, 4, 21, 98, 20, 21, 195, 84, 15, 64, 135, 119, 14, 0, 44, 135, 129, 21, 54, 47, 151, 81, 75, 80, 20, 0, 59, 36, 22, 120, 79, 115, 124, 152, 62, 120, 43, 0, 60, 31, 128, 78, 33, 150, 38, 36, 152, 113, 8, 1, 100, 47, 95, 119, 62, 156, 63, 8, 138, 48, 58, 0, 37, 46, 24, 184, 62, 131, 32, 64, 74, 47, 33, 0, 20, 35, 12, 206, 29, 105, 59, 65, 0, 51, 26, 0, 29, 37, 49, 36, 64, 86, 0, 0, 0, 0, 0, 15, 0, 34, 12, 29, 0, 59, 0, 39, 2, 8, 75, 12, 0, 52, 49, 27, 0, 16, 0, 62, 3, 54, 0, 32, 0, 29, 0, 34, 1, 15, 30, 11, 15, 8, 0, 14, 36, 28, 5, 7, 6, 18, 24, 68, 28, 110, 23, 6, 36, 49, 30, 53, 12, 14, 0, 78, 37, 2, 23, 24, 21, 0, 24, 14, 36, 59, 2, 24, 6, 4, 38, 6, 27, 34, 82, 0, 52, 38, 88, 14, 32, 18, 0, 10, 27, 48, 4, 19, 5, 32, 8], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 3, 2, 0, 3, 0, 5, 2, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, 1, 0, 3, 0, 0, 0, 0, 5, 1, 2, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 114, 3, 1, 0, 0, 0, 12, 9, 1, 0, 1, 116, 0, 0, 0, 5, 0, 0, 2, 0, 1, 0, 2, 2, 10, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 4, 0, 3, 0, 0, 0, 1, 0, 0, 3, 4, 0, 0, 0, 3, 0, 0, 7, 0, 1, 0, 0, 1, 0, 0, 0, 2, 0, 1, 0, 21, 0, 0, 61, 0, 0, 73, 3, 0, 0, 1, 0, 0, 3, 1, 0, 890, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 500, 327, 377, 121, 401, 498, 0, 303, 912, 206, 379, 497, 2, 223, 377, 525, 120, 187, 233, 260, 1016, 561, 270, 464, 418, 158, 544, 131, 17, 534, 193, 573, 272, 590, 169, 118, 152, 238, 271, 440, 26, 120, 405, 293, 199, 662, 170, 427, 499, 494, 429, 563, 1001, 935, 696, 375, 43, 273, 356, 403, 441, 1411, 344, 1076, 1038, 842, 918, 370, 224, 228, 117, 333, 320, 666, 270, 534, 458, 231, 595, 646, 364, 128, 545, 144, 124, 424, 363, 289, 952, 284, 264, 528, 269, 166, 125, 596, 26, 327, 256, 449, 506, 194, 295, 568, 441, 241, 87, 185, 376, 206, 893, 395, 427, 402, 628, 707, 217, 349, 278, 111, 334, 50, 204, 246, 326, 251, 678, 512, 0, 316, 324, 2, 378, 475, 564, 139, 402, 353, 0, 164, 2, 95, 128, 423, 228, 158, 684, 231, 28, 1020, 466, 451, 166, 242, 183, 354, 285, 574, 222, 500, 163, 147, 328, 336, 169, 87, 302, 667, 273, 432, 227, 307, 86, 4, 2, 263, 284, 1110, 512, 339, 357, 1137, 393, 58, 0, 245, 503, 290, 58, 239, 123, 1279, 272, 191, 226, 118, 0, 311, 173, 155, 734, 254, 598, 947, 352, 494, 375, 83, 0, 641, 385, 283, 37, 59, 964, 310, 99, 506, 462, 157, 1, 695, 255, 354, 11, 727, 1855, 375, 19, 1264, 106, 470, 0, 166, 500, 378, 14, 673, 1565, 779, 439, 639, 730, 189, 0, 309, 300, 197, 1778, 336, 665, 837, 822, 0, 228, 121, 0, 177, 527, 3, 495, 118, 456, 48, 0, 0, 0, 0, 1, 0, 3, 3, 2, 0, 1, 0, 3, 0, 1, 2, 1, 0, 1, 1, 3, 0, 3, 0, 0, 0, 0, 0, 4, 0, 4, 0, 5, 0, 2, 2, 0, 1, 3, 0, 0, 0, 5, 4, 3, 1, 0, 6, 1, 2, 3, 1, 0, 8, 12, 0, 3, 0, 2, 0, 3, 0, 0, 1, 0, 3, 0, 2, 1, 0, 1, 1, 0, 0, 0, 4, 0, 1, 0, 6, 0, 2, 0, 5, 1, 1, 3, 0, 1, 0, 2, 2, 3, 0, 1, 2], [238, 26, 0, 7, 24, 73, 20, 0, 0, 32, 7, 1, 59, 62, 10, 16, 35, 9, 124, 5, 94, 34, 2, 1, 207, 140, 38, 14, 54, 257, 7, 18, 70, 99, 85, 0, 319, 35, 45, 114, 41, 31, 78, 64, 60, 21, 46, 1, 370, 260, 675, 104, 125, 34, 157, 122, 34, 36, 53, 0, 775, 258, 64, 153, 4, 17, 49, 37, 13, 22, 5, 0, 126, 107, 89, 124, 29, 60, 401, 20, 134, 32, 31, 0, 330, 984, 21, 84, 0, 8, 102, 0, 55, 0, 106, 0, 1, 1, 181, 165, 257, 4, 9, 1, 14, 22, 15, 1, 93, 232, 1, 59, 5, 3, 33, 34, 12, 40, 24, 10, 51, 261, 9, 2, 55, 43, 4, 13, 28, 4, 13, 10, 190, 118, 60, 33, 5, 7, 8, 8, 27, 3, 10, 1, 5, 263, 238, 28, 16, 13, 15, 28, 34, 29, 23, 26, 0, 31, 33, 74, 2, 8, 3, 12, 6, 8, 11, 0, 77, 3, 37, 76, 62, 10, 14, 13, 26, 2, 1, 0, 42, 1083, 12, 108, 93, 0, 13, 1, 0, 2, 1, 0, 358, 299, 283, 195, 385, 247, 226, 547, 480, 334, 411, 327, 206, 469, 339, 401, 213, 320, 268, 501, 514, 451, 200, 407, 374, 396, 525, 325, 8, 379, 136, 442, 194, 305, 195, 244, 94, 155, 198, 224, 8, 122, 308, 180, 92, 478, 266, 405, 542, 588, 450, 404, 706, 560, 438, 529, 187, 409, 252, 280, 619, 739, 460, 658, 679, 971, 616, 431, 176, 194, 185, 149, 358, 362, 435, 607, 274, 280, 421, 515, 262, 210, 491, 252, 262, 276, 589, 505, 693, 405, 433, 439, 306, 174, 241, 441, 39, 446, 221, 321, 257, 259, 319, 313, 209, 215, 79, 181, 230, 273, 472, 228, 245, 419, 347, 381, 243, 173, 200, 120, 180, 16, 266, 107, 320, 276, 396, 240, 74, 368, 387, 2, 436, 142, 325, 84, 363, 212, 58, 230, 0, 144, 135, 306, 265, 307, 292, 308, 303, 632, 377, 314, 91, 246, 329, 371, 331, 363, 181, 351, 302, 323, 330, 345, 285, 148, 182, 449, 275, 310, 206, 290, 106, 321, 357, 166, 181, 630, 278, 142, 248, 795, 520, 169, 0, 294, 393, 289, 258, 269, 211, 683, 354, 275, 333, 198, 0, 220, 397, 222, 743, 189, 468, 463, 381, 309, 524, 192, 0, 440, 282, 430, 208, 99, 482, 418, 183, 361, 439, 181, 0, 493, 276, 295, 620, 480, 831, 317, 11, 684, 163, 319, 0, 92, 294, 210, 722, 801, 883, 541, 589, 446, 422, 230, 0, 208, 356, 131, 874, 236, 592, 416, 481, 3, 301, 51, 0, 224, 223, 328, 202, 116, 352, 32, 0, 12, 0, 0, 155, 0, 248, 74, 133, 1, 200, 0, 110, 0, 66, 251, 122, 1, 175, 317, 202, 0, 185, 1, 341, 85, 176, 1, 257, 0, 387, 1, 122, 0, 126, 166, 226, 173, 89, 0, 121, 213, 243, 121, 203, 78, 125, 252, 108, 142, 371, 122, 3, 406, 631, 262, 380, 100, 187, 4, 232, 252, 70, 138, 101, 158, 10, 165, 76, 127, 151, 130, 110, 20, 133, 179, 10, 111, 154, 370, 0, 189, 121, 366, 16, 182, 93, 0, 165, 141, 188, 269, 136, 23, 265, 97], [6, 3, 0, 1, 0, 10, 0, 0, 0, 4, 2, 0, 21, 7, 0, 5, 3, 1, 14, 0, 15, 2, 2, 0, 6, 19, 3, 3, 12, 47, 2, 5, 11, 10, 14, 0, 0, 2, 9, 26, 6, 5, 17, 7, 10, 1, 8, 0, 0, 46, 110, 11, 21, 13, 24, 14, 3, 1, 5, 0, 66, 45, 11, 28, 0, 3, 5, 1, 0, 8, 1, 0, 14, 20, 8, 24, 0, 8, 81, 2, 24, 2, 4, 0, 68, 202, 13, 20, 0, 0, 23, 0, 21, 0, 46, 0, 2, 0, 77, 0, 0, 0, 0, 0, 13, 1, 0, 0, 1, 87, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 2, 0, 5, 0, 1, 0, 0, 0, 5, 2, 0, 0, 0, 1, 8, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 7, 7, 0, 31, 0, 2, 45, 10, 1, 8, 11, 0, 0, 0, 0, 0, 639, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 149, 164, 144, 65, 133, 172, 0, 157, 428, 111, 126, 154, 35, 134, 157, 184, 72, 95, 125, 185, 422, 176, 94, 181, 113, 86, 206, 82, 1, 189, 48, 180, 72, 205, 95, 98, 70, 125, 122, 164, 5, 65, 143, 132, 81, 266, 72, 242, 186, 230, 199, 247, 504, 391, 265, 190, 13, 123, 128, 115, 193, 553, 202, 443, 443, 429, 354, 143, 75, 79, 47, 111, 122, 191, 150, 241, 127, 99, 208, 203, 77, 65, 198, 67, 77, 162, 162, 163, 338, 183, 126, 161, 102, 56, 63, 193, 12, 162, 67, 186, 185, 109, 155, 202, 158, 109, 24, 89, 147, 139, 327, 145, 138, 221, 249, 296, 124, 102, 114, 62, 104, 10, 125, 93, 174, 143, 242, 193, 0, 100, 178, 1, 186, 153, 152, 31, 108, 118, 1, 55, 0, 39, 33, 148, 108, 107, 207, 91, 20, 438, 193, 158, 51, 96, 115, 160, 124, 245, 92, 177, 93, 71, 127, 89, 96, 31, 115, 246, 132, 217, 105, 150, 52, 72, 93, 123, 151, 343, 150, 140, 65, 396, 161, 39, 0, 80, 166, 84, 22, 69, 34, 445, 77, 76, 112, 47, 1, 97, 83, 56, 392, 110, 220, 279, 148, 127, 151, 45, 0, 222, 110, 120, 23, 30, 335, 137, 47, 156, 139, 47, 1, 209, 82, 107, 143, 224, 753, 147, 10, 490, 35, 148, 0, 49, 145, 104, 262, 330, 609, 330, 242, 288, 276, 89, 0, 108, 134, 71, 736, 151, 235, 302, 273, 0, 118, 36, 0, 80, 128, 24, 193, 46, 163, 19, 0, 0, 0, 0, 23, 0, 71, 13, 41, 0, 25, 0, 29, 0, 20, 54, 18, 0, 32, 42, 32, 0, 30, 0, 52, 13, 32, 0, 43, 0, 67, 0, 23, 0, 28, 30, 56, 33, 23, 0, 12, 39, 36, 20, 53, 11, 30, 36, 20, 25, 75, 36, 0, 80, 121, 42, 45, 13, 53, 2, 58, 42, 4, 24, 18, 29, 3, 22, 24, 21, 26, 31, 22, 4, 21, 36, 1, 14, 17, 65, 0, 24, 20, 58, 3, 34, 30, 0, 22, 23, 57, 95, 34, 8, 48, 19], [75, 4, 1, 2, 5, 33, 2, 2, 0, 8, 3, 2, 12, 28, 4, 8, 3, 10, 33, 7, 37, 2, 0, 0, 81, 17, 15, 2, 17, 37, 2, 6, 27, 24, 20, 2, 67, 29, 14, 36, 10, 4, 21, 12, 18, 2, 9, 2, 61, 111, 185, 18, 25, 6, 85, 10, 16, 3, 12, 0, 259, 62, 14, 54, 2, 10, 22, 11, 4, 8, 2, 0, 34, 38, 24, 77, 8, 4, 123, 7, 48, 10, 6, 2, 130, 532, 8, 36, 3, 2, 14, 1, 22, 1, 40, 1, 1, 1, 66, 0, 2, 6, 0, 0, 9, 8, 0, 2, 0, 78, 1, 2, 10, 3, 1, 0, 7, 1, 10, 2, 48, 1, 0, 0, 2, 0, 4, 0, 4, 6, 2, 0, 3, 3, 22, 1, 0, 1, 0, 1, 0, 1, 0, 0, 1, 2, 7, 7, 0, 12, 1, 0, 2, 1, 0, 0, 2, 6, 0, 2, 0, 0, 0, 0, 0, 6, 8, 0, 40, 3, 0, 76, 21, 0, 9, 10, 0, 1, 0, 0, 1, 758, 2, 1, 2, 0, 0, 0, 0, 2, 0, 0, 180, 98, 98, 81, 74, 117, 53, 183, 185, 101, 101, 78, 37, 105, 56, 148, 60, 68, 110, 156, 153, 81, 48, 97, 90, 77, 110, 89, 2, 83, 32, 130, 51, 113, 55, 88, 53, 53, 60, 69, 0, 54, 107, 68, 46, 151, 69, 105, 195, 196, 180, 125, 205, 192, 142, 159, 88, 106, 78, 79, 220, 396, 174, 269, 194, 297, 185, 140, 61, 60, 31, 73, 128, 105, 186, 195, 98, 65, 109, 165, 83, 55, 132, 93, 95, 151, 204, 155, 306, 126, 156, 114, 94, 49, 66, 136, 24, 177, 54, 84, 131, 98, 147, 151, 122, 121, 49, 82, 83, 112, 260, 90, 110, 162, 177, 130, 86, 92, 66, 68, 54, 4, 119, 56, 161, 126, 195, 125, 11, 106, 146, 0, 190, 43, 139, 24, 110, 120, 9, 50, 2, 54, 37, 83, 95, 51, 79, 83, 132, 189, 78, 121, 33, 51, 75, 84, 51, 188, 45, 93, 66, 49, 75, 80, 83, 32, 49, 88, 145, 90, 49, 123, 54, 115, 163, 46, 64, 272, 119, 54, 86, 353, 232, 50, 3, 108, 185, 75, 185, 62, 58, 275, 133, 93, 99, 57, 1, 66, 98, 77, 464, 75, 207, 146, 152, 128, 154, 76, 0, 142, 87, 104, 62, 23, 178, 96, 42, 95, 102, 41, 1, 132, 90, 73, 272, 131, 328, 83, 2, 226, 47, 75, 1, 38, 175, 99, 417, 218, 312, 182, 200, 165, 149, 91, 1, 82, 173, 60, 511, 88, 248, 139, 133, 2, 107, 31, 0, 91, 109, 49, 48, 36, 112, 11, 0, 16, 0, 0, 52, 0, 113, 19, 74, 0, 73, 0, 57, 0, 50, 89, 59, 0, 87, 145, 137, 0, 54, 0, 129, 30, 99, 0, 110, 0, 222, 0, 60, 0, 47, 58, 119, 52, 44, 0, 80, 81, 107, 47, 63, 56, 71, 128, 32, 43, 151, 35, 3, 157, 430, 86, 265, 22, 52, 6, 84, 110, 23, 40, 41, 60, 1, 60, 24, 60, 48, 57, 60, 7, 54, 87, 4, 44, 53, 135, 0, 84, 33, 221, 6, 83, 103, 2, 88, 69, 106, 141, 73, 14, 116, 18], [52, 5, 0, 0, 3, 9, 0, 0, 1, 5, 2, 1, 14, 11, 5, 6, 4, 3, 19, 3, 15, 2, 0, 0, 5, 28, 12, 2, 9, 42, 2, 5, 13, 20, 10, 0, 31, 10, 6, 16, 10, 2, 17, 18, 7, 2, 16, 0, 69, 33, 103, 19, 16, 4, 21, 18, 3, 2, 11, 0, 135, 40, 11, 34, 1, 3, 14, 7, 3, 4, 0, 0, 16, 18, 8, 24, 3, 5, 73, 2, 28, 7, 7, 0, 56, 178, 4, 26, 0, 1, 16, 0, 8, 0, 13, 0, 1, 1, 64, 69, 31, 1, 0, 0, 6, 5, 2, 1, 14, 39, 0, 14, 0, 1, 11, 8, 3, 6, 3, 2, 2, 61, 2, 3, 12, 12, 6, 4, 4, 3, 4, 0, 39, 20, 17, 10, 2, 1, 9, 10, 8, 2, 0, 2, 0, 30, 22, 5, 4, 1, 5, 6, 17, 6, 6, 1, 0, 12, 4, 36, 0, 7, 0, 5, 1, 5, 2, 1, 22, 3, 10, 26, 14, 2, 4, 4, 3, 0, 0, 1, 2, 290, 3, 14, 20, 0, 3, 0, 1, 2, 3, 1, 83, 67, 51, 43, 54, 67, 5, 81, 112, 59, 75, 61, 42, 78, 64, 65, 43, 49, 44, 76, 107, 69, 26, 58, 67, 57, 106, 44, 2, 78, 26, 108, 42, 41, 36, 24, 24, 36, 36, 43, 2, 31, 59, 38, 23, 62, 45, 112, 96, 100, 72, 83, 131, 119, 71, 138, 5, 73, 49, 48, 94, 152, 86, 133, 134, 172, 108, 87, 39, 38, 26, 28, 73, 57, 73, 129, 54, 57, 63, 118, 72, 36, 78, 63, 77, 76, 142, 108, 178, 82, 74, 89, 45, 35, 35, 95, 6, 96, 38, 55, 51, 55, 59, 72, 45, 61, 8, 20, 43, 57, 74, 44, 48, 80, 53, 81, 59, 48, 26, 19, 35, 3, 61, 22, 52, 70, 101, 52, 0, 71, 63, 0, 86, 28, 55, 17, 58, 29, 0, 22, 1, 35, 23, 56, 30, 50, 74, 32, 5, 124, 62, 39, 14, 40, 49, 59, 43, 70, 37, 56, 42, 40, 56, 47, 40, 27, 21, 64, 43, 40, 28, 50, 27, 38, 69, 19, 26, 95, 62, 24, 46, 105, 96, 26, 0, 50, 73, 53, 13, 65, 34, 142, 68, 51, 52, 29, 0, 27, 62, 10, 171, 36, 58, 103, 59, 51, 82, 24, 0, 79, 42, 75, 42, 23, 83, 56, 43, 62, 53, 25, 1, 78, 37, 48, 112, 66, 122, 26, 4, 109, 29, 63, 0, 22, 58, 33, 153, 95, 118, 74, 99, 76, 55, 39, 0, 22, 66, 23, 233, 23, 115, 60, 57, 0, 44, 7, 0, 34, 45, 49, 47, 18, 57, 2, 0, 0, 0, 0, 33, 0, 70, 28, 36, 0, 37, 0, 18, 1, 16, 50, 35, 0, 25, 75, 41, 0, 34, 0, 69, 8, 38, 0, 45, 0, 71, 0, 23, 0, 40, 31, 47, 41, 21, 0, 26, 30, 39, 28, 31, 12, 26, 46, 10, 26, 77, 25, 0, 74, 134, 55, 81, 17, 58, 2, 50, 43, 3, 29, 17, 29, 4, 34, 24, 18, 22, 30, 26, 8, 22, 38, 0, 18, 32, 59, 1, 39, 24, 151, 5, 47, 39, 0, 15, 34, 46, 57, 23, 7, 58, 12], [12, 2, 0, 2, 4, 8, 8, 0, 0, 0, 4, 1, 9, 8, 1, 1, 7, 5, 9, 0, 11, 3, 0, 0, 6, 13, 8, 1, 9, 46, 1, 4, 14, 13, 4, 0, 26, 15, 4, 17, 1, 1, 14, 4, 3, 3, 9, 1, 38, 34, 84, 18, 16, 3, 14, 5, 1, 0, 2, 0, 193, 16, 12, 17, 0, 10, 7, 1, 3, 6, 0, 0, 25, 24, 19, 32, 2, 12, 53, 3, 26, 5, 7, 0, 66, 218, 10, 24, 0, 0, 20, 0, 10, 0, 14, 0, 1, 1, 9, 35, 10, 0, 3, 0, 6, 1, 3, 0, 8, 28, 0, 4, 0, 0, 3, 0, 0, 3, 2, 1, 5, 10, 1, 0, 8, 1, 1, 3, 0, 1, 1, 0, 17, 7, 3, 16, 0, 2, 0, 0, 7, 1, 1, 0, 0, 37, 18, 1, 1, 0, 3, 0, 2, 5, 2, 0, 0, 4, 3, 30, 1, 4, 2, 4, 5, 2, 2, 1, 18, 0, 31, 9, 9, 3, 5, 3, 12, 1, 1, 0, 9, 282, 0, 33, 17, 0, 4, 6, 0, 0, 3, 0, 62, 59, 25, 28, 53, 59, 140, 68, 131, 34, 32, 36, 10, 44, 21, 56, 22, 20, 48, 53, 152, 35, 18, 42, 23, 22, 34, 21, 1, 31, 9, 71, 23, 38, 36, 39, 24, 30, 38, 52, 1, 36, 33, 51, 24, 67, 37, 62, 94, 75, 70, 50, 130, 107, 86, 69, 5, 41, 37, 43, 62, 150, 75, 78, 97, 210, 87, 87, 23, 18, 12, 32, 71, 77, 73, 88, 37, 30, 61, 48, 32, 35, 40, 25, 29, 48, 63, 47, 112, 59, 73, 45, 58, 22, 21, 59, 0, 58, 22, 42, 61, 68, 76, 95, 57, 36, 30, 39, 54, 62, 114, 50, 57, 114, 74, 89, 43, 42, 39, 29, 43, 7, 53, 31, 81, 54, 89, 55, 70, 24, 103, 0, 71, 21, 61, 9, 52, 39, 58, 17, 0, 22, 17, 41, 45, 37, 16, 36, 4, 88, 41, 39, 28, 28, 49, 33, 28, 76, 18, 25, 33, 22, 32, 43, 29, 8, 23, 56, 91, 58, 62, 85, 23, 68, 86, 36, 33, 125, 58, 18, 27, 101, 72, 6, 0, 42, 49, 10, 16, 31, 22, 168, 69, 36, 37, 17, 0, 20, 16, 29, 212, 31, 69, 102, 74, 39, 90, 16, 0, 48, 40, 54, 23, 10, 71, 57, 19, 42, 24, 4, 1, 78, 27, 38, 105, 82, 227, 21, 1, 134, 17, 39, 1, 21, 51, 52, 193, 139, 347, 103, 110, 91, 70, 32, 0, 52, 43, 25, 288, 43, 120, 123, 103, 0, 61, 10, 0, 50, 59, 20, 26, 8, 44, 8, 0, 39, 0, 0, 23, 0, 41, 8, 22, 0, 28, 0, 7, 0, 14, 39, 24, 0, 18, 58, 27, 0, 21, 0, 47, 8, 38, 0, 31, 0, 61, 0, 25, 0, 29, 33, 48, 25, 20, 0, 16, 44, 46, 29, 21, 6, 24, 45, 10, 13, 63, 16, 0, 58, 137, 36, 65, 9, 19, 0, 42, 26, 2, 10, 16, 35, 0, 19, 9, 13, 21, 26, 10, 1, 19, 25, 0, 9, 26, 60, 1, 25, 16, 69, 2, 35, 35, 0, 37, 26, 43, 56, 25, 2, 53, 11], [36, 2, 0, 1, 2, 12, 0, 0, 0, 3, 7, 2, 15, 12, 4, 4, 2, 1, 16, 2, 12, 4, 2, 0, 58, 27, 9, 0, 9, 43, 0, 7, 17, 12, 2, 0, 54, 9, 4, 6, 11, 6, 12, 9, 13, 5, 10, 0, 56, 67, 133, 11, 27, 13, 20, 14, 3, 3, 1, 0, 204, 34, 10, 35, 0, 2, 6, 9, 0, 9, 0, 0, 41, 18, 10, 36, 8, 8, 137, 4, 46, 5, 9, 0, 97, 331, 9, 18, 0, 1, 35, 0, 11, 0, 6, 0, 0, 0, 26, 66, 30, 1, 0, 0, 4, 3, 4, 1, 10, 35, 0, 2, 1, 0, 11, 1, 2, 3, 4, 1, 19, 41, 2, 0, 6, 5, 2, 4, 4, 3, 5, 1, 34, 15, 13, 20, 1, 2, 1, 0, 8, 1, 2, 1, 1, 46, 26, 5, 5, 5, 3, 6, 7, 6, 1, 3, 0, 6, 5, 54, 0, 8, 2, 1, 6, 5, 2, 0, 28, 3, 14, 25, 25, 4, 6, 4, 10, 2, 3, 0, 5, 296, 1, 21, 41, 1, 6, 5, 0, 1, 1, 0, 96, 65, 49, 46, 79, 79, 58, 136, 169, 84, 56, 68, 43, 110, 43, 64, 27, 27, 61, 104, 199, 84, 41, 92, 62, 55, 95, 58, 1, 80, 27, 108, 42, 94, 51, 53, 29, 40, 44, 98, 3, 47, 53, 69, 37, 116, 48, 84, 132, 132, 111, 92, 133, 122, 87, 133, 74, 104, 49, 67, 140, 243, 105, 129, 163, 252, 139, 102, 28, 21, 36, 42, 112, 108, 113, 148, 64, 62, 95, 123, 62, 52, 80, 32, 62, 60, 112, 85, 153, 99, 98, 79, 92, 18, 39, 87, 3, 113, 29, 84, 75, 85, 82, 96, 113, 107, 28, 50, 67, 73, 155, 66, 74, 141, 91, 126, 87, 50, 47, 34, 72, 6, 77, 38, 111, 74, 133, 68, 9, 75, 156, 0, 140, 63, 93, 13, 80, 47, 10, 47, 0, 35, 17, 71, 64, 60, 57, 60, 98, 144, 69, 75, 48, 56, 67, 44, 60, 63, 38, 64, 46, 59, 55, 80, 60, 30, 32, 73, 86, 79, 69, 69, 32, 75, 123, 55, 54, 205, 115, 14, 56, 242, 139, 26, 0, 71, 97, 53, 107, 53, 36, 198, 97, 82, 89, 65, 0, 49, 60, 40, 249, 72, 121, 146, 156, 98, 165, 27, 0, 135, 64, 91, 45, 18, 167, 123, 35, 103, 58, 28, 0, 108, 65, 64, 197, 77, 304, 43, 0, 193, 21, 74, 0, 28, 88, 51, 358, 222, 287, 142, 170, 136, 107, 62, 0, 79, 101, 46, 419, 75, 216, 147, 165, 2, 64, 26, 0, 83, 92, 55, 44, 19, 75, 9, 1, 2, 0, 0, 20, 0, 58, 6, 23, 0, 40, 0, 14, 0, 17, 48, 19, 0, 17, 71, 30, 0, 22, 3, 42, 4, 37, 0, 29, 0, 60, 0, 21, 0, 27, 33, 55, 32, 18, 0, 30, 37, 52, 16, 40, 13, 19, 46, 6, 17, 59, 16, 0, 71, 151, 33, 71, 10, 24, 0, 42, 39, 14, 16, 12, 33, 0, 32, 16, 17, 27, 20, 24, 1, 21, 33, 1, 16, 18, 59, 0, 36, 24, 149, 2, 39, 25, 0, 23, 30, 52, 69, 27, 4, 53, 15], [31, 7, 0, 2, 3, 25, 14, 0, 0, 3, 2, 1, 11, 18, 6, 7, 4, 6, 17, 3, 19, 5, 1, 0, 9, 27, 10, 1, 8, 61, 1, 4, 23, 32, 4, 0, 62, 12, 7, 30, 6, 9, 16, 5, 9, 1, 3, 0, 48, 73, 115, 16, 33, 7, 31, 8, 6, 2, 8, 0, 268, 43, 12, 48, 0, 12, 9, 7, 7, 5, 0, 1, 44, 33, 29, 58, 8, 12, 121, 5, 50, 10, 11, 0, 123, 337, 12, 36, 1, 3, 37, 0, 16, 0, 24, 0, 1, 0, 35, 22, 4, 4, 7, 0, 5, 4, 2, 1, 6, 17, 0, 4, 0, 0, 2, 1, 3, 5, 0, 0, 3, 9, 1, 0, 10, 4, 0, 2, 1, 4, 0, 0, 11, 10, 9, 4, 1, 0, 1, 1, 4, 1, 0, 0, 0, 23, 10, 7, 3, 3, 0, 0, 10, 1, 2, 0, 0, 1, 5, 13, 0, 5, 2, 0, 5, 6, 2, 0, 48, 3, 24, 21, 20, 2, 8, 9, 6, 2, 1, 0, 4, 477, 7, 20, 19, 1, 6, 2, 0, 0, 4, 0, 84, 110, 66, 48, 84, 117, 274, 162, 233, 80, 44, 69, 29, 93, 54, 110, 33, 41, 95, 115, 241, 65, 61, 81, 64, 39, 53, 45, 2, 67, 12, 144, 48, 118, 79, 64, 45, 45, 59, 93, 7, 56, 77, 84, 53, 141, 61, 114, 156, 144, 115, 89, 188, 149, 153, 172, 14, 71, 70, 94, 175, 288, 154, 185, 172, 307, 141, 90, 36, 30, 38, 74, 122, 125, 117, 193, 88, 74, 118, 116, 71, 32, 85, 36, 64, 78, 102, 77, 240, 105, 123, 83, 104, 20, 34, 139, 3, 137, 27, 107, 133, 114, 128, 170, 161, 104, 44, 76, 80, 105, 236, 76, 95, 207, 137, 167, 136, 79, 70, 68, 92, 8, 114, 63, 148, 103, 158, 129, 104, 61, 142, 0, 219, 46, 121, 22, 79, 113, 77, 25, 0, 52, 36, 67, 78, 81, 45, 72, 16, 135, 78, 88, 50, 39, 82, 59, 43, 130, 35, 68, 61, 38, 46, 87, 70, 21, 42, 86, 123, 104, 80, 120, 48, 122, 174, 62, 50, 338, 154, 47, 43, 211, 174, 20, 0, 88, 133, 35, 32, 44, 57, 309, 123, 78, 110, 48, 1, 67, 49, 43, 410, 50, 128, 192, 197, 85, 217, 34, 0, 142, 75, 84, 55, 33, 208, 132, 36, 90, 66, 32, 0, 136, 68, 53, 239, 154, 596, 94, 0, 258, 23, 95, 0, 50, 147, 116, 521, 349, 602, 193, 233, 193, 163, 79, 1, 82, 158, 51, 642, 92, 298, 224, 208, 2, 159, 35, 0, 118, 146, 35, 49, 28, 94, 6, 0, 180, 0, 0, 45, 0, 83, 11, 56, 0, 39, 0, 32, 0, 25, 46, 23, 0, 36, 86, 52, 0, 27, 0, 70, 5, 51, 0, 55, 1, 102, 0, 36, 0, 65, 45, 99, 33, 43, 0, 36, 62, 69, 35, 57, 19, 47, 85, 28, 16, 83, 28, 1, 110, 247, 65, 77, 25, 45, 0, 41, 42, 5, 15, 15, 59, 0, 22, 21, 24, 28, 43, 34, 3, 39, 50, 1, 19, 28, 85, 0, 40, 27, 195, 1, 49, 62, 0, 48, 55, 72, 103, 53, 5, 66, 30], [125, 11, 0, 9, 10, 20, 0, 0, 0, 20, 0, 0, 28, 26, 5, 22, 8, 3, 40, 1, 43, 6, 3, 0, 8, 54, 8, 3, 27, 93, 2, 20, 32, 16, 8, 0, 121, 16, 18, 35, 7, 11, 36, 13, 21, 5, 17, 0, 160, 92, 275, 31, 74, 20, 128, 60, 19, 3, 9, 0, 242, 132, 19, 43, 4, 13, 35, 18, 3, 8, 1, 0, 15, 14, 10, 29, 4, 11, 60, 2, 26, 4, 3, 0, 58, 229, 3, 25, 1, 0, 19, 0, 5, 0, 11, 0, 6, 0, 67, 0, 0, 1, 0, 1, 3, 1, 0, 0, 0, 48, 0, 5, 7, 0, 0, 0, 6, 0, 4, 0, 3, 2, 11, 2, 5, 0, 15, 0, 9, 4, 0, 0, 2, 3, 22, 0, 0, 0, 11, 0, 0, 0, 0, 2, 5, 0, 7, 9, 0, 3, 7, 6, 39, 2, 0, 1, 0, 19, 5, 8, 0, 5, 0, 0, 0, 6, 2, 0, 12, 0, 1, 16, 6, 0, 2, 1, 0, 0, 0, 0, 0, 240, 0, 2, 0, 0, 1, 1, 0, 1, 0, 0, 230, 131, 106, 79, 184, 90, 1, 288, 117, 118, 132, 142, 114, 197, 105, 110, 98, 85, 95, 140, 86, 155, 66, 192, 126, 152, 271, 148, 9, 136, 88, 211, 81, 67, 47, 44, 30, 25, 42, 60, 1, 35, 166, 38, 37, 220, 102, 172, 222, 229, 144, 189, 281, 265, 147, 431, 14, 232, 123, 140, 262, 316, 172, 325, 272, 310, 244, 222, 52, 75, 89, 60, 208, 210, 200, 341, 120, 96, 166, 297, 133, 76, 272, 96, 142, 138, 288, 275, 369, 173, 252, 216, 148, 81, 86, 100, 29, 181, 102, 108, 73, 109, 102, 99, 70, 65, 17, 63, 51, 87, 164, 66, 81, 104, 84, 84, 60, 40, 65, 35, 45, 1, 78, 32, 86, 80, 92, 77, 0, 218, 70, 0, 356, 78, 232, 62, 217, 42, 0, 95, 0, 102, 107, 133, 96, 125, 127, 159, 18, 328, 133, 191, 27, 106, 80, 97, 104, 132, 87, 95, 82, 97, 152, 129, 110, 58, 71, 135, 43, 54, 29, 59, 22, 56, 174, 27, 51, 246, 168, 68, 115, 394, 175, 72, 0, 157, 236, 124, 8, 132, 135, 364, 207, 124, 159, 113, 0, 102, 190, 99, 232, 79, 220, 168, 174, 166, 243, 88, 0, 279, 129, 198, 55, 49, 230, 153, 69, 139, 264, 113, 0, 274, 140, 146, 230, 229, 262, 73, 10, 272, 79, 126, 1, 36, 120, 40, 287, 188, 236, 106, 119, 91, 89, 56, 0, 54, 72, 37, 388, 58, 127, 126, 106, 1, 84, 35, 0, 64, 78, 153, 73, 73, 161, 8, 0, 0, 0, 0, 20, 0, 115, 9, 12, 0, 43, 0, 32, 0, 32, 15, 39, 0, 46, 9, 36, 0, 4, 0, 64, 18, 38, 0, 36, 0, 79, 0, 42, 0, 8, 14, 18, 3, 1, 0, 13, 22, 18, 14, 7, 17, 2, 22, 14, 21, 93, 35, 3, 127, 105, 13, 90, 15, 42, 3, 30, 56, 4, 14, 24, 22, 1, 62, 27, 45, 5, 18, 18, 7, 20, 65, 2, 22, 30, 65, 0, 41, 18, 82, 18, 7, 24, 0, 9, 9, 16, 45, 18, 3, 18, 6], [8, 1, 0, 2, 1, 12, 2, 0, 0, 4, 4, 0, 3, 6, 1, 5, 1, 2, 21, 2, 4, 3, 2, 0, 4, 25, 17, 3, 3, 18, 0, 3, 3, 12, 4, 0, 20, 16, 2, 18, 6, 6, 12, 5, 6, 0, 1, 1, 39, 40, 70, 13, 16, 2, 26, 13, 4, 0, 4, 0, 123, 24, 2, 48, 0, 4, 4, 0, 9, 10, 1, 0, 29, 16, 2, 18, 6, 12, 63, 2, 23, 12, 9, 0, 58, 194, 3, 17, 0, 0, 23, 0, 10, 0, 4, 2, 1, 1, 12, 44, 26, 0, 2, 0, 4, 0, 1, 0, 10, 20, 0, 4, 1, 1, 5, 0, 4, 0, 0, 3, 2, 14, 4, 0, 5, 1, 4, 2, 0, 0, 2, 0, 35, 12, 8, 12, 0, 3, 0, 4, 12, 0, 0, 0, 0, 31, 26, 0, 1, 0, 2, 0, 14, 6, 4, 0, 0, 2, 4, 34, 0, 2, 2, 0, 6, 7, 0, 0, 15, 2, 49, 12, 10, 2, 2, 0, 2, 2, 0, 0, 6, 233, 2, 26, 45, 0, 6, 2, 0, 4, 2, 0, 34, 29, 30, 26, 48, 61, 148, 54, 89, 67, 27, 29, 10, 47, 28, 39, 12, 9, 27, 79, 115, 39, 18, 32, 28, 19, 29, 19, 0, 34, 8, 64, 30, 48, 44, 16, 14, 20, 26, 50, 2, 36, 21, 33, 22, 65, 26, 58, 62, 102, 79, 57, 135, 81, 83, 50, 6, 67, 45, 33, 85, 135, 113, 101, 87, 179, 72, 54, 18, 10, 25, 26, 72, 64, 66, 98, 45, 37, 34, 74, 21, 13, 50, 16, 32, 30, 75, 38, 102, 38, 88, 54, 33, 27, 15, 54, 2, 52, 17, 30, 46, 45, 49, 71, 44, 31, 18, 27, 31, 54, 100, 62, 50, 88, 77, 99, 63, 41, 51, 55, 44, 2, 65, 30, 49, 47, 84, 61, 58, 26, 120, 1, 89, 24, 54, 18, 40, 50, 30, 13, 1, 22, 2, 38, 40, 36, 37, 39, 6, 70, 45, 42, 17, 10, 27, 49, 11, 62, 24, 20, 21, 17, 36, 48, 20, 17, 8, 54, 70, 79, 70, 38, 27, 53, 100, 33, 38, 184, 81, 14, 16, 149, 80, 5, 2, 56, 52, 16, 16, 20, 33, 186, 67, 41, 28, 16, 0, 33, 21, 22, 245, 32, 70, 97, 84, 31, 77, 9, 2, 50, 39, 63, 12, 10, 110, 39, 24, 44, 47, 14, 1, 67, 40, 29, 153, 112, 195, 53, 0, 152, 25, 35, 0, 18, 76, 27, 299, 213, 217, 111, 89, 97, 80, 41, 1, 42, 73, 15, 354, 56, 149, 84, 68, 0, 79, 24, 0, 43, 59, 8, 16, 4, 37, 6, 0, 36, 0, 0, 43, 0, 46, 3, 12, 0, 16, 0, 10, 0, 6, 18, 21, 0, 13, 37, 35, 0, 14, 0, 41, 7, 33, 0, 40, 0, 60, 0, 8, 0, 18, 26, 38, 36, 5, 0, 8, 30, 20, 18, 24, 14, 24, 36, 10, 6, 35, 10, 0, 59, 108, 44, 25, 4, 8, 0, 12, 16, 0, 1, 2, 22, 0, 16, 8, 8, 4, 24, 8, 2, 8, 19, 1, 10, 12, 22, 1, 21, 10, 91, 0, 23, 20, 0, 19, 12, 32, 34, 18, 4, 42, 14], [138, 10, 1, 8, 14, 3, 0, 1, 1, 6, 4, 0, 27, 26, 9, 14, 12, 2, 40, 6, 46, 4, 0, 0, 8, 50, 13, 17, 19, 94, 1, 17, 69, 17, 42, 0, 124, 7, 33, 55, 24, 12, 35, 18, 36, 2, 17, 0, 166, 98, 285, 29, 23, 12, 83, 80, 34, 12, 16, 0, 158, 66, 6, 98, 0, 0, 24, 29, 6, 10, 0, 1, 19, 16, 1, 16, 0, 11, 105, 8, 45, 3, 9, 2, 56, 295, 9, 17, 2, 0, 7, 0, 27, 1, 23, 3, 40, 0, 80, 244, 140, 0, 0, 0, 4, 4, 2, 2, 33, 76, 6, 24, 8, 10, 35, 16, 6, 30, 4, 5, 4, 128, 14, 4, 38, 35, 32, 14, 12, 0, 13, 4, 82, 55, 44, 33, 1, 44, 0, 22, 26, 3, 13, 15, 19, 164, 80, 32, 10, 26, 25, 3, 231, 17, 9, 9, 1, 13, 23, 84, 1, 15, 7, 12, 3, 2, 0, 1, 32, 6, 10, 14, 16, 2, 0, 2, 0, 4, 5, 0, 6, 287, 7, 22, 44, 2, 9, 9, 2, 0, 4, 1, 332, 207, 112, 105, 253, 73, 0, 278, 125, 137, 190, 181, 136, 284, 158, 198, 73, 121, 143, 130, 130, 181, 95, 150, 144, 189, 331, 135, 6, 181, 117, 273, 84, 76, 62, 25, 39, 21, 47, 58, 2, 25, 129, 39, 32, 332, 93, 225, 320, 222, 118, 203, 340, 285, 193, 375, 22, 245, 93, 260, 285, 364, 177, 290, 395, 435, 241, 284, 107, 151, 80, 62, 269, 148, 306, 340, 196, 134, 196, 380, 87, 82, 299, 110, 169, 172, 459, 331, 573, 184, 278, 295, 187, 63, 96, 160, 31, 238, 129, 108, 86, 131, 143, 124, 48, 73, 15, 76, 88, 87, 149, 65, 71, 85, 66, 98, 44, 64, 64, 38, 94, 3, 100, 32, 78, 94, 96, 54, 2, 298, 95, 6, 395, 150, 208, 45, 272, 88, 0, 131, 3, 69, 122, 233, 113, 119, 188, 150, 22, 326, 196, 224, 30, 115, 188, 133, 138, 110, 49, 154, 107, 99, 170, 132, 159, 50, 88, 213, 78, 75, 34, 79, 51, 60, 178, 30, 41, 350, 160, 90, 104, 399, 267, 113, 0, 152, 257, 140, 22, 129, 69, 318, 166, 160, 162, 119, 1, 107, 199, 88, 309, 115, 176, 279, 185, 137, 276, 77, 4, 285, 133, 312, 84, 22, 267, 221, 86, 116, 164, 69, 1, 300, 153, 141, 296, 177, 215, 67, 14, 411, 116, 120, 0, 40, 88, 50, 240, 165, 130, 91, 137, 92, 85, 32, 0, 44, 86, 27, 237, 64, 228, 82, 133, 0, 88, 30, 0, 64, 91, 222, 70, 55, 201, 11, 0, 0, 0, 0, 52, 0, 131, 11, 81, 0, 59, 0, 56, 0, 17, 54, 59, 0, 69, 67, 60, 0, 56, 0, 121, 24, 72, 0, 43, 0, 121, 0, 36, 0, 20, 28, 42, 20, 15, 0, 18, 30, 32, 16, 30, 12, 33, 23, 22, 20, 147, 48, 4, 227, 286, 77, 107, 15, 65, 2, 54, 90, 4, 51, 31, 59, 2, 46, 13, 56, 43, 29, 20, 0, 48, 43, 0, 47, 22, 77, 1, 50, 48, 315, 21, 29, 23, 0, 9, 33, 21, 73, 29, 8, 35, 5], [20, 8, 0, 0, 2, 8, 0, 1, 0, 2, 6, 2, 12, 8, 3, 2, 4, 6, 18, 2, 14, 0, 0, 0, 54, 18, 4, 4, 16, 48, 0, 0, 12, 20, 4, 0, 52, 14, 8, 13, 8, 2, 20, 4, 2, 4, 4, 0, 35, 45, 90, 6, 15, 9, 34, 18, 5, 2, 6, 0, 112, 39, 6, 24, 0, 4, 15, 8, 2, 2, 2, 0, 22, 20, 6, 22, 14, 2, 60, 2, 41, 13, 4, 0, 80, 152, 2, 19, 2, 0, 17, 0, 12, 0, 20, 0, 2, 2, 36, 17, 20, 0, 0, 0, 0, 2, 2, 0, 2, 37, 0, 0, 4, 0, 2, 0, 0, 0, 6, 0, 22, 21, 2, 0, 8, 0, 8, 2, 0, 0, 0, 0, 15, 4, 9, 4, 0, 0, 0, 0, 2, 1, 0, 0, 0, 14, 8, 2, 2, 1, 0, 6, 24, 4, 0, 2, 0, 8, 0, 4, 0, 2, 0, 2, 0, 2, 2, 1, 12, 8, 4, 29, 20, 4, 2, 6, 3, 0, 4, 0, 4, 324, 1, 17, 8, 0, 2, 2, 0, 0, 0, 0, 76, 53, 67, 23, 76, 49, 42, 128, 134, 90, 103, 62, 34, 77, 40, 72, 29, 36, 54, 75, 198, 84, 32, 73, 75, 46, 98, 36, 2, 58, 28, 118, 26, 74, 54, 50, 9, 39, 48, 77, 4, 32, 92, 50, 33, 94, 48, 74, 83, 127, 89, 86, 158, 124, 108, 155, 55, 96, 42, 63, 150, 202, 90, 146, 161, 202, 128, 101, 33, 18, 41, 38, 95, 82, 85, 184, 72, 46, 73, 98, 50, 56, 82, 45, 85, 81, 92, 124, 146, 91, 109, 82, 80, 24, 52, 65, 8, 116, 34, 69, 79, 80, 76, 66, 60, 64, 18, 49, 82, 48, 152, 42, 64, 89, 94, 139, 75, 74, 30, 24, 76, 6, 81, 27, 73, 46, 100, 75, 6, 64, 92, 0, 123, 29, 110, 21, 81, 52, 4, 33, 0, 24, 28, 53, 42, 72, 52, 56, 68, 114, 67, 55, 39, 29, 66, 46, 26, 80, 25, 52, 62, 28, 52, 74, 33, 20, 28, 96, 64, 58, 22, 57, 18, 53, 84, 33, 36, 146, 76, 11, 62, 198, 74, 29, 1, 49, 68, 38, 103, 68, 21, 163, 95, 41, 81, 36, 2, 37, 48, 18, 161, 38, 74, 100, 120, 70, 156, 11, 0, 130, 53, 68, 30, 12, 110, 57, 47, 88, 53, 18, 1, 69, 28, 42, 131, 73, 139, 40, 0, 160, 22, 66, 0, 29, 102, 55, 189, 170, 237, 109, 124, 119, 113, 51, 0, 49, 52, 33, 325, 50, 162, 120, 120, 0, 87, 15, 0, 60, 74, 41, 22, 13, 45, 5, 0, 2, 0, 0, 30, 0, 57, 14, 51, 0, 32, 0, 30, 0, 12, 62, 28, 0, 24, 78, 44, 0, 27, 0, 61, 14, 44, 0, 32, 0, 63, 0, 17, 0, 26, 48, 42, 52, 16, 0, 26, 34, 32, 27, 40, 5, 28, 52, 31, 21, 67, 36, 1, 86, 156, 76, 70, 4, 28, 0, 36, 33, 30, 16, 16, 44, 0, 11, 26, 36, 23, 42, 22, 0, 22, 29, 2, 24, 19, 76, 0, 38, 28, 156, 4, 48, 20, 0, 14, 35, 52, 73, 32, 14, 75, 15], [22, 1, 2, 5, 3, 3, 2, 3, 2, 2, 7, 5, 11, 4, 7, 4, 6, 4, 5, 2, 2, 1, 1, 3, 0, 7, 3, 1, 17, 5, 5, 0, 2, 4, 4, 5, 16, 5, 5, 2, 3, 1, 3, 5, 0, 3, 6, 1, 10, 2, 3, 4, 5, 2, 3, 4, 3, 3, 9, 4, 15, 8, 8, 7, 0, 3, 6, 1, 4, 1, 5, 1, 8, 2, 2, 7, 1, 2, 6, 4, 6, 6, 6, 4, 8, 13, 4, 4, 9, 0, 1, 1, 6, 5, 5, 5, 47, 12, 3762, 109, 250, 77, 0, 4, 146, 128, 5, 11, 43, 3063, 1, 75, 2, 7, 44, 4, 243, 16, 264, 11, 171, 82, 226, 38, 42, 28, 25, 18, 1, 0, 6, 6, 82, 93, 4, 22, 7, 45, 110, 12, 11, 1, 6, 4, 1, 75, 107, 478, 35, 39, 33, 18, 145, 17, 8, 9, 8, 652, 23, 96, 1, 25, 12, 16, 6, 80, 0, 0, 923, 18, 16, 581, 2, 4, 0, 0, 18, 2, 1, 0, 11, 8927, 13, 26, 41, 2, 6, 10, 0, 9, 9, 0, 7, 3, 12, 9, 3, 14, 0, 3, 11, 19, 25, 4, 18, 28, 8, 27, 3, 31, 2, 5, 13, 8, 6, 35, 25, 3, 26, 20, 1, 5, 4, 32, 3, 5, 14, 8, 5, 2, 2, 23, 2, 7, 3, 9, 5, 18, 7, 4, 10, 7, 7, 4, 6, 9, 6, 21, 0, 2, 15, 15, 5, 17, 5, 62, 8, 3, 5, 3, 0, 3, 15, 7, 19, 4, 14, 9, 18, 5, 6, 20, 5, 8, 12, 9, 14, 21, 17, 28, 17, 6, 1, 26, 11, 3, 5, 7, 0, 4, 0, 3, 3, 19, 15, 6, 5, 6, 3, 9, 10, 12, 5, 6, 10, 5, 9, 4, 4, 3, 6, 15, 9, 1, 11, 1, 4, 7, 7, 16, 2, 23, 15, 1, 32, 24, 3, 7, 20, 25, 0, 6, 4, 5, 3, 21, 21, 4, 15, 10, 0, 15, 24, 14, 13, 9, 12, 13, 19, 11, 5, 13, 12, 15, 10, 3, 12, 5, 26, 11, 7, 10, 6, 36, 8, 12, 9, 11, 4, 28, 6, 6, 10, 7, 9, 8, 1, 3, 4, 24, 0, 15, 3, 34, 23, 12, 9, 15, 6, 0, 5, 4, 11, 10, 11, 8, 16, 6, 10, 41, 1, 6, 9, 8, 4, 18, 26, 6, 8, 35, 4, 4, 4, 8, 8, 8, 13, 23, 15, 11, 0, 4, 3, 4, 5, 5, 6, 4, 23, 12, 17, 9, 3, 12, 6, 9, 2, 4, 19, 4, 22, 14, 15, 10, 12, 0, 10, 7, 1, 14, 5, 24, 10, 10, 10, 4, 3, 22, 0, 3, 1129, 2, 3780, 1115, 2662, 2, 2024, 0, 1869, 5, 1082, 2551, 1079, 18, 1727, 1583, 1557, 0, 1748, 6, 2586, 994, 1977, 3, 2024, 8, 3500, 0, 1491, 0, 889, 926, 1543, 1076, 709, 0, 569, 1143, 1202, 688, 1142, 445, 1031, 1109, 1412, 1215, 4389, 1866, 23, 5713, 3858, 2439, 2202, 1045, 2807, 101, 3354, 2499, 209, 1601, 924, 2198, 211, 2121, 1118, 1993, 1397, 1055, 1731, 386, 1120, 1830, 72, 1048, 1051, 3484, 12, 1743, 1597, 2013, 421, 1011, 985, 6, 472, 1001, 1442, 2292, 1002, 280, 1266, 639], [55, 16, 0, 0, 1, 30, 0, 1, 0, 2, 6, 0, 17, 17, 5, 11, 8, 3, 32, 1, 32, 2, 5, 0, 4, 60, 16, 2, 13, 49, 1, 4, 28, 35, 6, 0, 68, 12, 9, 26, 11, 7, 47, 10, 17, 6, 11, 0, 90, 54, 182, 20, 34, 14, 60, 25, 22, 4, 1, 0, 349, 60, 12, 67, 1, 16, 11, 5, 6, 17, 10, 0, 57, 41, 34, 57, 9, 19, 200, 12, 61, 12, 12, 0, 161, 643, 15, 43, 0, 6, 49, 0, 23, 0, 29, 0, 3, 0, 34, 103, 51, 3, 0, 0, 9, 5, 10, 2, 19, 64, 1, 16, 3, 2, 17, 6, 0, 9, 3, 1, 4, 46, 0, 1, 17, 10, 1, 2, 3, 4, 1, 1, 65, 31, 14, 37, 1, 3, 3, 3, 7, 0, 2, 1, 0, 83, 58, 2, 9, 5, 6, 2, 17, 11, 4, 3, 0, 7, 15, 60, 0, 6, 2, 4, 8, 6, 3, 0, 31, 1, 18, 35, 32, 3, 7, 4, 7, 3, 2, 0, 12, 718, 7, 64, 64, 1, 11, 4, 0, 1, 3, 0, 163, 153, 87, 74, 115, 154, 4, 199, 232, 96, 84, 92, 57, 104, 90, 101, 64, 48, 90, 139, 328, 118, 60, 113, 70, 56, 97, 73, 4, 91, 27, 183, 53, 153, 116, 105, 43, 66, 66, 93, 4, 76, 135, 80, 59, 198, 65, 291, 238, 201, 204, 159, 230, 270, 147, 200, 5, 147, 74, 108, 190, 384, 191, 259, 243, 396, 172, 173, 50, 63, 34, 74, 123, 175, 203, 237, 102, 109, 142, 141, 64, 72, 137, 76, 85, 109, 185, 130, 282, 177, 158, 145, 93, 38, 51, 130, 4, 140, 56, 99, 159, 133, 161, 223, 164, 147, 28, 92, 99, 146, 283, 141, 163, 208, 167, 193, 151, 119, 94, 79, 134, 11, 170, 63, 182, 122, 226, 139, 0, 67, 231, 1, 227, 128, 149, 33, 120, 136, 1, 60, 0, 62, 28, 93, 83, 94, 151, 89, 9, 231, 113, 114, 68, 42, 100, 88, 67, 150, 44, 90, 66, 45, 83, 119, 94, 27, 62, 116, 122, 97, 56, 117, 46, 160, 205, 61, 98, 342, 165, 93, 73, 346, 215, 39, 0, 118, 149, 62, 25, 68, 59, 341, 154, 108, 105, 60, 0, 94, 84, 51, 521, 69, 190, 220, 205, 129, 265, 40, 0, 176, 105, 132, 71, 23, 268, 147, 67, 136, 105, 32, 0, 189, 88, 96, 294, 133, 466, 107, 0, 299, 45, 107, 0, 43, 143, 99, 549, 374, 424, 236, 296, 233, 215, 83, 0, 121, 167, 62, 699, 128, 368, 189, 276, 2, 154, 48, 0, 128, 162, 73, 93, 23, 106, 10, 0, 3, 0, 0, 77, 0, 165, 21, 77, 0, 80, 1, 67, 0, 44, 155, 74, 1, 86, 218, 94, 0, 48, 1, 152, 25, 90, 0, 120, 0, 192, 1, 65, 0, 61, 96, 147, 98, 70, 0, 64, 124, 132, 88, 134, 39, 79, 186, 38, 102, 180, 53, 1, 222, 468, 111, 207, 38, 109, 1, 105, 96, 8, 57, 31, 79, 1, 60, 28, 68, 71, 80, 64, 6, 80, 88, 0, 31, 72, 152, 0, 108, 65, 283, 2, 96, 84, 0, 57, 86, 125, 182, 93, 17, 195, 46], [53, 6, 0, 0, 12, 20, 0, 0, 2, 2, 6, 6, 16, 12, 4, 8, 6, 6, 32, 0, 24, 8, 0, 0, 2, 57, 14, 4, 22, 70, 0, 4, 22, 20, 23, 4, 83, 25, 8, 20, 12, 6, 32, 11, 16, 0, 14, 0, 139, 70, 240, 22, 26, 24, 76, 10, 22, 24, 10, 0, 604, 74, 14, 64, 2, 6, 13, 8, 7, 8, 2, 0, 91, 34, 16, 60, 13, 6, 197, 0, 60, 4, 18, 0, 269, 917, 8, 58, 0, 2, 30, 0, 31, 0, 26, 0, 0, 1, 70, 212, 124, 4, 0, 6, 11, 2, 5, 0, 29, 84, 0, 36, 4, 2, 30, 17, 3, 8, 6, 0, 4, 82, 7, 0, 38, 26, 0, 12, 0, 4, 6, 6, 102, 61, 14, 25, 0, 6, 2, 0, 21, 2, 2, 0, 25, 92, 50, 6, 14, 4, 6, 12, 26, 16, 4, 10, 0, 11, 20, 89, 2, 0, 4, 2, 12, 6, 0, 0, 47, 2, 40, 28, 20, 2, 14, 9, 9, 10, 6, 0, 36, 866, 3, 52, 47, 2, 15, 10, 0, 0, 2, 0, 186, 239, 69, 75, 154, 157, 3, 246, 291, 137, 160, 110, 32, 145, 140, 107, 56, 54, 109, 138, 276, 136, 92, 115, 118, 96, 183, 85, 2, 161, 38, 260, 59, 110, 60, 62, 53, 89, 70, 118, 8, 61, 120, 64, 55, 181, 106, 284, 237, 277, 239, 176, 297, 345, 226, 301, 4, 142, 106, 131, 239, 495, 188, 330, 306, 501, 316, 205, 60, 60, 65, 92, 157, 165, 203, 346, 107, 133, 189, 251, 123, 97, 183, 88, 106, 200, 327, 211, 363, 153, 220, 184, 131, 34, 78, 190, 13, 176, 86, 122, 189, 120, 187, 276, 150, 165, 21, 68, 133, 192, 370, 148, 171, 224, 258, 300, 194, 94, 106, 87, 116, 10, 212, 55, 229, 146, 301, 105, 0, 123, 213, 2, 329, 143, 204, 61, 155, 173, 0, 119, 0, 84, 46, 100, 89, 80, 159, 119, 22, 182, 108, 110, 129, 64, 119, 74, 65, 145, 52, 107, 80, 74, 123, 134, 92, 24, 60, 104, 115, 125, 64, 130, 64, 145, 195, 85, 64, 417, 142, 130, 98, 531, 300, 46, 0, 132, 243, 70, 15, 107, 94, 421, 225, 168, 166, 55, 0, 104, 139, 83, 575, 72, 252, 230, 223, 160, 350, 44, 0, 200, 91, 209, 171, 41, 222, 177, 78, 178, 149, 49, 0, 181, 90, 130, 290, 178, 474, 114, 2, 405, 58, 116, 0, 55, 211, 129, 483, 382, 468, 229, 282, 237, 195, 130, 0, 115, 154, 65, 788, 149, 312, 325, 314, 2, 203, 64, 0, 128, 158, 93, 104, 38, 148, 30, 0, 8, 0, 2, 164, 0, 316, 46, 156, 0, 164, 0, 150, 0, 102, 268, 118, 2, 105, 372, 195, 0, 117, 2, 325, 42, 235, 0, 224, 0, 385, 0, 114, 0, 107, 183, 293, 165, 93, 0, 121, 218, 247, 121, 160, 88, 173, 324, 79, 104, 334, 79, 0, 426, 697, 225, 349, 41, 196, 1, 172, 166, 6, 58, 54, 177, 6, 132, 79, 70, 164, 104, 87, 8, 82, 188, 1, 80, 129, 312, 4, 173, 86, 462, 6, 168, 117, 0, 78, 186, 267, 355, 159, 35, 295, 99], [124, 28, 2, 6, 7, 60, 0, 1, 0, 13, 9, 3, 27, 79, 14, 27, 16, 30, 92, 2, 80, 17, 0, 1, 31, 76, 31, 13, 45, 172, 1, 29, 98, 102, 47, 4, 188, 28, 43, 75, 28, 20, 91, 51, 48, 14, 33, 3, 269, 231, 493, 82, 96, 20, 149, 55, 33, 26, 27, 1, 670, 210, 62, 125, 4, 5, 33, 23, 38, 43, 0, 3, 119, 92, 38, 123, 25, 38, 410, 14, 135, 20, 33, 5, 287, 967, 22, 88, 2, 9, 94, 2, 42, 5, 74, 2, 1, 2, 114, 349, 162, 5, 0, 2, 15, 1, 12, 4, 53, 208, 6, 47, 10, 6, 49, 11, 9, 25, 14, 9, 12, 163, 9, 6, 42, 20, 2, 19, 6, 7, 14, 12, 156, 114, 24, 59, 11, 13, 5, 9, 28, 7, 2, 0, 0, 318, 176, 9, 30, 7, 26, 12, 29, 29, 16, 11, 2, 23, 23, 194, 2, 15, 8, 14, 22, 10, 6, 2, 102, 27, 51, 89, 87, 13, 14, 19, 14, 6, 13, 0, 42, 1251, 11, 127, 135, 9, 20, 15, 0, 7, 17, 0, 430, 576, 300, 230, 369, 447, 6, 600, 788, 367, 331, 294, 151, 365, 232, 366, 181, 189, 317, 471, 900, 328, 190, 338, 298, 216, 412, 191, 7, 338, 119, 604, 192, 419, 272, 216, 125, 164, 230, 338, 16, 174, 463, 239, 160, 572, 262, 814, 729, 713, 578, 487, 939, 721, 553, 774, 29, 436, 236, 302, 886, 1133, 541, 752, 875, 1258, 664, 547, 196, 135, 199, 213, 557, 493, 607, 800, 310, 293, 432, 548, 233, 216, 427, 190, 310, 363, 691, 505, 1032, 441, 505, 455, 446, 155, 206, 492, 38, 599, 207, 378, 472, 449, 534, 488, 376, 371, 84, 276, 301, 319, 771, 296, 378, 596, 407, 519, 395, 259, 251, 229, 325, 27, 485, 166, 456, 368, 520, 445, 1, 268, 555, 3, 653, 290, 414, 216, 290, 272, 1, 100, 2, 145, 109, 362, 320, 278, 484, 255, 79, 726, 327, 344, 270, 188, 366, 249, 195, 431, 151, 365, 205, 185, 276, 233, 222, 93, 175, 459, 417, 310, 137, 428, 180, 371, 469, 174, 181, 787, 407, 164, 217, 823, 609, 98, 0, 312, 417, 174, 107, 204, 185, 877, 360, 290, 326, 202, 1, 244, 253, 141, 1141, 227, 473, 603, 580, 354, 642, 165, 0, 506, 237, 417, 402, 85, 656, 432, 201, 358, 349, 156, 2, 496, 195, 221, 751, 412, 1148, 286, 5, 1030, 154, 312, 1, 122, 357, 232, 1281, 964, 864, 534, 687, 476, 533, 205, 0, 233, 419, 147, 1417, 256, 797, 638, 643, 6, 418, 161, 1, 304, 370, 200, 339, 179, 375, 43, 2, 2, 0, 2, 141, 0, 257, 34, 138, 0, 172, 0, 100, 0, 78, 202, 163, 2, 106, 287, 175, 0, 126, 0, 284, 32, 149, 0, 188, 0, 299, 0, 119, 0, 107, 166, 221, 120, 79, 0, 92, 200, 196, 113, 180, 65, 136, 242, 52, 127, 314, 95, 4, 305, 638, 178, 376, 60, 200, 1, 232, 203, 9, 80, 63, 152, 4, 95, 80, 140, 115, 145, 90, 14, 99, 145, 7, 69, 97, 300, 0, 149, 120, 568, 19, 175, 123, 2, 71, 103, 215, 338, 137, 30, 231, 68], [0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]}], "layout": {"coloraxis": {"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]]}, "height": 1000, "margin": {"t": 60}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}, "pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"pattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"fillpattern": {"fillmode": "overlay", "size": 10, "solidity": 0.2}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "autotypenumbers": "strict", "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 1000, "xaxis": {"anchor": "y", "domain": [0.0, 1.0], "title": {"text": "sample_id"}}, "yaxis": {"anchor": "x", "autorange": "reversed", "domain": [0.0, 1.0], "title": {"text": "amplicon"}}}}, "text/html": ["<div>                            <div id=\"b2702371-b533-472e-a35a-9b123d2e1a68\" class=\"plotly-graph-div\" style=\"height:1000px; width:1000px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"b2702371-b533-472e-a35a-9b123d2e1a68\")) {                    Plotly.newPlot(                        \"b2702371-b533-472e-a35a-9b123d2e1a68\",                        [{\"coloraxis\":\"coloraxis\",\"name\":\"0\",\"x\":[\"GH_01\",\"GH_02\",\"GH_03\",\"GH_04\",\"GH_05\",\"GH_06\",\"GH_07\",\"GH_08\",\"GH_09\",\"GH_10\",\"GH_11\",\"GH_12\",\"GH_13\",\"GH_14\",\"GH_15\",\"GH_16\",\"GH_17\",\"GH_18\",\"GH_19\",\"GH_20\",\"GH_21\",\"GH_22\",\"GH_23\",\"GH_24\",\"GH_25\",\"GH_26\",\"GH_27\",\"GH_28\",\"GH_29\",\"GH_30\",\"GH_31\",\"GH_32\",\"GH_33\",\"GH_34\",\"GH_35\",\"GH_36\",\"GH_37\",\"GH_38\",\"GH_39\",\"GH_40_low_vol\",\"GH_41\",\"GH_42\",\"GH_43\",\"GH_44\",\"GH_45\",\"GH_46\",\"GH_47\",\"GH_48\",\"GH_49\",\"GH_50\",\"GH_51\",\"GH_52\",\"GH_53\",\"GH_54\",\"GH_55\",\"GH_56\",\"GH_57\",\"GH_58\",\"GH_59\",\"GH_60\",\"GH_61\",\"GH_62\",\"GH_63\",\"GH_64\",\"GH_65_low_vol\",\"GH_66\",\"GH_67\",\"GH_68\",\"GH_69\",\"GH_70\",\"GH_71\",\"GH_72\",\"GH_73\",\"GH_74\",\"GH_75\",\"GH_76\",\"GH_77\",\"GH_78\",\"GH_79\",\"GH_80_low_vol\",\"GH_81\",\"GH_82\",\"GH_83\",\"GH_84\",\"GH_85\",\"GH_86\",\"GH_87\",\"GH_88\",\"GH_89\",\"GH_90\",\"GH_91\",\"GH_92\",\"GH_93\",\"GH_94\",\"GH_95\",\"GH_Negative\",\"GM_01\",\"GM_02\",\"GM_03\",\"GM_04\",\"GM_05\",\"GM_06\",\"GM_07\",\"GM_08\",\"GM_09\",\"GM_10\",\"GM_11\",\"GM_12\",\"GM_13\",\"GM_14\",\"GM_15\",\"GM_16\",\"GM_17\",\"GM_18\",\"GM_19\",\"GM_20\",\"GM_21\",\"GM_22\",\"GM_23\",\"GM_24\",\"GM_25\",\"GM_26\",\"GM_27\",\"GM_28\",\"GM_29\",\"GM_30\",\"GM_31\",\"GM_32\",\"GM_33\",\"GM_34\",\"GM_35\",\"GM_36\",\"GM_37\",\"GM_38\",\"GM_39\",\"GM_40\",\"GM_41\",\"GM_42\",\"GM_43\",\"GM_44\",\"GM_45\",\"GM_46\",\"GM_47\",\"GM_48\",\"GM_49\",\"GM_50\",\"GM_51\",\"GM_52\",\"GM_53\",\"GM_54\",\"GM_55\",\"GM_56\",\"GM_57\",\"GM_58\",\"GM_59\",\"GM_60\",\"GM_61\",\"GM_62\",\"GM_63\",\"GM_64\",\"GM_65\",\"GM_66\",\"GM_67\",\"GM_68\",\"GM_69\",\"GM_70\",\"GM_71\",\"GM_72\",\"GM_73\",\"GM_74\",\"GM_75\",\"GM_76\",\"GM_77\",\"GM_78\",\"GM_79\",\"GM_80\",\"GM_81\",\"GM_82\",\"GM_83\",\"GM_84\",\"GM_85\",\"GM_86\",\"GM_87\",\"GM_88\",\"GM_89\",\"GM_90\",\"GM_91\",\"GM_92\",\"GM_93\",\"GM_94\",\"GM_95\",\"GM_96\",\"Siaya_Delta_Alive_01\",\"Siaya_Delta_Alive_02\",\"Siaya_Delta_Alive_03\",\"Siaya_Delta_Alive_04\",\"Siaya_Delta_Alive_05\",\"Siaya_Delta_Alive_06\",\"Siaya_Delta_Alive_07\",\"Siaya_Delta_Alive_08\",\"Siaya_Delta_Alive_09\",\"Siaya_Delta_Alive_10\",\"Siaya_Delta_Alive_100\",\"Siaya_Delta_Alive_101\",\"Siaya_Delta_Alive_102\",\"Siaya_Delta_Alive_103\",\"Siaya_Delta_Alive_104\",\"Siaya_Delta_Alive_105\",\"Siaya_Delta_Alive_106\",\"Siaya_Delta_Alive_107\",\"Siaya_Delta_Alive_108\",\"Siaya_Delta_Alive_109\",\"Siaya_Delta_Alive_11\",\"Siaya_Delta_Alive_110\",\"Siaya_Delta_Alive_111\",\"Siaya_Delta_Alive_112\",\"Siaya_Delta_Alive_113\",\"Siaya_Delta_Alive_114\",\"Siaya_Delta_Alive_115\",\"Siaya_Delta_Alive_116\",\"Siaya_Delta_Alive_117\",\"Siaya_Delta_Alive_118\",\"Siaya_Delta_Alive_119\",\"Siaya_Delta_Alive_12\",\"Siaya_Delta_Alive_120\",\"Siaya_Delta_Alive_121\",\"Siaya_Delta_Alive_122\",\"Siaya_Delta_Alive_123\",\"Siaya_Delta_Alive_124\",\"Siaya_Delta_Alive_125\",\"Siaya_Delta_Alive_126\",\"Siaya_Delta_Alive_127\",\"Siaya_Delta_Alive_128\",\"Siaya_Delta_Alive_129\",\"Siaya_Delta_Alive_13\",\"Siaya_Delta_Alive_130\",\"Siaya_Delta_Alive_131\",\"Siaya_Delta_Alive_14\",\"Siaya_Delta_Alive_15\",\"Siaya_Delta_Alive_16\",\"Siaya_Delta_Alive_17\",\"Siaya_Delta_Alive_18\",\"Siaya_Delta_Alive_19\",\"Siaya_Delta_Alive_20\",\"Siaya_Delta_Alive_21\",\"Siaya_Delta_Alive_22\",\"Siaya_Delta_Alive_23\",\"Siaya_Delta_Alive_24\",\"Siaya_Delta_Alive_25\",\"Siaya_Delta_Alive_26\",\"Siaya_Delta_Alive_27\",\"Siaya_Delta_Alive_28\",\"Siaya_Delta_Alive_29\",\"Siaya_Delta_Alive_30\",\"Siaya_Delta_Alive_31\",\"Siaya_Delta_Alive_32\",\"Siaya_Delta_Alive_33\",\"Siaya_Delta_Alive_34\",\"Siaya_Delta_Alive_35\",\"Siaya_Delta_Alive_36\",\"Siaya_Delta_Alive_37\",\"Siaya_Delta_Alive_38\",\"Siaya_Delta_Alive_39\",\"Siaya_Delta_Alive_40\",\"Siaya_Delta_Alive_41\",\"Siaya_Delta_Alive_42\",\"Siaya_Delta_Alive_43\",\"Siaya_Delta_Alive_44\",\"Siaya_Delta_Alive_45\",\"Siaya_Delta_Alive_46\",\"Siaya_Delta_Alive_47\",\"Siaya_Delta_Alive_48\",\"Siaya_Delta_Alive_49\",\"Siaya_Delta_Alive_50\",\"Siaya_Delta_Alive_51\",\"Siaya_Delta_Alive_52\",\"Siaya_Delta_Alive_53\",\"Siaya_Delta_Alive_54\",\"Siaya_Delta_Alive_55\",\"Siaya_Delta_Alive_56\",\"Siaya_Delta_Alive_57\",\"Siaya_Delta_Alive_58\",\"Siaya_Delta_Alive_59\",\"Siaya_Delta_Alive_60\",\"Siaya_Delta_Alive_61\",\"Siaya_Delta_Alive_62\",\"Siaya_Delta_Alive_63\",\"Siaya_Delta_Alive_64\",\"Siaya_Delta_Alive_65\",\"Siaya_Delta_Alive_66\",\"Siaya_Delta_Alive_67\",\"Siaya_Delta_Alive_68\",\"Siaya_Delta_Alive_69\",\"Siaya_Delta_Alive_70\",\"Siaya_Delta_Alive_71\",\"Siaya_Delta_Alive_72\",\"Siaya_Delta_Alive_73\",\"Siaya_Delta_Alive_74\",\"Siaya_Delta_Alive_75\",\"Siaya_Delta_Alive_76\",\"Siaya_Delta_Alive_77\",\"Siaya_Delta_Alive_78\",\"Siaya_Delta_Alive_79\",\"Siaya_Delta_Alive_80\",\"Siaya_Delta_Alive_81\",\"Siaya_Delta_Alive_82\",\"Siaya_Delta_Alive_83\",\"Siaya_Delta_Alive_84\",\"Siaya_Delta_Alive_85\",\"Siaya_Delta_Alive_86\",\"Siaya_Delta_Alive_87\",\"Siaya_Delta_Alive_88\",\"Siaya_Delta_Alive_89\",\"Siaya_Delta_Alive_90\",\"Siaya_Delta_Alive_91\",\"Siaya_Delta_Alive_92\",\"Siaya_Delta_Alive_93\",\"Siaya_Delta_Alive_94\",\"Siaya_Delta_Alive_95\",\"Siaya_Delta_Alive_96\",\"Siaya_Delta_Alive_97\",\"Siaya_Delta_Alive_98\",\"Siaya_Delta_Alive_99\",\"Siaya_Delta_Alive_Negative\",\"Siaya_Delta_Dead_01\",\"Siaya_Delta_Dead_02\",\"Siaya_Delta_Dead_03\",\"Siaya_Delta_Dead_04\",\"Siaya_Delta_Dead_05\",\"Siaya_Delta_Dead_06\",\"Siaya_Delta_Dead_07\",\"Siaya_Delta_Dead_08\",\"Siaya_Delta_Dead_09\",\"Siaya_Delta_Dead_10\",\"Siaya_Delta_Dead_100\",\"Siaya_Delta_Dead_101\",\"Siaya_Delta_Dead_102\",\"Siaya_Delta_Dead_103\",\"Siaya_Delta_Dead_104\",\"Siaya_Delta_Dead_105\",\"Siaya_Delta_Dead_106\",\"Siaya_Delta_Dead_107\",\"Siaya_Delta_Dead_108\",\"Siaya_Delta_Dead_109\",\"Siaya_Delta_Dead_11\",\"Siaya_Delta_Dead_110\",\"Siaya_Delta_Dead_111\",\"Siaya_Delta_Dead_112\",\"Siaya_Delta_Dead_113\",\"Siaya_Delta_Dead_114\",\"Siaya_Delta_Dead_115\",\"Siaya_Delta_Dead_116\",\"Siaya_Delta_Dead_117\",\"Siaya_Delta_Dead_118\",\"Siaya_Delta_Dead_119\",\"Siaya_Delta_Dead_12\",\"Siaya_Delta_Dead_120\",\"Siaya_Delta_Dead_121\",\"Siaya_Delta_Dead_122\",\"Siaya_Delta_Dead_123\",\"Siaya_Delta_Dead_124\",\"Siaya_Delta_Dead_125\",\"Siaya_Delta_Dead_126\",\"Siaya_Delta_Dead_127\",\"Siaya_Delta_Dead_128\",\"Siaya_Delta_Dead_129\",\"Siaya_Delta_Dead_13\",\"Siaya_Delta_Dead_130\",\"Siaya_Delta_Dead_131\",\"Siaya_Delta_Dead_14\",\"Siaya_Delta_Dead_15\",\"Siaya_Delta_Dead_16\",\"Siaya_Delta_Dead_17\",\"Siaya_Delta_Dead_18\",\"Siaya_Delta_Dead_19\",\"Siaya_Delta_Dead_20\",\"Siaya_Delta_Dead_21\",\"Siaya_Delta_Dead_22\",\"Siaya_Delta_Dead_23\",\"Siaya_Delta_Dead_24\",\"Siaya_Delta_Dead_25\",\"Siaya_Delta_Dead_26\",\"Siaya_Delta_Dead_27\",\"Siaya_Delta_Dead_28\",\"Siaya_Delta_Dead_29\",\"Siaya_Delta_Dead_30\",\"Siaya_Delta_Dead_31\",\"Siaya_Delta_Dead_32\",\"Siaya_Delta_Dead_33\",\"Siaya_Delta_Dead_34\",\"Siaya_Delta_Dead_35\",\"Siaya_Delta_Dead_36\",\"Siaya_Delta_Dead_37\",\"Siaya_Delta_Dead_38\",\"Siaya_Delta_Dead_39\",\"Siaya_Delta_Dead_40\",\"Siaya_Delta_Dead_41\",\"Siaya_Delta_Dead_42\",\"Siaya_Delta_Dead_43\",\"Siaya_Delta_Dead_44\",\"Siaya_Delta_Dead_45\",\"Siaya_Delta_Dead_46\",\"Siaya_Delta_Dead_47\",\"Siaya_Delta_Dead_48\",\"Siaya_Delta_Dead_49\",\"Siaya_Delta_Dead_50\",\"Siaya_Delta_Dead_51\",\"Siaya_Delta_Dead_52\",\"Siaya_Delta_Dead_53\",\"Siaya_Delta_Dead_54\",\"Siaya_Delta_Dead_55\",\"Siaya_Delta_Dead_56\",\"Siaya_Delta_Dead_57\",\"Siaya_Delta_Dead_58\",\"Siaya_Delta_Dead_59\",\"Siaya_Delta_Dead_60\",\"Siaya_Delta_Dead_61\",\"Siaya_Delta_Dead_62\",\"Siaya_Delta_Dead_63\",\"Siaya_Delta_Dead_64\",\"Siaya_Delta_Dead_65\",\"Siaya_Delta_Dead_66\",\"Siaya_Delta_Dead_67\",\"Siaya_Delta_Dead_68\",\"Siaya_Delta_Dead_69\",\"Siaya_Delta_Dead_70\",\"Siaya_Delta_Dead_71\",\"Siaya_Delta_Dead_72\",\"Siaya_Delta_Dead_73\",\"Siaya_Delta_Dead_74\",\"Siaya_Delta_Dead_75\",\"Siaya_Delta_Dead_76\",\"Siaya_Delta_Dead_77\",\"Siaya_Delta_Dead_78\",\"Siaya_Delta_Dead_79\",\"Siaya_Delta_Dead_80\",\"Siaya_Delta_Dead_81\",\"Siaya_Delta_Dead_82\",\"Siaya_Delta_Dead_83\",\"Siaya_Delta_Dead_84\",\"Siaya_Delta_Dead_85\",\"Siaya_Delta_Dead_86\",\"Siaya_Delta_Dead_87\",\"Siaya_Delta_Dead_88\",\"Siaya_Delta_Dead_89\",\"Siaya_Delta_Dead_90\",\"Siaya_Delta_Dead_91\",\"Siaya_Delta_Dead_92\",\"Siaya_Delta_Dead_93\",\"Siaya_Delta_Dead_94\",\"Siaya_Delta_Dead_95\",\"Siaya_Delta_Dead_96\",\"Siaya_Delta_Dead_97\",\"Siaya_Delta_Dead_98\",\"Siaya_Delta_Dead_99\",\"Siaya_Delta_Dead_Negative\",\"VK7_Negative\",\"VK7_alive_01\",\"VK7_alive_02\",\"VK7_alive_03\",\"VK7_alive_04\",\"VK7_alive_05\",\"VK7_alive_06\",\"VK7_alive_07\",\"VK7_alive_08\",\"VK7_alive_09\",\"VK7_alive_10\",\"VK7_alive_11\",\"VK7_alive_12\",\"VK7_alive_13\",\"VK7_alive_14\",\"VK7_alive_15\",\"VK7_alive_16\",\"VK7_alive_17\",\"VK7_alive_18\",\"VK7_alive_19\",\"VK7_alive_20\",\"VK7_alive_21\",\"VK7_alive_22\",\"VK7_alive_23\",\"VK7_alive_24\",\"VK7_alive_25\",\"VK7_alive_26\",\"VK7_alive_27\",\"VK7_alive_28\",\"VK7_alive_29\",\"VK7_alive_30\",\"VK7_alive_31\",\"VK7_alive_32\",\"VK7_alive_33\",\"VK7_alive_34\",\"VK7_alive_35\",\"VK7_alive_36\",\"VK7_alive_37\",\"VK7_alive_38\",\"VK7_alive_39\",\"VK7_alive_40\",\"VK7_alive_41\",\"VK7_alive_42\",\"VK7_alive_43\",\"VK7_alive_44\",\"VK7_alive_45\",\"VK7_alive_46\",\"VK7_alive_47\",\"VK7_dead_01\",\"VK7_dead_02\",\"VK7_dead_03\",\"VK7_dead_04\",\"VK7_dead_04_dil\",\"VK7_dead_05\",\"VK7_dead_06\",\"VK7_dead_07\",\"VK7_dead_08\",\"VK7_dead_09\",\"VK7_dead_10\",\"VK7_dead_10_dil\",\"VK7_dead_11\",\"VK7_dead_12\",\"VK7_dead_13\",\"VK7_dead_14\",\"VK7_dead_15\",\"VK7_dead_16\",\"VK7_dead_16_dil\",\"VK7_dead_17\",\"VK7_dead_18\",\"VK7_dead_19\",\"VK7_dead_20\",\"VK7_dead_21\",\"VK7_dead_22\",\"VK7_dead_22_dil\",\"VK7_dead_23\",\"VK7_dead_24\",\"VK7_dead_25\",\"VK7_dead_26\",\"VK7_dead_27\",\"VK7_dead_28\",\"VK7_dead_28_dil\",\"VK7_dead_29\",\"VK7_dead_30\",\"VK7_dead_31\",\"VK7_dead_32\",\"VK7_dead_33\",\"VK7_dead_34\",\"VK7_dead_34_dil\",\"VK7_dead_35\",\"VK7_dead_36\",\"VK7_dead_37\",\"VK7_dead_38\",\"VK7_dead_39\",\"VK7_dead_40\",\"VK7_dead_41\",\"VK7_dead_42\"],\"y\":[\"Agam_1\",\"Agam_2\",\"Agam_3\",\"Agam_4\",\"Agam_5\",\"Agam_6\",\"Agam_7\",\"Agam_8\",\"Agam_9\",\"Agam_10\",\"Agam_11\",\"Agam_12\",\"Agam_13\",\"Agam_14\",\"Agam_15\",\"Agam_16\",\"Agam_17\",\"Agam_18\",\"Agam_19\",\"Agam_20\",\"Agam_21\",\"Agam_22\",\"Agam_23\",\"Agam_24\",\"Agam_25\",\"Agam_26\",\"Agam_27\",\"Agam_28\",\"Agam_29\",\"Agam_30\",\"Agam_31\",\"Agam_32\",\"Agam_33\",\"Agam_34\",\"Agam_35\",\"Agam_36\",\"Agam_37\",\"Agam_38\",\"Agam_39\",\"Agam_40\",\"Agam_41\",\"Agam_42\",\"Agam_43\",\"Agam_44\",\"Agam_45\",\"Agam_46\",\"Agam_47\",\"Agam_48\",\"Agam_49\",\"Agam_50\",\"Agam_51\",\"Agam_52\",\"Agam_53\",\"Agam_54\",\"Agam_55\",\"Agam_56\",\"Agam_57\",\"Agam_58\",\"Agam_59\",\"Agam_60\",\"Agam_61\",\"Agam_62\",\"Agam_63\",\"Agam_64\",\"Agam_65\",\"Agam_66\",\"Agam_67\",\"Agam_68\",\"Agam_69\",\"Agam_70\",\"Agam_71\",\"Agam_72\",\"Agam_73\",\"Agam_74\",\"Agam_75\",\"Agam_76\",\"Agam_77\",\"Agam_78\",\"Agam_79\",\"Agam_80\",\"Agam_81\",\"Agam_82\"],\"z\":[[32,17,0,2,7,20,0,0,0,4,5,0,13,20,0,8,2,1,21,4,18,6,0,0,7,55,7,3,21,54,0,8,25,33,8,0,55,16,9,24,12,8,31,14,19,3,13,0,80,70,142,16,23,12,38,12,13,8,8,1,247,68,6,47,2,6,10,9,5,10,3,0,40,25,22,51,16,10,111,2,39,10,11,1,123,359,5,36,1,2,28,0,21,0,18,0,1,0,26,76,73,3,1,0,8,1,3,5,20,22,0,26,1,2,12,8,1,8,5,0,4,50,5,0,16,5,1,2,2,3,4,3,36,35,9,34,1,4,3,2,8,1,0,0,0,72,59,4,11,8,1,6,20,13,6,2,0,5,13,64,1,3,0,3,6,2,2,0,22,1,12,25,24,5,10,7,8,4,7,0,14,433,3,48,60,0,7,8,0,2,5,0,115,149,88,78,108,105,2,182,229,106,97,86,46,125,81,114,52,54,107,168,245,100,69,108,92,74,109,65,2,121,37,170,55,115,83,90,27,49,50,85,6,53,115,83,42,169,68,201,187,224,177,141,228,186,129,200,6,141,57,65,188,313,155,242,225,330,184,155,41,50,57,73,140,158,126,257,96,86,115,184,100,64,132,74,85,114,193,141,322,133,150,123,109,24,74,134,6,114,45,109,140,118,146,129,151,118,18,77,76,100,242,98,116,176,135,206,92,96,80,72,112,10,114,47,128,112,166,107,0,82,164,0,197,81,109,68,73,69,1,60,1,27,36,87,95,74,114,82,6,222,76,106,68,51,85,87,63,131,21,86,51,61,85,58,81,30,51,128,97,79,44,138,56,109,138,57,59,261,144,65,48,224,111,37,0,71,111,62,17,59,65,236,140,73,99,57,0,62,58,52,312,66,147,188,181,97,143,37,0,138,76,132,98,27,198,107,62,79,104,25,1,143,63,68,208,147,353,48,1,278,46,109,1,33,113,80,373,313,230,124,184,145,133,64,0,72,123,49,494,73,234,161,151,5,117,50,0,80,146,48,77,53,111,19,0,0,0,0,30,0,63,22,31,0,45,0,19,0,17,52,26,0,48,99,37,0,23,0,59,10,50,0,77,0,103,0,26,0,36,42,70,43,25,0,46,63,50,27,49,25,43,64,25,42,76,32,1,99,175,48,89,20,55,4,54,57,2,28,16,49,3,20,23,34,24,50,21,4,40,57,2,20,22,105,1,47,27,162,6,39,34,0,22,55,73,94,51,5,61,26],[29,4,0,2,2,25,2,0,0,2,2,0,13,13,3,2,4,1,24,1,23,0,0,0,78,38,5,5,13,39,0,4,17,14,3,0,46,6,1,20,10,8,12,10,12,0,8,0,59,70,104,18,28,27,30,9,9,2,6,0,205,56,10,52,0,4,8,6,8,5,1,0,41,28,16,28,5,8,116,6,33,6,5,0,85,235,1,26,0,0,27,0,10,0,27,0,2,0,110,359,145,7,1,0,32,6,24,9,91,202,1,26,3,2,40,10,7,14,29,5,120,214,9,2,32,45,5,16,1,2,4,10,205,65,10,94,8,5,2,9,24,4,8,2,1,250,152,16,26,2,21,4,66,18,11,13,1,30,8,131,0,20,5,16,25,18,2,1,60,9,75,87,21,17,8,5,29,12,3,0,50,1486,9,171,215,1,38,30,1,3,15,0,131,83,56,50,69,111,20,132,153,65,71,64,35,95,51,105,24,35,56,108,195,89,44,66,57,60,50,46,2,56,26,121,39,74,71,42,29,48,28,100,4,47,115,68,33,124,52,112,141,128,89,68,151,106,98,168,93,98,68,68,179,203,97,133,143,244,118,100,28,31,51,70,127,87,136,172,71,50,102,144,64,36,109,65,83,69,134,119,208,127,119,111,106,30,54,100,6,111,44,89,155,108,113,155,108,98,34,64,99,81,164,75,80,162,103,137,102,62,71,57,68,7,111,55,108,109,151,89,7,78,164,0,180,56,95,48,63,70,1,49,0,27,30,65,80,67,62,52,112,153,82,79,78,43,60,83,48,113,21,65,40,46,48,56,37,16,38,48,65,37,25,85,43,72,136,23,40,240,115,25,51,178,126,25,0,81,89,37,138,52,31,244,89,55,88,51,0,57,66,39,336,46,107,201,159,83,152,37,0,123,49,86,100,20,150,69,30,84,54,18,0,117,44,55,188,102,264,41,0,185,10,36,0,38,94,63,307,195,230,115,142,71,72,52,0,66,90,32,436,59,216,146,134,2,81,37,0,77,111,52,31,48,90,21,0,0,0,0,11,0,18,15,17,0,17,0,12,0,7,32,17,0,16,26,26,0,27,0,15,6,9,0,25,0,28,0,16,0,13,15,19,19,15,0,14,23,19,13,12,7,21,26,4,11,40,18,0,43,83,30,28,12,16,0,37,39,11,9,7,13,0,21,8,15,13,18,18,3,13,18,1,16,10,39,0,18,9,36,0,21,20,0,17,16,29,39,16,4,27,15],[4,4,1,0,2,17,4,0,0,2,2,0,4,6,4,0,0,4,6,2,6,2,0,0,4,20,4,4,4,37,0,0,8,14,0,0,29,2,4,14,0,0,10,7,4,2,1,0,39,52,52,2,32,12,12,0,6,4,2,0,135,26,4,20,0,2,6,2,0,0,2,0,16,10,14,32,3,11,43,2,11,10,8,0,66,169,4,22,0,0,22,0,16,0,8,0,0,0,28,47,14,0,1,0,2,2,7,2,6,15,0,0,0,2,12,0,0,6,0,0,4,16,0,0,2,4,0,0,1,0,0,2,16,14,6,11,0,4,0,0,4,4,3,0,2,47,14,0,3,1,0,2,8,2,2,0,0,5,6,22,2,0,0,0,2,2,6,0,14,2,10,31,27,2,8,2,6,2,0,0,4,248,4,32,37,5,8,8,1,2,2,0,52,37,11,36,24,62,92,44,82,39,24,46,12,44,11,44,32,10,35,60,100,29,22,28,18,10,38,31,0,36,10,85,10,33,39,24,10,16,20,25,0,49,42,24,22,67,41,38,96,66,71,42,58,129,41,52,2,47,24,32,77,92,58,84,80,152,54,35,32,16,26,24,54,67,47,67,41,28,58,42,25,18,20,16,23,42,57,44,119,44,64,44,41,16,20,59,0,43,10,65,73,47,41,58,61,58,22,38,39,44,114,36,64,96,49,56,50,33,26,32,43,0,79,22,54,60,77,51,46,14,60,0,92,26,53,14,26,61,35,20,1,24,14,45,6,32,28,35,10,65,28,28,49,10,42,33,28,65,22,53,14,17,14,23,20,2,14,46,58,61,34,44,16,44,40,14,26,96,58,10,20,111,58,20,0,30,43,14,8,16,18,129,43,40,20,24,0,24,20,12,152,26,48,98,51,47,48,23,0,28,47,36,25,22,48,53,10,77,46,14,0,64,30,32,82,46,177,38,0,91,10,30,0,28,48,24,198,100,213,70,88,92,72,34,0,34,60,27,202,51,106,100,65,2,37,39,0,35,35,7,22,13,33,16,0,84,0,2,18,0,50,14,28,0,35,0,12,0,12,38,22,0,26,66,29,0,15,0,31,2,16,0,38,0,60,0,18,0,27,24,51,28,16,0,21,47,30,28,38,10,26,52,7,15,52,22,0,72,127,29,60,8,8,0,40,14,2,10,8,40,0,21,17,14,20,24,20,0,34,25,0,14,30,58,1,24,10,104,0,28,22,0,36,20,45,56,29,0,58,12],[13,5,0,0,1,11,2,0,0,5,2,0,6,4,3,2,1,0,8,0,5,3,1,0,9,21,8,1,6,28,1,2,14,14,8,0,28,7,3,15,5,6,4,7,4,3,6,0,32,37,68,9,8,7,13,2,2,1,2,0,177,35,2,23,0,5,2,1,0,2,1,0,33,20,16,30,2,8,76,0,21,2,4,0,78,241,2,26,0,1,24,0,11,0,12,0,0,1,12,46,19,0,2,0,2,2,9,0,5,23,0,4,0,1,2,2,2,0,2,1,5,14,1,0,5,8,0,7,0,1,0,1,30,9,7,12,1,1,1,1,4,1,0,0,0,38,23,3,3,3,0,1,10,1,1,1,0,3,3,22,1,3,1,1,1,2,1,0,23,3,32,17,13,3,5,1,4,1,0,0,10,326,5,26,26,2,7,0,0,0,2,0,54,71,34,24,52,73,168,61,123,49,29,35,16,61,39,56,25,16,44,65,191,57,26,53,43,16,29,23,3,40,12,65,20,59,45,27,25,24,32,57,3,28,56,35,27,75,40,55,98,93,74,71,103,94,75,71,7,45,37,28,85,178,101,107,110,177,85,70,30,20,18,24,62,83,84,102,53,42,85,53,41,23,52,38,24,48,67,61,122,59,81,55,52,9,28,47,0,67,20,51,72,71,101,70,67,62,20,59,71,67,127,61,70,130,93,90,61,55,53,47,62,4,70,30,93,80,91,67,42,23,87,0,101,22,72,23,34,41,26,16,0,15,15,47,40,25,27,47,15,83,47,63,48,22,54,43,27,49,24,47,35,28,29,32,36,10,23,52,64,55,59,69,22,69,66,28,39,118,63,20,27,116,78,12,0,37,43,19,15,19,18,178,55,48,48,16,0,21,22,18,198,40,67,87,63,31,74,18,0,54,31,48,57,13,104,52,14,53,28,7,0,68,20,21,108,64,231,37,1,124,15,58,0,25,66,44,236,152,347,93,121,75,105,33,0,36,76,27,332,43,147,107,81,1,60,44,0,51,66,12,19,12,43,14,0,33,0,0,26,0,69,8,37,0,34,0,23,0,20,47,25,0,25,70,36,0,26,0,53,11,30,0,55,0,95,0,19,0,34,42,49,33,22,0,16,34,50,25,46,16,39,46,11,17,61,11,0,91,190,45,61,16,25,0,28,33,4,11,6,37,2,17,16,20,26,26,30,1,22,35,1,17,20,52,0,24,12,100,0,32,30,1,26,29,48,69,37,9,60,12],[21,6,0,0,2,12,12,0,0,0,3,0,19,7,3,1,3,2,26,1,24,4,1,0,10,31,13,2,10,42,2,5,24,17,11,0,30,11,8,28,12,9,22,9,8,5,10,0,46,79,169,21,19,9,35,4,3,3,4,0,287,55,12,40,0,7,3,7,5,19,1,0,41,34,38,34,9,12,173,5,56,11,10,0,117,393,8,40,0,0,38,0,20,0,29,0,0,0,17,73,34,0,7,1,2,1,4,2,8,35,0,6,3,0,2,0,2,3,2,0,1,27,5,0,18,2,2,4,0,2,1,0,34,12,7,18,1,2,0,0,8,0,0,0,0,74,37,2,2,6,1,0,5,4,2,1,0,5,7,33,2,6,1,2,4,4,2,2,17,3,36,25,22,1,6,2,8,1,2,0,13,390,10,39,58,0,0,4,0,0,1,0,124,79,56,27,68,122,289,109,209,69,71,62,23,77,49,101,44,32,99,97,255,56,37,68,53,34,56,31,2,62,19,121,26,117,72,50,39,46,43,79,4,61,85,69,43,147,71,114,168,151,125,74,264,149,106,116,10,61,47,71,159,269,154,172,173,326,114,105,40,21,38,48,125,114,117,155,66,76,89,84,50,34,69,47,51,67,106,73,165,84,92,70,84,18,32,109,1,111,37,72,118,91,112,143,108,83,38,63,97,94,200,63,103,142,101,175,101,72,64,50,61,0,90,45,113,116,146,121,101,33,168,0,155,61,115,35,69,88,60,22,0,23,24,76,81,73,74,59,12,155,73,95,56,27,90,59,41,112,43,58,59,45,41,73,69,16,49,104,124,87,97,114,44,138,134,35,65,256,118,22,27,198,145,12,0,54,78,39,33,15,30,279,76,54,88,37,0,45,45,31,364,52,97,153,157,75,146,16,1,114,62,80,71,18,199,114,31,94,69,17,1,108,29,45,206,83,447,68,0,199,30,58,0,28,106,61,459,234,528,173,202,145,148,64,0,54,86,43,465,75,198,169,162,5,134,46,0,86,102,29,42,32,90,21,1,43,0,0,29,1,72,17,23,0,40,0,14,0,17,53,26,0,36,80,39,0,28,0,52,8,54,0,40,1,93,0,21,0,29,47,74,37,20,0,23,49,55,30,46,14,27,68,19,23,74,26,0,121,230,59,88,16,29,0,56,53,10,18,11,40,1,26,13,25,24,28,26,0,22,48,2,16,22,90,0,41,33,156,2,47,30,0,39,49,81,109,56,6,82,16],[30,5,0,0,0,14,0,2,1,0,0,0,14,7,0,4,4,0,16,0,16,8,0,0,6,18,5,1,10,46,1,2,8,12,9,0,52,6,2,10,0,7,9,9,6,2,8,0,57,42,76,6,18,14,18,22,7,4,6,1,162,32,0,15,0,10,12,8,2,4,1,2,19,11,22,27,9,13,106,4,19,3,10,1,88,239,7,8,2,0,18,0,5,0,31,1,2,1,33,46,39,0,0,0,2,8,8,0,5,53,2,27,3,0,6,2,0,10,3,2,2,26,12,0,26,7,0,6,1,2,2,0,26,25,22,16,0,4,0,2,6,0,2,1,4,38,41,2,6,0,18,4,22,2,1,1,1,18,6,28,0,6,0,4,6,2,4,0,26,6,2,31,9,2,3,5,8,1,0,0,12,286,8,44,43,0,4,0,2,1,6,0,63,117,34,40,76,57,0,97,111,48,53,64,21,73,49,40,40,59,43,101,148,75,36,57,64,50,81,52,0,67,10,91,26,94,58,48,27,27,48,64,0,20,56,41,22,84,30,129,119,124,120,70,147,144,60,164,2,76,57,72,129,211,71,115,128,254,105,105,27,21,40,54,96,122,93,114,52,43,107,109,42,53,98,33,77,71,98,72,142,42,107,88,99,28,28,94,6,91,36,60,70,66,124,74,73,66,24,61,57,65,133,53,49,116,93,121,60,55,48,33,60,6,106,32,91,106,118,51,0,61,85,0,114,73,68,43,58,77,0,26,1,27,34,53,41,57,88,30,8,145,64,40,52,26,75,49,41,79,52,62,35,34,62,70,50,19,51,94,39,69,34,88,18,61,162,23,29,151,111,42,45,184,106,29,0,67,96,29,16,51,48,208,83,45,74,60,1,55,56,31,279,26,101,137,107,54,179,14,0,115,28,85,91,14,130,119,42,119,91,21,2,104,57,76,94,89,235,46,4,191,15,59,0,36,53,56,267,226,294,97,153,106,108,52,1,35,120,25,363,70,198,107,113,2,88,40,0,70,109,44,56,25,40,24,1,0,0,0,29,0,52,16,24,0,25,0,25,0,21,61,23,0,33,76,28,0,29,0,57,14,51,0,46,0,69,0,20,0,13,26,49,28,14,0,21,42,46,19,32,10,20,60,15,23,76,26,0,95,155,29,91,20,43,0,40,32,4,24,14,43,4,20,22,25,18,30,32,3,10,42,1,25,29,87,0,25,32,151,2,30,35,0,18,20,58,71,27,10,86,15],[21,6,0,0,2,12,1,0,0,3,3,0,5,8,1,3,0,3,6,0,17,3,0,0,2,22,3,2,4,40,1,6,7,11,10,0,32,14,3,15,2,2,14,6,7,0,6,0,50,25,93,6,19,6,21,18,3,2,1,0,146,32,3,23,3,7,7,8,5,4,0,0,23,10,6,24,3,8,45,3,16,4,3,0,82,184,4,9,0,1,19,0,8,0,7,0,1,0,7,25,14,1,0,0,2,1,1,0,7,38,0,7,0,0,8,0,0,7,2,0,0,0,0,1,10,0,0,1,5,2,0,0,0,1,5,25,0,1,0,1,0,0,0,0,0,0,38,5,2,1,0,7,11,2,1,0,0,8,7,9,0,2,0,0,1,0,0,1,17,0,2,5,14,0,6,3,0,1,0,0,11,0,0,0,0,0,0,3,0,0,0,0,82,88,31,23,70,35,0,142,151,62,58,31,23,51,39,54,20,25,34,38,90,76,27,44,42,37,74,25,3,40,25,93,19,58,45,40,19,32,30,52,5,22,56,30,25,102,19,97,112,64,75,36,99,57,83,186,3,87,39,46,107,120,51,92,82,156,113,53,46,29,26,20,83,96,123,129,45,41,77,66,68,39,59,24,42,38,76,100,187,78,83,74,61,15,37,58,16,80,67,59,34,78,62,71,52,52,16,40,57,27,94,60,38,105,73,90,47,45,24,28,39,3,72,30,70,67,88,30,0,41,81,0,120,62,66,17,48,24,1,34,0,24,13,29,27,16,66,49,11,140,54,15,48,21,62,22,29,71,31,74,20,14,55,38,30,7,21,22,51,33,15,30,31,23,72,34,26,79,47,42,47,147,86,38,0,71,63,41,12,25,30,134,73,45,49,10,0,62,21,16,135,51,76,144,78,39,149,20,0,57,34,66,75,12,117,66,43,71,63,26,0,79,53,32,105,43,91,25,2,85,52,48,0,15,51,30,197,122,117,27,60,44,53,36,0,43,49,10,195,65,111,107,103,3,51,22,0,51,58,42,29,14,31,10,0,0,0,0,28,0,54,12,35,0,27,0,24,0,15,37,15,0,23,39,33,0,20,0,26,9,42,0,35,0,69,0,20,0,16,17,40,26,10,0,10,40,45,16,26,6,17,37,11,13,57,20,1,64,112,38,50,13,42,0,54,39,3,16,13,25,0,16,13,26,22,34,37,3,23,16,2,12,14,49,0,21,20,95,7,24,24,0,18,24,49,61,37,5,30,18],[14,3,0,0,4,8,0,0,0,3,2,1,5,11,2,7,4,1,13,0,13,1,0,0,4,15,6,0,3,25,0,6,14,13,5,0,20,1,5,9,6,6,18,8,7,1,9,0,37,38,75,12,16,10,18,9,3,2,4,0,108,29,5,33,0,7,3,2,2,5,0,0,19,10,8,19,7,11,55,4,27,5,5,0,51,198,7,22,0,1,21,0,8,0,11,0,1,0,4,0,0,3,0,0,7,2,0,0,0,22,0,2,1,0,0,0,2,0,0,0,0,0,1,0,0,0,2,0,0,0,0,1,0,0,3,0,0,0,2,0,0,0,0,0,0,3,0,2,0,1,0,0,1,0,0,0,0,3,0,0,0,0,0,0,0,1,3,0,11,0,0,8,13,1,2,0,0,0,1,0,0,194,0,1,2,0,0,0,0,0,0,0,85,109,43,38,42,57,4,82,112,34,45,34,14,42,32,51,21,16,58,65,150,45,35,32,29,31,55,35,0,48,16,85,27,56,41,34,15,26,39,53,4,30,46,36,19,60,37,140,102,83,74,77,128,89,71,100,2,45,23,26,85,163,112,111,97,170,69,75,22,20,24,34,79,69,82,117,49,42,61,78,51,32,67,47,42,41,73,50,135,64,65,80,43,19,16,58,3,76,24,39,57,57,73,92,63,47,20,40,49,49,100,45,43,60,76,89,51,39,29,23,39,4,45,28,62,49,79,57,1,39,121,0,93,51,58,18,34,37,0,17,0,15,24,50,39,38,84,36,13,101,40,41,28,12,50,44,27,67,25,48,40,18,39,36,35,20,34,47,79,57,39,71,33,54,86,29,29,110,53,40,34,104,56,9,0,40,45,15,12,30,23,146,61,22,66,30,0,31,28,17,218,32,56,96,82,33,78,16,0,68,34,53,36,13,119,51,19,52,45,24,0,61,29,27,105,60,162,24,1,142,17,35,0,14,36,35,183,158,164,73,100,62,58,35,0,30,44,19,182,45,120,89,99,1,65,25,0,46,74,39,40,15,49,8,0,0,0,0,18,0,39,2,20,0,18,0,10,0,7,22,16,0,25,36,25,0,9,0,30,1,21,0,26,0,34,0,11,0,15,15,25,12,14,0,12,25,18,15,19,6,10,30,6,15,43,9,1,53,84,27,62,9,27,0,21,20,3,6,9,23,4,16,9,16,25,10,7,3,10,18,1,4,6,45,0,20,13,105,1,16,12,0,6,13,40,32,20,2,43,7],[82,6,0,1,4,10,0,0,0,8,3,2,30,19,3,29,9,2,47,1,57,1,3,0,9,43,20,2,13,70,2,7,27,41,25,0,126,6,22,36,13,14,42,22,18,6,17,0,151,89,232,47,51,28,81,53,10,15,11,0,281,98,16,39,2,13,24,11,3,12,0,0,30,32,19,39,18,20,203,5,55,12,18,0,112,438,6,42,0,1,35,0,16,0,19,0,0,0,63,155,96,5,0,0,11,4,3,5,34,94,1,20,10,1,23,20,8,13,6,1,3,104,3,0,31,14,4,14,9,3,6,5,82,41,21,32,4,5,3,5,21,0,4,0,4,108,109,15,16,10,13,10,30,19,11,7,1,17,35,99,3,19,5,11,7,5,3,2,28,9,16,38,33,2,12,3,11,4,6,0,15,528,14,52,53,3,12,7,0,1,11,0,231,231,143,96,202,144,14,277,259,174,147,139,106,211,141,180,90,86,137,233,309,168,83,189,161,157,219,135,5,167,79,254,74,155,107,92,52,51,77,124,2,70,204,96,55,236,105,350,270,258,253,223,352,292,194,382,11,224,143,162,408,451,251,362,406,430,306,270,87,82,95,89,214,250,252,373,141,162,195,316,141,104,264,140,128,150,362,320,497,238,292,211,172,81,103,202,15,221,123,176,175,130,206,230,171,143,34,116,124,150,319,93,101,228,169,202,131,93,108,82,114,7,141,69,170,136,229,151,0,222,252,0,300,148,228,104,190,98,3,129,1,73,67,138,103,126,223,170,16,367,167,143,115,94,180,134,120,154,73,176,95,127,151,143,139,49,67,191,140,107,56,169,48,103,264,82,68,426,186,124,140,498,253,75,0,174,206,120,23,133,100,454,250,154,174,113,0,125,154,84,488,144,265,274,268,142,359,98,0,303,146,198,217,37,282,222,96,163,217,92,0,305,103,157,288,185,466,121,3,349,73,159,1,54,128,90,438,403,407,247,290,187,196,69,0,104,184,60,642,132,303,243,220,3,167,88,0,129,205,137,131,118,163,38,0,2,1,0,47,0,85,26,55,0,54,0,50,0,23,84,41,0,52,112,60,0,43,2,115,19,69,0,84,0,121,1,33,0,43,64,75,48,23,0,48,51,68,34,62,13,37,98,32,45,120,35,0,183,254,69,142,33,101,2,105,70,2,35,21,80,1,51,30,44,53,42,54,14,42,58,3,22,37,122,0,46,40,143,9,65,38,0,17,48,69,145,53,9,107,23],[221,10,0,15,24,28,0,0,0,24,10,3,43,51,25,27,32,8,109,5,75,16,4,0,27,99,28,11,49,245,1,25,84,87,80,0,237,44,32,88,16,11,67,36,66,17,39,0,344,193,579,91,84,29,103,95,29,29,14,0,494,220,47,129,6,14,56,34,11,21,1,0,56,31,31,60,23,39,176,6,70,7,18,0,147,543,6,55,0,2,54,0,17,0,31,0,22,1,78,56,64,3,0,1,6,6,4,7,13,155,0,21,1,5,2,8,10,22,7,0,6,64,6,0,23,7,13,20,10,4,12,2,17,8,41,0,1,2,3,3,10,1,2,1,0,23,22,2,0,19,7,7,30,5,3,3,0,10,28,51,0,11,3,2,0,1,2,0,23,2,1,12,21,4,7,6,2,0,3,1,4,396,15,12,13,0,3,5,0,0,0,0,438,241,189,141,386,169,3,516,279,267,307,221,190,354,245,294,133,196,167,359,269,370,208,280,268,262,391,153,16,216,143,291,202,165,103,104,49,80,97,139,1,64,306,93,58,362,197,391,383,296,302,386,457,465,370,578,16,357,200,310,528,662,341,544,601,558,485,407,129,176,221,101,336,314,434,521,244,261,308,569,227,125,389,233,215,237,578,392,566,298,389,402,330,85,222,351,50,276,230,274,188,170,187,165,142,142,18,97,100,152,303,116,127,238,163,219,110,98,81,86,130,5,183,56,184,116,192,119,1,452,213,1,569,157,307,152,491,122,0,213,0,205,165,281,200,222,274,210,32,554,215,277,115,188,230,212,240,204,154,206,169,170,306,233,234,87,129,242,162,121,66,137,58,110,418,82,93,542,279,143,210,655,485,169,1,241,435,243,40,291,176,627,425,263,261,152,0,192,316,176,514,179,447,287,410,248,378,146,1,475,176,394,298,87,339,367,158,240,309,123,0,333,211,296,503,336,568,193,16,447,164,297,0,86,152,96,564,401,380,239,256,202,199,84,0,85,154,109,623,146,291,273,305,2,160,83,0,147,148,294,132,182,300,34,0,0,1,0,82,0,191,48,157,0,139,1,95,0,69,171,79,3,102,138,105,0,109,1,190,41,139,0,141,0,213,0,88,0,57,80,73,52,33,0,33,72,72,44,61,18,45,80,85,73,253,96,0,349,290,140,190,58,138,6,148,149,13,81,46,119,11,105,53,107,93,77,79,19,45,92,6,35,61,208,0,93,89,320,22,29,31,0,37,56,75,91,64,8,86,38],[2,0,0,3,2,6,0,0,0,0,0,0,3,8,0,0,0,0,7,1,2,2,0,0,20,5,3,0,6,11,0,0,4,6,4,0,18,4,0,5,0,6,6,4,2,1,2,1,8,25,30,5,3,2,12,2,2,0,0,1,122,12,0,4,0,2,6,0,2,0,0,0,24,16,6,14,4,2,40,2,12,6,14,1,63,198,0,9,1,2,10,0,4,0,8,0,0,0,18,2,2,1,0,0,2,0,0,0,2,18,0,1,2,0,0,0,0,0,0,0,15,2,0,0,0,2,2,0,1,0,0,0,4,6,2,1,0,0,2,0,0,0,0,0,0,18,0,7,0,2,2,0,0,0,0,3,3,6,0,4,2,0,0,0,0,0,0,0,12,0,2,10,2,2,0,4,0,0,0,0,4,261,2,4,1,0,0,3,0,0,0,0,32,18,16,23,33,32,14,63,59,18,16,32,12,37,26,41,10,13,24,38,106,49,8,30,16,14,13,21,0,20,6,47,17,52,30,16,9,18,25,25,0,15,18,16,9,37,21,28,31,57,51,28,55,43,22,20,24,34,12,24,51,137,60,64,66,90,55,41,20,16,13,16,36,51,55,86,24,32,55,35,22,12,39,24,32,36,61,38,75,44,42,22,26,16,14,30,0,35,18,32,46,35,32,60,24,25,5,12,23,35,76,22,30,52,33,35,40,34,28,6,19,4,66,10,18,25,60,20,2,15,51,0,58,1,34,19,26,17,0,14,0,16,6,22,36,32,13,11,50,99,14,21,26,14,22,13,24,35,10,23,22,20,16,39,24,14,15,25,38,19,20,28,12,18,47,9,22,76,26,14,22,74,55,5,0,25,28,16,32,20,20,59,42,30,26,15,1,20,22,5,154,13,35,76,62,31,53,21,0,41,20,38,28,9,22,38,20,46,25,14,0,54,5,14,66,27,188,26,0,75,4,30,0,20,41,15,117,108,98,38,59,42,45,7,0,12,26,6,134,18,50,57,75,1,48,9,0,38,33,13,13,8,26,6,0,0,0,0,34,0,59,2,46,0,26,0,24,2,13,58,31,0,37,98,39,0,28,0,87,14,48,0,58,0,108,0,28,0,36,16,80,42,23,0,26,46,43,26,36,14,28,77,16,24,91,19,2,110,179,42,80,8,21,1,47,30,32,10,18,43,0,36,25,24,32,17,37,0,40,53,0,20,26,57,0,36,40,154,6,44,36,2,20,41,40,79,49,9,61,21],[39,6,0,0,3,15,0,4,3,7,5,2,7,22,4,2,7,0,14,0,8,4,3,1,4,22,5,0,9,54,3,9,12,18,18,2,53,2,8,14,6,8,30,12,12,9,5,1,51,43,89,28,21,3,24,17,0,6,6,3,120,51,10,43,0,6,5,2,7,6,0,0,14,22,10,35,6,8,98,2,58,8,12,3,109,306,7,40,1,2,24,1,8,0,3,1,4,1,33,13,7,0,0,2,4,3,0,1,6,41,0,9,1,7,1,0,0,3,0,0,0,12,8,1,1,3,1,0,0,2,2,1,6,2,12,2,0,2,0,1,1,1,1,1,2,17,7,6,1,9,1,0,9,0,1,1,0,2,5,3,0,1,0,2,0,2,4,0,24,0,4,19,21,0,14,0,2,0,1,1,5,271,1,5,4,0,0,3,0,0,1,1,62,132,56,37,95,87,2,100,124,74,83,52,39,101,53,59,29,41,94,82,158,53,28,70,56,55,87,38,4,51,20,99,43,96,44,33,22,38,22,37,0,30,85,64,23,94,53,148,108,110,77,75,129,92,66,134,6,104,64,57,104,136,80,120,106,196,68,95,52,46,37,46,111,76,117,123,56,38,80,110,58,33,95,35,59,82,131,76,164,93,91,96,76,18,38,77,18,100,32,62,92,72,73,93,50,68,24,49,48,73,178,61,59,97,68,121,61,52,43,32,61,3,68,28,58,105,93,60,0,79,86,2,124,88,132,57,57,72,0,31,3,36,24,54,46,58,98,62,14,105,57,73,42,41,65,47,49,69,29,48,59,50,38,61,48,21,20,102,77,80,21,117,24,74,106,40,30,217,78,63,53,208,100,29,0,82,106,58,18,66,70,213,115,36,96,27,1,47,85,21,276,50,123,147,89,62,129,41,2,121,56,115,55,33,139,95,47,94,52,23,0,148,56,84,185,84,236,67,2,178,22,72,2,26,97,71,327,204,192,153,134,90,116,57,0,38,84,29,355,58,183,119,61,0,101,51,2,58,153,39,78,29,71,14,0,0,0,0,22,0,64,20,28,0,32,0,35,0,12,51,28,0,38,45,45,0,38,0,58,17,34,0,58,0,62,0,34,0,29,40,57,42,23,0,29,36,44,36,51,30,19,53,17,25,67,19,1,81,128,43,72,11,74,2,33,21,2,25,14,48,3,18,12,14,29,36,17,6,16,38,5,12,24,69,0,33,28,238,7,24,36,0,10,42,67,89,35,7,71,16],[44,8,0,0,2,3,0,0,0,5,0,3,17,32,3,14,5,3,14,6,30,3,1,0,8,42,10,3,11,54,0,1,25,14,12,0,65,9,10,30,8,10,26,15,16,2,14,0,86,107,183,11,38,11,65,17,12,9,7,0,206,53,5,48,0,4,12,3,8,5,0,1,21,26,15,47,7,14,153,1,35,7,12,0,103,360,10,30,0,2,31,0,15,0,21,0,0,0,3,68,28,0,0,0,1,2,3,3,22,16,0,12,2,3,8,2,0,9,1,3,4,43,2,0,6,18,3,9,3,0,3,1,48,22,16,20,2,1,0,7,19,0,1,2,0,75,40,0,6,5,0,5,18,3,2,4,0,1,24,48,1,6,0,3,1,1,0,0,12,5,7,1,15,2,1,6,12,0,1,0,14,263,6,33,41,3,12,5,0,0,2,0,143,162,115,61,106,118,0,158,205,75,83,84,46,120,72,135,55,59,85,142,271,109,66,106,81,70,109,52,2,87,31,141,39,103,70,57,21,35,55,97,1,57,91,64,33,149,70,238,168,226,147,114,209,178,133,198,8,89,69,97,193,359,169,203,240,396,168,163,54,41,37,79,134,133,145,202,114,98,120,201,65,66,117,61,97,100,191,151,204,136,150,109,133,42,49,158,10,158,48,94,138,106,100,148,94,102,18,49,86,125,223,60,107,156,121,160,111,66,46,44,78,2,103,49,110,110,122,102,2,75,150,0,170,69,129,57,68,71,0,26,2,46,23,75,94,96,163,56,8,178,79,132,79,65,95,48,44,129,40,77,68,56,71,65,55,20,45,112,87,95,32,99,42,101,154,21,33,210,159,98,62,266,163,25,0,68,102,49,21,49,35,271,108,88,94,40,0,65,61,37,454,52,134,182,170,99,161,29,0,123,63,83,78,34,219,106,37,82,109,26,1,122,49,75,160,105,248,59,2,226,36,60,0,23,81,55,332,211,224,150,142,92,111,40,1,54,109,38,443,49,202,94,145,3,90,56,1,51,98,40,60,41,112,18,1,1,0,0,57,0,100,18,41,0,53,0,41,0,18,62,27,0,41,99,58,0,41,1,85,16,53,0,84,0,104,0,39,0,34,42,91,51,25,0,25,58,55,31,55,23,48,81,26,37,94,44,0,152,261,75,84,25,74,0,72,50,10,18,19,42,3,30,28,50,35,48,48,0,47,73,3,30,36,113,1,57,38,151,5,56,53,0,18,52,87,133,43,10,88,23],[25,7,0,0,5,8,1,0,0,1,3,0,11,6,3,1,4,0,9,0,14,4,0,0,52,18,5,0,2,21,0,2,12,11,4,0,41,4,3,8,6,8,13,6,6,2,5,0,45,22,106,8,17,7,36,12,6,4,5,0,147,31,6,16,0,2,7,3,1,3,3,0,24,16,8,27,1,3,90,3,28,0,10,0,63,249,4,13,0,0,23,0,7,0,21,0,4,0,30,11,19,1,3,0,5,1,0,0,5,20,0,1,4,0,5,1,3,4,3,1,22,26,2,0,3,4,0,1,3,2,0,2,18,4,4,7,2,0,1,1,3,1,1,0,0,11,25,5,3,4,0,1,1,0,0,2,0,11,6,21,0,1,0,1,2,7,1,0,14,0,4,32,14,0,7,2,6,3,2,0,5,307,2,16,33,1,7,2,0,1,3,0,82,55,52,27,58,67,42,93,135,60,47,39,18,53,42,50,18,40,56,66,144,50,28,63,47,33,56,30,1,39,20,84,32,66,50,39,21,25,36,64,1,24,63,49,22,76,43,65,96,116,65,78,127,89,67,111,68,63,32,44,101,167,92,132,124,172,83,95,25,24,20,43,57,74,72,107,60,45,87,86,48,42,76,46,59,63,101,83,125,78,56,70,48,28,29,92,4,103,23,62,63,65,84,81,63,51,27,33,48,68,134,50,58,95,97,114,73,57,37,34,52,3,76,21,84,102,114,66,12,56,88,0,121,16,88,30,63,73,8,31,0,31,24,41,39,36,46,25,66,79,35,53,64,29,38,40,25,58,23,55,49,35,33,38,52,14,26,67,50,44,36,47,28,53,92,25,23,174,77,15,60,164,101,22,0,50,55,39,107,38,27,164,65,64,38,35,0,38,30,19,186,27,66,90,72,61,125,31,0,61,48,58,59,15,137,70,24,78,57,25,0,76,38,51,100,69,185,43,1,157,21,66,0,19,47,56,212,176,176,117,121,83,81,52,0,41,84,30,299,39,106,88,86,1,82,38,0,56,81,29,23,32,42,9,0,4,0,0,42,0,79,12,64,0,49,0,28,0,28,67,27,2,22,99,41,0,28,0,88,13,58,0,69,0,113,1,34,0,26,40,79,41,34,0,32,70,77,29,67,22,49,96,38,15,89,34,0,114,174,63,104,12,30,1,45,58,24,33,17,54,1,31,32,46,33,38,41,3,36,48,1,22,25,89,0,50,32,173,1,41,46,0,31,37,91,91,39,11,88,24],[19,1,0,1,6,13,6,0,1,2,2,0,6,6,2,2,15,2,16,0,10,0,0,0,2,26,3,2,3,42,1,2,19,8,2,2,40,5,1,9,2,3,16,2,14,6,6,1,26,30,82,14,23,9,32,7,4,2,8,0,171,37,4,38,0,5,8,10,0,19,0,1,30,20,16,32,5,8,104,2,63,8,16,4,74,275,4,34,0,3,22,0,11,0,20,2,4,1,14,27,18,0,12,0,0,0,4,2,2,25,0,6,1,0,2,0,4,2,1,2,0,15,2,0,0,2,0,0,1,2,2,0,9,11,6,4,0,2,0,0,8,2,0,0,0,12,9,10,0,7,1,0,14,1,0,2,1,11,0,21,0,0,0,0,0,4,4,0,31,5,8,21,15,0,14,8,0,2,1,0,3,221,13,22,8,2,4,3,0,0,2,0,80,55,41,21,40,67,108,87,165,51,61,27,5,55,36,62,18,8,48,56,166,47,26,24,24,18,47,32,2,40,2,102,18,76,74,64,12,40,61,62,1,16,45,40,21,87,16,53,75,93,86,53,129,108,79,117,13,75,40,38,82,141,68,95,79,129,105,75,30,17,32,32,74,87,97,143,70,66,96,60,52,56,55,23,58,50,66,59,163,68,78,103,71,7,27,68,1,47,23,84,79,97,126,104,78,96,45,74,94,79,101,62,38,139,97,104,55,71,57,44,57,0,71,17,124,48,148,46,54,14,99,0,131,48,75,50,42,68,74,8,0,49,17,37,27,10,25,42,12,111,79,24,96,16,56,32,18,60,15,46,19,7,48,35,41,28,22,32,71,56,63,53,22,24,93,42,54,78,49,12,56,107,86,14,0,77,77,18,25,27,24,157,58,59,59,8,0,68,28,21,172,58,126,137,69,38,129,34,1,58,42,63,56,37,116,46,46,66,46,18,1,106,46,42,110,93,277,52,0,71,22,55,1,26,90,51,375,220,398,50,115,73,85,62,0,97,64,24,266,100,199,148,163,0,62,39,0,85,86,24,9,21,46,5,0,60,0,0,52,0,75,20,42,0,27,0,21,0,18,38,39,0,37,70,39,0,23,0,66,12,68,0,63,0,97,0,38,0,45,50,96,64,20,0,32,81,84,32,52,30,49,64,14,10,70,22,0,98,151,61,58,7,36,0,51,61,0,21,8,45,6,32,21,20,25,34,35,3,26,51,2,22,28,88,0,24,28,169,4,56,40,0,79,34,71,98,57,15,77,18],[15,2,0,0,0,2,0,0,0,3,1,0,3,8,4,5,3,4,10,3,4,3,0,0,1,9,2,0,6,13,0,0,10,13,2,0,17,4,5,15,3,7,6,5,7,4,1,0,30,31,74,6,19,2,13,6,5,0,2,0,108,30,9,11,0,0,5,4,1,7,1,0,21,13,3,18,2,8,54,0,14,4,5,0,53,170,4,8,0,1,19,0,5,0,9,0,3,0,11,0,1,3,0,0,3,0,0,0,1,13,0,0,0,0,0,0,2,0,2,0,0,0,4,0,0,0,1,0,3,0,0,0,0,0,4,0,0,2,0,0,0,0,0,0,0,1,0,4,0,3,1,0,3,0,0,0,0,8,1,1,0,1,0,0,0,1,2,0,6,0,1,8,12,0,2,3,1,0,0,0,0,157,0,0,2,0,1,0,0,0,0,0,56,75,23,38,35,56,1,66,90,33,24,29,11,36,38,37,18,19,47,51,78,32,17,27,22,20,37,23,1,30,8,55,28,42,25,24,10,23,26,36,2,21,45,23,10,67,23,115,94,92,38,51,84,73,75,82,5,31,17,37,79,127,52,74,98,140,60,50,20,20,11,19,75,56,61,102,32,37,51,56,28,28,63,24,34,48,71,73,119,56,54,48,58,12,18,65,4,57,9,43,59,50,53,70,69,36,7,21,53,45,126,41,40,69,60,48,55,33,19,24,28,5,45,22,62,45,59,52,0,29,51,0,98,40,50,38,50,43,0,21,0,18,10,35,28,27,53,17,9,71,21,43,23,18,35,28,14,53,12,42,31,18,19,27,25,14,11,38,31,36,11,48,14,38,71,19,13,119,92,25,23,135,73,9,0,46,40,34,4,24,21,157,43,26,57,24,0,19,30,26,181,23,69,88,92,48,89,25,0,43,23,54,47,12,86,59,29,54,27,12,0,56,35,27,79,58,139,36,0,109,10,45,0,12,48,39,189,159,155,90,93,64,43,27,0,51,50,23,205,43,102,75,79,1,59,29,0,46,76,21,31,19,23,13,1,0,0,0,15,0,41,7,22,0,22,0,13,0,4,26,21,0,17,35,16,0,15,0,39,5,33,0,42,0,44,0,14,0,25,19,34,30,12,0,19,38,34,12,37,4,21,48,19,27,40,13,0,76,85,36,34,7,40,4,27,24,0,1,13,21,1,13,17,18,20,10,20,1,18,18,0,12,20,44,0,29,26,84,0,17,15,0,12,29,52,55,35,2,68,7],[15,1,0,1,1,11,1,0,0,0,3,0,5,9,1,0,0,0,22,0,7,0,0,0,31,9,6,1,4,20,1,3,11,16,3,0,34,2,3,19,5,4,17,5,5,3,5,0,30,34,74,17,10,2,14,6,3,0,2,0,102,29,10,35,1,2,2,1,2,5,0,0,16,14,6,14,0,6,87,0,25,2,4,0,58,191,2,18,0,0,16,0,10,0,8,0,0,0,8,37,15,0,1,0,3,1,1,1,10,19,0,3,0,0,4,3,1,1,0,1,13,24,1,0,5,9,0,1,1,2,2,0,13,10,7,12,1,0,0,3,4,2,1,0,0,49,15,3,5,0,6,0,16,4,0,0,0,5,5,18,0,4,0,1,3,1,2,0,8,1,10,19,7,1,2,1,3,1,2,0,6,168,8,26,15,1,3,2,0,0,4,0,58,40,42,21,44,46,9,59,95,45,26,42,11,50,34,49,27,16,30,62,129,40,34,43,42,23,68,27,0,34,9,61,25,61,45,31,24,25,17,49,0,21,41,26,13,71,32,39,61,75,77,53,136,83,54,92,48,70,36,44,96,127,65,94,91,189,66,50,23,24,21,31,86,56,65,130,40,30,71,86,45,30,57,30,20,46,93,69,115,59,74,60,59,23,35,42,7,54,34,44,57,48,64,53,60,41,10,33,53,37,120,30,29,62,56,62,57,32,21,29,31,6,54,27,71,37,72,59,6,35,76,0,101,20,76,35,41,47,6,21,0,25,12,42,40,30,24,36,67,93,34,35,36,27,52,35,29,62,26,28,37,28,46,61,28,21,23,53,53,60,20,52,19,57,87,28,27,143,51,12,24,105,77,16,0,50,48,35,75,25,29,135,73,46,63,36,0,29,27,24,188,27,87,112,109,69,101,13,0,89,31,75,58,18,126,55,9,52,59,20,0,51,34,33,83,74,212,33,3,122,13,60,0,21,61,38,186,174,154,100,95,79,67,34,0,53,71,25,234,38,144,94,104,2,53,24,1,51,66,28,15,21,50,8,0,0,0,0,16,0,40,3,16,0,24,0,15,0,10,23,11,0,18,49,22,0,18,0,32,3,33,0,29,1,47,0,11,0,12,19,30,18,22,0,11,28,24,11,28,8,17,31,11,7,41,12,0,51,102,26,46,9,12,1,34,25,12,12,6,20,0,21,13,19,19,23,18,1,20,28,0,21,15,48,0,27,17,87,0,20,23,1,14,22,41,59,34,5,38,12],[536,47,0,9,33,64,0,1,0,46,5,1,102,108,37,40,29,12,149,9,155,52,2,0,26,231,44,17,31,383,11,32,150,152,154,0,475,43,95,98,49,29,155,80,78,30,69,0,592,298,813,116,173,55,291,167,67,42,48,0,915,404,83,162,1,25,72,52,7,39,6,0,60,88,38,101,18,31,426,7,111,29,24,0,290,828,18,64,1,1,80,0,51,1,59,0,16,4,314,610,552,3,0,0,8,11,18,27,191,321,0,26,18,28,93,63,13,61,41,18,16,409,31,4,65,67,14,12,14,11,13,23,288,233,104,79,2,19,12,24,67,6,10,5,1,339,318,59,33,22,28,45,112,49,15,15,1,64,98,395,5,55,8,11,17,3,5,0,86,7,47,55,39,14,6,8,23,4,6,0,43,1045,19,92,83,0,15,17,1,0,9,1,1017,649,393,310,837,301,3,1186,389,479,654,581,536,910,609,636,313,389,394,649,635,749,351,579,513,469,845,417,31,575,268,1023,374,333,215,150,86,141,159,259,9,143,695,207,100,763,445,847,842,759,637,704,960,788,555,1113,46,684,412,540,880,1494,770,1086,1317,1280,1007,734,321,326,329,211,679,624,814,1230,474,452,553,968,319,211,699,409,451,450,1083,717,1191,724,813,684,532,225,480,613,88,598,350,469,381,334,441,325,264,260,38,171,186,246,657,201,290,390,305,404,215,188,246,103,267,14,348,137,285,277,270,304,0,800,403,0,1095,269,444,327,952,266,2,471,1,288,390,458,429,434,572,555,66,991,534,609,195,350,590,447,511,531,267,500,320,422,563,588,398,195,295,499,253,213,107,309,122,229,888,160,130,1101,728,194,415,1388,1019,300,1,710,722,380,85,587,437,1316,577,488,664,393,3,326,597,275,1277,323,889,802,782,544,723,300,0,862,523,717,506,125,652,689,179,570,499,243,1,780,413,366,1180,711,991,230,35,851,332,595,0,151,321,209,924,573,553,486,495,392,356,226,1,186,279,130,1204,206,686,459,424,5,324,126,0,183,207,665,377,324,680,60,0,4,0,0,120,0,394,86,279,0,248,0,128,1,79,290,141,1,161,231,190,0,183,1,257,73,216,1,215,0,384,1,126,0,83,108,125,106,73,1,50,164,130,68,131,49,85,113,120,109,397,171,3,825,551,294,293,106,285,5,383,288,17,132,110,237,16,183,121,203,193,135,169,9,109,194,12,97,128,440,2,234,211,263,61,119,68,0,48,92,160,226,127,17,199,68],[822,50,9,24,78,107,1,13,15,76,27,24,126,139,45,42,65,56,295,18,282,52,15,9,68,276,93,27,113,519,13,65,176,214,157,5,566,47,108,168,110,60,154,188,94,41,151,5,994,519,1608,219,269,92,412,397,118,86,101,11,923,631,143,306,13,47,171,107,19,66,13,13,119,143,41,211,28,59,578,12,156,36,50,15,323,1253,54,130,26,4,155,22,60,17,73,23,41,11,448,752,672,13,4,7,20,14,28,36,252,437,4,60,14,33,103,108,18,67,21,21,14,519,45,7,137,118,58,55,45,3,49,7,356,335,98,83,1,22,23,31,70,5,18,6,41,593,523,99,44,40,71,39,129,94,38,64,17,89,189,439,10,35,24,61,41,14,15,5,99,33,41,115,58,18,25,10,31,9,12,0,73,1438,19,114,182,2,24,34,6,0,27,0,1620,780,818,498,1340,399,9,1822,705,787,923,875,487,1176,751,851,433,560,632,898,715,815,442,1091,829,979,1485,714,48,799,495,1435,541,479,251,332,167,184,281,415,6,200,1011,276,157,1022,533,987,1250,1104,909,1061,1625,1124,901,2077,65,1280,624,892,1821,1744,1186,1780,2009,1922,1493,1521,444,494,497,368,1047,960,969,1799,583,695,1142,1838,758,464,1500,535,815,826,2146,1640,2095,1314,1499,1276,1026,507,601,1001,176,1329,737,796,536,558,613,483,380,374,96,321,412,389,913,327,375,612,466,544,377,310,307,241,407,14,331,182,485,406,499,495,2,1290,691,7,1783,434,1141,564,1457,325,0,623,25,439,456,823,750,639,759,707,118,1575,794,807,217,608,706,919,699,664,445,884,533,649,863,922,656,436,465,1033,447,356,205,483,181,406,1024,258,169,1443,690,272,656,2004,1348,444,2,825,1050,688,118,731,525,1853,1187,844,918,593,18,539,895,584,1721,641,1276,986,1245,706,1413,583,8,1457,699,1313,1000,201,1166,1141,511,938,1270,568,4,1367,803,927,1820,1045,1510,664,70,1892,586,932,8,224,611,322,1429,953,931,771,809,572,648,304,4,299,499,182,1595,307,931,624,876,4,461,259,5,386,426,1119,496,630,891,97,4,2,0,0,141,0,449,108,354,1,277,0,277,4,139,427,195,0,204,292,256,0,233,2,443,104,287,3,311,0,514,2,198,0,100,147,206,134,71,2,94,156,167,81,180,51,127,162,150,145,676,244,5,951,634,345,511,95,314,21,452,400,22,200,161,353,36,255,147,263,227,162,197,40,198,277,13,178,169,444,5,337,230,504,105,119,116,0,68,142,180,278,129,45,247,55],[59,27,0,3,2,41,1,0,0,13,9,0,20,60,13,14,25,14,66,2,65,13,3,0,35,62,26,6,24,136,1,16,57,68,39,0,134,25,24,58,23,17,52,33,32,7,33,0,197,196,434,47,79,11,125,38,17,20,23,0,505,142,32,125,0,18,36,19,14,38,0,0,68,60,29,92,19,34,292,3,83,16,23,0,210,698,14,63,0,0,68,0,37,0,53,0,1,0,80,204,65,3,1,0,11,9,20,6,29,116,0,29,2,1,26,5,1,17,9,3,14,91,3,0,38,22,0,9,6,3,9,3,116,47,20,47,2,6,4,4,17,4,2,0,0,170,114,14,10,7,3,6,7,21,7,8,0,13,14,109,2,8,2,13,10,7,3,1,44,3,26,46,40,7,20,11,13,4,6,0,20,895,8,93,99,1,21,13,1,4,11,0,319,464,198,161,273,341,9,437,564,253,221,202,106,267,183,297,146,90,264,373,609,249,130,225,219,169,298,170,5,288,89,399,140,280,202,175,100,129,163,246,8,135,294,185,106,452,170,560,576,546,435,362,673,548,406,598,48,354,170,223,521,890,458,562,676,926,438,438,131,123,129,190,447,380,424,601,242,250,352,385,184,171,279,152,199,277,485,407,774,402,460,312,307,97,171,450,25,461,151,282,346,299,351,342,301,246,68,186,240,280,614,221,256,434,277,394,251,176,145,160,219,14,296,148,346,272,437,278,0,190,481,1,447,223,301,135,175,165,0,71,0,99,71,220,208,199,408,216,74,629,234,254,164,126,272,197,155,364,143,246,154,159,177,154,186,83,131,312,292,239,123,313,122,306,349,128,140,621,271,162,138,629,370,70,1,232,223,136,102,122,101,680,286,161,237,166,1,144,164,112,992,145,305,498,423,222,382,80,0,362,141,300,247,50,459,285,89,237,228,63,0,302,145,173,477,316,827,173,8,797,107,242,1,96,215,158,913,625,663,382,486,351,324,137,0,152,267,92,1076,179,550,349,396,8,285,119,2,182,258,134,256,143,284,44,1,0,0,0,54,1,123,25,72,0,115,0,55,0,48,102,58,1,76,178,119,0,66,0,165,17,99,1,136,0,182,1,56,0,64,73,134,81,48,0,37,114,114,51,93,29,59,161,25,76,224,81,1,188,430,158,171,40,126,0,160,124,19,40,25,100,3,76,51,67,72,70,70,9,67,101,3,38,65,220,2,114,76,198,9,94,73,0,40,79,157,209,97,24,176,44],[54,19,0,5,5,41,2,0,0,13,3,1,19,47,8,11,21,6,59,4,60,14,2,0,227,70,27,6,20,133,4,15,46,63,28,0,143,21,18,68,12,28,59,36,20,10,30,0,163,139,345,28,72,15,82,45,9,17,13,0,577,149,26,95,0,17,19,7,10,19,2,0,66,63,48,83,22,33,317,11,78,10,26,0,196,789,12,50,0,3,79,0,39,0,38,0,0,0,46,143,54,5,1,0,9,7,8,6,28,105,2,15,1,2,10,6,7,6,10,1,63,85,9,2,24,30,3,9,3,0,4,1,85,62,17,47,0,9,1,4,15,1,2,4,1,138,102,6,15,8,6,8,38,14,6,8,2,10,17,70,3,12,4,11,12,10,5,2,42,4,59,61,43,5,14,10,11,3,3,0,15,792,11,68,105,3,18,9,0,0,5,0,219,233,175,122,198,290,75,353,540,229,201,200,76,240,146,253,117,93,207,339,513,198,123,210,170,171,265,142,10,225,78,289,84,246,180,163,67,120,143,236,12,115,268,175,85,353,157,304,454,451,340,338,567,435,335,488,313,300,160,173,390,740,435,457,503,760,418,355,103,127,108,146,407,340,367,528,190,201,276,378,163,144,257,131,168,213,450,306,580,342,362,251,274,70,128,328,24,320,124,242,267,230,313,339,260,260,68,170,224,258,502,204,208,408,256,367,211,139,148,133,207,13,274,123,275,244,360,248,6,156,395,1,352,99,321,112,182,222,14,85,0,90,69,180,196,184,172,183,480,552,200,251,219,133,259,164,128,304,132,204,143,134,163,155,194,66,118,284,271,233,148,245,107,284,389,132,141,587,275,77,157,570,369,83,1,208,243,150,433,154,125,600,268,188,233,122,1,151,179,101,758,167,312,517,486,248,527,80,0,367,168,291,237,62,459,273,113,285,297,96,1,354,178,175,504,393,837,180,7,639,92,253,0,95,244,185,806,755,940,422,509,431,401,207,0,150,329,108,935,182,578,376,490,11,298,135,0,210,274,122,101,119,191,63,0,1,1,0,42,0,78,21,61,0,77,0,29,0,33,102,61,0,65,156,68,0,54,1,132,22,93,1,100,0,125,0,43,0,71,52,93,90,48,1,57,108,84,47,78,29,61,111,25,26,157,53,1,191,331,101,214,29,50,0,96,93,41,41,30,66,7,50,37,60,56,45,67,3,52,75,2,42,45,164,0,81,51,245,6,65,77,1,55,57,133,158,88,9,167,38],[30,7,0,2,7,17,0,0,0,4,0,2,6,10,0,7,8,4,11,1,12,2,0,0,6,15,6,1,10,36,1,5,18,32,5,0,58,8,6,22,5,7,18,6,10,5,4,0,69,58,139,8,29,8,36,17,5,2,3,0,267,55,6,33,0,9,7,7,1,12,1,0,27,23,7,34,10,12,152,0,53,4,13,0,101,378,6,12,0,3,30,0,13,1,29,0,0,2,16,65,29,2,1,0,6,2,2,2,12,35,0,14,1,2,3,2,1,6,4,1,1,49,3,0,6,6,2,6,0,2,1,3,40,37,3,29,0,8,0,3,11,0,1,0,5,72,33,3,6,10,3,2,15,7,4,1,0,1,16,38,0,8,2,1,5,4,1,2,22,3,14,11,17,0,6,10,6,0,1,0,10,428,4,45,48,0,5,7,0,1,7,0,132,132,63,43,124,122,17,189,193,90,80,69,40,107,66,112,40,37,96,99,170,91,44,105,83,60,82,70,0,95,28,158,48,137,90,62,30,59,66,96,3,42,84,86,36,144,56,211,160,206,146,145,223,185,126,186,12,90,61,85,174,318,130,235,206,392,165,133,57,51,44,76,154,115,158,241,85,86,96,159,52,57,108,56,61,70,154,126,252,129,137,119,116,34,39,138,3,143,68,102,127,114,140,170,100,109,17,72,119,112,220,88,102,165,103,163,88,68,72,57,87,11,112,65,132,117,169,98,4,87,171,0,146,65,136,48,72,80,4,36,2,39,33,69,71,67,141,64,17,234,73,90,80,40,90,74,44,114,50,87,58,47,62,56,52,18,36,94,91,73,48,102,40,111,137,51,39,202,120,77,36,230,147,17,0,69,107,68,27,40,50,256,103,85,99,45,1,44,72,33,324,50,123,189,169,113,234,32,0,130,46,80,106,18,128,87,44,93,88,28,0,107,55,59,170,95,289,58,1,267,26,77,0,44,98,66,286,190,246,122,177,124,141,73,0,59,111,41,413,78,214,136,182,1,109,51,0,73,88,59,90,46,78,25,1,1,0,0,55,1,101,14,59,0,50,0,30,0,34,74,42,1,36,162,61,0,42,0,108,9,80,0,92,0,145,0,40,1,50,56,109,56,31,0,45,116,109,40,81,39,52,115,26,45,103,33,1,139,262,69,136,11,62,0,65,70,6,30,21,56,3,44,23,40,27,34,39,2,50,70,2,27,35,125,0,71,31,190,6,70,50,0,27,67,100,135,57,13,141,34],[70,20,2,5,6,70,35,4,4,7,19,8,40,42,14,6,20,18,56,3,53,16,4,7,25,80,23,10,25,169,3,21,80,60,34,2,138,27,27,53,21,38,70,26,28,8,40,1,154,219,369,47,72,34,96,15,20,10,17,3,805,148,39,109,1,21,22,15,18,48,4,2,149,134,105,112,39,31,399,16,133,21,39,1,393,1192,33,103,2,7,127,4,43,7,90,2,1,1,84,205,103,5,22,0,17,9,25,11,41,152,1,15,3,3,20,8,4,12,12,3,10,86,12,0,28,18,3,13,3,4,14,1,188,84,28,70,6,7,3,2,27,5,6,1,3,142,103,9,18,8,5,7,33,9,7,8,3,23,21,111,0,9,5,4,22,19,7,2,88,8,126,65,71,12,23,18,28,4,11,2,40,1334,23,131,132,1,31,10,1,0,21,1,345,283,195,141,267,386,921,396,622,201,200,176,70,244,198,316,103,108,246,323,728,199,143,272,199,114,199,164,2,243,58,430,117,345,250,234,111,143,181,298,14,172,219,241,111,433,157,337,482,486,426,299,609,474,401,425,44,226,131,236,440,838,491,539,569,948,370,336,119,92,95,166,378,324,382,579,199,213,316,320,142,151,268,137,181,235,303,269,589,327,337,311,280,71,121,441,5,286,115,266,393,293,397,494,361,348,117,223,288,289,656,254,263,540,452,492,304,212,206,184,207,35,330,166,375,349,479,386,263,133,498,5,486,147,309,118,200,206,326,89,4,95,68,200,279,223,196,172,73,540,235,297,190,155,282,180,131,372,136,215,182,95,155,208,182,61,146,243,370,255,236,351,157,350,363,139,225,746,318,94,148,580,414,53,0,201,253,83,94,110,92,818,298,177,274,164,4,118,128,88,925,158,405,493,418,245,477,70,2,326,202,237,253,62,527,293,115,301,199,52,4,305,134,147,625,316,1065,149,6,655,89,189,3,116,253,214,1123,849,1464,451,616,378,397,214,0,188,388,92,1472,176,686,482,455,2,348,114,2,219,338,103,123,133,300,54,0,135,0,0,122,0,276,32,149,0,170,0,70,1,72,220,113,0,103,317,179,0,114,0,246,27,144,0,219,0,325,0,108,1,138,167,268,150,86,0,106,203,210,99,206,54,143,287,54,57,262,89,0,425,746,221,293,59,128,6,151,126,9,53,47,142,4,109,68,90,102,124,93,10,105,142,7,82,101,248,0,148,57,405,5,173,106,0,156,139,257,349,167,17,358,61],[80,6,0,4,8,10,0,0,0,32,0,1,18,19,0,2,8,0,30,0,33,25,0,1,8,68,10,1,12,48,0,22,48,26,12,0,42,13,8,16,5,4,23,5,16,12,2,0,98,68,159,46,30,8,41,70,20,7,11,0,101,66,9,36,2,6,20,0,0,6,1,0,14,4,2,12,8,12,83,5,12,10,14,0,66,196,2,18,0,0,18,0,0,0,14,1,58,7,279,904,748,16,0,0,8,4,18,36,318,619,6,70,10,1,121,91,46,78,66,4,16,674,27,12,143,78,39,36,10,0,54,20,328,236,18,144,9,16,6,24,106,16,14,4,8,487,375,54,38,26,133,59,294,58,50,36,12,95,219,793,10,46,22,48,24,7,0,0,160,15,72,46,34,35,0,4,26,11,6,0,51,1040,28,140,180,5,26,16,0,6,18,0,12,3,1,4,10,1,0,4,3,5,8,1,2,1,2,6,4,20,0,29,4,1,2,8,20,11,22,14,0,1,0,18,2,4,3,1,0,0,2,12,0,2,108,0,3,6,0,21,0,0,4,1,1,44,6,31,0,34,14,14,43,11,11,22,32,28,2,1,16,0,0,2,48,6,48,14,0,0,8,29,0,0,12,0,26,8,24,13,26,17,2,32,38,0,1,0,0,0,0,5,0,19,4,2,7,4,1,5,1,4,4,24,1,7,2,4,1,1,49,1,37,0,7,0,2,100,2,2,0,29,10,0,37,72,158,2,16,1,0,11,0,10,0,0,2,12,11,2,0,13,43,0,0,0,4,2,0,62,0,1,23,0,68,4,0,6,1,15,0,0,0,24,0,1,22,0,7,1,7,0,5,1,11,0,2,1,92,8,0,17,0,46,3,1,11,0,0,0,10,5,16,90,155,6,0,6,3,1,0,13,0,2,15,2,19,1,9,0,5,9,0,76,4,0,18,22,26,1,4,0,0,0,0,0,2,0,138,12,18,3,10,0,4,1,0,1,5,0,18,1,1,6,3,0,0,1,1,21,1,12,5,5,9,0,0,0,0,0,16,2,148,24,148,0,26,0,48,0,30,52,21,0,42,23,29,0,21,0,50,12,52,0,29,0,77,0,16,0,8,16,32,28,22,0,8,23,12,12,24,9,8,14,16,4,75,46,0,126,38,14,20,16,31,2,56,40,4,38,12,26,2,24,17,35,14,6,32,2,18,20,0,19,26,42,0,26,14,95,8,20,12,0,4,14,30,24,16,8,23,6],[36,10,4,5,2,32,0,0,5,4,0,2,18,41,19,8,8,5,13,5,40,8,12,4,8,50,4,4,16,67,2,18,30,18,20,0,65,16,12,30,12,11,26,22,12,4,14,0,71,84,121,17,21,6,64,13,8,5,2,0,247,72,6,33,0,17,8,6,6,6,6,0,53,41,23,25,10,8,222,11,49,9,22,5,143,537,6,34,4,2,47,0,28,6,37,2,6,0,49,116,23,2,0,0,4,6,16,6,8,36,0,20,8,2,12,2,3,2,4,2,6,62,6,2,30,8,4,8,2,2,4,6,43,45,16,30,0,2,2,6,11,1,4,1,2,77,31,4,5,5,8,0,27,6,4,4,9,13,8,59,0,8,0,6,9,7,0,0,41,12,16,23,30,0,4,6,12,5,1,2,26,564,3,48,30,0,21,6,3,2,9,0,98,120,84,55,109,142,3,167,255,109,107,72,41,93,84,142,53,34,110,138,322,107,71,88,91,76,90,83,7,96,20,161,45,124,98,83,24,42,71,138,6,65,149,100,62,197,58,215,242,190,220,126,201,200,127,215,6,153,101,104,208,395,188,233,225,371,239,166,44,62,56,75,160,142,151,237,117,76,143,156,72,55,154,58,86,121,177,160,272,159,115,143,145,44,76,133,12,166,42,98,145,130,173,203,114,129,30,90,90,81,215,101,106,241,160,183,157,71,62,69,123,6,142,62,130,110,200,92,2,72,180,0,175,120,179,82,101,75,0,54,2,45,29,127,79,84,130,90,8,208,94,98,131,59,107,57,69,147,76,102,52,39,66,81,75,20,49,117,111,98,56,118,38,130,200,76,65,375,171,81,95,339,252,42,1,121,144,59,26,88,35,419,147,95,114,68,6,82,82,40,493,84,131,287,173,121,225,62,4,158,92,146,98,43,241,144,49,163,118,29,0,188,76,81,280,177,490,60,2,317,56,118,2,20,145,76,509,408,375,213,292,211,234,85,2,90,160,43,585,121,214,273,200,0,160,79,6,128,175,43,92,77,104,37,0,0,0,0,70,0,115,23,65,0,79,0,46,0,34,116,51,0,51,164,56,0,39,0,125,11,63,0,110,2,123,0,36,0,53,54,101,43,37,0,48,87,92,37,71,29,44,124,25,54,133,36,1,147,351,87,224,21,87,0,70,68,5,40,25,61,2,43,33,54,60,52,31,6,44,60,9,31,32,117,4,64,38,216,2,87,69,0,26,78,121,144,83,6,148,35],[1,0,3,1,3,4,0,5,5,3,6,1,6,1,5,2,2,1,2,1,1,5,3,2,1,2,6,2,4,4,2,4,3,1,0,3,4,3,1,0,4,1,4,3,1,2,5,1,3,2,9,1,9,2,4,2,2,6,2,6,14,0,2,5,0,3,1,0,7,4,1,4,13,2,0,3,1,3,2,1,1,6,1,6,6,10,3,4,4,0,3,3,7,2,7,4,2,3,2,8,3,1,0,0,17,0,2,0,2,2,2,5,1,0,2,1,3,1,3,1,0,24,1,0,3,2,2,1,2,0,1,1,0,8,0,0,0,3,1,1,2,1,0,0,2,2,1,2,1,2,1,1,7,0,1,4,3,2,3,1,0,0,3,1,0,0,0,0,3,4,9,11,3,0,0,0,1,0,1,1,6,17,8,1,3,1,1,0,0,0,0,0,1323,944,492,719,542,1314,1,826,1125,559,1086,505,274,1288,484,1212,602,524,891,1312,2605,1272,650,1082,885,724,1115,10,26,4,151,911,340,1086,489,367,177,644,385,977,39,559,9,347,442,1661,709,2070,1124,1949,870,722,1334,1154,822,1165,2,602,797,986,1081,1657,1667,1068,2369,3100,815,6,537,271,254,342,673,823,909,1216,986,482,1527,1901,446,365,1460,654,535,1241,2132,793,2814,814,1016,661,1241,385,688,759,30,851,554,1267,1430,8,680,1816,707,570,96,372,571,1264,1339,11,546,938,785,911,1254,497,14,724,464,54,773,554,799,713,978,1211,8,405,967,5,2103,17,1838,828,1164,1245,5,587,3,272,169,961,966,837,823,425,93,1222,480,1009,572,23,528,913,346,628,516,1165,387,736,19,995,882,368,512,1118,1097,964,232,535,273,605,1035,519,660,2890,1728,563,981,1760,2297,488,3,31,830,397,1,870,630,3424,1569,1271,1252,792,2,485,921,700,1977,15,838,1031,961,656,1232,276,6,1815,461,882,753,7,1157,1380,254,731,640,226,4,1230,874,1053,1412,894,3582,411,8,2763,360,552,4,455,13,514,4225,1718,1664,908,1261,885,1591,432,0,894,1725,339,3098,520,1335,2084,2127,19,715,751,0,1153,793,513,442,653,647,120,1,0,0,0,5,0,5,2,4,0,17,0,7,1,3,10,1,0,6,4,7,0,4,0,10,7,9,0,7,0,12,0,5,0,4,2,16,4,4,0,2,6,9,1,10,0,5,3,4,3,8,4,1,17,10,3,6,1,12,2,10,4,2,11,12,2,3,5,5,1,3,3,1,1,4,5,1,5,9,17,0,6,4,8,0,5,5,0,4,4,4,11,4,3,8,3],[24,6,0,0,4,8,0,4,7,4,3,0,10,13,4,2,2,0,16,6,20,2,0,0,74,36,4,2,11,40,2,4,15,13,6,4,39,13,8,18,4,0,14,6,6,2,0,2,44,50,97,11,32,12,45,6,15,2,11,0,226,48,4,35,0,8,4,3,3,2,8,2,24,34,24,37,14,24,140,2,34,6,10,1,116,363,9,28,2,0,28,5,12,2,25,2,0,2,23,64,26,0,2,0,0,0,4,0,16,26,2,6,3,6,4,2,4,8,0,2,38,50,4,5,5,11,1,2,2,1,2,0,29,20,10,6,2,9,0,1,5,0,0,0,14,45,42,4,2,14,6,2,28,0,0,0,2,3,2,41,0,6,0,4,2,8,3,4,28,2,18,38,18,4,3,2,6,4,4,4,6,334,3,52,24,2,4,6,0,2,8,2,68,50,42,36,60,80,22,107,119,54,43,46,12,54,43,50,18,30,68,50,174,51,27,45,49,36,42,27,0,43,17,73,22,70,59,47,21,28,38,68,4,41,55,42,33,127,26,57,117,143,68,75,133,113,58,99,50,76,46,38,104,167,91,132,118,203,146,91,28,35,20,36,89,94,99,145,57,34,92,109,25,29,39,54,50,66,119,83,137,75,89,80,47,12,30,70,0,95,19,62,80,72,59,113,74,68,14,54,69,60,150,66,60,134,70,103,66,56,31,38,48,4,82,35,102,46,98,48,6,34,103,1,93,29,52,30,43,78,4,19,0,25,8,92,32,42,43,56,104,113,52,68,71,29,85,37,34,60,38,51,23,32,29,65,22,8,39,95,68,62,25,94,26,72,93,28,31,225,83,28,51,168,90,21,0,64,70,31,108,26,32,137,71,70,34,29,4,38,40,26,212,45,73,144,102,72,129,35,1,84,65,72,82,14,116,105,38,82,69,15,0,120,56,56,139,83,177,54,2,139,39,60,4,25,87,31,200,291,220,130,117,68,79,31,0,60,91,34,265,58,141,111,162,2,88,22,0,71,69,41,18,26,30,13,1,0,0,0,30,0,47,10,13,0,42,0,25,0,6,35,30,0,18,78,75,0,22,0,55,6,52,0,46,0,79,0,16,0,14,32,38,46,22,0,30,72,50,30,34,10,38,60,20,14,60,21,0,104,164,50,146,24,30,2,24,32,20,18,11,29,2,29,28,14,18,38,18,4,14,40,0,16,20,63,0,28,21,136,2,30,20,0,32,37,64,80,35,6,68,20],[389,32,2,19,57,38,0,3,2,58,4,4,26,62,24,2,34,4,112,2,92,50,2,2,20,115,69,10,75,201,10,14,84,103,24,1,108,42,56,67,20,39,126,69,60,6,73,1,352,244,639,134,56,42,96,196,27,18,41,2,396,347,63,49,8,26,86,78,16,40,4,2,92,61,16,109,13,14,133,4,50,19,18,2,172,731,21,41,1,4,105,1,36,0,41,2,85,4,152,470,346,6,0,4,6,9,6,47,148,112,11,26,6,6,85,51,10,67,38,16,4,339,36,7,101,63,125,45,18,14,35,2,184,160,64,64,11,12,6,4,54,13,8,17,52,203,240,54,18,54,68,42,147,54,19,20,15,16,117,155,8,18,23,2,28,4,11,4,19,13,37,79,21,9,5,18,15,14,10,2,8,474,13,77,110,4,12,19,0,2,19,0,350,406,115,162,417,97,2,737,345,266,422,169,186,370,267,276,182,209,113,428,193,353,109,345,317,400,362,308,12,252,34,512,71,125,135,134,40,87,102,115,3,76,261,65,37,405,145,242,417,392,249,186,440,549,400,466,16,497,279,152,731,369,216,294,560,461,540,377,179,194,257,90,466,294,481,317,201,241,371,740,218,142,534,215,260,239,479,547,589,258,472,488,202,147,226,343,40,182,206,356,127,270,249,235,213,141,33,158,115,249,343,134,141,366,275,143,110,91,179,65,64,7,143,46,209,181,152,141,0,256,213,2,540,193,427,181,390,245,0,195,3,276,243,391,228,262,288,275,36,589,309,235,89,176,225,264,229,104,95,301,295,203,353,398,248,44,163,338,139,128,62,89,52,167,423,56,84,782,411,112,188,779,552,162,0,424,501,218,35,360,170,794,300,281,250,181,1,198,246,140,676,183,359,228,320,195,683,177,5,406,386,532,489,157,497,562,122,466,477,253,3,283,313,332,779,353,505,164,32,717,179,432,5,95,130,125,648,565,323,306,352,349,219,179,1,95,203,62,929,125,515,270,325,6,183,123,0,239,107,364,199,162,274,53,0,2,0,0,110,0,185,55,153,0,131,0,53,1,48,128,53,0,106,159,102,0,104,2,302,40,104,0,118,0,211,0,72,0,43,86,66,63,26,0,40,62,66,51,33,19,30,53,92,74,209,58,0,257,290,163,162,41,85,10,122,155,4,82,74,100,2,55,71,44,111,57,47,8,58,95,10,71,61,150,0,94,79,395,22,62,29,0,26,69,60,88,47,7,63,48],[75,9,0,2,9,19,4,0,1,7,10,2,12,27,17,3,0,9,43,0,7,1,1,0,0,44,21,7,5,73,1,2,10,23,11,1,18,13,7,81,16,21,22,15,18,4,7,0,102,89,0,54,14,6,53,3,3,6,5,0,330,82,3,46,0,13,2,2,4,17,0,0,8,56,43,58,0,19,153,2,110,28,24,0,107,359,12,14,0,2,9,0,21,0,56,0,5,0,36,0,1,0,3,0,4,2,0,0,1,22,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,3,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,0,1,1,0,4,1,1,6,1,0,1,0,23,0,1,0,7,0,0,1,5,0,0,0,3,1,3,0,1,0,0,1,0,1,0,0,662,1,0,1,0,0,1,0,0,0,0,124,105,65,44,98,129,2,173,222,71,82,0,0,147,61,237,39,40,105,152,217,174,45,165,67,50,81,0,4,1,0,156,3,150,95,57,40,113,56,221,4,130,3,1,42,270,48,92,185,419,1,0,239,188,155,165,0,103,126,1,155,4,177,7,189,346,168,1,78,1,44,49,99,122,133,204,103,53,243,120,49,54,104,62,0,75,138,94,239,133,144,91,116,27,69,122,6,1,76,161,128,0,148,167,113,104,42,75,96,121,251,2,120,200,130,168,79,81,0,65,103,8,149,60,126,122,200,133,100,51,217,0,312,1,202,43,58,93,105,17,0,40,26,176,103,78,61,62,23,221,86,206,68,1,99,135,46,153,74,180,54,47,1,170,138,24,117,226,249,174,94,142,46,134,149,119,157,426,137,37,33,224,325,43,0,7,83,41,1,61,31,474,103,125,79,52,1,51,44,69,401,0,116,173,164,71,175,31,0,122,57,100,73,0,182,91,37,122,78,21,0,99,87,57,173,138,314,72,0,467,75,69,0,68,1,81,772,275,540,142,244,186,288,46,1,128,193,42,2,60,241,340,333,4,89,112,0,141,114,86,40,36,77,1,0,0,0,0,0,0,17,0,0,0,0,0,9,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,13,0,0,0,18,0,0,0,0,0,0,0,5,0,0,0,0,1,0,1,0,0,27,0,0,0,6,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0],[84,16,0,2,4,14,0,1,1,8,4,7,26,14,4,16,12,19,36,8,20,15,1,0,10,66,18,6,11,91,4,12,68,12,14,1,94,37,11,18,18,36,29,7,6,18,18,1,97,64,242,36,60,34,94,29,12,12,14,0,284,60,24,62,2,8,18,2,4,13,0,1,57,77,32,79,13,2,195,19,63,16,15,2,196,608,16,34,0,0,64,0,23,0,52,0,1,0,48,55,59,4,0,0,4,2,8,8,16,83,2,25,1,1,28,2,5,18,10,3,6,56,2,1,30,26,7,16,4,2,12,0,44,2,20,46,0,2,3,2,11,0,2,0,0,143,53,10,9,7,8,7,26,8,2,6,4,6,18,31,0,14,2,2,16,9,2,0,38,0,36,42,19,8,9,6,9,0,2,0,30,770,10,59,33,0,12,11,1,0,4,0,153,222,184,100,122,199,2,272,293,173,108,125,58,133,135,143,99,89,147,227,425,168,61,148,94,118,145,112,0,139,49,242,73,177,122,101,77,76,93,155,7,99,131,130,68,209,127,268,277,233,216,168,272,292,177,341,12,162,110,123,254,459,223,321,323,508,302,210,66,69,97,95,207,199,233,352,125,146,194,273,126,82,194,96,141,200,237,221,425,188,244,208,165,39,122,221,8,181,84,145,219,165,219,274,149,207,42,135,129,170,381,113,168,305,237,278,185,114,135,82,182,7,231,91,242,208,278,144,0,118,267,0,260,171,132,70,122,133,0,58,2,49,56,121,146,118,239,122,20,272,130,120,148,104,167,115,82,177,75,124,101,91,105,165,115,43,60,149,175,175,58,163,54,174,177,85,71,373,170,112,126,379,194,23,0,105,146,80,32,103,63,363,138,113,116,58,4,80,78,58,464,99,187,215,197,166,258,50,0,199,115,178,126,32,196,140,55,166,121,34,0,182,72,97,292,162,543,82,6,347,32,133,1,43,173,100,629,396,440,212,253,207,152,102,0,126,195,100,834,115,271,200,204,4,146,79,0,145,164,67,131,76,148,45,0,1,0,0,42,0,104,16,62,0,67,0,39,0,37,81,39,0,49,105,57,0,49,0,87,14,70,0,107,0,83,1,23,0,27,69,132,72,47,0,28,66,85,56,81,28,73,94,12,48,89,34,0,159,288,72,117,13,75,0,60,49,7,29,18,68,6,25,36,38,30,67,43,0,32,57,0,29,55,102,0,53,38,130,4,75,64,0,20,65,96,101,48,10,92,44],[89,11,0,2,11,28,2,0,0,7,7,1,24,54,15,10,16,6,62,4,53,12,1,0,215,84,27,10,32,117,3,18,63,39,28,1,138,10,32,67,20,20,32,40,24,7,28,0,248,174,363,33,65,41,81,41,22,16,19,0,522,157,35,128,1,20,25,9,9,29,2,0,100,76,45,53,23,42,289,4,98,18,33,0,247,885,27,75,1,4,81,0,33,0,44,0,3,0,38,268,64,2,2,0,12,6,15,4,55,134,0,15,2,0,24,9,5,12,7,5,75,112,4,2,36,24,8,6,12,2,10,6,88,77,34,55,1,5,7,5,30,0,5,0,1,190,108,7,25,4,5,17,24,22,7,8,0,20,19,140,0,15,6,6,17,8,4,1,53,7,69,73,51,8,19,15,9,6,1,0,30,902,9,55,66,3,13,4,0,0,5,1,233,216,138,98,194,225,78,316,426,174,197,149,66,206,126,227,92,82,163,276,456,196,96,204,145,131,182,125,7,188,51,238,92,212,151,122,65,113,99,191,7,83,215,141,71,368,109,322,361,376,309,248,491,352,326,406,191,241,138,167,381,603,322,365,459,714,311,287,92,87,120,104,275,247,380,455,188,188,231,334,138,120,233,126,135,183,340,303,541,256,280,269,254,53,103,248,10,279,97,200,249,271,263,313,228,192,71,136,174,203,462,170,175,364,219,302,213,140,138,117,150,9,233,102,236,238,308,206,21,150,309,0,395,108,275,113,166,161,12,93,1,95,75,180,159,147,131,154,354,474,188,202,128,85,188,158,112,218,92,188,134,105,142,125,164,73,115,235,191,171,96,212,100,191,301,94,128,593,237,69,125,527,326,64,1,183,242,102,345,114,109,576,244,145,186,95,0,135,130,87,675,94,328,385,338,183,368,83,1,346,133,224,218,39,398,355,95,169,176,77,0,280,146,178,408,277,728,153,0,466,78,203,1,56,202,147,884,571,768,313,382,283,297,142,1,164,193,69,956,150,454,333,321,5,227,101,1,174,265,131,101,117,192,50,0,3,1,0,7,0,131,7,68,0,21,0,37,0,9,91,8,1,14,117,128,0,53,1,83,16,10,0,165,0,41,1,44,0,13,55,110,62,69,0,55,24,75,49,76,38,59,87,26,13,178,27,1,179,399,78,220,10,28,1,158,71,72,43,12,66,1,62,46,17,40,62,44,9,46,55,0,56,46,142,1,17,66,156,2,72,44,0,48,46,177,208,26,8,106,11],[144,34,0,6,13,56,45,0,0,10,6,6,81,66,18,10,16,16,100,0,86,24,4,0,30,171,37,18,38,146,4,12,46,129,22,0,262,143,32,100,16,34,89,50,50,12,48,0,285,391,450,44,170,60,187,18,32,16,19,0,991,330,58,165,0,45,23,18,18,46,0,0,459,226,234,122,32,40,912,28,157,34,66,0,623,2714,52,102,2,18,268,0,102,0,107,2,0,0,22,40,10,0,2,0,0,0,2,0,8,19,0,2,0,0,6,0,0,0,2,0,2,12,2,1,14,4,6,2,0,0,3,0,22,24,2,20,0,0,4,2,6,0,0,0,0,38,26,0,0,2,2,4,15,0,0,0,0,6,0,24,0,0,0,6,4,4,0,0,7,2,32,12,6,4,0,4,2,0,0,0,8,274,4,8,36,0,4,0,0,2,4,0,44,24,22,24,22,52,96,42,60,22,33,33,6,20,14,20,12,20,40,47,89,21,18,21,28,16,24,10,0,16,6,32,12,40,28,34,20,16,29,39,0,22,16,26,16,22,24,30,50,63,38,30,66,78,33,36,2,20,25,32,48,114,40,76,59,115,58,20,6,8,12,8,36,32,38,36,46,32,37,22,12,12,22,12,21,24,24,26,80,27,27,19,22,8,2,28,0,30,14,24,40,26,43,58,32,42,14,15,22,39,32,22,26,61,76,64,33,14,36,18,12,4,34,0,38,30,56,30,18,16,78,0,51,18,36,9,20,31,22,13,0,0,4,24,22,40,14,18,10,76,34,58,27,11,18,20,8,52,9,28,24,14,16,20,22,12,26,42,57,42,40,66,14,37,29,26,30,70,20,8,8,80,43,5,0,22,18,11,14,8,9,106,14,22,18,6,2,12,8,6,104,13,34,56,54,18,49,8,0,30,8,25,32,2,94,56,8,57,22,8,0,23,4,32,64,23,187,28,2,113,12,24,0,20,40,16,189,119,182,54,72,83,63,26,0,30,35,12,220,30,111,60,47,0,41,16,0,39,19,10,4,8,36,6,0,0,0,0,70,0,78,14,0,0,56,4,22,0,32,58,28,0,54,94,88,0,170,2,304,16,56,0,72,0,120,0,50,0,46,104,265,333,52,0,54,108,58,46,61,108,30,118,35,49,54,18,0,356,288,62,96,22,28,0,64,48,4,38,50,39,0,25,62,34,39,50,24,4,30,52,1,19,64,86,0,48,28,157,0,55,69,0,55,48,64,100,32,8,60,41],[16,2,0,1,2,8,9,0,1,2,2,1,10,12,1,0,5,5,10,0,9,5,0,0,4,17,5,1,5,15,0,0,12,19,5,0,30,10,7,15,0,5,19,9,8,1,10,0,36,35,67,11,12,7,15,6,6,0,3,0,200,41,5,26,0,2,5,6,5,9,0,0,30,11,17,27,3,6,96,1,59,4,6,0,57,265,7,6,1,0,30,0,14,1,19,0,1,0,18,15,8,4,3,0,6,4,2,0,2,31,0,2,0,0,9,0,0,1,1,1,4,12,3,2,7,2,1,0,1,0,0,0,19,11,6,7,0,0,1,1,3,0,0,0,0,23,13,2,3,1,1,0,6,1,3,0,0,9,3,19,0,1,2,0,4,2,0,0,27,3,16,32,13,0,3,4,0,2,0,0,4,372,2,14,17,0,4,0,0,0,2,0,80,97,41,52,65,107,226,118,167,80,54,61,19,39,52,108,61,30,97,94,255,62,49,69,53,21,67,47,4,68,30,109,29,106,70,81,30,38,49,96,2,55,66,67,29,121,68,70,159,118,141,107,221,172,130,124,15,92,47,76,138,244,142,156,166,296,136,101,34,19,30,48,112,81,148,161,66,65,94,81,42,54,76,34,55,57,90,76,224,113,120,75,108,24,17,106,6,98,42,77,121,93,111,86,125,96,40,60,101,85,193,81,80,190,145,150,101,69,75,64,76,4,125,49,109,103,184,74,62,49,174,1,160,39,111,53,47,72,80,25,1,30,16,62,82,76,50,66,22,130,83,88,73,33,96,49,40,112,48,65,61,33,38,69,56,20,35,93,105,90,81,127,74,121,164,64,56,244,134,30,53,213,124,17,0,75,83,21,28,30,44,200,84,76,80,52,0,51,32,27,317,68,104,183,158,77,170,27,0,115,66,78,99,25,149,90,49,99,60,12,0,97,52,55,187,134,358,51,0,217,23,90,0,31,107,92,405,281,530,174,248,172,136,57,0,52,112,56,476,97,250,174,158,4,128,50,0,91,114,28,38,38,76,27,0,45,0,0,38,0,41,8,23,0,31,0,6,0,12,40,18,0,26,68,33,0,32,0,51,5,26,0,50,0,59,1,24,0,23,41,38,32,16,0,41,40,58,15,49,18,28,51,14,23,45,20,1,66,201,47,94,16,23,0,61,42,4,13,22,20,2,24,15,16,32,30,26,6,31,36,0,10,25,74,0,43,22,115,4,43,29,0,50,24,52,63,30,4,69,24],[39,5,0,2,3,13,0,0,0,5,1,3,8,16,2,4,1,0,12,3,13,1,0,0,8,48,4,4,13,37,0,0,11,20,21,0,55,11,9,19,5,5,23,9,8,0,4,0,89,47,169,14,14,11,59,12,11,3,7,0,290,51,5,44,0,11,11,2,2,6,1,0,12,20,14,34,3,3,112,1,15,4,7,0,157,277,9,7,0,0,16,0,6,0,17,0,1,0,26,107,37,3,0,0,4,3,4,0,12,41,0,13,2,0,3,6,2,5,4,1,1,42,0,0,8,4,3,1,1,0,5,0,37,25,7,10,0,2,1,2,6,0,2,0,1,31,40,4,3,1,2,5,24,3,2,2,0,3,21,64,0,6,0,5,2,0,2,0,23,0,1,13,13,0,2,3,1,3,0,0,9,489,1,30,9,0,6,4,0,2,4,0,104,9,7,3,6,10,0,5,8,3,24,16,2,12,11,4,2,5,6,5,14,12,6,9,7,5,12,37,0,2,2,39,3,9,4,1,3,3,0,11,0,8,11,10,5,128,2,11,8,5,7,25,4,4,2,22,1,16,0,7,20,15,5,44,14,9,4,15,2,12,0,2,11,7,8,18,10,5,78,14,7,8,20,49,5,4,5,4,126,16,14,20,8,0,5,29,1,12,5,106,1,7,9,8,10,12,1,4,10,6,9,6,3,9,2,7,7,2,3,3,3,2,2,0,5,9,7,81,0,9,76,0,25,7,10,39,14,7,0,6,0,2,4,7,8,16,11,6,1,19,2,16,3,5,1,57,3,1,4,13,3,7,2,106,4,2,2,8,7,5,3,3,3,21,43,3,26,10,13,6,2,5,12,1,0,7,3,2,4,40,5,75,17,6,5,1,0,7,5,3,32,3,27,9,12,17,14,4,0,88,7,5,4,4,8,5,1,31,1,5,0,5,6,7,63,7,13,3,0,201,4,2,0,4,8,10,27,18,10,4,9,6,2,6,0,2,11,2,110,6,25,9,11,0,5,3,0,5,11,2,6,7,6,2,0,0,0,0,18,0,84,0,0,0,10,0,18,0,0,0,30,0,28,4,0,1,15,0,87,1,43,0,97,0,10,1,1,0,24,4,22,15,0,0,50,1,2,0,0,1,18,5,16,114,243,72,0,0,60,208,298,47,213,0,205,2,9,64,68,122,1,72,52,89,165,86,50,4,76,140,3,64,58,330,0,163,94,389,4,78,22,0,57,129,26,197,95,11,107,0],[319,21,0,8,30,27,3,0,0,19,6,3,61,80,32,21,48,16,113,5,144,8,0,0,9,161,40,9,90,251,6,26,115,31,75,0,277,67,48,93,31,27,95,56,44,22,39,0,509,260,931,77,136,44,257,63,47,46,60,0,588,349,67,150,11,64,101,37,8,36,4,0,31,73,29,105,23,31,333,7,207,20,22,0,175,782,13,75,0,2,56,0,40,0,49,0,10,1,125,256,191,1,0,0,7,9,4,4,67,132,1,26,2,3,23,36,2,22,6,0,9,156,16,2,19,21,25,8,3,2,11,1,107,43,52,38,0,6,0,1,13,4,7,0,7,100,154,12,5,26,21,11,97,6,13,16,2,12,32,77,0,13,5,5,9,3,3,0,31,0,12,44,9,2,3,4,7,1,2,0,2,600,4,55,51,0,1,6,0,0,7,1,488,271,271,102,557,165,14,538,188,236,399,238,158,376,240,323,128,178,160,380,246,285,144,291,199,329,454,170,10,281,131,406,165,177,80,81,37,68,71,121,2,38,300,94,43,266,191,352,459,467,263,368,428,364,249,558,24,372,223,237,505,570,402,589,582,677,426,436,162,127,135,100,348,272,364,579,148,203,264,604,163,206,397,202,189,264,648,354,778,397,436,353,274,124,157,370,70,426,196,286,140,193,219,140,160,128,22,73,83,142,260,92,111,232,158,235,85,46,66,72,108,4,146,74,153,124,193,117,4,440,153,1,625,106,409,121,491,110,5,198,0,110,120,206,157,193,243,195,31,493,149,272,90,147,222,244,211,167,86,212,147,169,189,228,189,85,110,276,141,71,36,106,33,148,262,88,51,361,217,55,231,840,518,165,0,162,201,149,39,220,171,616,478,173,213,103,0,118,229,93,523,121,437,243,238,218,252,107,0,446,146,364,282,51,323,254,87,198,339,86,0,317,223,317,412,310,538,126,24,659,167,190,1,70,138,104,511,280,282,206,206,201,164,96,1,73,140,23,400,106,298,210,215,1,112,79,0,131,98,359,164,154,388,20,0,3,0,0,57,0,150,24,83,0,119,0,73,0,62,146,80,0,65,132,154,0,88,0,235,36,135,0,122,1,283,1,36,0,50,89,58,48,32,0,15,91,46,50,67,14,45,76,120,67,261,52,2,306,204,143,218,40,76,0,175,317,3,68,43,110,8,104,38,115,69,55,37,3,56,104,3,73,63,238,1,97,69,308,41,66,67,0,18,38,55,62,45,12,103,41],[18,3,0,0,0,6,0,0,0,5,1,0,9,7,0,2,3,3,7,0,13,2,0,0,4,10,1,6,2,13,0,2,6,11,4,0,26,0,2,7,3,3,6,3,1,0,7,0,43,30,68,7,16,2,9,7,2,1,0,0,206,25,7,10,2,2,4,3,0,3,1,0,29,11,2,13,4,5,36,0,26,4,1,0,50,166,0,18,1,0,6,0,6,0,5,0,3,1,12,30,5,0,0,0,0,1,0,0,4,12,0,5,0,0,0,0,1,5,1,1,0,32,0,0,2,2,2,3,2,0,2,0,6,7,6,8,0,0,2,1,1,0,1,0,1,19,12,0,1,6,0,0,9,5,2,3,0,3,4,22,1,1,0,0,2,0,3,0,10,0,9,8,2,3,2,2,1,2,1,0,2,197,5,21,5,0,1,1,0,0,2,0,27,31,25,13,42,29,2,35,51,36,26,19,11,40,21,25,19,19,23,40,80,25,13,27,24,27,42,23,1,30,10,54,16,19,19,20,5,17,4,29,1,15,45,24,6,31,15,71,57,76,37,45,55,44,29,62,0,31,24,40,71,82,50,80,88,85,58,67,13,14,10,8,64,41,63,68,37,24,25,70,27,10,32,14,25,24,71,36,60,51,40,45,52,12,14,39,6,43,35,26,24,34,27,42,23,14,4,15,30,25,59,21,22,35,29,36,28,24,15,22,13,1,34,10,33,26,55,8,1,35,41,0,38,27,57,13,38,22,0,31,0,19,17,27,20,22,35,18,4,44,26,28,22,21,22,23,16,37,6,27,13,17,21,16,25,7,11,32,23,29,7,25,7,20,51,17,13,71,47,16,27,87,31,11,0,45,41,21,5,15,13,58,39,40,43,17,0,26,24,14,81,21,42,82,76,28,56,18,0,35,22,36,30,10,57,50,9,26,32,10,0,46,20,26,66,48,124,33,0,69,26,31,0,14,26,14,78,80,94,53,54,46,60,16,0,25,24,6,140,19,103,49,41,3,32,16,0,33,31,29,20,20,22,5,0,0,0,0,25,0,23,7,18,0,46,0,18,0,15,33,22,0,18,49,29,0,8,0,39,5,30,0,14,0,65,0,18,0,25,27,38,21,16,0,15,44,32,16,23,6,12,46,20,24,80,9,0,63,106,53,66,10,39,0,33,71,0,18,20,15,0,26,6,19,22,14,13,0,18,29,1,18,21,31,0,26,8,59,0,26,30,0,8,20,25,35,22,2,72,20],[269,18,0,9,27,14,0,0,0,22,10,2,11,48,6,23,22,7,62,1,107,3,4,0,14,67,18,10,31,70,0,4,80,39,41,0,2,11,28,47,26,6,65,40,24,4,22,0,158,98,428,64,61,36,112,56,17,5,6,0,478,9,39,94,3,6,48,24,6,6,1,0,35,22,15,59,10,9,94,1,48,6,6,0,142,538,13,57,0,0,10,0,24,0,20,0,9,1,150,175,139,7,0,0,2,2,1,5,38,67,0,6,4,1,26,17,10,14,11,2,10,109,8,4,30,22,7,13,4,1,13,2,68,46,20,43,4,0,3,8,13,9,7,1,0,111,48,19,4,10,9,1,43,25,7,3,0,22,38,68,0,13,3,4,9,1,1,0,11,4,16,42,0,3,1,2,9,1,0,0,7,542,0,28,29,0,4,2,1,1,2,0,526,242,298,157,240,146,9,461,208,161,290,210,219,314,185,233,105,165,153,239,200,271,87,219,220,220,344,184,13,239,81,364,113,110,88,80,30,52,78,143,0,44,226,106,51,293,169,232,401,346,244,251,416,351,227,526,8,347,165,249,500,483,231,416,414,526,430,316,98,123,148,82,211,210,288,372,156,142,236,341,197,121,371,147,207,200,505,400,566,318,321,317,199,100,129,272,29,366,157,207,121,209,194,143,105,105,16,76,132,103,279,93,104,214,123,174,84,93,84,41,86,4,146,38,160,129,145,85,3,328,181,0,426,107,270,110,403,85,4,225,0,101,138,238,173,166,226,206,23,370,213,219,65,179,194,143,185,202,95,212,209,138,186,278,153,65,107,188,110,87,33,182,41,88,232,42,49,344,305,121,176,589,360,111,0,252,341,183,27,194,171,483,316,255,234,134,0,130,242,113,461,171,278,250,316,290,282,77,0,337,229,347,302,72,243,209,100,243,428,159,0,292,196,208,428,311,444,136,21,516,144,182,0,61,148,82,381,284,306,203,258,187,200,79,2,95,125,63,498,91,270,173,181,2,144,80,0,119,123,256,126,149,258,41,1,0,0,0,78,0,195,23,153,0,191,0,78,0,92,193,125,2,112,101,192,0,96,1,258,36,244,0,83,0,412,1,64,0,83,137,92,53,52,0,42,97,49,37,87,27,22,106,122,101,398,56,4,372,359,253,225,44,179,0,180,352,11,124,85,110,7,107,70,143,158,90,68,5,55,135,2,67,116,236,0,123,78,162,47,63,86,0,21,57,84,123,54,4,174,50],[171,13,0,2,19,32,5,1,1,44,2,0,62,40,5,1,12,8,65,17,45,13,2,3,35,115,28,14,70,159,2,11,62,88,32,0,115,36,44,89,27,34,47,24,39,13,50,1,256,149,540,78,61,26,88,77,12,11,51,1,417,74,105,89,6,12,61,9,12,3,3,0,43,54,18,55,18,13,171,8,64,8,20,2,38,438,13,25,0,0,11,0,27,0,17,1,7,0,63,161,135,4,2,0,3,15,3,2,30,60,1,12,3,1,19,3,3,30,8,3,9,138,25,1,9,22,4,2,1,6,2,6,82,35,27,30,0,4,6,2,11,0,7,2,2,77,79,10,1,5,4,18,22,19,8,10,4,19,39,69,0,27,0,10,14,1,0,1,11,3,18,47,10,0,2,0,2,1,0,0,5,454,5,31,49,0,9,8,0,0,9,0,359,172,90,73,200,99,64,336,182,136,152,112,89,192,118,161,96,128,101,136,207,189,87,135,91,128,267,113,3,195,96,271,90,95,55,59,36,55,60,64,0,30,268,70,41,243,84,212,266,283,227,191,304,310,197,447,18,254,150,166,379,469,199,314,408,424,286,279,63,64,90,75,238,201,191,313,131,129,226,355,117,91,243,148,122,146,352,353,448,136,292,218,117,45,121,207,45,145,90,183,115,134,133,108,86,77,16,55,92,54,203,59,118,128,110,150,98,46,51,50,57,9,62,15,115,102,117,97,18,173,145,0,257,76,186,105,212,47,27,68,2,82,127,187,95,119,181,144,27,389,152,175,46,131,182,141,100,152,87,135,135,100,234,158,103,81,73,152,104,92,33,146,41,66,246,46,25,202,128,53,178,393,237,58,0,139,249,145,42,113,94,340,191,159,263,97,3,133,143,104,307,91,124,143,287,205,232,69,2,236,112,186,213,44,201,156,101,191,240,111,0,258,150,135,303,198,275,116,14,326,123,186,0,47,89,47,333,173,324,143,234,138,182,47,0,51,88,26,294,64,287,99,211,1,129,42,2,92,96,97,110,96,213,8,0,0,0,0,69,0,152,17,135,0,204,0,85,0,75,169,86,4,95,87,200,0,110,0,280,53,212,0,138,0,349,0,67,0,94,116,55,43,38,0,40,117,67,46,93,21,53,77,95,102,353,49,3,370,286,144,105,47,143,2,182,309,9,98,77,116,3,72,37,107,124,71,36,1,57,133,2,86,94,184,0,107,79,376,41,64,81,0,48,91,69,67,47,9,115,45],[0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,1,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,2,3,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,4,0,1,0,0,0,0,0,0,0,0,0,0,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,1,0,0,1,1,0,0,0,0,0,0,0,0,2,0,1,0,0,0,0,0,0,0,0,0,0,17,0,1,1,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,0,1,0,0,1,2,0,0,3,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,2,0,0,1,1,0,3,2,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,1,0,1,0,1,1,0,0,1,0,2,2,1,1,0,1,1,1,0,0,0,0,0,1,5,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,2,1,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,1,0,1,1,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,1,0,0,1,0,2,0,0,2,0,0,0,0,0,0,0,3,6,0,0,2,0,1,0,0,2,2,0,0,0,0,0,0,0,1,0,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,2,0,5,0,1,0,3,2,0,0,2,5,3,0,1,0,3,0,2,0,3,0,7,0,0,0,4,5,6,0,1,0,0,0,3,0,4,2,0,3,0,0,2,1,0,2,11,1,4,0,3,0,1,2,1,2,1,2,0,0,1,1,1,0,0,0,0,1,0,0,0,2,0,3,0,4,0,0,2,0,0,5,0,2,1,0,5,0],[29,8,1,1,8,14,30,1,1,5,7,3,7,8,3,13,7,4,36,1,36,2,0,0,6,27,28,0,14,24,9,4,24,25,15,0,2,21,16,40,8,3,42,14,18,13,6,0,52,88,100,40,46,4,36,6,12,10,3,3,230,46,26,38,1,7,4,10,5,14,2,1,39,15,92,81,37,7,270,3,31,25,14,1,298,292,17,26,1,4,70,0,53,2,60,2,0,0,28,8,29,1,6,0,0,4,4,4,13,53,0,4,4,0,0,1,5,2,1,0,6,3,6,2,4,2,4,2,0,2,4,0,9,4,2,2,3,6,4,2,0,2,2,1,2,85,28,8,0,6,0,0,6,0,1,4,2,5,2,1,2,0,0,2,0,10,2,0,43,1,12,30,28,1,17,3,1,0,0,0,26,877,6,36,8,0,2,0,0,2,10,0,136,177,131,104,156,239,659,268,462,166,136,154,27,170,104,206,115,46,176,274,597,150,85,150,140,62,103,81,3,161,38,254,94,286,173,145,70,127,98,171,5,117,140,120,79,208,134,263,367,318,182,230,440,403,261,279,25,161,106,175,324,407,278,428,345,567,210,325,56,39,55,109,212,211,254,312,167,174,150,206,61,80,155,64,122,165,202,152,296,217,197,183,175,53,61,159,11,216,48,143,274,215,274,297,205,192,70,135,238,183,511,215,218,427,271,304,227,136,142,142,185,6,301,101,303,263,322,201,235,99,423,8,323,66,208,44,164,129,260,43,1,46,62,133,116,136,135,143,52,362,177,213,104,81,148,109,85,262,92,97,78,65,81,130,128,55,105,162,183,216,155,268,110,195,299,109,101,429,224,68,122,412,323,41,1,118,178,77,46,35,73,538,175,114,179,76,2,81,66,73,685,90,222,294,223,144,206,38,4,194,99,148,169,32,291,192,85,172,100,27,2,199,91,108,364,245,735,143,0,448,76,163,0,75,231,128,704,547,1026,288,440,299,300,135,0,113,216,52,992,141,478,292,275,6,209,80,1,158,221,58,78,68,165,27,0,50,0,1,58,0,93,4,13,0,52,0,14,0,42,79,25,2,20,56,67,0,93,2,64,17,81,0,149,0,90,0,8,0,33,70,47,74,22,0,50,57,28,30,41,21,73,64,11,33,109,22,1,110,184,130,55,25,40,0,79,83,4,16,12,63,0,14,6,60,14,48,15,2,23,29,2,31,35,147,1,24,9,174,6,52,44,0,32,32,60,80,23,8,74,26],[26,2,0,1,2,7,0,0,0,5,2,0,14,21,1,7,3,2,18,0,37,4,0,0,5,35,8,4,11,65,0,8,24,33,5,0,61,11,10,20,4,4,12,12,8,10,9,0,84,93,165,10,26,20,45,10,10,1,4,0,415,73,11,35,0,11,8,2,4,6,1,0,40,32,9,38,7,4,131,3,36,4,4,0,171,598,4,28,0,0,26,0,25,0,17,0,0,1,19,64,14,2,0,0,0,3,3,0,10,41,0,10,0,1,8,3,0,2,3,0,0,26,1,0,5,11,1,1,2,1,4,1,30,14,7,9,3,1,0,3,7,2,2,0,0,39,17,1,1,1,1,1,7,4,4,3,0,1,6,27,0,5,1,1,2,1,0,0,7,0,16,21,10,3,3,3,9,2,3,0,7,379,1,30,25,0,7,2,0,0,6,0,120,159,59,33,80,89,4,124,177,81,65,60,27,91,71,120,46,40,90,102,221,73,59,90,71,66,74,43,2,94,19,157,33,118,66,60,27,52,44,91,4,42,92,61,25,126,50,178,206,175,105,122,187,170,114,169,9,113,60,74,151,297,181,191,206,325,155,150,47,37,40,43,127,114,162,202,89,63,130,120,56,56,111,57,61,87,136,93,241,98,170,76,112,28,50,133,6,140,49,105,95,102,108,112,91,82,18,64,78,65,218,73,74,164,103,122,84,58,47,46,67,7,92,1,116,92,153,122,1,53,144,0,155,71,101,60,68,61,1,19,0,26,26,87,70,82,122,66,11,225,77,76,68,33,76,79,48,109,40,79,70,33,51,56,78,19,44,101,75,78,43,115,32,118,147,51,45,216,126,63,56,233,152,23,0,62,88,33,20,35,45,236,89,69,83,49,0,30,48,23,359,59,111,174,133,96,199,36,0,146,75,95,95,21,171,129,44,91,80,25,0,124,67,46,146,109,391,42,2,292,33,93,0,27,87,44,326,263,344,165,189,133,118,63,0,41,103,22,503,76,168,124,140,6,86,51,0,61,91,36,73,41,88,16,0,0,0,0,62,0,73,11,10,0,114,0,34,0,28,99,80,2,45,156,140,0,58,1,145,12,111,0,71,0,242,0,50,0,94,118,103,65,49,0,42,143,71,80,109,39,43,130,38,81,186,27,0,161,324,108,177,20,92,0,96,169,4,46,31,61,2,57,25,67,76,53,32,1,43,79,1,46,59,155,0,80,42,242,3,83,112,0,36,54,99,115,64,12,212,67],[6,2,0,1,1,3,0,0,0,2,0,0,8,6,2,0,0,2,4,0,14,2,0,0,6,8,0,0,0,8,0,1,6,5,3,0,49,6,3,2,2,2,8,0,4,0,0,0,39,32,1,12,15,6,0,4,2,0,2,1,88,23,0,14,0,4,2,0,2,8,1,1,30,2,7,2,6,0,67,2,1,2,0,0,51,92,0,0,0,2,14,0,13,0,8,0,3,0,23,34,22,0,0,0,4,0,0,0,4,12,0,8,0,0,4,0,2,6,2,0,0,10,1,0,0,8,4,0,0,0,4,0,19,10,0,12,0,0,0,0,4,0,2,0,2,18,17,0,3,4,0,0,2,0,2,2,3,4,6,24,0,0,2,2,0,0,0,0,20,0,6,24,7,0,4,0,4,1,0,0,2,371,18,12,14,0,4,2,1,0,3,0,134,108,65,37,144,175,1,149,167,64,72,90,24,118,55,116,75,53,79,125,304,93,50,103,80,76,118,38,0,85,19,79,59,125,64,101,43,51,35,102,2,55,67,96,42,101,84,179,151,248,123,124,152,136,94,160,12,59,52,87,162,318,173,274,190,340,122,120,44,23,27,53,97,104,246,250,70,70,87,144,39,54,108,32,47,104,184,118,195,111,181,44,80,24,61,95,2,132,19,61,129,72,141,180,149,120,22,51,56,109,165,63,85,131,96,223,89,57,71,62,97,6,96,71,102,84,191,65,0,103,129,0,209,43,65,37,125,113,2,47,0,30,11,40,59,51,131,46,15,142,34,128,69,38,63,55,49,85,40,50,16,35,13,80,42,25,33,102,174,36,30,130,22,88,134,43,44,151,90,80,43,321,210,58,0,32,46,36,22,41,39,382,181,66,65,38,1,42,12,38,266,16,107,134,73,81,72,32,2,102,43,92,76,20,161,129,36,79,40,16,0,69,43,102,182,160,606,42,2,341,27,29,0,32,116,91,647,273,193,179,200,150,138,59,0,133,98,16,427,79,205,223,110,4,50,98,1,87,47,65,83,56,130,19,0,2,0,0,24,0,65,12,50,0,105,0,20,0,26,72,47,0,54,170,126,0,58,0,103,10,77,0,24,0,199,2,50,0,112,118,121,35,38,0,38,118,65,80,85,30,30,122,37,82,158,24,0,170,317,92,156,26,81,0,68,135,4,64,26,38,2,50,28,46,46,38,20,2,41,62,0,25,66,86,0,76,20,94,2,90,96,0,26,70,64,107,40,2,186,53],[204,3,0,0,13,8,0,0,0,9,0,2,32,38,3,1,9,3,49,3,10,15,1,1,6,63,12,7,33,75,0,13,27,15,39,0,76,16,7,48,9,15,47,45,9,13,18,2,193,143,335,40,48,15,100,78,16,20,10,0,313,81,42,76,0,12,31,19,8,6,0,0,15,57,9,34,7,14,108,2,55,4,3,0,76,216,4,12,0,1,37,0,14,1,6,1,9,2,53,55,11,3,0,0,3,1,3,4,6,67,0,10,6,1,18,0,0,0,4,1,0,25,12,0,4,5,19,6,2,3,0,1,16,0,25,0,1,0,0,1,0,0,0,0,0,67,31,12,0,23,4,0,49,0,6,4,0,18,22,38,0,2,3,3,0,3,0,0,10,1,0,11,10,0,1,3,0,0,0,0,5,165,3,0,2,0,1,1,0,2,1,0,343,134,131,47,232,68,1,263,124,74,168,115,108,168,116,147,95,118,98,154,126,134,91,134,102,197,194,118,7,138,52,203,81,55,49,48,15,33,52,54,0,28,191,36,39,250,91,179,226,228,85,205,327,192,101,256,12,179,94,149,233,251,170,218,316,254,184,169,29,119,85,57,169,136,158,305,91,68,163,258,105,81,165,100,93,126,310,250,446,235,262,173,100,49,110,175,10,216,83,190,69,98,107,77,78,64,7,44,76,80,141,52,68,81,59,68,60,36,36,24,47,0,47,35,73,92,81,78,1,165,102,0,209,66,131,78,170,59,0,62,0,35,76,121,105,104,98,102,10,227,121,185,34,101,125,131,100,102,42,141,81,94,85,165,129,40,54,133,54,59,27,75,24,47,124,29,53,151,116,65,76,377,233,44,0,103,112,99,21,181,97,247,203,99,75,53,0,37,131,52,234,34,151,160,139,77,164,32,0,302,92,188,104,24,156,213,64,96,193,60,0,149,128,126,150,174,231,48,10,294,92,101,0,24,66,39,201,144,132,102,133,100,83,22,0,41,58,15,177,33,159,93,77,3,30,19,0,73,64,151,95,130,163,9,0,1,0,0,24,0,54,21,18,0,55,0,22,0,18,42,39,0,29,28,64,0,36,0,82,17,37,0,48,0,82,0,25,0,15,34,20,21,4,0,3,34,12,7,12,4,17,34,33,26,108,37,0,111,89,57,91,17,47,1,45,96,0,57,24,47,0,25,10,46,36,15,12,1,18,43,0,21,40,54,0,67,44,191,13,30,31,0,9,18,13,27,26,3,47,18],[1176,53,0,5,83,68,1,0,0,39,16,6,45,48,15,50,24,58,267,21,67,63,6,0,79,501,65,4,35,166,7,72,204,300,275,0,132,23,47,60,32,18,39,56,21,5,107,0,227,116,196,89,79,15,130,272,40,30,35,0,202,169,39,115,5,12,184,17,17,14,2,0,78,109,25,58,7,65,548,2,189,55,14,0,135,300,20,102,0,3,110,0,56,0,95,1,44,0,458,602,452,4,1,2,16,33,26,35,274,291,3,95,12,22,111,53,18,38,51,1,25,465,28,7,234,7,51,60,36,11,85,19,229,253,113,184,1,29,5,2,84,5,27,4,25,455,758,51,6,24,79,34,283,63,35,56,4,46,147,442,5,58,12,42,27,21,8,4,72,3,2,69,25,1,13,6,44,6,10,0,3,1416,18,95,282,3,20,41,0,2,18,0,2778,1531,1205,914,2233,810,80,3109,1411,1251,1627,1290,1181,2164,1330,1401,850,1089,919,1472,1270,1677,654,1577,1301,1723,2169,1284,92,1554,741,2349,889,749,517,511,259,379,430,749,17,374,1418,473,296,1837,943,1924,2242,1881,1399,1821,2637,1914,1649,3509,111,2274,1046,1394,2853,3083,1667,2511,3097,3198,2443,2085,678,911,948,591,1572,1769,1891,2720,1236,1085,1694,3216,1460,958,2282,962,1372,1271,3272,2936,3855,2056,2427,2163,1488,632,1098,2029,338,2105,1204,1378,982,1062,1218,979,688,724,141,559,730,757,1600,555,712,1114,922,983,586,560,457,388,648,28,777,366,975,715,1051,739,16,2165,1008,2,2598,567,1836,836,2448,582,20,1190,2,765,1023,1308,953,1118,1289,1334,180,2897,1255,1393,533,992,1333,1244,1162,1041,732,1413,784,1148,1296,1471,1020,569,771,1379,748,568,262,679,252,673,2062,429,319,2330,1469,584,1195,3181,2059,803,2,1524,1636,1329,195,1504,935,3211,1956,1125,1493,923,1,892,1640,787,2742,823,2034,1454,1776,1390,2166,823,0,2194,1164,2284,1708,418,1828,1626,819,1237,1908,853,1,2119,1392,1347,2448,1809,2091,851,157,2692,1047,1550,0,398,928,522,2155,1448,1723,1102,1351,966,1038,527,1,555,811,325,2796,556,1581,1140,1316,13,709,391,1,629,918,1592,759,1001,1476,205,0,0,0,1,83,0,3,77,454,2,172,0,136,0,74,260,201,3,130,207,314,3,142,1,8,73,375,0,171,0,614,1,200,0,176,1,115,7,79,0,104,2,192,102,110,33,2,119,94,89,2,0,1,26,798,208,496,81,403,31,280,426,25,215,155,201,17,181,93,3,245,0,263,1,112,355,5,151,0,302,1,167,148,619,131,95,104,0,39,139,1,153,162,14,1,49],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,1,0,0,1,0,113,0,0,3,0,0,13,4,1,0,1,106,0,1,0,0,0,0,9,0,5,0,36,0,7,0,0,0,1,0,0,0,1,0,1,0,11,2,0,0,5,0,0,0,1,1,0,3,0,12,0,0,0,0,11,0,0,1,0,24,1,4,0,0,0,0,0,6,0,0,86,0,2,37,1,0,0,5,0,0,0,0,0,1043,1,0,0,0,0,0,0,1,0,0,1,318,208,142,325,139,69,469,489,117,229,119,54,290,189,154,69,140,241,158,613,250,59,226,197,184,163,90,6,114,69,406,109,172,98,158,35,55,179,118,6,62,127,97,49,202,83,196,480,573,183,168,620,517,437,574,86,365,180,106,553,794,210,321,325,454,233,141,111,143,116,164,282,343,406,298,105,245,297,178,90,146,283,59,189,129,450,169,361,195,314,174,225,87,164,176,28,432,134,266,148,110,169,156,138,114,37,94,247,260,584,212,280,447,162,241,142,247,198,165,106,14,295,60,354,266,266,298,31,106,180,1,452,127,151,113,91,234,15,106,0,51,96,257,190,242,108,190,179,606,251,117,67,128,270,192,181,322,122,124,174,69,207,216,197,0,181,0,171,230,173,126,97,123,192,126,223,312,251,82,84,581,179,50,1,138,277,132,364,132,116,308,156,197,224,128,1,151,81,113,691,161,174,474,377,252,4,90,0,139,152,169,246,24,462,187,107,298,100,92,1,323,73,90,256,348,923,208,3,600,100,208,0,73,277,184,912,624,898,408,254,196,306,172,0,92,268,122,1060,216,541,452,191,7,317,57,0,100,116,87,73,67,274,38,0,1,0,0,109,0,182,33,96,0,165,0,89,0,69,169,83,0,87,252,156,0,96,0,206,28,137,0,171,0,277,0,92,0,115,121,228,131,94,0,83,147,175,85,126,62,97,183,78,86,230,82,2,318,522,209,262,58,116,5,193,132,67,72,35,128,3,104,63,84,87,88,99,4,78,120,1,59,104,266,0,138,104,310,7,127,106,0,128,108,188,267,110,14,187,60],[80,12,0,2,11,39,3,0,0,11,6,3,22,18,9,10,16,18,66,8,74,14,1,1,183,90,26,7,29,131,1,20,75,46,28,0,154,18,23,65,27,26,44,35,34,8,20,0,188,182,343,37,64,29,85,49,33,9,15,0,418,148,31,97,2,20,38,19,17,13,4,0,51,60,58,87,12,24,293,4,78,15,17,0,173,593,13,56,0,1,67,0,39,0,63,0,7,1,73,16,4,8,1,0,5,3,0,1,3,91,0,1,5,1,1,0,6,2,7,0,59,2,1,0,0,2,3,0,12,2,0,0,4,2,32,0,0,0,3,1,0,0,0,0,3,8,2,6,0,13,2,1,13,1,0,0,0,23,3,12,0,3,0,0,1,12,7,0,38,0,0,68,43,0,18,11,0,0,2,0,0,729,2,0,2,0,0,1,0,0,0,0,276,244,177,129,215,256,119,371,441,215,210,167,108,221,154,224,105,127,170,308,501,211,103,184,165,176,281,137,9,215,79,279,102,214,138,116,75,101,97,184,6,114,224,135,99,363,157,342,355,372,356,273,533,411,269,462,218,274,159,191,418,520,310,403,484,637,410,257,106,83,102,155,313,297,365,473,202,191,266,378,199,126,272,141,142,242,420,376,586,327,294,275,296,74,133,318,29,321,118,228,233,209,281,308,239,238,59,161,186,221,446,194,153,378,285,346,201,146,150,96,170,12,258,98,242,222,258,215,22,195,291,0,477,129,343,119,231,173,23,108,0,109,81,196,183,156,155,147,259,472,183,186,175,125,213,159,140,228,103,198,141,117,157,188,156,79,95,238,220,162,135,207,92,186,331,79,115,560,274,105,145,526,348,111,0,255,295,154,363,169,122,707,268,178,235,117,1,152,202,92,750,169,339,369,363,209,409,112,0,305,190,306,212,48,398,271,106,269,260,97,0,345,166,218,483,317,714,180,5,533,108,198,1,77,252,177,761,559,704,364,402,265,272,167,0,169,272,107,887,161,509,349,372,3,224,114,2,163,279,142,128,106,224,58,0,7,1,1,45,0,109,30,80,0,79,0,33,0,30,125,50,0,61,157,91,0,62,0,159,26,98,1,113,0,174,0,54,0,55,64,123,68,45,0,42,116,117,43,110,30,52,119,44,59,166,54,1,233,341,111,145,31,86,1,95,116,55,46,25,89,10,66,45,63,52,75,92,5,68,98,1,33,59,173,1,82,60,257,8,92,70,1,54,53,127,198,79,12,179,40],[13,8,0,0,2,14,0,0,0,2,2,0,12,16,0,5,3,4,9,1,15,3,0,0,4,21,7,2,11,19,4,11,22,13,4,2,40,12,6,12,3,8,15,2,12,3,3,0,30,36,128,5,12,9,16,4,1,6,5,0,159,33,6,11,0,2,7,2,1,5,1,0,24,8,5,26,5,3,109,3,32,7,2,0,70,288,14,5,0,0,6,0,10,0,9,0,1,2,36,34,10,1,0,0,5,2,3,0,7,40,0,17,0,0,3,0,2,2,1,1,4,19,0,0,8,5,1,3,1,3,1,1,30,13,3,11,0,0,1,1,3,0,1,0,1,24,30,3,3,3,2,3,13,3,0,0,0,10,0,35,0,3,1,1,3,8,1,0,38,1,4,26,8,4,6,1,3,1,1,0,3,414,0,14,21,0,4,2,0,2,2,0,1,131,66,50,88,49,1,137,228,40,85,32,16,88,71,47,16,32,85,47,248,63,22,79,64,49,44,25,3,45,24,119,46,41,26,68,12,20,46,37,5,29,44,25,15,59,31,102,158,165,75,47,198,155,127,151,8,126,55,27,209,307,54,83,83,156,90,49,31,36,45,60,125,97,136,99,26,65,111,73,31,46,97,32,83,50,139,80,98,55,126,49,122,25,50,67,7,111,36,86,48,44,67,65,63,36,7,20,70,106,194,71,73,134,48,81,37,46,58,53,45,0,87,10,91,79,66,83,0,26,77,0,157,88,53,37,36,64,0,35,0,7,27,83,78,64,66,45,9,184,91,35,30,30,89,71,52,112,36,35,56,23,52,84,81,0,52,0,44,78,36,37,36,42,56,38,54,134,102,62,22,195,70,13,0,62,75,48,11,35,38,147,45,63,101,61,0,51,26,46,335,27,37,151,146,72,3,34,1,56,67,59,105,9,171,76,34,99,30,37,0,112,27,29,105,99,276,50,1,193,34,83,0,28,67,65,374,257,265,147,58,69,127,64,0,30,119,52,399,59,226,137,69,1,90,31,0,37,59,19,29,21,88,19,0,1,0,0,38,0,62,20,36,0,54,0,30,0,22,81,41,0,48,100,64,0,22,1,82,12,51,0,64,0,103,0,51,0,41,39,86,40,39,0,39,65,61,29,74,12,59,78,23,45,74,38,0,120,237,84,87,15,92,0,75,57,7,14,17,46,0,31,32,34,22,37,41,6,44,46,3,25,33,79,0,57,31,145,2,54,53,0,26,40,77,119,46,9,94,16],[421,19,3,2,39,29,0,1,1,6,5,8,34,45,3,30,21,20,87,0,33,21,2,1,8,80,33,0,20,155,0,7,87,31,53,1,146,23,31,24,23,11,83,16,19,14,22,1,203,126,417,107,58,14,160,105,27,7,46,1,360,229,47,134,0,9,54,35,10,13,5,1,47,49,14,47,11,30,161,9,36,6,16,1,110,460,13,62,3,0,35,1,16,3,21,2,38,0,137,18,16,0,0,6,7,9,1,3,6,119,1,0,11,12,5,1,21,0,8,2,10,2,6,8,0,1,59,3,14,2,0,1,11,2,23,4,0,7,10,4,0,0,0,0,11,30,3,67,32,11,10,5,98,9,5,3,11,27,27,35,2,23,0,18,0,7,12,0,36,3,2,73,21,0,6,8,3,0,2,0,4,392,5,2,0,0,0,3,0,3,0,2,343,246,156,143,390,158,3,486,256,271,320,267,110,424,234,279,108,197,167,331,226,358,140,310,238,264,277,157,4,270,126,391,166,117,84,82,49,53,112,81,3,67,292,72,32,279,157,245,472,433,193,200,516,378,260,624,4,445,210,281,499,583,333,528,640,422,361,314,149,136,176,100,360,316,482,408,198,288,357,464,176,220,397,210,282,232,628,457,478,302,491,343,341,75,210,182,49,487,218,278,128,109,175,178,109,113,12,76,98,98,261,125,140,271,143,197,105,123,89,72,73,6,109,52,278,126,213,123,1,288,213,0,641,102,281,169,470,132,0,227,3,90,188,292,117,188,187,194,34,345,256,192,68,235,175,177,264,183,117,283,119,202,300,344,218,94,173,191,158,156,38,129,60,96,255,91,111,439,330,103,260,830,280,103,1,212,384,245,46,217,177,519,318,372,235,221,3,176,285,179,454,131,376,211,279,264,196,152,1,284,238,376,301,70,315,350,201,324,451,167,0,458,250,247,488,367,489,194,16,364,170,304,1,96,140,115,345,363,284,243,267,271,216,103,0,61,205,38,497,93,427,173,218,3,129,68,0,130,203,270,117,168,294,24,0,2,0,2,136,0,251,78,250,0,177,2,170,0,108,222,56,2,158,171,135,0,79,0,329,48,152,0,179,0,304,0,118,0,99,79,97,66,22,0,30,75,112,57,89,43,66,91,123,103,242,92,2,529,521,194,177,58,144,0,147,203,10,102,46,177,18,142,70,135,123,105,109,6,80,150,8,102,153,222,2,191,101,381,34,68,71,0,33,90,115,120,53,6,134,42],[50,3,0,2,0,16,13,0,0,4,8,2,20,13,1,3,6,4,21,1,18,13,1,0,7,24,16,3,12,59,0,9,21,36,6,0,55,13,10,33,18,7,43,15,9,8,11,0,56,78,105,17,31,11,36,7,4,4,7,0,228,59,11,65,1,9,10,4,3,11,0,0,36,41,32,52,6,27,148,5,60,13,17,0,121,331,8,44,0,1,52,0,11,0,21,0,0,1,28,81,17,2,5,0,6,2,9,1,13,48,0,4,0,0,8,1,0,2,4,0,3,43,4,0,2,8,3,3,1,2,0,2,45,25,10,38,2,7,0,2,10,0,0,1,0,53,42,2,4,2,6,3,15,4,6,2,0,6,10,60,0,5,1,2,4,4,5,1,34,3,36,21,36,8,10,5,15,2,1,0,12,404,8,63,41,3,7,10,0,3,7,0,75,71,49,43,49,142,258,115,241,48,48,62,23,61,46,81,28,28,74,109,231,51,46,56,45,41,61,34,1,69,13,100,40,94,71,58,34,50,52,90,2,57,59,60,35,124,51,92,130,147,133,101,202,114,96,128,6,61,42,75,151,246,146,166,125,313,121,110,21,29,30,48,117,118,104,173,67,59,99,75,38,49,63,46,44,63,97,65,187,104,90,69,71,18,24,126,2,79,25,71,138,77,98,137,95,73,46,53,103,91,204,84,85,156,132,137,108,59,78,46,63,3,119,44,128,108,168,96,52,33,181,0,141,32,85,29,62,78,77,19,0,23,17,52,72,64,47,66,12,145,70,84,65,32,61,51,39,100,31,50,48,24,46,45,47,36,35,74,119,81,75,105,45,103,107,48,41,198,90,30,39,197,120,12,1,69,86,32,15,23,38,243,78,57,77,30,0,38,31,23,312,57,95,149,132,70,156,22,0,83,54,67,53,12,149,72,30,97,68,10,0,85,54,56,162,95,283,35,1,205,23,52,1,27,77,76,339,236,354,125,172,133,118,53,0,69,74,29,425,55,168,146,166,1,77,48,0,65,103,37,25,36,75,20,0,47,0,0,54,0,64,7,39,0,49,1,25,0,24,74,33,0,31,84,59,0,38,1,72,8,59,0,72,0,97,0,31,0,37,55,85,50,37,0,42,72,72,29,77,23,41,71,30,22,79,31,1,113,232,75,102,31,35,0,55,45,8,28,20,43,0,41,27,40,30,35,39,1,24,47,2,18,31,117,0,56,18,166,1,42,51,0,49,57,93,127,62,10,125,28],[211,2,0,4,2,28,0,4,2,25,8,1,14,31,3,16,15,12,58,3,55,10,7,0,77,46,27,1,27,122,3,15,35,101,28,1,56,33,44,34,20,13,69,32,5,15,26,4,209,168,170,49,41,16,103,44,24,6,31,0,303,115,32,134,0,7,32,20,12,19,4,2,57,46,48,47,18,24,93,11,22,8,18,4,123,492,16,41,2,9,44,0,17,2,40,1,8,0,97,4,2,6,6,0,8,6,0,0,1,157,1,1,6,5,1,1,17,2,19,3,26,6,1,0,1,0,1,1,6,2,2,1,2,3,48,3,1,1,8,0,0,1,0,1,2,1,1,16,0,6,1,6,11,1,0,1,4,15,1,1,0,0,0,1,1,9,0,0,17,3,3,62,24,0,18,4,2,0,0,0,2,656,2,3,2,0,1,0,0,2,0,0,309,222,203,118,261,171,101,309,298,181,248,198,131,237,166,226,136,131,112,260,364,238,167,171,166,214,278,129,3,157,53,254,114,142,105,111,67,81,103,178,3,106,192,141,54,232,154,295,372,277,237,262,306,340,267,520,151,349,148,188,363,537,248,371,370,490,295,315,125,137,155,92,220,317,265,357,206,182,234,461,222,159,330,186,162,214,516,346,475,265,343,278,180,82,159,307,31,352,178,196,171,167,254,216,152,147,39,130,131,163,395,155,192,310,247,225,149,120,104,86,168,11,216,81,195,181,270,155,38,278,237,0,380,133,216,111,230,123,31,126,1,86,126,216,160,163,160,170,193,479,186,157,130,143,221,192,168,228,90,172,119,127,248,174,174,77,107,234,148,133,90,175,54,161,299,94,101,384,234,54,119,549,258,80,0,156,280,131,233,218,132,451,260,182,235,147,4,128,202,118,493,168,209,311,347,224,276,109,0,222,154,285,274,66,325,218,137,282,184,140,2,369,182,192,409,209,450,144,2,402,116,109,2,70,189,113,482,378,548,265,294,189,191,96,2,171,217,76,726,123,417,276,280,0,153,60,0,167,203,187,108,168,244,30,0,3,0,0,30,0,104,29,50,0,81,0,55,2,23,86,48,0,64,87,66,0,30,0,117,38,99,0,82,0,109,0,56,0,33,91,102,58,35,0,51,64,94,46,49,25,46,78,42,40,172,59,0,190,240,107,145,49,107,0,110,119,50,66,50,67,2,61,19,37,88,54,72,4,52,73,5,39,38,141,2,76,74,164,2,60,41,0,48,54,89,147,67,22,111,30],[120,12,0,5,44,14,0,0,0,9,3,0,24,24,12,27,28,4,29,3,9,18,4,0,4,103,19,6,32,44,0,10,35,16,26,0,195,40,52,23,15,20,0,2,28,18,23,0,201,98,140,8,14,16,53,62,20,18,36,2,297,85,20,68,4,0,41,12,3,8,1,1,33,44,15,22,4,13,205,6,22,2,11,1,110,461,1,30,1,2,31,0,33,0,34,1,33,1,95,107,103,0,0,2,7,4,7,4,34,82,0,22,4,7,24,8,4,36,15,3,4,68,13,0,44,27,50,18,6,2,9,4,127,106,21,10,1,6,4,3,18,4,4,8,16,63,72,21,2,21,24,12,103,27,4,25,12,34,65,98,4,6,2,10,11,4,4,2,51,0,18,16,9,0,2,3,4,4,6,0,25,293,4,36,52,0,6,9,0,1,6,0,105,66,113,150,137,125,5,431,217,175,157,64,116,122,125,24,49,47,126,158,85,104,54,116,132,1,77,99,4,132,44,1,48,61,64,24,23,18,30,30,0,25,243,31,54,115,68,194,85,106,75,0,153,270,80,328,0,7,68,97,182,161,178,175,19,364,144,220,60,58,81,91,172,132,186,24,84,64,79,157,2,44,0,68,180,161,242,144,480,115,162,353,220,56,79,245,8,154,24,81,30,96,3,120,83,106,14,84,47,45,87,20,147,78,168,0,5,1,61,21,34,8,113,58,90,101,2,52,0,249,129,0,377,75,102,36,276,0,0,71,1,79,156,62,98,164,72,194,0,165,51,54,96,127,131,110,78,0,45,80,153,161,86,1,127,35,18,97,35,42,18,4,46,64,224,22,19,229,195,54,50,258,186,134,0,76,191,186,4,105,135,463,351,99,238,98,0,1,120,99,264,44,175,176,180,90,159,3,1,177,191,1,9,44,77,82,75,0,256,18,3,8,217,245,283,171,235,72,4,4,91,264,1,13,67,77,130,231,203,169,149,121,92,109,0,2,127,37,149,48,127,3,139,2,141,38,0,47,0,2,34,75,119,0,0,2,0,1,41,0,160,42,131,0,83,0,71,0,42,123,69,0,63,106,87,0,56,2,183,48,100,0,108,0,164,0,45,0,46,43,78,46,40,0,21,65,60,38,52,37,40,51,57,39,164,64,0,270,220,120,139,39,89,2,134,94,4,56,54,100,0,55,39,75,63,56,53,2,39,68,5,59,61,114,0,92,73,199,21,44,48,0,22,35,50,88,36,6,59,29],[68,4,3,5,6,18,2,2,2,10,4,4,17,12,8,12,12,5,48,5,12,6,1,2,115,68,14,4,26,53,2,9,36,63,18,0,133,18,20,56,10,12,9,0,30,6,14,0,134,110,194,12,23,14,57,28,24,13,13,1,377,108,18,54,0,3,30,15,8,14,2,0,59,54,28,41,10,15,213,15,49,0,20,1,165,708,8,40,2,4,44,0,41,1,42,2,8,2,62,59,31,0,2,0,2,4,0,6,2,76,0,14,1,2,8,8,4,0,6,3,24,45,0,1,14,4,8,5,2,3,2,0,48,15,37,23,2,8,6,2,12,4,0,0,2,85,37,10,5,10,2,0,28,6,5,8,0,17,2,39,0,2,2,0,4,2,2,0,43,2,35,35,21,2,12,10,3,2,0,3,9,705,4,5,21,2,6,4,0,0,12,0,78,51,43,26,68,65,54,84,102,47,29,55,19,70,58,29,36,22,65,86,96,31,30,51,35,30,54,29,2,51,16,57,20,59,60,28,13,21,31,42,4,32,81,30,26,90,30,60,122,80,87,71,137,111,77,146,30,56,28,66,108,162,118,108,70,218,112,80,17,21,19,28,96,46,94,125,34,43,66,181,28,37,68,30,46,47,94,76,161,86,97,77,86,12,8,124,6,68,39,68,70,50,44,60,70,47,12,59,62,70,108,36,40,64,93,63,45,28,39,26,28,0,79,18,71,63,60,60,6,40,80,0,119,26,73,21,74,33,6,32,2,26,12,58,50,66,34,72,67,137,54,52,55,42,62,43,38,51,24,37,40,28,40,43,59,24,21,60,67,44,24,51,35,101,65,31,31,148,74,29,32,140,99,20,0,66,49,46,99,34,62,198,62,43,79,30,2,18,48,35,313,63,97,132,140,54,122,20,4,53,43,29,32,16,163,49,38,42,75,16,0,54,31,36,98,75,203,34,4,74,22,51,0,14,58,58,155,140,175,90,136,43,60,31,0,23,53,23,248,25,122,42,112,6,56,43,1,20,26,26,23,24,40,14,0,2,0,0,68,0,151,19,116,0,84,0,49,2,34,101,44,2,74,211,74,0,56,0,208,17,107,0,116,0,176,0,65,0,72,88,92,86,51,0,61,86,114,52,81,24,82,143,39,44,158,53,0,249,407,130,194,34,75,0,102,104,37,52,30,116,0,83,46,59,72,86,52,8,64,92,6,50,69,202,0,84,73,303,6,90,74,0,75,66,120,161,94,12,172,28],[695,38,4,19,56,60,1,4,0,55,2,6,75,151,47,54,43,22,118,23,203,50,10,0,44,231,78,28,129,373,7,48,198,142,143,3,488,42,116,111,61,50,191,52,95,29,78,0,784,486,1085,188,268,84,325,274,129,84,78,0,969,496,71,303,12,34,145,86,15,30,1,0,85,92,46,160,28,54,529,15,147,29,36,0,342,912,37,65,0,3,78,0,55,0,80,0,31,3,355,613,548,12,1,8,9,12,16,33,176,281,6,68,12,11,134,59,18,33,34,16,28,565,12,13,140,127,54,44,36,15,36,10,271,152,111,95,4,44,24,19,80,12,8,5,15,361,391,65,47,33,61,68,191,65,38,31,5,46,91,330,7,53,15,56,22,19,4,0,74,11,36,119,58,10,26,10,22,8,11,0,11,1036,19,118,157,5,15,16,1,2,15,1,1448,758,633,411,1137,417,11,1487,646,657,890,618,623,988,618,689,431,544,523,687,561,811,335,802,654,800,1122,588,48,760,379,1051,427,345,298,232,91,176,186,371,8,158,889,226,135,936,488,965,1134,1066,781,859,1215,1120,802,1747,47,944,524,721,1258,1570,872,1378,1528,1480,1194,1067,366,449,473,322,834,810,839,1213,522,609,998,1182,630,447,1096,553,620,672,1533,1314,1650,1008,1184,966,732,308,549,753,142,1171,634,796,513,530,508,455,357,359,76,268,333,322,764,284,454,552,423,559,278,218,294,182,352,14,412,176,465,375,451,394,3,1031,527,1,1649,445,1045,414,1241,349,0,622,1,387,495,685,562,454,681,554,86,1310,728,689,276,532,661,590,592,686,348,731,425,466,690,733,570,304,349,757,336,268,184,395,156,303,1008,211,202,1196,899,305,619,1793,1221,368,0,688,918,706,102,626,546,1583,1015,626,770,455,1,519,826,443,1412,450,1046,867,891,677,1038,350,2,1193,716,1231,859,211,873,938,414,676,1055,437,0,1299,807,727,1393,932,1187,462,62,1586,524,790,0,231,471,336,1347,831,798,695,765,510,624,242,2,263,412,139,1407,265,849,539,613,6,411,206,0,322,378,851,378,504,727,75,0,3,0,0,213,1,456,122,336,1,268,1,189,0,136,338,177,1,234,324,293,0,210,1,449,124,303,1,298,0,494,1,172,0,144,174,198,144,85,0,95,173,171,102,111,53,125,191,163,162,538,206,3,926,664,318,473,98,333,18,401,306,21,207,139,259,15,221,149,185,213,170,182,34,175,240,11,133,199,490,1,348,190,506,99,149,120,1,77,134,188,228,123,32,211,76],[39,10,1,2,4,39,22,1,1,8,5,3,28,37,6,5,3,10,45,2,14,4,1,0,8,76,30,4,10,118,1,7,39,66,22,0,75,28,3,60,8,6,29,20,18,6,18,0,91,138,215,26,44,22,70,8,15,10,9,2,434,96,14,53,4,6,10,14,12,20,5,0,58,79,81,72,22,21,270,9,102,26,22,1,243,680,28,57,1,2,71,2,30,1,35,1,3,0,50,102,32,6,19,1,5,9,12,4,21,97,2,4,0,0,9,6,0,4,9,3,4,57,2,5,18,8,0,3,0,0,5,4,73,29,9,24,1,4,0,2,6,0,7,0,1,86,69,14,4,2,4,0,22,10,5,2,2,10,14,86,0,8,4,7,15,6,4,0,44,12,83,64,42,5,16,19,25,11,4,0,25,538,5,86,39,0,14,10,0,0,10,1,180,158,98,76,177,161,555,249,472,121,95,135,29,123,121,209,53,47,151,192,480,120,61,165,103,52,130,79,2,108,33,186,59,206,133,84,55,124,126,217,6,91,187,116,89,273,133,190,332,374,256,171,316,271,195,261,14,173,108,142,276,510,272,308,289,623,230,255,90,79,69,130,228,202,218,354,177,127,218,179,113,72,143,48,134,156,209,189,408,214,204,179,166,46,56,209,0,178,69,148,187,212,237,206,207,189,71,122,191,136,357,179,172,361,271,308,169,157,102,92,138,16,196,110,207,200,353,188,90,92,254,1,317,126,272,102,126,194,169,58,1,77,53,179,113,121,95,116,15,347,112,174,176,57,124,106,81,164,57,109,122,77,70,143,162,61,69,176,210,185,179,233,86,151,385,110,76,528,296,59,96,422,323,59,0,160,201,73,31,78,101,636,250,175,165,93,0,124,97,106,642,147,283,365,321,173,327,101,0,251,133,202,238,50,383,212,79,151,143,53,2,208,132,130,429,248,612,164,0,439,54,163,2,92,259,182,743,556,936,354,403,304,281,162,2,147,245,120,1030,203,511,311,389,8,262,101,3,225,293,37,80,61,144,46,1,126,0,0,32,0,112,33,77,0,66,0,36,2,29,102,59,0,64,135,78,0,42,0,120,16,71,0,89,0,183,0,26,0,59,71,84,76,41,2,47,110,82,45,80,31,48,105,27,22,77,39,3,128,325,85,171,30,55,0,65,70,14,30,27,72,2,63,16,39,51,37,36,2,30,67,6,18,53,113,0,70,29,319,2,77,38,0,57,47,68,119,44,10,102,25],[34,7,1,2,2,23,0,1,1,8,1,4,7,24,0,2,1,5,23,2,22,0,0,0,6,60,8,12,9,40,0,12,12,30,10,0,60,5,13,30,8,3,18,11,11,0,9,3,60,82,183,12,22,6,26,28,6,5,0,2,393,68,8,50,2,3,8,6,17,12,2,1,56,11,14,64,8,8,163,3,56,8,3,3,163,569,7,64,0,0,49,1,30,3,19,2,3,1,26,110,39,0,0,1,14,2,3,0,16,33,1,14,2,0,8,2,3,4,2,2,2,80,0,0,25,5,0,2,0,4,7,6,37,30,11,27,1,0,1,2,15,2,2,1,0,77,43,4,2,8,1,5,39,6,4,6,0,1,12,58,0,5,0,1,0,5,4,2,29,10,18,38,15,0,15,5,0,2,8,0,14,581,10,63,46,0,8,4,0,0,11,2,92,145,69,56,108,139,0,154,223,64,61,75,12,54,73,85,37,26,65,126,276,75,58,67,52,42,99,47,0,76,14,165,29,97,84,71,22,47,53,48,2,68,81,69,60,154,45,146,168,147,189,87,191,193,164,196,4,98,59,58,168,343,147,193,207,322,149,111,38,52,26,42,150,136,156,258,81,82,95,99,80,57,109,41,68,80,139,120,220,122,119,111,84,36,34,109,4,119,40,107,111,88,129,141,127,118,20,82,103,141,256,80,101,219,119,155,102,76,59,49,77,4,94,79,183,128,171,105,0,53,190,4,179,83,147,59,108,127,0,35,1,48,21,89,56,58,125,78,18,181,76,85,113,41,63,51,40,128,31,88,52,50,57,98,50,26,45,110,75,162,38,81,49,125,186,73,60,275,168,65,82,302,185,29,0,101,147,65,12,55,67,299,131,95,130,43,2,59,76,45,379,75,138,183,166,107,246,13,2,154,76,83,100,46,170,121,46,150,104,14,2,154,85,90,181,120,459,100,0,227,38,124,0,35,138,79,522,403,426,154,221,243,150,69,0,74,197,48,595,88,254,180,186,4,123,68,1,95,149,45,56,38,82,16,0,2,0,0,60,0,95,16,67,0,65,0,48,0,37,106,50,2,26,200,84,0,39,0,123,6,82,0,121,0,134,0,65,0,50,59,111,68,39,0,34,95,150,43,77,33,56,132,33,70,128,30,1,144,368,97,199,20,80,2,74,59,4,31,29,75,1,65,26,47,39,26,50,2,35,79,5,39,42,132,0,80,32,299,4,95,77,2,34,48,96,133,58,16,126,38],[14,2,4,5,3,6,0,2,1,5,8,1,11,16,5,7,3,1,11,6,11,2,4,3,37,8,12,3,12,24,3,1,10,8,4,2,30,13,7,15,5,4,18,8,6,2,9,3,26,48,288,12,8,7,24,12,5,3,6,3,130,23,7,24,0,5,6,5,6,5,3,0,36,20,10,19,6,8,50,4,28,3,6,2,57,198,4,26,4,1,14,1,17,5,14,3,7,0,128,25,2,4,3,0,11,20,1,4,9,101,0,5,1,8,0,4,2,2,9,4,58,14,8,3,10,9,17,4,4,0,0,0,6,6,7,4,0,2,0,2,4,1,1,1,5,17,11,24,5,4,4,0,11,0,8,9,2,25,8,1,1,5,0,1,1,20,3,0,59,2,0,82,15,1,5,7,0,2,0,0,8,1273,3,1,17,1,1,1,3,2,12,1,429,297,216,83,158,383,131,514,401,281,246,137,119,286,113,161,115,100,157,381,424,35,128,168,211,172,162,157,6,176,83,68,94,188,258,198,90,154,99,415,16,191,166,150,102,467,189,300,511,584,425,223,321,407,457,480,316,57,49,311,95,861,417,614,586,970,70,385,110,82,45,122,378,85,93,321,212,136,336,386,220,127,448,100,131,242,446,229,434,318,179,386,318,107,128,198,6,368,122,75,415,233,226,512,192,323,78,121,296,407,664,301,256,332,417,506,461,148,165,149,226,19,385,156,318,397,238,296,0,136,496,2,561,111,240,189,130,313,21,86,1,179,106,250,206,183,161,129,211,321,247,318,169,84,287,135,151,239,135,234,118,150,108,177,164,89,126,307,361,320,167,157,178,371,561,101,166,459,367,46,213,810,325,104,3,268,367,70,263,197,181,445,241,188,259,191,4,31,177,127,595,63,259,307,547,155,570,83,2,246,212,184,333,69,374,386,156,204,284,77,3,232,228,132,632,236,1025,220,0,427,47,120,3,76,392,237,1215,916,1177,459,568,258,503,152,1,208,460,155,1543,189,580,539,601,2,403,118,1,86,392,65,135,125,259,63,0,2,0,0,144,0,183,43,214,0,180,0,111,0,116,216,129,8,142,375,212,0,161,0,255,33,187,4,207,2,306,0,129,0,91,197,213,143,118,0,110,241,253,135,193,70,172,260,52,87,234,107,4,374,579,183,362,62,102,2,170,180,104,101,52,141,2,75,72,99,99,124,96,13,94,167,6,90,143,287,1,153,95,321,2,215,143,0,133,111,214,347,135,25,277,103],[40,6,0,2,3,13,0,0,0,7,8,0,10,17,2,7,8,3,22,0,12,8,0,0,79,66,18,7,22,68,0,1,8,21,12,0,79,34,9,38,8,9,23,18,13,0,15,0,106,79,163,22,32,10,39,23,9,5,3,0,425,54,16,52,2,8,13,6,7,11,1,0,75,37,34,62,10,15,145,2,49,10,9,0,178,576,8,41,0,3,59,0,15,0,28,0,0,0,29,76,34,4,1,0,2,4,9,5,14,72,1,1,1,0,11,4,1,4,3,0,25,43,4,0,9,14,3,4,2,0,4,0,51,39,18,23,0,4,2,9,7,1,3,0,1,48,26,0,5,2,4,1,21,3,5,3,0,12,13,36,0,1,1,9,16,3,1,0,25,0,36,31,36,6,3,13,5,2,1,0,12,500,4,53,47,1,11,3,0,2,3,0,113,90,75,61,71,128,21,170,248,92,83,98,33,141,76,107,53,67,97,155,301,138,63,111,99,72,102,69,1,125,28,135,67,121,93,69,28,62,80,118,4,63,89,93,56,163,71,96,174,158,134,133,208,168,114,169,86,132,75,83,236,328,146,186,239,327,164,153,54,48,53,54,138,159,200,266,109,91,160,155,85,74,133,78,91,101,169,161,299,144,175,119,123,27,55,145,8,140,41,99,113,122,140,172,133,132,46,84,112,140,261,95,106,193,185,157,141,94,71,84,130,4,150,69,173,140,190,102,4,69,192,0,141,49,94,44,70,90,6,40,1,37,38,88,102,98,76,93,124,186,85,89,100,59,112,112,80,152,60,104,81,83,82,72,64,34,62,124,99,93,73,145,68,119,143,61,66,260,110,33,53,234,192,44,0,79,132,47,139,64,53,250,113,98,89,41,0,72,73,41,336,68,140,161,160,111,193,51,0,137,78,100,99,23,163,116,39,103,100,20,0,114,61,70,199,130,407,50,0,248,27,100,0,40,131,89,347,271,380,134,172,143,154,82,1,77,142,28,460,88,265,177,151,6,129,52,0,91,125,36,52,54,123,16,0,1,0,0,7,0,2,1,41,0,47,0,19,0,1,5,55,0,29,6,4,0,27,0,115,0,31,0,54,0,10,0,25,0,1,1,67,39,5,0,1,48,2,1,1,21,20,128,14,39,6,18,0,65,135,0,66,14,2,0,1,1,29,12,22,64,1,25,1,20,0,0,28,0,19,1,0,1,25,73,0,38,2,99,1,2,23,0,25,17,59,4,36,6,60,36],[41,4,2,1,2,19,9,0,1,6,3,0,23,33,5,2,6,4,10,0,28,7,0,1,4,40,23,2,0,60,0,6,34,7,4,0,59,25,15,11,12,0,27,15,8,4,11,1,60,80,134,22,14,6,35,12,4,8,9,0,355,76,8,44,0,15,10,6,10,8,0,0,91,59,44,54,10,14,191,4,75,19,18,0,171,401,2,41,0,2,37,0,22,1,45,0,0,0,40,4,0,0,8,0,10,2,0,2,0,34,0,1,6,1,0,0,0,0,0,1,0,4,8,2,2,4,2,0,2,0,0,0,0,1,10,0,0,0,2,1,2,0,0,0,0,0,1,0,0,0,0,0,4,1,0,0,0,2,0,4,0,1,0,0,0,6,2,0,16,4,0,40,26,0,6,4,4,0,0,0,5,237,1,6,7,0,0,0,1,0,2,0,117,88,72,41,60,132,246,159,250,76,50,66,38,104,70,109,59,44,69,136,289,81,46,66,79,54,78,51,0,98,28,143,81,117,108,88,45,74,68,122,0,52,65,84,62,199,75,169,206,155,137,101,223,199,183,157,10,67,61,78,167,291,162,185,192,319,121,166,24,31,32,55,166,125,123,213,76,94,112,109,71,50,98,45,66,80,144,103,226,130,165,120,71,34,50,151,2,100,28,77,129,111,190,207,177,121,52,54,126,131,197,63,135,197,185,194,136,91,109,84,65,6,158,70,159,129,191,148,88,51,219,0,189,55,94,55,60,90,116,43,2,41,30,68,111,99,66,90,18,192,97,126,106,43,118,75,32,108,52,95,86,35,71,68,64,41,81,111,155,158,107,171,78,101,167,68,58,233,175,27,84,232,148,20,0,94,108,25,32,32,54,288,72,76,92,42,1,63,43,23,309,76,147,154,150,95,144,33,2,127,42,77,107,24,208,88,36,100,76,23,0,134,45,52,240,146,383,65,0,312,27,92,1,49,85,64,396,366,515,173,253,133,198,88,1,96,127,52,628,115,303,169,188,6,112,65,2,99,146,48,44,53,84,28,0,59,0,0,36,0,82,6,38,0,68,0,29,0,14,72,20,0,54,72,58,0,37,0,90,2,60,0,30,2,100,0,21,0,49,60,46,62,21,0,45,48,70,27,53,14,56,90,10,6,111,36,0,80,226,53,127,31,28,2,48,54,8,22,6,31,4,40,18,32,28,36,30,8,25,88,3,18,36,63,2,54,31,105,2,52,32,0,40,68,74,123,66,4,47,16],[36,10,0,2,2,22,2,0,0,4,5,5,7,15,6,11,2,3,21,1,10,4,3,3,2,10,2,2,6,39,0,4,4,16,0,0,29,14,4,24,5,6,16,14,6,2,13,0,62,58,184,10,35,20,20,4,10,4,5,1,334,30,12,37,4,3,2,8,0,13,6,0,74,44,18,51,10,12,99,2,52,0,10,1,151,569,1,34,0,0,45,0,16,0,30,3,2,2,43,92,19,0,0,0,2,0,7,2,18,42,2,13,0,0,10,2,6,0,0,0,0,62,2,2,7,10,4,11,2,2,4,2,6,25,8,10,2,2,0,2,2,1,0,2,0,49,16,1,2,4,1,0,6,6,0,0,1,7,2,46,0,2,0,10,6,0,4,0,41,3,5,18,13,2,4,2,4,8,6,0,4,425,11,16,41,0,0,6,0,0,2,0,82,135,66,59,76,173,0,136,186,100,77,74,30,66,56,72,46,40,53,113,211,86,62,49,54,71,102,57,2,59,18,127,35,105,66,57,37,39,55,92,2,53,76,68,44,133,56,113,159,162,127,96,175,144,142,126,8,125,38,107,153,246,170,175,186,259,105,134,64,33,38,29,84,102,123,174,73,80,125,116,86,55,125,52,90,114,158,127,183,126,115,89,100,32,50,124,0,95,36,69,116,110,104,164,85,119,19,71,115,114,179,98,137,129,147,93,120,73,56,81,93,10,164,46,126,132,162,91,0,23,168,0,200,75,115,41,68,112,0,34,2,32,46,81,83,79,118,69,4,188,82,57,73,40,69,44,42,96,26,75,41,63,49,55,41,25,54,95,132,92,51,73,59,115,155,60,71,266,104,75,67,248,172,32,0,88,142,33,8,37,56,199,90,84,81,37,0,63,58,51,240,50,103,107,111,86,212,30,0,105,75,111,98,24,179,47,45,97,96,26,0,87,79,76,201,149,349,65,2,147,26,68,0,47,112,86,451,368,283,144,203,151,105,70,1,66,173,59,596,120,213,161,142,4,133,56,0,110,153,48,76,34,79,31,0,2,0,0,64,0,146,15,154,0,87,0,60,0,56,130,71,0,105,216,91,0,90,2,188,13,83,0,154,0,195,0,63,0,84,99,155,126,68,0,48,133,138,100,134,30,82,186,44,76,143,41,0,179,403,90,170,21,90,0,78,89,8,12,17,102,2,39,64,52,38,70,32,0,64,76,1,68,63,152,0,103,43,331,2,92,105,0,17,71,114,152,73,16,164,56],[25,15,0,4,4,26,17,0,0,4,3,0,14,13,10,6,4,3,16,1,42,7,0,0,16,43,8,5,13,41,1,12,22,26,4,0,70,16,12,22,6,12,3,19,10,3,10,0,70,83,166,28,46,16,64,14,15,11,3,0,339,73,14,67,3,12,13,16,2,4,3,0,70,43,16,62,15,28,164,4,55,6,14,0,160,423,13,31,0,2,58,3,20,0,38,0,1,0,38,93,10,3,3,0,7,3,7,4,13,76,0,4,2,0,7,6,4,4,4,0,11,39,1,1,14,7,2,6,2,3,1,0,42,31,6,37,2,2,2,1,9,1,5,0,1,89,40,0,4,5,1,2,11,5,3,2,1,5,8,55,0,5,1,5,13,5,2,1,30,1,58,28,33,2,12,7,14,4,0,0,10,531,5,54,62,1,6,5,1,0,5,0,123,95,87,47,92,108,240,185,276,109,77,83,32,68,80,142,54,32,107,138,344,84,50,124,55,47,102,40,4,108,40,166,50,178,144,93,40,84,95,118,3,65,96,87,44,151,69,154,198,189,184,178,272,196,142,124,31,91,84,102,237,306,188,252,262,397,145,125,36,32,74,72,158,176,169,231,89,81,133,116,61,62,96,56,65,65,141,107,225,137,151,101,106,35,50,151,0,132,27,153,157,113,241,183,195,129,57,94,124,144,256,102,164,216,156,195,147,103,93,67,81,8,142,55,186,124,191,145,113,59,165,1,182,72,105,39,103,105,122,29,0,28,27,94,96,72,95,99,30,217,113,125,113,38,119,75,36,168,38,87,83,39,57,72,59,14,75,109,164,130,133,140,59,107,149,70,82,296,137,35,49,281,204,26,0,63,70,42,56,35,48,345,115,90,92,61,0,75,52,55,424,54,140,198,135,124,202,37,0,129,65,116,93,22,185,130,42,117,73,27,1,167,60,72,194,127,327,84,2,307,49,88,0,42,125,89,460,315,733,266,208,169,180,68,0,84,124,54,597,88,278,209,195,7,147,62,0,141,207,39,54,52,97,25,0,34,0,0,24,0,84,9,16,0,29,0,19,0,10,66,14,1,31,138,45,0,59,0,45,6,52,0,17,0,63,0,10,0,27,24,72,33,37,0,14,51,91,42,58,15,33,108,19,18,113,32,0,123,193,30,78,10,39,1,25,59,5,16,11,42,2,16,25,23,36,22,47,0,8,23,2,9,23,105,0,37,36,88,2,56,16,0,47,25,72,109,37,13,113,15],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,57,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,1,0,3,0,22,0,0,0,0,1,0,0,0,1,0,17,0,0,0,0,2,0,5,0,1,0,0,1,1,0,2,0,0,1,5,0,34,18,0,16,0,3,0,1,7,0,0,0,3,105,24,0,2,4,1,0,0,0,2,4,0,0,0,41,0,0,1,2,2,6,0,1,2,0,1,14,2,3,0,0,6,0,1,0,0,27,3,1,0,0,5,0,0,0,0,0,288,331,173,106,206,228,3,345,440,195,207,181,110,212,132,263,100,117,219,243,474,216,123,186,154,144,250,114,9,192,56,281,93,268,155,140,68,94,130,231,5,117,240,137,92,387,228,501,402,371,295,305,460,404,308,463,18,306,141,181,485,678,371,504,456,792,381,336,98,80,103,179,329,262,328,523,232,178,316,338,157,155,232,109,180,200,413,298,539,327,384,237,259,82,98,354,20,350,110,230,249,279,277,333,283,206,55,159,224,205,475,198,218,379,236,308,198,143,105,111,174,20,277,130,276,230,312,211,2,135,335,0,334,223,331,130,191,155,1,80,0,99,73,171,167,216,317,168,31,507,227,270,167,119,212,140,123,359,95,184,200,119,162,176,170,54,125,253,222,182,90,220,99,208,342,125,83,591,417,171,145,596,367,84,0,219,267,133,57,142,138,675,314,172,238,118,0,172,173,99,792,168,326,548,389,209,388,89,0,357,214,245,288,80,481,313,87,236,226,67,0,314,136,171,466,365,775,159,5,524,92,190,0,79,220,160,879,564,788,376,435,321,337,130,0,155,257,75,982,186,491,392,341,7,236,130,1,188,281,115,202,125,220,54,0,0,0,0,0,0,51,0,22,0,0,0,3,1,0,2,0,0,0,0,0,0,0,0,49,0,41,0,39,0,7,0,0,0,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,91,0,0,0,0,0,1,0,1,0,0,0,0],[30,4,2,4,0,0,0,0,2,4,0,2,18,2,0,0,5,0,16,0,16,6,0,0,16,24,0,0,3,28,0,8,24,4,13,0,30,16,2,0,8,3,16,6,1,2,5,0,38,22,64,10,24,0,6,14,4,3,2,0,41,4,6,17,0,0,4,0,4,0,0,0,8,2,4,12,2,0,28,0,17,2,6,0,26,74,2,8,0,0,14,0,4,0,11,0,0,0,35,43,32,2,0,0,6,1,4,0,17,21,0,8,2,2,6,8,2,6,2,0,10,54,2,0,12,30,3,2,10,4,0,0,15,8,20,16,0,0,2,4,5,3,0,2,1,39,21,2,6,8,4,18,9,2,4,0,1,12,14,32,0,14,0,2,0,10,2,0,3,3,0,4,6,0,6,2,4,0,2,0,18,149,2,40,50,0,0,6,0,0,1,0,79,82,67,43,97,40,48,110,71,65,57,53,46,100,51,73,38,65,88,49,95,82,32,50,48,56,86,61,2,79,14,83,62,42,31,25,26,29,18,37,2,14,95,58,24,114,72,85,97,102,69,74,120,71,89,189,70,86,63,91,185,182,88,113,100,165,116,133,53,50,39,37,90,88,69,118,60,38,80,100,67,31,92,81,56,46,127,111,156,84,108,121,94,36,64,121,16,98,58,81,81,66,96,74,79,61,18,37,70,50,103,42,53,106,119,99,68,54,50,40,41,0,38,45,67,60,104,84,16,81,105,0,86,40,82,10,78,26,12,25,0,30,68,54,54,75,59,59,89,158,90,79,33,64,57,51,62,80,30,51,40,43,56,68,38,16,34,35,68,24,34,38,18,38,83,12,18,147,52,40,59,98,69,38,0,97,46,87,104,63,32,158,103,31,67,40,2,46,70,11,156,74,78,101,66,44,76,39,0,72,44,38,66,30,115,62,44,45,61,46,0,87,64,60,90,50,151,28,0,94,20,31,2,22,34,43,140,90,125,41,75,38,23,36,0,39,63,24,254,19,77,49,40,0,46,11,0,27,88,54,32,45,50,14,0,0,0,0,14,0,31,16,18,0,26,0,22,2,15,26,16,0,24,36,20,0,24,0,20,10,33,0,20,0,48,0,10,0,24,18,24,32,16,0,16,21,18,20,8,10,19,16,18,8,30,11,0,56,101,27,34,4,12,4,26,38,7,20,12,18,0,16,14,22,14,6,8,4,11,26,4,9,7,34,0,18,19,26,0,32,17,2,16,4,21,29,8,4,24,21],[15,1,1,0,0,9,1,0,0,1,1,0,0,6,1,2,3,1,8,0,7,0,0,1,5,6,6,0,0,16,5,0,0,12,0,0,20,16,5,13,2,1,11,0,10,0,0,0,25,22,48,7,5,7,6,1,3,0,2,0,83,40,6,5,0,2,4,2,2,3,1,0,9,27,7,0,0,9,34,5,15,3,4,0,0,190,10,6,0,2,24,0,17,0,12,0,1,0,17,130,1,1,0,0,4,0,0,0,14,12,0,0,0,0,0,3,0,0,0,1,1,26,1,0,12,3,4,9,0,1,1,0,13,21,1,20,1,0,0,0,2,2,0,0,0,2,4,0,0,0,0,0,12,0,7,1,0,1,17,0,0,3,0,3,3,0,1,0,13,0,0,18,13,0,1,1,0,2,0,0,8,308,0,78,34,0,9,0,0,0,17,1,74,75,38,32,53,84,197,69,161,41,43,36,11,42,28,58,25,20,64,68,176,42,27,55,38,18,31,33,0,53,10,77,21,81,41,45,15,37,41,55,2,39,46,35,32,104,22,46,68,132,77,53,124,150,80,87,4,33,37,44,88,122,107,111,118,176,102,65,33,17,23,24,64,69,85,109,53,45,52,86,32,28,48,34,26,40,61,56,124,84,81,66,62,18,25,98,1,77,26,57,93,73,99,105,70,92,27,45,73,66,147,88,39,125,75,99,73,63,41,34,49,4,81,35,104,74,129,90,57,43,125,0,91,23,82,39,50,61,64,13,0,21,13,47,45,33,35,44,5,83,63,64,50,23,56,29,24,76,19,27,31,27,26,40,40,12,36,77,62,67,65,68,30,86,76,56,41,169,95,16,27,186,93,12,0,55,54,23,9,14,30,210,56,46,60,38,0,33,19,16,213,63,71,115,85,52,102,22,0,67,46,42,50,20,90,66,20,52,55,12,0,55,36,38,150,87,229,34,1,136,27,32,1,21,73,45,252,240,349,129,143,117,82,54,0,29,84,43,350,51,193,129,84,2,88,40,0,68,93,32,32,21,37,20,0,65,1,0,47,0,116,20,29,0,97,0,63,0,13,138,75,0,58,201,118,0,31,0,152,14,79,0,109,0,42,0,45,0,61,85,76,82,64,0,69,122,153,19,37,45,100,194,47,53,133,44,0,127,203,74,200,8,10,3,108,61,4,37,26,56,0,31,43,56,48,27,28,0,37,98,5,50,32,165,0,98,56,222,1,113,77,0,87,61,147,12,78,11,166,43],[67,4,2,0,0,2,2,2,2,2,3,3,1,16,0,2,10,2,53,1,13,0,6,2,0,16,10,6,0,1,0,4,1,6,0,0,32,9,5,22,0,10,5,0,4,0,1,2,66,0,52,10,1,8,9,3,1,12,2,6,31,0,4,16,0,0,10,3,0,0,0,0,18,12,2,12,3,12,14,2,4,6,11,2,36,73,3,0,0,0,9,1,6,3,0,3,13,4,25,32,22,1,0,0,1,0,0,2,4,0,0,9,0,0,8,9,1,8,2,0,0,22,0,2,38,1,0,0,0,2,3,2,14,9,0,15,0,0,2,0,0,0,0,0,0,26,26,4,0,8,6,0,40,0,0,0,0,2,11,14,2,0,0,12,0,0,0,0,13,0,8,4,9,0,0,2,0,2,0,0,0,4,3,5,10,0,2,4,0,0,6,2,178,91,100,70,185,30,4,244,77,71,117,73,57,112,51,93,42,93,39,54,57,124,30,105,54,76,132,74,4,87,46,152,49,50,22,22,10,14,21,20,0,8,100,44,14,103,29,158,49,148,64,46,127,120,103,259,14,145,65,108,150,220,123,179,160,209,180,154,90,38,37,47,62,117,114,125,59,58,105,125,50,38,116,65,58,120,171,184,196,106,134,115,97,33,61,86,18,70,46,42,46,58,62,67,38,21,6,37,40,44,100,36,77,43,73,66,55,16,28,24,20,2,22,28,36,22,53,19,0,134,34,0,160,25,62,25,188,18,0,35,2,30,29,66,62,52,55,72,12,167,113,97,23,52,68,69,50,53,28,89,80,55,59,118,73,42,41,128,74,45,40,24,4,21,98,20,21,195,84,15,64,135,119,14,0,44,135,129,21,54,47,151,81,75,80,20,0,59,36,22,120,79,115,124,152,62,120,43,0,60,31,128,78,33,150,38,36,152,113,8,1,100,47,95,119,62,156,63,8,138,48,58,0,37,46,24,184,62,131,32,64,74,47,33,0,20,35,12,206,29,105,59,65,0,51,26,0,29,37,49,36,64,86,0,0,0,0,0,15,0,34,12,29,0,59,0,39,2,8,75,12,0,52,49,27,0,16,0,62,3,54,0,32,0,29,0,34,1,15,30,11,15,8,0,14,36,28,5,7,6,18,24,68,28,110,23,6,36,49,30,53,12,14,0,78,37,2,23,24,21,0,24,14,36,59,2,24,6,4,38,6,27,34,82,0,52,38,88,14,32,18,0,10,27,48,4,19,5,32,8],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,0,0,1,1,0,0,0,0,0,0,0,2,0,3,2,0,3,0,5,2,0,0,0,0,0,0,2,0,1,0,1,1,0,3,0,0,0,0,5,1,2,0,0,1,0,0,0,0,0,2,0,114,3,1,0,0,0,12,9,1,0,1,116,0,0,0,5,0,0,2,0,1,0,2,2,10,0,0,0,0,0,0,0,1,0,0,2,0,4,0,3,0,0,0,1,0,0,3,4,0,0,0,3,0,0,7,0,1,0,0,1,0,0,0,2,0,1,0,21,0,0,61,0,0,73,3,0,0,1,0,0,3,1,0,890,0,1,1,0,1,0,0,0,0,0,500,327,377,121,401,498,0,303,912,206,379,497,2,223,377,525,120,187,233,260,1016,561,270,464,418,158,544,131,17,534,193,573,272,590,169,118,152,238,271,440,26,120,405,293,199,662,170,427,499,494,429,563,1001,935,696,375,43,273,356,403,441,1411,344,1076,1038,842,918,370,224,228,117,333,320,666,270,534,458,231,595,646,364,128,545,144,124,424,363,289,952,284,264,528,269,166,125,596,26,327,256,449,506,194,295,568,441,241,87,185,376,206,893,395,427,402,628,707,217,349,278,111,334,50,204,246,326,251,678,512,0,316,324,2,378,475,564,139,402,353,0,164,2,95,128,423,228,158,684,231,28,1020,466,451,166,242,183,354,285,574,222,500,163,147,328,336,169,87,302,667,273,432,227,307,86,4,2,263,284,1110,512,339,357,1137,393,58,0,245,503,290,58,239,123,1279,272,191,226,118,0,311,173,155,734,254,598,947,352,494,375,83,0,641,385,283,37,59,964,310,99,506,462,157,1,695,255,354,11,727,1855,375,19,1264,106,470,0,166,500,378,14,673,1565,779,439,639,730,189,0,309,300,197,1778,336,665,837,822,0,228,121,0,177,527,3,495,118,456,48,0,0,0,0,1,0,3,3,2,0,1,0,3,0,1,2,1,0,1,1,3,0,3,0,0,0,0,0,4,0,4,0,5,0,2,2,0,1,3,0,0,0,5,4,3,1,0,6,1,2,3,1,0,8,12,0,3,0,2,0,3,0,0,1,0,3,0,2,1,0,1,1,0,0,0,4,0,1,0,6,0,2,0,5,1,1,3,0,1,0,2,2,3,0,1,2],[238,26,0,7,24,73,20,0,0,32,7,1,59,62,10,16,35,9,124,5,94,34,2,1,207,140,38,14,54,257,7,18,70,99,85,0,319,35,45,114,41,31,78,64,60,21,46,1,370,260,675,104,125,34,157,122,34,36,53,0,775,258,64,153,4,17,49,37,13,22,5,0,126,107,89,124,29,60,401,20,134,32,31,0,330,984,21,84,0,8,102,0,55,0,106,0,1,1,181,165,257,4,9,1,14,22,15,1,93,232,1,59,5,3,33,34,12,40,24,10,51,261,9,2,55,43,4,13,28,4,13,10,190,118,60,33,5,7,8,8,27,3,10,1,5,263,238,28,16,13,15,28,34,29,23,26,0,31,33,74,2,8,3,12,6,8,11,0,77,3,37,76,62,10,14,13,26,2,1,0,42,1083,12,108,93,0,13,1,0,2,1,0,358,299,283,195,385,247,226,547,480,334,411,327,206,469,339,401,213,320,268,501,514,451,200,407,374,396,525,325,8,379,136,442,194,305,195,244,94,155,198,224,8,122,308,180,92,478,266,405,542,588,450,404,706,560,438,529,187,409,252,280,619,739,460,658,679,971,616,431,176,194,185,149,358,362,435,607,274,280,421,515,262,210,491,252,262,276,589,505,693,405,433,439,306,174,241,441,39,446,221,321,257,259,319,313,209,215,79,181,230,273,472,228,245,419,347,381,243,173,200,120,180,16,266,107,320,276,396,240,74,368,387,2,436,142,325,84,363,212,58,230,0,144,135,306,265,307,292,308,303,632,377,314,91,246,329,371,331,363,181,351,302,323,330,345,285,148,182,449,275,310,206,290,106,321,357,166,181,630,278,142,248,795,520,169,0,294,393,289,258,269,211,683,354,275,333,198,0,220,397,222,743,189,468,463,381,309,524,192,0,440,282,430,208,99,482,418,183,361,439,181,0,493,276,295,620,480,831,317,11,684,163,319,0,92,294,210,722,801,883,541,589,446,422,230,0,208,356,131,874,236,592,416,481,3,301,51,0,224,223,328,202,116,352,32,0,12,0,0,155,0,248,74,133,1,200,0,110,0,66,251,122,1,175,317,202,0,185,1,341,85,176,1,257,0,387,1,122,0,126,166,226,173,89,0,121,213,243,121,203,78,125,252,108,142,371,122,3,406,631,262,380,100,187,4,232,252,70,138,101,158,10,165,76,127,151,130,110,20,133,179,10,111,154,370,0,189,121,366,16,182,93,0,165,141,188,269,136,23,265,97],[6,3,0,1,0,10,0,0,0,4,2,0,21,7,0,5,3,1,14,0,15,2,2,0,6,19,3,3,12,47,2,5,11,10,14,0,0,2,9,26,6,5,17,7,10,1,8,0,0,46,110,11,21,13,24,14,3,1,5,0,66,45,11,28,0,3,5,1,0,8,1,0,14,20,8,24,0,8,81,2,24,2,4,0,68,202,13,20,0,0,23,0,21,0,46,0,2,0,77,0,0,0,0,0,13,1,0,0,1,87,0,0,3,0,0,0,0,0,1,0,2,0,5,0,1,0,0,0,5,2,0,0,0,1,8,0,0,0,1,0,0,0,0,0,0,0,1,3,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,7,7,0,31,0,2,45,10,1,8,11,0,0,0,0,0,639,0,0,0,0,0,0,0,0,0,0,149,164,144,65,133,172,0,157,428,111,126,154,35,134,157,184,72,95,125,185,422,176,94,181,113,86,206,82,1,189,48,180,72,205,95,98,70,125,122,164,5,65,143,132,81,266,72,242,186,230,199,247,504,391,265,190,13,123,128,115,193,553,202,443,443,429,354,143,75,79,47,111,122,191,150,241,127,99,208,203,77,65,198,67,77,162,162,163,338,183,126,161,102,56,63,193,12,162,67,186,185,109,155,202,158,109,24,89,147,139,327,145,138,221,249,296,124,102,114,62,104,10,125,93,174,143,242,193,0,100,178,1,186,153,152,31,108,118,1,55,0,39,33,148,108,107,207,91,20,438,193,158,51,96,115,160,124,245,92,177,93,71,127,89,96,31,115,246,132,217,105,150,52,72,93,123,151,343,150,140,65,396,161,39,0,80,166,84,22,69,34,445,77,76,112,47,1,97,83,56,392,110,220,279,148,127,151,45,0,222,110,120,23,30,335,137,47,156,139,47,1,209,82,107,143,224,753,147,10,490,35,148,0,49,145,104,262,330,609,330,242,288,276,89,0,108,134,71,736,151,235,302,273,0,118,36,0,80,128,24,193,46,163,19,0,0,0,0,23,0,71,13,41,0,25,0,29,0,20,54,18,0,32,42,32,0,30,0,52,13,32,0,43,0,67,0,23,0,28,30,56,33,23,0,12,39,36,20,53,11,30,36,20,25,75,36,0,80,121,42,45,13,53,2,58,42,4,24,18,29,3,22,24,21,26,31,22,4,21,36,1,14,17,65,0,24,20,58,3,34,30,0,22,23,57,95,34,8,48,19],[75,4,1,2,5,33,2,2,0,8,3,2,12,28,4,8,3,10,33,7,37,2,0,0,81,17,15,2,17,37,2,6,27,24,20,2,67,29,14,36,10,4,21,12,18,2,9,2,61,111,185,18,25,6,85,10,16,3,12,0,259,62,14,54,2,10,22,11,4,8,2,0,34,38,24,77,8,4,123,7,48,10,6,2,130,532,8,36,3,2,14,1,22,1,40,1,1,1,66,0,2,6,0,0,9,8,0,2,0,78,1,2,10,3,1,0,7,1,10,2,48,1,0,0,2,0,4,0,4,6,2,0,3,3,22,1,0,1,0,1,0,1,0,0,1,2,7,7,0,12,1,0,2,1,0,0,2,6,0,2,0,0,0,0,0,6,8,0,40,3,0,76,21,0,9,10,0,1,0,0,1,758,2,1,2,0,0,0,0,2,0,0,180,98,98,81,74,117,53,183,185,101,101,78,37,105,56,148,60,68,110,156,153,81,48,97,90,77,110,89,2,83,32,130,51,113,55,88,53,53,60,69,0,54,107,68,46,151,69,105,195,196,180,125,205,192,142,159,88,106,78,79,220,396,174,269,194,297,185,140,61,60,31,73,128,105,186,195,98,65,109,165,83,55,132,93,95,151,204,155,306,126,156,114,94,49,66,136,24,177,54,84,131,98,147,151,122,121,49,82,83,112,260,90,110,162,177,130,86,92,66,68,54,4,119,56,161,126,195,125,11,106,146,0,190,43,139,24,110,120,9,50,2,54,37,83,95,51,79,83,132,189,78,121,33,51,75,84,51,188,45,93,66,49,75,80,83,32,49,88,145,90,49,123,54,115,163,46,64,272,119,54,86,353,232,50,3,108,185,75,185,62,58,275,133,93,99,57,1,66,98,77,464,75,207,146,152,128,154,76,0,142,87,104,62,23,178,96,42,95,102,41,1,132,90,73,272,131,328,83,2,226,47,75,1,38,175,99,417,218,312,182,200,165,149,91,1,82,173,60,511,88,248,139,133,2,107,31,0,91,109,49,48,36,112,11,0,16,0,0,52,0,113,19,74,0,73,0,57,0,50,89,59,0,87,145,137,0,54,0,129,30,99,0,110,0,222,0,60,0,47,58,119,52,44,0,80,81,107,47,63,56,71,128,32,43,151,35,3,157,430,86,265,22,52,6,84,110,23,40,41,60,1,60,24,60,48,57,60,7,54,87,4,44,53,135,0,84,33,221,6,83,103,2,88,69,106,141,73,14,116,18],[52,5,0,0,3,9,0,0,1,5,2,1,14,11,5,6,4,3,19,3,15,2,0,0,5,28,12,2,9,42,2,5,13,20,10,0,31,10,6,16,10,2,17,18,7,2,16,0,69,33,103,19,16,4,21,18,3,2,11,0,135,40,11,34,1,3,14,7,3,4,0,0,16,18,8,24,3,5,73,2,28,7,7,0,56,178,4,26,0,1,16,0,8,0,13,0,1,1,64,69,31,1,0,0,6,5,2,1,14,39,0,14,0,1,11,8,3,6,3,2,2,61,2,3,12,12,6,4,4,3,4,0,39,20,17,10,2,1,9,10,8,2,0,2,0,30,22,5,4,1,5,6,17,6,6,1,0,12,4,36,0,7,0,5,1,5,2,1,22,3,10,26,14,2,4,4,3,0,0,1,2,290,3,14,20,0,3,0,1,2,3,1,83,67,51,43,54,67,5,81,112,59,75,61,42,78,64,65,43,49,44,76,107,69,26,58,67,57,106,44,2,78,26,108,42,41,36,24,24,36,36,43,2,31,59,38,23,62,45,112,96,100,72,83,131,119,71,138,5,73,49,48,94,152,86,133,134,172,108,87,39,38,26,28,73,57,73,129,54,57,63,118,72,36,78,63,77,76,142,108,178,82,74,89,45,35,35,95,6,96,38,55,51,55,59,72,45,61,8,20,43,57,74,44,48,80,53,81,59,48,26,19,35,3,61,22,52,70,101,52,0,71,63,0,86,28,55,17,58,29,0,22,1,35,23,56,30,50,74,32,5,124,62,39,14,40,49,59,43,70,37,56,42,40,56,47,40,27,21,64,43,40,28,50,27,38,69,19,26,95,62,24,46,105,96,26,0,50,73,53,13,65,34,142,68,51,52,29,0,27,62,10,171,36,58,103,59,51,82,24,0,79,42,75,42,23,83,56,43,62,53,25,1,78,37,48,112,66,122,26,4,109,29,63,0,22,58,33,153,95,118,74,99,76,55,39,0,22,66,23,233,23,115,60,57,0,44,7,0,34,45,49,47,18,57,2,0,0,0,0,33,0,70,28,36,0,37,0,18,1,16,50,35,0,25,75,41,0,34,0,69,8,38,0,45,0,71,0,23,0,40,31,47,41,21,0,26,30,39,28,31,12,26,46,10,26,77,25,0,74,134,55,81,17,58,2,50,43,3,29,17,29,4,34,24,18,22,30,26,8,22,38,0,18,32,59,1,39,24,151,5,47,39,0,15,34,46,57,23,7,58,12],[12,2,0,2,4,8,8,0,0,0,4,1,9,8,1,1,7,5,9,0,11,3,0,0,6,13,8,1,9,46,1,4,14,13,4,0,26,15,4,17,1,1,14,4,3,3,9,1,38,34,84,18,16,3,14,5,1,0,2,0,193,16,12,17,0,10,7,1,3,6,0,0,25,24,19,32,2,12,53,3,26,5,7,0,66,218,10,24,0,0,20,0,10,0,14,0,1,1,9,35,10,0,3,0,6,1,3,0,8,28,0,4,0,0,3,0,0,3,2,1,5,10,1,0,8,1,1,3,0,1,1,0,17,7,3,16,0,2,0,0,7,1,1,0,0,37,18,1,1,0,3,0,2,5,2,0,0,4,3,30,1,4,2,4,5,2,2,1,18,0,31,9,9,3,5,3,12,1,1,0,9,282,0,33,17,0,4,6,0,0,3,0,62,59,25,28,53,59,140,68,131,34,32,36,10,44,21,56,22,20,48,53,152,35,18,42,23,22,34,21,1,31,9,71,23,38,36,39,24,30,38,52,1,36,33,51,24,67,37,62,94,75,70,50,130,107,86,69,5,41,37,43,62,150,75,78,97,210,87,87,23,18,12,32,71,77,73,88,37,30,61,48,32,35,40,25,29,48,63,47,112,59,73,45,58,22,21,59,0,58,22,42,61,68,76,95,57,36,30,39,54,62,114,50,57,114,74,89,43,42,39,29,43,7,53,31,81,54,89,55,70,24,103,0,71,21,61,9,52,39,58,17,0,22,17,41,45,37,16,36,4,88,41,39,28,28,49,33,28,76,18,25,33,22,32,43,29,8,23,56,91,58,62,85,23,68,86,36,33,125,58,18,27,101,72,6,0,42,49,10,16,31,22,168,69,36,37,17,0,20,16,29,212,31,69,102,74,39,90,16,0,48,40,54,23,10,71,57,19,42,24,4,1,78,27,38,105,82,227,21,1,134,17,39,1,21,51,52,193,139,347,103,110,91,70,32,0,52,43,25,288,43,120,123,103,0,61,10,0,50,59,20,26,8,44,8,0,39,0,0,23,0,41,8,22,0,28,0,7,0,14,39,24,0,18,58,27,0,21,0,47,8,38,0,31,0,61,0,25,0,29,33,48,25,20,0,16,44,46,29,21,6,24,45,10,13,63,16,0,58,137,36,65,9,19,0,42,26,2,10,16,35,0,19,9,13,21,26,10,1,19,25,0,9,26,60,1,25,16,69,2,35,35,0,37,26,43,56,25,2,53,11],[36,2,0,1,2,12,0,0,0,3,7,2,15,12,4,4,2,1,16,2,12,4,2,0,58,27,9,0,9,43,0,7,17,12,2,0,54,9,4,6,11,6,12,9,13,5,10,0,56,67,133,11,27,13,20,14,3,3,1,0,204,34,10,35,0,2,6,9,0,9,0,0,41,18,10,36,8,8,137,4,46,5,9,0,97,331,9,18,0,1,35,0,11,0,6,0,0,0,26,66,30,1,0,0,4,3,4,1,10,35,0,2,1,0,11,1,2,3,4,1,19,41,2,0,6,5,2,4,4,3,5,1,34,15,13,20,1,2,1,0,8,1,2,1,1,46,26,5,5,5,3,6,7,6,1,3,0,6,5,54,0,8,2,1,6,5,2,0,28,3,14,25,25,4,6,4,10,2,3,0,5,296,1,21,41,1,6,5,0,1,1,0,96,65,49,46,79,79,58,136,169,84,56,68,43,110,43,64,27,27,61,104,199,84,41,92,62,55,95,58,1,80,27,108,42,94,51,53,29,40,44,98,3,47,53,69,37,116,48,84,132,132,111,92,133,122,87,133,74,104,49,67,140,243,105,129,163,252,139,102,28,21,36,42,112,108,113,148,64,62,95,123,62,52,80,32,62,60,112,85,153,99,98,79,92,18,39,87,3,113,29,84,75,85,82,96,113,107,28,50,67,73,155,66,74,141,91,126,87,50,47,34,72,6,77,38,111,74,133,68,9,75,156,0,140,63,93,13,80,47,10,47,0,35,17,71,64,60,57,60,98,144,69,75,48,56,67,44,60,63,38,64,46,59,55,80,60,30,32,73,86,79,69,69,32,75,123,55,54,205,115,14,56,242,139,26,0,71,97,53,107,53,36,198,97,82,89,65,0,49,60,40,249,72,121,146,156,98,165,27,0,135,64,91,45,18,167,123,35,103,58,28,0,108,65,64,197,77,304,43,0,193,21,74,0,28,88,51,358,222,287,142,170,136,107,62,0,79,101,46,419,75,216,147,165,2,64,26,0,83,92,55,44,19,75,9,1,2,0,0,20,0,58,6,23,0,40,0,14,0,17,48,19,0,17,71,30,0,22,3,42,4,37,0,29,0,60,0,21,0,27,33,55,32,18,0,30,37,52,16,40,13,19,46,6,17,59,16,0,71,151,33,71,10,24,0,42,39,14,16,12,33,0,32,16,17,27,20,24,1,21,33,1,16,18,59,0,36,24,149,2,39,25,0,23,30,52,69,27,4,53,15],[31,7,0,2,3,25,14,0,0,3,2,1,11,18,6,7,4,6,17,3,19,5,1,0,9,27,10,1,8,61,1,4,23,32,4,0,62,12,7,30,6,9,16,5,9,1,3,0,48,73,115,16,33,7,31,8,6,2,8,0,268,43,12,48,0,12,9,7,7,5,0,1,44,33,29,58,8,12,121,5,50,10,11,0,123,337,12,36,1,3,37,0,16,0,24,0,1,0,35,22,4,4,7,0,5,4,2,1,6,17,0,4,0,0,2,1,3,5,0,0,3,9,1,0,10,4,0,2,1,4,0,0,11,10,9,4,1,0,1,1,4,1,0,0,0,23,10,7,3,3,0,0,10,1,2,0,0,1,5,13,0,5,2,0,5,6,2,0,48,3,24,21,20,2,8,9,6,2,1,0,4,477,7,20,19,1,6,2,0,0,4,0,84,110,66,48,84,117,274,162,233,80,44,69,29,93,54,110,33,41,95,115,241,65,61,81,64,39,53,45,2,67,12,144,48,118,79,64,45,45,59,93,7,56,77,84,53,141,61,114,156,144,115,89,188,149,153,172,14,71,70,94,175,288,154,185,172,307,141,90,36,30,38,74,122,125,117,193,88,74,118,116,71,32,85,36,64,78,102,77,240,105,123,83,104,20,34,139,3,137,27,107,133,114,128,170,161,104,44,76,80,105,236,76,95,207,137,167,136,79,70,68,92,8,114,63,148,103,158,129,104,61,142,0,219,46,121,22,79,113,77,25,0,52,36,67,78,81,45,72,16,135,78,88,50,39,82,59,43,130,35,68,61,38,46,87,70,21,42,86,123,104,80,120,48,122,174,62,50,338,154,47,43,211,174,20,0,88,133,35,32,44,57,309,123,78,110,48,1,67,49,43,410,50,128,192,197,85,217,34,0,142,75,84,55,33,208,132,36,90,66,32,0,136,68,53,239,154,596,94,0,258,23,95,0,50,147,116,521,349,602,193,233,193,163,79,1,82,158,51,642,92,298,224,208,2,159,35,0,118,146,35,49,28,94,6,0,180,0,0,45,0,83,11,56,0,39,0,32,0,25,46,23,0,36,86,52,0,27,0,70,5,51,0,55,1,102,0,36,0,65,45,99,33,43,0,36,62,69,35,57,19,47,85,28,16,83,28,1,110,247,65,77,25,45,0,41,42,5,15,15,59,0,22,21,24,28,43,34,3,39,50,1,19,28,85,0,40,27,195,1,49,62,0,48,55,72,103,53,5,66,30],[125,11,0,9,10,20,0,0,0,20,0,0,28,26,5,22,8,3,40,1,43,6,3,0,8,54,8,3,27,93,2,20,32,16,8,0,121,16,18,35,7,11,36,13,21,5,17,0,160,92,275,31,74,20,128,60,19,3,9,0,242,132,19,43,4,13,35,18,3,8,1,0,15,14,10,29,4,11,60,2,26,4,3,0,58,229,3,25,1,0,19,0,5,0,11,0,6,0,67,0,0,1,0,1,3,1,0,0,0,48,0,5,7,0,0,0,6,0,4,0,3,2,11,2,5,0,15,0,9,4,0,0,2,3,22,0,0,0,11,0,0,0,0,2,5,0,7,9,0,3,7,6,39,2,0,1,0,19,5,8,0,5,0,0,0,6,2,0,12,0,1,16,6,0,2,1,0,0,0,0,0,240,0,2,0,0,1,1,0,1,0,0,230,131,106,79,184,90,1,288,117,118,132,142,114,197,105,110,98,85,95,140,86,155,66,192,126,152,271,148,9,136,88,211,81,67,47,44,30,25,42,60,1,35,166,38,37,220,102,172,222,229,144,189,281,265,147,431,14,232,123,140,262,316,172,325,272,310,244,222,52,75,89,60,208,210,200,341,120,96,166,297,133,76,272,96,142,138,288,275,369,173,252,216,148,81,86,100,29,181,102,108,73,109,102,99,70,65,17,63,51,87,164,66,81,104,84,84,60,40,65,35,45,1,78,32,86,80,92,77,0,218,70,0,356,78,232,62,217,42,0,95,0,102,107,133,96,125,127,159,18,328,133,191,27,106,80,97,104,132,87,95,82,97,152,129,110,58,71,135,43,54,29,59,22,56,174,27,51,246,168,68,115,394,175,72,0,157,236,124,8,132,135,364,207,124,159,113,0,102,190,99,232,79,220,168,174,166,243,88,0,279,129,198,55,49,230,153,69,139,264,113,0,274,140,146,230,229,262,73,10,272,79,126,1,36,120,40,287,188,236,106,119,91,89,56,0,54,72,37,388,58,127,126,106,1,84,35,0,64,78,153,73,73,161,8,0,0,0,0,20,0,115,9,12,0,43,0,32,0,32,15,39,0,46,9,36,0,4,0,64,18,38,0,36,0,79,0,42,0,8,14,18,3,1,0,13,22,18,14,7,17,2,22,14,21,93,35,3,127,105,13,90,15,42,3,30,56,4,14,24,22,1,62,27,45,5,18,18,7,20,65,2,22,30,65,0,41,18,82,18,7,24,0,9,9,16,45,18,3,18,6],[8,1,0,2,1,12,2,0,0,4,4,0,3,6,1,5,1,2,21,2,4,3,2,0,4,25,17,3,3,18,0,3,3,12,4,0,20,16,2,18,6,6,12,5,6,0,1,1,39,40,70,13,16,2,26,13,4,0,4,0,123,24,2,48,0,4,4,0,9,10,1,0,29,16,2,18,6,12,63,2,23,12,9,0,58,194,3,17,0,0,23,0,10,0,4,2,1,1,12,44,26,0,2,0,4,0,1,0,10,20,0,4,1,1,5,0,4,0,0,3,2,14,4,0,5,1,4,2,0,0,2,0,35,12,8,12,0,3,0,4,12,0,0,0,0,31,26,0,1,0,2,0,14,6,4,0,0,2,4,34,0,2,2,0,6,7,0,0,15,2,49,12,10,2,2,0,2,2,0,0,6,233,2,26,45,0,6,2,0,4,2,0,34,29,30,26,48,61,148,54,89,67,27,29,10,47,28,39,12,9,27,79,115,39,18,32,28,19,29,19,0,34,8,64,30,48,44,16,14,20,26,50,2,36,21,33,22,65,26,58,62,102,79,57,135,81,83,50,6,67,45,33,85,135,113,101,87,179,72,54,18,10,25,26,72,64,66,98,45,37,34,74,21,13,50,16,32,30,75,38,102,38,88,54,33,27,15,54,2,52,17,30,46,45,49,71,44,31,18,27,31,54,100,62,50,88,77,99,63,41,51,55,44,2,65,30,49,47,84,61,58,26,120,1,89,24,54,18,40,50,30,13,1,22,2,38,40,36,37,39,6,70,45,42,17,10,27,49,11,62,24,20,21,17,36,48,20,17,8,54,70,79,70,38,27,53,100,33,38,184,81,14,16,149,80,5,2,56,52,16,16,20,33,186,67,41,28,16,0,33,21,22,245,32,70,97,84,31,77,9,2,50,39,63,12,10,110,39,24,44,47,14,1,67,40,29,153,112,195,53,0,152,25,35,0,18,76,27,299,213,217,111,89,97,80,41,1,42,73,15,354,56,149,84,68,0,79,24,0,43,59,8,16,4,37,6,0,36,0,0,43,0,46,3,12,0,16,0,10,0,6,18,21,0,13,37,35,0,14,0,41,7,33,0,40,0,60,0,8,0,18,26,38,36,5,0,8,30,20,18,24,14,24,36,10,6,35,10,0,59,108,44,25,4,8,0,12,16,0,1,2,22,0,16,8,8,4,24,8,2,8,19,1,10,12,22,1,21,10,91,0,23,20,0,19,12,32,34,18,4,42,14],[138,10,1,8,14,3,0,1,1,6,4,0,27,26,9,14,12,2,40,6,46,4,0,0,8,50,13,17,19,94,1,17,69,17,42,0,124,7,33,55,24,12,35,18,36,2,17,0,166,98,285,29,23,12,83,80,34,12,16,0,158,66,6,98,0,0,24,29,6,10,0,1,19,16,1,16,0,11,105,8,45,3,9,2,56,295,9,17,2,0,7,0,27,1,23,3,40,0,80,244,140,0,0,0,4,4,2,2,33,76,6,24,8,10,35,16,6,30,4,5,4,128,14,4,38,35,32,14,12,0,13,4,82,55,44,33,1,44,0,22,26,3,13,15,19,164,80,32,10,26,25,3,231,17,9,9,1,13,23,84,1,15,7,12,3,2,0,1,32,6,10,14,16,2,0,2,0,4,5,0,6,287,7,22,44,2,9,9,2,0,4,1,332,207,112,105,253,73,0,278,125,137,190,181,136,284,158,198,73,121,143,130,130,181,95,150,144,189,331,135,6,181,117,273,84,76,62,25,39,21,47,58,2,25,129,39,32,332,93,225,320,222,118,203,340,285,193,375,22,245,93,260,285,364,177,290,395,435,241,284,107,151,80,62,269,148,306,340,196,134,196,380,87,82,299,110,169,172,459,331,573,184,278,295,187,63,96,160,31,238,129,108,86,131,143,124,48,73,15,76,88,87,149,65,71,85,66,98,44,64,64,38,94,3,100,32,78,94,96,54,2,298,95,6,395,150,208,45,272,88,0,131,3,69,122,233,113,119,188,150,22,326,196,224,30,115,188,133,138,110,49,154,107,99,170,132,159,50,88,213,78,75,34,79,51,60,178,30,41,350,160,90,104,399,267,113,0,152,257,140,22,129,69,318,166,160,162,119,1,107,199,88,309,115,176,279,185,137,276,77,4,285,133,312,84,22,267,221,86,116,164,69,1,300,153,141,296,177,215,67,14,411,116,120,0,40,88,50,240,165,130,91,137,92,85,32,0,44,86,27,237,64,228,82,133,0,88,30,0,64,91,222,70,55,201,11,0,0,0,0,52,0,131,11,81,0,59,0,56,0,17,54,59,0,69,67,60,0,56,0,121,24,72,0,43,0,121,0,36,0,20,28,42,20,15,0,18,30,32,16,30,12,33,23,22,20,147,48,4,227,286,77,107,15,65,2,54,90,4,51,31,59,2,46,13,56,43,29,20,0,48,43,0,47,22,77,1,50,48,315,21,29,23,0,9,33,21,73,29,8,35,5],[20,8,0,0,2,8,0,1,0,2,6,2,12,8,3,2,4,6,18,2,14,0,0,0,54,18,4,4,16,48,0,0,12,20,4,0,52,14,8,13,8,2,20,4,2,4,4,0,35,45,90,6,15,9,34,18,5,2,6,0,112,39,6,24,0,4,15,8,2,2,2,0,22,20,6,22,14,2,60,2,41,13,4,0,80,152,2,19,2,0,17,0,12,0,20,0,2,2,36,17,20,0,0,0,0,2,2,0,2,37,0,0,4,0,2,0,0,0,6,0,22,21,2,0,8,0,8,2,0,0,0,0,15,4,9,4,0,0,0,0,2,1,0,0,0,14,8,2,2,1,0,6,24,4,0,2,0,8,0,4,0,2,0,2,0,2,2,1,12,8,4,29,20,4,2,6,3,0,4,0,4,324,1,17,8,0,2,2,0,0,0,0,76,53,67,23,76,49,42,128,134,90,103,62,34,77,40,72,29,36,54,75,198,84,32,73,75,46,98,36,2,58,28,118,26,74,54,50,9,39,48,77,4,32,92,50,33,94,48,74,83,127,89,86,158,124,108,155,55,96,42,63,150,202,90,146,161,202,128,101,33,18,41,38,95,82,85,184,72,46,73,98,50,56,82,45,85,81,92,124,146,91,109,82,80,24,52,65,8,116,34,69,79,80,76,66,60,64,18,49,82,48,152,42,64,89,94,139,75,74,30,24,76,6,81,27,73,46,100,75,6,64,92,0,123,29,110,21,81,52,4,33,0,24,28,53,42,72,52,56,68,114,67,55,39,29,66,46,26,80,25,52,62,28,52,74,33,20,28,96,64,58,22,57,18,53,84,33,36,146,76,11,62,198,74,29,1,49,68,38,103,68,21,163,95,41,81,36,2,37,48,18,161,38,74,100,120,70,156,11,0,130,53,68,30,12,110,57,47,88,53,18,1,69,28,42,131,73,139,40,0,160,22,66,0,29,102,55,189,170,237,109,124,119,113,51,0,49,52,33,325,50,162,120,120,0,87,15,0,60,74,41,22,13,45,5,0,2,0,0,30,0,57,14,51,0,32,0,30,0,12,62,28,0,24,78,44,0,27,0,61,14,44,0,32,0,63,0,17,0,26,48,42,52,16,0,26,34,32,27,40,5,28,52,31,21,67,36,1,86,156,76,70,4,28,0,36,33,30,16,16,44,0,11,26,36,23,42,22,0,22,29,2,24,19,76,0,38,28,156,4,48,20,0,14,35,52,73,32,14,75,15],[22,1,2,5,3,3,2,3,2,2,7,5,11,4,7,4,6,4,5,2,2,1,1,3,0,7,3,1,17,5,5,0,2,4,4,5,16,5,5,2,3,1,3,5,0,3,6,1,10,2,3,4,5,2,3,4,3,3,9,4,15,8,8,7,0,3,6,1,4,1,5,1,8,2,2,7,1,2,6,4,6,6,6,4,8,13,4,4,9,0,1,1,6,5,5,5,47,12,3762,109,250,77,0,4,146,128,5,11,43,3063,1,75,2,7,44,4,243,16,264,11,171,82,226,38,42,28,25,18,1,0,6,6,82,93,4,22,7,45,110,12,11,1,6,4,1,75,107,478,35,39,33,18,145,17,8,9,8,652,23,96,1,25,12,16,6,80,0,0,923,18,16,581,2,4,0,0,18,2,1,0,11,8927,13,26,41,2,6,10,0,9,9,0,7,3,12,9,3,14,0,3,11,19,25,4,18,28,8,27,3,31,2,5,13,8,6,35,25,3,26,20,1,5,4,32,3,5,14,8,5,2,2,23,2,7,3,9,5,18,7,4,10,7,7,4,6,9,6,21,0,2,15,15,5,17,5,62,8,3,5,3,0,3,15,7,19,4,14,9,18,5,6,20,5,8,12,9,14,21,17,28,17,6,1,26,11,3,5,7,0,4,0,3,3,19,15,6,5,6,3,9,10,12,5,6,10,5,9,4,4,3,6,15,9,1,11,1,4,7,7,16,2,23,15,1,32,24,3,7,20,25,0,6,4,5,3,21,21,4,15,10,0,15,24,14,13,9,12,13,19,11,5,13,12,15,10,3,12,5,26,11,7,10,6,36,8,12,9,11,4,28,6,6,10,7,9,8,1,3,4,24,0,15,3,34,23,12,9,15,6,0,5,4,11,10,11,8,16,6,10,41,1,6,9,8,4,18,26,6,8,35,4,4,4,8,8,8,13,23,15,11,0,4,3,4,5,5,6,4,23,12,17,9,3,12,6,9,2,4,19,4,22,14,15,10,12,0,10,7,1,14,5,24,10,10,10,4,3,22,0,3,1129,2,3780,1115,2662,2,2024,0,1869,5,1082,2551,1079,18,1727,1583,1557,0,1748,6,2586,994,1977,3,2024,8,3500,0,1491,0,889,926,1543,1076,709,0,569,1143,1202,688,1142,445,1031,1109,1412,1215,4389,1866,23,5713,3858,2439,2202,1045,2807,101,3354,2499,209,1601,924,2198,211,2121,1118,1993,1397,1055,1731,386,1120,1830,72,1048,1051,3484,12,1743,1597,2013,421,1011,985,6,472,1001,1442,2292,1002,280,1266,639],[55,16,0,0,1,30,0,1,0,2,6,0,17,17,5,11,8,3,32,1,32,2,5,0,4,60,16,2,13,49,1,4,28,35,6,0,68,12,9,26,11,7,47,10,17,6,11,0,90,54,182,20,34,14,60,25,22,4,1,0,349,60,12,67,1,16,11,5,6,17,10,0,57,41,34,57,9,19,200,12,61,12,12,0,161,643,15,43,0,6,49,0,23,0,29,0,3,0,34,103,51,3,0,0,9,5,10,2,19,64,1,16,3,2,17,6,0,9,3,1,4,46,0,1,17,10,1,2,3,4,1,1,65,31,14,37,1,3,3,3,7,0,2,1,0,83,58,2,9,5,6,2,17,11,4,3,0,7,15,60,0,6,2,4,8,6,3,0,31,1,18,35,32,3,7,4,7,3,2,0,12,718,7,64,64,1,11,4,0,1,3,0,163,153,87,74,115,154,4,199,232,96,84,92,57,104,90,101,64,48,90,139,328,118,60,113,70,56,97,73,4,91,27,183,53,153,116,105,43,66,66,93,4,76,135,80,59,198,65,291,238,201,204,159,230,270,147,200,5,147,74,108,190,384,191,259,243,396,172,173,50,63,34,74,123,175,203,237,102,109,142,141,64,72,137,76,85,109,185,130,282,177,158,145,93,38,51,130,4,140,56,99,159,133,161,223,164,147,28,92,99,146,283,141,163,208,167,193,151,119,94,79,134,11,170,63,182,122,226,139,0,67,231,1,227,128,149,33,120,136,1,60,0,62,28,93,83,94,151,89,9,231,113,114,68,42,100,88,67,150,44,90,66,45,83,119,94,27,62,116,122,97,56,117,46,160,205,61,98,342,165,93,73,346,215,39,0,118,149,62,25,68,59,341,154,108,105,60,0,94,84,51,521,69,190,220,205,129,265,40,0,176,105,132,71,23,268,147,67,136,105,32,0,189,88,96,294,133,466,107,0,299,45,107,0,43,143,99,549,374,424,236,296,233,215,83,0,121,167,62,699,128,368,189,276,2,154,48,0,128,162,73,93,23,106,10,0,3,0,0,77,0,165,21,77,0,80,1,67,0,44,155,74,1,86,218,94,0,48,1,152,25,90,0,120,0,192,1,65,0,61,96,147,98,70,0,64,124,132,88,134,39,79,186,38,102,180,53,1,222,468,111,207,38,109,1,105,96,8,57,31,79,1,60,28,68,71,80,64,6,80,88,0,31,72,152,0,108,65,283,2,96,84,0,57,86,125,182,93,17,195,46],[53,6,0,0,12,20,0,0,2,2,6,6,16,12,4,8,6,6,32,0,24,8,0,0,2,57,14,4,22,70,0,4,22,20,23,4,83,25,8,20,12,6,32,11,16,0,14,0,139,70,240,22,26,24,76,10,22,24,10,0,604,74,14,64,2,6,13,8,7,8,2,0,91,34,16,60,13,6,197,0,60,4,18,0,269,917,8,58,0,2,30,0,31,0,26,0,0,1,70,212,124,4,0,6,11,2,5,0,29,84,0,36,4,2,30,17,3,8,6,0,4,82,7,0,38,26,0,12,0,4,6,6,102,61,14,25,0,6,2,0,21,2,2,0,25,92,50,6,14,4,6,12,26,16,4,10,0,11,20,89,2,0,4,2,12,6,0,0,47,2,40,28,20,2,14,9,9,10,6,0,36,866,3,52,47,2,15,10,0,0,2,0,186,239,69,75,154,157,3,246,291,137,160,110,32,145,140,107,56,54,109,138,276,136,92,115,118,96,183,85,2,161,38,260,59,110,60,62,53,89,70,118,8,61,120,64,55,181,106,284,237,277,239,176,297,345,226,301,4,142,106,131,239,495,188,330,306,501,316,205,60,60,65,92,157,165,203,346,107,133,189,251,123,97,183,88,106,200,327,211,363,153,220,184,131,34,78,190,13,176,86,122,189,120,187,276,150,165,21,68,133,192,370,148,171,224,258,300,194,94,106,87,116,10,212,55,229,146,301,105,0,123,213,2,329,143,204,61,155,173,0,119,0,84,46,100,89,80,159,119,22,182,108,110,129,64,119,74,65,145,52,107,80,74,123,134,92,24,60,104,115,125,64,130,64,145,195,85,64,417,142,130,98,531,300,46,0,132,243,70,15,107,94,421,225,168,166,55,0,104,139,83,575,72,252,230,223,160,350,44,0,200,91,209,171,41,222,177,78,178,149,49,0,181,90,130,290,178,474,114,2,405,58,116,0,55,211,129,483,382,468,229,282,237,195,130,0,115,154,65,788,149,312,325,314,2,203,64,0,128,158,93,104,38,148,30,0,8,0,2,164,0,316,46,156,0,164,0,150,0,102,268,118,2,105,372,195,0,117,2,325,42,235,0,224,0,385,0,114,0,107,183,293,165,93,0,121,218,247,121,160,88,173,324,79,104,334,79,0,426,697,225,349,41,196,1,172,166,6,58,54,177,6,132,79,70,164,104,87,8,82,188,1,80,129,312,4,173,86,462,6,168,117,0,78,186,267,355,159,35,295,99],[124,28,2,6,7,60,0,1,0,13,9,3,27,79,14,27,16,30,92,2,80,17,0,1,31,76,31,13,45,172,1,29,98,102,47,4,188,28,43,75,28,20,91,51,48,14,33,3,269,231,493,82,96,20,149,55,33,26,27,1,670,210,62,125,4,5,33,23,38,43,0,3,119,92,38,123,25,38,410,14,135,20,33,5,287,967,22,88,2,9,94,2,42,5,74,2,1,2,114,349,162,5,0,2,15,1,12,4,53,208,6,47,10,6,49,11,9,25,14,9,12,163,9,6,42,20,2,19,6,7,14,12,156,114,24,59,11,13,5,9,28,7,2,0,0,318,176,9,30,7,26,12,29,29,16,11,2,23,23,194,2,15,8,14,22,10,6,2,102,27,51,89,87,13,14,19,14,6,13,0,42,1251,11,127,135,9,20,15,0,7,17,0,430,576,300,230,369,447,6,600,788,367,331,294,151,365,232,366,181,189,317,471,900,328,190,338,298,216,412,191,7,338,119,604,192,419,272,216,125,164,230,338,16,174,463,239,160,572,262,814,729,713,578,487,939,721,553,774,29,436,236,302,886,1133,541,752,875,1258,664,547,196,135,199,213,557,493,607,800,310,293,432,548,233,216,427,190,310,363,691,505,1032,441,505,455,446,155,206,492,38,599,207,378,472,449,534,488,376,371,84,276,301,319,771,296,378,596,407,519,395,259,251,229,325,27,485,166,456,368,520,445,1,268,555,3,653,290,414,216,290,272,1,100,2,145,109,362,320,278,484,255,79,726,327,344,270,188,366,249,195,431,151,365,205,185,276,233,222,93,175,459,417,310,137,428,180,371,469,174,181,787,407,164,217,823,609,98,0,312,417,174,107,204,185,877,360,290,326,202,1,244,253,141,1141,227,473,603,580,354,642,165,0,506,237,417,402,85,656,432,201,358,349,156,2,496,195,221,751,412,1148,286,5,1030,154,312,1,122,357,232,1281,964,864,534,687,476,533,205,0,233,419,147,1417,256,797,638,643,6,418,161,1,304,370,200,339,179,375,43,2,2,0,2,141,0,257,34,138,0,172,0,100,0,78,202,163,2,106,287,175,0,126,0,284,32,149,0,188,0,299,0,119,0,107,166,221,120,79,0,92,200,196,113,180,65,136,242,52,127,314,95,4,305,638,178,376,60,200,1,232,203,9,80,63,152,4,95,80,140,115,145,90,14,99,145,7,69,97,300,0,149,120,568,19,175,123,2,71,103,215,338,137,30,231,68],[0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]],\"type\":\"heatmap\",\"xaxis\":\"x\",\"yaxis\":\"y\",\"hovertemplate\":\"sample_id: %{x}\\u003cbr\\u003eamplicon: %{y}\\u003cbr\\u003ecolor: %{z}\\u003cextra\\u003e\\u003c\\u002fextra\\u003e\"}],                        {\"template\":{\"data\":{\"histogram2dcontour\":[{\"type\":\"histogram2dcontour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"choropleth\":[{\"type\":\"choropleth\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"histogram2d\":[{\"type\":\"histogram2d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmap\":[{\"type\":\"heatmap\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmapgl\":[{\"type\":\"heatmapgl\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"contourcarpet\":[{\"type\":\"contourcarpet\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"contour\":[{\"type\":\"contour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"surface\":[{\"type\":\"surface\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"mesh3d\":[{\"type\":\"mesh3d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"parcoords\":[{\"type\":\"parcoords\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolargl\":[{\"type\":\"scatterpolargl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"scattergeo\":[{\"type\":\"scattergeo\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolar\":[{\"type\":\"scatterpolar\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"scattergl\":[{\"type\":\"scattergl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatter3d\":[{\"type\":\"scatter3d\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattermapbox\":[{\"type\":\"scattermapbox\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterternary\":[{\"type\":\"scatterternary\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattercarpet\":[{\"type\":\"scattercarpet\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}]},\"layout\":{\"autotypenumbers\":\"strict\",\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"hovermode\":\"closest\",\"hoverlabel\":{\"align\":\"left\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"bgcolor\":\"#E5ECF6\",\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"ternary\":{\"bgcolor\":\"#E5ECF6\",\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]]},\"xaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"yaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"geo\":{\"bgcolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"subunitcolor\":\"white\",\"showland\":true,\"showlakes\":true,\"lakecolor\":\"white\"},\"title\":{\"x\":0.05},\"mapbox\":{\"style\":\"light\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"title\":{\"text\":\"sample_id\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"autorange\":\"reversed\",\"title\":{\"text\":\"amplicon\"}},\"coloraxis\":{\"colorscale\":[[0.0,\"rgb(247,251,255)\"],[0.125,\"rgb(222,235,247)\"],[0.25,\"rgb(198,219,239)\"],[0.375,\"rgb(158,202,225)\"],[0.5,\"rgb(107,174,214)\"],[0.625,\"rgb(66,146,198)\"],[0.75,\"rgb(33,113,181)\"],[0.875,\"rgb(8,81,156)\"],[1.0,\"rgb(8,48,107)\"]]},\"margin\":{\"t\":60},\"height\":1000,\"width\":1000},                        {\"responsive\": true}                    ).then(function(){\n", "                            \n", "var gd = document.getElementById('b2702371-b533-472e-a35a-9b123d2e1a68');\n", "var x = new MutationObserver(function (mutations, observer) {{\n", "        var display = window.getComputedStyle(gd).display;\n", "        if (!display || display === 'none') {{\n", "            console.log([gd, 'removed!']);\n", "            Plotly.purge(gd);\n", "            observer.disconnect();\n", "        }}\n", "}});\n", "\n", "// Listen for the removal of the full notebook cells\n", "var notebookContainer = gd.closest('#notebook-container');\n", "if (notebookContainer) {{\n", "    x.observe(notebookContainer, {childList: true});\n", "}}\n", "\n", "// Listen for the clearing of the current output cell\n", "var outputEl = gd.closest('.output');\n", "if (outputEl) {{\n", "    x.observe(outputEl, {childList: true});\n", "}}\n", "\n", "                        })                };                });            </script>        </div>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["# pivot to heatmap shape and take mean where we have multiple SNPs in one amplicon \n", "df = target_cov_df.pivot_table(index='amplicon', columns='sample_id', values='depth', aggfunc='mean').fillna(0).astype(int)\n", "# reorder amplicons alphabetical\n", "order = natural_sort(df.index.to_list())\n", "df = df.loc[order]\n", "\n", "df.to_excel(f\"{wkdir}/results/coverage/amplicon_by_sample_depth.xlsx\")\n", "\n", "from IPython.display import display, Markdown\n", "display(Markdown(f'<a href=\"{wkdir}/results/coverage/amplicon_by_sample_depth.xlsx\">Amplicon by sample read depth (.xlsx)</a>'))\n", "\n", "px.imshow(df, width=1000, height=1000, color_continuous_scale='blues', aspect='auto')"]}, {"cell_type": "code", "execution_count": null, "id": "e8983a8c", "metadata": {"papermill": {"duration": 0.83689, "end_time": "2024-12-04T12:15:03.488180", "exception": false, "start_time": "2024-12-04T12:15:02.651290", "status": "completed"}, "tags": []}, "outputs": [], "source": []}, {"cell_type": "code", "execution_count": null, "id": "26e4787a", "metadata": {"papermill": {"duration": 0.744688, "end_time": "2024-12-04T12:15:05.065106", "exception": false, "start_time": "2024-12-04T12:15:04.320418", "status": "completed"}, "tags": []}, "outputs": [], "source": []}], "metadata": {"celltoolbar": "Tags", "kernelspec": {"display_name": "3b1c9fccc6ddcee649a430b64373b071_", "language": "python", "name": "python3"}, "language_info": {"codemirror_mode": {"name": "ipython", "version": 3}, "file_extension": ".py", "mimetype": "text/x-python", "name": "python", "nbconvert_exporter": "python", "pygments_lexer": "ipython3", "version": "3.12.7"}, "papermill": {"default_parameters": {}, "duration": 20.760171, "end_time": "2024-12-04T12:15:06.626322", "environment_variables": {}, "exception": null, "input_path": "/home/snagi/lstm_projects/ampseq-agvampir002/workflow/notebooks/coverage.ipynb", "output_path": "results/notebooks/coverage.ipynb", "parameters": {"bed_targets_path": "config/ag-vampir.bed", "metadata_path": "config/metadata_ms.tsv", "wkdir": "/home/snagi/lstm_projects/ampseq-agvampir002"}, "start_time": "2024-12-04T12:14:45.866151", "version": "2.6.0"}}, "nbformat": 4, "nbformat_minor": 5}